# -*- coding: utf-8 -*-
################################################################################
#                                                                              #
# tonescale                                                                    #
#                                                                              #
################################################################################
#                                                                              #
# LICENCE INFORMATION                                                          #
#                                                                              #
# This program provides sound utilities and sounds.                            #
#                                                                              #
# copyright (C) 2017 William Breaden Madden                                    #
#                                                                              #
# This software is released under the terms of the GNU General Public License  #
# version 3 (GPLv3).                                                           #
#                                                                              #
# This program is free software: you can redistribute it and/or modify it      #
# under the terms of the GNU General Public License as published by the Free   #
# Software Foundation, either version 3 of the License, or (at your option)    #
# any later version.                                                           #
#                                                                              #
# This program is distributed in the hope that it will be useful, but WITHOUT  #
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        #
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for     #
# more details.                                                                #
#                                                                              #
# For a copy of the GNU General Public License, see                            #
# <http://www.gnu.org/licenses/>.                                              #
#                                                                              #
################################################################################
from __future__ import division

name    = "tonescale"
version = "2017-01-13T1331Z"

import os

import numpy
import scipy.io.wavfile
import shijian

class Sound(object):

    def __init__(
        self,
        name = None,
        rate = 41000,
        data = None
        ):

        self._name = name
        self._rate = rate
        self._data = data

    def name(
        self
        ):

        return self._name

    def set_name(
        self,
        name = None
        ):

        self._name = name

    def rate(
        self
        ):

        return self._rate

    def set_rate(
        self,
        rate = None
        ):

        self._rate = rate

    def data(
        self
        ):

        return self._data

    def set_data(
        self,
        data = None
        ):
        self._data = data

    def read_WAVE(
        self,
        filename = None
        ):

        self._rate, self._data = scipy.io.wavfile.read(filename)
        if self._name is None:
            self._name = filename.rstrip(".wav").rstrip(".WAV")

    def save_WAVE(
        self,
        filename = None
        ):

        if filename is None:
            filename = shijian.slugify(text = self._name)
        scipy.io.wavfile.write(
            filename,
            self._rate,
            self._data
        )

    def save_plaintext(
        self,
        filename = None
        ):

        if filename is None:
            filename = shijian.slugify(text = self._name)
        file_save = open(filename, "w")
        numpy_print_option_threshold_tmp = numpy.get_printoptions()["threshold"]
        numpy.set_printoptions(threshold = numpy.nan)
        file_save.write(numpy.array_repr(self._data))
        numpy.set_printoptions(threshold = numpy_print_option_threshold_tmp)
        file_save.close()

    def repeat(
        self,
        number = None
        ):

        data_tmp = numpy.concatenate((self._data,) * number)
        self._data = data_tmp

    def play(
        self,
        background = False
        ):

        filename_tmp = shijian.propose_filename(
            filename = shijian.time_UTC() + ".wav"
        )
        self.save_WAVE(
            filename = filename_tmp
        )
        command = """
        aplay --quiet "{filename}"
        """.format(
            filename = filename_tmp
        )
        if background:
            command = command.rstrip().rstrip("\n") + " &"
        shijian.engage_command(
            command = command
        )
        os.remove(filename_tmp)

sounds = []

def access_sound(
    name = None
    ):

    for sound in sounds:
        if sound.name() == name:
            return sound
    return None

def convert_WAVE_file_to_tonescale_sound_file(
    filename_WAVE            = None,
    filename_tonescale_sound = None
    ):

    filename_tonescale_sound = filename_WAVE.rstrip(".wav").rstrip(".WAV")
    filename_tonescale_sound = shijian.propose_filename(
        filename = filename_tonescale_sound + ".py"
    )
    sound = Sound()
    sound.read_WAVE(filename = filename_WAVE)
    sound.save_plaintext(filename = filename_tonescale_sound)

sounds.append(Sound(
    name = "199935__drzhnn__04-blip",
    rate = 41000,
    data = numpy.array([[     1,      1],
                        [     1,      2],
                        [     1,      1],
                        [     1,      1],
                        [     3,      4],
                        [     4,      4],
                        [     2,      2],
                        [     2,      2],
                        [    -1,      1],
                        [    -1,      1],
                        [     6,      7],
                        [     8,      9],
                        [     6,      6],
                        [     2,      1],
                        [     4,      2],
                        [     6,      5],
                        [     0,      2],
                        [     2,      2],
                        [     2,      1],
                        [     0,     -2],
                        [     5,      6],
                        [     3,      7],
                        [     1,      2],
                        [     2,      0],
                        [     4,      4],
                        [     7,      9],
                        [     3,      2],
                        [     2,      2],
                        [     4,      7],
                        [    -1,     -2],
                        [    -2,      0],
                        [     2,      4],
                        [    10,      7],
                        [     2,      2],
                        [    -4,     -2],
                        [    11,     11],
                        [    -4,     -4],
                        [     2,      3],
                        [    12,     12],
                        [    -8,     -8],
                        [     6,      5],
                        [     4,      7],
                        [    -1,      0],
                        [     8,      8],
                        [     2,      7],
                        [     1,      0],
                        [     7,      6],
                        [     2,      5],
                        [    -1,      0],
                        [     7,      6],
                        [    -2,      1],
                        [     2,      2],
                        [     4,      2],
                        [     2,      5],
                        [     4,      2],
                        [     2,     -1],
                        [     5,      6],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     1,      2],
                        [     2,      2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     7,      8],
                        [     5,      5],
                        [     2,      2],
                        [     7,     10],
                        [     2,      3],
                        [     2,      1],
                        [     6,      6],
                        [     1,      0],
                        [    -2,     -1],
                        [     7,      6],
                        [    -2,     -2],
                        [     4,      3],
                        [    10,      9],
                        [    -4,     -2],
                        [     4,      5],
                        [    -1,     -2],
                        [    -3,     -2],
                        [     9,      9],
                        [     2,      2],
                        [     2,      3],
                        [    -6,     -5],
                        [    -4,     -3],
                        [    11,      9],
                        [    -4,     -4],
                        [     2,      2],
                        [    11,      9],
                        [     5,      4],
                        [     7,      7],
                        [    -5,     -5],
                        [     7,      4],
                        [     5,      5],
                        [    -5,     -3],
                        [    10,      9],
                        [    -2,     -3],
                        [     2,      1],
                        [    11,     11],
                        [    -1,     -5],
                        [     0,      2],
                        [     2,      6],
                        [    -1,     -3],
                        [     7,      8],
                        [    10,      9],
                        [     4,      3],
                        [     6,      7],
                        [    -5,     -4],
                        [    -2,      0],
                        [     8,      7],
                        [    -1,      1],
                        [    -5,     -4],
                        [     4,      3],
                        [     2,      5],
                        [    -1,     -3],
                        [    12,     11],
                        [    -1,      1],
                        [    -6,     -6],
                        [    10,      9],
                        [     2,      2],
                        [     2,      1],
                        [     1,      0],
                        [     6,      5],
                        [     5,      2],
                        [    -4,     -2],
                        [     6,      7],
                        [     0,     -1],
                        [    -2,      0],
                        [     6,      5],
                        [     1,      2],
                        [    -2,     -4],
                        [    -4,     -2],
                        [    -1,      2],
                        [     1,     -2],
                        [     4,      8],
                        [     8,      8],
                        [     1,     -3],
                        [    -4,     -2],
                        [     1,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      0],
                        [    -4,     -2],
                        [     2,      2],
                        [     2,      3],
                        [    -4,     -2],
                        [     2,     -1],
                        [    -4,     -2],
                        [     4,      4],
                        [     3,      1],
                        [    -7,     -4],
                        [     7,      6],
                        [     2,     -1],
                        [    -2,     -2],
                        [     4,      7],
                        [    -1,      1],
                        [    -3,     -6],
                        [    -9,    -11],
                        [    -7,     -6],
                        [     7,      7],
                        [     1,      0],
                        [     5,      7],
                        [     6,      8],
                        [    -7,     -5],
                        [     0,     -2],
                        [    -3,     -3],
                        [    -5,     -5],
                        [    -2,     -3],
                        [    -2,     -3],
                        [     0,      0],
                        [    -4,     -2],
                        [    -3,     -2],
                        [     3,      2],
                        [     3,      2],
                        [    -2,     -2],
                        [    -6,     -4],
                        [     1,      1],
                        [     1,     -1],
                        [     0,     -1],
                        [    -2,     -3],
                        [    -4,     -4],
                        [    -1,      0],
                        [    -3,     -3],
                        [     5,      6],
                        [    -2,      1],
                        [    -7,     -5],
                        [     9,      8],
                        [     3,      3],
                        [    -3,     -1],
                        [     1,      3],
                        [    -1,     -3],
                        [     2,      1],
                        [     3,      2],
                        [    -2,     -3],
                        [     0,      3],
                        [     4,      4],
                        [    -2,     -5],
                        [    -5,     -7],
                        [    -5,     -4],
                        [     1,      3],
                        [     6,      4],
                        [    -7,     -7],
                        [     3,      4],
                        [     5,      4],
                        [    -5,     -4],
                        [     5,      3],
                        [    -7,     -7],
                        [    -7,     -4],
                        [    -3,     -4],
                        [    -7,     -8],
                        [     7,      7],
                        [     0,      2],
                        [    -4,     -3],
                        [     1,     -2],
                        [     0,      0],
                        [     1,      1],
                        [    -8,     -7],
                        [    -4,     -2],
                        [     3,      2],
                        [     1,      0],
                        [    -7,     -8],
                        [    -1,      0],
                        [     2,      0],
                        [    -9,     -9],
                        [     6,      7],
                        [     8,      8],
                        [    -4,     -5],
                        [   -10,    -11],
                        [    -4,     -2],
                        [     4,      3],
                        [     2,      2],
                        [     2,      3],
                        [    -3,     -6],
                        [    -4,     -4],
                        [     1,      0],
                        [    -5,     -7],
                        [    -5,     -3],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -7],
                        [    -5,     -3],
                        [     2,      4],
                        [    -2,     -3],
                        [    -9,     -7],
                        [    -3,     -3],
                        [     1,      2],
                        [     0,      1],
                        [    -7,     -9],
                        [    -2,     -2],
                        [    -6,     -2],
                        [     2,      1],
                        [     5,      2],
                        [    -8,     -5],
                        [    -1,     -2],
                        [     0,     -3],
                        [     4,      5],
                        [    -2,     -1],
                        [    -6,     -5],
                        [     3,      6],
                        [    -5,     -7],
                        [    -5,     -8],
                        [     6,      6],
                        [    -3,     -5],
                        [    -3,      0],
                        [     7,      8],
                        [    -2,     -4],
                        [    -3,     -4],
                        [    -3,     -2],
                        [     0,     -1],
                        [     3,      4],
                        [    -2,     -2],
                        [     3,      2],
                        [     1,     -1],
                        [    -7,     -8],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -1,     -2],
                        [    -3,     -4],
                        [    -4,     -5],
                        [     2,      1],
                        [     6,      3],
                        [    -2,     -2],
                        [    -3,     -1],
                        [     2,      3],
                        [    -1,     -2],
                        [    -1,     -3],
                        [    -6,     -6],
                        [    -7,     -6],
                        [    -5,     -4],
                        [     2,      0],
                        [     8,      7],
                        [    -1,     -1],
                        [    -6,     -4],
                        [    -5,     -4],
                        [    -4,     -6],
                        [     3,      2],
                        [     2,      1],
                        [    -6,     -6],
                        [     4,      3],
                        [    -1,     -1],
                        [    -5,     -6],
                        [     1,      2],
                        [    -2,     -2],
                        [    -7,     -9],
                        [     0,      2],
                        [     4,      3],
                        [     1,     -3],
                        [    -3,     -3],
                        [    -1,     -2],
                        [     1,     -1],
                        [    -8,     -7],
                        [     1,      1],
                        [    -7,     -7],
                        [    -6,     -6],
                        [     3,      3],
                        [   -11,    -11],
                        [     0,     -2],
                        [     2,      1],
                        [    -9,    -10],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -8,     -7],
                        [    -6,     -8],
                        [    -6,     -7],
                        [    -5,     -4],
                        [    -3,     -5],
                        [    -2,     -3],
                        [     2,      0],
                        [    -4,     -2],
                        [    -7,     -6],
                        [    -2,     -5],
                        [    -2,     -2],
                        [    -4,     -4],
                        [     2,      2],
                        [     1,     -2],
                        [    -9,    -10],
                        [    -7,     -7],
                        [    -1,      0],
                        [     4,      2],
                        [    -6,    -10],
                        [    -7,     -4],
                        [    -2,      0],
                        [    -5,     -6],
                        [     1,      3],
                        [    -5,     -7],
                        [   -10,    -11],
                        [     0,      2],
                        [    -5,     -6],
                        [    -5,     -4],
                        [    -2,     -2],
                        [    -6,     -6],
                        [    -2,     -2],
                        [    -4,     -6],
                        [     3,      3],
                        [    -4,     -3],
                        [    -6,     -7],
                        [     4,      3],
                        [   -11,    -11],
                        [    -5,     -2],
                        [     0,      0],
                        [    -8,    -10],
                        [    -7,     -7],
                        [   -10,    -10],
                        [     0,     -1],
                        [     2,      1],
                        [    -7,     -6],
                        [     0,     -1],
                        [    -6,     -7],
                        [    -4,     -4],
                        [     3,      1],
                        [   -12,    -13],
                        [    -6,     -6],
                        [     1,      1],
                        [    -6,     -5],
                        [    -2,     -2],
                        [    -4,     -7],
                        [    -4,     -5],
                        [    -3,     -1],
                        [    -1,     -2],
                        [     1,      0],
                        [    -7,     -9],
                        [    -9,    -11],
                        [    -3,     -2],
                        [    -2,     -3],
                        [    -6,     -5],
                        [    -2,     -4],
                        [    -4,     -6],
                        [    -4,     -1],
                        [     1,      0],
                        [    -7,     -7],
                        [    -2,     -2],
                        [    -4,     -2],
                        [    -5,     -3],
                        [     1,     -1],
                        [    -6,     -5],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -7,     -6],
                        [     1,      1],
                        [    -3,     -5],
                        [    -2,     -2],
                        [     3,      1],
                        [    -7,     -7],
                        [     1,      3],
                        [    -3,     -4],
                        [    -9,     -9],
                        [    -2,     -2],
                        [    -6,     -5],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -4],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -5,     -5],
                        [    -3,     -3],
                        [    -6,     -7],
                        [    -7,     -7],
                        [    -1,     -2],
                        [    -5,     -4],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -8,     -6],
                        [     2,      2],
                        [    -2,     -3],
                        [     1,      2],
                        [     5,      5],
                        [    -5,     -7],
                        [    -1,     -2],
                        [    -7,     -7],
                        [    -2,     -2],
                        [     7,      5],
                        [    -7,     -6],
                        [    -2,     -3],
                        [    -2,     -2],
                        [    -3,     -4],
                        [    -3,     -5],
                        [    -8,     -8],
                        [     4,      3],
                        [    -3,     -1],
                        [    -8,     -7],
                        [     9,      9],
                        [     1,     -1],
                        [    -9,     -8],
                        [    -1,      0],
                        [    -2,     -3],
                        [    -6,     -7],
                        [     5,      6],
                        [    -3,     -2],
                        [   -10,    -11],
                        [    -1,      0],
                        [     1,      0],
                        [     3,      0],
                        [    -2,     -1],
                        [    -5,     -2],
                        [    -2,     -2],
                        [    -3,     -3],
                        [    -4,     -4],
                        [     2,      2],
                        [    -4,     -4],
                        [    -6,     -3],
                        [     2,      3],
                        [    -7,     -7],
                        [    -3,     -3],
                        [    -3,     -5],
                        [    -1,      0],
                        [    -2,     -1],
                        [    -7,     -6],
                        [     6,      6],
                        [     0,     -3],
                        [    -2,     -3],
                        [    -2,     -1],
                        [    -3,     -4],
                        [    -2,     -1],
                        [     1,      0],
                        [    -1,      0],
                        [    -8,     -6],
                        [    -2,     -3],
                        [    -3,     -4],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -3],
                        [    -2,     -2],
                        [    -5,     -2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -3,     -3],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -6,     -3],
                        [    -5,     -2],
                        [    -3,     -4],
                        [    -8,     -9],
                        [     3,      3],
                        [     7,      8],
                        [    -6,     -6],
                        [   -11,     -9],
                        [    -2,      0],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -5,     -2],
                        [    -1,     -1],
                        [    -2,     -4],
                        [    -6,     -5],
                        [     2,      3],
                        [    -1,     -2],
                        [    -4,     -3],
                        [     0,      0],
                        [     1,      2],
                        [    -3,      0],
                        [    -1,     -4],
                        [    -3,     -5],
                        [    -7,     -2],
                        [     5,      3],
                        [    -3,     -3],
                        [    -6,     -6],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     3,      2],
                        [     2,      1],
                        [     1,      2],
                        [    -3,     -2],
                        [    -2,     -4],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -7,     -7],
                        [    -2,     -3],
                        [     6,      6],
                        [    -1,      1],
                        [    -3,     -4],
                        [    -4,     -4],
                        [    -2,     -1],
                        [     2,      2],
                        [    -2,     -3],
                        [    -1,      2],
                        [     0,      0],
                        [    -3,     -4],
                        [    -1,      1],
                        [     1,      0],
                        [    -2,     -1],
                        [     1,     -1],
                        [    -5,     -5],
                        [    -1,     -1],
                        [     5,      6],
                        [    -4,     -2],
                        [     3,      1],
                        [     5,      6],
                        [     2,      0],
                        [    -2,     -3],
                        [    -2,      2],
                        [     0,      0],
                        [    -3,     -3],
                        [     0,     -1],
                        [     1,      2],
                        [    -2,      2],
                        [    -7,     -8],
                        [     4,      4],
                        [     2,      2],
                        [    -3,     -4],
                        [     2,      3],
                        [    -7,     -7],
                        [    -2,     -4],
                        [    -2,     -2],
                        [    -3,     -4],
                        [     6,      5],
                        [    -1,     -2],
                        [    -3,     -3],
                        [     5,      6],
                        [    -3,     -6],
                        [    -2,     -3],
                        [    -3,     -1],
                        [    -4,     -2],
                        [     2,      2],
                        [     0,     -2],
                        [    -2,     -2],
                        [     0,      2],
                        [     2,      2],
                        [     0,      0],
                        [     1,     -2],
                        [     1,     -3],
                        [     0,      2],
                        [    -4,     -7],
                        [    -2,     -2],
                        [     2,      3],
                        [     1,      0],
                        [    -4,     -3],
                        [    -5,     -7],
                        [     4,      3],
                        [     2,      4],
                        [    -2,     -3],
                        [     0,      0],
                        [     3,      5],
                        [     1,      0],
                        [     0,      0],
                        [     4,      4],
                        [     3,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,      1],
                        [    -2,     -2],
                        [     2,      4],
                        [     6,      7],
                        [    -5,     -7],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,     -1],
                        [     1,      2],
                        [     4,      5],
                        [     5,      4],
                        [    -1,     -1],
                        [     0,      2],
                        [    -2,     -1],
                        [     1,      1],
                        [     2,      2],
                        [    -1,      0],
                        [    -1,      0],
                        [    -2,     -1],
                        [     0,      2],
                        [     6,      5],
                        [     2,      2],
                        [     2,      3],
                        [     4,      3],
                        [    -5,     -4],
                        [    -2,     -1],
                        [     2,      2],
                        [     4,      3],
                        [     0,     -2],
                        [    -2,     -2],
                        [     4,      7],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     3,      2],
                        [     3,      5],
                        [     3,      4],
                        [     2,      2],
                        [     2,      2],
                        [     3,      2],
                        [     5,      7],
                        [    -2,     -1],
                        [     1,     -2],
                        [     2,      4],
                        [    -3,     -2],
                        [     4,      2],
                        [     4,      3],
                        [     0,      1],
                        [    -7,     -7],
                        [    -1,      0],
                        [     7,      7],
                        [    -2,     -4],
                        [     2,      2],
                        [     3,      4],
                        [     2,      1],
                        [    -2,      0],
                        [     1,      0],
                        [     4,      4],
                        [     0,      2],
                        [    -1,      1],
                        [    -2,     -3],
                        [     1,      0],
                        [    -2,     -1],
                        [    -4,     -3],
                        [     4,      2],
                        [    -1,     -2],
                        [     3,      2],
                        [     2,      2],
                        [     0,      0],
                        [     4,      7],
                        [    -7,     -7],
                        [    -2,     -2],
                        [    10,      9],
                        [    -5,     -6],
                        [    -2,      0],
                        [     4,      2],
                        [    -4,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [    -5,     -6],
                        [    -1,     -4],
                        [     1,      2],
                        [     2,      0],
                        [     7,      3],
                        [     0,      2],
                        [    -9,    -10],
                        [     0,     -1],
                        [     0,      1],
                        [     0,     -1],
                        [     3,      4],
                        [    -3,     -3],
                        [     7,      5],
                        [     6,      6],
                        [   -10,     -8],
                        [     3,      7],
                        [     3,      2],
                        [    -5,     -7],
                        [     3,      6],
                        [    -1,     -1],
                        [     0,     -1],
                        [     7,      5],
                        [     2,      3],
                        [     0,      1],
                        [     7,      7],
                        [     4,      3],
                        [     0,      0],
                        [     3,      2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [     6,      6],
                        [     4,      6],
                        [    -4,     -5],
                        [     3,      2],
                        [     3,      3],
                        [    -4,     -4],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      1],
                        [     4,      3],
                        [    -2,     -3],
                        [    -1,      0],
                        [     7,      8],
                        [    -1,      0],
                        [     1,      0],
                        [     5,      5],
                        [    -4,     -3],
                        [     3,      2],
                        [     5,      5],
                        [    -2,     -3],
                        [     2,      2],
                        [     3,      4],
                        [     2,      2],
                        [     6,      5],
                        [    -2,     -1],
                        [     2,      1],
                        [     4,      6],
                        [    -2,      0],
                        [     2,      0],
                        [    -1,     -2],
                        [     5,      4],
                        [     9,      9],
                        [    -2,     -1],
                        [     5,      5],
                        [     2,      2],
                        [    -3,     -2],
                        [     3,      2],
                        [    -1,     -1],
                        [     2,      4],
                        [    -1,     -3],
                        [    -1,     -2],
                        [     4,      4],
                        [     0,     -2],
                        [     3,      3],
                        [     3,      2],
                        [    -2,     -2],
                        [    -1,      2],
                        [     4,      2],
                        [    -2,      0],
                        [    -4,     -3],
                        [     1,     -2],
                        [     4,      5],
                        [     0,      2],
                        [    -4,     -4],
                        [     2,      2],
                        [     1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [    -4,     -5],
                        [     3,      4],
                        [     9,     11],
                        [     0,      0],
                        [    -1,     -2],
                        [     4,      3],
                        [     1,      1],
                        [     4,      3],
                        [     7,      4],
                        [    -1,     -1],
                        [     2,      2],
                        [     4,      2],
                        [     1,      1],
                        [    -3,     -3],
                        [     2,      3],
                        [     7,      6],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      3],
                        [     3,      5],
                        [     7,      7],
                        [     2,      2],
                        [     2,      1],
                        [     1,     -1],
                        [    -1,      0],
                        [     4,      5],
                        [     3,      1],
                        [     1,      0],
                        [     3,      4],
                        [     5,      2],
                        [    -2,     -2],
                        [    -5,     -2],
                        [     8,      7],
                        [     2,      1],
                        [    -7,     -5],
                        [     8,      8],
                        [     3,      3],
                        [    -4,     -3],
                        [     4,      3],
                        [     1,      2],
                        [     2,      2],
                        [     5,      3],
                        [     1,      2],
                        [     3,      3],
                        [     2,      2],
                        [    -2,     -2],
                        [     5,      6],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -1],
                        [     9,      9],
                        [     1,     -2],
                        [     0,      3],
                        [     5,      6],
                        [    -3,     -5],
                        [     1,      2],
                        [     1,      2],
                        [     5,      5],
                        [     2,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     4,      4],
                        [     5,      2],
                        [     4,      3],
                        [     2,      1],
                        [    -5,     -5],
                        [     8,      8],
                        [     5,      4],
                        [    -2,     -2],
                        [     8,      7],
                        [     1,     -1],
                        [     3,      4],
                        [     3,      3],
                        [    -2,     -3],
                        [     3,      5],
                        [     3,      2],
                        [     1,     -1],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      1],
                        [     6,      5],
                        [     1,      0],
                        [    -3,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [     2,      3],
                        [     3,      3],
                        [     2,      2],
                        [     2,      2],
                        [    -3,     -2],
                        [     4,      2],
                        [     7,      9],
                        [    -6,     -4],
                        [     5,      4],
                        [     4,      7],
                        [    -2,     -1],
                        [     2,      1],
                        [    -1,      1],
                        [     7,      8],
                        [     5,      5],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      2],
                        [     5,      6],
                        [     3,      2],
                        [     3,      2],
                        [     2,      4],
                        [     4,      5],
                        [     2,      3],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [     6,      7],
                        [     2,      2],
                        [     2,      2],
                        [     2,      4],
                        [     1,      2],
                        [     3,      5],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [     1,      2],
                        [     7,      8],
                        [    -2,     -2],
                        [     2,      4],
                        [     4,      7],
                        [    -2,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     6,      7],
                        [     3,      4],
                        [     0,     -2],
                        [     2,      2],
                        [    -3,     -1],
                        [     2,      3],
                        [     5,      5],
                        [     0,      0],
                        [     4,      6],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      3],
                        [     1,      0],
                        [     2,      1],
                        [    -1,      0],
                        [     6,      7],
                        [     0,     -1],
                        [    -1,     -1],
                        [     7,      7],
                        [     0,      1],
                        [     2,      4],
                        [     1,     -2],
                        [     0,     -1],
                        [     1,      3],
                        [     2,      0],
                        [     1,      0],
                        [    -2,     -2],
                        [     2,      3],
                        [     4,      4],
                        [     6,      5],
                        [    -1,      0],
                        [     2,      0],
                        [     6,      5],
                        [     2,      2],
                        [    -2,     -1],
                        [     0,      0],
                        [     6,      7],
                        [     0,      2],
                        [     4,      3],
                        [     2,      2],
                        [     1,      1],
                        [     1,     -1],
                        [    -2,     -2],
                        [    10,      8],
                        [     3,      2],
                        [    -6,     -4],
                        [     2,      2],
                        [     4,      2],
                        [    -2,     -2],
                        [     0,      2],
                        [     7,      6],
                        [     2,      0],
                        [     1,      1],
                        [     2,      1],
                        [     0,     -1],
                        [     1,     -1],
                        [     7,      7],
                        [     4,      5],
                        [     3,      2],
                        [     3,      4],
                        [    -2,     -4],
                        [     3,      2],
                        [     2,      2],
                        [     2,      1],
                        [     2,      5],
                        [     3,      2],
                        [    -2,     -2],
                        [    -1,      2],
                        [     5,      3],
                        [    -1,      0],
                        [    -2,     -1],
                        [     2,      2],
                        [     5,      6],
                        [     4,      3],
                        [     2,      2],
                        [    -2,     -1],
                        [     1,      1],
                        [     7,      7],
                        [     0,      0],
                        [     1,      2],
                        [     5,      7],
                        [    -2,     -3],
                        [     2,      2],
                        [     2,      4],
                        [    -1,      0],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     0,     -2],
                        [     1,      1],
                        [     7,      7],
                        [     1,      1],
                        [    -2,      0],
                        [     4,      4],
                        [     1,      1],
                        [     2,      3],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     5,      5],
                        [    -2,     -2],
                        [     0,      1],
                        [     3,      3],
                        [     3,      2],
                        [     2,      1],
                        [    -2,     -2],
                        [     4,      5],
                        [     6,      4],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,      0],
                        [     8,     11],
                        [     6,      5],
                        [    -2,     -2],
                        [     2,      2],
                        [    -3,     -2],
                        [     2,      2],
                        [     7,      6],
                        [    -1,      2],
                        [     0,      1],
                        [    -1,     -2],
                        [    -1,      1],
                        [     7,      7],
                        [     6,      5],
                        [    -1,      0],
                        [    -4,     -3],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     7,      6],
                        [     1,      3],
                        [     5,      5],
                        [     2,      0],
                        [    -5,     -5],
                        [     4,      3],
                        [     0,      2],
                        [     2,      4],
                        [     4,      4],
                        [    -2,     -1],
                        [     2,      2],
                        [    -1,     -2],
                        [     0,      1],
                        [     3,      5],
                        [    -1,     -2],
                        [     2,      2],
                        [     1,      2],
                        [     1,      0],
                        [     7,      6],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -3,     -3],
                        [     4,      5],
                        [     2,      0],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     2,      4],
                        [     3,      2],
                        [     0,      0],
                        [    -3,     -5],
                        [     5,      5],
                        [     2,      3],
                        [    -4,     -3],
                        [     6,      7],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,      2],
                        [     4,      5],
                        [     7,      6],
                        [    -2,     -2],
                        [     3,      4],
                        [     3,      2],
                        [    -2,     -1],
                        [     2,      5],
                        [     3,      2],
                        [     1,      1],
                        [     2,      4],
                        [    -4,     -3],
                        [    -1,      0],
                        [     7,      7],
                        [    -2,      0],
                        [     2,      2],
                        [     1,      1],
                        [    -3,     -2],
                        [     7,      5],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      1],
                        [     5,      4],
                        [    -1,      0],
                        [    -2,      0],
                        [     7,      5],
                        [     4,      3],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [     4,      2],
                        [     2,      3],
                        [     3,      4],
                        [    -2,     -2],
                        [    -2,     -3],
                        [     2,     -1],
                        [    -7,     -5],
                        [     5,      5],
                        [     3,      4],
                        [    -2,     -1],
                        [     6,      4],
                        [    -2,     -2],
                        [     3,      3],
                        [     3,      2],
                        [    -2,     -2],
                        [     5,      5],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     2,      1],
                        [     0,      0],
                        [     2,      0],
                        [    -3,     -2],
                        [     0,      1],
                        [     6,      2],
                        [    -1,     -1],
                        [    -4,     -3],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      2],
                        [    -2,     -2],
                        [     2,      2],
                        [     5,      4],
                        [    -1,      0],
                        [     0,      0],
                        [    -3,     -5],
                        [    -1,      1],
                        [     2,      0],
                        [    -3,     -2],
                        [     4,      7],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     6,      4],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     0,      2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     3,      2],
                        [     4,      3],
                        [     2,      3],
                        [     1,      1],
                        [    -5,     -6],
                        [     1,      2],
                        [     2,      2],
                        [    -1,     -2],
                        [     1,      0],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     6,      4],
                        [     1,      1],
                        [    -2,     -1],
                        [     4,      3],
                        [     4,      2],
                        [     3,      2],
                        [    -3,     -2],
                        [     2,      2],
                        [     2,      1],
                        [    -3,     -2],
                        [     2,      2],
                        [     1,     -1],
                        [    -2,     -1],
                        [     1,      0],
                        [     7,      5],
                        [    -5,     -2],
                        [     0,      1],
                        [    10,      7],
                        [     0,      0],
                        [     0,      1],
                        [     2,      1],
                        [     2,      2],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     2,      0],
                        [     5,      4],
                        [     0,      1],
                        [     1,      2],
                        [     4,      4],
                        [     0,      0],
                        [     1,      2],
                        [     0,     -1],
                        [     2,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     7,      7],
                        [    -3,     -2],
                        [     0,      1],
                        [     2,      3],
                        [    -2,     -3],
                        [     3,      2],
                        [     2,      3],
                        [     4,      4],
                        [     1,     -2],
                        [    -7,     -5],
                        [     5,      3],
                        [     5,      2],
                        [     2,      5],
                        [     5,      5],
                        [     1,      1],
                        [    -1,      0],
                        [     0,     -1],
                        [    -2,     -1],
                        [     3,      3],
                        [     1,      1],
                        [    -5,     -4],
                        [     4,      3],
                        [    -2,     -2],
                        [    -4,     -3],
                        [     6,      6],
                        [    -2,     -2],
                        [     1,      1],
                        [     5,      5],
                        [    -4,     -3],
                        [     0,     -1],
                        [     4,      5],
                        [     2,      2],
                        [    -2,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     3,      3],
                        [     3,      4],
                        [    -2,     -1],
                        [    -2,     -3],
                        [     0,      0],
                        [     0,      2],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     4,      4],
                        [    -2,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [    -3,     -2],
                        [     4,      2],
                        [     4,      4],
                        [    -2,      0],
                        [     5,      3],
                        [     2,      2],
                        [     1,      2],
                        [     2,      2],
                        [    -3,     -3],
                        [     0,      1],
                        [     1,      1],
                        [    -4,     -5],
                        [     2,      2],
                        [     3,      3],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      0],
                        [    -5,     -7],
                        [     2,      3],
                        [    -1,      0],
                        [    -2,     -2],
                        [     4,      5],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -6,     -5],
                        [     6,      6],
                        [     2,      2],
                        [    -4,     -5],
                        [     7,      6],
                        [     0,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [    -2,     -4],
                        [    -1,     -1],
                        [     3,      4],
                        [     0,      0],
                        [     1,     -1],
                        [    -2,     -2],
                        [    -2,      0],
                        [     1,      1],
                        [    -4,     -4],
                        [     2,      2],
                        [    -4,     -3],
                        [     1,      2],
                        [     2,      3],
                        [    -4,     -4],
                        [     7,      5],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -3],
                        [     0,     -1],
                        [     2,      3],
                        [    -2,     -2],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -4,     -2],
                        [    -4,     -5],
                        [     4,      2],
                        [    -3,     -1],
                        [    -5,     -5],
                        [     0,      0],
                        [     1,      2],
                        [     3,      4],
                        [    -2,     -2],
                        [    -3,     -4],
                        [     2,      3],
                        [     0,     -1],
                        [     0,     -2],
                        [     0,      1],
                        [     2,      1],
                        [    -4,     -4],
                        [    -3,     -2],
                        [     3,      1],
                        [     2,      1],
                        [    -2,     -2],
                        [    -3,     -3],
                        [     2,      4],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     1,      0],
                        [    -4,     -6],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [     3,      2],
                        [    -2,      0],
                        [    -4,     -5],
                        [    -3,     -3],
                        [     0,      2],
                        [     6,      4],
                        [    -1,     -2],
                        [    -3,     -5],
                        [     2,      2],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,      1],
                        [    -5,     -5],
                        [     0,     -1],
                        [     0,      2],
                        [     1,      3],
                        [     2,      1],
                        [    -1,     -3],
                        [     2,      1],
                        [     0,     -2],
                        [    -4,     -2],
                        [     0,      1],
                        [     0,      0],
                        [     2,      3],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,     -2],
                        [     3,      2],
                        [     0,      2],
                        [    -3,     -3],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [     2,      1],
                        [    -2,     -4],
                        [     0,     -1],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [    -1,      0],
                        [    -3,     -3],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -3,     -3],
                        [    -3,     -1],
                        [     0,     -2],
                        [    -1,     -2],
                        [     1,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      2],
                        [     0,      1],
                        [     2,      2],
                        [     1,      1],
                        [    -4,     -5],
                        [    -3,     -4],
                        [     2,      2],
                        [    -1,     -1],
                        [    -4,     -4],
                        [     1,     -1],
                        [     2,      2],
                        [     2,      4],
                        [    -1,      0],
                        [    -2,     -4],
                        [     1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,      0],
                        [     2,      2],
                        [     0,     -2],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     6,      3],
                        [     0,      0],
                        [    -2,      1],
                        [     4,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -2],
                        [     2,      2],
                        [     2,      5],
                        [    -2,     -3],
                        [     2,      2],
                        [     0,      1],
                        [    -4,     -5],
                        [     0,      0],
                        [     0,      1],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      2],
                        [    -3,     -2],
                        [     1,      0],
                        [     2,      0],
                        [    -1,     -1],
                        [     4,      3],
                        [     0,     -1],
                        [     1,      0],
                        [     7,      7],
                        [    -4,     -2],
                        [    -3,     -3],
                        [     1,     -1],
                        [     1,      0],
                        [     3,      5],
                        [     0,      2],
                        [     2,      1],
                        [    -1,      1],
                        [    -2,     -3],
                        [     2,      2],
                        [     2,      2],
                        [     1,      0],
                        [    -3,     -2],
                        [    -2,     -2],
                        [     7,      6],
                        [    -1,      0],
                        [    -7,     -6],
                        [     5,      3],
                        [     2,      2],
                        [    -2,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     2,      4],
                        [    -3,     -2],
                        [     3,      3],
                        [     7,      7],
                        [    -3,     -4],
                        [     0,      0],
                        [     3,      5],
                        [     0,      1],
                        [     2,      1],
                        [     2,      2],
                        [    -3,     -2],
                        [     4,      4],
                        [     2,      3],
                        [    -4,     -5],
                        [     4,      5],
                        [     0,      1],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [     2,      2],
                        [     2,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -3,     -2],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -2],
                        [    -2,      2],
                        [     0,      0],
                        [    -2,     -3],
                        [     3,      3],
                        [     2,      2],
                        [    -1,     -2],
                        [     4,      3],
                        [    -2,     -1],
                        [    -4,     -2],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      2],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      3],
                        [    -4,     -3],
                        [    -1,     -2],
                        [     3,      2],
                        [     0,      1],
                        [     1,     -1],
                        [     2,      2],
                        [    -3,     -3],
                        [    -1,     -3],
                        [     3,      3],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      2],
                        [    -3,     -4],
                        [     0,     -1],
                        [     4,      2],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      1],
                        [     1,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      3],
                        [     0,     -1],
                        [     0,     -2],
                        [     2,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [    -3,     -3],
                        [     1,      1],
                        [     1,      0],
                        [     1,     -1],
                        [    -2,      0],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      0],
                        [    -2,     -1],
                        [    -3,     -5],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     2,      3],
                        [    -5,     -5],
                        [     1,      2],
                        [     4,      4],
                        [    -4,     -5],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      2],
                        [     0,      0],
                        [     1,      1],
                        [    -5,     -5],
                        [    -1,      2],
                        [     3,      4],
                        [    -3,     -4],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     2,      2],
                        [    -4,     -4],
                        [    -4,     -4],
                        [     5,      5],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -4,     -4],
                        [     1,      2],
                        [     2,      3],
                        [    -3,     -4],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [     5,      3],
                        [    -4,     -3],
                        [    -5,     -4],
                        [     3,      2],
                        [     1,      2],
                        [    -2,     -2],
                        [     0,     -2],
                        [    -3,     -2],
                        [     2,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     4,      5],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      3],
                        [     5,      6],
                        [    -1,     -2],
                        [     0,     -1],
                        [    -3,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -5,     -3],
                        [    -2,     -3],
                        [     4,      4],
                        [    -1,      0],
                        [    -2,     -4],
                        [     2,      3],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -2,     -1],
                        [    -4,     -3],
                        [    -2,     -1],
                        [    -1,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [     0,      1],
                        [    -3,     -3],
                        [    -4,     -4],
                        [    -2,     -4],
                        [     0,      1],
                        [    -1,      2],
                        [     0,     -2],
                        [    -2,     -4],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -2,      0],
                        [    -2,     -2],
                        [    -1,      1],
                        [    -2,     -2],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -8,     -7],
                        [    -2,     -4],
                        [     2,      1],
                        [    -3,     -2],
                        [     0,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -6,     -5],
                        [     3,      4],
                        [     2,      1],
                        [    -4,     -3],
                        [    -4,     -2],
                        [     0,      1],
                        [     2,      2],
                        [    -4,     -2],
                        [     0,      2],
                        [     0,     -3],
                        [    -1,      0],
                        [     0,      1],
                        [    -3,     -4],
                        [    -1,      2],
                        [     0,     -1],
                        [     1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,     -1],
                        [     0,     -2],
                        [     2,      3],
                        [    -1,      0],
                        [    -3,     -3],
                        [     2,      2],
                        [    -2,     -3],
                        [    -4,     -3],
                        [     2,      2],
                        [     2,      2],
                        [    -2,      1],
                        [    -1,     -2],
                        [     2,      1],
                        [    -2,     -2],
                        [    -4,     -4],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      1],
                        [     2,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -4,     -3],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -3,     -3],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [    -1,     -2],
                        [     1,      0],
                        [    -3,     -2],
                        [    -2,      0],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -4,     -3],
                        [    -1,     -1],
                        [    -4,     -4],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     2,      1],
                        [     1,     -1],
                        [    -4,     -4],
                        [     0,      1],
                        [    -1,      0],
                        [    -5,     -5],
                        [    -1,      1],
                        [     2,      2],
                        [    -3,     -5],
                        [     2,      2],
                        [     2,      2],
                        [    -3,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [    -4,     -4],
                        [    -6,     -6],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -4,     -3],
                        [    -4,     -2],
                        [     0,     -1],
                        [    -1,     -2],
                        [    -2,     -1],
                        [    -3,     -4],
                        [     1,      2],
                        [     3,      4],
                        [    -7,     -7],
                        [    -2,     -3],
                        [    -2,     -1],
                        [    -2,     -1],
                        [     0,     -2],
                        [    -7,     -7],
                        [    -2,     -2],
                        [     2,      1],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -3],
                        [     0,      0],
                        [     3,      3],
                        [    -2,     -2],
                        [    -4,     -2],
                        [     2,      2],
                        [    -1,     -2],
                        [    -4,     -4],
                        [     2,      2],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     3,      4],
                        [    -2,     -2],
                        [     2,      1],
                        [    -5,     -3],
                        [    -2,     -2],
                        [     4,      2],
                        [    -3,     -3],
                        [    -5,     -3],
                        [     0,      1],
                        [     2,      1],
                        [     0,     -1],
                        [     3,      2],
                        [    -1,     -1],
                        [    -3,     -4],
                        [     0,     -1],
                        [     1,      1],
                        [    -2,     -1],
                        [     2,      1],
                        [     2,      2],
                        [    -2,     -3],
                        [    -3,     -4],
                        [    -1,      1],
                        [     2,      1],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -1,     -2],
                        [     1,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -3,     -3],
                        [     1,      2],
                        [    -2,     -2],
                        [    -5,     -6],
                        [     2,      4],
                        [    -1,     -1],
                        [    -2,     -4],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -2],
                        [    -3,     -3],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -3,     -2],
                        [     1,      1],
                        [    -2,     -3],
                        [     1,      2],
                        [    -2,     -2],
                        [    -5,     -7],
                        [     0,      2],
                        [     2,      2],
                        [    -4,     -3],
                        [    -4,     -5],
                        [     2,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -3,     -2],
                        [    -4,     -3],
                        [    -2,     -2],
                        [    -2,     -3],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [    -3,     -4],
                        [    -3,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -4,     -3],
                        [     2,      2],
                        [     1,      0],
                        [    -5,     -5],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      2],
                        [     0,     -2],
                        [    -4,     -3],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [    -1,     -2],
                        [    -3,     -4],
                        [     1,     -1],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [    -2,      0],
                        [    -4,     -4],
                        [     3,      3],
                        [     0,      1],
                        [    -4,     -5],
                        [     0,      1],
                        [     0,      0],
                        [    -3,     -4],
                        [     1,      0],
                        [     5,      6],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -2,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [    -2,     -1],
                        [    -2,     -3],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      2],
                        [    -3,     -2],
                        [     1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -3,     -3],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,      1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     1,     -1],
                        [    -2,     -3],
                        [    -5,     -2],
                        [     1,      2],
                        [     1,     -1],
                        [    -4,     -3],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -3,     -3],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -2,     -3],
                        [    -1,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -1,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      1],
                        [     5,      4],
                        [    -4,     -5],
                        [    -2,     -2],
                        [     2,      3],
                        [     1,     -1],
                        [     0,     -1],
                        [     1,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      2],
                        [     0,      1],
                        [    -4,     -3],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,     -2],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      0],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      2],
                        [    -4,     -3],
                        [    -2,     -3],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -1,      0],
                        [    -2,     -1],
                        [     0,     -2],
                        [     0,      1],
                        [    -2,     -2],
                        [    -3,     -4],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,     -1],
                        [    -3,     -2],
                        [     0,      0],
                        [     0,      0],
                        [    -7,     -6],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,      0],
                        [    -3,     -2],
                        [     0,      0],
                        [    -1,      0],
                        [    -3,     -3],
                        [     2,      3],
                        [    -2,     -1],
                        [    -2,     -3],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,      0],
                        [     0,     -2],
                        [    -5,     -5],
                        [     0,      2],
                        [     2,      2],
                        [    -3,     -5],
                        [     0,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     4,      3],
                        [    -2,     -2],
                        [    -3,     -3],
                        [     2,      4],
                        [     0,     -2],
                        [    -5,     -6],
                        [     0,      2],
                        [     3,      2],
                        [    -2,     -2],
                        [    -1,      0],
                        [     0,      1],
                        [    -1,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -4,     -4],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -2,     -2],
                        [     2,      3],
                        [     2,      0],
                        [    -1,     -1],
                        [     4,      4],
                        [    -2,     -2],
                        [    -6,     -5],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      1],
                        [    -1,      0],
                        [    -1,      1],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -2,     -1],
                        [    -2,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      3],
                        [    -6,     -5],
                        [    -3,     -4],
                        [     3,      3],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     2,      3],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [    -2,     -3],
                        [    -3,     -3],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     3,      3],
                        [    -1,      0],
                        [    -3,     -2],
                        [     0,     -1],
                        [    -4,     -4],
                        [     0,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      2],
                        [    -2,     -2],
                        [    -2,     -4],
                        [    -1,     -1],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     1,      2],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [    -2,      0],
                        [    -1,      0],
                        [    -2,     -1],
                        [     2,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      1],
                        [    -3,     -2],
                        [    -1,     -2],
                        [     2,      2],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      0],
                        [    -5,     -5],
                        [     0,      1],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -3,     -2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [    -5,     -4],
                        [     1,      0],
                        [     2,      2],
                        [     0,      0],
                        [     0,      2],
                        [     0,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     4,      4],
                        [    -3,     -3],
                        [    -2,     -2],
                        [     2,      2],
                        [    -1,     -2],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [    -3,     -3],
                        [    -1,      0],
                        [     2,      1],
                        [    -1,     -2],
                        [     2,      2],
                        [     2,      3],
                        [    -3,     -3],
                        [    -2,     -2],
                        [    -1,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     3,      2],
                        [     2,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     3,      4],
                        [     2,      2],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     2,      1],
                        [    -3,     -2],
                        [     1,      2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     2,      0],
                        [    -5,     -3],
                        [     2,      2],
                        [     5,      4],
                        [    -2,     -2],
                        [     2,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [     1,      0],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -1,     -2],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     2,      3],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      2],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      1],
                        [     4,      3],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      0],
                        [     2,      2],
                        [     3,      2],
                        [     0,     -1],
                        [     2,      2],
                        [     0,     -2],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -2],
                        [     4,      4],
                        [     0,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     3,      2],
                        [     0,      1],
                        [    -2,     -1],
                        [     3,      1],
                        [     2,      2],
                        [     3,      3],
                        [     2,      2],
                        [    -3,     -2],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      2],
                        [     2,      1],
                        [     2,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      1],
                        [     0,     -1],
                        [    -1,      0],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,     -1],
                        [     3,      3],
                        [    -3,     -2],
                        [    -1,     -1],
                        [     2,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     2,      2],
                        [    -3,     -2],
                        [    -1,     -1],
                        [     3,      4],
                        [    -3,     -3],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,      0],
                        [     2,      2],
                        [     2,      1],
                        [    -1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      0],
                        [     1,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     0,      1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [     4,      3],
                        [     1,      2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [     0,     -1],
                        [     5,      5],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     3,      4],
                        [    -2,     -2],
                        [     0,      0],
                        [     4,      5],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [    -1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     3,      2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      3],
                        [     2,      2],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      2],
                        [    -1,      0],
                        [     1,      0],
                        [     0,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      0],
                        [     3,      3],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     2,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     2,      2],
                        [     4,      4],
                        [    -1,      1],
                        [     2,      0],
                        [     2,      2],
                        [    -1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,     -2],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -4],
                        [    -1,     -1],
                        [     1,      2],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     3,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [    -2,     -1],
                        [     2,      1],
                        [     0,     -1],
                        [    -5,     -4],
                        [     2,      2],
                        [     3,      3],
                        [    -2,     -2],
                        [     2,      1],
                        [     0,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     3,      2],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      2],
                        [     2,      2],
                        [     3,      2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     2,      2],
                        [     2,      1],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     2,      2],
                        [     0,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      2],
                        [    -1,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -3],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      2],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     0,      2],
                        [     4,      3],
                        [    -2,     -2],
                        [    -3,     -2],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [     1,      0],
                        [     1,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -3,     -2],
                        [     2,      2],
                        [     2,      1],
                        [     2,      2],
                        [     1,      2],
                        [    -1,     -1],
                        [     3,      2],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -1],
                        [    -1,     -3],
                        [     4,      4],
                        [     2,      2],
                        [    -2,     -3],
                        [     2,      3],
                        [     1,      0],
                        [    -1,      0],
                        [     2,      3],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -4],
                        [     1,      2],
                        [     0,      2],
                        [     1,     -1],
                        [     1,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     4,      5],
                        [     1,      2],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      3],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      1],
                        [     2,      2],
                        [     1,      1],
                        [    -3,     -3],
                        [     2,      2],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [     0,      0],
                        [     2,      2],
                        [     0,      1],
                        [     0,      0],
                        [     2,      1],
                        [    -1,      0],
                        [    -2,     -1],
                        [     3,      3],
                        [     2,      1],
                        [     0,      0],
                        [     4,      3],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [     1,      0],
                        [     3,      3],
                        [     2,      3],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,      1],
                        [     1,      1],
                        [     2,      2],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     3,      2],
                        [    -3,     -3],
                        [    -2,     -1],
                        [     4,      4],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [     0,      2],
                        [     0,      1],
                        [    -1,     -1],
                        [     3,      2],
                        [     2,      3],
                        [    -2,     -1],
                        [     1,      0],
                        [     0,      2],
                        [     1,      0],
                        [     0,      1],
                        [     1,      2],
                        [     2,      0],
                        [    -2,     -1],
                        [     1,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     4,      4],
                        [    -2,     -2],
                        [    -3,     -2],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      1],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,      2],
                        [     0,      1],
                        [     1,      1],
                        [     2,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      2],
                        [     2,      2],
                        [     2,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     3,      2],
                        [     0,      0],
                        [    -2,     -1],
                        [     2,      3],
                        [    -2,     -2],
                        [     2,      2],
                        [     3,      3],
                        [    -4,     -3],
                        [     2,      2],
                        [     4,      3],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     0,      1],
                        [     1,      1],
                        [     1,     -1],
                        [     3,      4],
                        [     4,      3],
                        [    -3,     -3],
                        [     2,      2],
                        [     1,      2],
                        [    -1,      0],
                        [     3,      2],
                        [     0,      2],
                        [     2,      2],
                        [     1,      0],
                        [     2,      2],
                        [     0,      1],
                        [     1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     3,      3],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      2],
                        [     2,      3],
                        [     2,      2],
                        [     0,      0],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      1],
                        [     1,      2],
                        [     1,      0],
                        [     1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     2,      1],
                        [     2,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [     2,      2],
                        [    -2,      0],
                        [     1,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     3,      3],
                        [     3,      4],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     2,      0],
                        [     2,      2],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      2],
                        [     0,      1],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [    -4,     -4],
                        [     1,      0],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [    -2,     -1],
                        [     2,      1],
                        [     0,      1],
                        [     2,      2],
                        [     2,      0],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [     3,      3],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     3,      2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [     1,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [    -1,      1],
                        [     1,      2],
                        [     0,     -1],
                        [    -2,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      2],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -3,     -3],
                        [     3,      4],
                        [     2,      2],
                        [    -2,     -3],
                        [    -2,     -1],
                        [     0,     -1],
                        [     0,      1],
                        [     1,      2],
                        [     2,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     2,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     3,      3],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     2,      2],
                        [     3,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -2],
                        [     2,      0],
                        [     2,      0],
                        [    -2,     -1],
                        [    -1,      0],
                        [     2,      1],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      2],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     3,      3],
                        [     0,     -1],
                        [    -3,     -4],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     2,      3],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      1],
                        [     1,      2],
                        [     1,      0],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     1,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [    -1,      0],
                        [     2,      1],
                        [     2,      3],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      0],
                        [     2,      2],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      2],
                        [     2,      3],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      1],
                        [     3,      3],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -3,     -2],
                        [     2,      2],
                        [     2,      1],
                        [     2,      1],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [     2,      1],
                        [     2,      2],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -1],
                        [     2,      2],
                        [     2,      2],
                        [    -1,      0],
                        [     2,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -2,     -3],
                        [     2,      2],
                        [    -1,      1],
                        [    -2,     -1],
                        [     1,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      2],
                        [    -1,      0],
                        [    -3,     -2],
                        [     0,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      2],
                        [    -1,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     3,      4],
                        [     2,      1],
                        [     2,      1],
                        [     1,      2],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     1,      0],
                        [     0,     -1],
                        [     2,      3],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     2,      1],
                        [    -2,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      3],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     2,      3],
                        [     1,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [    -2,     -3],
                        [     1,      1],
                        [     2,      2],
                        [     1,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -3,     -2],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     5,      6],
                        [     1,      1],
                        [    -2,     -4],
                        [     2,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -1],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [     0,     -1],
                        [    -3,     -3],
                        [    -3,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [     2,      2],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      2],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -2,      0],
                        [     2,      2],
                        [     1,      2],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     3,      3],
                        [     0,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [     0,      0],
                        [     4,      4],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     0,      1],
                        [    -1,     -2],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [    -2,      0],
                        [     2,      2],
                        [     1,      2],
                        [    -1,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [    -1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -2],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -1,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      2],
                        [     0,      0],
                        [     2,     -1],
                        [     0,      0],
                        [    -3,     -3],
                        [     1,      0],
                        [     2,      2],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     4,      3],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -3],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      0],
                        [     1,      0],
                        [     2,      2],
                        [     2,      1],
                        [     1,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -2],
                        [     2,      2],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [     2,      1],
                        [     2,      1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     2,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [    -3,     -3],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      2],
                        [     0,     -1],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -4,     -3],
                        [     0,      0],
                        [     2,      2],
                        [    -3,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      2],
                        [    -2,     -3],
                        [    -1,     -1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,      0],
                        [     1,      0],
                        [     2,      1],
                        [    -2,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      2],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     3,      3],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      3],
                        [     0,      1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [     1,      2],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      2],
                        [    -3,     -2],
                        [     0,      0],
                        [     4,      3],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,      0],
                        [     3,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     1,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     3,      3],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -3,     -3],
                        [    -1,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [    -2,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -3,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     2,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      1],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      0],
                        [    -1,      0],
                        [    -2,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -2,      0],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      2],
                        [    -1,     -2],
                        [     2,      1],
                        [     2,      2],
                        [    -2,     -1],
                        [     0,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [    -2,     -1],
                        [    -2,     -3],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -3],
                        [     0,      0],
                        [     1,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,     -1],
                        [    -2,     -1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [    -2,     -2],
                        [     2,      0],
                        [     1,      0],
                        [    -1,      0],
                        [     1,      0],
                        [    -3,     -2],
                        [    -1,      0],
                        [     1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [    -1,      0],
                        [     2,      3],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      2],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -1,      0],
                        [     1,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [    -3,     -3],
                        [    -2,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -2,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -2,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [    -1,     -1],
                        [     2,      0],
                        [     1,      1],
                        [    -2,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      2],
                        [    -1,      0],
                        [     1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [    -1,     -2],
                        [     0,      1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -2],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [    -1,      0],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      0],
                        [     0,      1],
                        [    -2,     -1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -1],
                        [     2,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     3,      3],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     2,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [     2,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,     -2],
                        [     2,      2],
                        [     0,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -2,     -1],
                        [    -2,     -3],
                        [     2,      2],
                        [     0,      0],
                        [    -1,      1],
                        [     1,      2],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     2,      2],
                        [     1,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      1],
                        [     0,      0],
                        [     1,      2],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     3,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     0,     -1],
                        [     1,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,     -1],
                        [     1,      2],
                        [     1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      1],
                        [     1,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,      1],
                        [    -1,     -2],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      2],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      2],
                        [    -1,     -2],
                        [     0,      0],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     1,      2],
                        [     1,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     1,      1],
                        [     2,      1],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      2],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -2],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [     2,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      1],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     2,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,      1],
                        [     2,      2],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      2],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     1,      0],
                        [    -1,     -2],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     1,      0],
                        [     0,      0],
                        [     1,      2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      2],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     2,      2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -2,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      2],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      2],
                        [    -1,     -2],
                        [     1,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     2,      2],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     2,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      2],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [    -2,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      1],
                        [     1,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      2],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     2,      2],
                        [     0,      1],
                        [     1,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     2,      1],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     2,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     1,      2],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      1],
                        [     1,      2],
                        [     0,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     2,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     1,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     2,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      2],
                        [     0,      0],
                        [     1,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [    -1,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      2],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [    -1,      0],
                        [     2,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [     1,      2],
                        [    -1,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     2,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -1],
                        [    -1,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -2,     -1],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -2],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      1],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     1,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,      0],
                        [     1,      2],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     2,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     2,      2],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     5,      6],
                        [    11,     11],
                        [    18,     18],
                        [    28,     27],
                        [    34,     34],
                        [    42,     42],
                        [    51,     51],
                        [    59,     59],
                        [    66,     66],
                        [    73,     73],
                        [    79,     79],
                        [    83,     83],
                        [     7,      7],
                        [    12,     12],
                        [    16,     16],
                        [    21,     21],
                        [    26,     26],
                        [    30,     30],
                        [    33,     33],
                        [    38,     38],
                        [    41,     41],
                        [    45,     45],
                        [    50,     50],
                        [    53,     52],
                        [    56,     56],
                        [    60,     60],
                        [    63,     63],
                        [    68,     68],
                        [   -15,    -15],
                        [    -4,     -4],
                        [     7,      7],
                        [    19,     19],
                        [    31,     30],
                        [    44,     43],
                        [    57,     57],
                        [    71,     71],
                        [    85,     85],
                        [    99,     99],
                        [   115,    115],
                        [   131,    131],
                        [   145,    145],
                        [   162,    162],
                        [   177,    177],
                        [   194,    194],
                        [   179,    178],
                        [   194,    193],
                        [   210,    210],
                        [   226,    226],
                        [   241,    241],
                        [   255,    255],
                        [   270,    270],
                        [   283,    283],
                        [   294,    294],
                        [   306,    306],
                        [   318,    318],
                        [   327,    326],
                        [   335,    335],
                        [   343,    343],
                        [   349,    349],
                        [   353,    353],
                        [   358,    358],
                        [   361,    361],
                        [   362,    363],
                        [   363,    363],
                        [   362,    362],
                        [   360,    360],
                        [   358,    358],
                        [   354,    354],
                        [   349,    349],
                        [   344,    343],
                        [   337,    336],
                        [   328,    328],
                        [   319,    319],
                        [   310,    310],
                        [   301,    300],
                        [   289,    288],
                        [   276,    275],
                        [   262,    262],
                        [   249,    249],
                        [   234,    234],
                        [   217,    217],
                        [   200,    201],
                        [   182,    181],
                        [   161,    161],
                        [   141,    141],
                        [   119,    119],
                        [    93,     93],
                        [    68,     68],
                        [    39,     40],
                        [     9,      9],
                        [   -23,    -23],
                        [   -59,    -59],
                        [   -96,    -96],
                        [  -136,   -136],
                        [  -179,   -179],
                        [  -224,   -225],
                        [  -273,   -273],
                        [  -324,   -324],
                        [  -381,   -381],
                        [  -437,   -437],
                        [  -476,   -476],
                        [  -487,   -487],
                        [  -466,   -467],
                        [  -414,   -414],
                        [  -321,   -321],
                        [  -188,   -188],
                        [   -40,    -40],
                        [   102,    102],
                        [   234,    234],
                        [   354,    354],
                        [   462,    461],
                        [   551,    551],
                        [   624,    624],
                        [   679,    680],
                        [   717,    717],
                        [   735,    735],
                        [   733,    733],
                        [   713,    713],
                        [   674,    674],
                        [   618,    618],
                        [   546,    546],
                        [   460,    460],
                        [   360,    360],
                        [   249,    249],
                        [   126,    125],
                        [    -6,     -6],
                        [  -143,   -144],
                        [  -287,   -287],
                        [  -434,   -434],
                        [  -583,   -583],
                        [  -732,   -732],
                        [  -882,   -882],
                        [ -1029,  -1029],
                        [ -1172,  -1172],
                        [ -1311,  -1311],
                        [ -1443,  -1444],
                        [ -1570,  -1570],
                        [ -1689,  -1689],
                        [ -1801,  -1801],
                        [ -1903,  -1903],
                        [ -1997,  -1997],
                        [ -2082,  -2082],
                        [ -2156,  -2156],
                        [ -2222,  -2222],
                        [ -2277,  -2277],
                        [ -2321,  -2321],
                        [ -2358,  -2358],
                        [ -2387,  -2387],
                        [ -2405,  -2405],
                        [ -2415,  -2416],
                        [ -2417,  -2417],
                        [ -2412,  -2412],
                        [ -2400,  -2400],
                        [ -2382,  -2382],
                        [ -2359,  -2358],
                        [ -2329,  -2329],
                        [ -2297,  -2297],
                        [ -2260,  -2261],
                        [ -2221,  -2221],
                        [ -2181,  -2181],
                        [ -2139,  -2139],
                        [ -2095,  -2095],
                        [ -2050,  -2051],
                        [ -2008,  -2009],
                        [ -1965,  -1966],
                        [ -1925,  -1926],
                        [ -1887,  -1887],
                        [ -1851,  -1850],
                        [ -1819,  -1819],
                        [ -1790,  -1790],
                        [ -1763,  -1763],
                        [ -1742,  -1742],
                        [ -1724,  -1724],
                        [ -1710,  -1710],
                        [ -1701,  -1701],
                        [ -1695,  -1696],
                        [ -1695,  -1694],
                        [ -1697,  -1697],
                        [ -1703,  -1703],
                        [ -1713,  -1713],
                        [ -1725,  -1725],
                        [ -1741,  -1741],
                        [ -1759,  -1759],
                        [ -1779,  -1779],
                        [ -1801,  -1801],
                        [ -1823,  -1823],
                        [ -1846,  -1846],
                        [ -1868,  -1868],
                        [ -1891,  -1891],
                        [ -1912,  -1911],
                        [ -1931,  -1931],
                        [ -1948,  -1948],
                        [ -1960,  -1960],
                        [ -1970,  -1970],
                        [ -1975,  -1975],
                        [ -1976,  -1976],
                        [ -1972,  -1972],
                        [ -1961,  -1961],
                        [ -1944,  -1944],
                        [ -1922,  -1922],
                        [ -1892,  -1892],
                        [ -1855,  -1855],
                        [ -1811,  -1811],
                        [ -1759,  -1758],
                        [ -1698,  -1698],
                        [ -1631,  -1630],
                        [ -1554,  -1554],
                        [ -1471,  -1471],
                        [ -1380,  -1380],
                        [ -1281,  -1281],
                        [ -1175,  -1175],
                        [ -1062,  -1063],
                        [  -942,   -942],
                        [  -816,   -816],
                        [  -684,   -684],
                        [  -548,   -548],
                        [  -405,   -405],
                        [  -260,   -260],
                        [  -113,   -112],
                        [    39,     39],
                        [   192,    192],
                        [   346,    346],
                        [   492,    493],
                        [   594,    594],
                        [   629,    629],
                        [   591,    591],
                        [   477,    477],
                        [   276,    276],
                        [    -3,     -2],
                        [  -309,   -308],
                        [  -604,   -603],
                        [  -882,   -882],
                        [ -1143,  -1142],
                        [ -1383,  -1384],
                        [ -1601,  -1601],
                        [ -1793,  -1793],
                        [ -1958,  -1958],
                        [ -2098,  -2098],
                        [ -2209,  -2209],
                        [ -2295,  -2295],
                        [ -2354,  -2354],
                        [ -2388,  -2388],
                        [ -2399,  -2399],
                        [ -2386,  -2386],
                        [ -2353,  -2353],
                        [ -2299,  -2299],
                        [ -2230,  -2230],
                        [ -2144,  -2144],
                        [ -2042,  -2042],
                        [ -1928,  -1928],
                        [ -1805,  -1805],
                        [ -1669,  -1670],
                        [ -1527,  -1527],
                        [ -1377,  -1376],
                        [ -1222,  -1221],
                        [ -1061,  -1060],
                        [  -896,   -896],
                        [  -729,   -729],
                        [  -557,   -558],
                        [  -387,   -387],
                        [  -215,   -215],
                        [   -42,    -41],
                        [   132,    132],
                        [   305,    305],
                        [   476,    476],
                        [   649,    648],
                        [   819,    819],
                        [   987,    987],
                        [  1153,   1154],
                        [  1319,   1319],
                        [  1481,   1482],
                        [  1640,   1640],
                        [  1797,   1798],
                        [  1951,   1951],
                        [  2101,   2101],
                        [  2248,   2248],
                        [  2390,   2390],
                        [  2528,   2529],
                        [  2661,   2661],
                        [  2789,   2789],
                        [  2913,   2913],
                        [  3031,   3031],
                        [  3142,   3142],
                        [  3248,   3248],
                        [  3347,   3347],
                        [  3439,   3439],
                        [  3526,   3526],
                        [  3606,   3606],
                        [  3679,   3679],
                        [  3745,   3745],
                        [  3804,   3804],
                        [  3856,   3857],
                        [  3902,   3902],
                        [  3942,   3942],
                        [  3976,   3976],
                        [  4003,   4003],
                        [  4024,   4024],
                        [  4041,   4041],
                        [  4051,   4052],
                        [  4058,   4058],
                        [  4060,   4060],
                        [  4058,   4058],
                        [  4053,   4053],
                        [  4045,   4045],
                        [  4033,   4033],
                        [  4020,   4020],
                        [  4005,   4006],
                        [  3989,   3989],
                        [  3973,   3973],
                        [  3955,   3955],
                        [  3937,   3937],
                        [  3921,   3921],
                        [  3903,   3903],
                        [  3886,   3886],
                        [  3871,   3872],
                        [  3855,   3855],
                        [  3840,   3840],
                        [  3826,   3826],
                        [  3812,   3812],
                        [  3798,   3798],
                        [  3784,   3784],
                        [  3770,   3770],
                        [  3755,   3755],
                        [  3738,   3737],
                        [  3718,   3718],
                        [  3696,   3696],
                        [  3669,   3669],
                        [  3640,   3640],
                        [  3606,   3606],
                        [  3565,   3565],
                        [  3519,   3518],
                        [  3465,   3464],
                        [  3402,   3402],
                        [  3331,   3331],
                        [  3251,   3251],
                        [  3161,   3161],
                        [  3062,   3062],
                        [  2949,   2949],
                        [  2826,   2826],
                        [  2693,   2692],
                        [  2546,   2546],
                        [  2386,   2386],
                        [  2217,   2217],
                        [  2036,   2037],
                        [  1840,   1840],
                        [  1649,   1649],
                        [  1513,   1514],
                        [  1458,   1458],
                        [  1485,   1485],
                        [  1605,   1606],
                        [  1833,   1833],
                        [  2152,   2152],
                        [  2492,   2492],
                        [  2805,   2805],
                        [  3086,   3086],
                        [  3335,   3335],
                        [  3543,   3544],
                        [  3712,   3712],
                        [  3839,   3839],
                        [  3922,   3921],
                        [  3964,   3964],
                        [  3963,   3963],
                        [  3921,   3921],
                        [  3842,   3842],
                        [  3727,   3727],
                        [  3580,   3580],
                        [  3404,   3404],
                        [  3202,   3202],
                        [  2978,   2978],
                        [  2737,   2737],
                        [  2481,   2481],
                        [  2215,   2215],
                        [  1944,   1943],
                        [  1667,   1667],
                        [  1391,   1391],
                        [  1119,   1119],
                        [   853,    853],
                        [   596,    596],
                        [   349,    349],
                        [   115,    115],
                        [  -104,   -104],
                        [  -308,   -308],
                        [  -494,   -494],
                        [  -662,   -662],
                        [  -813,   -812],
                        [  -944,   -944],
                        [ -1058,  -1058],
                        [ -1152,  -1152],
                        [ -1229,  -1229],
                        [ -1289,  -1289],
                        [ -1330,  -1331],
                        [ -1359,  -1359],
                        [ -1371,  -1371],
                        [ -1370,  -1370],
                        [ -1357,  -1357],
                        [ -1332,  -1333],
                        [ -1298,  -1298],
                        [ -1255,  -1256],
                        [ -1207,  -1207],
                        [ -1153,  -1154],
                        [ -1094,  -1094],
                        [ -1034,  -1034],
                        [  -971,   -971],
                        [  -908,   -908],
                        [  -847,   -847],
                        [  -787,   -787],
                        [  -729,   -730],
                        [  -677,   -677],
                        [  -628,   -628],
                        [  -583,   -583],
                        [  -547,   -547],
                        [  -515,   -515],
                        [  -488,   -488],
                        [  -470,   -470],
                        [  -458,   -458],
                        [  -453,   -452],
                        [  -453,   -453],
                        [  -459,   -459],
                        [  -472,   -472],
                        [  -489,   -490],
                        [  -511,   -511],
                        [  -538,   -538],
                        [  -566,   -566],
                        [  -599,   -599],
                        [  -634,   -634],
                        [  -667,   -667],
                        [  -701,   -701],
                        [  -735,   -735],
                        [  -766,   -767],
                        [  -795,   -795],
                        [  -819,   -819],
                        [  -839,   -839],
                        [  -854,   -854],
                        [  -861,   -861],
                        [  -861,   -862],
                        [  -854,   -854],
                        [  -838,   -838],
                        [  -811,   -812],
                        [  -776,   -776],
                        [  -730,   -730],
                        [  -673,   -674],
                        [  -605,   -605],
                        [  -527,   -527],
                        [  -436,   -436],
                        [  -334,   -334],
                        [  -220,   -220],
                        [   -94,    -94],
                        [    41,     41],
                        [   187,    188],
                        [   345,    345],
                        [   512,    511],
                        [   688,    687],
                        [   873,    873],
                        [  1065,   1064],
                        [  1264,   1264],
                        [  1471,   1471],
                        [  1683,   1683],
                        [  1898,   1898],
                        [  2117,   2117],
                        [  2338,   2337],
                        [  2560,   2561],
                        [  2783,   2783],
                        [  3003,   3002],
                        [  3222,   3222],
                        [  3438,   3438],
                        [  3646,   3646],
                        [  3847,   3847],
                        [  4047,   4047],
                        [  4214,   4214],
                        [  4293,   4293],
                        [  4261,   4260],
                        [  4111,   4111],
                        [  3835,   3835],
                        [  3413,   3413],
                        [  2862,   2862],
                        [  2263,   2263],
                        [  1675,   1675],
                        [  1101,   1101],
                        [   546,    545],
                        [    18,     18],
                        [  -477,   -477],
                        [  -931,   -931],
                        [ -1345,  -1345],
                        [ -1713,  -1714],
                        [ -2034,  -2035],
                        [ -2308,  -2308],
                        [ -2529,  -2529],
                        [ -2703,  -2702],
                        [ -2829,  -2829],
                        [ -2907,  -2907],
                        [ -2940,  -2940],
                        [ -2930,  -2930],
                        [ -2877,  -2877],
                        [ -2786,  -2786],
                        [ -2660,  -2659],
                        [ -2499,  -2499],
                        [ -2308,  -2309],
                        [ -2091,  -2091],
                        [ -1848,  -1848],
                        [ -1584,  -1584],
                        [ -1301,  -1301],
                        [ -1001,  -1001],
                        [  -687,   -687],
                        [  -363,   -363],
                        [   -28,    -28],
                        [   313,    313],
                        [   658,    657],
                        [  1005,   1005],
                        [  1353,   1354],
                        [  1701,   1701],
                        [  2045,   2045],
                        [  2386,   2386],
                        [  2720,   2719],
                        [  3047,   3047],
                        [  3365,   3365],
                        [  3676,   3676],
                        [  3976,   3975],
                        [  4262,   4262],
                        [  4537,   4538],
                        [  4800,   4800],
                        [  5048,   5048],
                        [  5282,   5282],
                        [  5501,   5502],
                        [  5707,   5707],
                        [  5896,   5896],
                        [  6069,   6069],
                        [  6227,   6227],
                        [  6369,   6369],
                        [  6496,   6496],
                        [  6607,   6607],
                        [  6703,   6703],
                        [  6784,   6784],
                        [  6852,   6852],
                        [  6905,   6905],
                        [  6945,   6945],
                        [  6973,   6973],
                        [  6988,   6988],
                        [  6993,   6993],
                        [  6986,   6987],
                        [  6970,   6970],
                        [  6945,   6946],
                        [  6913,   6914],
                        [  6874,   6874],
                        [  6830,   6830],
                        [  6781,   6780],
                        [  6727,   6727],
                        [  6671,   6671],
                        [  6611,   6611],
                        [  6550,   6551],
                        [  6490,   6490],
                        [  6428,   6428],
                        [  6366,   6366],
                        [  6305,   6305],
                        [  6245,   6245],
                        [  6186,   6186],
                        [  6129,   6129],
                        [  6072,   6072],
                        [  6017,   6017],
                        [  5962,   5963],
                        [  5909,   5909],
                        [  5857,   5857],
                        [  5804,   5804],
                        [  5749,   5749],
                        [  5695,   5695],
                        [  5637,   5637],
                        [  5577,   5577],
                        [  5512,   5512],
                        [  5439,   5439],
                        [  5362,   5362],
                        [  5278,   5277],
                        [  5184,   5185],
                        [  5083,   5083],
                        [  4971,   4971],
                        [  4849,   4849],
                        [  4716,   4716],
                        [  4568,   4568],
                        [  4414,   4414],
                        [  4249,   4249],
                        [  4069,   4069],
                        [  3873,   3874],
                        [  3659,   3659],
                        [  3424,   3424],
                        [  3174,   3174],
                        [  2910,   2910],
                        [  2632,   2632],
                        [  2339,   2340],
                        [  2034,   2034],
                        [  1716,   1716],
                        [  1391,   1391],
                        [  1055,   1055],
                        [   708,    709],
                        [   386,    386],
                        [   145,    145],
                        [     4,      4],
                        [   -37,    -37],
                        [    36,     37],
                        [   248,    248],
                        [   586,    586],
                        [   973,    973],
                        [  1351,   1352],
                        [  1723,   1723],
                        [  2082,   2082],
                        [  2419,   2419],
                        [  2727,   2727],
                        [  3003,   3003],
                        [  3245,   3245],
                        [  3449,   3450],
                        [  3613,   3613],
                        [  3738,   3738],
                        [  3826,   3826],
                        [  3876,   3876],
                        [  3886,   3886],
                        [  3860,   3860],
                        [  3801,   3801],
                        [  3714,   3714],
                        [  3599,   3599],
                        [  3461,   3461],
                        [  3306,   3306],
                        [  3135,   3135],
                        [  2951,   2951],
                        [  2758,   2758],
                        [  2561,   2561],
                        [  2360,   2360],
                        [  2160,   2160],
                        [  1961,   1961],
                        [  1767,   1767],
                        [  1580,   1580],
                        [  1401,   1401],
                        [  1230,   1230],
                        [  1069,   1069],
                        [   920,    920],
                        [   781,    781],
                        [   652,    652],
                        [   535,    535],
                        [   429,    430],
                        [   335,    335],
                        [   248,    247],
                        [   171,    170],
                        [   101,    101],
                        [    38,     39],
                        [   -17,    -17],
                        [   -70,    -70],
                        [  -115,   -116],
                        [  -160,   -160],
                        [  -203,   -204],
                        [  -245,   -245],
                        [  -286,   -286],
                        [  -329,   -329],
                        [  -373,   -372],
                        [  -417,   -417],
                        [  -465,   -465],
                        [  -514,   -514],
                        [  -568,   -568],
                        [  -624,   -624],
                        [  -683,   -683],
                        [  -745,   -744],
                        [  -808,   -808],
                        [  -874,   -874],
                        [  -943,   -943],
                        [ -1011,  -1011],
                        [ -1080,  -1080],
                        [ -1147,  -1147],
                        [ -1211,  -1211],
                        [ -1276,  -1276],
                        [ -1337,  -1337],
                        [ -1398,  -1398],
                        [ -1463,  -1463],
                        [ -1533,  -1533],
                        [ -1611,  -1611],
                        [ -1694,  -1694],
                        [ -1783,  -1783],
                        [ -1878,  -1878],
                        [ -1962,  -1962],
                        [ -2039,  -2038],
                        [ -2097,  -2097],
                        [ -2137,  -2137],
                        [ -2159,  -2159],
                        [ -2161,  -2161],
                        [ -2142,  -2142],
                        [ -2101,  -2101],
                        [ -2039,  -2039],
                        [ -1957,  -1956],
                        [ -1851,  -1852],
                        [ -1726,  -1726],
                        [ -1581,  -1581],
                        [ -1418,  -1418],
                        [ -1237,  -1237],
                        [ -1038,  -1038],
                        [  -826,   -826],
                        [  -599,   -599],
                        [  -360,   -360],
                        [  -111,   -111],
                        [   147,    147],
                        [   411,    411],
                        [   680,    680],
                        [   954,    954],
                        [  1228,   1228],
                        [  1500,   1501],
                        [  1773,   1773],
                        [  2042,   2042],
                        [  2303,   2303],
                        [  2559,   2559],
                        [  2806,   2806],
                        [  3042,   3042],
                        [  3266,   3266],
                        [  3478,   3478],
                        [  3675,   3675],
                        [  3855,   3855],
                        [  4019,   4019],
                        [  4167,   4167],
                        [  4294,   4294],
                        [  4400,   4400],
                        [  4486,   4486],
                        [  4554,   4554],
                        [  4570,   4570],
                        [  4490,   4490],
                        [  4310,   4310],
                        [  4026,   4026],
                        [  3621,   3621],
                        [  3065,   3065],
                        [  2366,   2366],
                        [  1599,   1600],
                        [   820,    820],
                        [    28,     28],
                        [  -766,   -765],
                        [ -1547,  -1547],
                        [ -2304,  -2304],
                        [ -3029,  -3029],
                        [ -3715,  -3715],
                        [ -4351,  -4351],
                        [ -4935,  -4935],
                        [ -5460,  -5460],
                        [ -5921,  -5921],
                        [ -6319,  -6319],
                        [ -6650,  -6650],
                        [ -6911,  -6911],
                        [ -7107,  -7107],
                        [ -7236,  -7236],
                        [ -7300,  -7300],
                        [ -7302,  -7302],
                        [ -7244,  -7244],
                        [ -7131,  -7131],
                        [ -6964,  -6964],
                        [ -6748,  -6748],
                        [ -6489,  -6489],
                        [ -6190,  -6190],
                        [ -5854,  -5854],
                        [ -5488,  -5488],
                        [ -5096,  -5096],
                        [ -4682,  -4682],
                        [ -4250,  -4250],
                        [ -3805,  -3805],
                        [ -3352,  -3352],
                        [ -2893,  -2893],
                        [ -2433,  -2433],
                        [ -1975,  -1975],
                        [ -1523,  -1523],
                        [ -1081,  -1081],
                        [  -650,   -650],
                        [  -233,   -233],
                        [   165,    165],
                        [   547,    546],
                        [   906,    905],
                        [  1242,   1243],
                        [  1557,   1557],
                        [  1844,   1844],
                        [  2108,   2108],
                        [  2345,   2345],
                        [  2555,   2555],
                        [  2739,   2739],
                        [  2897,   2897],
                        [  3027,   3028],
                        [  3133,   3133],
                        [  3214,   3214],
                        [  3272,   3272],
                        [  3307,   3306],
                        [  3318,   3318],
                        [  3311,   3311],
                        [  3283,   3284],
                        [  3239,   3239],
                        [  3179,   3179],
                        [  3105,   3105],
                        [  3018,   3018],
                        [  2919,   2919],
                        [  2810,   2810],
                        [  2692,   2692],
                        [  2569,   2569],
                        [  2442,   2442],
                        [  2325,   2325],
                        [  2218,   2218],
                        [  2139,   2139],
                        [  2084,   2085],
                        [  2064,   2063],
                        [  2073,   2073],
                        [  2096,   2096],
                        [  2140,   2140],
                        [  2175,   2174],
                        [  2203,   2203],
                        [  2222,   2222],
                        [  2232,   2232],
                        [  2230,   2230],
                        [  2217,   2217],
                        [  2191,   2191],
                        [  2151,   2150],
                        [  2096,   2096],
                        [  2028,   2028],
                        [  1946,   1946],
                        [  1848,   1848],
                        [  1736,   1736],
                        [  1607,   1608],
                        [  1463,   1463],
                        [  1302,   1302],
                        [  1126,   1126],
                        [   933,    934],
                        [   722,    722],
                        [   496,    496],
                        [   254,    254],
                        [    -8,     -8],
                        [  -284,   -284],
                        [  -577,   -577],
                        [  -887,   -887],
                        [ -1213,  -1213],
                        [ -1554,  -1554],
                        [ -1909,  -1909],
                        [ -2278,  -2278],
                        [ -2661,  -2661],
                        [ -3056,  -3056],
                        [ -3459,  -3460],
                        [ -3872,  -3872],
                        [ -4292,  -4292],
                        [ -4716,  -4716],
                        [ -5142,  -5142],
                        [ -5568,  -5569],
                        [ -5994,  -5994],
                        [ -6412,  -6412],
                        [ -6823,  -6823],
                        [ -7226,  -7225],
                        [ -7588,  -7588],
                        [ -7884,  -7885],
                        [ -8114,  -8114],
                        [ -8272,  -8273],
                        [ -8338,  -8338],
                        [ -8270,  -8270],
                        [ -8062,  -8062],
                        [ -7771,  -7771],
                        [ -7435,  -7435],
                        [ -7054,  -7054],
                        [ -6636,  -6636],
                        [ -6195,  -6195],
                        [ -5737,  -5738],
                        [ -5272,  -5272],
                        [ -4808,  -4808],
                        [ -4348,  -4348],
                        [ -3901,  -3901],
                        [ -3470,  -3471],
                        [ -3062,  -3062],
                        [ -2676,  -2675],
                        [ -2316,  -2315],
                        [ -1984,  -1983],
                        [ -1680,  -1680],
                        [ -1406,  -1406],
                        [ -1162,  -1162],
                        [  -946,   -945],
                        [  -756,   -756],
                        [  -596,   -596],
                        [  -459,   -459],
                        [  -347,   -346],
                        [  -257,   -257],
                        [  -188,   -188],
                        [  -137,   -137],
                        [  -105,   -105],
                        [   -89,    -89],
                        [   -89,    -89],
                        [  -101,   -100],
                        [  -124,   -124],
                        [  -161,   -161],
                        [  -206,   -207],
                        [  -263,   -262],
                        [  -327,   -327],
                        [  -400,   -401],
                        [  -481,   -481],
                        [  -568,   -568],
                        [  -662,   -662],
                        [  -763,   -763],
                        [  -869,   -869],
                        [  -981,   -981],
                        [ -1096,  -1096],
                        [ -1216,  -1216],
                        [ -1341,  -1341],
                        [ -1469,  -1469],
                        [ -1600,  -1599],
                        [ -1731,  -1731],
                        [ -1866,  -1866],
                        [ -2001,  -2002],
                        [ -2134,  -2135],
                        [ -2269,  -2269],
                        [ -2400,  -2400],
                        [ -2528,  -2528],
                        [ -2652,  -2651],
                        [ -2771,  -2771],
                        [ -2882,  -2882],
                        [ -2988,  -2988],
                        [ -3084,  -3085],
                        [ -3170,  -3171],
                        [ -3248,  -3248],
                        [ -3312,  -3312],
                        [ -3361,  -3361],
                        [ -3396,  -3395],
                        [ -3416,  -3416],
                        [ -3421,  -3421],
                        [ -3418,  -3418],
                        [ -3404,  -3404],
                        [ -3404,  -3404],
                        [ -3417,  -3417],
                        [ -3452,  -3452],
                        [ -3508,  -3508],
                        [ -3581,  -3581],
                        [ -3672,  -3673],
                        [ -3742,  -3742],
                        [ -3794,  -3794],
                        [ -3811,  -3811],
                        [ -3798,  -3798],
                        [ -3752,  -3752],
                        [ -3671,  -3672],
                        [ -3560,  -3560],
                        [ -3417,  -3417],
                        [ -3244,  -3244],
                        [ -3044,  -3044],
                        [ -2816,  -2816],
                        [ -2564,  -2565],
                        [ -2295,  -2295],
                        [ -2004,  -2004],
                        [ -1700,  -1701],
                        [ -1383,  -1384],
                        [ -1058,  -1058],
                        [  -726,   -727],
                        [  -394,   -394],
                        [   -60,    -60],
                        [   269,    268],
                        [   593,    592],
                        [   908,    908],
                        [  1211,   1212],
                        [  1502,   1502],
                        [  1776,   1776],
                        [  2033,   2033],
                        [  2270,   2270],
                        [  2485,   2485],
                        [  2679,   2679],
                        [  2849,   2849],
                        [  2994,   2994],
                        [  3114,   3114],
                        [  3207,   3208],
                        [  3274,   3274],
                        [  3313,   3313],
                        [  3325,   3325],
                        [  3311,   3311],
                        [  3269,   3269],
                        [  3198,   3198],
                        [  3103,   3103],
                        [  2980,   2980],
                        [  2819,   2819],
                        [  2615,   2616],
                        [  2381,   2381],
                        [  2117,   2117],
                        [  1801,   1801],
                        [  1396,   1397],
                        [   883,    883],
                        [   292,    292],
                        [  -345,   -345],
                        [ -1022,  -1022],
                        [ -1728,  -1728],
                        [ -2449,  -2448],
                        [ -3171,  -3170],
                        [ -3885,  -3885],
                        [ -4583,  -4582],
                        [ -5250,  -5250],
                        [ -5882,  -5882],
                        [ -6472,  -6471],
                        [ -7011,  -7010],
                        [ -7496,  -7495],
                        [ -7923,  -7923],
                        [ -8290,  -8290],
                        [ -8595,  -8595],
                        [ -8837,  -8837],
                        [ -9017,  -9017],
                        [ -9136,  -9136],
                        [ -9197,  -9197],
                        [ -9200,  -9200],
                        [ -9150,  -9150],
                        [ -9050,  -9051],
                        [ -8906,  -8907],
                        [ -8719,  -8720],
                        [ -8497,  -8498],
                        [ -8241,  -8242],
                        [ -7959,  -7960],
                        [ -7654,  -7655],
                        [ -7330,  -7331],
                        [ -6995,  -6996],
                        [ -6649,  -6650],
                        [ -6298,  -6299],
                        [ -5947,  -5947],
                        [ -5597,  -5598],
                        [ -5254,  -5255],
                        [ -4921,  -4921],
                        [ -4600,  -4600],
                        [ -4292,  -4292],
                        [ -4002,  -4002],
                        [ -3728,  -3728],
                        [ -3474,  -3475],
                        [ -3244,  -3244],
                        [ -3032,  -3033],
                        [ -2845,  -2845],
                        [ -2677,  -2678],
                        [ -2533,  -2533],
                        [ -2410,  -2410],
                        [ -2310,  -2310],
                        [ -2230,  -2231],
                        [ -2169,  -2169],
                        [ -2126,  -2126],
                        [ -2101,  -2101],
                        [ -2091,  -2091],
                        [ -2096,  -2096],
                        [ -2114,  -2113],
                        [ -2143,  -2142],
                        [ -2179,  -2179],
                        [ -2225,  -2225],
                        [ -2277,  -2277],
                        [ -2331,  -2332],
                        [ -2390,  -2390],
                        [ -2454,  -2454],
                        [ -2519,  -2518],
                        [ -2581,  -2581],
                        [ -2641,  -2641],
                        [ -2698,  -2698],
                        [ -2728,  -2728],
                        [ -2731,  -2731],
                        [ -2688,  -2688],
                        [ -2598,  -2598],
                        [ -2459,  -2459],
                        [ -2270,  -2270],
                        [ -2055,  -2055],
                        [ -1814,  -1814],
                        [ -1588,  -1588],
                        [ -1374,  -1374],
                        [ -1179,  -1179],
                        [ -1003,  -1003],
                        [  -854,   -854],
                        [  -730,   -730],
                        [  -637,   -637],
                        [  -574,   -573],
                        [  -542,   -542],
                        [  -544,   -544],
                        [  -579,   -579],
                        [  -648,   -648],
                        [  -752,   -752],
                        [  -889,   -888],
                        [ -1059,  -1059],
                        [ -1263,  -1263],
                        [ -1497,  -1497],
                        [ -1762,  -1762],
                        [ -2056,  -2056],
                        [ -2377,  -2377],
                        [ -2724,  -2725],
                        [ -3096,  -3097],
                        [ -3488,  -3488],
                        [ -3902,  -3902],
                        [ -4331,  -4331],
                        [ -4774,  -4774],
                        [ -5231,  -5230],
                        [ -5696,  -5696],
                        [ -6166,  -6166],
                        [ -6639,  -6639],
                        [ -7112,  -7112],
                        [ -7581,  -7581],
                        [ -8042,  -8042],
                        [ -8494,  -8493],
                        [ -8930,  -8930],
                        [ -9349,  -9349],
                        [ -9747,  -9746],
                        [-10120, -10119],
                        [-10463, -10462],
                        [-10775, -10775],
                        [-11052, -11052],
                        [-11295, -11295],
                        [-11522, -11521],
                        [-11745, -11744],
                        [-11958, -11958],
                        [-12143, -12142],
                        [-12254, -12253],
                        [-12245, -12244],
                        [-12120, -12119],
                        [-11895, -11895],
                        [-11572, -11572],
                        [-11161, -11161],
                        [-10677, -10677],
                        [-10129, -10129],
                        [ -9524,  -9524],
                        [ -8874,  -8875],
                        [ -8192,  -8192],
                        [ -7485,  -7485],
                        [ -6761,  -6761],
                        [ -6031,  -6031],
                        [ -5301,  -5301],
                        [ -4578,  -4578],
                        [ -3869,  -3870],
                        [ -3179,  -3179],
                        [ -2512,  -2513],
                        [ -1874,  -1874],
                        [ -1268,  -1268],
                        [  -694,   -695],
                        [  -158,   -158],
                        [   340,    340],
                        [   801,    801],
                        [  1221,   1221],
                        [  1602,   1602],
                        [  1944,   1944],
                        [  2246,   2246],
                        [  2508,   2508],
                        [  2734,   2734],
                        [  2923,   2923],
                        [  3076,   3076],
                        [  3196,   3196],
                        [  3285,   3285],
                        [  3343,   3342],
                        [  3372,   3371],
                        [  3373,   3373],
                        [  3351,   3351],
                        [  3306,   3306],
                        [  3239,   3240],
                        [  3157,   3157],
                        [  3057,   3057],
                        [  2942,   2942],
                        [  2818,   2818],
                        [  2682,   2682],
                        [  2541,   2541],
                        [  2393,   2394],
                        [  2243,   2243],
                        [  2093,   2093],
                        [  1944,   1944],
                        [  1799,   1800],
                        [  1658,   1659],
                        [  1527,   1527],
                        [  1404,   1405],
                        [  1292,   1293],
                        [  1193,   1194],
                        [  1109,   1109],
                        [  1039,   1040],
                        [   986,    986],
                        [   951,    951],
                        [   933,    933],
                        [   934,    934],
                        [   956,    956],
                        [   997,    997],
                        [  1061,   1060],
                        [  1146,   1145],
                        [  1246,   1246],
                        [  1356,   1356],
                        [  1476,   1476],
                        [  1575,   1575],
                        [  1657,   1656],
                        [  1709,   1707],
                        [  1732,   1731],
                        [  1723,   1721],
                        [  1681,   1680],
                        [  1649,   1649],
                        [  1624,   1624],
                        [  1622,   1621],
                        [  1635,   1634],
                        [  1675,   1675],
                        [  1737,   1736],
                        [  1821,   1820],
                        [  1928,   1927],
                        [  2056,   2055],
                        [  2204,   2204],
                        [  2370,   2369],
                        [  2552,   2551],
                        [  2750,   2749],
                        [  2956,   2955],
                        [  3170,   3170],
                        [  3392,   3392],
                        [  3615,   3615],
                        [  3839,   3839],
                        [  4059,   4059],
                        [  4274,   4274],
                        [  4479,   4479],
                        [  4675,   4676],
                        [  4857,   4857],
                        [  5023,   5024],
                        [  5173,   5173],
                        [  5304,   5304],
                        [  5414,   5415],
                        [  5502,   5503],
                        [  5568,   5570],
                        [  5612,   5613],
                        [  5631,   5631],
                        [  5626,   5627],
                        [  5596,   5597],
                        [  5540,   5542],
                        [  5463,   5464],
                        [  5361,   5362],
                        [  5234,   5235],
                        [  5086,   5086],
                        [  4915,   4916],
                        [  4723,   4723],
                        [  4509,   4509],
                        [  4277,   4277],
                        [  4055,   4055],
                        [  3884,   3884],
                        [  3780,   3780],
                        [  3746,   3746],
                        [  3768,   3768],
                        [  3799,   3799],
                        [  3776,   3776],
                        [  3671,   3672],
                        [  3493,   3493],
                        [  3248,   3249],
                        [  2945,   2945],
                        [  2594,   2596],
                        [  2207,   2208],
                        [  1788,   1788],
                        [  1350,   1350],
                        [   901,    902],
                        [   450,    450],
                        [     4,      5],
                        [  -430,   -429],
                        [  -845,   -844],
                        [ -1237,  -1237],
                        [ -1601,  -1601],
                        [ -1935,  -1935],
                        [ -2235,  -2234],
                        [ -2498,  -2498],
                        [ -2726,  -2726],
                        [ -2916,  -2916],
                        [ -3070,  -3070],
                        [ -3188,  -3189],
                        [ -3273,  -3274],
                        [ -3327,  -3327],
                        [ -3351,  -3352],
                        [ -3348,  -3348],
                        [ -3322,  -3323],
                        [ -3274,  -3275],
                        [ -3208,  -3209],
                        [ -3129,  -3131],
                        [ -3036,  -3037],
                        [ -2935,  -2936],
                        [ -2828,  -2829],
                        [ -2717,  -2718],
                        [ -2605,  -2606],
                        [ -2494,  -2495],
                        [ -2385,  -2386],
                        [ -2280,  -2281],
                        [ -2182,  -2182],
                        [ -2089,  -2089],
                        [ -2004,  -2005],
                        [ -1928,  -1929],
                        [ -1860,  -1860],
                        [ -1800,  -1801],
                        [ -1749,  -1749],
                        [ -1705,  -1705],
                        [ -1669,  -1669],
                        [ -1640,  -1640],
                        [ -1616,  -1617],
                        [ -1597,  -1598],
                        [ -1583,  -1584],
                        [ -1572,  -1572],
                        [ -1563,  -1563],
                        [ -1554,  -1554],
                        [ -1545,  -1546],
                        [ -1536,  -1536],
                        [ -1523,  -1522],
                        [ -1506,  -1506],
                        [ -1486,  -1486],
                        [ -1460,  -1460],
                        [ -1429,  -1428],
                        [ -1393,  -1392],
                        [ -1353,  -1351],
                        [ -1306,  -1305],
                        [ -1254,  -1253],
                        [ -1192,  -1191],
                        [ -1123,  -1122],
                        [ -1026,  -1025],
                        [  -904,   -903],
                        [  -745,   -743],
                        [  -548,   -547],
                        [  -308,   -306],
                        [   -24,    -22],
                        [   287,    288],
                        [   622,    623],
                        [   943,    944],
                        [  1253,   1255],
                        [  1541,   1543],
                        [  1808,   1809],
                        [  2042,   2043],
                        [  2245,   2246],
                        [  2407,   2408],
                        [  2531,   2532],
                        [  2611,   2613],
                        [  2646,   2647],
                        [  2636,   2637],
                        [  2580,   2581],
                        [  2477,   2477],
                        [  2329,   2329],
                        [  2138,   2139],
                        [  1904,   1905],
                        [  1629,   1630],
                        [  1317,   1318],
                        [   972,    973],
                        [   593,    595],
                        [   189,    190],
                        [  -240,   -239],
                        [  -687,   -687],
                        [ -1151,  -1151],
                        [ -1624,  -1624],
                        [ -2105,  -2104],
                        [ -2586,  -2585],
                        [ -3063,  -3063],
                        [ -3534,  -3534],
                        [ -3992,  -3992],
                        [ -4431,  -4431],
                        [ -4851,  -4851],
                        [ -5243,  -5242],
                        [ -5605,  -5604],
                        [ -5933,  -5931],
                        [ -6222,  -6221],
                        [ -6469,  -6468],
                        [ -6671,  -6670],
                        [ -6827,  -6826],
                        [ -6930,  -6929],
                        [ -6985,  -6983],
                        [ -7041,  -7040],
                        [ -7152,  -7150],
                        [ -7333,  -7331],
                        [ -7585,  -7583],
                        [ -7897,  -7895],
                        [ -8220,  -8219],
                        [ -8466,  -8466],
                        [ -8579,  -8579],
                        [ -8563,  -8563],
                        [ -8424,  -8424],
                        [ -8166,  -8167],
                        [ -7802,  -7803],
                        [ -7339,  -7340],
                        [ -6788,  -6789],
                        [ -6158,  -6159],
                        [ -5462,  -5464],
                        [ -4712,  -4714],
                        [ -3917,  -3920],
                        [ -3088,  -3090],
                        [ -2237,  -2239],
                        [ -1373,  -1376],
                        [  -505,   -507],
                        [   358,    356],
                        [  1208,   1206],
                        [  2038,   2035],
                        [  2841,   2839],
                        [  3613,   3611],
                        [  4347,   4345],
                        [  5039,   5038],
                        [  5690,   5688],
                        [  6294,   6292],
                        [  6848,   6847],
                        [  7354,   7353],
                        [  7811,   7810],
                        [  8218,   8217],
                        [  8575,   8574],
                        [  8885,   8885],
                        [  9147,   9147],
                        [  9366,   9365],
                        [  9541,   9541],
                        [  9677,   9677],
                        [  9775,   9776],
                        [  9838,   9839],
                        [  9869,   9870],
                        [  9874,   9874],
                        [  9852,   9852],
                        [  9809,   9809],
                        [  9747,   9747],
                        [  9669,   9669],
                        [  9579,   9579],
                        [  9481,   9481],
                        [  9377,   9377],
                        [  9269,   9269],
                        [  9163,   9164],
                        [  9059,   9060],
                        [  8960,   8960],
                        [  8868,   8869],
                        [  8786,   8787],
                        [  8716,   8717],
                        [  8658,   8659],
                        [  8615,   8615],
                        [  8587,   8587],
                        [  8574,   8574],
                        [  8578,   8578],
                        [  8599,   8599],
                        [  8636,   8636],
                        [  8690,   8690],
                        [  8759,   8758],
                        [  8845,   8843],
                        [  8946,   8945],
                        [  9062,   9060],
                        [  9189,   9186],
                        [  9324,   9322],
                        [  9461,   9458],
                        [  9597,   9595],
                        [  9718,   9715],
                        [  9822,   9819],
                        [  9899,   9895],
                        [  9951,   9947],
                        [  9960,   9957],
                        [  9927,   9924],
                        [  9878,   9874],
                        [  9806,   9803],
                        [  9727,   9724],
                        [  9638,   9635],
                        [  9545,   9542],
                        [  9449,   9445],
                        [  9350,   9348],
                        [  9253,   9250],
                        [  9157,   9154],
                        [  9061,   9059],
                        [  8970,   8968],
                        [  8881,   8878],
                        [  8793,   8791],
                        [  8708,   8707],
                        [  8625,   8623],
                        [  8542,   8541],
                        [  8459,   8457],
                        [  8375,   8374],
                        [  8288,   8288],
                        [  8199,   8198],
                        [  8106,   8105],
                        [  8006,   8006],
                        [  7901,   7901],
                        [  7789,   7789],
                        [  7668,   7668],
                        [  7539,   7540],
                        [  7401,   7401],
                        [  7254,   7255],
                        [  7096,   7097],
                        [  6928,   6929],
                        [  6751,   6751],
                        [  6562,   6563],
                        [  6363,   6364],
                        [  6154,   6154],
                        [  5935,   5935],
                        [  5706,   5707],
                        [  5469,   5470],
                        [  5224,   5223],
                        [  4969,   4969],
                        [  4709,   4708],
                        [  4436,   4435],
                        [  4170,   4169],
                        [  3981,   3980],
                        [  3934,   3933],
                        [  4045,   4045],
                        [  4315,   4314],
                        [  4743,   4743],
                        [  5280,   5280],
                        [  5812,   5812],
                        [  6263,   6263],
                        [  6627,   6628],
                        [  6911,   6912],
                        [  7114,   7115],
                        [  7240,   7242],
                        [  7294,   7295],
                        [  7278,   7280],
                        [  7202,   7204],
                        [  7069,   7070],
                        [  6887,   6888],
                        [  6662,   6663],
                        [  6399,   6400],
                        [  6107,   6108],
                        [  5790,   5791],
                        [  5453,   5454],
                        [  5102,   5103],
                        [  4743,   4744],
                        [  4378,   4379],
                        [  4011,   4012],
                        [  3647,   3648],
                        [  3288,   3289],
                        [  2936,   2936],
                        [  2591,   2592],
                        [  2257,   2257],
                        [  1934,   1934],
                        [  1621,   1621],
                        [  1321,   1320],
                        [  1033,   1032],
                        [   756,    755],
                        [   492,    492],
                        [   239,    238],
                        [    -2,     -3],
                        [  -231,   -232],
                        [  -449,   -451],
                        [  -657,   -658],
                        [  -852,   -854],
                        [ -1039,  -1041],
                        [ -1214,  -1216],
                        [ -1379,  -1380],
                        [ -1533,  -1535],
                        [ -1677,  -1679],
                        [ -1809,  -1811],
                        [ -1931,  -1932],
                        [ -2041,  -2042],
                        [ -2139,  -2140],
                        [ -2225,  -2226],
                        [ -2299,  -2301],
                        [ -2360,  -2361],
                        [ -2407,  -2408],
                        [ -2442,  -2444],
                        [ -2464,  -2465],
                        [ -2472,  -2472],
                        [ -2466,  -2467],
                        [ -2446,  -2447],
                        [ -2414,  -2415],
                        [ -2368,  -2368],
                        [ -2309,  -2309],
                        [ -2238,  -2238],
                        [ -2156,  -2156],
                        [ -2062,  -2062],
                        [ -1959,  -1958],
                        [ -1845,  -1845],
                        [ -1728,  -1727],
                        [ -1605,  -1603],
                        [ -1473,  -1471],
                        [ -1338,  -1336],
                        [ -1199,  -1197],
                        [ -1052,  -1050],
                        [  -901,   -898],
                        [  -746,   -743],
                        [  -591,   -587],
                        [  -419,   -416],
                        [  -233,   -231],
                        [   -31,    -27],
                        [   189,    193],
                        [   405,    409],
                        [   618,    622],
                        [   817,    821],
                        [  1002,   1005],
                        [  1162,   1165],
                        [  1297,   1301],
                        [  1399,   1402],
                        [  1471,   1474],
                        [  1506,   1509],
                        [  1502,   1506],
                        [  1459,   1462],
                        [  1378,   1381],
                        [  1259,   1260],
                        [  1101,   1103],
                        [   907,    908],
                        [   678,    680],
                        [   419,    421],
                        [   132,    134],
                        [  -177,   -176],
                        [  -509,   -507],
                        [  -856,   -854],
                        [ -1215,  -1213],
                        [ -1580,  -1578],
                        [ -1946,  -1944],
                        [ -2308,  -2307],
                        [ -2664,  -2663],
                        [ -3006,  -3005],
                        [ -3332,  -3330],
                        [ -3634,  -3633],
                        [ -3911,  -3909],
                        [ -4156,  -4154],
                        [ -4367,  -4366],
                        [ -4539,  -4537],
                        [ -4671,  -4669],
                        [ -4759,  -4757],
                        [ -4801,  -4799],
                        [ -4794,  -4792],
                        [ -4738,  -4736],
                        [ -4634,  -4631],
                        [ -4472,  -4470],
                        [ -4280,  -4278],
                        [ -4147,  -4145],
                        [ -4137,  -4136],
                        [ -4267,  -4266],
                        [ -4540,  -4539],
                        [ -4964,  -4964],
                        [ -5493,  -5493],
                        [ -5996,  -5995],
                        [ -6385,  -6385],
                        [ -6654,  -6654],
                        [ -6813,  -6814],
                        [ -6859,  -6861],
                        [ -6796,  -6798],
                        [ -6632,  -6633],
                        [ -6369,  -6372],
                        [ -6019,  -6022],
                        [ -5591,  -5594],
                        [ -5092,  -5095],
                        [ -4533,  -4536],
                        [ -3923,  -3927],
                        [ -3271,  -3275],
                        [ -2589,  -2593],
                        [ -1885,  -1889],
                        [ -1168,  -1172],
                        [  -447,   -451],
                        [   270,    267],
                        [   976,    972],
                        [  1664,   1661],
                        [  2329,   2326],
                        [  2966,   2962],
                        [  3572,   3569],
                        [  4141,   4138],
                        [  4673,   4670],
                        [  5166,   5163],
                        [  5616,   5615],
                        [  6027,   6026],
                        [  6397,   6395],
                        [  6726,   6725],
                        [  7016,   7015],
                        [  7268,   7267],
                        [  7485,   7485],
                        [  7668,   7668],
                        [  7820,   7820],
                        [  7944,   7945],
                        [  8045,   8045],
                        [  8121,   8122],
                        [  8178,   8179],
                        [  8221,   8222],
                        [  8249,   8249],
                        [  8266,   8267],
                        [  8276,   8278],
                        [  8282,   8283],
                        [  8286,   8287],
                        [  8288,   8290],
                        [  8293,   8294],
                        [  8301,   8303],
                        [  8315,   8317],
                        [  8335,   8336],
                        [  8361,   8363],
                        [  8397,   8398],
                        [  8441,   8442],
                        [  8492,   8493],
                        [  8551,   8552],
                        [  8620,   8621],
                        [  8693,   8695],
                        [  8773,   8774],
                        [  8860,   8860],
                        [  8948,   8948],
                        [  9037,   9037],
                        [  9128,   9128],
                        [  9219,   9218],
                        [  9306,   9304],
                        [  9385,   9384],
                        [  9458,   9456],
                        [  9522,   9519],
                        [  9575,   9571],
                        [  9627,   9622],
                        [  9672,   9668],
                        [  9706,   9702],
                        [  9729,   9725],
                        [  9709,   9705],
                        [  9648,   9644],
                        [  9540,   9535],
                        [  9383,   9378],
                        [  9185,   9181],
                        [  8947,   8942],
                        [  8676,   8672],
                        [  8372,   8368],
                        [  8044,   8040],
                        [  7690,   7685],
                        [  7318,   7315],
                        [  6929,   6926],
                        [  6528,   6525],
                        [  6118,   6116],
                        [  5702,   5701],
                        [  5280,   5279],
                        [  4857,   4856],
                        [  4435,   4434],
                        [  4015,   4015],
                        [  3599,   3598],
                        [  3187,   3187],
                        [  2781,   2781],
                        [  2383,   2383],
                        [  1992,   1992],
                        [  1609,   1609],
                        [  1237,   1237],
                        [   872,    872],
                        [   516,    516],
                        [   171,    171],
                        [  -166,   -165],
                        [  -492,   -492],
                        [  -809,   -809],
                        [ -1118,  -1118],
                        [ -1415,  -1415],
                        [ -1706,  -1705],
                        [ -1987,  -1987],
                        [ -2260,  -2260],
                        [ -2524,  -2524],
                        [ -2781,  -2782],
                        [ -3031,  -3031],
                        [ -3271,  -3272],
                        [ -3504,  -3504],
                        [ -3737,  -3737],
                        [ -3932,  -3933],
                        [ -3994,  -3995],
                        [ -3859,  -3861],
                        [ -3522,  -3524],
                        [ -2974,  -2975],
                        [ -2202,  -2203],
                        [ -1254,  -1255],
                        [  -276,   -277],
                        [   631,    631],
                        [  1458,   1458],
                        [  2211,   2212],
                        [  2875,   2876],
                        [  3447,   3449],
                        [  3929,   3930],
                        [  4318,   4319],
                        [  4614,   4616],
                        [  4821,   4823],
                        [  4941,   4942],
                        [  4977,   4980],
                        [  4938,   4940],
                        [  4825,   4828],
                        [  4643,   4647],
                        [  4401,   4404],
                        [  4105,   4106],
                        [  3759,   3762],
                        [  3372,   3374],
                        [  2946,   2948],
                        [  2491,   2493],
                        [  2012,   2013],
                        [  1511,   1512],
                        [   995,    996],
                        [   470,    470],
                        [   -62,    -62],
                        [  -596,   -596],
                        [ -1127,  -1128],
                        [ -1654,  -1654],
                        [ -2171,  -2171],
                        [ -2677,  -2678],
                        [ -3170,  -3170],
                        [ -3646,  -3647],
                        [ -4103,  -4105],
                        [ -4539,  -4541],
                        [ -4952,  -4955],
                        [ -5342,  -5345],
                        [ -5706,  -5709],
                        [ -6043,  -6045],
                        [ -6351,  -6354],
                        [ -6632,  -6634],
                        [ -6882,  -6884],
                        [ -7101,  -7103],
                        [ -7291,  -7293],
                        [ -7449,  -7451],
                        [ -7577,  -7579],
                        [ -7674,  -7677],
                        [ -7743,  -7746],
                        [ -7782,  -7785],
                        [ -7794,  -7796],
                        [ -7779,  -7781],
                        [ -7737,  -7739],
                        [ -7670,  -7673],
                        [ -7582,  -7586],
                        [ -7473,  -7476],
                        [ -7345,  -7347],
                        [ -7198,  -7201],
                        [ -7038,  -7040],
                        [ -6864,  -6866],
                        [ -6678,  -6680],
                        [ -6485,  -6487],
                        [ -6285,  -6286],
                        [ -6081,  -6082],
                        [ -5876,  -5877],
                        [ -5671,  -5671],
                        [ -5470,  -5469],
                        [ -5274,  -5272],
                        [ -5085,  -5084],
                        [ -4926,  -4925],
                        [ -4796,  -4795],
                        [ -4710,  -4709],
                        [ -4668,  -4668],
                        [ -4652,  -4652],
                        [ -4663,  -4664],
                        [ -4664,  -4665],
                        [ -4659,  -4660],
                        [ -4646,  -4647],
                        [ -4625,  -4625],
                        [ -4603,  -4603],
                        [ -4582,  -4579],
                        [ -4566,  -4562],
                        [ -4556,  -4551],
                        [ -4557,  -4552],
                        [ -4567,  -4562],
                        [ -4594,  -4590],
                        [ -4635,  -4631],
                        [ -4693,  -4691],
                        [ -4767,  -4765],
                        [ -4858,  -4856],
                        [ -4963,  -4962],
                        [ -5083,  -5083],
                        [ -5214,  -5214],
                        [ -5354,  -5354],
                        [ -5503,  -5502],
                        [ -5656,  -5653],
                        [ -5809,  -5805],
                        [ -5959,  -5954],
                        [ -6100,  -6095],
                        [ -6231,  -6227],
                        [ -6350,  -6346],
                        [ -6448,  -6446],
                        [ -6527,  -6527],
                        [ -6581,  -6582],
                        [ -6609,  -6611],
                        [ -6606,  -6611],
                        [ -6572,  -6577],
                        [ -6502,  -6509],
                        [ -6398,  -6407],
                        [ -6255,  -6264],
                        [ -6076,  -6086],
                        [ -5858,  -5870],
                        [ -5601,  -5614],
                        [ -5306,  -5319],
                        [ -4978,  -4991],
                        [ -4613,  -4628],
                        [ -4208,  -4223],
                        [ -3809,  -3825],
                        [ -3521,  -3538],
                        [ -3400,  -3417],
                        [ -3450,  -3469],
                        [ -3688,  -3707],
                        [ -4141,  -4161],
                        [ -4767,  -4787],
                        [ -5419,  -5440],
                        [ -6000,  -6023],
                        [ -6513,  -6536],
                        [ -6957,  -6979],
                        [ -7323,  -7346],
                        [ -7608,  -7631],
                        [ -7811,  -7835],
                        [ -7937,  -7959],
                        [ -7984,  -8006],
                        [ -7958,  -7979],
                        [ -7861,  -7882],
                        [ -7700,  -7720],
                        [ -7481,  -7499],
                        [ -7209,  -7226],
                        [ -6890,  -6907],
                        [ -6533,  -6547],
                        [ -6143,  -6156],
                        [ -5728,  -5740],
                        [ -5293,  -5303],
                        [ -4846,  -4853],
                        [ -4391,  -4396],
                        [ -3933,  -3936],
                        [ -3476,  -3477],
                        [ -3025,  -3024],
                        [ -2584,  -2581],
                        [ -2154,  -2149],
                        [ -1739,  -1731],
                        [ -1338,  -1328],
                        [  -956,   -943],
                        [  -592,   -577],
                        [  -245,   -227],
                        [    85,    106],
                        [   394,    419],
                        [   688,    717],
                        [   966,    999],
                        [  1229,   1265],
                        [  1477,   1519],
                        [  1714,   1760],
                        [  1939,   1990],
                        [  2156,   2211],
                        [  2364,   2424],
                        [  2563,   2628],
                        [  2759,   2828],
                        [  2950,   3023],
                        [  3140,   3213],
                        [  3329,   3399],
                        [  3517,   3583],
                        [  3707,   3766],
                        [  3898,   3947],
                        [  4089,   4126],
                        [  4280,   4302],
                        [  4466,   4474],
                        [  4650,   4643],
                        [  4824,   4806],
                        [  4992,   4963],
                        [  5150,   5111],
                        [  5295,   5251],
                        [  5428,   5380],
                        [  5548,   5497],
                        [  5651,   5599],
                        [  5736,   5683],
                        [  5801,   5750],
                        [  5846,   5800],
                        [  5866,   5827],
                        [  5864,   5835],
                        [  5835,   5817],
                        [  5780,   5773],
                        [  5713,   5719],
                        [  5632,   5652],
                        [  5569,   5604],
                        [  5520,   5570],
                        [  5483,   5548],
                        [  5458,   5539],
                        [  5402,   5498],
                        [  5318,   5428],
                        [  5168,   5292],
                        [  4955,   5092],
                        [  4682,   4833],
                        [  4353,   4514],
                        [  3975,   4147],
                        [  3545,   3729],
                        [  3079,   3270],
                        [  2572,   2772],
                        [  2038,   2245],
                        [  1477,   1689],
                        [   898,   1115],
                        [   303,    523],
                        [  -298,    -76],
                        [  -906,   -684],
                        [ -1512,  -1291],
                        [ -2115,  -1896],
                        [ -2708,  -2493],
                        [ -3291,  -3081],
                        [ -3859,  -3653],
                        [ -4410,  -4211],
                        [ -4941,  -4749],
                        [ -5451,  -5267],
                        [ -5939,  -5763],
                        [ -6400,  -6234],
                        [ -6839,  -6682],
                        [ -7251,  -7105],
                        [ -7636,  -7500],
                        [ -7997,  -7872],
                        [ -8331,  -8217],
                        [ -8640,  -8536],
                        [ -8925,  -8833],
                        [ -9185,  -9102],
                        [ -9422,  -9350],
                        [ -9636,  -9575],
                        [ -9829,  -9777],
                        [ -9999,  -9957],
                        [-10153, -10120],
                        [-10287, -10263],
                        [-10402, -10386],
                        [-10500, -10493],
                        [-10590, -10589],
                        [-10618, -10624],
                        [-10496, -10509],
                        [-10183, -10203],
                        [ -9680,  -9705],
                        [ -8970,  -9000],
                        [ -8024,  -8059],
                        [ -6883,  -6923],
                        [ -5693,  -5736],
                        [ -4547,  -4594],
                        [ -3448,  -3499],
                        [ -2405,  -2459],
                        [ -1433,  -1491],
                        [  -542,   -605],
                        [   262,    197],
                        [   974,    905],
                        [  1590,   1518],
                        [  2106,   2031],
                        [  2524,   2448],
                        [  2845,   2770],
                        [  3070,   3000],
                        [  3204,   3140],
                        [  3248,   3193],
                        [  3211,   3167],
                        [  3096,   3062],
                        [  2911,   2888],
                        [  2663,   2646],
                        [  2356,   2347],
                        [  2001,   1996],
                        [  1601,   1597],
                        [  1167,   1162],
                        [   703,    693],
                        [   217,    201],
                        [  -284,   -310],
                        [  -797,   -833],
                        [ -1314,  -1363],
                        [ -1828,  -1894],
                        [ -2338,  -2421],
                        [ -2835,  -2937],
                        [ -3319,  -3443],
                        [ -3782,  -3930],
                        [ -4225,  -4396],
                        [ -4643,  -4840],
                        [ -5034,  -5257],
                        [ -5397,  -5644],
                        [ -5727,  -6001],
                        [ -6026,  -6327],
                        [ -6293,  -6619],
                        [ -6526,  -6878],
                        [ -6726,  -7103],
                        [ -6893,  -7292],
                        [ -7030,  -7450],
                        [ -7139,  -7573],
                        [ -7222,  -7664],
                        [ -7282,  -7725],
                        [ -7322,  -7756],
                        [ -7342,  -7759],
                        [ -7343,  -7737],
                        [ -7325,  -7690],
                        [ -7287,  -7621],
                        [ -7227,  -7533],
                        [ -7149,  -7426],
                        [ -7055,  -7305],
                        [ -6945,  -7171],
                        [ -6823,  -7027],
                        [ -6692,  -6875],
                        [ -6552,  -6719],
                        [ -6407,  -6559],
                        [ -6258,  -6398],
                        [ -6109,  -6238],
                        [ -5961,  -6082],
                        [ -5813,  -5930],
                        [ -5672,  -5785],
                        [ -5539,  -5650],
                        [ -5420,  -5532],
                        [ -5316,  -5428],
                        [ -5270,  -5385],
                        [ -5282,  -5402],
                        [ -5368,  -5493],
                        [ -5528,  -5661],
                        [ -5744,  -5883],
                        [ -6013,  -6161],
                        [ -6271,  -6428],
                        [ -6520,  -6686],
                        [ -6740,  -6916],
                        [ -6930,  -7118],
                        [ -7095,  -7292],
                        [ -7231,  -7440],
                        [ -7343,  -7564],
                        [ -7430,  -7660],
                        [ -7494,  -7737],
                        [ -7533,  -7788],
                        [ -7553,  -7820],
                        [ -7551,  -7830],
                        [ -7533,  -7822],
                        [ -7493,  -7794],
                        [ -7436,  -7748],
                        [ -7360,  -7684],
                        [ -7268,  -7602],
                        [ -7156,  -7499],
                        [ -7027,  -7380],
                        [ -6877,  -7239],
                        [ -6708,  -7079],
                        [ -6520,  -6898],
                        [ -6310,  -6695],
                        [ -6078,  -6470],
                        [ -5824,  -6221],
                        [ -5548,  -5949],
                        [ -5248,  -5653],
                        [ -4924,  -5331],
                        [ -4577,  -4985],
                        [ -4206,  -4614],
                        [ -3811,  -4219],
                        [ -3395,  -3799],
                        [ -2958,  -3358],
                        [ -2498,  -2894],
                        [ -2022,  -2411],
                        [ -1528,  -1910],
                        [ -1019,  -1391],
                        [  -498,   -860],
                        [    33,   -317],
                        [   566,    230],
                        [  1104,    782],
                        [  1648,   1341],
                        [  2138,   1848],
                        [  2496,   2224],
                        [  2693,   2440],
                        [  2724,   2491],
                        [  2566,   2353],
                        [  2177,   1985],
                        [  1587,   1417],
                        [   921,    774],
                        [   259,    134],
                        [  -402,   -504],
                        [ -1055,  -1133],
                        [ -1682,  -1738],
                        [ -2275,  -2308],
                        [ -2830,  -2841],
                        [ -3339,  -3328],
                        [ -3798,  -3766],
                        [ -4201,  -4152],
                        [ -4550,  -4486],
                        [ -4843,  -4772],
                        [ -5077,  -5006],
                        [ -5254,  -5190],
                        [ -5379,  -5329],
                        [ -5449,  -5417],
                        [ -5470,  -5460],
                        [ -5445,  -5454],
                        [ -5375,  -5402],
                        [ -5267,  -5308],
                        [ -5120,  -5175],
                        [ -4942,  -5006],
                        [ -4734,  -4804],
                        [ -4498,  -4573],
                        [ -4240,  -4315],
                        [ -3962,  -4034],
                        [ -3665,  -3732],
                        [ -3354,  -3412],
                        [ -3030,  -3076],
                        [ -2696,  -2728],
                        [ -2352,  -2367],
                        [ -2002,  -1996],
                        [ -1646,  -1619],
                        [ -1286,  -1234],
                        [  -925,   -845],
                        [  -561,   -453],
                        [  -197,    -59],
                        [   166,    335],
                        [   528,    730],
                        [   886,   1123],
                        [  1241,   1512],
                        [  1591,   1898],
                        [  1935,   2278],
                        [  2275,   2650],
                        [  2610,   3015],
                        [  2942,   3369],
                        [  3273,   3712],
                        [  3599,   4042],
                        [  3923,   4359],
                        [  4234,   4658],
                        [  4535,   4939],
                        [  4815,   5201],
                        [  5072,   5441],
                        [  5301,   5658],
                        [  5503,   5852],
                        [  5672,   6017],
                        [  5810,   6156],
                        [  5915,   6264],
                        [  5984,   6342],
                        [  6017,   6387],
                        [  6014,   6400],
                        [  5974,   6379],
                        [  5896,   6322],
                        [  5778,   6229],
                        [  5623,   6099],
                        [  5432,   5938],
                        [  5206,   5740],
                        [  4975,   5539],
                        [  4739,   5333],
                        [  4544,   5168],
                        [  4384,   5038],
                        [  4266,   4946],
                        [  4188,   4895],
                        [  4102,   4832],
                        [  4010,   4764],
                        [  3857,   4631],
                        [  3642,   4435],
                        [  3374,   4182],
                        [  3053,   3872],
                        [  2680,   3510],
                        [  2261,   3097],
                        [  1801,   2641],
                        [  1304,   2146],
                        [   779,   1619],
                        [   227,   1063],
                        [  -342,    488],
                        [  -925,   -106],
                        [ -1514,   -706],
                        [ -2108,  -1315],
                        [ -2698,  -1919],
                        [ -3282,  -2521],
                        [ -3853,  -3111],
                        [ -4409,  -3688],
                        [ -4947,  -4245],
                        [ -5462,  -4783],
                        [ -5952,  -5297],
                        [ -6418,  -5786],
                        [ -6853,  -6245],
                        [ -7261,  -6676],
                        [ -7637,  -7076],
                        [ -7983,  -7444],
                        [ -8296,  -7781],
                        [ -8579,  -8086],
                        [ -8833,  -8361],
                        [ -9055,  -8603],
                        [ -9247,  -8816],
                        [ -9411,  -8999],
                        [ -9549,  -9155],
                        [ -9659,  -9283],
                        [ -9745,  -9385],
                        [ -9805,  -9462],
                        [ -9845,  -9516],
                        [ -9862,  -9548],
                        [ -9856,  -9555],
                        [ -9833,  -9546],
                        [ -9795,  -9520],
                        [ -9692,  -9430],
                        [ -9474,  -9224],
                        [ -9128,  -8891],
                        [ -8657,  -8433],
                        [ -8036,  -7824],
                        [ -7225,  -7026],
                        [ -6240,  -6055],
                        [ -5192,  -5020],
                        [ -4143,  -3986],
                        [ -3096,  -2954],
                        [ -2063,  -1939],
                        [ -1063,   -956],
                        [  -108,    -19],
                        [   794,    863],
                        [  1633,   1681],
                        [  2402,   2429],
                        [  3096,   3102],
                        [  3709,   3702],
                        [  4242,   4226],
                        [  4692,   4675],
                        [  5060,   5051],
                        [  5350,   5353],
                        [  5560,   5584],
                        [  5696,   5739],
                        [  5764,   5822],
                        [  5769,   5839],
                        [  5713,   5789],
                        [  5605,   5683],
                        [  5452,   5526],
                        [  5257,   5321],
                        [  5029,   5080],
                        [  4774,   4806],
                        [  4496,   4504],
                        [  4205,   4184],
                        [  3902,   3850],
                        [  3593,   3507],
                        [  3285,   3161],
                        [  2982,   2817],
                        [  2687,   2480],
                        [  2404,   2153],
                        [  2135,   1840],
                        [  1886,   1545],
                        [  1655,   1270],
                        [  1445,   1016],
                        [  1258,    787],
                        [  1093,    580],
                        [   954,    401],
                        [   838,    249],
                        [   743,    120],
                        [   671,     19],
                        [   618,    -59],
                        [   579,   -113],
                        [   552,   -145],
                        [   530,   -155],
                        [   513,   -148],
                        [   498,   -123],
                        [   485,    -82],
                        [   477,    -31],
                        [   473,     33],
                        [   481,    105],
                        [   495,    181],
                        [   514,    262],
                        [   540,    346],
                        [   570,    429],
                        [   602,    509],
                        [   634,    586],
                        [   666,    658],
                        [   696,    722],
                        [   722,    777],
                        [   747,    825],
                        [   769,    865],
                        [   786,    894],
                        [   795,    911],
                        [   787,    905],
                        [   761,    878],
                        [   665,    775],
                        [   501,    601],
                        [   252,    339],
                        [   -79,    -10],
                        [  -475,   -426],
                        [  -935,   -910],
                        [ -1376,  -1377],
                        [ -1801,  -1830],
                        [ -2182,  -2240],
                        [ -2517,  -2607],
                        [ -2806,  -2927],
                        [ -3044,  -3197],
                        [ -3230,  -3417],
                        [ -3364,  -3585],
                        [ -3447,  -3702],
                        [ -3476,  -3764],
                        [ -3455,  -3775],
                        [ -3382,  -3734],
                        [ -3262,  -3646],
                        [ -3093,  -3506],
                        [ -2879,  -3321],
                        [ -2620,  -3088],
                        [ -2321,  -2814],
                        [ -1981,  -2495],
                        [ -1603,  -2139],
                        [ -1190,  -1743],
                        [  -746,  -1315],
                        [  -269,   -851],
                        [   233,   -358],
                        [   763,    163],
                        [  1315,    711],
                        [  1887,   1281],
                        [  2475,   1870],
                        [  3079,   2477],
                        [  3692,   3096],
                        [  4315,   3729],
                        [  4942,   4366],
                        [  5571,   5010],
                        [  6197,   5653],
                        [  6819,   6294],
                        [  7431,   6928],
                        [  8030,   7551],
                        [  8612,   8159],
                        [  9176,   8750],
                        [  9714,   9319],
                        [ 10222,   9858],
                        [ 10704,  10372],
                        [ 11149,  10850],
                        [ 11521,  11257],
                        [ 11789,  11559],
                        [ 11949,  11756],
                        [ 11999,  11842],
                        [ 11912,  11791],
                        [ 11637,  11554],
                        [ 11178,  11130],
                        [ 10607,  10595],
                        [  9973,   9995],
                        [  9276,   9333],
                        [  8532,   8621],
                        [  7759,   7880],
                        [  6968,   7119],
                        [  6171,   6351],
                        [  5380,   5588],
                        [  4604,   4838],
                        [  3855,   4107],
                        [  3140,   3404],
                        [  2465,   2731],
                        [  1836,   2091],
                        [  1260,   1493],
                        [   737,    935],
                        [   271,    428],
                        [  -135,    -26],
                        [  -482,   -418],
                        [  -769,   -747],
                        [  -997,  -1015],
                        [ -1168,  -1220],
                        [ -1280,  -1363],
                        [ -1339,  -1445],
                        [ -1346,  -1471],
                        [ -1304,  -1441],
                        [ -1215,  -1358],
                        [ -1083,  -1225],
                        [  -912,  -1047],
                        [  -703,   -825],
                        [  -462,   -564],
                        [  -188,   -267],
                        [   112,     61],
                        [   433,    418],
                        [   775,    798],
                        [  1133,   1198],
                        [  1501,   1614],
                        [  1880,   2045],
                        [  2264,   2483],
                        [  2650,   2926],
                        [  3036,   3370],
                        [  3416,   3811],
                        [  3790,   4247],
                        [  4154,   4674],
                        [  4508,   5087],
                        [  4851,   5485],
                        [  5185,   5863],
                        [  5509,   6220],
                        [  5820,   6551],
                        [  6119,   6856],
                        [  6398,   7131],
                        [  6657,   7375],
                        [  6884,   7585],
                        [  7077,   7758],
                        [  7233,   7895],
                        [  7349,   7994],
                        [  7423,   8054],
                        [  7456,   8075],
                        [  7446,   8055],
                        [  7391,   7995],
                        [  7294,   7894],
                        [  7154,   7754],
                        [  6974,   7576],
                        [  6749,   7356],
                        [  6485,   7099],
                        [  6184,   6807],
                        [  5850,   6484],
                        [  5484,   6131],
                        [  5131,   5790],
                        [  4787,   5461],
                        [  4498,   5186],
                        [  4262,   4964],
                        [  4089,   4804],
                        [  3980,   4707],
                        [  3886,   4626],
                        [  3813,   4563],
                        [  3699,   4458],
                        [  3548,   4314],
                        [  3358,   4130],
                        [  3134,   3910],
                        [  2874,   3651],
                        [  2579,   3356],
                        [  2255,   3029],
                        [  1902,   2672],
                        [  1527,   2290],
                        [  1131,   1887],
                        [   722,   1468],
                        [   297,   1033],
                        [  -131,    593],
                        [  -566,    145],
                        [  -998,   -300],
                        [ -1426,   -743],
                        [ -1846,  -1180],
                        [ -2257,  -1606],
                        [ -2654,  -2019],
                        [ -3034,  -2416],
                        [ -3395,  -2793],
                        [ -3738,  -3152],
                        [ -4058,  -3488],
                        [ -4357,  -3801],
                        [ -4630,  -4091],
                        [ -4881,  -4356],
                        [ -5107,  -4596],
                        [ -5308,  -4811],
                        [ -5485,  -5001],
                        [ -5640,  -5168],
                        [ -5769,  -5308],
                        [ -5875,  -5426],
                        [ -5960,  -5522],
                        [ -6021,  -5595],
                        [ -6062,  -5646],
                        [ -6080,  -5676],
                        [ -6080,  -5688],
                        [ -6059,  -5678],
                        [ -6016,  -5648],
                        [ -5956,  -5601],
                        [ -5874,  -5536],
                        [ -5753,  -5434],
                        [ -5589,  -5293],
                        [ -5393,  -5122],
                        [ -5164,  -4922],
                        [ -4876,  -4667],
                        [ -4482,  -4307],
                        [ -3959,  -3821],
                        [ -3354,  -3253],
                        [ -2698,  -2635],
                        [ -1994,  -1969],
                        [ -1254,  -1268],
                        [  -495,   -548],
                        [   271,    178],
                        [  1034,    902],
                        [  1785,   1614],
                        [  2514,   2305],
                        [  3213,   2969],
                        [  3875,   3604],
                        [  4496,   4207],
                        [  5072,   4775],
                        [  5599,   5303],
                        [  6075,   5793],
                        [  6502,   6244],
                        [  6878,   6645],
                        [  7202,   6996],
                        [  7479,   7300],
                        [  7711,   7554],
                        [  7898,   7761],
                        [  8047,   7926],
                        [  8160,   8049],
                        [  8240,   8136],
                        [  8291,   8189],
                        [  8317,   8214],
                        [  8320,   8211],
                        [  8307,   8188],
                        [  8279,   8146],
                        [  8240,   8088],
                        [  8192,   8019],
                        [  8138,   7942],
                        [  8080,   7859],
                        [  8020,   7772],
                        [  7962,   7685],
                        [  7902,   7596],
                        [  7846,   7510],
                        [  7793,   7427],
                        [  7742,   7347],
                        [  7692,   7270],
                        [  7645,   7198],
                        [  7601,   7131],
                        [  7557,   7067],
                        [  7512,   7005],
                        [  7461,   6947],
                        [  7404,   6890],
                        [  7333,   6832],
                        [  7251,   6775],
                        [  7152,   6716],
                        [  7038,   6654],
                        [  6913,   6589],
                        [  6773,   6518],
                        [  6628,   6440],
                        [  6476,   6355],
                        [  6319,   6264],
                        [  6154,   6163],
                        [  5985,   6054],
                        [  5812,   5937],
                        [  5635,   5809],
                        [  5454,   5674],
                        [  5272,   5528],
                        [  5086,   5372],
                        [  4903,   5212],
                        [  4722,   5047],
                        [  4542,   4876],
                        [  4362,   4696],
                        [  4171,   4499],
                        [  3968,   4284],
                        [  3707,   4003],
                        [  3394,   3664],
                        [  3013,   3252],
                        [  2567,   2770],
                        [  2067,   2230],
                        [  1511,   1631],
                        [   984,   1055],
                        [   479,    500],
                        [    24,     -7],
                        [  -378,   -463],
                        [  -721,   -862],
                        [ -1003,  -1200],
                        [ -1219,  -1472],
                        [ -1370,  -1679],
                        [ -1454,  -1818],
                        [ -1467,  -1885],
                        [ -1416,  -1887],
                        [ -1298,  -1819],
                        [ -1116,  -1687],
                        [  -873,  -1489],
                        [  -573,  -1230],
                        [  -215,   -912],
                        [   191,   -540],
                        [   647,   -117],
                        [  1143,    351],
                        [  1680,    864],
                        [  2247,   1410],
                        [  2846,   1991],
                        [  3466,   2599],
                        [  4105,   3229],
                        [  4758,   3876],
                        [  5419,   4535],
                        [  6082,   5201],
                        [  6745,   5869],
                        [  7398,   6530],
                        [  8042,   7187],
                        [  8668,   7826],
                        [  9273,   8449],
                        [  9853,   9049],
                        [ 10402,   9620],
                        [ 10919,  10160],
                        [ 11398,  10665],
                        [ 11835,  11129],
                        [ 12227,  11551],
                        [ 12572,  11925],
                        [ 12865,  12249],
                        [ 13104,  12521],
                        [ 13287,  12740],
                        [ 13414,  12907],
                        [ 13504,  13041],
                        [ 13574,  13160],
                        [ 13621,  13258],
                        [ 13623,  13314],
                        [ 13531,  13275],
                        [ 13302,  13098],
                        [ 12948,  12793],
                        [ 12488,  12377],
                        [ 11928,  11858],
                        [ 11286,  11253],
                        [ 10574,  10573],
                        [  9808,   9835],
                        [  8999,   9050],
                        [  8162,   8232],
                        [  7311,   7396],
                        [  6457,   6550],
                        [  5610,   5701],
                        [  4782,   4861],
                        [  3980,   4037],
                        [  3215,   3236],
                        [  2491,   2464],
                        [  1814,   1731],
                        [  1190,   1042],
                        [   623,    411],
                        [   113,   -164],
                        [  -335,   -674],
                        [  -723,  -1118],
                        [ -1050,  -1496],
                        [ -1316,  -1806],
                        [ -1525,  -2050],
                        [ -1677,  -2229],
                        [ -1775,  -2347],
                        [ -1822,  -2405],
                        [ -1822,  -2408],
                        [ -1778,  -2362],
                        [ -1695,  -2269],
                        [ -1575,  -2133],
                        [ -1425,  -1961],
                        [ -1249,  -1754],
                        [ -1051,  -1520],
                        [  -835,  -1264],
                        [  -605,   -989],
                        [  -367,   -702],
                        [  -126,   -407],
                        [   117,   -108],
                        [   355,    188],
                        [   586,    479],
                        [   806,    759],
                        [  1012,   1025],
                        [  1203,   1273],
                        [  1376,   1501],
                        [  1529,   1701],
                        [  1664,   1878],
                        [  1779,   2023],
                        [  1871,   2136],
                        [  1943,   2216],
                        [  1991,   2260],
                        [  2012,   2270],
                        [  2001,   2243],
                        [  1957,   2178],
                        [  1879,   2076],
                        [  1767,   1939],
                        [  1623,   1766],
                        [  1441,   1558],
                        [  1229,   1317],
                        [   984,   1047],
                        [   709,    746],
                        [   405,    419],
                        [    71,     63],
                        [  -286,   -314],
                        [  -665,   -710],
                        [ -1059,  -1119],
                        [ -1465,  -1538],
                        [ -1844,  -1928],
                        [ -2197,  -2290],
                        [ -2492,  -2591],
                        [ -2731,  -2834],
                        [ -2896,  -3002],
                        [ -2988,  -3096],
                        [ -3040,  -3148],
                        [ -3046,  -3153],
                        [ -3066,  -3170],
                        [ -3088,  -3189],
                        [ -3121,  -3218],
                        [ -3163,  -3256],
                        [ -3219,  -3306],
                        [ -3289,  -3371],
                        [ -3375,  -3451],
                        [ -3474,  -3543],
                        [ -3589,  -3651],
                        [ -3716,  -3772],
                        [ -3856,  -3905],
                        [ -4007,  -4049],
                        [ -4168,  -4201],
                        [ -4338,  -4362],
                        [ -4513,  -4529],
                        [ -4692,  -4700],
                        [ -4876,  -4874],
                        [ -5061,  -5050],
                        [ -5243,  -5222],
                        [ -5425,  -5394],
                        [ -5604,  -5563],
                        [ -5779,  -5727],
                        [ -5946,  -5884],
                        [ -6108,  -6035],
                        [ -6260,  -6177],
                        [ -6404,  -6311],
                        [ -6539,  -6434],
                        [ -6663,  -6549],
                        [ -6776,  -6652],
                        [ -6878,  -6745],
                        [ -6966,  -6823],
                        [ -7042,  -6892],
                        [ -7105,  -6947],
                        [ -7153,  -6988],
                        [ -7185,  -7015],
                        [ -7202,  -7028],
                        [ -7203,  -7027],
                        [ -7186,  -7009],
                        [ -7149,  -6975],
                        [ -7092,  -6923],
                        [ -7012,  -6855],
                        [ -6938,  -6799],
                        [ -6912,  -6799],
                        [ -6949,  -6871],
                        [ -7047,  -7009],
                        [ -7186,  -7197],
                        [ -7320,  -7380],
                        [ -7375,  -7485],
                        [ -7328,  -7486],
                        [ -7187,  -7393],
                        [ -6958,  -7209],
                        [ -6649,  -6942],
                        [ -6270,  -6603],
                        [ -5830,  -6201],
                        [ -5337,  -5744],
                        [ -4804,  -5241],
                        [ -4236,  -4700],
                        [ -3644,  -4132],
                        [ -3036,  -3538],
                        [ -2419,  -2929],
                        [ -1800,  -2309],
                        [ -1184,  -1684],
                        [  -577,  -1055],
                        [    15,   -429],
                        [   590,    185],
                        [  1146,    786],
                        [  1676,   1364],
                        [  2182,   1918],
                        [  2660,   2442],
                        [  3111,   2935],
                        [  3534,   3395],
                        [  3928,   3821],
                        [  4295,   4214],
                        [  4632,   4576],
                        [  4942,   4908],
                        [  5227,   5212],
                        [  5484,   5487],
                        [  5715,   5734],
                        [  5922,   5955],
                        [  6104,   6151],
                        [  6262,   6320],
                        [  6397,   6464],
                        [  6509,   6585],
                        [  6599,   6684],
                        [  6667,   6759],
                        [  6714,   6812],
                        [  6738,   6844],
                        [  6741,   6853],
                        [  6723,   6842],
                        [  6684,   6810],
                        [  6622,   6758],
                        [  6541,   6686],
                        [  6437,   6594],
                        [  6311,   6482],
                        [  6164,   6351],
                        [  5995,   6202],
                        [  5802,   6034],
                        [  5584,   5849],
                        [  5343,   5647],
                        [  5078,   5430],
                        [  4795,   5196],
                        [  4495,   4949],
                        [  4180,   4688],
                        [  3855,   4417],
                        [  3522,   4135],
                        [  3180,   3843],
                        [  2836,   3543],
                        [  2491,   3239],
                        [  2146,   2931],
                        [  1805,   2620],
                        [  1475,   2315],
                        [  1155,   2012],
                        [   845,   1713],
                        [   548,   1419],
                        [   254,   1123],
                        [   -36,    825],
                        [  -348,    497],
                        [  -678,    145],
                        [ -1037,   -240],
                        [ -1419,   -654],
                        [ -1831,  -1104],
                        [ -2271,  -1587],
                        [ -2684,  -2045],
                        [ -3071,  -2481],
                        [ -3413,  -2874],
                        [ -3708,  -3223],
                        [ -3948,  -3517],
                        [ -4130,  -3756],
                        [ -4250,  -3932],
                        [ -4310,  -4047],
                        [ -4304,  -4097],
                        [ -4235,  -4082],
                        [ -4102,  -4002],
                        [ -3907,  -3859],
                        [ -3655,  -3655],
                        [ -3346,  -3393],
                        [ -2984,  -3076],
                        [ -2574,  -2707],
                        [ -2121,  -2294],
                        [ -1631,  -1838],
                        [ -1107,  -1347],
                        [  -556,   -826],
                        [    15,   -280],
                        [   603,    285],
                        [  1198,    860],
                        [  1797,   1443],
                        [  2392,   2025],
                        [  2979,   2602],
                        [  3551,   3167],
                        [  4104,   3714],
                        [  4631,   4238],
                        [  5130,   4737],
                        [  5592,   5201],
                        [  6018,   5630],
                        [  6400,   6016],
                        [  6736,   6359],
                        [  7024,   6653],
                        [  7260,   6897],
                        [  7443,   7089],
                        [  7569,   7226],
                        [  7639,   7305],
                        [  7652,   7330],
                        [  7602,   7295],
                        [  7495,   7207],
                        [  7389,   7125],
                        [  7339,   7106],
                        [  7363,   7168],
                        [  7461,   7310],
                        [  7629,   7524],
                        [  7814,   7755],
                        [  7927,   7910],
                        [  7916,   7937],
                        [  7789,   7844],
                        [  7554,   7638],
                        [  7218,   7326],
                        [  6796,   6922],
                        [  6296,   6436],
                        [  5731,   5877],
                        [  5111,   5260],
                        [  4450,   4596],
                        [  3759,   3895],
                        [  3049,   3170],
                        [  2331,   2432],
                        [  1614,   1688],
                        [   906,    947],
                        [   215,    216],
                        [  -450,   -499],
                        [ -1083,  -1190],
                        [ -1680,  -1848],
                        [ -2237,  -2471],
                        [ -2750,  -3046],
                        [ -3219,  -3574],
                        [ -3639,  -4049],
                        [ -4014,  -4470],
                        [ -4341,  -4837],
                        [ -4623,  -5150],
                        [ -4860,  -5413],
                        [ -5055,  -5629],
                        [ -5213,  -5803],
                        [ -5334,  -5937],
                        [ -5423,  -6034],
                        [ -5484,  -6098],
                        [ -5519,  -6134],
                        [ -5534,  -6143],
                        [ -5532,  -6133],
                        [ -5517,  -6106],
                        [ -5493,  -6067],
                        [ -5464,  -6021],
                        [ -5435,  -5971],
                        [ -5408,  -5922],
                        [ -5385,  -5876],
                        [ -5372,  -5839],
                        [ -5371,  -5813],
                        [ -5381,  -5798],
                        [ -5409,  -5802],
                        [ -5454,  -5823],
                        [ -5521,  -5865],
                        [ -5612,  -5929],
                        [ -5725,  -6015],
                        [ -5861,  -6125],
                        [ -6013,  -6260],
                        [ -6180,  -6417],
                        [ -6359,  -6598],
                        [ -6554,  -6801],
                        [ -6762,  -7027],
                        [ -6982,  -7272],
                        [ -7215,  -7534],
                        [ -7460,  -7815],
                        [ -7715,  -8108],
                        [ -7979,  -8413],
                        [ -8250,  -8727],
                        [ -8526,  -9046],
                        [ -8806,  -9369],
                        [ -9091,  -9696],
                        [ -9375, -10021],
                        [ -9655, -10340],
                        [ -9926, -10648],
                        [-10187, -10942],
                        [-10415, -11201],
                        [-10612, -11424],
                        [-10766, -11600],
                        [-10875, -11728],
                        [-10920, -11789],
                        [-10901, -11781],
                        [-10827, -11715],
                        [-10698, -11590],
                        [-10545, -11437],
                        [-10369, -11256],
                        [-10176, -11055],
                        [ -9967, -10835],
                        [ -9752, -10607],
                        [ -9531, -10369],
                        [ -9313, -10131],
                        [ -9096,  -9892],
                        [ -8886,  -9657],
                        [ -8684,  -9428],
                        [ -8495,  -9209],
                        [ -8317,  -9000],
                        [ -8153,  -8804],
                        [ -8004,  -8620],
                        [ -7871,  -8451],
                        [ -7754,  -8297],
                        [ -7652,  -8158],
                        [ -7568,  -8033],
                        [ -7497,  -7923],
                        [ -7441,  -7828],
                        [ -7398,  -7746],
                        [ -7369,  -7676],
                        [ -7349,  -7617],
                        [ -7340,  -7570],
                        [ -7340,  -7532],
                        [ -7347,  -7502],
                        [ -7357,  -7477],
                        [ -7373,  -7458],
                        [ -7390,  -7441],
                        [ -7406,  -7426],
                        [ -7420,  -7410],
                        [ -7431,  -7395],
                        [ -7434,  -7372],
                        [ -7430,  -7345],
                        [ -7416,  -7309],
                        [ -7390,  -7265],
                        [ -7347,  -7207],
                        [ -7291,  -7138],
                        [ -7215,  -7053],
                        [ -7113,  -6948],
                        [ -6997,  -6838],
                        [ -6946,  -6801],
                        [ -7019,  -6897],
                        [ -7231,  -7141],
                        [ -7581,  -7530],
                        [ -8062,  -8060],
                        [ -8627,  -8674],
                        [ -9152,  -9249],
                        [ -9566,  -9710],
                        [ -9864, -10054],
                        [-10052, -10285],
                        [-10132, -10405],
                        [-10108, -10415],
                        [ -9983, -10323],
                        [ -9765, -10131],
                        [ -9462,  -9849],
                        [ -9082,  -9486],
                        [ -8632,  -9046],
                        [ -8121,  -8541],
                        [ -7557,  -7981],
                        [ -6949,  -7373],
                        [ -6304,  -6724],
                        [ -5633,  -6039],
                        [ -4939,  -5325],
                        [ -4235,  -4588],
                        [ -3525,  -3836],
                        [ -2815,  -3077],
                        [ -2111,  -2319],
                        [ -1419,  -1571],
                        [  -743,   -840],
                        [   -89,   -132],
                        [   544,    551],
                        [  1146,   1203],
                        [  1719,   1824],
                        [  2258,   2412],
                        [  2762,   2966],
                        [  3229,   3485],
                        [  3659,   3967],
                        [  4047,   4408],
                        [  4396,   4809],
                        [  4704,   5169],
                        [  4970,   5488],
                        [  5196,   5766],
                        [  5380,   6000],
                        [  5523,   6193],
                        [  5626,   6346],
                        [  5689,   6457],
                        [  5714,   6529],
                        [  5701,   6562],
                        [  5653,   6558],
                        [  5569,   6517],
                        [  5453,   6442],
                        [  5311,   6335],
                        [  5144,   6196],
                        [  4957,   6029],
                        [  4753,   5834],
                        [  4531,   5615],
                        [  4288,   5373],
                        [  4021,   5111],
                        [  3733,   4833],
                        [  3424,   4539],
                        [  3096,   4232],
                        [  2756,   3916],
                        [  2404,   3593],
                        [  2047,   3264],
                        [  1686,   2934],
                        [  1327,   2604],
                        [   972,   2277],
                        [   624,   1957],
                        [   287,   1645],
                        [   -34,   1344],
                        [  -340,   1055],
                        [  -626,    781],
                        [  -894,    522],
                        [ -1145,    275],
                        [ -1375,     43],
                        [ -1587,   -175],
                        [ -1782,   -380],
                        [ -1961,   -574],
                        [ -2127,   -761],
                        [ -2303,   -960],
                        [ -2484,  -1170],
                        [ -2656,  -1374],
                        [ -2819,  -1572],
                        [ -2961,  -1753],
                        [ -3083,  -1915],
                        [ -3174,  -2049],
                        [ -3239,  -2157],
                        [ -3267,  -2230],
                        [ -3265,  -2273],
                        [ -3223,  -2277],
                        [ -3146,  -2245],
                        [ -3032,  -2178],
                        [ -2883,  -2073],
                        [ -2699,  -1933],
                        [ -2484,  -1761],
                        [ -2240,  -1558],
                        [ -1970,  -1328],
                        [ -1677,  -1073],
                        [ -1366,   -799],
                        [ -1040,   -509],
                        [  -704,   -206],
                        [  -364,    102],
                        [   -22,    414],
                        [   314,    724],
                        [   644,   1027],
                        [   960,   1319],
                        [  1259,   1594],
                        [  1536,   1850],
                        [  1790,   2084],
                        [  2014,   2289],
                        [  2207,   2464],
                        [  2365,   2605],
                        [  2488,   2711],
                        [  2571,   2778],
                        [  2613,   2806],
                        [  2615,   2793],
                        [  2576,   2739],
                        [  2493,   2641],
                        [  2368,   2503],
                        [  2203,   2324],
                        [  1996,   2105],
                        [  1740,   1841],
                        [  1469,   1565],
                        [  1275,   1371],
                        [  1224,   1325],
                        [  1329,   1443],
                        [  1597,   1729],
                        [  2039,   2191],
                        [  2602,   2777],
                        [  3152,   3348],
                        [  3603,   3816],
                        [  3959,   4187],
                        [  4223,   4463],
                        [  4396,   4643],
                        [  4479,   4731],
                        [  4482,   4732],
                        [  4407,   4652],
                        [  4262,   4497],
                        [  4055,   4276],
                        [  3794,   4000],
                        [  3485,   3674],
                        [  3137,   3313],
                        [  2760,   2923],
                        [  2357,   2510],
                        [  1937,   2080],
                        [  1507,   1633],
                        [  1072,   1177],
                        [   638,    713],
                        [   210,    249],
                        [  -210,   -209],
                        [  -618,   -656],
                        [ -1008,  -1086],
                        [ -1384,  -1499],
                        [ -1742,  -1890],
                        [ -2080,  -2259],
                        [ -2401,  -2608],
                        [ -2704,  -2937],
                        [ -2990,  -3251],
                        [ -3261,  -3549],
                        [ -3519,  -3833],
                        [ -3766,  -4104],
                        [ -4002,  -4363],
                        [ -4232,  -4614],
                        [ -4454,  -4857],
                        [ -4674,  -5096],
                        [ -4890,  -5331],
                        [ -5107,  -5565],
                        [ -5324,  -5800],
                        [ -5544,  -6036],
                        [ -5768,  -6276],
                        [ -5997,  -6522],
                        [ -6231,  -6772],
                        [ -6472,  -7030],
                        [ -6721,  -7293],
                        [ -6982,  -7565],
                        [ -7259,  -7843],
                        [ -7553,  -8127],
                        [ -7863,  -8418],
                        [ -8187,  -8713],
                        [ -8513,  -9011],
                        [ -8842,  -9314],
                        [ -9160,  -9614],
                        [ -9466,  -9914],
                        [ -9758, -10212],
                        [-10036, -10503],
                        [-10296, -10786],
                        [-10538, -11061],
                        [-10761, -11321],
                        [-10964, -11568],
                        [-11145, -11797],
                        [-11303, -12007],
                        [-11438, -12195],
                        [-11550, -12362],
                        [-11637, -12504],
                        [-11694, -12617],
                        [-11726, -12702],
                        [-11728, -12756],
                        [-11710, -12786],
                        [-11668, -12790],
                        [-11610, -12774],
                        [-11538, -12739],
                        [-11428, -12662],
                        [-11282, -12544],
                        [-11078, -12363],
                        [-10818, -12120],
                        [-10515, -11828],
                        [-10166, -11486],
                        [ -9786, -11106],
                        [ -9373, -10688],
                        [ -8940, -10247],
                        [ -8488,  -9781],
                        [ -8029,  -9303],
                        [ -7564,  -8816],
                        [ -7101,  -8325],
                        [ -6642,  -7834],
                        [ -6195,  -7352],
                        [ -5761,  -6879],
                        [ -5345,  -6422],
                        [ -4947,  -5980],
                        [ -4573,  -5560],
                        [ -4223,  -5160],
                        [ -3898,  -4785],
                        [ -3599,  -4435],
                        [ -3324,  -4108],
                        [ -3077,  -3807],
                        [ -2854,  -3531],
                        [ -2654,  -3279],
                        [ -2477,  -3049],
                        [ -2321,  -2842],
                        [ -2182,  -2654],
                        [ -2061,  -2484],
                        [ -1955,  -2329],
                        [ -1861,  -2190],
                        [ -1773,  -2059],
                        [ -1692,  -1937],
                        [ -1616,  -1822],
                        [ -1540,  -1710],
                        [ -1458,  -1596],
                        [ -1375,  -1482],
                        [ -1282,  -1363],
                        [ -1180,  -1237],
                        [ -1063,  -1099],
                        [  -934,   -951],
                        [  -787,   -791],
                        [  -611,   -606],
                        [  -448,   -440],
                        [  -397,   -392],
                        [  -514,   -518],
                        [  -807,   -828],
                        [ -1281,  -1326],
                        [ -1950,  -2025],
                        [ -2763,  -2869],
                        [ -3565,  -3706],
                        [ -4267,  -4440],
                        [ -4865,  -5070],
                        [ -5361,  -5596],
                        [ -5747,  -6009],
                        [ -6023,  -6309],
                        [ -6189,  -6494],
                        [ -6249,  -6567],
                        [ -6205,  -6533],
                        [ -6065,  -6396],
                        [ -5833,  -6165],
                        [ -5517,  -5852],
                        [ -5124,  -5464],
                        [ -4665,  -5012],
                        [ -4144,  -4503],
                        [ -3572,  -3941],
                        [ -2957,  -3335],
                        [ -2310,  -2685],
                        [ -1636,  -2001],
                        [  -947,  -1290],
                        [  -250,   -561],
                        [   446,    175],
                        [  1135,    911],
                        [  1809,   1636],
                        [  2461,   2347],
                        [  3087,   3033],
                        [  3681,   3692],
                        [  4242,   4321],
                        [  4764,   4916],
                        [  5246,   5475],
                        [  5685,   5994],
                        [  6080,   6471],
                        [  6429,   6901],
                        [  6731,   7287],
                        [  6987,   7628],
                        [  7195,   7919],
                        [  7357,   8165],
                        [  7473,   8363],
                        [  7546,   8517],
                        [  7574,   8625],
                        [  7562,   8689],
                        [  7511,   8712],
                        [  7422,   8697],
                        [  7302,   8644],
                        [  7151,   8557],
                        [  6983,   8439],
                        [  6800,   8292],
                        [  6610,   8118],
                        [  6417,   7921],
                        [  6221,   7706],
                        [  6021,   7473],
                        [  5809,   7228],
                        [  5586,   6972],
                        [  5349,   6710],
                        [  5103,   6443],
                        [  4849,   6175],
                        [  4591,   5909],
                        [  4332,   5647],
                        [  4076,   5390],
                        [  3824,   5144],
                        [  3582,   4909],
                        [  3349,   4686],
                        [  3131,   4478],
                        [  2927,   4287],
                        [  2742,   4114],
                        [  2576,   3958],
                        [  2429,   3820],
                        [  2312,   3712],
                        [  2225,   3634],
                        [  2191,   3606],
                        [  2212,   3629],
                        [  2278,   3696],
                        [  2392,   3808],
                        [  2512,   3924],
                        [  2640,   4045],
                        [  2751,   4146],
                        [  2846,   4229],
                        [  2931,   4301],
                        [  3002,   4357],
                        [  3067,   4405],
                        [  3124,   4444],
                        [  3178,   4479],
                        [  3226,   4508],
                        [  3275,   4535],
                        [  3322,   4559],
                        [  3370,   4583],
                        [  3419,   4607],
                        [  3469,   4630],
                        [  3518,   4652],
                        [  3569,   4674],
                        [  3616,   4692],
                        [  3662,   4708],
                        [  3704,   4720],
                        [  3741,   4725],
                        [  3769,   4722],
                        [  3789,   4710],
                        [  3798,   4687],
                        [  3793,   4649],
                        [  3775,   4598],
                        [  3741,   4530],
                        [  3687,   4443],
                        [  3616,   4337],
                        [  3525,   4212],
                        [  3411,   4063],
                        [  3277,   3894],
                        [  3120,   3702],
                        [  2942,   3488],
                        [  2741,   3250],
                        [  2519,   2992],
                        [  2277,   2714],
                        [  2016,   2416],
                        [  1736,   2099],
                        [  1439,   1765],
                        [  1129,   1419],
                        [   808,   1062],
                        [   468,    687],
                        [   165,    349],
                        [     2,    154],
                        [    29,    150],
                        [   252,    346],
                        [   686,    759],
                        [  1354,   1410],
                        [  2208,   2249],
                        [  3095,   3124],
                        [  3924,   3942],
                        [  4697,   4704],
                        [  5412,   5410],
                        [  6059,   6046],
                        [  6632,   6607],
                        [  7131,   7094],
                        [  7555,   7504],
                        [  7903,   7837],
                        [  8178,   8095],
                        [  8379,   8286],
                        [  8513,   8413],
                        [  8579,   8484],
                        [  8585,   8506],
                        [  8531,   8478],
                        [  8422,   8408],
                        [  8263,   8288],
                        [  8058,   8123],
                        [  7811,   7910],
                        [  7528,   7655],
                        [  7213,   7359],
                        [  6871,   7030],
                        [  6507,   6671],
                        [  6124,   6286],
                        [  5725,   5881],
                        [  5314,   5457],
                        [  4893,   5020],
                        [  4462,   4569],
                        [  4024,   4104],
                        [  3577,   3627],
                        [  3124,   3142],
                        [  2666,   2649],
                        [  2205,   2149],
                        [  1741,   1645],
                        [  1275,   1135],
                        [   808,    622],
                        [   341,    109],
                        [  -124,   -406],
                        [  -587,   -921],
                        [ -1047,  -1432],
                        [ -1502,  -1940],
                        [ -1949,  -2444],
                        [ -2389,  -2941],
                        [ -2820,  -3430],
                        [ -3245,  -3908],
                        [ -3665,  -4376],
                        [ -4088,  -4829],
                        [ -4510,  -5267],
                        [ -4933,  -5688],
                        [ -5354,  -6088],
                        [ -5757,  -6467],
                        [ -6147,  -6823],
                        [ -6500,  -7153],
                        [ -6819,  -7456],
                        [ -7096,  -7729],
                        [ -7334,  -7973],
                        [ -7529,  -8183],
                        [ -7681,  -8358],
                        [ -7789,  -8498],
                        [ -7851,  -8601],
                        [ -7872,  -8667],
                        [ -7848,  -8695],
                        [ -7781,  -8683],
                        [ -7671,  -8632],
                        [ -7521,  -8543],
                        [ -7332,  -8416],
                        [ -7109,  -8254],
                        [ -6853,  -8060],
                        [ -6600,  -7867],
                        [ -6350,  -7675],
                        [ -6121,  -7501],
                        [ -5916,  -7345],
                        [ -5711,  -7187],
                        [ -5511,  -7027],
                        [ -5262,  -6812],
                        [ -4968,  -6549],
                        [ -4625,  -6232],
                        [ -4234,  -5860],
                        [ -3804,  -5445],
                        [ -3339,  -4991],
                        [ -2847,  -4505],
                        [ -2331,  -3990],
                        [ -1803,  -3459],
                        [ -1263,  -2909],
                        [  -723,  -2354],
                        [  -182,  -1792],
                        [   350,  -1235],
                        [   873,   -683],
                        [  1378,   -145],
                        [  1865,    381],
                        [  2330,    887],
                        [  2774,   1376],
                        [  3192,   1840],
                        [  3584,   2280],
                        [  3950,   2696],
                        [  4288,   3086],
                        [  4604,   3452],
                        [  4894,   3794],
                        [  5161,   4111],
                        [  5406,   4407],
                        [  5632,   4682],
                        [  5842,   4940],
                        [  6037,   5182],
                        [  6221,   5410],
                        [  6396,   5627],
                        [  6563,   5835],
                        [  6728,   6037],
                        [  6890,   6235],
                        [  7054,   6433],
                        [  7222,   6629],
                        [  7395,   6831],
                        [  7577,   7037],
                        [  7768,   7251],
                        [  7966,   7469],
                        [  8175,   7698],
                        [  8403,   7942],
                        [  8589,   8146],
                        [  8642,   8217],
                        [  8527,   8119],
                        [  8242,   7850],
                        [  7773,   7391],
                        [  7089,   6712],
                        [  6236,   5862],
                        [  5363,   4988],
                        [  4550,   4175],
                        [  3798,   3420],
                        [  3111,   2732],
                        [  2503,   2122],
                        [  1977,   1598],
                        [  1537,   1164],
                        [  1185,    820],
                        [   922,    569],
                        [   746,    404],
                        [   653,    326],
                        [   641,    319],
                        [   704,    380],
                        [   836,    500],
                        [  1033,    671],
                        [  1286,    894],
                        [  1591,   1159],
                        [  1937,   1473],
                        [  2319,   1827],
                        [  2727,   2218],
                        [  3153,   2639],
                        [  3585,   3083],
                        [  4018,   3542],
                        [  4445,   4007],
                        [  4859,   4474],
                        [  5253,   4929],
                        [  5625,   5372],
                        [  5970,   5794],
                        [  6285,   6192],
                        [  6568,   6563],
                        [  6819,   6905],
                        [  7034,   7213],
                        [  7212,   7488],
                        [  7356,   7727],
                        [  7461,   7929],
                        [  7531,   8096],
                        [  7567,   8226],
                        [  7567,   8318],
                        [  7537,   8379],
                        [  7477,   8407],
                        [  7387,   8401],
                        [  7274,   8369],
                        [  7137,   8309],
                        [  6983,   8225],
                        [  6814,   8120],
                        [  6645,   7997],
                        [  6478,   7857],
                        [  6323,   7704],
                        [  6183,   7542],
                        [  6058,   7373],
                        [  5950,   7199],
                        [  5845,   7023],
                        [  5744,   6848],
                        [  5640,   6676],
                        [  5536,   6509],
                        [  5434,   6351],
                        [  5332,   6199],
                        [  5233,   6059],
                        [  5139,   5930],
                        [  5050,   5814],
                        [  4968,   5712],
                        [  4892,   5623],
                        [  4825,   5549],
                        [  4766,   5487],
                        [  4716,   5439],
                        [  4675,   5406],
                        [  4643,   5385],
                        [  4648,   5403],
                        [  4684,   5456],
                        [  4793,   5584],
                        [  4970,   5781],
                        [  5211,   6043],
                        [  5516,   6370],
                        [  5829,   6705],
                        [  6152,   7051],
                        [  6431,   7352],
                        [  6667,   7612],
                        [  6862,   7829],
                        [  7011,   8002],
                        [  7118,   8132],
                        [  7181,   8218],
                        [  7205,   8264],
                        [  7187,   8267],
                        [  7134,   8232],
                        [  7043,   8157],
                        [  6921,   8048],
                        [  6766,   7902],
                        [  6585,   7726],
                        [  6373,   7517],
                        [  6139,   7282],
                        [  5881,   7018],
                        [  5602,   6732],
                        [  5303,   6420],
                        [  4988,   6089],
                        [  4656,   5737],
                        [  4310,   5369],
                        [  3950,   4983],
                        [  3579,   4583],
                        [  3196,   4170],
                        [  2806,   3745],
                        [  2408,   3311],
                        [  2004,   2867],
                        [  1596,   2417],
                        [  1185,   1963],
                        [   771,   1504],
                        [   359,   1046],
                        [   -50,    589],
                        [  -458,    132],
                        [  -859,   -319],
                        [ -1251,   -761],
                        [ -1634,  -1194],
                        [ -2007,  -1617],
                        [ -2364,  -2026],
                        [ -2702,  -2414],
                        [ -3023,  -2786],
                        [ -3325,  -3143],
                        [ -3547,  -3422],
                        [ -3612,  -3547],
                        [ -3495,  -3492],
                        [ -3200,  -3257],
                        [ -2702,  -2817],
                        [ -1972,  -2135],
                        [ -1044,  -1250],
                        [   -52,   -295],
                        [   932,    658],
                        [  1907,   1608],
                        [  2863,   2544],
                        [  3782,   3447],
                        [  4654,   4306],
                        [  5471,   5115],
                        [  6226,   5865],
                        [  6912,   6548],
                        [  7525,   7161],
                        [  8058,   7707],
                        [  8514,   8183],
                        [  8889,   8595],
                        [  9182,   8944],
                        [  9393,   9229],
                        [  9523,   9453],
                        [  9575,   9604],
                        [  9549,   9689],
                        [  9453,   9695],
                        [  9288,   9627],
                        [  9061,   9485],
                        [  8776,   9271],
                        [  8442,   8991],
                        [  8062,   8647],
                        [  7642,   8249],
                        [  7187,   7800],
                        [  6700,   7309],
                        [  6186,   6782],
                        [  5649,   6224],
                        [  5091,   5637],
                        [  4518,   5028],
                        [  3930,   4399],
                        [  3335,   3756],
                        [  2735,   3102],
                        [  2131,   2442],
                        [  1529,   1777],
                        [   934,   1116],
                        [   345,    457],
                        [  -232,   -193],
                        [  -795,   -834],
                        [ -1340,  -1458],
                        [ -1866,  -2065],
                        [ -2370,  -2651],
                        [ -2850,  -3214],
                        [ -3310,  -3750],
                        [ -3749,  -4257],
                        [ -4173,  -4731],
                        [ -4582,  -5174],
                        [ -4976,  -5579],
                        [ -5354,  -5948],
                        [ -5705,  -6277],
                        [ -6030,  -6567],
                        [ -6307,  -6813],
                        [ -6541,  -7018],
                        [ -6723,  -7178],
                        [ -6855,  -7295],
                        [ -6935,  -7368],
                        [ -6962,  -7396],
                        [ -6940,  -7382],
                        [ -6867,  -7324],
                        [ -6748,  -7225],
                        [ -6581,  -7085],
                        [ -6369,  -6904],
                        [ -6112,  -6683],
                        [ -5819,  -6428],
                        [ -5488,  -6138],
                        [ -5136,  -5828],
                        [ -4762,  -5499],
                        [ -4424,  -5205],
                        [ -4120,  -4944],
                        [ -3872,  -4739],
                        [ -3682,  -4589],
                        [ -3534,  -4478],
                        [ -3429,  -4408],
                        [ -3292,  -4303],
                        [ -3129,  -4169],
                        [ -2924,  -3990],
                        [ -2678,  -3768],
                        [ -2396,  -3509],
                        [ -2081,  -3213],
                        [ -1737,  -2888],
                        [ -1367,  -2533],
                        [  -980,  -2156],
                        [  -574,  -1758],
                        [  -158,  -1347],
                        [   266,   -922],
                        [   693,   -492],
                        [  1121,    -57],
                        [  1545,    378],
                        [  1965,    811],
                        [  2374,   1237],
                        [  2775,   1656],
                        [  3161,   2065],
                        [  3537,   2463],
                        [  3898,   2849],
                        [  4245,   3223],
                        [  4578,   3585],
                        [  4899,   3934],
                        [  5208,   4270],
                        [  5506,   4596],
                        [  5796,   4911],
                        [  6076,   5216],
                        [  6349,   5514],
                        [  6616,   5804],
                        [  6881,   6090],
                        [  7141,   6370],
                        [  7399,   6647],
                        [  7658,   6923],
                        [  7916,   7197],
                        [  8174,   7469],
                        [  8433,   7742],
                        [  8694,   8015],
                        [  8955,   8289],
                        [  9210,   8557],
                        [  9463,   8829],
                        [  9712,   9100],
                        [  9898,   9318],
                        [  9969,   9427],
                        [  9917,   9419],
                        [  9739,   9288],
                        [  9415,   9008],
                        [  8901,   8537],
                        [  8223,   7897],
                        [  7487,   7196],
                        [  6750,   6490],
                        [  6010,   5780],
                        [  5276,   5074],
                        [  4565,   4390],
                        [  3885,   3737],
                        [  3241,   3119],
                        [  2640,   2545],
                        [  2087,   2019],
                        [  1584,   1541],
                        [  1135,   1115],
                        [   738,    728],
                        [   396,    385],
                        [   106,     76],
                        [  -135,   -199],
                        [  -326,   -439],
                        [  -472,   -649],
                        [  -578,   -820],
                        [  -645,   -954],
                        [  -683,  -1047],
                        [  -696,  -1103],
                        [  -690,  -1123],
                        [  -671,  -1112],
                        [  -644,  -1075],
                        [  -614,  -1016],
                        [  -585,   -945],
                        [  -560,   -865],
                        [  -540,   -786],
                        [  -531,   -710],
                        [  -531,   -640],
                        [  -542,   -579],
                        [  -564,   -526],
                        [  -599,   -484],
                        [  -646,   -454],
                        [  -705,   -436],
                        [  -776,   -430],
                        [  -856,   -436],
                        [  -946,   -452],
                        [ -1045,   -479],
                        [ -1148,   -514],
                        [ -1257,   -558],
                        [ -1368,   -608],
                        [ -1480,   -661],
                        [ -1589,   -719],
                        [ -1692,   -778],
                        [ -1778,   -835],
                        [ -1846,   -893],
                        [ -1886,   -946],
                        [ -1899,   -994],
                        [ -1884,  -1036],
                        [ -1840,  -1071],
                        [ -1779,  -1097],
                        [ -1702,  -1114],
                        [ -1620,  -1122],
                        [ -1531,  -1120],
                        [ -1438,  -1107],
                        [ -1342,  -1085],
                        [ -1246,  -1052],
                        [ -1146,  -1010],
                        [ -1049,   -959],
                        [  -952,   -900],
                        [  -858,   -835],
                        [  -768,   -765],
                        [  -684,   -692],
                        [  -606,   -617],
                        [  -532,   -538],
                        [  -466,   -457],
                        [  -368,   -340],
                        [  -242,   -188],
                        [   -50,     37],
                        [   210,    332],
                        [   531,    695],
                        [   917,   1125],
                        [  1307,   1562],
                        [  1703,   2007],
                        [  2038,   2393],
                        [  2314,   2724],
                        [  2529,   2992],
                        [  2680,   3200],
                        [  2768,   3345],
                        [  2791,   3425],
                        [  2751,   3443],
                        [  2649,   3396],
                        [  2490,   3291],
                        [  2273,   3124],
                        [  2006,   2902],
                        [  1688,   2626],
                        [  1326,   2302],
                        [   922,   1930],
                        [   484,   1519],
                        [    12,   1068],
                        [  -483,    586],
                        [ -1004,     74],
                        [ -1540,   -460],
                        [ -2090,  -1013],
                        [ -2648,  -1581],
                        [ -3211,  -2159],
                        [ -3774,  -2741],
                        [ -4336,  -3326],
                        [ -4891,  -3907],
                        [ -5437,  -4483],
                        [ -5970,  -5048],
                        [ -6485,  -5598],
                        [ -6983,  -6132],
                        [ -7458,  -6645],
                        [ -7906,  -7134],
                        [ -8329,  -7597],
                        [ -8723,  -8032],
                        [ -9085,  -8435],
                        [ -9414,  -8806],
                        [ -9706,  -9139],
                        [ -9964,  -9437],
                        [-10183,  -9696],
                        [-10358,  -9913],
                        [-10492, -10093],
                        [-10575, -10229],
                        [-10569, -10285],
                        [-10449, -10231],
                        [-10214, -10070],
                        [ -9873,  -9800],
                        [ -9395,  -9393],
                        [ -8747,  -8806],
                        [ -7937,  -8046],
                        [ -7044,  -7197],
                        [ -6114,  -6303],
                        [ -5153,  -5368],
                        [ -4175,  -4408],
                        [ -3199,  -3443],
                        [ -2240,  -2488],
                        [ -1308,  -1554],
                        [  -418,   -656],
                        [   423,    199],
                        [  1203,    999],
                        [  1915,   1742],
                        [  2555,   2425],
                        [  3114,   3045],
                        [  3591,   3603],
                        [  3983,   4093],
                        [  4286,   4517],
                        [  4504,   4864],
                        [  4634,   5137],
                        [  4682,   5322],
                        [  4647,   5420],
                        [  4537,   5428],
                        [  4357,   5351],
                        [  4114,   5186],
                        [  3811,   4939],
                        [  3456,   4619],
                        [  3053,   4231],
                        [  2610,   3790],
                        [  2132,   3299],
                        [  1627,   2771],
                        [  1098,   2212],
                        [   550,   1624],
                        [   -10,   1016],
                        [  -574,    396],
                        [ -1143,   -236],
                        [ -1708,   -869],
                        [ -2264,  -1500],
                        [ -2808,  -2123],
                        [ -3336,  -2735],
                        [ -3843,  -3328],
                        [ -4326,  -3901],
                        [ -4782,  -4449],
                        [ -5207,  -4968],
                        [ -5600,  -5454],
                        [ -5959,  -5907],
                        [ -6286,  -6320],
                        [ -6582,  -6694],
                        [ -6852,  -7027],
                        [ -7094,  -7316],
                        [ -7313,  -7561],
                        [ -7508,  -7762],
                        [ -7673,  -7916],
                        [ -7807,  -8024],
                        [ -7901,  -8088],
                        [ -7954,  -8108],
                        [ -7961,  -8084],
                        [ -7924,  -8017],
                        [ -7844,  -7910],
                        [ -7720,  -7763],
                        [ -7555,  -7580],
                        [ -7351,  -7362],
                        [ -7111,  -7113],
                        [ -6836,  -6834],
                        [ -6528,  -6526],
                        [ -6189,  -6192],
                        [ -5826,  -5838],
                        [ -5442,  -5467],
                        [ -5055,  -5097],
                        [ -4669,  -4730],
                        [ -4340,  -4424],
                        [ -4068,  -4178],
                        [ -3874,  -4011],
                        [ -3757,  -3922],
                        [ -3707,  -3902],
                        [ -3728,  -3954],
                        [ -3735,  -3992],
                        [ -3737,  -4026],
                        [ -3711,  -4032],
                        [ -3657,  -4012],
                        [ -3575,  -3965],
                        [ -3465,  -3890],
                        [ -3327,  -3789],
                        [ -3162,  -3661],
                        [ -2972,  -3508],
                        [ -2757,  -3330],
                        [ -2520,  -3129],
                        [ -2262,  -2906],
                        [ -1987,  -2663],
                        [ -1692,  -2401],
                        [ -1385,  -2125],
                        [ -1064,  -1833],
                        [  -733,  -1528],
                        [  -391,  -1211],
                        [   -45,   -886],
                        [   309,   -551],
                        [   666,   -208],
                        [  1029,    142],
                        [  1393,    498],
                        [  1763,    860],
                        [  2135,   1224],
                        [  2511,   1593],
                        [  2888,   1965],
                        [  3267,   2339],
                        [  3646,   2715],
                        [  4025,   3092],
                        [  4404,   3468],
                        [  4779,   3842],
                        [  5152,   4215],
                        [  5521,   4585],
                        [  5883,   4949],
                        [  6238,   5306],
                        [  6580,   5655],
                        [  6914,   5995],
                        [  7230,   6321],
                        [  7525,   6631],
                        [  7795,   6927],
                        [  8032,   7200],
                        [  8212,   7430],
                        [  8330,   7613],
                        [  8399,   7755],
                        [  8413,   7851],
                        [  8352,   7872],
                        [  8164,   7763],
                        [  7837,   7510],
                        [  7414,   7155],
                        [  6920,   6725],
                        [  6359,   6225],
                        [  5741,   5664],
                        [  5083,   5058],
                        [  4394,   4417],
                        [  3681,   3748],
                        [  2955,   3062],
                        [  2227,   2369],
                        [  1501,   1673],
                        [   785,    981],
                        [    85,    290],
                        [  -596,   -393],
                        [ -1250,  -1071],
                        [ -1879,  -1740],
                        [ -2476,  -2394],
                        [ -3040,  -3034],
                        [ -3572,  -3647],
                        [ -4070,  -4235],
                        [ -4535,  -4783],
                        [ -4966,  -5294],
                        [ -5367,  -5758],
                        [ -5741,  -6178],
                        [ -6087,  -6554],
                        [ -6407,  -6885],
                        [ -6703,  -7180],
                        [ -6977,  -7439],
                        [ -7230,  -7673],
                        [ -7464,  -7885],
                        [ -7677,  -8073],
                        [ -7874,  -8240],
                        [ -8051,  -8387],
                        [ -8213,  -8514],
                        [ -8356,  -8624],
                        [ -8482,  -8714],
                        [ -8590,  -8787],
                        [ -8680,  -8842],
                        [ -8752,  -8881],
                        [ -8808,  -8902],
                        [ -8843,  -8906],
                        [ -8863,  -8894],
                        [ -8862,  -8864],
                        [ -8842,  -8818],
                        [ -8803,  -8756],
                        [ -8742,  -8678],
                        [ -8655,  -8583],
                        [ -8543,  -8474],
                        [ -8400,  -8349],
                        [ -8229,  -8211],
                        [ -8028,  -8060],
                        [ -7799,  -7896],
                        [ -7550,  -7720],
                        [ -7282,  -7535],
                        [ -7007,  -7342],
                        [ -6725,  -7140],
                        [ -6442,  -6934],
                        [ -6158,  -6723],
                        [ -5879,  -6511],
                        [ -5605,  -6297],
                        [ -5342,  -6084],
                        [ -5090,  -5875],
                        [ -4851,  -5670],
                        [ -4631,  -5475],
                        [ -4432,  -5293],
                        [ -4250,  -5117],
                        [ -4088,  -4952],
                        [ -3944,  -4799],
                        [ -3780,  -4616],
                        [ -3600,  -4411],
                        [ -3373,  -4151],
                        [ -3100,  -3839],
                        [ -2774,  -3469],
                        [ -2397,  -3043],
                        [ -2018,  -2611],
                        [ -1637,  -2173],
                        [ -1313,  -1790],
                        [ -1043,  -1458],
                        [  -835,  -1186],
                        [  -685,   -972],
                        [  -600,   -821],
                        [  -579,   -735],
                        [  -619,   -709],
                        [  -722,   -747],
                        [  -883,   -844],
                        [ -1101,  -1001],
                        [ -1371,  -1212],
                        [ -1689,  -1475],
                        [ -2050,  -1783],
                        [ -2453,  -2138],
                        [ -2885,  -2526],
                        [ -3348,  -2950],
                        [ -3832,  -3400],
                        [ -4333,  -3875],
                        [ -4843,  -4366],
                        [ -5362,  -4871],
                        [ -5879,  -5383],
                        [ -6396,  -5899],
                        [ -6905,  -6411],
                        [ -7403,  -6917],
                        [ -7885,  -7409],
                        [ -8349,  -7888],
                        [ -8790,  -8345],
                        [ -9206,  -8779],
                        [ -9593,  -9186],
                        [ -9950,  -9563],
                        [-10272,  -9907],
                        [-10559, -10215],
                        [-10808, -10485],
                        [-11019, -10719],
                        [-11189, -10908],
                        [-11318, -11057],
                        [-11407, -11164],
                        [-11450, -11225],
                        [-11445, -11243],
                        [-11392, -11218],
                        [-11285, -11149],
                        [-11128, -11042],
                        [-10946, -10918],
                        [-10757, -10793],
                        [-10565, -10667],
                        [-10346, -10513],
                        [-10064, -10284],
                        [ -9674,  -9939],
                        [ -9193,  -9493],
                        [ -8639,  -8967],
                        [ -8022,  -8367],
                        [ -7355,  -7709],
                        [ -6656,  -7011],
                        [ -5935,  -6281],
                        [ -5204,  -5536],
                        [ -4479,  -4788],
                        [ -3768,  -4049],
                        [ -3083,  -3328],
                        [ -2433,  -2631],
                        [ -1825,  -1968],
                        [ -1267,  -1340],
                        [  -763,   -754],
                        [  -318,   -212],
                        [    65,    283],
                        [   384,    724],
                        [   638,   1110],
                        [   826,   1429],
                        [   951,   1684],
                        [  1013,   1863],
                        [  1018,   1972],
                        [   969,   2006],
                        [   869,   1970],
                        [   725,   1867],
                        [   540,   1704],
                        [   322,   1494],
                        [    74,   1241],
                        [  -194,    960],
                        [  -479,    653],
                        [  -775,    328],
                        [ -1076,    -11],
                        [ -1378,   -358],
                        [ -1676,   -708],
                        [ -1966,  -1055],
                        [ -2243,  -1395],
                        [ -2504,  -1722],
                        [ -2745,  -2033],
                        [ -2966,  -2325],
                        [ -3161,  -2594],
                        [ -3327,  -2835],
                        [ -3465,  -3048],
                        [ -3574,  -3230],
                        [ -3651,  -3379],
                        [ -3699,  -3494],
                        [ -3719,  -3574],
                        [ -3712,  -3619],
                        [ -3681,  -3628],
                        [ -3628,  -3602],
                        [ -3555,  -3542],
                        [ -3463,  -3448],
                        [ -3352,  -3322],
                        [ -3222,  -3165],
                        [ -3070,  -2979],
                        [ -2897,  -2767],
                        [ -2703,  -2530],
                        [ -2489,  -2272],
                        [ -2257,  -1996],
                        [ -2009,  -1702],
                        [ -1744,  -1394],
                        [ -1469,  -1077],
                        [ -1183,   -752],
                        [  -884,   -418],
                        [  -576,    -80],
                        [  -267,    254],
                        [    43,    586],
                        [   336,    894],
                        [   610,   1181],
                        [   822,   1398],
                        [   973,   1551],
                        [  1050,   1624],
                        [  1051,   1616],
                        [   979,   1531],
                        [   830,   1365],
                        [   678,   1191],
                        [   517,   1003],
                        [   366,    821],
                        [   229,    650],
                        [   111,    495],
                        [    15,    358],
                        [   -55,    243],
                        [   -99,    153],
                        [  -111,     90],
                        [   -92,     55],
                        [   -41,     51],
                        [    44,     77],
                        [   160,    134],
                        [   310,    223],
                        [   491,    340],
                        [   703,    489],
                        [   943,    666],
                        [  1211,    873],
                        [  1504,   1107],
                        [  1819,   1368],
                        [  2156,   1654],
                        [  2513,   1965],
                        [  2885,   2295],
                        [  3275,   2646],
                        [  3678,   3011],
                        [  4093,   3393],
                        [  4515,   3784],
                        [  4942,   4185],
                        [  5372,   4591],
                        [  5804,   5000],
                        [  6229,   5408],
                        [  6648,   5813],
                        [  7057,   6211],
                        [  7452,   6598],
                        [  7829,   6970],
                        [  8186,   7326],
                        [  8517,   7661],
                        [  8822,   7971],
                        [  9091,   8253],
                        [  9322,   8504],
                        [  9501,   8720],
                        [  9633,   8900],
                        [  9741,   9073],
                        [  9864,   9276],
                        [ 10021,   9523],
                        [ 10207,   9809],
                        [ 10409,  10110],
                        [ 10571,  10369],
                        [ 10628,  10515],
                        [ 10556,  10529],
                        [ 10364,  10417],
                        [ 10059,  10186],
                        [  9649,   9844],
                        [  9148,   9402],
                        [  8563,   8870],
                        [  7905,   8257],
                        [  7185,   7575],
                        [  6415,   6835],
                        [  5605,   6046],
                        [  4762,   5216],
                        [  3900,   4354],
                        [  3025,   3468],
                        [  2146,   2563],
                        [  1269,   1649],
                        [   401,    729],
                        [  -450,   -189],
                        [ -1276,  -1094],
                        [ -2077,  -1983],
                        [ -2843,  -2841],
                        [ -3572,  -3663],
                        [ -4262,  -4436],
                        [ -4909,  -5160],
                        [ -5512,  -5828],
                        [ -6069,  -6437],
                        [ -6580,  -6991],
                        [ -7044,  -7487],
                        [ -7463,  -7936],
                        [ -7837,  -8339],
                        [ -8166,  -8693],
                        [ -8452,  -9003],
                        [ -8695,  -9265],
                        [ -8897,  -9484],
                        [ -9057,  -9658],
                        [ -9176,  -9791],
                        [ -9258,  -9882],
                        [ -9300,  -9933],
                        [ -9306,  -9946],
                        [ -9276,  -9922],
                        [ -9212,  -9865],
                        [ -9116,  -9774],
                        [ -8990,  -9653],
                        [ -8835,  -9502],
                        [ -8654,  -9326],
                        [ -8447,  -9125],
                        [ -8217,  -8903],
                        [ -7967,  -8661],
                        [ -7696,  -8403],
                        [ -7408,  -8130],
                        [ -7102,  -7846],
                        [ -6780,  -7553],
                        [ -6445,  -7253],
                        [ -6098,  -6949],
                        [ -5747,  -6645],
                        [ -5393,  -6340],
                        [ -5042,  -6039],
                        [ -4699,  -5745],
                        [ -4364,  -5458],
                        [ -4042,  -5181],
                        [ -3738,  -4916],
                        [ -3450,  -4664],
                        [ -3184,  -4428],
                        [ -2945,  -4213],
                        [ -2730,  -4016],
                        [ -2542,  -3839],
                        [ -2375,  -3677],
                        [ -2233,  -3532],
                        [ -2087,  -3378],
                        [ -1938,  -3213],
                        [ -1767,  -3022],
                        [ -1580,  -2807],
                        [ -1357,  -2552],
                        [ -1100,  -2259],
                        [  -838,  -1955],
                        [  -566,  -1638],
                        [  -329,  -1354],
                        [  -124,  -1097],
                        [    46,   -877],
                        [   178,   -691],
                        [   267,   -550],
                        [   316,   -448],
                        [   322,   -388],
                        [   288,   -370],
                        [   212,   -392],
                        [    98,   -453],
                        [   -52,   -549],
                        [  -236,   -681],
                        [  -449,   -840],
                        [  -688,  -1028],
                        [  -949,  -1238],
                        [ -1227,  -1467],
                        [ -1517,  -1711],
                        [ -1815,  -1967],
                        [ -2115,  -2230],
                        [ -2416,  -2498],
                        [ -2711,  -2766],
                        [ -2998,  -3030],
                        [ -3274,  -3283],
                        [ -3534,  -3527],
                        [ -3777,  -3754],
                        [ -4000,  -3963],
                        [ -4200,  -4149],
                        [ -4375,  -4314],
                        [ -4522,  -4450],
                        [ -4640,  -4558],
                        [ -4727,  -4636],
                        [ -4785,  -4683],
                        [ -4810,  -4698],
                        [ -4802,  -4679],
                        [ -4762,  -4627],
                        [ -4689,  -4541],
                        [ -4583,  -4422],
                        [ -4444,  -4271],
                        [ -4266,  -4088],
                        [ -4048,  -3871],
                        [ -3799,  -3634],
                        [ -3575,  -3434],
                        [ -3435,  -3326],
                        [ -3397,  -3327],
                        [ -3465,  -3437],
                        [ -3629,  -3644],
                        [ -3843,  -3892],
                        [ -4009,  -4085],
                        [ -4083,  -4180],
                        [ -4069,  -4182],
                        [ -3976,  -4097],
                        [ -3813,  -3935],
                        [ -3587,  -3703],
                        [ -3308,  -3410],
                        [ -2983,  -3066],
                        [ -2624,  -2680],
                        [ -2239,  -2263],
                        [ -1839,  -1824],
                        [ -1428,  -1370],
                        [ -1016,   -909],
                        [  -609,   -448],
                        [  -210,      7],
                        [   173,    453],
                        [   538,    882],
                        [   882,   1298],
                        [  1199,   1694],
                        [  1488,   2065],
                        [  1745,   2408],
                        [  1973,   2715],
                        [  2170,   2988],
                        [  2336,   3218],
                        [  2475,   3407],
                        [  2588,   3557],
                        [  2677,   3671],
                        [  2747,   3755],
                        [  2800,   3814],
                        [  2844,   3858],
                        [  2880,   3890],
                        [  2914,   3915],
                        [  2948,   3932],
                        [  2984,   3948],
                        [  3025,   3965],
                        [  3075,   3986],
                        [  3135,   4015],
                        [  3205,   4053],
                        [  3291,   4103],
                        [  3388,   4167],
                        [  3502,   4245],
                        [  3629,   4340],
                        [  3772,   4452],
                        [  3929,   4581],
                        [  4102,   4729],
                        [  4289,   4892],
                        [  4491,   5072],
                        [  4708,   5269],
                        [  4937,   5480],
                        [  5176,   5703],
                        [  5423,   5938],
                        [  5670,   6181],
                        [  5917,   6433],
                        [  6156,   6690],
                        [  6388,   6951],
                        [  6614,   7212],
                        [  6830,   7472],
                        [  7037,   7728],
                        [  7233,   7979],
                        [  7420,   8221],
                        [  7594,   8454],
                        [  7757,   8675],
                        [  7906,   8882],
                        [  8048,   9078],
                        [  8175,   9258],
                        [  8288,   9418],
                        [  8387,   9560],
                        [  8461,   9671],
                        [  8510,   9752],
                        [  8518,   9786],
                        [  8486,   9772],
                        [  8407,   9705],
                        [  8281,   9583],
                        [  8096,   9395],
                        [  7854,   9143],
                        [  7595,   8868],
                        [  7317,   8566],
                        [  7039,   8259],
                        [  6761,   7946],
                        [  6496,   7642],
                        [  6245,   7347],
                        [  6017,   7074],
                        [  5813,   6819],
                        [  5642,   6592],
                        [  5504,   6394],
                        [  5402,   6227],
                        [  5339,   6095],
                        [  5315,   6000],
                        [  5332,   5939],
                        [  5390,   5919],
                        [  5488,   5935],
                        [  5621,   5987],
                        [  5793,   6076],
                        [  5998,   6200],
                        [  6234,   6359],
                        [  6497,   6549],
                        [  6786,   6769],
                        [  7095,   7014],
                        [  7423,   7282],
                        [  7763,   7567],
                        [  8115,   7868],
                        [  8472,   8179],
                        [  8831,   8498],
                        [  9185,   8816],
                        [  9533,   9134],
                        [  9867,   9443],
                        [ 10186,   9741],
                        [ 10481,  10021],
                        [ 10753,  10281],
                        [ 10992,  10517],
                        [ 11200,  10723],
                        [ 11369,  10896],
                        [ 11498,  11033],
                        [ 11577,  11130],
                        [ 11607,  11184],
                        [ 11572,  11187],
                        [ 11493,  11161],
                        [ 11447,  11178],
                        [ 11492,  11302],
                        [ 11643,  11539],
                        [ 11902,  11893],
                        [ 12270,  12352],
                        [ 12689,  12861],
                        [ 13037,  13296],
                        [ 13249,  13588],
                        [ 13329,  13743],
                        [ 13280,  13762],
                        [ 13109,  13649],
                        [ 12821,  13413],
                        [ 12423,  13057],
                        [ 11926,  12592],
                        [ 11340,  12029],
                        [ 10675,  11376],
                        [  9943,  10646],
                        [  9150,   9848],
                        [  8312,   8997],
                        [  7438,   8102],
                        [  6537,   7177],
                        [  5615,   6229],
                        [  4685,   5265],
                        [  3757,   4296],
                        [  2840,   3326],
                        [  1941,   2361],
                        [  1073,   1418],
                        [   241,    501],
                        [  -552,   -378],
                        [ -1298,  -1211],
                        [ -1991,  -1990],
                        [ -2632,  -2712],
                        [ -3216,  -3373],
                        [ -3742,  -3970],
                        [ -4211,  -4510],
                        [ -4624,  -4993],
                        [ -4981,  -5418],
                        [ -5284,  -5785],
                        [ -5534,  -6096],
                        [ -5732,  -6352],
                        [ -5879,  -6554],
                        [ -5978,  -6703],
                        [ -6030,  -6804],
                        [ -6039,  -6856],
                        [ -6005,  -6864],
                        [ -5933,  -6831],
                        [ -5824,  -6759],
                        [ -5683,  -6652],
                        [ -5511,  -6513],
                        [ -5313,  -6346],
                        [ -5094,  -6155],
                        [ -4855,  -5940],
                        [ -4607,  -5709],
                        [ -4351,  -5464],
                        [ -4093,  -5207],
                        [ -3837,  -4943],
                        [ -3582,  -4675],
                        [ -3328,  -4405],
                        [ -3071,  -4136],
                        [ -2815,  -3872],
                        [ -2558,  -3615],
                        [ -2303,  -3366],
                        [ -2053,  -3129],
                        [ -1812,  -2904],
                        [ -1582,  -2693],
                        [ -1365,  -2498],
                        [ -1163,  -2320],
                        [  -976,  -2158],
                        [  -810,  -2016],
                        [  -665,  -1895],
                        [  -539,  -1791],
                        [  -433,  -1705],
                        [  -345,  -1633],
                        [  -275,  -1578],
                        [  -215,  -1530],
                        [  -165,  -1488],
                        [  -124,  -1451],
                        [   -89,  -1418],
                        [   -41,  -1366],
                        [    24,  -1296],
                        [   109,  -1201],
                        [   216,  -1081],
                        [   324,   -958],
                        [   439,   -826],
                        [   549,   -696],
                        [   659,   -567],
                        [   761,   -444],
                        [   856,   -329],
                        [   940,   -224],
                        [  1015,   -128],
                        [  1074,    -43],
                        [  1124,     33],
                        [  1159,     99],
                        [  1184,    158],
                        [  1197,    207],
                        [  1200,    251],
                        [  1194,    288],
                        [  1182,    322],
                        [  1165,    353],
                        [  1144,    383],
                        [  1122,    411],
                        [  1103,    442],
                        [  1086,    475],
                        [  1075,    513],
                        [  1071,    557],
                        [  1073,    609],
                        [  1087,    671],
                        [  1111,    743],
                        [  1146,    827],
                        [  1194,    922],
                        [  1254,   1031],
                        [  1329,   1154],
                        [  1417,   1290],
                        [  1519,   1440],
                        [  1636,   1605],
                        [  1765,   1782],
                        [  1909,   1973],
                        [  2065,   2176],
                        [  2236,   2391],
                        [  2418,   2616],
                        [  2615,   2849],
                        [  2837,   3101],
                        [  3047,   3329],
                        [  3147,   3439],
                        [  3081,   3374],
                        [  2835,   3118],
                        [  2398,   2670],
                        [  1766,   2023],
                        [   997,   1241],
                        [   230,    462],
                        [  -453,   -230],
                        [ -1053,   -839],
                        [ -1575,  -1364],
                        [ -2015,  -1806],
                        [ -2373,  -2161],
                        [ -2652,  -2435],
                        [ -2857,  -2630],
                        [ -2992,  -2750],
                        [ -3062,  -2802],
                        [ -3072,  -2789],
                        [ -3027,  -2720],
                        [ -2932,  -2603],
                        [ -2791,  -2446],
                        [ -2607,  -2254],
                        [ -2386,  -2031],
                        [ -2132,  -1783],
                        [ -1852,  -1507],
                        [ -1549,  -1208],
                        [ -1233,   -884],
                        [  -904,   -540],
                        [  -570,   -186],
                        [  -232,    180],
                        [   107,    547],
                        [   446,    916],
                        [   782,   1280],
                        [  1114,   1638],
                        [  1445,   1993],
                        [  1772,   2342],
                        [  2099,   2691],
                        [  2425,   3041],
                        [  2752,   3389],
                        [  3082,   3738],
                        [  3410,   4084],
                        [  3741,   4431],
                        [  4071,   4780],
                        [  4401,   5128],
                        [  4731,   5475],
                        [  5059,   5822],
                        [  5384,   6168],
                        [  5706,   6513],
                        [  6023,   6855],
                        [  6335,   7196],
                        [  6641,   7531],
                        [  6939,   7862],
                        [  7234,   8187],
                        [  7523,   8504],
                        [  7811,   8811],
                        [  8100,   9109],
                        [  8384,   9393],
                        [  8665,   9666],
                        [  8929,   9922],
                        [  9177,  10163],
                        [  9398,  10385],
                        [  9591,  10588],
                        [  9752,  10770],
                        [  9885,  10931],
                        [  9987,  11070],
                        [ 10059,  11185],
                        [ 10103,  11276],
                        [ 10117,  11342],
                        [ 10106,  11383],
                        [ 10069,  11400],
                        [ 10011,  11395],
                        [  9928,  11364],
                        [  9825,  11310],
                        [  9701,  11232],
                        [  9562,  11134],
                        [  9407,  11017],
                        [  9251,  10891],
                        [  9095,  10758],
                        [  8934,  10615],
                        [  8770,  10462],
                        [  8574,  10269],
                        [  8348,  10041],
                        [  8097,   9779],
                        [  7821,   9486],
                        [  7531,   9175],
                        [  7230,   8847],
                        [  6931,   8517],
                        [  6633,   8186],
                        [  6347,   7864],
                        [  6073,   7552],
                        [  5822,   7258],
                        [  5591,   6982],
                        [  5389,   6729],
                        [  5215,   6502],
                        [  5072,   6302],
                        [  4961,   6129],
                        [  4883,   5987],
                        [  4836,   5874],
                        [  4820,   5789],
                        [  4834,   5733],
                        [  4875,   5705],
                        [  4941,   5701],
                        [  5025,   5719],
                        [  5129,   5758],
                        [  5242,   5813],
                        [  5367,   5881],
                        [  5493,   5957],
                        [  5622,   6039],
                        [  5745,   6121],
                        [  5861,   6199],
                        [  5962,   6270],
                        [  6048,   6329],
                        [  6112,   6372],
                        [  6152,   6396],
                        [  6162,   6394],
                        [  6141,   6368],
                        [  6084,   6307],
                        [  5991,   6216],
                        [  5857,   6087],
                        [  5679,   5919],
                        [  5456,   5711],
                        [  5187,   5464],
                        [  4860,   5166],
                        [  4525,   4866],
                        [  4279,   4665],
                        [  4180,   4616],
                        [  4239,   4730],
                        [  4462,   5015],
                        [  4871,   5482],
                        [  5404,   6072],
                        [  5911,   6633],
                        [  6308,   7080],
                        [  6602,   7418],
                        [  6791,   7646],
                        [  6874,   7759],
                        [  6852,   7760],
                        [  6729,   7651],
                        [  6511,   7438],
                        [  6203,   7126],
                        [  5813,   6722],
                        [  5350,   6237],
                        [  4821,   5677],
                        [  4235,   5064],
                        [  3601,   4403],
                        [  2924,   3708],
                        [  2214,   2988],
                        [  1482,   2251],
                        [   738,   1503],
                        [    -9,    743],
                        [  -749,    -22],
                        [ -1471,   -784],
                        [ -2169,  -1536],
                        [ -2835,  -2265],
                        [ -3465,  -2970],
                        [ -4051,  -3638],
                        [ -4592,  -4269],
                        [ -5085,  -4851],
                        [ -5525,  -5384],
                        [ -5917,  -5870],
                        [ -6256,  -6304],
                        [ -6548,  -6688],
                        [ -6793,  -7024],
                        [ -6992,  -7310],
                        [ -7147,  -7549],
                        [ -7260,  -7742],
                        [ -7332,  -7892],
                        [ -7367,  -8000],
                        [ -7368,  -8069],
                        [ -7335,  -8102],
                        [ -7273,  -8103],
                        [ -7186,  -8075],
                        [ -7075,  -8021],
                        [ -6945,  -7946],
                        [ -6799,  -7851],
                        [ -6642,  -7740],
                        [ -6479,  -7618],
                        [ -6320,  -7486],
                        [ -6169,  -7349],
                        [ -6033,  -7209],
                        [ -5916,  -7068],
                        [ -5813,  -6929],
                        [ -5727,  -6795],
                        [ -5647,  -6667],
                        [ -5574,  -6546],
                        [ -5500,  -6434],
                        [ -5428,  -6333],
                        [ -5357,  -6242],
                        [ -5289,  -6164],
                        [ -5224,  -6095],
                        [ -5164,  -6040],
                        [ -5108,  -5995],
                        [ -5056,  -5961],
                        [ -5011,  -5937],
                        [ -4969,  -5922],
                        [ -4933,  -5915],
                        [ -4899,  -5914],
                        [ -4871,  -5918],
                        [ -4846,  -5929],
                        [ -4843,  -5962],
                        [ -4863,  -6017],
                        [ -4912,  -6102],
                        [ -4990,  -6212],
                        [ -5072,  -6325],
                        [ -5155,  -6437],
                        [ -5201,  -6509],
                        [ -5208,  -6540],
                        [ -5179,  -6532],
                        [ -5108,  -6480],
                        [ -5006,  -6394],
                        [ -4869,  -6273],
                        [ -4707,  -6126],
                        [ -4518,  -5951],
                        [ -4310,  -5755],
                        [ -4080,  -5536],
                        [ -3839,  -5301],
                        [ -3584,  -5046],
                        [ -3321,  -4778],
                        [ -3050,  -4496],
                        [ -2777,  -4206],
                        [ -2499,  -3907],
                        [ -2223,  -3602],
                        [ -1948,  -3291],
                        [ -1677,  -2977],
                        [ -1411,  -2660],
                        [ -1148,  -2342],
                        [  -891,  -2025],
                        [  -637,  -1708],
                        [  -389,  -1393],
                        [  -146,  -1081],
                        [    91,   -773],
                        [   323,   -469],
                        [   549,   -169],
                        [   769,    126],
                        [   982,    414],
                        [  1189,    695],
                        [  1386,    968],
                        [  1577,   1232],
                        [  1761,   1489],
                        [  1937,   1737],
                        [  2104,   1974],
                        [  2264,   2201],
                        [  2414,   2417],
                        [  2557,   2623],
                        [  2689,   2814],
                        [  2814,   2992],
                        [  2936,   3165],
                        [  3001,   3274],
                        [  2907,   3218],
                        [  2613,   2953],
                        [  2113,   2473],
                        [  1393,   1767],
                        [   431,    813],
                        [  -712,   -325],
                        [ -1877,  -1489],
                        [ -2980,  -2594],
                        [ -4022,  -3639],
                        [ -4994,  -4615],
                        [ -5886,  -5513],
                        [ -6691,  -6324],
                        [ -7407,  -7044],
                        [ -8029,  -7668],
                        [ -8556,  -8198],
                        [ -8990,  -8631],
                        [ -9331,  -8969],
                        [ -9578,  -9219],
                        [ -9736,  -9384],
                        [ -9805,  -9475],
                        [ -9787,  -9497],
                        [ -9689,  -9455],
                        [ -9514,  -9354],
                        [ -9270,  -9185],
                        [ -8962,  -8956],
                        [ -8601,  -8661],
                        [ -8193,  -8305],
                        [ -7746,  -7896],
                        [ -7263,  -7437],
                        [ -6753,  -6936],
                        [ -6221,  -6397],
                        [ -5670,  -5831],
                        [ -5108,  -5240],
                        [ -4536,  -4635],
                        [ -3960,  -4019],
                        [ -3382,  -3396],
                        [ -2802,  -2767],
                        [ -2223,  -2137],
                        [ -1649,  -1509],
                        [ -1082,   -886],
                        [  -525,   -271],
                        [    19,    332],
                        [   548,    922],
                        [  1060,   1496],
                        [  1550,   2052],
                        [  2020,   2586],
                        [  2464,   3100],
                        [  2884,   3588],
                        [  3275,   4051],
                        [  3639,   4486],
                        [  3974,   4892],
                        [  4285,   5267],
                        [  4572,   5613],
                        [  4844,   5925],
                        [  5101,   6204],
                        [  5343,   6450],
                        [  5571,   6663],
                        [  5773,   6840],
                        [  5952,   6983],
                        [  6090,   7092],
                        [  6190,   7168],
                        [  6248,   7210],
                        [  6266,   7220],
                        [  6245,   7198],
                        [  6186,   7145],
                        [  6095,   7064],
                        [  5969,   6955],
                        [  5813,   6819],
                        [  5630,   6660],
                        [  5423,   6478],
                        [  5194,   6275],
                        [  4947,   6055],
                        [  4682,   5818],
                        [  4426,   5585],
                        [  4176,   5359],
                        [  3970,   5173],
                        [  3807,   5027],
                        [  3685,   4919],
                        [  3605,   4849],
                        [  3525,   4774],
                        [  3444,   4696],
                        [  3335,   4583],
                        [  3196,   4437],
                        [  3035,   4266],
                        [  2853,   4072],
                        [  2658,   3864],
                        [  2450,   3642],
                        [  2236,   3416],
                        [  2017,   3184],
                        [  1803,   2954],
                        [  1588,   2724],
                        [  1383,   2499],
                        [  1184,   2279],
                        [   996,   2069],
                        [   819,   1866],
                        [   653,   1673],
                        [   500,   1490],
                        [   359,   1317],
                        [   228,   1151],
                        [   109,    994],
                        [    -4,    840],
                        [  -113,    690],
                        [  -220,    541],
                        [  -332,    391],
                        [  -449,    236],
                        [  -574,     75],
                        [  -711,    -96],
                        [  -863,   -279],
                        [ -1030,   -475],
                        [ -1219,   -689],
                        [ -1429,   -922],
                        [ -1663,  -1175],
                        [ -1923,  -1450],
                        [ -2210,  -1752],
                        [ -2524,  -2077],
                        [ -2869,  -2429],
                        [ -3241,  -2807],
                        [ -3644,  -3214],
                        [ -4075,  -3647],
                        [ -4528,  -4103],
                        [ -5010,  -4587],
                        [ -5518,  -5098],
                        [ -5989,  -5573],
                        [ -6333,  -5919],
                        [ -6513,  -6099],
                        [ -6526,  -6110],
                        [ -6352,  -5929],
                        [ -5954,  -5524],
                        [ -5389,  -4951],
                        [ -4800,  -4356],
                        [ -4264,  -3813],
                        [ -3772,  -3318],
                        [ -3332,  -2878],
                        [ -2953,  -2501],
                        [ -2638,  -2195],
                        [ -2389,  -1958],
                        [ -2206,  -1793],
                        [ -2089,  -1701],
                        [ -2035,  -1676],
                        [ -2043,  -1717],
                        [ -2106,  -1818],
                        [ -2224,  -1961],
                        [ -2392,  -2144],
                        [ -2607,  -2355],
                        [ -2861,  -2589],
                        [ -3148,  -2841],
                        [ -3462,  -3106],
                        [ -3794,  -3395],
                        [ -4135,  -3702],
                        [ -4478,  -4025],
                        [ -4816,  -4359],
                        [ -5145,  -4700],
                        [ -5461,  -5046],
                        [ -5757,  -5388],
                        [ -6030,  -5723],
                        [ -6277,  -6043],
                        [ -6498,  -6345],
                        [ -6693,  -6624],
                        [ -6858,  -6877],
                        [ -6999,  -7107],
                        [ -7113,  -7311],
                        [ -7206,  -7491],
                        [ -7274,  -7646],
                        [ -7323,  -7779],
                        [ -7352,  -7890],
                        [ -7362,  -7980],
                        [ -7357,  -8052],
                        [ -7337,  -8106],
                        [ -7307,  -8148],
                        [ -7265,  -8175],
                        [ -7215,  -8193],
                        [ -7160,  -8203],
                        [ -7100,  -8205],
                        [ -7042,  -8205],
                        [ -6986,  -8200],
                        [ -6945,  -8196],
                        [ -6918,  -8191],
                        [ -6917,  -8188],
                        [ -6940,  -8187],
                        [ -6984,  -8188],
                        [ -7052,  -8195],
                        [ -7124,  -8204],
                        [ -7204,  -8217],
                        [ -7278,  -8234],
                        [ -7345,  -8253],
                        [ -7404,  -8275],
                        [ -7456,  -8298],
                        [ -7496,  -8321],
                        [ -7526,  -8343],
                        [ -7544,  -8361],
                        [ -7550,  -8378],
                        [ -7542,  -8387],
                        [ -7517,  -8388],
                        [ -7478,  -8382],
                        [ -7423,  -8365],
                        [ -7359,  -8343],
                        [ -7285,  -8316],
                        [ -7243,  -8324],
                        [ -7230,  -8363],
                        [ -7264,  -8451],
                        [ -7341,  -8582],
                        [ -7436,  -8732],
                        [ -7551,  -8899],
                        [ -7616,  -9016],
                        [ -7634,  -9083],
                        [ -7593,  -9087],
                        [ -7490,  -9027],
                        [ -7334,  -8912],
                        [ -7122,  -8738],
                        [ -6862,  -8516],
                        [ -6554,  -8244],
                        [ -6208,  -7931],
                        [ -5823,  -7576],
                        [ -5410,  -7187],
                        [ -4967,  -6762],
                        [ -4505,  -6313],
                        [ -4024,  -5838],
                        [ -3533,  -5345],
                        [ -3032,  -4838],
                        [ -2532,  -4323],
                        [ -2032,  -3798],
                        [ -1541,  -3274],
                        [ -1056,  -2747],
                        [  -585,  -2225],
                        [  -128,  -1708],
                        [   315,  -1200],
                        [   742,   -704],
                        [  1151,   -221],
                        [  1540,    245],
                        [  1909,    694],
                        [  2257,   1123],
                        [  2582,   1530],
                        [  2884,   1915],
                        [  3163,   2276],
                        [  3417,   2611],
                        [  3646,   2919],
                        [  3851,   3202],
                        [  4032,   3458],
                        [  4187,   3685],
                        [  4319,   3886],
                        [  4429,   4060],
                        [  4513,   4207],
                        [  4569,   4323],
                        [  4602,   4417],
                        [  4611,   4486],
                        [  4536,   4470],
                        [  4305,   4295],
                        [  3904,   3944],
                        [  3332,   3413],
                        [  2570,   2682],
                        [  1582,   1717],
                        [   416,    566],
                        [  -790,   -632],
                        [ -1968,  -1809],
                        [ -3119,  -2965],
                        [ -4230,  -4084],
                        [ -5282,  -5150],
                        [ -6266,  -6151],
                        [ -7174,  -7077],
                        [ -7997,  -7919],
                        [ -8730,  -8673],
                        [ -9367,  -9332],
                        [ -9907,  -9892],
                        [-10347, -10363],
                        [-10688, -10740],
                        [-10925, -11036],
                        [-11062, -11252],
                        [-11104, -11391],
                        [-11052, -11460],
                        [-10914, -11447],
                        [-10694, -11360],
                        [-10405, -11190],
                        [-10052, -10943],
                        [ -9644, -10620],
                        [ -9186, -10228],
                        [ -8687,  -9770],
                        [ -8153,  -9254],
                        [ -7594,  -8691],
                        [ -7012,  -8084],
                        [ -6417,  -7451],
                        [ -5813,  -6797],
                        [ -5207,  -6130],
                        [ -4600,  -5456],
                        [ -3998,  -4778],
                        [ -3402,  -4104],
                        [ -2819,  -3438],
                        [ -2251,  -2784],
                        [ -1704,  -2147],
                        [ -1180,  -1530],
                        [  -679,   -936],
                        [  -207,   -369],
                        [   235,    169],
                        [   646,    677],
                        [  1023,   1150],
                        [  1366,   1588],
                        [  1674,   1989],
                        [  1947,   2355],
                        [  2191,   2681],
                        [  2406,   2969],
                        [  2606,   3220],
                        [  2789,   3433],
                        [  2958,   3608],
                        [  3115,   3746],
                        [  3253,   3848],
                        [  3375,   3915],
                        [  3461,   3950],
                        [  3517,   3954],
                        [  3538,   3927],
                        [  3525,   3872],
                        [  3482,   3792],
                        [  3408,   3689],
                        [  3307,   3563],
                        [  3183,   3419],
                        [  3037,   3259],
                        [  2871,   3082],
                        [  2686,   2893],
                        [  2490,   2694],
                        [  2283,   2490],
                        [  2069,   2280],
                        [  1884,   2104],
                        [  1730,   1960],
                        [  1648,   1891],
                        [  1640,   1896],
                        [  1703,   1976],
                        [  1840,   2130],
                        [  1996,   2301],
                        [  2170,   2494],
                        [  2309,   2648],
                        [  2413,   2768],
                        [  2485,   2858],
                        [  2524,   2914],
                        [  2532,   2941],
                        [  2506,   2936],
                        [  2452,   2907],
                        [  2369,   2851],
                        [  2261,   2771],
                        [  2128,   2666],
                        [  1973,   2539],
                        [  1795,   2390],
                        [  1598,   2221],
                        [  1381,   2032],
                        [  1151,   1827],
                        [   901,   1603],
                        [   639,   1363],
                        [   363,   1105],
                        [    74,    828],
                        [  -229,    533],
                        [  -548,    219],
                        [  -883,   -115],
                        [ -1236,   -470],
                        [ -1608,   -844],
                        [ -1999,  -1237],
                        [ -2409,  -1653],
                        [ -2838,  -2087],
                        [ -3286,  -2542],
                        [ -3752,  -3014],
                        [ -4236,  -3506],
                        [ -4737,  -4015],
                        [ -5253,  -4539],
                        [ -5783,  -5077],
                        [ -6325,  -5629],
                        [ -6878,  -6192],
                        [ -7437,  -6762],
                        [ -8001,  -7338],
                        [ -8565,  -7916],
                        [ -9118,  -8492],
                        [ -9664,  -9067],
                        [-10194,  -9635],
                        [-10649, -10138],
                        [-10980, -10518],
                        [-11174, -10766],
                        [-11234, -10876],
                        [-11126, -10815],
                        [-10809, -10541],
                        [-10312, -10084],
                        [ -9743,  -9553],
                        [ -9151,  -8996],
                        [ -8535,  -8413],
                        [ -7906,  -7815],
                        [ -7277,  -7217],
                        [ -6658,  -6628],
                        [ -6053,  -6055],
                        [ -5471,  -5504],
                        [ -4918,  -4981],
                        [ -4398,  -4493],
                        [ -3915,  -4038],
                        [ -3468,  -3617],
                        [ -3063,  -3222],
                        [ -2702,  -2853],
                        [ -2383,  -2504],
                        [ -2107,  -2176],
                        [ -1870,  -1867],
                        [ -1672,  -1578],
                        [ -1508,  -1322],
                        [ -1373,  -1096],
                        [ -1263,   -908],
                        [ -1175,   -753],
                        [ -1106,   -636],
                        [ -1053,   -556],
                        [ -1012,   -509],
                        [  -982,   -494],
                        [  -960,   -502],
                        [  -943,   -531],
                        [  -931,   -571],
                        [  -923,   -622],
                        [  -918,   -679],
                        [  -917,   -743],
                        [  -921,   -815],
                        [  -930,   -892],
                        [  -941,   -973],
                        [  -958,  -1059],
                        [  -979,  -1149],
                        [ -1004,  -1242],
                        [ -1035,  -1341],
                        [ -1071,  -1442],
                        [ -1112,  -1547],
                        [ -1156,  -1656],
                        [ -1206,  -1768],
                        [ -1259,  -1883],
                        [ -1319,  -2000],
                        [ -1384,  -2120],
                        [ -1464,  -2242],
                        [ -1558,  -2363],
                        [ -1672,  -2484],
                        [ -1806,  -2604],
                        [ -1957,  -2722],
                        [ -2125,  -2836],
                        [ -2294,  -2945],
                        [ -2464,  -3049],
                        [ -2618,  -3144],
                        [ -2757,  -3229],
                        [ -2875,  -3304],
                        [ -2975,  -3366],
                        [ -3052,  -3414],
                        [ -3102,  -3446],
                        [ -3128,  -3461],
                        [ -3127,  -3458],
                        [ -3096,  -3433],
                        [ -3032,  -3384],
                        [ -2941,  -3313],
                        [ -2821,  -3222],
                        [ -2685,  -3119],
                        [ -2532,  -3005],
                        [ -2418,  -2936],
                        [ -2339,  -2906],
                        [ -2315,  -2933],
                        [ -2342,  -3014],
                        [ -2402,  -3130],
                        [ -2498,  -3282],
                        [ -2547,  -3385],
                        [ -2555,  -3445],
                        [ -2502,  -3443],
                        [ -2388,  -3378],
                        [ -2218,  -3255],
                        [ -1992,  -3074],
                        [ -1714,  -2840],
                        [ -1387,  -2553],
                        [ -1017,  -2221],
                        [  -606,  -1846],
                        [  -163,  -1434],
                        [   311,   -986],
                        [   807,   -512],
                        [  1323,    -12],
                        [  1848,    502],
                        [  2384,   1032],
                        [  2917,   1566],
                        [  3447,   2104],
                        [  3966,   2639],
                        [  4472,   3170],
                        [  4961,   3691],
                        [  5430,   4202],
                        [  5878,   4698],
                        [  6304,   5176],
                        [  6705,   5633],
                        [  7080,   6068],
                        [  7428,   6476],
                        [  7746,   6857],
                        [  8036,   7210],
                        [  8296,   7534],
                        [  8524,   7825],
                        [  8721,   8085],
                        [  8889,   8313],
                        [  9025,   8508],
                        [  9133,   8670],
                        [  9211,   8800],
                        [  9259,   8899],
                        [  9278,   8965],
                        [  9267,   9002],
                        [  9220,   9004],
                        [  9143,   8982],
                        [  9029,   8929],
                        [  8842,   8806],
                        [  8557,   8588],
                        [  8187,   8279],
                        [  7726,   7875],
                        [  7158,   7350],
                        [  6435,   6660],
                        [  5573,   5822],
                        [  4656,   4919],
                        [  3724,   3993],
                        [  2779,   3048],
                        [  1839,   2100],
                        [   921,   1168],
                        [    36,    264],
                        [  -804,   -600],
                        [ -1590,  -1413],
                        [ -2312,  -2165],
                        [ -2963,  -2849],
                        [ -3538,  -3458],
                        [ -4033,  -3998],
                        [ -4444,  -4462],
                        [ -4766,  -4858],
                        [ -5003,  -5185],
                        [ -5155,  -5446],
                        [ -5223,  -5644],
                        [ -5213,  -5772],
                        [ -5126,  -5833],
                        [ -4975,  -5820],
                        [ -4760,  -5734],
                        [ -4492,  -5575],
                        [ -4175,  -5347],
                        [ -3816,  -5052],
                        [ -3424,  -4695],
                        [ -3003,  -4287],
                        [ -2562,  -3830],
                        [ -2107,  -3344],
                        [ -1643,  -2832],
                        [ -1177,  -2310],
                        [  -714,  -1780],
                        [  -257,  -1250],
                        [   190,   -722],
                        [   624,   -203],
                        [  1039,    301],
                        [  1435,    789],
                        [  1809,   1256],
                        [  2158,   1700],
                        [  2481,   2117],
                        [  2776,   2503],
                        [  3041,   2861],
                        [  3278,   3187],
                        [  3485,   3480],
                        [  3661,   3740],
                        [  3808,   3968],
                        [  3933,   4162],
                        [  4033,   4325],
                        [  4123,   4457],
                        [  4203,   4557],
                        [  4277,   4630],
                        [  4345,   4676],
                        [  4409,   4695],
                        [  4469,   4693],
                        [  4511,   4669],
                        [  4538,   4626],
                        [  4548,   4565],
                        [  4541,   4491],
                        [  4519,   4404],
                        [  4483,   4306],
                        [  4434,   4201],
                        [  4375,   4090],
                        [  4306,   3976],
                        [  4227,   3856],
                        [  4141,   3736],
                        [  4049,   3616],
                        [  3956,   3504],
                        [  3863,   3397],
                        [  3814,   3341],
                        [  3806,   3332],
                        [  3876,   3408],
                        [  4024,   3569],
                        [  4252,   3816],
                        [  4561,   4151],
                        [  4893,   4511],
                        [  5248,   4901],
                        [  5564,   5255],
                        [  5843,   5575],
                        [  6079,   5857],
                        [  6271,   6099],
                        [  6415,   6297],
                        [  6509,   6449],
                        [  6553,   6554],
                        [  6545,   6612],
                        [  6488,   6623],
                        [  6378,   6585],
                        [  6221,   6499],
                        [  6013,   6364],
                        [  5761,   6186],
                        [  5461,   5961],
                        [  5123,   5696],
                        [  4743,   5389],
                        [  4328,   5043],
                        [  3880,   4659],
                        [  3400,   4238],
                        [  2891,   3781],
                        [  2355,   3292],
                        [  1794,   2771],
                        [  1208,   2221],
                        [   600,   1643],
                        [   -25,   1044],
                        [  -669,    423],
                        [ -1323,   -214],
                        [ -1987,   -865],
                        [ -2658,  -1527],
                        [ -3329,  -2194],
                        [ -3998,  -2862],
                        [ -4663,  -3531],
                        [ -5318,  -4193],
                        [ -5960,  -4846],
                        [ -6582,  -5483],
                        [ -7183,  -6102],
                        [ -7755,  -6698],
                        [ -8293,  -7267],
                        [ -8784,  -7802],
                        [ -9228,  -8305],
                        [ -9615,  -8764],
                        [ -9923,  -9157],
                        [-10153,  -9479],
                        [-10310,  -9735],
                        [-10398,  -9917],
                        [-10387,  -9994],
                        [-10225,  -9915],
                        [ -9901,  -9667],
                        [ -9463,  -9298],
                        [ -8938,  -8837],
                        [ -8327,  -8284],
                        [ -7643,  -7653],
                        [ -6905,  -6962],
                        [ -6122,  -6221],
                        [ -5306,  -5440],
                        [ -4469,  -4632],
                        [ -3622,  -3810],
                        [ -2773,  -2980],
                        [ -1932,  -2152],
                        [ -1108,  -1330],
                        [  -307,   -515],
                        [   464,    287],
                        [  1201,   1075],
                        [  1899,   1845],
                        [  2553,   2593],
                        [  3162,   3317],
                        [  3725,   3999],
                        [  4243,   4643],
                        [  4714,   5235],
                        [  5141,   5774],
                        [  5523,   6252],
                        [  5861,   6669],
                        [  6157,   7022],
                        [  6413,   7313],
                        [  6630,   7547],
                        [  6810,   7726],
                        [  6957,   7863],
                        [  7071,   7958],
                        [  7156,   8018],
                        [  7212,   8043],
                        [  7240,   8036],
                        [  7242,   7997],
                        [  7219,   7931],
                        [  7174,   7839],
                        [  7108,   7725],
                        [  7022,   7590],
                        [  6919,   7436],
                        [  6801,   7268],
                        [  6671,   7085],
                        [  6529,   6892],
                        [  6381,   6692],
                        [  6227,   6485],
                        [  6069,   6275],
                        [  5909,   6064],
                        [  5742,   5854],
                        [  5569,   5648],
                        [  5389,   5449],
                        [  5205,   5258],
                        [  5015,   5077],
                        [  4821,   4910],
                        [  4633,   4757],
                        [  4453,   4622],
                        [  4292,   4505],
                        [  4154,   4408],
                        [  4040,   4332],
                        [  3950,   4279],
                        [  3889,   4250],
                        [  3859,   4247],
                        [  3859,   4268],
                        [  3889,   4314],
                        [  3954,   4390],
                        [  4052,   4494],
                        [  4180,   4621],
                        [  4338,   4773],
                        [  4507,   4930],
                        [  4687,   5094],
                        [  4828,   5213],
                        [  4930,   5289],
                        [  4977,   5307],
                        [  4970,   5267],
                        [  4916,   5179],
                        [  4813,   5040],
                        [  4739,   4929],
                        [  4685,   4838],
                        [  4672,   4787],
                        [  4697,   4776],
                        [  4761,   4805],
                        [  4865,   4873],
                        [  5007,   4981],
                        [  5184,   5127],
                        [  5393,   5305],
                        [  5633,   5514],
                        [  5899,   5752],
                        [  6188,   6015],
                        [  6494,   6296],
                        [  6816,   6597],
                        [  7146,   6905],
                        [  7482,   7223],
                        [  7817,   7542],
                        [  8149,   7862],
                        [  8470,   8175],
                        [  8781,   8483],
                        [  9076,   8780],
                        [  9354,   9067],
                        [  9615,   9339],
                        [  9857,   9595],
                        [ 10077,   9832],
                        [ 10276,  10049],
                        [ 10453,  10244],
                        [ 10606,  10416],
                        [ 10732,  10563],
                        [ 10836,  10687],
                        [ 10915,  10784],
                        [ 10970,  10857],
                        [ 10999,  10904],
                        [ 11003,  10923],
                        [ 10985,  10918],
                        [ 10943,  10888],
                        [ 10876,  10831],
                        [ 10787,  10752],
                        [ 10666,  10648],
                        [ 10515,  10520],
                        [ 10333,  10372],
                        [ 10116,  10201],
                        [  9877,  10013],
                        [  9634,   9830],
                        [  9414,   9667],
                        [  9212,   9519],
                        [  9010,   9361],
                        [  8756,   9140],
                        [  8410,   8821],
                        [  7992,   8419],
                        [  7517,   7955],
                        [  6993,   7433],
                        [  6429,   6866],
                        [  5843,   6269],
                        [  5242,   5654],
                        [  4638,   5029],
                        [  4040,   4407],
                        [  3459,   3798],
                        [  2902,   3209],
                        [  2377,   2647],
                        [  1889,   2114],
                        [  1444,   1617],
                        [  1043,   1153],
                        [   691,    725],
                        [   388,    332],
                        [   137,    -24],
                        [   -64,   -339],
                        [  -216,   -615],
                        [  -323,   -843],
                        [  -385,  -1026],
                        [  -409,  -1156],
                        [  -397,  -1239],
                        [  -354,  -1268],
                        [  -284,  -1246],
                        [  -191,  -1181],
                        [   -79,  -1074],
                        [    47,   -939],
                        [   180,   -779],
                        [   319,   -609],
                        [   457,   -431],
                        [   595,   -249],
                        [   726,    -66],
                        [   851,    115],
                        [   967,    290],
                        [  1074,    456],
                        [  1171,    613],
                        [  1255,    756],
                        [  1327,    885],
                        [  1387,    999],
                        [  1433,   1097],
                        [  1467,   1180],
                        [  1487,   1246],
                        [  1494,   1296],
                        [  1489,   1330],
                        [  1476,   1350],
                        [  1457,   1357],
                        [  1437,   1351],
                        [  1417,   1333],
                        [  1401,   1307],
                        [  1391,   1272],
                        [  1391,   1230],
                        [  1402,   1184],
                        [  1416,   1133],
                        [  1434,   1081],
                        [  1455,   1029],
                        [  1479,    977],
                        [  1503,    929],
                        [  1530,    883],
                        [  1558,    843],
                        [  1588,    808],
                        [  1618,    778],
                        [  1645,    752],
                        [  1670,    730],
                        [  1697,    718],
                        [  1724,    716],
                        [  1753,    723],
                        [  1821,    778],
                        [  1923,    878],
                        [  2084,   1046],
                        [  2300,   1277],
                        [  2582,   1583],
                        [  2927,   1960],
                        [  3288,   2363],
                        [  3668,   2793],
                        [  4012,   3192],
                        [  4321,   3564],
                        [  4586,   3898],
                        [  4805,   4191],
                        [  4971,   4435],
                        [  5082,   4629],
                        [  5133,   4766],
                        [  5125,   4848],
                        [  5055,   4872],
                        [  4922,   4835],
                        [  4731,   4741],
                        [  4479,   4587],
                        [  4168,   4376],
                        [  3801,   4109],
                        [  3385,   3792],
                        [  2918,   3423],
                        [  2409,   3010],
                        [  1858,   2551],
                        [  1274,   2052],
                        [   658,   1516],
                        [    17,    947],
                        [  -648,    346],
                        [ -1332,   -279],
                        [ -2030,   -925],
                        [ -2736,  -1584],
                        [ -3446,  -2256],
                        [ -4154,  -2931],
                        [ -4857,  -3608],
                        [ -5546,  -4276],
                        [ -6220,  -4936],
                        [ -6869,  -5578],
                        [ -7493,  -6200],
                        [ -8084,  -6795],
                        [ -8639,  -7358],
                        [ -9150,  -7885],
                        [ -9616,  -8370],
                        [-10027,  -8811],
                        [-10380,  -9202],
                        [-10662,  -9540],
                        [-10871,  -9819],
                        [-11009, -10043],
                        [-11106, -10241],
                        [-11204, -10446],
                        [-11318, -10674],
                        [-11456, -10918],
                        [-11593, -11156],
                        [-11674, -11330],
                        [-11632, -11373],
                        [-11453, -11271],
                        [-11152, -11038],
                        [-10732, -10676],
                        [-10204, -10199],
                        [ -9586,  -9622],
                        [ -8885,  -8954],
                        [ -8116,  -8209],
                        [ -7292,  -7399],
                        [ -6427,  -6538],
                        [ -5532,  -5639],
                        [ -4617,  -4710],
                        [ -3694,  -3765],
                        [ -2776,  -2810],
                        [ -1866,  -1853],
                        [  -978,   -904],
                        [  -117,     33],
                        [   709,    948],
                        [  1491,   1839],
                        [  2227,   2693],
                        [  2914,   3506],
                        [  3548,   4268],
                        [  4127,   4974],
                        [  4650,   5613],
                        [  5118,   6184],
                        [  5530,   6682],
                        [  5885,   7106],
                        [  6187,   7460],
                        [  6437,   7745],
                        [  6638,   7972],
                        [  6793,   8143],
                        [  6905,   8265],
                        [  6979,   8341],
                        [  7016,   8372],
                        [  7018,   8361],
                        [  6988,   8313],
                        [  6931,   8232],
                        [  6848,   8123],
                        [  6741,   7987],
                        [  6616,   7830],
                        [  6476,   7655],
                        [  6323,   7468],
                        [  6161,   7269],
                        [  5997,   7064],
                        [  5830,   6856],
                        [  5665,   6649],
                        [  5505,   6446],
                        [  5348,   6249],
                        [  5199,   6063],
                        [  5059,   5887],
                        [  4931,   5727],
                        [  4810,   5584],
                        [  4698,   5458],
                        [  4596,   5353],
                        [  4504,   5269],
                        [  4429,   5207],
                        [  4371,   5168],
                        [  4333,   5151],
                        [  4315,   5159],
                        [  4317,   5188],
                        [  4341,   5240],
                        [  4386,   5313],
                        [  4454,   5408],
                        [  4544,   5525],
                        [  4656,   5661],
                        [  4783,   5811],
                        [  4928,   5976],
                        [  5071,   6135],
                        [  5212,   6291],
                        [  5319,   6408],
                        [  5391,   6487],
                        [  5415,   6515],
                        [  5391,   6491],
                        [  5311,   6409],
                        [  5176,   6268],
                        [  5037,   6121],
                        [  4889,   5963],
                        [  4750,   5810],
                        [  4616,   5662],
                        [  4495,   5523],
                        [  4383,   5396],
                        [  4288,   5282],
                        [  4206,   5182],
                        [  4140,   5095],
                        [  4087,   5023],
                        [  4050,   4963],
                        [  4026,   4914],
                        [  4013,   4875],
                        [  4013,   4847],
                        [  4020,   4823],
                        [  4034,   4804],
                        [  4052,   4788],
                        [  4073,   4772],
                        [  4093,   4755],
                        [  4112,   4736],
                        [  4127,   4715],
                        [  4137,   4691],
                        [  4143,   4661],
                        [  4143,   4628],
                        [  4135,   4587],
                        [  4121,   4539],
                        [  4098,   4483],
                        [  4068,   4418],
                        [  4028,   4344],
                        [  3980,   4262],
                        [  3922,   4168],
                        [  3854,   4067],
                        [  3776,   3954],
                        [  3686,   3831],
                        [  3587,   3698],
                        [  3478,   3555],
                        [  3354,   3401],
                        [  3217,   3237],
                        [  3059,   3062],
                        [  2882,   2878],
                        [  2676,   2680],
                        [  2458,   2482],
                        [  2286,   2342],
                        [  2212,   2312],
                        [  2260,   2402],
                        [  2429,   2612],
                        [  2705,   2924],
                        [  3031,   3279],
                        [  3307,   3580],
                        [  3492,   3785],
                        [  3593,   3899],
                        [  3614,   3928],
                        [  3559,   3876],
                        [  3436,   3752],
                        [  3251,   3560],
                        [  3013,   3311],
                        [  2728,   3010],
                        [  2406,   2668],
                        [  2053,   2290],
                        [  1677,   1884],
                        [  1282,   1457],
                        [   877,   1014],
                        [   463,    561],
                        [    46,    102],
                        [  -366,   -360],
                        [  -771,   -821],
                        [ -1165,  -1281],
                        [ -1543,  -1735],
                        [ -1905,  -2179],
                        [ -2249,  -2611],
                        [ -2576,  -3023],
                        [ -2884,  -3413],
                        [ -3175,  -3773],
                        [ -3448,  -4103],
                        [ -3704,  -4405],
                        [ -3942,  -4675],
                        [ -4166,  -4920],
                        [ -4374,  -5140],
                        [ -4571,  -5345],
                        [ -4757,  -5536],
                        [ -4933,  -5713],
                        [ -5100,  -5876],
                        [ -5257,  -6027],
                        [ -5405,  -6167],
                        [ -5541,  -6296],
                        [ -5667,  -6414],
                        [ -5782,  -6522],
                        [ -5886,  -6621],
                        [ -5978,  -6711],
                        [ -6058,  -6791],
                        [ -6127,  -6862],
                        [ -6186,  -6924],
                        [ -6232,  -6976],
                        [ -6268,  -7018],
                        [ -6291,  -7051],
                        [ -6302,  -7073],
                        [ -6303,  -7083],
                        [ -6294,  -7085],
                        [ -6273,  -7074],
                        [ -6240,  -7052],
                        [ -6187,  -7018],
                        [ -6116,  -6974],
                        [ -6025,  -6918],
                        [ -5914,  -6851],
                        [ -5789,  -6774],
                        [ -5648,  -6686],
                        [ -5495,  -6588],
                        [ -5332,  -6482],
                        [ -5162,  -6368],
                        [ -4986,  -6245],
                        [ -4807,  -6117],
                        [ -4630,  -5988],
                        [ -4457,  -5856],
                        [ -4285,  -5721],
                        [ -4117,  -5581],
                        [ -3954,  -5440],
                        [ -3778,  -5277],
                        [ -3592,  -5098],
                        [ -3391,  -4895],
                        [ -3178,  -4669],
                        [ -2935,  -4408],
                        [ -2666,  -4111],
                        [ -2389,  -3798],
                        [ -2104,  -3470],
                        [ -1848,  -3161],
                        [ -1618,  -2873],
                        [ -1424,  -2615],
                        [ -1268,  -2389],
                        [ -1159,  -2208],
                        [ -1098,  -2070],
                        [ -1088,  -1984],
                        [ -1133,  -1948],
                        [ -1233,  -1967],
                        [ -1387,  -2040],
                        [ -1597,  -2165],
                        [ -1861,  -2343],
                        [ -2176,  -2572],
                        [ -2539,  -2848],
                        [ -2945,  -3168],
                        [ -3393,  -3530],
                        [ -3876,  -3929],
                        [ -4391,  -4362],
                        [ -4928,  -4822],
                        [ -5486,  -5306],
                        [ -6058,  -5810],
                        [ -6638,  -6329],
                        [ -7221,  -6856],
                        [ -7802,  -7387],
                        [ -8373,  -7915],
                        [ -8933,  -8435],
                        [ -9471,  -8941],
                        [ -9985,  -9428],
                        [-10468,  -9891],
                        [-10918, -10325],
                        [-11328, -10725],
                        [-11694, -11087],
                        [-12011, -11407],
                        [-12279, -11680],
                        [-12490, -11902],
                        [-12643, -12072],
                        [-12730, -12186],
                        [-12751, -12243],
                        [-12700, -12241],
                        [-12568, -12173],
                        [-12385, -12064],
                        [-12227, -11994],
                        [-12158, -12019],
                        [-12192, -12150],
                        [-12340, -12390],
                        [-12597, -12732],
                        [-12898, -13113],
                        [-13127, -13413],
                        [-13225, -13574],
                        [-13200, -13604],
                        [-13058, -13506],
                        [-12803, -13288],
                        [-12445, -12956],
                        [-11993, -12520],
                        [-11457, -11992],
                        [-10847, -11379],
                        [-10177, -10697],
                        [ -9456,  -9954],
                        [ -8695,  -9164],
                        [ -7905,  -8337],
                        [ -7095,  -7487],
                        [ -6273,  -6623],
                        [ -5451,  -5756],
                        [ -4638,  -4895],
                        [ -3843,  -4045],
                        [ -3075,  -3212],
                        [ -2340,  -2401],
                        [ -1645,  -1617],
                        [  -991,   -870],
                        [  -384,   -163],
                        [   176,    493],
                        [   685,   1096],
                        [  1143,   1640],
                        [  1551,   2124],
                        [  1909,   2547],
                        [  2216,   2910],
                        [  2477,   3222],
                        [  2696,   3482],
                        [  2876,   3699],
                        [  3020,   3875],
                        [  3132,   4011],
                        [  3214,   4110],
                        [  3270,   4178],
                        [  3303,   4218],
                        [  3313,   4233],
                        [  3308,   4227],
                        [  3288,   4207],
                        [  3257,   4173],
                        [  3219,   4130],
                        [  3178,   4080],
                        [  3136,   4030],
                        [  3098,   3980],
                        [  3064,   3934],
                        [  3038,   3895],
                        [  3024,   3863],
                        [  3026,   3842],
                        [  3047,   3833],
                        [  3088,   3836],
                        [  3144,   3853],
                        [  3215,   3885],
                        [  3291,   3932],
                        [  3373,   3993],
                        [  3456,   4067],
                        [  3546,   4157],
                        [  3637,   4258],
                        [  3731,   4370],
                        [  3828,   4492],
                        [  3927,   4623],
                        [  4027,   4758],
                        [  4128,   4899],
                        [  4228,   5043],
                        [  4327,   5188],
                        [  4421,   5328],
                        [  4508,   5463],
                        [  4581,   5584],
                        [  4639,   5688],
                        [  4677,   5770],
                        [  4694,   5829],
                        [  4678,   5853],
                        [  4630,   5842],
                        [  4527,   5771],
                        [  4370,   5643],
                        [  4178,   5474],
                        [  3949,   5263],
                        [  3694,   5022],
                        [  3413,   4750],
                        [  3117,   4460],
                        [  2804,   4149],
                        [  2485,   3828],
                        [  2157,   3496],
                        [  1830,   3161],
                        [  1502,   2823],
                        [  1179,   2485],
                        [   860,   2147],
                        [   553,   1812],
                        [   254,   1481],
                        [   -33,   1155],
                        [  -310,    836],
                        [  -572,    525],
                        [  -821,    221],
                        [ -1057,    -75],
                        [ -1279,   -361],
                        [ -1489,   -638],
                        [ -1687,   -905],
                        [ -1872,  -1162],
                        [ -2045,  -1407],
                        [ -2208,  -1643],
                        [ -2358,  -1868],
                        [ -2498,  -2084],
                        [ -2629,  -2290],
                        [ -2751,  -2487],
                        [ -2863,  -2675],
                        [ -2970,  -2855],
                        [ -3069,  -3026],
                        [ -3162,  -3190],
                        [ -3252,  -3347],
                        [ -3339,  -3498],
                        [ -3421,  -3643],
                        [ -3508,  -3785],
                        [ -3598,  -3924],
                        [ -3696,  -4061],
                        [ -3803,  -4195],
                        [ -3930,  -4336],
                        [ -4037,  -4444],
                        [ -4032,  -4427],
                        [ -3857,  -4228],
                        [ -3497,  -3842],
                        [ -2949,  -3266],
                        [ -2212,  -2500],
                        [ -1350,  -1612],
                        [  -511,   -748],
                        [   234,     20],
                        [   885,    692],
                        [  1444,   1268],
                        [  1905,   1742],
                        [  2269,   2116],
                        [  2537,   2391],
                        [  2715,   2570],
                        [  2805,   2658],
                        [  2814,   2659],
                        [  2744,   2578],
                        [  2604,   2424],
                        [  2399,   2204],
                        [  2131,   1923],
                        [  1809,   1594],
                        [  1437,   1222],
                        [  1029,    813],
                        [   587,    375],
                        [   123,    -97],
                        [  -358,   -593],
                        [  -849,  -1112],
                        [ -1347,  -1651],
                        [ -1847,  -2199],
                        [ -2345,  -2752],
                        [ -2838,  -3300],
                        [ -3320,  -3841],
                        [ -3789,  -4367],
                        [ -4242,  -4877],
                        [ -4676,  -5367],
                        [ -5091,  -5835],
                        [ -5486,  -6285],
                        [ -5861,  -6715],
                        [ -6215,  -7124],
                        [ -6548,  -7509],
                        [ -6858,  -7870],
                        [ -7145,  -8208],
                        [ -7405,  -8519],
                        [ -7639,  -8805],
                        [ -7847,  -9065],
                        [ -8028,  -9298],
                        [ -8180,  -9504],
                        [ -8307,  -9683],
                        [ -8408,  -9837],
                        [ -8482,  -9963],
                        [ -8531, -10064],
                        [ -8556, -10139],
                        [ -8561, -10189],
                        [ -8546, -10214],
                        [ -8520, -10215],
                        [ -8484, -10193],
                        [ -8440, -10150],
                        [ -8387, -10085],
                        [ -8318, -10001],
                        [ -8232,  -9899],
                        [ -8123,  -9778],
                        [ -7992,  -9644],
                        [ -7841,  -9496],
                        [ -7672,  -9335],
                        [ -7490,  -9164],
                        [ -7294,  -8985],
                        [ -7091,  -8799],
                        [ -6881,  -8609],
                        [ -6669,  -8416],
                        [ -6459,  -8225],
                        [ -6252,  -8035],
                        [ -6050,  -7847],
                        [ -5855,  -7664],
                        [ -5670,  -7488],
                        [ -5504,  -7327],
                        [ -5357,  -7180],
                        [ -5238,  -7057],
                        [ -5149,  -6959],
                        [ -5066,  -6862],
                        [ -4992,  -6767],
                        [ -4909,  -6658],
                        [ -4820,  -6537],
                        [ -4735,  -6416],
                        [ -4654,  -6294],
                        [ -4587,  -6180],
                        [ -4531,  -6075],
                        [ -4497,  -5991],
                        [ -4483,  -5925],
                        [ -4496,  -5886],
                        [ -4534,  -5873],
                        [ -4600,  -5889],
                        [ -4695,  -5933],
                        [ -4819,  -6005],
                        [ -4969,  -6103],
                        [ -5146,  -6225],
                        [ -5345,  -6370],
                        [ -5566,  -6535],
                        [ -5805,  -6719],
                        [ -6059,  -6916],
                        [ -6323,  -7125],
                        [ -6591,  -7339],
                        [ -6862,  -7556],
                        [ -7127,  -7771],
                        [ -7386,  -7981],
                        [ -7629,  -8179],
                        [ -7854,  -8366],
                        [ -8058,  -8531],
                        [ -8236,  -8675],
                        [ -8383,  -8791],
                        [ -8498,  -8877],
                        [ -8575,  -8930],
                        [ -8614,  -8947],
                        [ -8611,  -8926],
                        [ -8565,  -8865],
                        [ -8471,  -8760],
                        [ -8333,  -8614],
                        [ -8146,  -8422],
                        [ -7910,  -8184],
                        [ -7622,  -7901],
                        [ -7285,  -7576],
                        [ -6897,  -7205],
                        [ -6451,  -6785],
                        [ -6003,  -6370],
                        [ -5654,  -6063],
                        [ -5462,  -5915],
                        [ -5436,  -5939],
                        [ -5594,  -6143],
                        [ -5949,  -6540],
                        [ -6436,  -7066],
                        [ -6902,  -7566],
                        [ -7276,  -7967],
                        [ -7562,  -8274],
                        [ -7762,  -8488],
                        [ -7873,  -8606],
                        [ -7896,  -8630],
                        [ -7835,  -8561],
                        [ -7695,  -8406],
                        [ -7481,  -8170],
                        [ -7200,  -7859],
                        [ -6858,  -7482],
                        [ -6462,  -7048],
                        [ -6019,  -6565],
                        [ -5532,  -6047],
                        [ -5012,  -5502],
                        [ -4467,  -4942],
                        [ -3905,  -4373],
                        [ -3335,  -3798],
                        [ -2766,  -3225],
                        [ -2204,  -2648],
                        [ -1656,  -2075],
                        [ -1125,  -1509],
                        [  -613,   -951],
                        [  -124,   -412],
                        [   339,    107],
                        [   774,    602],
                        [  1179,   1070],
                        [  1554,   1508],
                        [  1900,   1915],
                        [  2217,   2293],
                        [  2508,   2641],
                        [  2776,   2966],
                        [  3022,   3266],
                        [  3250,   3544],
                        [  3461,   3801],
                        [  3658,   4041],
                        [  3842,   4265],
                        [  4013,   4474],
                        [  4175,   4673],
                        [  4330,   4863],
                        [  4479,   5045],
                        [  4624,   5222],
                        [  4768,   5396],
                        [  4910,   5568],
                        [  5054,   5741],
                        [  5200,   5914],
                        [  5349,   6089],
                        [  5511,   6265],
                        [  5686,   6444],
                        [  5878,   6624],
                        [  6088,   6808],
                        [  6308,   6992],
                        [  6539,   7176],
                        [  6763,   7359],
                        [  6979,   7541],
                        [  7179,   7717],
                        [  7363,   7890],
                        [  7527,   8054],
                        [  7672,   8211],
                        [  7795,   8356],
                        [  7897,   8487],
                        [  7974,   8603],
                        [  8028,   8702],
                        [  8056,   8782],
                        [  8058,   8842],
                        [  8033,   8877],
                        [  7980,   8888],
                        [  7906,   8882],
                        [  7815,   8859],
                        [  7725,   8837],
                        [  7636,   8815],
                        [  7541,   8786],
                        [  7440,   8747],
                        [  7295,   8660],
                        [  7107,   8527],
                        [  6863,   8331],
                        [  6562,   8072],
                        [  6215,   7762],
                        [  5822,   7399],
                        [  5395,   6995],
                        [  4934,   6552],
                        [  4450,   6083],
                        [  3944,   5588],
                        [  3428,   5077],
                        [  2902,   4552],
                        [  2376,   4020],
                        [  1849,   3483],
                        [  1332,   2947],
                        [   825,   2413],
                        [   333,   1887],
                        [  -141,   1372],
                        [  -593,    869],
                        [ -1022,    384],
                        [ -1425,    -82],
                        [ -1802,   -529],
                        [ -2153,   -955],
                        [ -2477,  -1359],
                        [ -2776,  -1739],
                        [ -3047,  -2095],
                        [ -3293,  -2428],
                        [ -3516,  -2737],
                        [ -3713,  -3024],
                        [ -3887,  -3287],
                        [ -4040,  -3527],
                        [ -4171,  -3746],
                        [ -4284,  -3945],
                        [ -4378,  -4122],
                        [ -4458,  -4282],
                        [ -4524,  -4422],
                        [ -4578,  -4548],
                        [ -4621,  -4657],
                        [ -4659,  -4756],
                        [ -4692,  -4843],
                        [ -4721,  -4918],
                        [ -4750,  -4986],
                        [ -4789,  -5055],
                        [ -4774,  -5060],
                        [ -4613,  -4908],
                        [ -4262,  -4556],
                        [ -3717,  -4004],
                        [ -2963,  -3237],
                        [ -1982,  -2238],
                        [  -843,  -1081],
                        [   294,     78],
                        [  1352,   1159],
                        [  2333,   2161],
                        [  3231,   3081],
                        [  4034,   3904],
                        [  4737,   4624],
                        [  5339,   5241],
                        [  5837,   5749],
                        [  6231,   6151],
                        [  6524,   6447],
                        [  6715,   6641],
                        [  6810,   6736],
                        [  6810,   6741],
                        [  6723,   6666],
                        [  6552,   6519],
                        [  6305,   6309],
                        [  5993,   6044],
                        [  5625,   5731],
                        [  5211,   5367],
                        [  4759,   4959],
                        [  4279,   4507],
                        [  3774,   4017],
                        [  3254,   3495],
                        [  2725,   2950],
                        [  2194,   2388],
                        [  1665,   1815],
                        [  1147,   1242],
                        [   644,    670],
                        [   160,    112],
                        [  -300,   -429],
                        [  -735,   -950],
                        [ -1143,  -1449],
                        [ -1523,  -1920],
                        [ -1874,  -2363],
                        [ -2193,  -2776],
                        [ -2479,  -3155],
                        [ -2732,  -3501],
                        [ -2949,  -3811],
                        [ -3132,  -4086],
                        [ -3281,  -4325],
                        [ -3395,  -4528],
                        [ -3475,  -4695],
                        [ -3524,  -4828],
                        [ -3542,  -4927],
                        [ -3531,  -4993],
                        [ -3493,  -5028],
                        [ -3437,  -5034],
                        [ -3363,  -5012],
                        [ -3285,  -4964],
                        [ -3205,  -4891],
                        [ -3125,  -4799],
                        [ -3050,  -4686],
                        [ -2968,  -4555],
                        [ -2884,  -4410],
                        [ -2784,  -4253],
                        [ -2671,  -4086],
                        [ -2544,  -3911],
                        [ -2407,  -3732],
                        [ -2260,  -3549],
                        [ -2108,  -3365],
                        [ -1952,  -3183],
                        [ -1796,  -3005],
                        [ -1642,  -2832],
                        [ -1490,  -2666],
                        [ -1345,  -2508],
                        [ -1206,  -2362],
                        [ -1081,  -2231],
                        [  -972,  -2118],
                        [  -913,  -2057],
                        [  -903,  -2045],
                        [  -956,  -2098],
                        [ -1071,  -2212],
                        [ -1222,  -2363],
                        [ -1412,  -2551],
                        [ -1585,  -2721],
                        [ -1744,  -2875],
                        [ -1882,  -3006],
                        [ -1997,  -3113],
                        [ -2095,  -3200],
                        [ -2174,  -3269],
                        [ -2240,  -3324],
                        [ -2290,  -3364],
                        [ -2331,  -3398],
                        [ -2360,  -3421],
                        [ -2382,  -3439],
                        [ -2394,  -3448],
                        [ -2399,  -3451],
                        [ -2395,  -3444],
                        [ -2385,  -3428],
                        [ -2365,  -3401],
                        [ -2338,  -3365],
                        [ -2302,  -3317],
                        [ -2256,  -3258],
                        [ -2197,  -3183],
                        [ -2125,  -3092],
                        [ -2035,  -2983],
                        [ -1926,  -2851],
                        [ -1796,  -2698],
                        [ -1641,  -2520],
                        [ -1462,  -2317],
                        [ -1255,  -2087],
                        [ -1021,  -1827],
                        [  -760,  -1540],
                        [  -469,  -1222],
                        [  -149,   -876],
                        [   199,   -501],
                        [   575,    -98],
                        [   977,    331],
                        [  1408,    787],
                        [  1861,   1265],
                        [  2338,   1766],
                        [  2836,   2289],
                        [  3352,   2831],
                        [  3880,   3382],
                        [  4423,   3951],
                        [  4978,   4532],
                        [  5480,   5055],
                        [  5835,   5429],
                        [  6011,   5620],
                        [  6002,   5621],
                        [  5782,   5410],
                        [  5320,   4955],
                        [  4681,   4323],
                        [  4010,   3659],
                        [  3375,   3033],
                        [  2771,   2439],
                        [  2205,   1886],
                        [  1689,   1385],
                        [  1228,    941],
                        [   823,    558],
                        [   481,    238],
                        [   199,    -17],
                        [   -20,   -206],
                        [  -176,   -332],
                        [  -268,   -401],
                        [  -301,   -412],
                        [  -273,   -379],
                        [  -190,   -306],
                        [   -57,   -201],
                        [   122,    -71],
                        [   337,     89],
                        [   583,    269],
                        [   856,    483],
                        [  1150,    722],
                        [  1463,    993],
                        [  1789,   1291],
                        [  2127,   1614],
                        [  2472,   1958],
                        [  2823,   2322],
                        [  3175,   2703],
                        [  3526,   3092],
                        [  3874,   3489],
                        [  4219,   3888],
                        [  4561,   4287],
                        [  4898,   4685],
                        [  5232,   5083],
                        [  5563,   5480],
                        [  5892,   5873],
                        [  6218,   6264],
                        [  6540,   6652],
                        [  6857,   7035],
                        [  7170,   7414],
                        [  7477,   7789],
                        [  7780,   8158],
                        [  8075,   8521],
                        [  8364,   8877],
                        [  8645,   9226],
                        [  8918,   9566],
                        [  9184,   9898],
                        [  9443,  10220],
                        [  9702,  10528],
                        [  9962,  10825],
                        [ 10227,  11106],
                        [ 10496,  11373],
                        [ 10763,  11620],
                        [ 11028,  11848],
                        [ 11271,  12054],
                        [ 11491,  12238],
                        [ 11677,  12397],
                        [ 11827,  12529],
                        [ 11939,  12633],
                        [ 12011,  12708],
                        [ 12044,  12751],
                        [ 12034,  12762],
                        [ 11983,  12740],
                        [ 11890,  12684],
                        [ 11754,  12591],
                        [ 11576,  12464],
                        [ 11358,  12301],
                        [ 11100,  12104],
                        [ 10832,  11900],
                        [ 10554,  11688],
                        [ 10304,  11507],
                        [ 10082,  11352],
                        [  9886,  11225],
                        [  9718,  11123],
                        [  9524,  10992],
                        [  9311,  10838],
                        [  9037,  10618],
                        [  8704,  10333],
                        [  8320,   9993],
                        [  7887,   9596],
                        [  7413,   9154],
                        [  6901,   8666],
                        [  6361,   8146],
                        [  5795,   7596],
                        [  5213,   7028],
                        [  4617,   6441],
                        [  4019,   5846],
                        [  3418,   5243],
                        [  2825,   4642],
                        [  2240,   4042],
                        [  1674,   3453],
                        [  1125,   2875],
                        [   602,   2315],
                        [   106,   1775],
                        [  -360,   1259],
                        [  -796,    768],
                        [ -1202,    302],
                        [ -1575,   -137],
                        [ -1920,   -548],
                        [ -2234,   -933],
                        [ -2520,  -1289],
                        [ -2776,  -1619],
                        [ -3005,  -1922],
                        [ -3208,  -2199],
                        [ -3387,  -2451],
                        [ -3541,  -2676],
                        [ -3675,  -2880],
                        [ -3788,  -3060],
                        [ -3883,  -3220],
                        [ -3963,  -3359],
                        [ -4029,  -3482],
                        [ -4081,  -3585],
                        [ -4124,  -3677],
                        [ -4154,  -3754],
                        [ -4171,  -3816],
                        [ -4180,  -3872],
                        [ -4186,  -3920],
                        [ -4120,  -3894],
                        [ -3920,  -3725],
                        [ -3566,  -3395],
                        [ -3058,  -2901],
                        [ -2373,  -2222],
                        [ -1473,  -1325],
                        [  -417,   -264],
                        [   659,    820],
                        [  1695,   1868],
                        [  2694,   2880],
                        [  3643,   3843],
                        [  4528,   4742],
                        [  5340,   5566],
                        [  6073,   6311],
                        [  6720,   6968],
                        [  7280,   7534],
                        [  7748,   8006],
                        [  8123,   8387],
                        [  8405,   8673],
                        [  8595,   8877],
                        [  8696,   9000],
                        [  8712,   9055],
                        [  8648,   9048],
                        [  8516,   8986],
                        [  8319,   8875],
                        [  8071,   8712],
                        [  7778,   8504],
                        [  7448,   8244],
                        [  7087,   7941],
                        [  6702,   7594],
                        [  6300,   7213],
                        [  5890,   6801],
                        [  5475,   6364],
                        [  5065,   5911],
                        [  4664,   5446],
                        [  4277,   4984],
                        [  3908,   4527],
                        [  3560,   4084],
                        [  3238,   3660],
                        [  2939,   3257],
                        [  2667,   2878],
                        [  2420,   2524],
                        [  2203,   2198],
                        [  2013,   1901],
                        [  1851,   1635],
                        [  1718,   1399],
                        [  1611,   1192],
                        [  1532,   1016],
                        [  1478,    870],
                        [  1446,    750],
                        [  1438,    657],
                        [  1448,    590],
                        [  1475,    544],
                        [  1508,    519],
                        [  1546,    513],
                        [  1577,    522],
                        [  1598,    546],
                        [  1604,    581],
                        [  1591,    625],
                        [  1569,    675],
                        [  1534,    730],
                        [  1501,    787],
                        [  1468,    844],
                        [  1438,    899],
                        [  1409,    950],
                        [  1381,    996],
                        [  1353,   1035],
                        [  1323,   1066],
                        [  1290,   1088],
                        [  1259,   1102],
                        [  1224,   1106],
                        [  1187,   1099],
                        [  1146,   1081],
                        [  1090,   1039],
                        [  1019,    975],
                        [   882,    839],
                        [   683,    634],
                        [   407,    346],
                        [    56,    -23],
                        [  -345,   -444],
                        [  -794,   -919],
                        [ -1212,  -1366],
                        [ -1602,  -1788],
                        [ -1946,  -2165],
                        [ -2243,  -2494],
                        [ -2491,  -2778],
                        [ -2689,  -3013],
                        [ -2841,  -3202],
                        [ -2942,  -3344],
                        [ -2997,  -3442],
                        [ -3005,  -3495],
                        [ -2971,  -3507],
                        [ -2890,  -3474],
                        [ -2771,  -3402],
                        [ -2609,  -3287],
                        [ -2412,  -3134],
                        [ -2176,  -2938],
                        [ -1909,  -2708],
                        [ -1611,  -2442],
                        [ -1285,  -2143],
                        [  -930,  -1811],
                        [  -550,  -1448],
                        [  -143,  -1054],
                        [   289,   -630],
                        [   745,   -176],
                        [  1225,    305],
                        [  1727,    811],
                        [  2247,   1342],
                        [  2785,   1896],
                        [  3338,   2467],
                        [  3904,   3055],
                        [  4479,   3658],
                        [  5063,   4271],
                        [  5650,   4890],
                        [  6240,   5514],
                        [  6827,   6138],
                        [  7409,   6758],
                        [  7981,   7372],
                        [  8541,   7977],
                        [  9077,   8566],
                        [  9587,   9135],
                        [ 10072,   9687],
                        [ 10523,  10212],
                        [ 10887,  10649],
                        [ 11109,  10945],
                        [ 11187,  11091],
                        [ 11114,  11078],
                        [ 10859,  10878],
                        [ 10381,  10447],
                        [  9718,   9828],
                        [  8982,   9132],
                        [  8221,   8405],
                        [  7433,   7646],
                        [  6632,   6872],
                        [  5835,   6099],
                        [  5051,   5337],
                        [  4289,   4595],
                        [  3560,   3882],
                        [  2871,   3209],
                        [  2230,   2579],
                        [  1640,   1999],
                        [  1111,   1468],
                        [   642,    990],
                        [   240,    560],
                        [   -97,    176],
                        [  -369,   -167],
                        [  -578,   -469],
                        [  -727,   -727],
                        [  -822,   -945],
                        [  -866,  -1109],
                        [  -859,  -1222],
                        [  -805,  -1276],
                        [  -709,  -1274],
                        [  -572,  -1214],
                        [  -401,  -1099],
                        [  -196,   -927],
                        [    37,   -705],
                        [   293,   -440],
                        [   570,   -136],
                        [   862,    197],
                        [  1169,    553],
                        [  1487,    930],
                        [  1814,   1322],
                        [  2149,   1728],
                        [  2490,   2143],
                        [  2832,   2566],
                        [  3176,   2992],
                        [  3517,   3419],
                        [  3854,   3844],
                        [  4182,   4263],
                        [  4500,   4675],
                        [  4805,   5074],
                        [  5096,   5460],
                        [  5370,   5830],
                        [  5623,   6181],
                        [  5858,   6510],
                        [  6074,   6817],
                        [  6277,   7096],
                        [  6464,   7348],
                        [  6644,   7571],
                        [  6812,   7762],
                        [  6966,   7919],
                        [  7105,   8041],
                        [  7216,   8127],
                        [  7295,   8176],
                        [  7333,   8187],
                        [  7329,   8159],
                        [  7280,   8091],
                        [  7187,   7984],
                        [  7050,   7838],
                        [  6868,   7653],
                        [  6642,   7430],
                        [  6371,   7167],
                        [  6056,   6866],
                        [  5701,   6532],
                        [  5311,   6166],
                        [  4887,   5771],
                        [  4474,   5391],
                        [  4071,   5024],
                        [  3721,   4713],
                        [  3426,   4457],
                        [  3187,   4258],
                        [  3007,   4120],
                        [  2830,   3983],
                        [  2659,   3851],
                        [  2442,   3669],
                        [  2181,   3441],
                        [  1881,   3170],
                        [  1543,   2858],
                        [  1171,   2507],
                        [   766,   2121],
                        [   337,   1709],
                        [  -116,   1269],
                        [  -585,    812],
                        [ -1068,    338],
                        [ -1558,   -143],
                        [ -2052,   -632],
                        [ -2545,  -1123],
                        [ -3033,  -1614],
                        [ -3508,  -2095],
                        [ -3972,  -2571],
                        [ -4418,  -3031],
                        [ -4843,  -3476],
                        [ -5246,  -3902],
                        [ -5625,  -4307],
                        [ -5981,  -4693],
                        [ -6315,  -5058],
                        [ -6626,  -5402],
                        [ -6914,  -5726],
                        [ -7182,  -6030],
                        [ -7427,  -6312],
                        [ -7653,  -6576],
                        [ -7859,  -6820],
                        [ -8046,  -7045],
                        [ -8217,  -7253],
                        [ -8372,  -7443],
                        [ -8509,  -7616],
                        [ -8634,  -7774],
                        [ -8747,  -7915],
                        [ -8845,  -8043],
                        [ -8930,  -8156],
                        [ -9001,  -8258],
                        [ -9052,  -8346],
                        [ -9081,  -8420],
                        [ -9094,  -8486],
                        [ -9089,  -8536],
                        [ -9022,  -8530],
                        [ -8877,  -8439],
                        [ -8656,  -8267],
                        [ -8357,  -8010],
                        [ -7950,  -7636],
                        [ -7388,  -7100],
                        [ -6691,  -6424],
                        [ -5942,  -5692],
                        [ -5178,  -4939],
                        [ -4398,  -4167],
                        [ -3616,  -3389],
                        [ -2847,  -2624],
                        [ -2102,  -1881],
                        [ -1386,  -1168],
                        [  -710,   -494],
                        [   -81,    132],
                        [   496,    705],
                        [  1015,   1224],
                        [  1474,   1684],
                        [  1869,   2090],
                        [  2199,   2441],
                        [  2468,   2747],
                        [  2675,   3010],
                        [  2826,   3235],
                        [  2924,   3422],
                        [  2978,   3572],
                        [  2989,   3686],
                        [  2964,   3755],
                        [  2906,   3785],
                        [  2821,   3771],
                        [  2715,   3718],
                        [  2591,   3625],
                        [  2455,   3497],
                        [  2312,   3338],
                        [  2164,   3152],
                        [  2017,   2952],
                        [  1873,   2740],
                        [  1737,   2529],
                        [  1610,   2321],
                        [  1489,   2117],
                        [  1381,   1920],
                        [  1281,   1731],
                        [  1190,   1553],
                        [  1109,   1385],
                        [  1038,   1228],
                        [   973,   1082],
                        [   919,    947],
                        [   873,    825],
                        [   831,    711],
                        [   795,    606],
                        [   762,    510],
                        [   730,    421],
                        [   698,    336],
                        [   657,    254],
                        [   606,    176],
                        [   536,     98],
                        [   447,     20],
                        [   332,    -62],
                        [   189,   -146],
                        [    26,   -235],
                        [  -160,   -331],
                        [  -357,   -432],
                        [  -563,   -540],
                        [  -775,   -656],
                        [  -990,   -778],
                        [ -1208,   -907],
                        [ -1428,  -1043],
                        [ -1646,  -1185],
                        [ -1862,  -1333],
                        [ -2071,  -1483],
                        [ -2273,  -1635],
                        [ -2467,  -1789],
                        [ -2653,  -1945],
                        [ -2845,  -2118],
                        [ -3043,  -2306],
                        [ -3298,  -2561],
                        [ -3606,  -2879],
                        [ -3977,  -3270],
                        [ -4412,  -3731],
                        [ -4888,  -4243],
                        [ -5406,  -4804],
                        [ -5878,  -5325],
                        [ -6309,  -5810],
                        [ -6677,  -6237],
                        [ -6981,  -6602],
                        [ -7216,  -6903],
                        [ -7381,  -7136],
                        [ -7476,  -7303],
                        [ -7500,  -7400],
                        [ -7455,  -7431],
                        [ -7340,  -7393],
                        [ -7161,  -7292],
                        [ -6916,  -7127],
                        [ -6612,  -6902],
                        [ -6250,  -6619],
                        [ -5837,  -6280],
                        [ -5373,  -5887],
                        [ -4869,  -5451],
                        [ -4325,  -4968],
                        [ -3749,  -4449],
                        [ -3144,  -3894],
                        [ -2514,  -3311],
                        [ -1862,  -2700],
                        [ -1194,  -2065],
                        [  -510,  -1410],
                        [   182,   -740],
                        [   882,    -56],
                        [  1581,    634],
                        [  2277,   1326],
                        [  2966,   2017],
                        [  3644,   2701],
                        [  4305,   3374],
                        [  4947,   4032],
                        [  5565,   4671],
                        [  6156,   5286],
                        [  6716,   5872],
                        [  7241,   6426],
                        [  7722,   6944],
                        [  8158,   7424],
                        [  8538,   7861],
                        [  8858,   8251],
                        [  9122,   8596],
                        [  9320,   8886],
                        [  9440,   9098],
                        [  9478,   9231],
                        [  9452,   9290],
                        [  9354,   9271],
                        [  9155,   9141],
                        [  8805,   8851],
                        [  8301,   8397],
                        [  7695,   7835],
                        [  7015,   7189],
                        [  6264,   6463],
                        [  5459,   5678],
                        [  4619,   4849],
                        [  3755,   3989],
                        [  2878,   3112],
                        [  2004,   2231],
                        [  1142,   1358],
                        [   307,    505],
                        [  -496,   -320],
                        [ -1253,  -1111],
                        [ -1958,  -1858],
                        [ -2607,  -2566],
                        [ -3195,  -3229],
                        [ -3716,  -3846],
                        [ -4170,  -4417],
                        [ -4559,  -4938],
                        [ -4881,  -5408],
                        [ -5139,  -5817],
                        [ -5333,  -6164],
                        [ -5467,  -6442],
                        [ -5543,  -6652],
                        [ -5563,  -6787],
                        [ -5533,  -6850],
                        [ -5457,  -6841],
                        [ -5337,  -6764],
                        [ -5181,  -6627],
                        [ -4991,  -6432],
                        [ -4774,  -6197],
                        [ -4534,  -5924],
                        [ -4277,  -5625],
                        [ -4006,  -5302],
                        [ -3725,  -4960],
                        [ -3437,  -4604],
                        [ -3146,  -4240],
                        [ -2856,  -3871],
                        [ -2571,  -3503],
                        [ -2295,  -3140],
                        [ -2032,  -2785],
                        [ -1785,  -2445],
                        [ -1558,  -2121],
                        [ -1353,  -1818],
                        [ -1172,  -1540],
                        [ -1019,  -1289],
                        [  -891,  -1066],
                        [  -792,   -874],
                        [  -717,   -717],
                        [  -666,   -595],
                        [  -635,   -509],
                        [  -627,   -462],
                        [  -638,   -453],
                        [  -669,   -481],
                        [  -726,   -548],
                        [  -811,   -655],
                        [  -930,   -798],
                        [ -1081,   -978],
                        [ -1268,  -1194],
                        [ -1488,  -1444],
                        [ -1740,  -1726],
                        [ -2022,  -2037],
                        [ -2335,  -2377],
                        [ -2680,  -2746],
                        [ -3051,  -3137],
                        [ -3445,  -3549],
                        [ -3855,  -3972],
                        [ -4280,  -4407],
                        [ -4673,  -4806],
                        [ -5032,  -5168],
                        [ -5324,  -5459],
                        [ -5549,  -5680],
                        [ -5696,  -5819],
                        [ -5764,  -5877],
                        [ -5805,  -5905],
                        [ -5813,  -5899],
                        [ -5842,  -5913],
                        [ -5888,  -5944],
                        [ -5955,  -5995],
                        [ -6039,  -6062],
                        [ -6145,  -6151],
                        [ -6270,  -6259],
                        [ -6415,  -6385],
                        [ -6578,  -6529],
                        [ -6756,  -6689],
                        [ -6949,  -6862],
                        [ -7153,  -7044],
                        [ -7369,  -7239],
                        [ -7592,  -7438],
                        [ -7820,  -7646],
                        [ -8050,  -7854],
                        [ -8282,  -8065],
                        [ -8509,  -8274],
                        [ -8733,  -8479],
                        [ -8951,  -8679],
                        [ -9162,  -8874],
                        [ -9366,  -9062],
                        [ -9564,  -9245],
                        [ -9756,  -9423],
                        [ -9941,  -9594],
                        [-10120,  -9761],
                        [-10291,  -9922],
                        [-10455, -10077],
                        [-10612, -10225],
                        [-10762, -10367],
                        [-10905, -10502],
                        [-11038, -10629],
                        [-11162, -10749],
                        [-11278, -10860],
                        [-11386, -10963],
                        [-11478, -11055],
                        [-11559, -11138],
                        [-11616, -11209],
                        [-11647, -11268],
                        [-11651, -11312],
                        [-11628, -11343],
                        [-11577, -11357],
                        [-11501, -11356],
                        [-11434, -11360],
                        [-11385, -11381],
                        [-11350, -11408],
                        [-11298, -11415],
                        [-11175, -11343],
                        [-10948, -11161],
                        [-10632, -10886],
                        [-10246, -10534],
                        [ -9791, -10109],
                        [ -9279,  -9622],
                        [ -8721,  -9085],
                        [ -8128,  -8511],
                        [ -7507,  -7904],
                        [ -6868,  -7278],
                        [ -6221,  -6643],
                        [ -5575,  -6004],
                        [ -4934,  -5367],
                        [ -4306,  -4740],
                        [ -3699,  -4124],
                        [ -3114,  -3524],
                        [ -2559,  -2937],
                        [ -2035,  -2365],
                        [ -1542,  -1809],
                        [ -1083,  -1271],
                        [  -657,   -752],
                        [  -262,   -254],
                        [   102,    214],
                        [   433,    650],
                        [   736,   1047],
                        [  1012,   1408],
                        [  1261,   1724],
                        [  1486,   1996],
                        [  1688,   2225],
                        [  1869,   2414],
                        [  2028,   2568],
                        [  2171,   2693],
                        [  2299,   2796],
                        [  2411,   2879],
                        [  2507,   2944],
                        [  2592,   2992],
                        [  2659,   3024],
                        [  2713,   3040],
                        [  2750,   3043],
                        [  2773,   3030],
                        [  2781,   3003],
                        [  2775,   2964],
                        [  2754,   2910],
                        [  2718,   2843],
                        [  2667,   2764],
                        [  2601,   2672],
                        [  2519,   2567],
                        [  2419,   2448],
                        [  2302,   2318],
                        [  2164,   2173],
                        [  2004,   2017],
                        [  1822,   1848],
                        [  1615,   1667],
                        [  1385,   1476],
                        [  1130,   1273],
                        [   853,   1060],
                        [   562,    838],
                        [   256,    608],
                        [   -55,    371],
                        [  -373,    129],
                        [  -691,   -117],
                        [ -1010,   -365],
                        [ -1324,   -614],
                        [ -1630,   -861],
                        [ -1922,  -1103],
                        [ -2201,  -1338],
                        [ -2465,  -1567],
                        [ -2712,  -1789],
                        [ -2957,  -2019],
                        [ -3199,  -2255],
                        [ -3475,  -2534],
                        [ -3782,  -2854],
                        [ -4130,  -3224],
                        [ -4515,  -3641],
                        [ -4930,  -4095],
                        [ -5375,  -4587],
                        [ -5776,  -5043],
                        [ -6137,  -5464],
                        [ -6438,  -5832],
                        [ -6681,  -6145],
                        [ -6856,  -6394],
                        [ -6964,  -6580],
                        [ -7001,  -6697],
                        [ -6969,  -6747],
                        [ -6866,  -6728],
                        [ -6693,  -6637],
                        [ -6455,  -6481],
                        [ -6151,  -6261],
                        [ -5788,  -5980],
                        [ -5367,  -5639],
                        [ -4896,  -5246],
                        [ -4377,  -4801],
                        [ -3819,  -4314],
                        [ -3226,  -3787],
                        [ -2604,  -3229],
                        [ -1960,  -2642],
                        [ -1298,  -2034],
                        [  -624,  -1408],
                        [    55,   -772],
                        [   739,   -128],
                        [  1418,    519],
                        [  2090,   1164],
                        [  2746,   1800],
                        [  3387,   2424],
                        [  4002,   3028],
                        [  4591,   3611],
                        [  5147,   4165],
                        [  5669,   4687],
                        [  6151,   5174],
                        [  6591,   5623],
                        [  6984,   6027],
                        [  7329,   6386],
                        [  7615,   6697],
                        [  7841,   6957],
                        [  8000,   7164],
                        [  8091,   7317],
                        [  8113,   7414],
                        [  8070,   7460],
                        [  8006,   7484],
                        [  7956,   7526],
                        [  7946,   7599],
                        [  7971,   7698],
                        [  8008,   7800],
                        [  8001,   7849],
                        [  7888,   7782],
                        [  7662,   7592],
                        [  7337,   7292],
                        [  6918,   6889],
                        [  6420,   6398],
                        [  5856,   5831],
                        [  5237,   5202],
                        [  4576,   4523],
                        [  3885,   3808],
                        [  3178,   3069],
                        [  2464,   2318],
                        [  1753,   1565],
                        [  1056,    821],
                        [   384,     93],
                        [  -258,   -612],
                        [  -860,  -1290],
                        [ -1420,  -1936],
                        [ -1929,  -2543],
                        [ -2388,  -3114],
                        [ -2793,  -3642],
                        [ -3144,  -4123],
                        [ -3441,  -4557],
                        [ -3686,  -4934],
                        [ -3881,  -5254],
                        [ -4027,  -5511],
                        [ -4127,  -5707],
                        [ -4186,  -5838],
                        [ -4206,  -5909],
                        [ -4190,  -5923],
                        [ -4145,  -5886],
                        [ -4076,  -5811],
                        [ -3985,  -5702],
                        [ -3881,  -5571],
                        [ -3766,  -5420],
                        [ -3644,  -5255],
                        [ -3520,  -5078],
                        [ -3397,  -4899],
                        [ -3279,  -4719],
                        [ -3169,  -4542],
                        [ -3070,  -4373],
                        [ -2989,  -4217],
                        [ -2925,  -4076],
                        [ -2882,  -3954],
                        [ -2862,  -3852],
                        [ -2866,  -3777],
                        [ -2894,  -3726],
                        [ -2948,  -3703],
                        [ -3027,  -3709],
                        [ -3130,  -3743],
                        [ -3258,  -3809],
                        [ -3408,  -3904],
                        [ -3580,  -4028],
                        [ -3768,  -4182],
                        [ -3971,  -4362],
                        [ -4185,  -4569],
                        [ -4412,  -4800],
                        [ -4650,  -5053],
                        [ -4900,  -5327],
                        [ -5160,  -5618],
                        [ -5429,  -5924],
                        [ -5706,  -6242],
                        [ -5987,  -6569],
                        [ -6274,  -6903],
                        [ -6566,  -7244],
                        [ -6858,  -7586],
                        [ -7148,  -7923],
                        [ -7428,  -8250],
                        [ -7698,  -8565],
                        [ -7925,  -8832],
                        [ -8107,  -9052],
                        [ -8227,  -9205],
                        [ -8283,  -9291],
                        [ -8261,  -9294],
                        [ -8160,  -9213],
                        [ -8013,  -9081],
                        [ -7817,  -8895],
                        [ -7616,  -8699],
                        [ -7404,  -8488],
                        [ -7193,  -8272],
                        [ -6979,  -8049],
                        [ -6775,  -7831],
                        [ -6578,  -7615],
                        [ -6393,  -7408],
                        [ -6222,  -7213],
                        [ -6068,  -7030],
                        [ -5930,  -6861],
                        [ -5810,  -6707],
                        [ -5709,  -6568],
                        [ -5627,  -6445],
                        [ -5564,  -6338],
                        [ -5519,  -6245],
                        [ -5491,  -6169],
                        [ -5479,  -6105],
                        [ -5483,  -6056],
                        [ -5500,  -6017],
                        [ -5531,  -5991],
                        [ -5573,  -5976],
                        [ -5627,  -5974],
                        [ -5692,  -5982],
                        [ -5768,  -6000],
                        [ -5852,  -6029],
                        [ -5943,  -6066],
                        [ -6039,  -6109],
                        [ -6139,  -6160],
                        [ -6240,  -6214],
                        [ -6342,  -6271],
                        [ -6442,  -6327],
                        [ -6537,  -6383],
                        [ -6627,  -6436],
                        [ -6706,  -6483],
                        [ -6771,  -6524],
                        [ -6820,  -6554],
                        [ -6840,  -6572],
                        [ -6830,  -6576],
                        [ -6788,  -6564],
                        [ -6706,  -6530],
                        [ -6602,  -6487],
                        [ -6533,  -6492],
                        [ -6556,  -6588],
                        [ -6684,  -6789],
                        [ -6913,  -7087],
                        [ -7222,  -7464],
                        [ -7547,  -7851],
                        [ -7796,  -8157],
                        [ -7929,  -8342],
                        [ -7954,  -8413],
                        [ -7874,  -8374],
                        [ -7695,  -8229],
                        [ -7425,  -7987],
                        [ -7069,  -7655],
                        [ -6637,  -7240],
                        [ -6137,  -6753],
                        [ -5578,  -6203],
                        [ -4969,  -5597],
                        [ -4318,  -4945],
                        [ -3634,  -4257],
                        [ -2924,  -3537],
                        [ -2198,  -2794],
                        [ -1465,  -2036],
                        [  -732,  -1269],
                        [    -7,   -499],
                        [   704,    271],
                        [  1399,   1038],
                        [  2072,   1797],
                        [  2719,   2540],
                        [  3339,   3263],
                        [  3928,   3954],
                        [  4483,   4613],
                        [  5005,   5228],
                        [  5491,   5796],
                        [  5939,   6315],
                        [  6349,   6784],
                        [  6719,   7203],
                        [  7051,   7573],
                        [  7344,   7905],
                        [  7600,   8196],
                        [  7819,   8447],
                        [  8002,   8660],
                        [  8147,   8834],
                        [  8256,   8969],
                        [  8329,   9068],
                        [  8367,   9131],
                        [  8372,   9159],
                        [  8346,   9154],
                        [  8288,   9117],
                        [  8202,   9049],
                        [  8088,   8951],
                        [  7947,   8827],
                        [  7781,   8678],
                        [  7592,   8504],
                        [  7382,   8309],
                        [  7153,   8094],
                        [  6910,   7862],
                        [  6653,   7614],
                        [  6382,   7352],
                        [  6102,   7080],
                        [  5808,   6798],
                        [  5502,   6510],
                        [  5186,   6217],
                        [  4862,   5923],
                        [  4535,   5630],
                        [  4209,   5339],
                        [  3887,   5055],
                        [  3571,   4776],
                        [  3266,   4508],
                        [  2975,   4253],
                        [  2706,   4014],
                        [  2455,   3791],
                        [  2228,   3586],
                        [  2023,   3399],
                        [  1833,   3218],
                        [  1658,   3049],
                        [  1483,   2872],
                        [  1311,   2693],
                        [  1132,   2499],
                        [   948,   2295],
                        [   750,   2069],
                        [   536,   1821],
                        [   349,   1595],
                        [   187,   1387],
                        [    61,   1211],
                        [   -28,   1067],
                        [   -72,    965],
                        [   -71,    904],
                        [   -22,    890],
                        [    74,    921],
                        [   219,   1002],
                        [   413,   1130],
                        [   651,   1307],
                        [   932,   1527],
                        [  1254,   1788],
                        [  1614,   2089],
                        [  2006,   2423],
                        [  2429,   2789],
                        [  2872,   3176],
                        [  3337,   3586],
                        [  3815,   4010],
                        [  4301,   4444],
                        [  4789,   4884],
                        [  5276,   5324],
                        [  5755,   5759],
                        [  6224,   6186],
                        [  6677,   6600],
                        [  7110,   6998],
                        [  7520,   7374],
                        [  7902,   7727],
                        [  8252,   8049],
                        [  8568,   8341],
                        [  8848,   8597],
                        [  9089,   8816],
                        [  9288,   8995],
                        [  9445,   9133],
                        [  9555,   9229],
                        [  9619,   9282],
                        [  9630,   9289],
                        [  9586,   9252],
                        [  9487,   9171],
                        [  9332,   9046],
                        [  9115,   8873],
                        [  8870,   8682],
                        [  8685,   8553],
                        [  8614,   8542],
                        [  8680,   8660],
                        [  8881,   8909],
                        [  9214,   9281],
                        [  9609,   9710],
                        [  9950,  10077],
                        [ 10186,  10331],
                        [ 10324,  10479],
                        [ 10370,  10526],
                        [ 10328,  10476],
                        [ 10205,  10338],
                        [ 10008,  10121],
                        [  9747,   9830],
                        [  9427,   9476],
                        [  9059,   9070],
                        [  8651,   8620],
                        [  8210,   8135],
                        [  7744,   7625],
                        [  7261,   7097],
                        [  6771,   6560],
                        [  6278,   6022],
                        [  5795,   5491],
                        [  5324,   4972],
                        [  4872,   4464],
                        [  4441,   3972],
                        [  4033,   3494],
                        [  3651,   3034],
                        [  3292,   2596],
                        [  2960,   2182],
                        [  2652,   1799],
                        [  2368,   1447],
                        [  2108,   1131],
                        [  1869,    848],
                        [  1649,    598],
                        [  1448,    379],
                        [  1261,    181],
                        [  1086,      6],
                        [   918,   -160],
                        [   756,   -316],
                        [   596,   -463],
                        [   436,   -606],
                        [   272,   -748],
                        [   106,   -892],
                        [   -67,  -1038],
                        [  -249,  -1190],
                        [  -440,  -1350],
                        [  -642,  -1519],
                        [  -855,  -1698],
                        [ -1080,  -1889],
                        [ -1315,  -2092],
                        [ -1563,  -2308],
                        [ -1821,  -2537],
                        [ -2090,  -2778],
                        [ -2370,  -3030],
                        [ -2662,  -3292],
                        [ -2966,  -3564],
                        [ -3281,  -3843],
                        [ -3598,  -4128],
                        [ -3917,  -4417],
                        [ -4226,  -4706],
                        [ -4524,  -4996],
                        [ -4805,  -5281],
                        [ -5069,  -5562],
                        [ -5314,  -5833],
                        [ -5539,  -6095],
                        [ -5743,  -6342],
                        [ -5922,  -6574],
                        [ -6080,  -6788],
                        [ -6216,  -6985],
                        [ -6326,  -7160],
                        [ -6409,  -7308],
                        [ -6465,  -7430],
                        [ -6491,  -7521],
                        [ -6481,  -7573],
                        [ -6433,  -7586],
                        [ -6348,  -7556],
                        [ -6226,  -7486],
                        [ -6047,  -7353],
                        [ -5810,  -7157],
                        [ -5522,  -6903],
                        [ -5182,  -6589],
                        [ -4815,  -6241],
                        [ -4419,  -5857],
                        [ -4009,  -5450],
                        [ -3583,  -5020],
                        [ -3156,  -4581],
                        [ -2726,  -4132],
                        [ -2306,  -3689],
                        [ -1895,  -3248],
                        [ -1501,  -2822],
                        [ -1125,  -2410],
                        [  -774,  -2018],
                        [  -445,  -1645],
                        [  -145,  -1297],
                        [   125,   -972],
                        [   367,   -672],
                        [   577,   -399],
                        [   757,   -150],
                        [   906,     71],
                        [  1028,    266],
                        [  1122,    436],
                        [  1191,    581],
                        [  1237,    704],
                        [  1260,    804],
                        [  1263,    884],
                        [  1250,    947],
                        [  1223,    990],
                        [  1184,   1021],
                        [  1136,   1040],
                        [  1082,   1051],
                        [  1025,   1057],
                        [   971,   1060],
                        [   918,   1061],
                        [   876,   1068],
                        [   843,   1078],
                        [   828,   1097],
                        [   834,   1128],
                        [   871,   1174],
                        [   934,   1233],
                        [  1034,   1315],
                        [  1175,   1423],
                        [  1315,   1518],
                        [  1364,   1508],
                        [  1259,   1341],
                        [   994,   1013],
                        [   564,    522],
                        [   -30,   -133],
                        [  -713,   -874],
                        [ -1343,  -1559],
                        [ -1857,  -2121],
                        [ -2256,  -2566],
                        [ -2545,  -2891],
                        [ -2719,  -3096],
                        [ -2783,  -3184],
                        [ -2739,  -3157],
                        [ -2594,  -3021],
                        [ -2352,  -2782],
                        [ -2022,  -2450],
                        [ -1610,  -2030],
                        [ -1124,  -1533],
                        [  -573,   -968],
                        [    34,   -345],
                        [   687,    327],
                        [  1372,   1030],
                        [  2081,   1757],
                        [  2800,   2502],
                        [  3522,   3252],
                        [  4240,   4011],
                        [  4947,   4770],
                        [  5636,   5527],
                        [  6303,   6274],
                        [  6940,   7000],
                        [  7544,   7701],
                        [  8111,   8366],
                        [  8637,   8990],
                        [  9119,   9567],
                        [  9553,  10095],
                        [  9938,  10571],
                        [ 10273,  10994],
                        [ 10558,  11367],
                        [ 10793,  11689],
                        [ 10980,  11961],
                        [ 11118,  12184],
                        [ 11211,  12357],
                        [ 11259,  12482],
                        [ 11262,  12561],
                        [ 11224,  12595],
                        [ 11148,  12586],
                        [ 11035,  12537],
                        [ 10888,  12449],
                        [ 10710,  12325],
                        [ 10505,  12169],
                        [ 10273,  11983],
                        [ 10021,  11771],
                        [  9748,  11535],
                        [  9463,  11280],
                        [  9169,  11009],
                        [  8876,  10723],
                        [  8586,  10428],
                        [  8303,  10125],
                        [  8029,   9818],
                        [  7759,   9510],
                        [  7494,   9204],
                        [  7227,   8903],
                        [  6962,   8608],
                        [  6702,   8324],
                        [  6446,   8051],
                        [  6199,   7792],
                        [  5962,   7549],
                        [  5740,   7323],
                        [  5532,   7117],
                        [  5344,   6932],
                        [  5175,   6769],
                        [  5025,   6626],
                        [  4898,   6506],
                        [  4794,   6408],
                        [  4713,   6334],
                        [  4666,   6293],
                        [  4652,   6282],
                        [  4662,   6294],
                        [  4695,   6326],
                        [  4720,   6348],
                        [  4739,   6361],
                        [  4755,   6367],
                        [  4763,   6362],
                        [  4774,   6356],
                        [  4786,   6348],
                        [  4805,   6344],
                        [  4831,   6343],
                        [  4869,   6353],
                        [  4916,   6371],
                        [  4977,   6403],
                        [  5050,   6448],
                        [  5134,   6506],
                        [  5230,   6576],
                        [  5338,   6658],
                        [  5454,   6749],
                        [  5579,   6846],
                        [  5709,   6945],
                        [  5843,   7046],
                        [  5980,   7147],
                        [  6114,   7242],
                        [  6245,   7332],
                        [  6367,   7412],
                        [  6478,   7482],
                        [  6576,   7535],
                        [  6658,   7573],
                        [  6720,   7590],
                        [  6763,   7588],
                        [  6784,   7563],
                        [  6782,   7514],
                        [  6754,   7438],
                        [  6702,   7337],
                        [  6623,   7209],
                        [  6517,   7053],
                        [  6383,   6869],
                        [  6223,   6658],
                        [  6034,   6422],
                        [  5818,   6162],
                        [  5572,   5876],
                        [  5297,   5568],
                        [  4995,   5241],
                        [  4666,   4894],
                        [  4302,   4522],
                        [  3965,   4187],
                        [  3762,   3990],
                        [  3742,   3980],
                        [  3916,   4164],
                        [  4297,   4554],
                        [  4895,   5159],
                        [  5635,   5905],
                        [  6365,   6638],
                        [  7017,   7289],
                        [  7596,   7863],
                        [  8101,   8357],
                        [  8526,   8769],
                        [  8869,   9094],
                        [  9133,   9336],
                        [  9320,   9498],
                        [  9430,   9580],
                        [  9468,   9589],
                        [  9434,   9528],
                        [  9334,   9403],
                        [  9172,   9220],
                        [  8954,   8985],
                        [  8686,   8710],
                        [  8375,   8400],
                        [  8032,   8067],
                        [  7662,   7715],
                        [  7269,   7342],
                        [  6859,   6953],
                        [  6433,   6539],
                        [  5997,   6108],
                        [  5551,   5657],
                        [  5099,   5192],
                        [  4643,   4718],
                        [  4183,   4237],
                        [  3722,   3754],
                        [  3262,   3269],
                        [  2804,   2786],
                        [  2348,   2306],
                        [  1896,   1830],
                        [  1445,   1357],
                        [   998,    884],
                        [   553,    411],
                        [   108,    -60],
                        [  -336,   -530],
                        [  -779,   -998],
                        [ -1221,  -1466],
                        [ -1662,  -1931],
                        [ -2101,  -2396],
                        [ -2536,  -2856],
                        [ -2970,  -3315],
                        [ -3398,  -3770],
                        [ -3820,  -4219],
                        [ -4236,  -4662],
                        [ -4643,  -5098],
                        [ -5041,  -5525],
                        [ -5429,  -5943],
                        [ -5813,  -6347],
                        [ -6190,  -6739],
                        [ -6566,  -7113],
                        [ -6937,  -7472],
                        [ -7298,  -7809],
                        [ -7646,  -8125],
                        [ -7964,  -8417],
                        [ -8255,  -8684],
                        [ -8505,  -8923],
                        [ -8716,  -9133],
                        [ -8886,  -9312],
                        [ -9014,  -9460],
                        [ -9099,  -9575],
                        [ -9142,  -9655],
                        [ -9145,  -9700],
                        [ -9106,  -9712],
                        [ -9029,  -9688],
                        [ -8911,  -9628],
                        [ -8759,  -9536],
                        [ -8573,  -9410],
                        [ -8377,  -9272],
                        [ -8169,  -9123],
                        [ -7963,  -8972],
                        [ -7759,  -8821],
                        [ -7534,  -8644],
                        [ -7290,  -8444],
                        [ -6997,  -8189],
                        [ -6658,  -7881],
                        [ -6281,  -7527],
                        [ -5866,  -7128],
                        [ -5428,  -6697],
                        [ -4964,  -6234],
                        [ -4491,  -5753],
                        [ -4007,  -5256],
                        [ -3525,  -4756],
                        [ -3046,  -4253],
                        [ -2579,  -3759],
                        [ -2125,  -3278],
                        [ -1691,  -2814],
                        [ -1279,  -2369],
                        [  -892,  -1947],
                        [  -534,  -1547],
                        [  -206,  -1174],
                        [    90,   -826],
                        [   353,   -507],
                        [   587,   -215],
                        [   790,     49],
                        [   964,    284],
                        [  1113,    496],
                        [  1239,    683],
                        [  1344,    849],
                        [  1431,    996],
                        [  1503,   1126],
                        [  1562,   1241],
                        [  1612,   1346],
                        [  1656,   1441],
                        [  1698,   1532],
                        [  1740,   1621],
                        [  1785,   1711],
                        [  1837,   1803],
                        [  1900,   1902],
                        [  1975,   2009],
                        [  2067,   2126],
                        [  2179,   2256],
                        [  2314,   2402],
                        [  2468,   2560],
                        [  2654,   2741],
                        [  2871,   2944],
                        [  3056,   3105],
                        [  3110,   3127],
                        [  2992,   2971],
                        [  2696,   2636],
                        [  2206,   2104],
                        [  1504,   1362],
                        [   666,    484],
                        [  -151,   -371],
                        [  -882,  -1133],
                        [ -1529,  -1810],
                        [ -2091,  -2394],
                        [ -2557,  -2877],
                        [ -2927,  -3257],
                        [ -3200,  -3532],
                        [ -3378,  -3706],
                        [ -3461,  -3778],
                        [ -3453,  -3755],
                        [ -3360,  -3642],
                        [ -3183,  -3443],
                        [ -2932,  -3170],
                        [ -2613,  -2832],
                        [ -2236,  -2438],
                        [ -1816,  -2009],
                        [ -1358,  -1549],
                        [  -878,  -1071],
                        [  -382,   -581],
                        [   122,    -77],
                        [   625,    432],
                        [  1121,    950],
                        [  1605,   1470],
                        [  2069,   1983],
                        [  2507,   2485],
                        [  2918,   2967],
                        [  3295,   3426],
                        [  3633,   3855],
                        [  3931,   4253],
                        [  4185,   4609],
                        [  4396,   4925],
                        [  4562,   5199],
                        [  4682,   5429],
                        [  4760,   5616],
                        [  4796,   5761],
                        [  4794,   5864],
                        [  4755,   5926],
                        [  4681,   5948],
                        [  4574,   5935],
                        [  4439,   5887],
                        [  4277,   5808],
                        [  4093,   5699],
                        [  3888,   5565],
                        [  3667,   5407],
                        [  3432,   5230],
                        [  3187,   5038],
                        [  2936,   4831],
                        [  2687,   4616],
                        [  2443,   4395],
                        [  2218,   4171],
                        [  2015,   3946],
                        [  1836,   3725],
                        [  1685,   3507],
                        [  1553,   3297],
                        [  1442,   3097],
                        [  1338,   2909],
                        [  1243,   2733],
                        [  1155,   2572],
                        [  1074,   2427],
                        [  1001,   2298],
                        [   935,   2186],
                        [   878,   2091],
                        [   830,   2013],
                        [   791,   1952],
                        [   761,   1909],
                        [   740,   1880],
                        [   728,   1867],
                        [   745,   1887],
                        [   787,   1939],
                        [   886,   2050],
                        [  1035,   2217],
                        [  1229,   2429],
                        [  1464,   2687],
                        [  1692,   2937],
                        [  1913,   3182],
                        [  2094,   3386],
                        [  2237,   3550],
                        [  2345,   3678],
                        [  2416,   3766],
                        [  2455,   3821],
                        [  2461,   3840],
                        [  2440,   3830],
                        [  2390,   3790],
                        [  2316,   3726],
                        [  2218,   3638],
                        [  2101,   3531],
                        [  1963,   3404],
                        [  1811,   3261],
                        [  1641,   3100],
                        [  1462,   2923],
                        [  1268,   2728],
                        [  1068,   2520],
                        [   859,   2295],
                        [   642,   2059],
                        [   418,   1810],
                        [   185,   1549],
                        [   -56,   1277],
                        [  -306,    994],
                        [  -564,    699],
                        [  -829,    392],
                        [ -1103,     75],
                        [ -1382,   -252],
                        [ -1667,   -588],
                        [ -1959,   -934],
                        [ -2255,  -1287],
                        [ -2554,  -1646],
                        [ -2856,  -2010],
                        [ -3161,  -2379],
                        [ -3466,  -2750],
                        [ -3772,  -3120],
                        [ -4075,  -3488],
                        [ -4376,  -3855],
                        [ -4673,  -4214],
                        [ -4961,  -4565],
                        [ -5246,  -4910],
                        [ -5530,  -5247],
                        [ -5737,  -5502],
                        [ -5783,  -5588],
                        [ -5635,  -5473],
                        [ -5289,  -5156],
                        [ -4721,  -4613],
                        [ -3909,  -3822],
                        [ -2923,  -2854],
                        [ -1914,  -1861],
                        [  -947,   -908],
                        [   -16,      7],
                        [   866,    876],
                        [  1686,   1683],
                        [  2438,   2420],
                        [  3114,   3082],
                        [  3712,   3665],
                        [  4223,   4164],
                        [  4649,   4578],
                        [  4982,   4904],
                        [  5226,   5146],
                        [  5380,   5306],
                        [  5445,   5384],
                        [  5428,   5395],
                        [  5333,   5342],
                        [  5169,   5236],
                        [  4941,   5078],
                        [  4653,   4870],
                        [  4312,   4617],
                        [  3921,   4305],
                        [  3486,   3943],
                        [  3010,   3527],
                        [  2499,   3062],
                        [  1957,   2554],
                        [  1389,   2004],
                        [   801,   1419],
                        [   194,    800],
                        [  -423,    159],
                        [ -1050,   -504],
                        [ -1679,  -1178],
                        [ -2311,  -1861],
                        [ -2939,  -2549],
                        [ -3563,  -3239],
                        [ -4181,  -3925],
                        [ -4791,  -4609],
                        [ -5392,  -5284],
                        [ -5978,  -5948],
                        [ -6549,  -6598],
                        [ -7102,  -7234],
                        [ -7635,  -7850],
                        [ -8147,  -8447],
                        [ -8634,  -9018],
                        [ -9095,  -9565],
                        [ -9528, -10082],
                        [ -9930, -10571],
                        [-10304, -11026],
                        [-10646, -11448],
                        [-10966, -11835],
                        [-11264, -12185],
                        [-11544, -12496],
                        [-11806, -12769],
                        [-12048, -13001],
                        [-12266, -13192],
                        [-12447, -13340],
                        [-12590, -13447],
                        [-12683, -13512],
                        [-12726, -13534],
                        [-12720, -13514],
                        [-12664, -13454],
                        [-12562, -13353],
                        [-12412, -13213],
                        [-12216, -13035],
                        [-11976, -12819],
                        [-11698, -12569],
                        [-11382, -12285],
                        [-11041, -11980],
                        [-10678, -11656],
                        [-10340, -11359],
                        [-10027, -11088],
                        [ -9757, -10860],
                        [ -9530, -10675],
                        [ -9323, -10510],
                        [ -9141, -10367],
                        [ -8920, -10181],
                        [ -8667,  -9958],
                        [ -8374,  -9692],
                        [ -8045,  -9384],
                        [ -7685,  -9041],
                        [ -7300,  -8666],
                        [ -6895,  -8267],
                        [ -6472,  -7846],
                        [ -6042,  -7414],
                        [ -5604,  -6971],
                        [ -5167,  -6530],
                        [ -4730,  -6088],
                        [ -4301,  -5655],
                        [ -3882,  -5228],
                        [ -3477,  -4815],
                        [ -3085,  -4413],
                        [ -2713,  -4026],
                        [ -2360,  -3652],
                        [ -2027,  -3296],
                        [ -1715,  -2956],
                        [ -1420,  -2633],
                        [ -1143,  -2327],
                        [  -879,  -2035],
                        [  -629,  -1758],
                        [  -388,  -1491],
                        [  -156,  -1233],
                        [    71,   -982],
                        [   293,   -735],
                        [   513,   -491],
                        [   733,   -247],
                        [   956,      0],
                        [  1181,    249],
                        [  1414,    503],
                        [  1653,    764],
                        [  1901,   1034],
                        [  2158,   1308],
                        [  2422,   1593],
                        [  2697,   1887],
                        [  2978,   2190],
                        [  3261,   2498],
                        [  3558,   2819],
                        [  3863,   3147],
                        [  4110,   3411],
                        [  4226,   3538],
                        [  4193,   3512],
                        [  4008,   3329],
                        [  3638,   2959],
                        [  3051,   2371],
                        [  2309,   1627],
                        [  1545,    861],
                        [   810,    127],
                        [   100,   -581],
                        [  -576,  -1250],
                        [ -1203,  -1868],
                        [ -1777,  -2428],
                        [ -2295,  -2927],
                        [ -2750,  -3359],
                        [ -3141,  -3722],
                        [ -3465,  -4016],
                        [ -3722,  -4244],
                        [ -3912,  -4405],
                        [ -4038,  -4503],
                        [ -4106,  -4550],
                        [ -4117,  -4550],
                        [ -4084,  -4518],
                        [ -4012,  -4461],
                        [ -3910,  -4385],
                        [ -3783,  -4297],
                        [ -3636,  -4190],
                        [ -3476,  -4073],
                        [ -3308,  -3936],
                        [ -3138,  -3785],
                        [ -2969,  -3621],
                        [ -2806,  -3450],
                        [ -2653,  -3271],
                        [ -2513,  -3089],
                        [ -2389,  -2907],
                        [ -2284,  -2729],
                        [ -2200,  -2563],
                        [ -2139,  -2408],
                        [ -2100,  -2273],
                        [ -2086,  -2159],
                        [ -2090,  -2062],
                        [ -2116,  -1987],
                        [ -2159,  -1932],
                        [ -2217,  -1893],
                        [ -2288,  -1872],
                        [ -2372,  -1866],
                        [ -2464,  -1873],
                        [ -2564,  -1892],
                        [ -2667,  -1919],
                        [ -2774,  -1954],
                        [ -2880,  -1995],
                        [ -2984,  -2039],
                        [ -3081,  -2083],
                        [ -3172,  -2126],
                        [ -3248,  -2166],
                        [ -3308,  -2201],
                        [ -3337,  -2230],
                        [ -3335,  -2250],
                        [ -3298,  -2261],
                        [ -3227,  -2263],
                        [ -3129,  -2253],
                        [ -3001,  -2231],
                        [ -2866,  -2199],
                        [ -2721,  -2154],
                        [ -2572,  -2099],
                        [ -2420,  -2032],
                        [ -2268,  -1956],
                        [ -2117,  -1870],
                        [ -1968,  -1776],
                        [ -1826,  -1677],
                        [ -1689,  -1574],
                        [ -1559,  -1467],
                        [ -1436,  -1357],
                        [ -1320,  -1246],
                        [ -1179,  -1098],
                        [ -1012,   -917],
                        [  -786,   -670],
                        [  -501,   -356],
                        [  -167,     13],
                        [   219,    438],
                        [   593,    855],
                        [   955,   1263],
                        [  1253,   1610],
                        [  1489,   1896],
                        [  1665,   2119],
                        [  1778,   2280],
                        [  1831,   2378],
                        [  1824,   2415],
                        [  1762,   2394],
                        [  1643,   2316],
                        [  1476,   2187],
                        [  1258,   2008],
                        [  1000,   1787],
                        [   699,   1521],
                        [   365,   1220],
                        [    -3,    883],
                        [  -396,    515],
                        [  -812,    117],
                        [ -1244,   -306],
                        [ -1691,   -752],
                        [ -2148,  -1213],
                        [ -2614,  -1690],
                        [ -3085,  -2177],
                        [ -3561,  -2672],
                        [ -4039,  -3171],
                        [ -4516,  -3674],
                        [ -4990,  -4179],
                        [ -5459,  -4682],
                        [ -5919,  -5181],
                        [ -6368,  -5674],
                        [ -6807,  -6160],
                        [ -7230,  -6633],
                        [ -7637,  -7093],
                        [ -8025,  -7538],
                        [ -8393,  -7965],
                        [ -8740,  -8372],
                        [ -9060,  -8756],
                        [ -9354,  -9115],
                        [ -9616,  -9448],
                        [ -9843,  -9752],
                        [-10035, -10025],
                        [-10198, -10270],
                        [-10328, -10480],
                        [-10366, -10593],
                        [-10268, -10559],
                        [-10027, -10374],
                        [ -9639, -10033],
                        [ -9072,  -9504],
                        [ -8291,  -8754],
                        [ -7344,  -7831],
                        [ -6347,  -6851],
                        [ -5344,  -5860],
                        [ -4336,  -4858],
                        [ -3339,  -3862],
                        [ -2372,  -2892],
                        [ -1445,  -1959],
                        [  -570,  -1075],
                        [   245,   -248],
                        [   989,    510],
                        [  1653,   1194],
                        [  2233,   1799],
                        [  2723,   2320],
                        [  3120,   2756],
                        [  3426,   3108],
                        [  3638,   3384],
                        [  3762,   3586],
                        [  3803,   3722],
                        [  3764,   3794],
                        [  3650,   3801],
                        [  3464,   3750],
                        [  3213,   3627],
                        [  2900,   3439],
                        [  2533,   3182],
                        [  2116,   2862],
                        [  1656,   2478],
                        [  1159,   2038],
                        [   633,   1542],
                        [    80,    996],
                        [  -488,    413],
                        [ -1069,   -206],
                        [ -1656,   -843],
                        [ -2243,  -1496],
                        [ -2826,  -2152],
                        [ -3399,  -2809],
                        [ -3960,  -3460],
                        [ -4505,  -4102],
                        [ -5031,  -4730],
                        [ -5533,  -5337],
                        [ -6009,  -5922],
                        [ -6455,  -6481],
                        [ -6871,  -7009],
                        [ -7251,  -7506],
                        [ -7595,  -7966],
                        [ -7902,  -8387],
                        [ -8169,  -8767],
                        [ -8396,  -9105],
                        [ -8585,  -9400],
                        [ -8733,  -9649],
                        [ -8852,  -9854],
                        [ -8942, -10012],
                        [ -9009, -10125],
                        [ -9055, -10191],
                        [ -9080, -10212],
                        [ -9085, -10190],
                        [ -9057, -10123],
                        [ -8999, -10013],
                        [ -8899,  -9864],
                        [ -8759,  -9676],
                        [ -8578,  -9451],
                        [ -8361,  -9192],
                        [ -8106,  -8902],
                        [ -7816,  -8581],
                        [ -7493,  -8232],
                        [ -7139,  -7858],
                        [ -6758,  -7462],
                        [ -6355,  -7049],
                        [ -5950,  -6639],
                        [ -5542,  -6231],
                        [ -5192,  -5885],
                        [ -4898,  -5598],
                        [ -4678,  -5389],
                        [ -4531,  -5258],
                        [ -4440,  -5182],
                        [ -4403,  -5165],
                        [ -4343,  -5124],
                        [ -4264,  -5066],
                        [ -4152,  -4975],
                        [ -4009,  -4852],
                        [ -3835,  -4698],
                        [ -3630,  -4513],
                        [ -3400,  -4301],
                        [ -3144,  -4063],
                        [ -2867,  -3804],
                        [ -2569,  -3523],
                        [ -2254,  -3228],
                        [ -1922,  -2917],
                        [ -1580,  -2598],
                        [ -1224,  -2268],
                        [  -862,  -1931],
                        [  -493,  -1586],
                        [  -123,  -1237],
                        [   250,   -882],
                        [   624,   -524],
                        [   998,   -163],
                        [  1371,    197],
                        [  1746,    560],
                        [  2123,    923],
                        [  2504,   1289],
                        [  2888,   1656],
                        [  3276,   2028],
                        [  3667,   2405],
                        [  4062,   2787],
                        [  4461,   3175],
                        [  4864,   3569],
                        [  5270,   3967],
                        [  5679,   4372],
                        [  6090,   4782],
                        [  6502,   5194],
                        [  6913,   5610],
                        [  7320,   6025],
                        [  7716,   6440],
                        [  8101,   6851],
                        [  8469,   7257],
                        [  8815,   7654],
                        [  9149,   8045],
                        [  9458,   8418],
                        [  9705,   8726],
                        [  9862,   8942],
                        [  9932,   9064],
                        [  9906,   9087],
                        [  9745,   8972],
                        [  9406,   8675],
                        [  8912,   8222],
                        [  8348,   7697],
                        [  7743,   7130],
                        [  7096,   6519],
                        [  6420,   5880],
                        [  5731,   5227],
                        [  5035,   4569],
                        [  4343,   3915],
                        [  3662,   3271],
                        [  3000,   2647],
                        [  2365,   2048],
                        [  1761,   1479],
                        [  1191,    939],
                        [   660,    436],
                        [   169,    -40],
                        [  -281,   -485],
                        [  -694,   -910],
                        [ -1070,  -1313],
                        [ -1412,  -1701],
                        [ -1723,  -2074],
                        [ -2003,  -2424],
                        [ -2255,  -2756],
                        [ -2481,  -3057],
                        [ -2684,  -3330],
                        [ -2865,  -3571],
                        [ -3028,  -3782],
                        [ -3174,  -3956],
                        [ -3304,  -4097],
                        [ -3421,  -4204],
                        [ -3527,  -4279],
                        [ -3621,  -4331],
                        [ -3707,  -4359],
                        [ -3785,  -4375],
                        [ -3854,  -4379],
                        [ -3913,  -4371],
                        [ -3967,  -4354],
                        [ -4008,  -4326],
                        [ -4039,  -4288],
                        [ -4060,  -4239],
                        [ -4068,  -4180],
                        [ -4065,  -4109],
                        [ -4049,  -4028],
                        [ -4019,  -3935],
                        [ -3976,  -3831],
                        [ -3917,  -3716],
                        [ -3843,  -3589],
                        [ -3755,  -3451],
                        [ -3651,  -3302],
                        [ -3527,  -3141],
                        [ -3384,  -2971],
                        [ -3212,  -2789],
                        [ -3010,  -2598],
                        [ -2780,  -2399],
                        [ -2522,  -2192],
                        [ -2238,  -1978],
                        [ -1931,  -1759],
                        [ -1620,  -1536],
                        [ -1307,  -1311],
                        [  -996,  -1085],
                        [  -692,   -860],
                        [  -398,   -637],
                        [  -116,   -419],
                        [   149,   -207],
                        [   393,     -7],
                        [   617,    181],
                        [   819,    359],
                        [  1000,    526],
                        [  1159,    681],
                        [  1341,    866],
                        [  1539,   1079],
                        [  1790,   1352],
                        [  2089,   1682],
                        [  2438,   2069],
                        [  2836,   2511],
                        [  3221,   2945],
                        [  3594,   3372],
                        [  3898,   3733],
                        [  4137,   4031],
                        [  4309,   4262],
                        [  4414,   4427],
                        [  4451,   4524],
                        [  4421,   4552],
                        [  4327,   4517],
                        [  4171,   4415],
                        [  3959,   4256],
                        [  3690,   4040],
                        [  3376,   3774],
                        [  3014,   3459],
                        [  2615,   3105],
                        [  2181,   2711],
                        [  1721,   2287],
                        [  1237,   1833],
                        [   740,   1358],
                        [   231,    863],
                        [  -284,    358],
                        [  -800,   -155],
                        [ -1314,   -669],
                        [ -1824,  -1181],
                        [ -2325,  -1686],
                        [ -2816,  -2182],
                        [ -3291,  -2667],
                        [ -3750,  -3138],
                        [ -4185,  -3590],
                        [ -4598,  -4023],
                        [ -4986,  -4433],
                        [ -5345,  -4818],
                        [ -5675,  -5175],
                        [ -5973,  -5502],
                        [ -6238,  -5800],
                        [ -6468,  -6064],
                        [ -6658,  -6293],
                        [ -6806,  -6485],
                        [ -6906,  -6643],
                        [ -6958,  -6762],
                        [ -6964,  -6843],
                        [ -6927,  -6888],
                        [ -6850,  -6890],
                        [ -6710,  -6828],
                        [ -6517,  -6702],
                        [ -6279,  -6519],
                        [ -5990,  -6275],
                        [ -5616,  -5938],
                        [ -5113,  -5462],
                        [ -4483,  -4849],
                        [ -3785,  -4159],
                        [ -3040,  -3414],
                        [ -2255,  -2621],
                        [ -1445,  -1797],
                        [  -631,   -962],
                        [   179,   -127],
                        [   970,    696],
                        [  1732,   1493],
                        [  2453,   2252],
                        [  3122,   2966],
                        [  3735,   3625],
                        [  4284,   4223],
                        [  4760,   4758],
                        [  5163,   5224],
                        [  5492,   5629],
                        [  5744,   5969],
                        [  5923,   6250],
                        [  6029,   6471],
                        [  6066,   6637],
                        [  6038,   6747],
                        [  5948,   6796],
                        [  5802,   6786],
                        [  5604,   6714],
                        [  5359,   6584],
                        [  5076,   6394],
                        [  4756,   6149],
                        [  4410,   5849],
                        [  4042,   5501],
                        [  3660,   5111],
                        [  3266,   4686],
                        [  2870,   4243],
                        [  2475,   3786],
                        [  2088,   3330],
                        [  1713,   2876],
                        [  1354,   2431],
                        [  1016,   2000],
                        [   701,   1588],
                        [   413,   1197],
                        [   154,    831],
                        [   -74,    494],
                        [  -269,    189],
                        [  -429,    -83],
                        [  -554,   -319],
                        [  -644,   -518],
                        [  -697,   -677],
                        [  -715,   -798],
                        [  -700,   -879],
                        [  -649,   -921],
                        [  -576,   -924],
                        [  -480,   -889],
                        [  -366,   -817],
                        [  -236,   -710],
                        [   -96,   -570],
                        [    53,   -397],
                        [   215,   -195],
                        [   390,     34],
                        [   585,    288],
                        [   798,    564],
                        [  1028,    858],
                        [  1273,   1168],
                        [  1534,   1492],
                        [  1808,   1827],
                        [  2096,   2173],
                        [  2395,   2528],
                        [  2701,   2882],
                        [  3010,   3236],
                        [  3303,   3568],
                        [  3577,   3875],
                        [  3782,   4106],
                        [  3920,   4264],
                        [  3976,   4333],
                        [  3950,   4315],
                        [  3859,   4224],
                        [  3698,   4058],
                        [  3551,   3900],
                        [  3410,   3743],
                        [  3296,   3608],
                        [  3205,   3491],
                        [  3146,   3402],
                        [  3119,   3341],
                        [  3126,   3310],
                        [  3167,   3311],
                        [  3243,   3343],
                        [  3354,   3408],
                        [  3499,   3505],
                        [  3681,   3634],
                        [  3894,   3793],
                        [  4139,   3982],
                        [  4414,   4199],
                        [  4717,   4444],
                        [  5044,   4713],
                        [  5397,   5010],
                        [  5769,   5328],
                        [  6160,   5668],
                        [  6571,   6026],
                        [  6998,   6403],
                        [  7440,   6793],
                        [  7898,   7198],
                        [  8367,   7616],
                        [  8847,   8046],
                        [  9335,   8487],
                        [  9828,   8937],
                        [ 10324,   9393],
                        [ 10820,   9854],
                        [ 11313,  10316],
                        [ 11800,  10779],
                        [ 12277,  11235],
                        [ 12742,  11686],
                        [ 13187,  12127],
                        [ 13609,  12553],
                        [ 13997,  12962],
                        [ 14348,  13350],
                        [ 14656,  13713],
                        [ 14917,  14047],
                        [ 15136,  14350],
                        [ 15307,  14617],
                        [ 15443,  14846],
                        [ 15560,  15056],
                        [ 15670,  15254],
                        [ 15763,  15431],
                        [ 15802,  15552],
                        [ 15736,  15562],
                        [ 15532,  15431],
                        [ 15215,  15181],
                        [ 14796,  14824],
                        [ 14279,  14366],
                        [ 13679,  13820],
                        [ 13009,  13199],
                        [ 12279,  12513],
                        [ 11498,  11773],
                        [ 10679,  10991],
                        [  9832,  10177],
                        [  8968,   9341],
                        [  8095,   8491],
                        [  7222,   7638],
                        [  6357,   6785],
                        [  5510,   5939],
                        [  4683,   5102],
                        [  3884,   4276],
                        [  3116,   3466],
                        [  2381,   2672],
                        [  1684,   1898],
                        [  1025,   1149],
                        [   406,    427],
                        [  -171,   -256],
                        [  -705,   -899],
                        [ -1198,  -1493],
                        [ -1648,  -2039],
                        [ -2055,  -2525],
                        [ -2420,  -2953],
                        [ -2745,  -3320],
                        [ -3028,  -3626],
                        [ -3271,  -3877],
                        [ -3475,  -4075],
                        [ -3641,  -4231],
                        [ -3769,  -4344],
                        [ -3863,  -4421],
                        [ -3924,  -4460],
                        [ -3954,  -4464],
                        [ -3952,  -4434],
                        [ -3921,  -4371],
                        [ -3862,  -4279],
                        [ -3777,  -4158],
                        [ -3666,  -4010],
                        [ -3533,  -3837],
                        [ -3376,  -3641],
                        [ -3200,  -3426],
                        [ -3006,  -3192],
                        [ -2794,  -2941],
                        [ -2568,  -2678],
                        [ -2326,  -2403],
                        [ -2072,  -2120],
                        [ -1802,  -1831],
                        [ -1518,  -1536],
                        [ -1221,  -1242],
                        [  -914,   -947],
                        [  -594,   -656],
                        [  -266,   -371],
                        [    59,    -93],
                        [   379,    176],
                        [   687,    433],
                        [   983,    676],
                        [  1260,    903],
                        [  1518,   1113],
                        [  1750,   1303],
                        [  1956,   1470],
                        [  2131,   1614],
                        [  2279,   1736],
                        [  2403,   1839],
                        [  2499,   1923],
                        [  2609,   2026],
                        [  2729,   2147],
                        [  2884,   2309],
                        [  3070,   2509],
                        [  3299,   2758],
                        [  3571,   3054],
                        [  3836,   3349],
                        [  4099,   3647],
                        [  4311,   3896],
                        [  4476,   4102],
                        [  4591,   4261],
                        [  4655,   4370],
                        [  4666,   4427],
                        [  4626,   4434],
                        [  4534,   4388],
                        [  4393,   4292],
                        [  4207,   4149],
                        [  3976,   3962],
                        [  3707,   3733],
                        [  3401,   3465],
                        [  3066,   3167],
                        [  2703,   2839],
                        [  2321,   2489],
                        [  1921,   2118],
                        [  1512,   1734],
                        [  1096,   1340],
                        [   681,    943],
                        [   267,    546],
                        [  -141,    156],
                        [  -540,   -226],
                        [  -925,   -595],
                        [ -1298,   -948],
                        [ -1651,  -1284],
                        [ -1984,  -1601],
                        [ -2295,  -1895],
                        [ -2580,  -2165],
                        [ -2838,  -2411],
                        [ -3069,  -2628],
                        [ -3270,  -2817],
                        [ -3441,  -2976],
                        [ -3580,  -3105],
                        [ -3685,  -3204],
                        [ -3750,  -3270],
                        [ -3775,  -3305],
                        [ -3755,  -3309],
                        [ -3690,  -3280],
                        [ -3585,  -3222],
                        [ -3438,  -3132],
                        [ -3266,  -3018],
                        [ -3103,  -2913],
                        [ -2995,  -2853],
                        [ -2953,  -2850],
                        [ -2972,  -2901],
                        [ -3026,  -2980],
                        [ -3058,  -3029],
                        [ -3010,  -2988],
                        [ -2878,  -2855],
                        [ -2671,  -2641],
                        [ -2397,  -2351],
                        [ -2068,  -2000],
                        [ -1694,  -1599],
                        [ -1288,  -1159],
                        [  -856,   -691],
                        [  -411,   -204],
                        [    38,    289],
                        [   483,    779],
                        [   917,   1260],
                        [  1332,   1722],
                        [  1720,   2160],
                        [  2077,   2571],
                        [  2399,   2953],
                        [  2680,   3302],
                        [  2921,   3619],
                        [  3121,   3902],
                        [  3280,   4154],
                        [  3400,   4376],
                        [  3482,   4563],
                        [  3528,   4718],
                        [  3543,   4837],
                        [  3529,   4922],
                        [  3490,   4968],
                        [  3430,   4977],
                        [  3354,   4948],
                        [  3265,   4884],
                        [  3166,   4790],
                        [  3062,   4669],
                        [  2956,   4535],
                        [  2853,   4391],
                        [  2754,   4249],
                        [  2667,   4113],
                        [  2593,   3985],
                        [  2535,   3868],
                        [  2496,   3765],
                        [  2478,   3680],
                        [  2481,   3612],
                        [  2507,   3567],
                        [  2555,   3543],
                        [  2625,   3542],
                        [  2718,   3564],
                        [  2832,   3610],
                        [  2966,   3679],
                        [  3121,   3772],
                        [  3292,   3887],
                        [  3480,   4024],
                        [  3678,   4180],
                        [  3888,   4356],
                        [  4104,   4547],
                        [  4325,   4752],
                        [  4544,   4969],
                        [  4758,   5197],
                        [  4964,   5431],
                        [  5162,   5670],
                        [  5353,   5912],
                        [  5536,   6153],
                        [  5710,   6391],
                        [  5875,   6626],
                        [  6032,   6853],
                        [  6178,   7071],
                        [  6320,   7282],
                        [  6451,   7483],
                        [  6572,   7668],
                        [  6680,   7838],
                        [  6760,   7973],
                        [  6812,   8075],
                        [  6807,   8111],
                        [  6746,   8086],
                        [  6620,   7987],
                        [  6429,   7815],
                        [  6179,   7576],
                        [  5866,   7265],
                        [  5553,   6945],
                        [  5238,   6615],
                        [  4938,   6290],
                        [  4652,   5974],
                        [  4395,   5678],
                        [  4165,   5402],
                        [  3969,   5155],
                        [  3810,   4939],
                        [  3690,   4760],
                        [  3612,   4617],
                        [  3577,   4515],
                        [  3587,   4457],
                        [  3641,   4439],
                        [  3738,   4464],
                        [  3877,   4530],
                        [  4058,   4636],
                        [  4275,   4780],
                        [  4530,   4961],
                        [  4814,   5175],
                        [  5130,   5421],
                        [  5471,   5693],
                        [  5837,   5991],
                        [  6221,   6309],
                        [  6624,   6645],
                        [  7038,   6996],
                        [  7462,   7358],
                        [  7888,   7727],
                        [  8316,   8101],
                        [  8738,   8476],
                        [  9152,   8848],
                        [  9552,   9211],
                        [  9933,   9561],
                        [ 10290,   9895],
                        [ 10622,  10207],
                        [ 10914,  10494],
                        [ 11168,  10753],
                        [ 11369,  10978],
                        [ 11514,  11165],
                        [ 11600,  11312],
                        [ 11625,  11416],
                        [ 11587,  11468],
                        [ 11503,  11486],
                        [ 11438,  11522],
                        [ 11439,  11623],
                        [ 11516,  11796],
                        [ 11662,  12034],
                        [ 11858,  12319],
                        [ 12038,  12580],
                        [ 12110,  12728],
                        [ 12047,  12732],
                        [ 11854,  12600],
                        [ 11538,  12337],
                        [ 11110,  11954],
                        [ 10577,  11457],
                        [  9950,  10857],
                        [  9239,  10166],
                        [  8455,   9394],
                        [  7609,   8554],
                        [  6713,   7659],
                        [  5775,   6717],
                        [  4810,   5741],
                        [  3827,   4743],
                        [  2839,   3729],
                        [  1855,   2710],
                        [   887,   1695],
                        [   -59,    691],
                        [  -973,   -293],
                        [ -1854,  -1257],
                        [ -2694,  -2192],
                        [ -3488,  -3093],
                        [ -4234,  -3955],
                        [ -4929,  -4773],
                        [ -5568,  -5536],
                        [ -6154,  -6245],
                        [ -6682,  -6884],
                        [ -7152,  -7456],
                        [ -7566,  -7955],
                        [ -7922,  -8382],
                        [ -8221,  -8738],
                        [ -8462,  -9025],
                        [ -8651,  -9256],
                        [ -8786,  -9430],
                        [ -8873,  -9551],
                        [ -8914,  -9622],
                        [ -8914,  -9646],
                        [ -8875,  -9625],
                        [ -8802,  -9564],
                        [ -8696,  -9464],
                        [ -8561,  -9329],
                        [ -8399,  -9164],
                        [ -8214,  -8972],
                        [ -8008,  -8756],
                        [ -7786,  -8520],
                        [ -7551,  -8267],
                        [ -7304,  -8002],
                        [ -7049,  -7729],
                        [ -6791,  -7449],
                        [ -6531,  -7168],
                        [ -6275,  -6888],
                        [ -6025,  -6611],
                        [ -5782,  -6342],
                        [ -5547,  -6082],
                        [ -5317,  -5835],
                        [ -5094,  -5601],
                        [ -4877,  -5383],
                        [ -4670,  -5182],
                        [ -4475,  -5000],
                        [ -4295,  -4839],
                        [ -4132,  -4700],
                        [ -3985,  -4581],
                        [ -3859,  -4485],
                        [ -3759,  -4415],
                        [ -3679,  -4367],
                        [ -3621,  -4340],
                        [ -3582,  -4331],
                        [ -3561,  -4338],
                        [ -3536,  -4339],
                        [ -3508,  -4334],
                        [ -3467,  -4314],
                        [ -3413,  -4277],
                        [ -3326,  -4205],
                        [ -3207,  -4096],
                        [ -3075,  -3971],
                        [ -2929,  -3827],
                        [ -2798,  -3694],
                        [ -2679,  -3569],
                        [ -2578,  -3459],
                        [ -2495,  -3363],
                        [ -2435,  -3287],
                        [ -2396,  -3231],
                        [ -2382,  -3196],
                        [ -2390,  -3184],
                        [ -2423,  -3196],
                        [ -2477,  -3228],
                        [ -2553,  -3283],
                        [ -2649,  -3358],
                        [ -2762,  -3450],
                        [ -2890,  -3557],
                        [ -3030,  -3676],
                        [ -3181,  -3803],
                        [ -3339,  -3936],
                        [ -3501,  -4072],
                        [ -3664,  -4207],
                        [ -3827,  -4340],
                        [ -3985,  -4467],
                        [ -4140,  -4587],
                        [ -4286,  -4695],
                        [ -4425,  -4792],
                        [ -4552,  -4876],
                        [ -4669,  -4947],
                        [ -4773,  -5003],
                        [ -4862,  -5044],
                        [ -4937,  -5068],
                        [ -4996,  -5077],
                        [ -5038,  -5068],
                        [ -5064,  -5041],
                        [ -5070,  -4997],
                        [ -5057,  -4937],
                        [ -5017,  -4859],
                        [ -4952,  -4765],
                        [ -4859,  -4655],
                        [ -4738,  -4531],
                        [ -4591,  -4392],
                        [ -4414,  -4234],
                        [ -4248,  -4090],
                        [ -4173,  -4040],
                        [ -4246,  -4132],
                        [ -4477,  -4378],
                        [ -4864,  -4777],
                        [ -5395,  -5316],
                        [ -5999,  -5922],
                        [ -6558,  -6478],
                        [ -7022,  -6935],
                        [ -7399,  -7299],
                        [ -7692,  -7572],
                        [ -7902,  -7758],
                        [ -8033,  -7861],
                        [ -8093,  -7888],
                        [ -8084,  -7844],
                        [ -8015,  -7736],
                        [ -7888,  -7573],
                        [ -7711,  -7360],
                        [ -7490,  -7105],
                        [ -7232,  -6815],
                        [ -6945,  -6497],
                        [ -6635,  -6155],
                        [ -6308,  -5796],
                        [ -5974,  -5428],
                        [ -5635,  -5055],
                        [ -5294,  -4678],
                        [ -4954,  -4298],
                        [ -4618,  -3919],
                        [ -4287,  -3538],
                        [ -3961,  -3156],
                        [ -3642,  -2777],
                        [ -3329,  -2403],
                        [ -3023,  -2039],
                        [ -2722,  -1688],
                        [ -2429,  -1355],
                        [ -2139,  -1038],
                        [ -1857,   -739],
                        [ -1580,   -457],
                        [ -1309,   -185],
                        [ -1042,     76],
                        [  -779,    334],
                        [  -518,    590],
                        [  -257,    843],
                        [     6,   1095],
                        [   270,   1346],
                        [   537,   1598],
                        [   804,   1849],
                        [  1074,   2101],
                        [  1343,   2352],
                        [  1612,   2602],
                        [  1878,   2851],
                        [  2141,   3099],
                        [  2400,   3343],
                        [  2653,   3585],
                        [  2898,   3822],
                        [  3136,   4053],
                        [  3368,   4277],
                        [  3594,   4493],
                        [  3813,   4699],
                        [  4027,   4895],
                        [  4226,   5077],
                        [  4410,   5247],
                        [  4570,   5402],
                        [  4705,   5541],
                        [  4813,   5663],
                        [  4893,   5767],
                        [  4947,   5852],
                        [  4973,   5917],
                        [  4976,   5965],
                        [  4955,   5991],
                        [  4916,   6001],
                        [  4856,   5992],
                        [  4778,   5963],
                        [  4681,   5915],
                        [  4563,   5841],
                        [  4426,   5744],
                        [  4267,   5620],
                        [  4088,   5471],
                        [  3883,   5289],
                        [  3652,   5076],
                        [  3382,   4814],
                        [  3075,   4507],
                        [  2757,   4182],
                        [  2429,   3838],
                        [  2106,   3490],
                        [  1787,   3139],
                        [  1488,   2799],
                        [  1207,   2470],
                        [   952,   2164],
                        [   728,   1879],
                        [   539,   1628],
                        [   385,   1410],
                        [   271,   1229],
                        [   197,   1088],
                        [   165,    989],
                        [   172,    930],
                        [   220,    910],
                        [   307,    930],
                        [   429,    984],
                        [   586,   1073],
                        [   770,   1190],
                        [   983,   1337],
                        [  1216,   1504],
                        [  1467,   1692],
                        [  1728,   1893],
                        [  2000,   2106],
                        [  2275,   2325],
                        [  2550,   2546],
                        [  2817,   2763],
                        [  3075,   2975],
                        [  3316,   3174],
                        [  3538,   3359],
                        [  3733,   3522],
                        [  3899,   3660],
                        [  4031,   3770],
                        [  4125,   3846],
                        [  4172,   3888],
                        [  4171,   3890],
                        [  4115,   3850],
                        [  4000,   3767],
                        [  3825,   3638],
                        [  3588,   3463],
                        [  3287,   3232],
                        [  2968,   2993],
                        [  2736,   2841],
                        [  2637,   2820],
                        [  2680,   2941],
                        [  2872,   3208],
                        [  3213,   3617],
                        [  3621,   4089],
                        [  3963,   4486],
                        [  4180,   4752],
                        [  4281,   4894],
                        [  4270,   4913],
                        [  4147,   4812],
                        [  3918,   4595],
                        [  3590,   4269],
                        [  3170,   3842],
                        [  2664,   3323],
                        [  2082,   2722],
                        [  1432,   2049],
                        [   726,   1315],
                        [   -28,    530],
                        [  -816,   -294],
                        [ -1625,  -1144],
                        [ -2446,  -2012],
                        [ -3264,  -2880],
                        [ -4071,  -3742],
                        [ -4862,  -4588],
                        [ -5626,  -5412],
                        [ -6358,  -6212],
                        [ -7053,  -6984],
                        [ -7706,  -7724],
                        [ -8313,  -8429],
                        [ -8871,  -9090],
                        [ -9376,  -9705],
                        [ -9830, -10263],
                        [-10229, -10765],
                        [-10573, -11204],
                        [-10862, -11582],
                        [-11095, -11897],
                        [-11273, -12152],
                        [-11400, -12352],
                        [-11477, -12500],
                        [-11508, -12601],
                        [-11498, -12656],
                        [-11451, -12668],
                        [-11371, -12641],
                        [-11264, -12578],
                        [-11130, -12484],
                        [-10974, -12362],
                        [-10801, -12217],
                        [-10612, -12051],
                        [-10412, -11870],
                        [-10204, -11675],
                        [ -9991, -11471],
                        [ -9776, -11263],
                        [ -9562, -11052],
                        [ -9355, -10843],
                        [ -9158, -10638],
                        [ -8980, -10440],
                        [ -8822, -10251],
                        [ -8686, -10072],
                        [ -8574,  -9906],
                        [ -8475,  -9754],
                        [ -8392,  -9618],
                        [ -8314,  -9497],
                        [ -8242,  -9392],
                        [ -8176,  -9302],
                        [ -8115,  -9230],
                        [ -8058,  -9172],
                        [ -8008,  -9128],
                        [ -7964,  -9099],
                        [ -7927,  -9085],
                        [ -7895,  -9083],
                        [ -7867,  -9089],
                        [ -7843,  -9102],
                        [ -7820,  -9121],
                        [ -7806,  -9150],
                        [ -7796,  -9185],
                        [ -7795,  -9229],
                        [ -7800,  -9280],
                        [ -7786,  -9310],
                        [ -7751,  -9319],
                        [ -7682,  -9291],
                        [ -7577,  -9222],
                        [ -7448,  -9126],
                        [ -7294,  -8999],
                        [ -7122,  -8851],
                        [ -6932,  -8678],
                        [ -6731,  -8490],
                        [ -6519,  -8286],
                        [ -6302,  -8074],
                        [ -6078,  -7851],
                        [ -5856,  -7627],
                        [ -5632,  -7399],
                        [ -5413,  -7173],
                        [ -5198,  -6949],
                        [ -4988,  -6729],
                        [ -4784,  -6513],
                        [ -4589,  -6299],
                        [ -4401,  -6090],
                        [ -4222,  -5881],
                        [ -4051,  -5676],
                        [ -3887,  -5472],
                        [ -3730,  -5270],
                        [ -3578,  -5070],
                        [ -3433,  -4872],
                        [ -3292,  -4674],
                        [ -3157,  -4479],
                        [ -3025,  -4283],
                        [ -2899,  -4088],
                        [ -2776,  -3894],
                        [ -2658,  -3702],
                        [ -2542,  -3510],
                        [ -2429,  -3319],
                        [ -2317,  -3129],
                        [ -2208,  -2940],
                        [ -2099,  -2753],
                        [ -1988,  -2567],
                        [ -1874,  -2384],
                        [ -1756,  -2204],
                        [ -1630,  -2025],
                        [ -1502,  -1854],
                        [ -1363,  -1684],
                        [ -1211,  -1515],
                        [ -1116,  -1404],
                        [ -1175,  -1454],
                        [ -1434,  -1707],
                        [ -1900,  -2167],
                        [ -2580,  -2842],
                        [ -3480,  -3739],
                        [ -4516,  -4770],
                        [ -5535,  -5783],
                        [ -6471,  -6712],
                        [ -7329,  -7561],
                        [ -8104,  -8325],
                        [ -8790,  -8997],
                        [ -9382,  -9573],
                        [ -9882, -10054],
                        [-10287, -10440],
                        [-10599, -10732],
                        [-10816, -10932],
                        [-10942, -11046],
                        [-10981, -11075],
                        [-10939, -11026],
                        [-10821, -10904],
                        [-10633, -10714],
                        [-10387, -10468],
                        [-10088, -10172],
                        [ -9742,  -9836],
                        [ -9355,  -9465],
                        [ -8930,  -9058],
                        [ -8474,  -8620],
                        [ -7992,  -8148],
                        [ -7486,  -7645],
                        [ -6961,  -7112],
                        [ -6420,  -6552],
                        [ -5870,  -5978],
                        [ -5310,  -5388],
                        [ -4744,  -4791],
                        [ -4177,  -4188],
                        [ -3613,  -3589],
                        [ -3054,  -2993],
                        [ -2503,  -2403],
                        [ -1962,  -1821],
                        [ -1434,  -1247],
                        [  -919,   -682],
                        [  -417,   -128],
                        [    72,    412],
                        [   547,    938],
                        [  1006,   1446],
                        [  1447,   1937],
                        [  1871,   2410],
                        [  2275,   2862],
                        [  2658,   3292],
                        [  3018,   3699],
                        [  3356,   4084],
                        [  3668,   4442],
                        [  3955,   4775],
                        [  4218,   5081],
                        [  4456,   5360],
                        [  4677,   5611],
                        [  4882,   5835],
                        [  5075,   6030],
                        [  5255,   6197],
                        [  5420,   6335],
                        [  5571,   6446],
                        [  5689,   6528],
                        [  5780,   6584],
                        [  5835,   6612],
                        [  5856,   6614],
                        [  5844,   6592],
                        [  5799,   6545],
                        [  5726,   6476],
                        [  5626,   6386],
                        [  5502,   6277],
                        [  5358,   6151],
                        [  5196,   6009],
                        [  5016,   5852],
                        [  4836,   5692],
                        [  4656,   5533],
                        [  4497,   5395],
                        [  4362,   5279],
                        [  4246,   5178],
                        [  4149,   5094],
                        [  4034,   4988],
                        [  3907,   4864],
                        [  3756,   4713],
                        [  3585,   4535],
                        [  3403,   4341],
                        [  3211,   4131],
                        [  3018,   3916],
                        [  2826,   3695],
                        [  2641,   3480],
                        [  2465,   3269],
                        [  2304,   3071],
                        [  2158,   2887],
                        [  2030,   2723],
                        [  1922,   2579],
                        [  1835,   2459],
                        [  1768,   2360],
                        [  1723,   2285],
                        [  1697,   2230],
                        [  1690,   2192],
                        [  1699,   2170],
                        [  1721,   2160],
                        [  1754,   2160],
                        [  1791,   2167],
                        [  1831,   2179],
                        [  1867,   2190],
                        [  1899,   2199],
                        [  1919,   2199],
                        [  1927,   2188],
                        [  1918,   2161],
                        [  1888,   2117],
                        [  1835,   2049],
                        [  1755,   1957],
                        [  1645,   1837],
                        [  1505,   1687],
                        [  1328,   1502],
                        [  1115,   1285],
                        [   863,   1030],
                        [   572,    741],
                        [   239,    414],
                        [  -136,     51],
                        [  -550,   -344],
                        [ -1010,   -777],
                        [ -1512,  -1247],
                        [ -1983,  -1679],
                        [ -2321,  -1978],
                        [ -2489,  -2105],
                        [ -2477,  -2055],
                        [ -2265,  -1808],
                        [ -1838,  -1348],
                        [ -1278,   -760],
                        [  -735,   -196],
                        [  -271,    284],
                        [   127,    690],
                        [   451,   1015],
                        [   696,   1252],
                        [   864,   1403],
                        [   953,   1469],
                        [   966,   1452],
                        [   904,   1355],
                        [   771,   1185],
                        [   572,    947],
                        [   312,    647],
                        [    -1,    293],
                        [  -357,   -107],
                        [  -746,   -540],
                        [ -1161,   -999],
                        [ -1589,  -1466],
                        [ -2025,  -1934],
                        [ -2461,  -2396],
                        [ -2892,  -2845],
                        [ -3312,  -3285],
                        [ -3715,  -3708],
                        [ -4098,  -4123],
                        [ -4457,  -4522],
                        [ -4788,  -4904],
                        [ -5090,  -5266],
                        [ -5361,  -5601],
                        [ -5599,  -5910],
                        [ -5803,  -6190],
                        [ -5973,  -6437],
                        [ -6108,  -6651],
                        [ -6208,  -6831],
                        [ -6276,  -6979],
                        [ -6311,  -7096],
                        [ -6319,  -7183],
                        [ -6300,  -7245],
                        [ -6262,  -7282],
                        [ -6206,  -7296],
                        [ -6136,  -7292],
                        [ -6054,  -7271],
                        [ -5963,  -7236],
                        [ -5865,  -7190],
                        [ -5765,  -7135],
                        [ -5662,  -7075],
                        [ -5558,  -7011],
                        [ -5458,  -6944],
                        [ -5360,  -6879],
                        [ -5269,  -6817],
                        [ -5190,  -6758],
                        [ -5126,  -6702],
                        [ -5085,  -6654],
                        [ -5068,  -6612],
                        [ -5079,  -6577],
                        [ -5116,  -6550],
                        [ -5165,  -6528],
                        [ -5230,  -6515],
                        [ -5291,  -6506],
                        [ -5350,  -6502],
                        [ -5398,  -6502],
                        [ -5437,  -6504],
                        [ -5465,  -6507],
                        [ -5480,  -6509],
                        [ -5480,  -6509],
                        [ -5466,  -6504],
                        [ -5436,  -6494],
                        [ -5389,  -6475],
                        [ -5331,  -6452],
                        [ -5260,  -6424],
                        [ -5209,  -6420],
                        [ -5175,  -6439],
                        [ -5168,  -6488],
                        [ -5186,  -6565],
                        [ -5202,  -6640],
                        [ -5214,  -6712],
                        [ -5174,  -6730],
                        [ -5082,  -6694],
                        [ -4939,  -6603],
                        [ -4743,  -6455],
                        [ -4503,  -6257],
                        [ -4218,  -6008],
                        [ -3897,  -5718],
                        [ -3540,  -5386],
                        [ -3157,  -5023],
                        [ -2748,  -4627],
                        [ -2323,  -4211],
                        [ -1881,  -3774],
                        [ -1431,  -3326],
                        [  -973,  -2867],
                        [  -518,  -2407],
                        [   -63,  -1941],
                        [   384,  -1478],
                        [   820,  -1017],
                        [  1244,   -561],
                        [  1653,   -111],
                        [  2046,    329],
                        [  2423,    760],
                        [  2782,   1176],
                        [  3123,   1578],
                        [  3447,   1965],
                        [  3751,   2335],
                        [  4035,   2689],
                        [  4298,   3026],
                        [  4543,   3347],
                        [  4766,   3650],
                        [  4971,   3937],
                        [  5155,   4204],
                        [  5323,   4456],
                        [  5471,   4689],
                        [  5604,   4907],
                        [  5718,   5105],
                        [  5818,   5288],
                        [  5903,   5454],
                        [  5975,   5602],
                        [  6030,   5730],
                        [  6086,   5846],
                        [  6135,   5947],
                        [  6104,   5957],
                        [  5904,   5791],
                        [  5513,   5428],
                        [  4928,   4863],
                        [  4126,   4076],
                        [  3088,   3049],
                        [  1896,   1865],
                        [   703,    676],
                        [  -434,   -458],
                        [ -1517,  -1540],
                        [ -2533,  -2555],
                        [ -3469,  -3491],
                        [ -4316,  -4337],
                        [ -5069,  -5090],
                        [ -5721,  -5741],
                        [ -6267,  -6290],
                        [ -6704,  -6733],
                        [ -7032,  -7070],
                        [ -7252,  -7304],
                        [ -7366,  -7436],
                        [ -7382,  -7470],
                        [ -7301,  -7411],
                        [ -7137,  -7274],
                        [ -6895,  -7063],
                        [ -6579,  -6791],
                        [ -6197,  -6463],
                        [ -5756,  -6085],
                        [ -5262,  -5658],
                        [ -4722,  -5180],
                        [ -4144,  -4655],
                        [ -3532,  -4081],
                        [ -2895,  -3467],
                        [ -2238,  -2818],
                        [ -1567,  -2140],
                        [  -887,  -1440],
                        [  -205,   -722],
                        [   474,      5],
                        [  1143,    735],
                        [  1798,   1458],
                        [  2437,   2173],
                        [  3052,   2874],
                        [  3642,   3556],
                        [  4206,   4215],
                        [  4742,   4850],
                        [  5250,   5456],
                        [  5727,   6033],
                        [  6173,   6576],
                        [  6585,   7086],
                        [  6962,   7560],
                        [  7306,   7998],
                        [  7615,   8398],
                        [  7889,   8761],
                        [  8127,   9085],
                        [  8331,   9371],
                        [  8504,   9618],
                        [  8645,   9828],
                        [  8767,  10001],
                        [  8872,  10138],
                        [  8967,  10241],
                        [  9054,  10310],
                        [  9131,  10347],
                        [  9200,  10354],
                        [  9247,  10333],
                        [  9273,  10285],
                        [  9270,  10214],
                        [  9238,  10119],
                        [  9180,  10005],
                        [  9096,   9873],
                        [  8989,   9725],
                        [  8860,   9562],
                        [  8714,   9388],
                        [  8552,   9206],
                        [  8379,   9018],
                        [  8197,   8825],
                        [  8037,   8659],
                        [  7901,   8521],
                        [  7824,   8446],
                        [  7807,   8434],
                        [  7843,   8478],
                        [  7934,   8579],
                        [  8024,   8681],
                        [  8119,   8786],
                        [  8175,   8855],
                        [  8198,   8888],
                        [  8192,   8892],
                        [  8157,   8865],
                        [  8097,   8812],
                        [  8010,   8731],
                        [  7905,   8631],
                        [  7778,   8509],
                        [  7637,   8372],
                        [  7479,   8220],
                        [  7311,   8059],
                        [  7129,   7887],
                        [  6939,   7711],
                        [  6740,   7527],
                        [  6533,   7338],
                        [  6319,   7142],
                        [  6099,   6939],
                        [  5872,   6725],
                        [  5637,   6502],
                        [  5393,   6266],
                        [  5135,   6019],
                        [  4864,   5759],
                        [  4577,   5486],
                        [  4271,   5197],
                        [  3948,   4890],
                        [  3606,   4565],
                        [  3243,   4218],
                        [  2860,   3849],
                        [  2456,   3456],
                        [  2030,   3040],
                        [  1584,   2601],
                        [  1117,   2139],
                        [   631,   1654],
                        [   124,   1147],
                        [  -394,    621],
                        [  -925,     76],
                        [ -1467,   -486],
                        [ -2016,  -1059],
                        [ -2571,  -1639],
                        [ -3135,  -2230],
                        [ -3705,  -2820],
                        [ -4202,  -3336],
                        [ -4552,  -3702],
                        [ -4739,  -3902],
                        [ -4752,  -3929],
                        [ -4560,  -3751],
                        [ -4130,  -3337],
                        [ -3533,  -2756],
                        [ -2899,  -2142],
                        [ -2275,  -1541],
                        [ -1654,   -945],
                        [ -1048,   -370],
                        [  -470,    176],
                        [    76,    683],
                        [   583,   1149],
                        [  1047,   1569],
                        [  1460,   1939],
                        [  1822,   2260],
                        [  2131,   2529],
                        [  2389,   2750],
                        [  2596,   2922],
                        [  2756,   3049],
                        [  2876,   3140],
                        [  2959,   3196],
                        [  3010,   3236],
                        [  3032,   3260],
                        [  3030,   3274],
                        [  3007,   3284],
                        [  2967,   3283],
                        [  2914,   3274],
                        [  2848,   3247],
                        [  2774,   3203],
                        [  2696,   3143],
                        [  2614,   3068],
                        [  2530,   2979],
                        [  2446,   2875],
                        [  2364,   2761],
                        [  2285,   2636],
                        [  2208,   2506],
                        [  2138,   2372],
                        [  2072,   2238],
                        [  2013,   2107],
                        [  1958,   1978],
                        [  1909,   1849],
                        [  1861,   1724],
                        [  1813,   1600],
                        [  1764,   1476],
                        [  1714,   1353],
                        [  1662,   1230],
                        [  1607,   1105],
                        [  1550,    981],
                        [  1489,    854],
                        [  1424,    726],
                        [  1357,    599],
                        [  1287,    470],
                        [  1214,    341],
                        [  1130,    213],
                        [  1039,     85],
                        [   930,    -40],
                        [   804,   -163],
                        [   660,   -280],
                        [   496,   -393],
                        [   329,   -499],
                        [   155,   -598],
                        [    -4,   -686],
                        [  -150,   -763],
                        [  -271,   -826],
                        [  -367,   -875],
                        [  -437,   -909],
                        [  -479,   -925],
                        [  -490,   -921],
                        [  -468,   -895],
                        [  -415,   -847],
                        [  -332,   -778],
                        [  -230,   -700],
                        [  -110,   -609],
                        [   -24,   -560],
                        [    34,   -545],
                        [    47,   -580],
                        [    17,   -661],
                        [   -29,   -761],
                        [   -93,   -881],
                        [  -102,   -944],
                        [   -58,   -955],
                        [    47,   -902],
                        [   211,   -786],
                        [   429,   -611],
                        [   701,   -379],
                        [  1018,    -95],
                        [  1379,    238],
                        [  1775,    611],
                        [  2205,   1025],
                        [  2659,   1466],
                        [  3135,   1935],
                        [  3623,   2418],
                        [  4123,   2917],
                        [  4623,   3421],
                        [  5123,   3928],
                        [  5614,   4431],
                        [  6093,   4932],
                        [  6554,   5422],
                        [  6998,   5902],
                        [  7421,   6366],
                        [  7820,   6813],
                        [  8197,   7237],
                        [  8549,   7638],
                        [  8876,   8012],
                        [  9176,   8360],
                        [  9449,   8683],
                        [  9693,   8979],
                        [  9910,   9249],
                        [ 10099,   9493],
                        [ 10262,   9711],
                        [ 10398,   9903],
                        [ 10508,  10070],
                        [ 10593,  10212],
                        [ 10652,  10332],
                        [ 10683,  10427],
                        [ 10687,  10500],
                        [ 10665,  10551],
                        [ 10619,  10580],
                        [ 10547,  10584],
                        [ 10471,  10576],
                        [ 10374,  10541],
                        [ 10203,  10421],
                        [  9908,  10168],
                        [  9488,   9779],
                        [  8938,   9250],
                        [  8223,   8552],
                        [  7311,   7649],
                        [  6262,   6603],
                        [  5189,   5528],
                        [  4132,   4466],
                        [  3092,   3417],
                        [  2084,   2399],
                        [  1127,   1428],
                        [   231,    518],
                        [  -597,   -324],
                        [ -1345,  -1089],
                        [ -2004,  -1768],
                        [ -2570,  -2358],
                        [ -3040,  -2854],
                        [ -3413,  -3256],
                        [ -3688,  -3561],
                        [ -3869,  -3774],
                        [ -3959,  -3896],
                        [ -3965,  -3941],
                        [ -3891,  -3913],
                        [ -3742,  -3824],
                        [ -3525,  -3680],
                        [ -3244,  -3484],
                        [ -2908,  -3242],
                        [ -2523,  -2946],
                        [ -2095,  -2605],
                        [ -1632,  -2214],
                        [ -1142,  -1780],
                        [  -631,  -1307],
                        [  -105,   -800],
                        [   431,   -263],
                        [   968,    299],
                        [  1501,    875],
                        [  2025,   1462],
                        [  2535,   2047],
                        [  3026,   2624],
                        [  3493,   3185],
                        [  3932,   3725],
                        [  4341,   4240],
                        [  4720,   4728],
                        [  5067,   5185],
                        [  5381,   5610],
                        [  5662,   6001],
                        [  5909,   6357],
                        [  6122,   6676],
                        [  6303,   6959],
                        [  6450,   7206],
                        [  6566,   7417],
                        [  6650,   7592],
                        [  6705,   7731],
                        [  6736,   7837],
                        [  6743,   7910],
                        [  6739,   7953],
                        [  6724,   7966],
                        [  6710,   7952],
                        [  6697,   7914],
                        [  6687,   7853],
                        [  6682,   7772],
                        [  6671,   7672],
                        [  6654,   7559],
                        [  6623,   7431],
                        [  6578,   7291],
                        [  6520,   7144],
                        [  6450,   6990],
                        [  6367,   6832],
                        [  6273,   6667],
                        [  6168,   6502],
                        [  6056,   6338],
                        [  5941,   6179],
                        [  5822,   6026],
                        [  5747,   5923],
                        [  5711,   5868],
                        [  5753,   5899],
                        [  5869,   6013],
                        [  6058,   6207],
                        [  6320,   6481],
                        [  6586,   6767],
                        [  6862,   7068],
                        [  7093,   7328],
                        [  7279,   7547],
                        [  7421,   7727],
                        [  7516,   7863],
                        [  7563,   7954],
                        [  7562,   7998],
                        [  7515,   7999],
                        [  7420,   7953],
                        [  7280,   7864],
                        [  7094,   7731],
                        [  6867,   7560],
                        [  6597,   7347],
                        [  6289,   7100],
                        [  5942,   6815],
                        [  5562,   6498],
                        [  5149,   6147],
                        [  4708,   5764],
                        [  4237,   5349],
                        [  3740,   4903],
                        [  3218,   4427],
                        [  2671,   3926],
                        [  2097,   3398],
                        [  1502,   2849],
                        [   885,   2277],
                        [   249,   1687],
                        [  -405,   1077],
                        [ -1073,    449],
                        [ -1753,   -196],
                        [ -2441,   -855],
                        [ -3136,  -1525],
                        [ -3834,  -2205],
                        [ -4532,  -2890],
                        [ -5224,  -3578],
                        [ -5908,  -4266],
                        [ -6570,  -4947],
                        [ -7210,  -5621],
                        [ -7824,  -6282],
                        [ -8406,  -6925],
                        [ -8957,  -7544],
                        [ -9479,  -8141],
                        [ -9969,  -8701],
                        [-10373,  -9173],
                        [-10666,  -9531],
                        [-10847,  -9773],
                        [-10905,  -9888],
                        [-10802,  -9840],
                        [-10496,  -9587],
                        [-10018,  -9159],
                        [ -9453,  -8642],
                        [ -8829,  -8063],
                        [ -8146,  -7426],
                        [ -7420,  -6743],
                        [ -6667,  -6031],
                        [ -5896,  -5302],
                        [ -5120,  -4563],
                        [ -4347,  -3826],
                        [ -3590,  -3101],
                        [ -2857,  -2394],
                        [ -2153,  -1711],
                        [ -1484,  -1059],
                        [  -854,   -442],
                        [  -267,    138],
                        [   279,    683],
                        [   782,   1191],
                        [  1240,   1672],
                        [  1655,   2126],
                        [  2024,   2551],
                        [  2350,   2952],
                        [  2633,   3322],
                        [  2875,   3664],
                        [  3076,   3959],
                        [  3241,   4212],
                        [  3369,   4418],
                        [  3464,   4578],
                        [  3525,   4689],
                        [  3556,   4751],
                        [  3558,   4764],
                        [  3534,   4730],
                        [  3486,   4656],
                        [  3417,   4545],
                        [  3328,   4407],
                        [  3223,   4244],
                        [  3105,   4062],
                        [  2973,   3861],
                        [  2830,   3644],
                        [  2677,   3413],
                        [  2516,   3170],
                        [  2346,   2918],
                        [  2169,   2657],
                        [  1988,   2390],
                        [  1805,   2121],
                        [  1619,   1849],
                        [  1434,   1579],
                        [  1251,   1310],
                        [  1072,   1047],
                        [   897,    790],
                        [   723,    544],
                        [   553,    308],
                        [   378,     86],
                        [   202,   -120],
                        [    21,   -310],
                        [  -163,   -479],
                        [  -341,   -629],
                        [  -515,   -757],
                        [  -666,   -860],
                        [  -798,   -940],
                        [  -898,   -994],
                        [  -968,  -1021],
                        [ -1007,  -1021],
                        [ -1011,   -994],
                        [  -977,   -936],
                        [  -908,   -849],
                        [  -808,   -736],
                        [  -673,   -597],
                        [  -527,   -453],
                        [  -367,   -301],
                        [  -254,   -200],
                        [  -180,   -145],
                        [  -164,   -151],
                        [  -204,   -218],
                        [  -280,   -323],
                        [  -395,   -470],
                        [  -466,   -576],
                        [  -502,   -647],
                        [  -491,   -669],
                        [  -431,   -643],
                        [  -327,   -569],
                        [  -179,   -449],
                        [    10,   -286],
                        [   236,    -82],
                        [   494,    157],
                        [   783,    430],
                        [  1094,    729],
                        [  1428,   1051],
                        [  1774,   1390],
                        [  2131,   1742],
                        [  2492,   2100],
                        [  2855,   2461],
                        [  3210,   2819],
                        [  3558,   3174],
                        [  3891,   3520],
                        [  4210,   3855],
                        [  4510,   4175],
                        [  4792,   4478],
                        [  5055,   4760],
                        [  5298,   5018],
                        [  5519,   5253],
                        [  5717,   5462],
                        [  5893,   5648],
                        [  6046,   5808],
                        [  6175,   5944],
                        [  6281,   6059],
                        [  6365,   6150],
                        [  6426,   6218],
                        [  6465,   6266],
                        [  6482,   6293],
                        [  6472,   6301],
                        [  6435,   6287],
                        [  6368,   6257],
                        [  6273,   6208],
                        [  6152,   6143],
                        [  6007,   6058],
                        [  5853,   5962],
                        [  5680,   5843],
                        [  5475,   5681],
                        [  5235,   5475],
                        [  4968,   5234],
                        [  4665,   4950],
                        [  4292,   4589],
                        [  3804,   4105],
                        [  3208,   3508],
                        [  2560,   2853],
                        [  1880,   2161],
                        [  1172,   1439],
                        [   453,    701],
                        [  -264,    -36],
                        [  -968,   -762],
                        [ -1649,  -1467],
                        [ -2295,  -2139],
                        [ -2897,  -2771],
                        [ -3452,  -3355],
                        [ -3950,  -3885],
                        [ -4391,  -4358],
                        [ -4768,  -4769],
                        [ -5084,  -5120],
                        [ -5339,  -5409],
                        [ -5534,  -5645],
                        [ -5671,  -5829],
                        [ -5753,  -5970],
                        [ -5780,  -6069],
                        [ -5759,  -6133],
                        [ -5693,  -6164],
                        [ -5587,  -6154],
                        [ -5445,  -6109],
                        [ -5272,  -6023],
                        [ -5074,  -5900],
                        [ -4855,  -5741],
                        [ -4619,  -5549],
                        [ -4371,  -5322],
                        [ -4117,  -5064],
                        [ -3859,  -4782],
                        [ -3600,  -4479],
                        [ -3347,  -4168],
                        [ -3101,  -3851],
                        [ -2867,  -3543],
                        [ -2649,  -3244],
                        [ -2446,  -2958],
                        [ -2265,  -2686],
                        [ -2101,  -2432],
                        [ -1956,  -2195],
                        [ -1830,  -1979],
                        [ -1723,  -1783],
                        [ -1633,  -1608],
                        [ -1562,  -1454],
                        [ -1506,  -1320],
                        [ -1467,  -1206],
                        [ -1441,  -1112],
                        [ -1430,  -1036],
                        [ -1426,   -977],
                        [ -1432,   -937],
                        [ -1436,   -910],
                        [ -1439,   -898],
                        [ -1433,   -898],
                        [ -1418,   -908],
                        [ -1389,   -927],
                        [ -1347,   -955],
                        [ -1297,   -987],
                        [ -1239,  -1025],
                        [ -1182,  -1066],
                        [ -1125,  -1109],
                        [ -1071,  -1152],
                        [ -1019,  -1195],
                        [  -972,  -1238],
                        [  -933,  -1284],
                        [  -900,  -1328],
                        [  -873,  -1369],
                        [  -846,  -1402],
                        [  -823,  -1430],
                        [  -760,  -1407],
                        [  -657,  -1335],
                        [  -488,  -1187],
                        [  -258,   -967],
                        [    39,   -671],
                        [   400,   -301],
                        [   761,     81],
                        [  1127,    475],
                        [  1441,    826],
                        [  1705,   1136],
                        [  1915,   1398],
                        [  2069,   1609],
                        [  2159,   1762],
                        [  2188,   1857],
                        [  2152,   1892],
                        [  2052,   1865],
                        [  1887,   1776],
                        [  1659,   1626],
                        [  1371,   1417],
                        [  1021,   1149],
                        [   617,    826],
                        [   157,    449],
                        [  -349,     24],
                        [  -901,   -451],
                        [ -1492,   -967],
                        [ -2121,  -1526],
                        [ -2780,  -2120],
                        [ -3469,  -2748],
                        [ -4182,  -3403],
                        [ -4917,  -4082],
                        [ -5669,  -4778],
                        [ -6434,  -5488],
                        [ -7206,  -6208],
                        [ -7982,  -6934],
                        [ -8754,  -7661],
                        [ -9520,  -8387],
                        [-10273,  -9107],
                        [-11011,  -9817],
                        [-11725, -10512],
                        [-12413, -11188],
                        [-13064, -11840],
                        [-13677, -12463],
                        [-14235, -13053],
                        [-14739, -13606],
                        [-15182, -14118],
                        [-15563, -14584],
                        [-15884, -14999],
                        [-16141, -15363],
                        [-16346, -15668],
                        [-16496, -15917],
                        [-16610, -16123],
                        [-16696, -16298],
                        [-16745, -16430],
                        [-16721, -16484],
                        [-16574, -16408],
                        [-16277, -16177],
                        [-15858, -15818],
                        [-15333, -15345],
                        [-14705, -14766],
                        [-13992, -14094],
                        [-13210, -13348],
                        [-12371, -12538],
                        [-11487, -11676],
                        [-10571, -10779],
                        [ -9640,  -9858],
                        [ -8700,  -8924],
                        [ -7766,  -7987],
                        [ -6845,  -7058],
                        [ -5949,  -6147],
                        [ -5083,  -5261],
                        [ -4252,  -4403],
                        [ -3464,  -3577],
                        [ -2721,  -2786],
                        [ -2030,  -2030],
                        [ -1392,  -1313],
                        [  -808,   -635],
                        [  -282,     -1],
                        [   188,    591],
                        [   601,   1124],
                        [   958,   1600],
                        [  1262,   2015],
                        [  1511,   2368],
                        [  1710,   2653],
                        [  1861,   2871],
                        [  1965,   3020],
                        [  2025,   3104],
                        [  2044,   3128],
                        [  2026,   3096],
                        [  1977,   3023],
                        [  1899,   2911],
                        [  1797,   2769],
                        [  1676,   2600],
                        [  1539,   2407],
                        [  1389,   2195],
                        [  1229,   1967],
                        [  1060,   1727],
                        [   889,   1479],
                        [   716,   1226],
                        [   544,    972],
                        [   377,    721],
                        [   216,    475],
                        [    65,    239],
                        [   -76,     14],
                        [  -205,   -197],
                        [  -321,   -391],
                        [  -423,   -565],
                        [  -516,   -717],
                        [  -596,   -847],
                        [  -666,   -952],
                        [  -727,  -1031],
                        [  -777,  -1084],
                        [  -815,  -1110],
                        [  -834,  -1108],
                        [  -835,  -1079],
                        [  -813,  -1023],
                        [  -768,   -940],
                        [  -700,   -833],
                        [  -606,   -700],
                        [  -486,   -542],
                        [  -341,   -360],
                        [  -177,   -161],
                        [     7,     56],
                        [   187,    266],
                        [   362,    468],
                        [   492,    620],
                        [   574,    722],
                        [   596,    761],
                        [   557,    735],
                        [   466,    652],
                        [   320,    510],
                        [   189,    380],
                        [    67,    256],
                        [   -35,    150],
                        [  -116,     63],
                        [  -174,     -3],
                        [  -209,    -47],
                        [  -219,    -67],
                        [  -207,    -66],
                        [  -173,    -42],
                        [  -117,      2],
                        [   -43,     64],
                        [    48,    143],
                        [   153,    235],
                        [   271,    341],
                        [   397,    454],
                        [   531,    574],
                        [   665,    697],
                        [   803,    821],
                        [   936,    944],
                        [  1068,   1064],
                        [  1194,   1178],
                        [  1315,   1286],
                        [  1431,   1384],
                        [  1541,   1471],
                        [  1642,   1547],
                        [  1737,   1610],
                        [  1822,   1661],
                        [  1900,   1699],
                        [  1967,   1727],
                        [  2025,   1744],
                        [  2073,   1752],
                        [  2110,   1749],
                        [  2135,   1736],
                        [  2148,   1714],
                        [  2140,   1682],
                        [  2113,   1640],
                        [  2061,   1591],
                        [  1984,   1532],
                        [  1888,   1464],
                        [  1770,   1388],
                        [  1644,   1301],
                        [  1512,   1209],
                        [  1415,   1146],
                        [  1385,   1144],
                        [  1432,   1214],
                        [  1545,   1346],
                        [  1699,   1512],
                        [  1831,   1651],
                        [  1882,   1705],
                        [  1852,   1672],
                        [  1748,   1562],
                        [  1575,   1379],
                        [  1342,   1133],
                        [  1062,    837],
                        [   739,    496],
                        [   384,    119],
                        [     3,   -282],
                        [  -392,   -700],
                        [  -795,  -1126],
                        [ -1201,  -1556],
                        [ -1601,  -1982],
                        [ -1990,  -2397],
                        [ -2364,  -2799],
                        [ -2722,  -3185],
                        [ -3059,  -3557],
                        [ -3373,  -3911],
                        [ -3661,  -4247],
                        [ -3926,  -4566],
                        [ -4166,  -4872],
                        [ -4381,  -5164],
                        [ -4574,  -5440],
                        [ -4744,  -5699],
                        [ -4895,  -5935],
                        [ -5026,  -6151],
                        [ -5142,  -6339],
                        [ -5241,  -6503],
                        [ -5328,  -6637],
                        [ -5402,  -6740],
                        [ -5465,  -6815],
                        [ -5520,  -6866],
                        [ -5566,  -6897],
                        [ -5608,  -6911],
                        [ -5645,  -6920],
                        [ -5682,  -6927],
                        [ -5718,  -6928],
                        [ -5753,  -6927],
                        [ -5790,  -6925],
                        [ -5827,  -6922],
                        [ -5862,  -6917],
                        [ -5897,  -6911],
                        [ -5929,  -6905],
                        [ -5960,  -6897],
                        [ -5986,  -6888],
                        [ -6007,  -6877],
                        [ -6023,  -6864],
                        [ -6033,  -6848],
                        [ -6034,  -6828],
                        [ -6027,  -6804],
                        [ -6009,  -6775],
                        [ -5980,  -6741],
                        [ -5937,  -6702],
                        [ -5880,  -6657],
                        [ -5805,  -6606],
                        [ -5713,  -6549],
                        [ -5602,  -6484],
                        [ -5474,  -6414],
                        [ -5336,  -6338],
                        [ -5185,  -6254],
                        [ -5029,  -6165],
                        [ -4865,  -6071],
                        [ -4702,  -5974],
                        [ -4540,  -5877],
                        [ -4383,  -5778],
                        [ -4227,  -5676],
                        [ -4075,  -5569],
                        [ -3925,  -5459],
                        [ -3750,  -5314],
                        [ -3551,  -5137],
                        [ -3317,  -4916],
                        [ -3051,  -4652],
                        [ -2741,  -4335],
                        [ -2389,  -3967],
                        [ -2040,  -3590],
                        [ -1691,  -3205],
                        [ -1383,  -2853],
                        [ -1117,  -2533],
                        [  -901,  -2257],
                        [  -735,  -2024],
                        [  -628,  -1845],
                        [  -580,  -1720],
                        [  -594,  -1654],
                        [  -671,  -1648],
                        [  -811,  -1702],
                        [ -1013,  -1818],
                        [ -1275,  -1993],
                        [ -1596,  -2228],
                        [ -1971,  -2519],
                        [ -2399,  -2864],
                        [ -2870,  -3257],
                        [ -3385,  -3696],
                        [ -3934,  -4174],
                        [ -4517,  -4689],
                        [ -5122,  -5232],
                        [ -5748,  -5800],
                        [ -6387,  -6383],
                        [ -7037,  -6981],
                        [ -7690,  -7582],
                        [ -8340,  -8185],
                        [ -8982,  -8781],
                        [ -9612,  -9366],
                        [-10220,  -9934],
                        [-10804, -10481],
                        [-11356, -11002],
                        [-11875, -11494],
                        [-12351, -11951],
                        [-12781, -12370],
                        [-13157, -12744],
                        [-13474, -13072],
                        [-13722, -13348],
                        [-13898, -13570],
                        [-14001, -13736],
                        [-14029, -13844],
                        [-13989, -13891],
                        [-13873, -13873],
                        [-13717, -13810],
                        [-13574, -13757],
                        [-13491, -13758],
                        [-13475, -13821],
                        [-13527, -13945],
                        [-13624, -14107],
                        [-13696, -14236],
                        [-13661, -14249],
                        [-13496, -14124],
                        [-13209, -13869],
                        [-12810, -13492],
                        [-12308, -13003],
                        [-11715, -12416],
                        [-11042, -11741],
                        [-10300, -10990],
                        [ -9501, -10175],
                        [ -8660,  -9311],
                        [ -7785,  -8409],
                        [ -6888,  -7481],
                        [ -5986,  -6539],
                        [ -5085,  -5593],
                        [ -4195,  -4653],
                        [ -3326,  -3727],
                        [ -2485,  -2823],
                        [ -1679,  -1947],
                        [  -915,  -1107],
                        [  -195,   -305],
                        [   476,    457],
                        [  1095,   1176],
                        [  1662,   1851],
                        [  2173,   2475],
                        [  2631,   3048],
                        [  3035,   3564],
                        [  3387,   4024],
                        [  3687,   4420],
                        [  3938,   4753],
                        [  4144,   5022],
                        [  4305,   5228],
                        [  4423,   5376],
                        [  4506,   5470],
                        [  4556,   5522],
                        [  4577,   5536],
                        [  4576,   5523],
                        [  4556,   5483],
                        [  4522,   5423],
                        [  4479,   5344],
                        [  4429,   5253],
                        [  4375,   5154],
                        [  4322,   5049],
                        [  4271,   4943],
                        [  4225,   4840],
                        [  4186,   4742],
                        [  4158,   4652],
                        [  4141,   4574],
                        [  4136,   4509],
                        [  4145,   4459],
                        [  4169,   4427],
                        [  4210,   4413],
                        [  4268,   4418],
                        [  4345,   4444],
                        [  4435,   4489],
                        [  4542,   4555],
                        [  4656,   4640],
                        [  4778,   4745],
                        [  4903,   4867],
                        [  5033,   5007],
                        [  5166,   5160],
                        [  5303,   5328],
                        [  5442,   5505],
                        [  5584,   5692],
                        [  5729,   5887],
                        [  5874,   6088],
                        [  6018,   6289],
                        [  6156,   6487],
                        [  6277,   6667],
                        [  6375,   6827],
                        [  6434,   6945],
                        [  6453,   7022],
                        [  6420,   7046],
                        [  6336,   7013],
                        [  6190,   6916],
                        [  5984,   6754],
                        [  5759,   6568],
                        [  5513,   6355],
                        [  5257,   6128],
                        [  4990,   5885],
                        [  4724,   5637],
                        [  4456,   5382],
                        [  4194,   5129],
                        [  3937,   4877],
                        [  3693,   4631],
                        [  3458,   4392],
                        [  3238,   4162],
                        [  3031,   3944],
                        [  2841,   3738],
                        [  2667,   3546],
                        [  2509,   3366],
                        [  2367,   3201],
                        [  2241,   3049],
                        [  2130,   2909],
                        [  2033,   2780],
                        [  1951,   2661],
                        [  1881,   2552],
                        [  1824,   2453],
                        [  1779,   2360],
                        [  1748,   2276],
                        [  1726,   2197],
                        [  1716,   2126],
                        [  1714,   2058],
                        [  1722,   1996],
                        [  1736,   1938],
                        [  1757,   1886],
                        [  1780,   1837],
                        [  1809,   1793],
                        [  1835,   1753],
                        [  1860,   1714],
                        [  1873,   1676],
                        [  1876,   1640],
                        [  1863,   1602],
                        [  1834,   1563],
                        [  1790,   1523],
                        [  1729,   1480],
                        [  1656,   1428],
                        [  1605,   1402],
                        [  1657,   1479],
                        [  1859,   1704],
                        [  2217,   2082],
                        [  2728,   2612],
                        [  3376,   3278],
                        [  4082,   3997],
                        [  4728,   4654],
                        [  5272,   5206],
                        [  5718,   5657],
                        [  6069,   6008],
                        [  6325,   6261],
                        [  6489,   6420],
                        [  6565,   6489],
                        [  6560,   6475],
                        [  6477,   6383],
                        [  6325,   6221],
                        [  6109,   5996],
                        [  5836,   5715],
                        [  5518,   5384],
                        [  5161,   5012],
                        [  4771,   4602],
                        [  4355,   4163],
                        [  3920,   3703],
                        [  3471,   3227],
                        [  3014,   2741],
                        [  2553,   2249],
                        [  2092,   1752],
                        [  1636,   1252],
                        [  1187,    749],
                        [   748,    247],
                        [   321,   -249],
                        [   -92,   -736],
                        [  -488,  -1207],
                        [  -866,  -1660],
                        [ -1224,  -2084],
                        [ -1562,  -2481],
                        [ -1876,  -2845],
                        [ -2168,  -3179],
                        [ -2435,  -3481],
                        [ -2679,  -3751],
                        [ -2898,  -3999],
                        [ -3096,  -4225],
                        [ -3271,  -4427],
                        [ -3426,  -4606],
                        [ -3557,  -4762],
                        [ -3669,  -4895],
                        [ -3759,  -5003],
                        [ -3829,  -5091],
                        [ -3878,  -5155],
                        [ -3906,  -5198],
                        [ -3913,  -5220],
                        [ -3900,  -5220],
                        [ -3868,  -5200],
                        [ -3816,  -5161],
                        [ -3746,  -5103],
                        [ -3661,  -5027],
                        [ -3563,  -4934],
                        [ -3452,  -4825],
                        [ -3336,  -4704],
                        [ -3213,  -4568],
                        [ -3080,  -4420],
                        [ -2940,  -4263],
                        [ -2784,  -4097],
                        [ -2615,  -3924],
                        [ -2433,  -3745],
                        [ -2241,  -3563],
                        [ -2041,  -3378],
                        [ -1836,  -3192],
                        [ -1634,  -3010],
                        [ -1434,  -2832],
                        [ -1241,  -2660],
                        [ -1053,  -2494],
                        [  -874,  -2333],
                        [  -705,  -2180],
                        [  -540,  -2026],
                        [  -382,  -1874],
                        [  -231,  -1723],
                        [   -87,  -1575],
                        [    68,  -1410],
                        [   234,  -1227],
                        [   401,  -1038],
                        [   568,   -839],
                        [   716,   -657],
                        [   843,   -487],
                        [   939,   -342],
                        [  1008,   -220],
                        [  1040,   -132],
                        [  1036,    -76],
                        [   991,    -59],
                        [   907,    -79],
                        [   781,   -140],
                        [   614,   -240],
                        [   410,   -380],
                        [   167,   -560],
                        [  -111,   -778],
                        [  -419,  -1029],
                        [  -754,  -1311],
                        [ -1113,  -1621],
                        [ -1491,  -1951],
                        [ -1883,  -2299],
                        [ -2282,  -2655],
                        [ -2684,  -3019],
                        [ -3083,  -3382],
                        [ -3476,  -3740],
                        [ -3857,  -4088],
                        [ -4221,  -4421],
                        [ -4562,  -4732],
                        [ -4879,  -5019],
                        [ -5163,  -5276],
                        [ -5414,  -5500],
                        [ -5624,  -5687],
                        [ -5793,  -5835],
                        [ -5914,  -5939],
                        [ -5988,  -5998],
                        [ -6004,  -6008],
                        [ -5965,  -5969],
                        [ -5862,  -5879],
                        [ -5696,  -5738],
                        [ -5467,  -5544],
                        [ -5176,  -5300],
                        [ -4827,  -5005],
                        [ -4415,  -4654],
                        [ -4006,  -4302],
                        [ -3690,  -4042],
                        [ -3519,  -3922],
                        [ -3497,  -3948],
                        [ -3636,  -4127],
                        [ -3931,  -4457],
                        [ -4299,  -4851],
                        [ -4606,  -5177],
                        [ -4804,  -5385],
                        [ -4902,  -5485],
                        [ -4903,  -5480],
                        [ -4807,  -5369],
                        [ -4622,  -5162],
                        [ -4352,  -4862],
                        [ -4002,  -4479],
                        [ -3582,  -4021],
                        [ -3098,  -3498],
                        [ -2561,  -2919],
                        [ -1981,  -2293],
                        [ -1367,  -1631],
                        [  -731,   -941],
                        [   -82,   -231],
                        [   573,    487],
                        [  1225,   1203],
                        [  1870,   1909],
                        [  2499,   2597],
                        [  3109,   3261],
                        [  3694,   3898],
                        [  4251,   4512],
                        [  4778,   5098],
                        [  5273,   5659],
                        [  5734,   6191],
                        [  6161,   6692],
                        [  6554,   7161],
                        [  6915,   7592],
                        [  7243,   7985],
                        [  7538,   8337],
                        [  7802,   8651],
                        [  8039,   8925],
                        [  8249,   9164],
                        [  8437,   9375],
                        [  8604,   9558],
                        [  8755,   9722],
                        [  8891,   9871],
                        [  9019,  10005],
                        [  9139,  10128],
                        [  9255,  10242],
                        [  9370,  10350],
                        [  9484,  10454],
                        [  9601,  10558],
                        [  9718,  10662],
                        [  9841,  10768],
                        [  9966,  10879],
                        [ 10098,  10995],
                        [ 10234,  11116],
                        [ 10376,  11243],
                        [ 10524,  11376],
                        [ 10680,  11516],
                        [ 10850,  11660],
                        [ 11032,  11810],
                        [ 11224,  11963],
                        [ 11425,  12120],
                        [ 11623,  12277],
                        [ 11816,  12435],
                        [ 11993,  12589],
                        [ 12152,  12739],
                        [ 12289,  12882],
                        [ 12404,  13017],
                        [ 12496,  13140],
                        [ 12565,  13251],
                        [ 12611,  13348],
                        [ 12630,  13427],
                        [ 12623,  13486],
                        [ 12589,  13522],
                        [ 12528,  13535],
                        [ 12439,  13525],
                        [ 12333,  13496],
                        [ 12208,  13449],
                        [ 12053,  13371],
                        [ 11868,  13262],
                        [ 11629,  13093],
                        [ 11334,  12864],
                        [ 10996,  12586],
                        [ 10611,  12256],
                        [ 10195,  11886],
                        [  9745,  11477],
                        [  9276,  11039],
                        [  8786,  10576],
                        [  8289,  10097],
                        [  7784,   9602],
                        [  7282,   9103],
                        [  6782,   8600],
                        [  6294,   8101],
                        [  5818,   7610],
                        [  5361,   7132],
                        [  4923,   6670],
                        [  4510,   6228],
                        [  4122,   5807],
                        [  3760,   5409],
                        [  3428,   5035],
                        [  3124,   4684],
                        [  2849,   4357],
                        [  2602,   4054],
                        [  2384,   3775],
                        [  2191,   3519],
                        [  2027,   3287],
                        [  1887,   3077],
                        [  1772,   2889],
                        [  1679,   2720],
                        [  1607,   2572],
                        [  1554,   2440],
                        [  1518,   2324],
                        [  1494,   2222],
                        [  1484,   2135],
                        [  1479,   2058],
                        [  1480,   1991],
                        [  1480,   1931],
                        [  1477,   1877],
                        [  1466,   1825],
                        [  1445,   1776],
                        [  1415,   1730],
                        [  1369,   1681],
                        [  1310,   1625],
                        [  1302,   1627],
                        [  1444,   1783],
                        [  1775,   2130],
                        [  2298,   2669],
                        [  3023,   3412],
                        [  3949,   4357],
                        [  4984,   5409],
                        [  5977,   6417],
                        [  6870,   7323],
                        [  7668,   8131],
                        [  8366,   8835],
                        [  8955,   9429],
                        [  9438,   9912],
                        [  9811,  10282],
                        [ 10074,  10543],
                        [ 10230,  10697],
                        [ 10283,  10748],
                        [ 10239,  10700],
                        [ 10103,  10561],
                        [  9887,  10337],
                        [  9599,  10034],
                        [  9246,   9661],
                        [  8837,   9226],
                        [  8379,   8745],
                        [  7882,   8224],
                        [  7352,   7676],
                        [  6797,   7105],
                        [  6223,   6517],
                        [  5638,   5918],
                        [  5048,   5303],
                        [  4458,   4678],
                        [  3875,   4049],
                        [  3302,   3417],
                        [  2745,   2794],
                        [  2206,   2182],
                        [  1692,   1591],
                        [  1204,   1024],
                        [   746,    486],
                        [   320,    -20],
                        [   -72,   -490],
                        [  -427,   -922],
                        [  -748,  -1320],
                        [ -1031,  -1684],
                        [ -1279,  -2012],
                        [ -1491,  -2303],
                        [ -1671,  -2557],
                        [ -1816,  -2776],
                        [ -1931,  -2960],
                        [ -2016,  -3109],
                        [ -2071,  -3226],
                        [ -2099,  -3309],
                        [ -2100,  -3364],
                        [ -2078,  -3388],
                        [ -2031,  -3387],
                        [ -1965,  -3361],
                        [ -1883,  -3311],
                        [ -1786,  -3242],
                        [ -1685,  -3154],
                        [ -1582,  -3050],
                        [ -1487,  -2933],
                        [ -1399,  -2806],
                        [ -1318,  -2669],
                        [ -1245,  -2527],
                        [ -1166,  -2381],
                        [ -1087,  -2234],
                        [  -999,  -2088],
                        [  -906,  -1945],
                        [  -810,  -1807],
                        [  -713,  -1675],
                        [  -620,  -1553],
                        [  -531,  -1442],
                        [  -449,  -1342],
                        [  -374,  -1255],
                        [  -313,  -1185],
                        [  -266,  -1133],
                        [  -255,  -1117],
                        [  -279,  -1138],
                        [  -346,  -1204],
                        [  -457,  -1314],
                        [  -582,  -1437],
                        [  -723,  -1575],
                        [  -850,  -1698],
                        [  -961,  -1804],
                        [ -1064,  -1897],
                        [ -1153,  -1977],
                        [ -1239,  -2051],
                        [ -1320,  -2116],
                        [ -1400,  -2179],
                        [ -1480,  -2240],
                        [ -1562,  -2303],
                        [ -1647,  -2367],
                        [ -1738,  -2437],
                        [ -1832,  -2509],
                        [ -1931,  -2588],
                        [ -2033,  -2671],
                        [ -2139,  -2760],
                        [ -2245,  -2853],
                        [ -2352,  -2947],
                        [ -2458,  -3042],
                        [ -2559,  -3132],
                        [ -2651,  -3215],
                        [ -2733,  -3287],
                        [ -2801,  -3343],
                        [ -2850,  -3381],
                        [ -2880,  -3400],
                        [ -2885,  -3395],
                        [ -2866,  -3365],
                        [ -2818,  -3305],
                        [ -2741,  -3217],
                        [ -2633,  -3095],
                        [ -2492,  -2939],
                        [ -2316,  -2745],
                        [ -2106,  -2517],
                        [ -1859,  -2251],
                        [ -1576,  -1950],
                        [ -1256,  -1610],
                        [  -901,  -1237],
                        [  -509,   -829],
                        [   -83,   -386],
                        [   380,     86],
                        [   872,    583],
                        [  1398,   1108],
                        [  1951,   1655],
                        [  2447,   2147],
                        [  2789,   2484],
                        [  2943,   2633],
                        [  2900,   2588],
                        [  2637,   2327],
                        [  2143,   1839],
                        [  1507,   1212],
                        [   882,    600],
                        [   319,     57],
                        [  -190,   -427],
                        [  -639,   -846],
                        [ -1021,  -1192],
                        [ -1331,  -1464],
                        [ -1571,  -1663],
                        [ -1738,  -1789],
                        [ -1833,  -1844],
                        [ -1859,  -1831],
                        [ -1821,  -1755],
                        [ -1723,  -1619],
                        [ -1573,  -1431],
                        [ -1378,  -1194],
                        [ -1144,   -913],
                        [  -876,   -602],
                        [  -579,   -264],
                        [  -261,     85],
                        [    77,    444],
                        [   429,    803],
                        [   790,   1160],
                        [  1157,   1522],
                        [  1526,   1883],
                        [  1896,   2253],
                        [  2264,   2627],
                        [  2627,   3005],
                        [  2985,   3386],
                        [  3336,   3764],
                        [  3679,   4139],
                        [  4013,   4509],
                        [  4338,   4874],
                        [  4654,   5229],
                        [  4958,   5575],
                        [  5253,   5910],
                        [  5537,   6237],
                        [  5813,   6557],
                        [  6079,   6869],
                        [  6339,   7174],
                        [  6592,   7473],
                        [  6840,   7765],
                        [  7085,   8052],
                        [  7324,   8332],
                        [  7558,   8607],
                        [  7786,   8875],
                        [  8008,   9137],
                        [  8223,   9391],
                        [  8430,   9638],
                        [  8627,   9874],
                        [  8815,  10103],
                        [  8996,  10318],
                        [  9171,  10522],
                        [  9347,  10711],
                        [  9524,  10884],
                        [  9700,  11040],
                        [  9874,  11177],
                        [ 10032,  11292],
                        [ 10175,  11386],
                        [ 10282,  11455],
                        [ 10353,  11499],
                        [ 10384,  11515],
                        [ 10374,  11503],
                        [ 10322,  11460],
                        [ 10228,  11386],
                        [ 10092,  11281],
                        [  9914,  11142],
                        [  9697,  10972],
                        [  9440,  10768],
                        [  9166,  10552],
                        [  8876,  10324],
                        [  8598,  10111],
                        [  8332,   9911],
                        [  8073,   9716],
                        [  7820,   9528],
                        [  7529,   9298],
                        [  7202,   9030],
                        [  6819,   8700],
                        [  6381,   8312],
                        [  5903,   7874],
                        [  5382,   7388],
                        [  4831,   6866],
                        [  4253,   6307],
                        [  3659,   5726],
                        [  3049,   5121],
                        [  2438,   4508],
                        [  1823,   3884],
                        [  1218,   3263],
                        [   622,   2646],
                        [    45,   2043],
                        [  -514,   1456],
                        [ -1045,    892],
                        [ -1548,    353],
                        [ -2018,   -159],
                        [ -2455,   -641],
                        [ -2858,  -1093],
                        [ -3226,  -1515],
                        [ -3562,  -1907],
                        [ -3863,  -2269],
                        [ -4134,  -2598],
                        [ -4373,  -2899],
                        [ -4583,  -3170],
                        [ -4763,  -3411],
                        [ -4917,  -3626],
                        [ -5046,  -3816],
                        [ -5157,  -3987],
                        [ -5247,  -4136],
                        [ -5321,  -4270],
                        [ -5382,  -4388],
                        [ -5432,  -4493],
                        [ -5472,  -4588],
                        [ -5506,  -4675],
                        [ -5535,  -4756],
                        [ -5567,  -4835],
                        [ -5601,  -4912],
                        [ -5640,  -4983],
                        [ -5696,  -5061],
                        [ -5758,  -5138],
                        [ -5749,  -5137],
                        [ -5585,  -4975],
                        [ -5245,  -4631],
                        [ -4725,  -4106],
                        [ -4000,  -3372],
                        [ -3054,  -2416],
                        [ -1977,  -1328],
                        [  -918,   -261],
                        [    72,    737],
                        [   997,   1667],
                        [  1848,   2520],
                        [  2610,   3281],
                        [  3278,   3945],
                        [  3846,   4509],
                        [  4312,   4968],
                        [  4673,   5324],
                        [  4929,   5575],
                        [  5085,   5725],
                        [  5144,   5776],
                        [  5116,   5735],
                        [  5005,   5604],
                        [  4821,   5394],
                        [  4570,   5111],
                        [  4261,   4774],
                        [  3898,   4389],
                        [  3493,   3971],
                        [  3052,   3525],
                        [  2583,   3058],
                        [  2091,   2577],
                        [  1588,   2075],
                        [  1077,   1560],
                        [   564,   1029],
                        [    57,    491],
                        [  -440,    -49],
                        [  -921,   -586],
                        [ -1383,  -1115],
                        [ -1822,  -1632],
                        [ -2235,  -2132],
                        [ -2618,  -2611],
                        [ -2969,  -3060],
                        [ -3286,  -3480],
                        [ -3567,  -3868],
                        [ -3812,  -4220],
                        [ -4024,  -4539],
                        [ -4200,  -4823],
                        [ -4346,  -5072],
                        [ -4461,  -5289],
                        [ -4548,  -5471],
                        [ -4610,  -5623],
                        [ -4649,  -5745],
                        [ -4666,  -5839],
                        [ -4664,  -5909],
                        [ -4645,  -5954],
                        [ -4613,  -5979],
                        [ -4567,  -5987],
                        [ -4516,  -5978],
                        [ -4458,  -5954],
                        [ -4410,  -5918],
                        [ -4373,  -5874],
                        [ -4355,  -5822],
                        [ -4359,  -5765],
                        [ -4383,  -5705],
                        [ -4429,  -5644],
                        [ -4479,  -5584],
                        [ -4538,  -5527],
                        [ -4591,  -5475],
                        [ -4643,  -5428],
                        [ -4693,  -5387],
                        [ -4741,  -5355],
                        [ -4788,  -5331],
                        [ -4833,  -5315],
                        [ -4879,  -5309],
                        [ -4925,  -5312],
                        [ -4984,  -5337],
                        [ -5054,  -5381],
                        [ -5179,  -5488],
                        [ -5354,  -5654],
                        [ -5592,  -5889],
                        [ -5892,  -6191],
                        [ -6221,  -6527],
                        [ -6576,  -6897],
                        [ -6896,  -7233],
                        [ -7181,  -7539],
                        [ -7424,  -7805],
                        [ -7622,  -8028],
                        [ -7779,  -8211],
                        [ -7894,  -8353],
                        [ -7971,  -8459],
                        [ -8009,  -8524],
                        [ -8011,  -8555],
                        [ -7978,  -8550],
                        [ -7913,  -8513],
                        [ -7815,  -8444],
                        [ -7690,  -8348],
                        [ -7534,  -8222],
                        [ -7356,  -8073],
                        [ -7149,  -7898],
                        [ -6923,  -7703],
                        [ -6674,  -7485],
                        [ -6404,  -7243],
                        [ -6114,  -6979],
                        [ -5802,  -6690],
                        [ -5468,  -6377],
                        [ -5113,  -6039],
                        [ -4736,  -5679],
                        [ -4340,  -5298],
                        [ -3922,  -4894],
                        [ -3486,  -4470],
                        [ -3032,  -4026],
                        [ -2562,  -3562],
                        [ -2076,  -3079],
                        [ -1575,  -2578],
                        [ -1064,  -2062],
                        [  -543,  -1530],
                        [   -14,   -985],
                        [   517,   -430],
                        [  1047,    132],
                        [  1574,    699],
                        [  2097,   1268],
                        [  2618,   1835],
                        [  3129,   2393],
                        [  3642,   2949],
                        [  4140,   3485],
                        [  4542,   3924],
                        [  4780,   4194],
                        [  4837,   4283],
                        [  4706,   4181],
                        [  4353,   3857],
                        [  3752,   3285],
                        [  2984,   2545],
                        [  2178,   1769],
                        [  1379,    999],
                        [   582,    232],
                        [  -199,   -516],
                        [  -949,  -1234],
                        [ -1657,  -1912],
                        [ -2319,  -2543],
                        [ -2923,  -3122],
                        [ -3465,  -3643],
                        [ -3941,  -4103],
                        [ -4350,  -4500],
                        [ -4692,  -4832],
                        [ -4968,  -5100],
                        [ -5182,  -5304],
                        [ -5336,  -5445],
                        [ -5431,  -5533],
                        [ -5470,  -5571],
                        [ -5457,  -5569],
                        [ -5393,  -5532],
                        [ -5283,  -5466],
                        [ -5130,  -5374],
                        [ -4938,  -5249],
                        [ -4710,  -5094],
                        [ -4451,  -4900],
                        [ -4163,  -4672],
                        [ -3850,  -4407],
                        [ -3515,  -4108],
                        [ -3161,  -3778],
                        [ -2793,  -3419],
                        [ -2412,  -3032],
                        [ -2022,  -2621],
                        [ -1626,  -2193],
                        [ -1228,  -1751],
                        [  -831,  -1302],
                        [  -436,   -848],
                        [   -49,   -397],
                        [   331,     54],
                        [   701,    501],
                        [  1061,    941],
                        [  1410,   1370],
                        [  1745,   1789],
                        [  2066,   2193],
                        [  2370,   2582],
                        [  2656,   2953],
                        [  2922,   3305],
                        [  3166,   3635],
                        [  3386,   3942],
                        [  3582,   4223],
                        [  3751,   4477],
                        [  3899,   4701],
                        [  4024,   4895],
                        [  4139,   5056],
                        [  4240,   5184],
                        [  4330,   5276],
                        [  4407,   5332],
                        [  4461,   5352],
                        [  4494,   5333],
                        [  4483,   5278],
                        [  4430,   5184],
                        [  4331,   5052],
                        [  4186,   4883],
                        [  3995,   4676],
                        [  3758,   4431],
                        [  3477,   4150],
                        [  3154,   3835],
                        [  2795,   3491],
                        [  2400,   3117],
                        [  2013,   2755],
                        [  1632,   2406],
                        [  1299,   2106],
                        [  1011,   1854],
                        [   767,   1649],
                        [   570,   1490],
                        [   358,   1318],
                        [   137,   1135],
                        [  -133,    900],
                        [  -451,    617],
                        [  -806,    291],
                        [ -1199,    -76],
                        [ -1622,   -479],
                        [ -2072,   -914],
                        [ -2542,  -1372],
                        [ -3027,  -1853],
                        [ -3522,  -2347],
                        [ -4024,  -2853],
                        [ -4522,  -3360],
                        [ -5017,  -3867],
                        [ -5500,  -4364],
                        [ -5970,  -4852],
                        [ -6420,  -5322],
                        [ -6849,  -5773],
                        [ -7252,  -6200],
                        [ -7629,  -6604],
                        [ -7979,  -6983],
                        [ -8301,  -7339],
                        [ -8599,  -7668],
                        [ -8870,  -7973],
                        [ -9117,  -8253],
                        [ -9341,  -8506],
                        [ -9542,  -8735],
                        [ -9721,  -8939],
                        [ -9881,  -9122],
                        [-10022,  -9284],
                        [-10149,  -9432],
                        [-10261,  -9562],
                        [-10361,  -9682],
                        [-10450,  -9791],
                        [-10527,  -9891],
                        [-10592,  -9984],
                        [-10644, -10073],
                        [-10685, -10156],
                        [-10723, -10240],
                        [-10753, -10320],
                        [-10785, -10395],
                        [-10827, -10475],
                        [-10866, -10545],
                        [-10837, -10540],
                        [-10693, -10414],
                        [-10429, -10164],
                        [-10038,  -9783],
                        [ -9485,  -9237],
                        [ -8737,  -8495],
                        [ -7859,  -7621],
                        [ -6962,  -6728],
                        [ -6078,  -5849],
                        [ -5207,  -4986],
                        [ -4362,  -4149],
                        [ -3560,  -3358],
                        [ -2810,  -2620],
                        [ -2117,  -1940],
                        [ -1492,  -1327],
                        [  -938,   -785],
                        [  -458,   -316],
                        [   -53,     78],
                        [   276,    396],
                        [   538,    639],
                        [   730,    811],
                        [   862,    917],
                        [   934,    960],
                        [   954,    956],
                        [   924,    910],
                        [   851,    834],
                        [   740,    733],
                        [   597,    612],
                        [   428,    477],
                        [   237,    319],
                        [    32,    145],
                        [  -185,    -49],
                        [  -407,   -259],
                        [  -631,   -485],
                        [  -854,   -720],
                        [ -1071,   -968],
                        [ -1280,  -1222],
                        [ -1476,  -1479],
                        [ -1658,  -1738],
                        [ -1824,  -1988],
                        [ -1972,  -2229],
                        [ -2101,  -2453],
                        [ -2211,  -2660],
                        [ -2302,  -2849],
                        [ -2373,  -3018],
                        [ -2429,  -3170],
                        [ -2472,  -3306],
                        [ -2503,  -3426],
                        [ -2523,  -3530],
                        [ -2536,  -3620],
                        [ -2542,  -3699],
                        [ -2545,  -3766],
                        [ -2546,  -3827],
                        [ -2548,  -3881],
                        [ -2551,  -3931],
                        [ -2561,  -3978],
                        [ -2578,  -4024],
                        [ -2615,  -4071],
                        [ -2676,  -4120],
                        [ -2765,  -4171],
                        [ -2884,  -4228],
                        [ -3034,  -4290],
                        [ -3216,  -4358],
                        [ -3411,  -4434],
                        [ -3622,  -4517],
                        [ -3834,  -4608],
                        [ -4049,  -4707],
                        [ -4262,  -4812],
                        [ -4473,  -4926],
                        [ -4678,  -5043],
                        [ -4877,  -5165],
                        [ -5068,  -5292],
                        [ -5253,  -5422],
                        [ -5447,  -5572],
                        [ -5648,  -5742],
                        [ -5907,  -5982],
                        [ -6221,  -6286],
                        [ -6598,  -6664],
                        [ -7036,  -7113],
                        [ -7503,  -7601],
                        [ -8002,  -8128],
                        [ -8444,  -8608],
                        [ -8834,  -9042],
                        [ -9159,  -9414],
                        [ -9414,  -9724],
                        [ -9603,  -9969],
                        [ -9720, -10144],
                        [ -9769, -10254],
                        [ -9748, -10296],
                        [ -9661, -10272],
                        [ -9508, -10183],
                        [ -9294, -10033],
                        [ -9019,  -9820],
                        [ -8691,  -9553],
                        [ -8307,  -9229],
                        [ -7879,  -8860],
                        [ -7404,  -8443],
                        [ -6893,  -7985],
                        [ -6346,  -7489],
                        [ -5770,  -6957],
                        [ -5163,  -6393],
                        [ -4534,  -5800],
                        [ -3881,  -5181],
                        [ -3210,  -4538],
                        [ -2523,  -3877],
                        [ -1824,  -3202],
                        [ -1118,  -2517],
                        [  -408,  -1827],
                        [   304,  -1132],
                        [  1012,   -437],
                        [  1713,    254],
                        [  2404,    941],
                        [  3082,   1619],
                        [  3738,   2285],
                        [  4371,   2937],
                        [  4971,   3571],
                        [  5533,   4181],
                        [  6059,   4768],
                        [  6543,   5326],
                        [  6992,   5852],
                        [  7399,   6341],
                        [  7781,   6797],
                        [  8114,   7202],
                        [  8354,   7508],
                        [  8476,   7690],
                        [  8479,   7748],
                        [  8356,   7673],
                        [  8067,   7429],
                        [  7577,   6976],
                        [  6924,   6359],
                        [  6199,   5664],
                        [  5424,   4916],
                        [  4604,   4120],
                        [  3759,   3294],
                        [  2904,   2456],
                        [  2055,   1619],
                        [  1222,    791],
                        [   418,    -13],
                        [  -346,   -782],
                        [ -1061,  -1510],
                        [ -1723,  -2188],
                        [ -2324,  -2810],
                        [ -2861,  -3371],
                        [ -3335,  -3868],
                        [ -3743,  -4299],
                        [ -4084,  -4668],
                        [ -4357,  -4975],
                        [ -4564,  -5228],
                        [ -4706,  -5431],
                        [ -4785,  -5584],
                        [ -4803,  -5693],
                        [ -4764,  -5753],
                        [ -4670,  -5767],
                        [ -4527,  -5726],
                        [ -4338,  -5633],
                        [ -4107,  -5487],
                        [ -3839,  -5291],
                        [ -3538,  -5042],
                        [ -3209,  -4748],
                        [ -2858,  -4408],
                        [ -2489,  -4025],
                        [ -2108,  -3611],
                        [ -1719,  -3169],
                        [ -1328,  -2714],
                        [  -940,  -2247],
                        [  -559,  -1780],
                        [  -189,  -1316],
                        [   167,   -860],
                        [   506,   -413],
                        [   825,     17],
                        [  1123,    430],
                        [  1396,    820],
                        [  1643,   1185],
                        [  1861,   1523],
                        [  2049,   1830],
                        [  2205,   2104],
                        [  2329,   2345],
                        [  2418,   2549],
                        [  2473,   2715],
                        [  2498,   2843],
                        [  2494,   2931],
                        [  2470,   2978],
                        [  2426,   2984],
                        [  2365,   2949],
                        [  2288,   2874],
                        [  2191,   2760],
                        [  2078,   2606],
                        [  1928,   2415],
                        [  1746,   2188],
                        [  1529,   1926],
                        [  1281,   1634],
                        [   998,   1311],
                        [   682,    957],
                        [   336,    578],
                        [   -34,    178],
                        [  -423,   -236],
                        [  -830,   -663],
                        [ -1201,  -1050],
                        [ -1537,  -1399],
                        [ -1803,  -1673],
                        [ -1999,  -1872],
                        [ -2120,  -1993],
                        [ -2165,  -2035],
                        [ -2198,  -2061],
                        [ -2214,  -2069],
                        [ -2263,  -2108],
                        [ -2338,  -2172],
                        [ -2441,  -2263],
                        [ -2568,  -2378],
                        [ -2719,  -2519],
                        [ -2896,  -2683],
                        [ -3091,  -2867],
                        [ -3305,  -3072],
                        [ -3534,  -3291],
                        [ -3776,  -3525],
                        [ -4026,  -3768],
                        [ -4285,  -4019],
                        [ -4545,  -4271],
                        [ -4808,  -4526],
                        [ -5066,  -4778],
                        [ -5320,  -5025],
                        [ -5567,  -5266],
                        [ -5805,  -5498],
                        [ -6035,  -5722],
                        [ -6255,  -5937],
                        [ -6468,  -6142],
                        [ -6674,  -6339],
                        [ -6871,  -6524],
                        [ -7059,  -6699],
                        [ -7241,  -6862],
                        [ -7415,  -7015],
                        [ -7583,  -7158],
                        [ -7744,  -7291],
                        [ -7898,  -7417],
                        [ -8049,  -7537],
                        [ -8190,  -7651],
                        [ -8323,  -7763],
                        [ -8443,  -7871],
                        [ -8547,  -7974],
                        [ -8632,  -8073],
                        [ -8700,  -8170],
                        [ -8755,  -8262],
                        [ -8793,  -8348],
                        [ -8825,  -8426],
                        [ -8855,  -8502],
                        [ -8873,  -8560],
                        [ -8852,  -8576],
                        [ -8792,  -8548],
                        [ -8697,  -8482],
                        [ -8555,  -8366],
                        [ -8328,  -8162],
                        [ -7968,  -7824],
                        [ -7489,  -7365],
                        [ -6944,  -6839],
                        [ -6351,  -6264],
                        [ -5710,  -5641],
                        [ -5038,  -4989],
                        [ -4348,  -4318],
                        [ -3651,  -3638],
                        [ -2953,  -2958],
                        [ -2266,  -2289],
                        [ -1599,  -1637],
                        [  -958,  -1010],
                        [  -345,   -410],
                        [   231,    154],
                        [   772,    683],
                        [  1275,   1172],
                        [  1741,   1623],
                        [  2169,   2036],
                        [  2559,   2419],
                        [  2910,   2771],
                        [  3227,   3102],
                        [  3510,   3413],
                        [  3760,   3704],
                        [  3979,   3979],
                        [  4169,   4231],
                        [  4334,   4463],
                        [  4474,   4666],
                        [  4593,   4845],
                        [  4692,   4994],
                        [  4773,   5116],
                        [  4838,   5203],
                        [  4888,   5261],
                        [  4927,   5289],
                        [  4955,   5287],
                        [  4975,   5267],
                        [  4987,   5227],
                        [  4991,   5177],
                        [  4990,   5120],
                        [  4983,   5055],
                        [  4969,   4984],
                        [  4949,   4906],
                        [  4921,   4821],
                        [  4883,   4730],
                        [  4837,   4631],
                        [  4779,   4526],
                        [  4712,   4413],
                        [  4631,   4292],
                        [  4539,   4162],
                        [  4433,   4025],
                        [  4314,   3878],
                        [  4181,   3722],
                        [  4032,   3558],
                        [  3862,   3385],
                        [  3669,   3204],
                        [  3452,   3014],
                        [  3211,   2819],
                        [  2945,   2618],
                        [  2654,   2411],
                        [  2350,   2200],
                        [  2034,   1987],
                        [  1719,   1772],
                        [  1406,   1557],
                        [  1099,   1342],
                        [   803,   1133],
                        [   522,    930],
                        [   258,    735],
                        [    12,    550],
                        [  -215,    373],
                        [  -443,    184],
                        [  -667,    -12],
                        [  -935,   -263],
                        [ -1242,   -564],
                        [ -1595,   -922],
                        [ -1993,  -1336],
                        [ -2414,  -1783],
                        [ -2858,  -2262],
                        [ -3242,  -2689],
                        [ -3570,  -3068],
                        [ -3829,  -3383],
                        [ -4016,  -3633],
                        [ -4128,  -3811],
                        [ -4162,  -3916],
                        [ -4121,  -3947],
                        [ -4003,  -3903],
                        [ -3811,  -3787],
                        [ -3548,  -3599],
                        [ -3216,  -3340],
                        [ -2818,  -3015],
                        [ -2361,  -2630],
                        [ -1846,  -2184],
                        [ -1284,  -1688],
                        [  -676,  -1141],
                        [   -33,   -554],
                        [   645,     72],
                        [  1346,    726],
                        [  2070,   1407],
                        [  2809,   2108],
                        [  3560,   2827],
                        [  4317,   3553],
                        [  5075,   4284],
                        [  5828,   5012],
                        [  6574,   5734],
                        [  7304,   6441],
                        [  8015,   7131],
                        [  8704,   7800],
                        [  9365,   8444],
                        [  9995,   9059],
                        [ 10589,   9644],
                        [ 11138,  10195],
                        [ 11639,  10710],
                        [ 12084,  11185],
                        [ 12469,  11616],
                        [ 12794,  12003],
                        [ 13058,  12344],
                        [ 13269,  12636],
                        [ 13424,  12876],
                        [ 13535,  13066],
                        [ 13596,  13201],
                        [ 13612,  13284],
                        [ 13601,  13334],
                        [ 13573,  13359],
                        [ 13518,  13349],
                        [ 13404,  13273],
                        [ 13176,  13076],
                        [ 12821,  12745],
                        [ 12367,  12306],
                        [ 11828,  11776],
                        [ 11213,  11165],
                        [ 10537,  10486],
                        [  9818,   9758],
                        [  9069,   8994],
                        [  8300,   8205],
                        [  7526,   7406],
                        [  6761,   6610],
                        [  6014,   5826],
                        [  5295,   5066],
                        [  4612,   4338],
                        [  3973,   3650],
                        [  3381,   3008],
                        [  2840,   2416],
                        [  2352,   1876],
                        [  1924,   1390],
                        [  1554,    954],
                        [  1242,    570],
                        [   987,    232],
                        [   791,    -58],
                        [   649,   -300],
                        [   560,   -496],
                        [   520,   -641],
                        [   527,   -737],
                        [   575,   -782],
                        [   662,   -779],
                        [   782,   -724],
                        [   930,   -623],
                        [  1099,   -475],
                        [  1287,   -283],
                        [  1486,    -57],
                        [  1692,    200],
                        [  1899,    470],
                        [  2104,    754],
                        [  2300,   1034],
                        [  2485,   1310],
                        [  2654,   1578],
                        [  2803,   1833],
                        [  2932,   2070],
                        [  3036,   2287],
                        [  3114,   2481],
                        [  3166,   2648],
                        [  3190,   2786],
                        [  3183,   2895],
                        [  3148,   2972],
                        [  3083,   3016],
                        [  2988,   3027],
                        [  2863,   3004],
                        [  2715,   2947],
                        [  2542,   2856],
                        [  2351,   2733],
                        [  2143,   2577],
                        [  1922,   2392],
                        [  1692,   2177],
                        [  1454,   1936],
                        [  1211,   1670],
                        [   957,   1382],
                        [   694,   1074],
                        [   420,    750],
                        [   139,    413],
                        [  -151,     63],
                        [  -450,   -297],
                        [  -753,   -661],
                        [ -1056,  -1026],
                        [ -1353,  -1383],
                        [ -1641,  -1730],
                        [ -1878,  -2020],
                        [ -2062,  -2256],
                        [ -2173,  -2411],
                        [ -2208,  -2487],
                        [ -2157,  -2472],
                        [ -2021,  -2364],
                        [ -1853,  -2221],
                        [ -1649,  -2037],
                        [ -1456,  -1857],
                        [ -1268,  -1676],
                        [ -1093,  -1504],
                        [  -930,  -1339],
                        [  -784,  -1188],
                        [  -658,  -1051],
                        [  -553,   -931],
                        [  -469,   -828],
                        [  -406,   -743],
                        [  -367,   -679],
                        [  -349,   -634],
                        [  -355,   -607],
                        [  -379,   -597],
                        [  -425,   -608],
                        [  -486,   -633],
                        [  -566,   -675],
                        [  -660,   -730],
                        [  -769,   -800],
                        [  -891,   -881],
                        [ -1026,   -974],
                        [ -1173,  -1077],
                        [ -1332,  -1190],
                        [ -1501,  -1311],
                        [ -1680,  -1439],
                        [ -1866,  -1570],
                        [ -2059,  -1705],
                        [ -2256,  -1842],
                        [ -2457,  -1980],
                        [ -2659,  -2120],
                        [ -2861,  -2260],
                        [ -3055,  -2399],
                        [ -3244,  -2539],
                        [ -3412,  -2676],
                        [ -3560,  -2807],
                        [ -3686,  -2933],
                        [ -3784,  -3051],
                        [ -3858,  -3157],
                        [ -3904,  -3252],
                        [ -3936,  -3332],
                        [ -3946,  -3394],
                        [ -3945,  -3441],
                        [ -3961,  -3505],
                        [ -4025,  -3616],
                        [ -4144,  -3778],
                        [ -4306,  -3982],
                        [ -4480,  -4196],
                        [ -4600,  -4353],
                        [ -4614,  -4401],
                        [ -4522,  -4340],
                        [ -4331,  -4179],
                        [ -4045,  -3921],
                        [ -3677,  -3577],
                        [ -3234,  -3157],
                        [ -2727,  -2671],
                        [ -2163,  -2126],
                        [ -1554,  -1536],
                        [  -911,   -907],
                        [  -242,   -249],
                        [   444,    429],
                        [  1138,   1120],
                        [  1832,   1816],
                        [  2523,   2511],
                        [  3204,   3200],
                        [  3871,   3879],
                        [  4518,   4546],
                        [  5142,   5196],
                        [  5741,   5830],
                        [  6312,   6446],
                        [  6849,   7042],
                        [  7354,   7618],
                        [  7824,   8168],
                        [  8257,   8693],
                        [  8653,   9182],
                        [  9011,   9638],
                        [  9330,  10050],
                        [  9612,  10420],
                        [  9855,  10738],
                        [ 10061,  11005],
                        [ 10233,  11221],
                        [ 10369,  11383],
                        [ 10472,  11499],
                        [ 10541,  11569],
                        [ 10578,  11604],
                        [ 10584,  11606],
                        [ 10560,  11576],
                        [ 10509,  11516],
                        [ 10431,  11427],
                        [ 10326,  11310],
                        [ 10197,  11167],
                        [ 10043,  10999],
                        [  9867,  10808],
                        [  9670,  10595],
                        [  9451,  10361],
                        [  9213,  10108],
                        [  8958,   9839],
                        [  8687,   9555],
                        [  8402,   9258],
                        [  8103,   8948],
                        [  7792,   8630],
                        [  7471,   8306],
                        [  7139,   7977],
                        [  6801,   7647],
                        [  6455,   7316],
                        [  6101,   6988],
                        [  5743,   6664],
                        [  5384,   6348],
                        [  5032,   6042],
                        [  4687,   5746],
                        [  4357,   5463],
                        [  4043,   5198],
                        [  3752,   4952],
                        [  3484,   4726],
                        [  3242,   4522],
                        [  3026,   4337],
                        [  2818,   4155],
                        [  2623,   3980],
                        [  2412,   3780],
                        [  2188,   3560],
                        [  1942,   3309],
                        [  1674,   3029],
                        [  1390,   2727],
                        [  1091,   2401],
                        [   836,   2114],
                        [   620,   1860],
                        [   457,   1653],
                        [   345,   1493],
                        [   293,   1389],
                        [   299,   1338],
                        [   366,   1347],
                        [   492,   1411],
                        [   675,   1534],
                        [   917,   1713],
                        [  1211,   1945],
                        [  1556,   2230],
                        [  1947,   2560],
                        [  2381,   2936],
                        [  2850,   3351],
                        [  3352,   3802],
                        [  3878,   4281],
                        [  4426,   4786],
                        [  4985,   5305],
                        [  5554,   5839],
                        [  6126,   6377],
                        [  6697,   6918],
                        [  7261,   7452],
                        [  7815,   7977],
                        [  8351,   8484],
                        [  8868,   8972],
                        [  9360,   9433],
                        [  9822,   9864],
                        [ 10251,  10261],
                        [ 10645,  10623],
                        [ 10996,  10945],
                        [ 11307,  11228],
                        [ 11565,  11469],
                        [ 11769,  11667],
                        [ 11914,  11818],
                        [ 11998,  11924],
                        [ 12022,  11984],
                        [ 11984,  11996],
                        [ 11897,  11962],
                        [ 11760,  11880],
                        [ 11578,  11750],
                        [ 11376,  11594],
                        [ 11212,  11473],
                        [ 11127,  11425],
                        [ 11135,  11461],
                        [ 11230,  11578],
                        [ 11390,  11753],
                        [ 11544,  11915],
                        [ 11611,  11980],
                        [ 11572,  11935],
                        [ 11438,  11787],
                        [ 11214,  11543],
                        [ 10911,  11215],
                        [ 10539,  10812],
                        [ 10107,  10345],
                        [  9623,   9825],
                        [  9101,   9263],
                        [  8550,   8670],
                        [  7982,   8058],
                        [  7405,   7433],
                        [  6831,   6806],
                        [  6266,   6186],
                        [  5714,   5577],
                        [  5184,   4989],
                        [  4676,   4423],
                        [  4197,   3885],
                        [  3748,   3378],
                        [  3331,   2901],
                        [  2948,   2457],
                        [  2598,   2045],
                        [  2282,   1662],
                        [  1999,   1307],
                        [  1747,    982],
                        [  1525,    685],
                        [  1330,    418],
                        [  1159,    180],
                        [  1009,    -24],
                        [   878,   -199],
                        [   758,   -340],
                        [   649,   -453],
                        [   544,   -540],
                        [   443,   -605],
                        [   340,   -660],
                        [   234,   -707],
                        [   120,   -759],
                        [    -2,   -817],
                        [  -137,   -882],
                        [  -287,   -959],
                        [  -453,  -1049],
                        [  -636,  -1156],
                        [  -837,  -1280],
                        [ -1055,  -1420],
                        [ -1292,  -1580],
                        [ -1547,  -1761],
                        [ -1816,  -1958],
                        [ -2102,  -2175],
                        [ -2401,  -2410],
                        [ -2712,  -2662],
                        [ -3032,  -2929],
                        [ -3362,  -3211],
                        [ -3699,  -3504],
                        [ -4041,  -3808],
                        [ -4382,  -4119],
                        [ -4723,  -4436],
                        [ -5052,  -4756],
                        [ -5368,  -5076],
                        [ -5668,  -5394],
                        [ -5950,  -5707],
                        [ -6213,  -6013],
                        [ -6455,  -6306],
                        [ -6679,  -6588],
                        [ -6883,  -6858],
                        [ -7066,  -7109],
                        [ -7223,  -7339],
                        [ -7353,  -7542],
                        [ -7455,  -7717],
                        [ -7505,  -7838],
                        [ -7505,  -7906],
                        [ -7447,  -7914],
                        [ -7333,  -7858],
                        [ -7144,  -7722],
                        [ -6882,  -7508],
                        [ -6576,  -7243],
                        [ -6226,  -6927],
                        [ -5863,  -6592],
                        [ -5487,  -6234],
                        [ -5111,  -5870],
                        [ -4734,  -5497],
                        [ -4368,  -5128],
                        [ -4013,  -4763],
                        [ -3678,  -4411],
                        [ -3365,  -4074],
                        [ -3079,  -3759],
                        [ -2820,  -3465],
                        [ -2592,  -3196],
                        [ -2397,  -2957],
                        [ -2234,  -2747],
                        [ -2107,  -2569],
                        [ -2011,  -2422],
                        [ -1950,  -2308],
                        [ -1920,  -2225],
                        [ -1921,  -2172],
                        [ -1951,  -2147],
                        [ -2009,  -2151],
                        [ -2093,  -2178],
                        [ -2214,  -2241],
                        [ -2353,  -2321],
                        [ -2511,  -2418],
                        [ -2681,  -2526],
                        [ -2863,  -2646],
                        [ -3052,  -2770],
                        [ -3244,  -2899],
                        [ -3436,  -3029],
                        [ -3625,  -3158],
                        [ -3802,  -3284],
                        [ -3966,  -3404],
                        [ -4106,  -3516],
                        [ -4219,  -3616],
                        [ -4301,  -3702],
                        [ -4350,  -3771],
                        [ -4364,  -3820],
                        [ -4344,  -3850],
                        [ -4297,  -3854],
                        [ -4215,  -3829],
                        [ -4141,  -3809],
                        [ -4148,  -3874],
                        [ -4280,  -4063],
                        [ -4544,  -4380],
                        [ -4934,  -4824],
                        [ -5436,  -5376],
                        [ -5964,  -5949],
                        [ -6406,  -6433],
                        [ -6725,  -6789],
                        [ -6928,  -7027],
                        [ -7019,  -7145],
                        [ -7000,  -7149],
                        [ -6875,  -7044],
                        [ -6658,  -6844],
                        [ -6346,  -6546],
                        [ -5949,  -6160],
                        [ -5476,  -5694],
                        [ -4938,  -5158],
                        [ -4347,  -4561],
                        [ -3712,  -3912],
                        [ -3041,  -3221],
                        [ -2347,  -2497],
                        [ -1636,  -1749],
                        [  -915,   -986],
                        [  -194,   -219],
                        [   521,    548],
                        [  1223,   1304],
                        [  1905,   2043],
                        [  2562,   2764],
                        [  3186,   3459],
                        [  3774,   4128],
                        [  4322,   4769],
                        [  4826,   5374],
                        [  5285,   5942],
                        [  5693,   6462],
                        [  6053,   6933],
                        [  6361,   7346],
                        [  6619,   7699],
                        [  6827,   7990],
                        [  6983,   8217],
                        [  7092,   8383],
                        [  7150,   8489],
                        [  7161,   8544],
                        [  7126,   8549],
                        [  7048,   8508],
                        [  6933,   8430],
                        [  6784,   8312],
                        [  6603,   8156],
                        [  6392,   7966],
                        [  6153,   7746],
                        [  5891,   7497],
                        [  5607,   7222],
                        [  5306,   6927],
                        [  4989,   6612],
                        [  4661,   6284],
                        [  4323,   5942],
                        [  3980,   5592],
                        [  3635,   5238],
                        [  3295,   4882],
                        [  2961,   4526],
                        [  2640,   4175],
                        [  2338,   3837],
                        [  2048,   3507],
                        [  1773,   3190],
                        [  1505,   2887],
                        [  1248,   2601],
                        [  1002,   2334],
                        [   768,   2087],
                        [   550,   1861],
                        [   350,   1661],
                        [   172,   1485],
                        [    16,   1335],
                        [  -118,   1208],
                        [  -229,   1107],
                        [  -323,   1021],
                        [  -400,    952],
                        [  -464,    895],
                        [  -514,    850],
                        [  -562,    804],
                        [  -609,    757],
                        [  -671,    692],
                        [  -748,    610],
                        [  -815,    535],
                        [  -874,    465],
                        [  -915,    409],
                        [  -942,    366],
                        [  -943,    345],
                        [  -921,    343],
                        [  -871,    367],
                        [  -795,    415],
                        [  -691,    491],
                        [  -560,    592],
                        [  -401,    719],
                        [  -217,    872],
                        [    -9,   1049],
                        [   220,   1247],
                        [   468,   1465],
                        [   730,   1700],
                        [  1004,   1948],
                        [  1286,   2206],
                        [  1571,   2469],
                        [  1858,   2734],
                        [  2139,   2995],
                        [  2415,   3248],
                        [  2678,   3488],
                        [  2929,   3714],
                        [  3161,   3919],
                        [  3375,   4102],
                        [  3564,   4259],
                        [  3729,   4388],
                        [  3866,   4486],
                        [  3973,   4552],
                        [  4046,   4584],
                        [  4087,   4583],
                        [  4086,   4546],
                        [  4045,   4474],
                        [  3962,   4369],
                        [  3835,   4228],
                        [  3664,   4053],
                        [  3451,   3845],
                        [  3205,   3608],
                        [  2924,   3338],
                        [  2615,   3036],
                        [  2333,   2760],
                        [  2173,   2602],
                        [  2178,   2607],
                        [  2357,   2780],
                        [  2716,   3129],
                        [  3247,   3643],
                        [  3859,   4235],
                        [  4420,   4769],
                        [  4886,   5204],
                        [  5265,   5547],
                        [  5557,   5797],
                        [  5759,   5956],
                        [  5877,   6027],
                        [  5910,   6015],
                        [  5865,   5926],
                        [  5748,   5765],
                        [  5566,   5540],
                        [  5327,   5258],
                        [  5039,   4925],
                        [  4711,   4548],
                        [  4349,   4135],
                        [  3959,   3690],
                        [  3545,   3222],
                        [  3113,   2737],
                        [  2667,   2240],
                        [  2212,   1741],
                        [  1750,   1243],
                        [  1285,    748],
                        [   819,    259],
                        [   353,   -228],
                        [  -107,   -713],
                        [  -564,  -1198],
                        [ -1015,  -1684],
                        [ -1458,  -2165],
                        [ -1896,  -2644],
                        [ -2329,  -3114],
                        [ -2755,  -3575],
                        [ -3178,  -4023],
                        [ -3597,  -4458],
                        [ -4014,  -4880],
                        [ -4428,  -5289],
                        [ -4839,  -5690],
                        [ -5248,  -6082],
                        [ -5654,  -6474],
                        [ -6059,  -6865],
                        [ -6463,  -7253],
                        [ -6865,  -7641],
                        [ -7267,  -8028],
                        [ -7669,  -8415],
                        [ -8069,  -8801],
                        [ -8466,  -9185],
                        [ -8860,  -9566],
                        [ -9248,  -9943],
                        [ -9628, -10316],
                        [-10002, -10684],
                        [-10363, -11044],
                        [-10713, -11395],
                        [-11052, -11734],
                        [-11378, -12062],
                        [-11695, -12374],
                        [-12002, -12669],
                        [-12296, -12946],
                        [-12575, -13202],
                        [-12826, -13436],
                        [-13050, -13646],
                        [-13237, -13831],
                        [-13384, -13989],
                        [-13492, -14117],
                        [-13558, -14217],
                        [-13586, -14286],
                        [-13574, -14327],
                        [-13526, -14334],
                        [-13438, -14309],
                        [-13315, -14252],
                        [-13157, -14161],
                        [-12972, -14042],
                        [-12762, -13898],
                        [-12530, -13730],
                        [-12279, -13539],
                        [-11985, -13301],
                        [-11651, -13017],
                        [-11272, -12683],
                        [-10849, -12299],
                        [-10399, -11880],
                        [ -9923, -11429],
                        [ -9436, -10958],
                        [ -8940, -10468],
                        [ -8446,  -9975],
                        [ -7956,  -9478],
                        [ -7482,  -8988],
                        [ -7022,  -8507],
                        [ -6589,  -8045],
                        [ -6179,  -7602],
                        [ -5802,  -7185],
                        [ -5457,  -6796],
                        [ -5147,  -6440],
                        [ -4874,  -6117],
                        [ -4639,  -5830],
                        [ -4440,  -5580],
                        [ -4278,  -5367],
                        [ -4151,  -5189],
                        [ -4056,  -5043],
                        [ -3992,  -4929],
                        [ -3954,  -4841],
                        [ -3943,  -4778],
                        [ -3952,  -4738],
                        [ -3980,  -4716],
                        [ -4021,  -4707],
                        [ -4074,  -4712],
                        [ -4132,  -4723],
                        [ -4193,  -4739],
                        [ -4250,  -4755],
                        [ -4303,  -4768],
                        [ -4342,  -4773],
                        [ -4366,  -4770],
                        [ -4366,  -4752],
                        [ -4341,  -4719],
                        [ -4285,  -4666],
                        [ -4196,  -4591],
                        [ -4071,  -4492],
                        [ -3912,  -4370],
                        [ -3718,  -4215],
                        [ -3490,  -4031],
                        [ -3298,  -3884],
                        [ -3237,  -3871],
                        [ -3346,  -4025],
                        [ -3627,  -4352],
                        [ -4093,  -4860],
                        [ -4744,  -5550],
                        [ -5480,  -6321],
                        [ -6155,  -7026],
                        [ -6721,  -7616],
                        [ -7187,  -8099],
                        [ -7547,  -8471],
                        [ -7799,  -8730],
                        [ -7941,  -8874],
                        [ -7977,  -8909],
                        [ -7911,  -8839],
                        [ -7746,  -8669],
                        [ -7496,  -8408],
                        [ -7165,  -8060],
                        [ -6768,  -7638],
                        [ -6315,  -7148],
                        [ -5813,  -6601],
                        [ -5272,  -6004],
                        [ -4701,  -5371],
                        [ -4110,  -4710],
                        [ -3506,  -4037],
                        [ -2898,  -3359],
                        [ -2294,  -2689],
                        [ -1700,  -2037],
                        [ -1123,  -1403],
                        [  -570,   -795],
                        [   -46,   -207],
                        [   445,    353],
                        [   896,    886],
                        [  1307,   1389],
                        [  1674,   1853],
                        [  1994,   2277],
                        [  2269,   2655],
                        [  2498,   2986],
                        [  2680,   3265],
                        [  2818,   3494],
                        [  2910,   3670],
                        [  2958,   3795],
                        [  2964,   3874],
                        [  2929,   3909],
                        [  2858,   3905],
                        [  2750,   3863],
                        [  2614,   3786],
                        [  2451,   3678],
                        [  2266,   3543],
                        [  2062,   3382],
                        [  1844,   3200],
                        [  1615,   3001],
                        [  1377,   2789],
                        [  1136,   2567],
                        [   893,   2338],
                        [   653,   2105],
                        [   418,   1874],
                        [   194,   1645],
                        [   -11,   1423],
                        [  -194,   1209],
                        [  -349,   1007],
                        [  -472,    817],
                        [  -570,    644],
                        [  -638,    487],
                        [  -691,    348],
                        [  -726,    229],
                        [  -754,    131],
                        [  -769,     54],
                        [  -775,     -3],
                        [  -769,    -38],
                        [  -752,    -52],
                        [  -724,    -46],
                        [  -685,    -21],
                        [  -635,     22],
                        [  -564,     93],
                        [  -473,    189],
                        [  -345,    327],
                        [  -181,    503],
                        [     3,    704],
                        [   209,    929],
                        [   394,   1135],
                        [   560,   1324],
                        [   696,   1483],
                        [   803,   1612],
                        [   886,   1717],
                        [   942,   1793],
                        [   982,   1851],
                        [  1001,   1886],
                        [  1007,   1905],
                        [   996,   1907],
                        [   977,   1896],
                        [   947,   1872],
                        [   909,   1837],
                        [   862,   1792],
                        [   811,   1740],
                        [   753,   1679],
                        [   692,   1612],
                        [   625,   1537],
                        [   554,   1459],
                        [   479,   1373],
                        [   397,   1281],
                        [   307,   1181],
                        [   210,   1068],
                        [   104,    945],
                        [   -11,    808],
                        [  -137,    658],
                        [  -274,    492],
                        [  -422,    313],
                        [  -580,    119],
                        [  -750,    -90],
                        [  -933,   -315],
                        [ -1127,   -554],
                        [ -1334,   -808],
                        [ -1552,  -1077],
                        [ -1783,  -1359],
                        [ -2026,  -1653],
                        [ -2281,  -1957],
                        [ -2547,  -2272],
                        [ -2829,  -2596],
                        [ -3122,  -2926],
                        [ -3420,  -3257],
                        [ -3729,  -3597],
                        [ -4039,  -3935],
                        [ -4268,  -4192],
                        [ -4322,  -4273],
                        [ -4170,  -4147],
                        [ -3807,  -3812],
                        [ -3213,  -3247],
                        [ -2384,  -2446],
                        [ -1417,  -1510],
                        [  -467,   -592],
                        [   420,    262],
                        [  1247,   1055],
                        [  2008,   1779],
                        [  2687,   2424],
                        [  3283,   2987],
                        [  3789,   3465],
                        [  4206,   3857],
                        [  4531,   4163],
                        [  4768,   4384],
                        [  4922,   4522],
                        [  4996,   4580],
                        [  4997,   4561],
                        [  4928,   4468],
                        [  4792,   4307],
                        [  4595,   4083],
                        [  4340,   3803],
                        [  4035,   3476],
                        [  3681,   3113],
                        [  3285,   2717],
                        [  2850,   2297],
                        [  2381,   1856],
                        [  1882,   1389],
                        [  1358,    899],
                        [   813,    380],
                        [   250,   -165],
                        [  -325,   -734],
                        [  -912,  -1324],
                        [ -1506,  -1926],
                        [ -2104,  -2542],
                        [ -2705,  -3163],
                        [ -3305,  -3790],
                        [ -3903,  -4414],
                        [ -4496,  -5036],
                        [ -5078,  -5649],
                        [ -5651,  -6253],
                        [ -6208,  -6847],
                        [ -6749,  -7430],
                        [ -7274,  -7997],
                        [ -7778,  -8549],
                        [ -8264,  -9084],
                        [ -8729,  -9599],
                        [ -9171, -10093],
                        [ -9589, -10563],
                        [ -9982, -11008],
                        [-10348, -11426],
                        [-10686, -11816],
                        [-10994, -12177],
                        [-11271, -12506],
                        [-11516, -12803],
                        [-11733, -13066],
                        [-11923, -13293],
                        [-12091, -13485],
                        [-12237, -13639],
                        [-12363, -13756],
                        [-12470, -13834],
                        [-12545, -13874],
                        [-12588, -13875],
                        [-12586, -13838],
                        [-12540, -13763],
                        [-12448, -13651],
                        [-12308, -13502],
                        [-12125, -13318],
                        [-11900, -13100],
                        [-11635, -12849],
                        [-11332, -12566],
                        [-11004, -12261],
                        [-10649, -11936],
                        [-10307, -11624],
                        [ -9977, -11326],
                        [ -9672, -11053],
                        [ -9393, -10807],
                        [ -9111, -10557],
                        [ -8831, -10307],
                        [ -8509, -10014],
                        [ -8151,  -9680],
                        [ -7760,  -9310],
                        [ -7337,  -8903],
                        [ -6895,  -8472],
                        [ -6433,  -8016],
                        [ -5963,  -7547],
                        [ -5487,  -7066],
                        [ -5014,  -6584],
                        [ -4544,  -6100],
                        [ -4088,  -5627],
                        [ -3643,  -5160],
                        [ -3219,  -4712],
                        [ -2814,  -4279],
                        [ -2433,  -3870],
                        [ -2078,  -3483],
                        [ -1749,  -3124],
                        [ -1448,  -2791],
                        [ -1172,  -2486],
                        [  -921,  -2208],
                        [  -693,  -1952],
                        [  -486,  -1721],
                        [  -295,  -1506],
                        [  -119,  -1309],
                        [    46,  -1125],
                        [   201,   -951],
                        [   351,   -783],
                        [   497,   -622],
                        [   644,   -463],
                        [   795,   -303],
                        [   954,   -137],
                        [  1120,     35],
                        [  1299,    220],
                        [  1493,    418],
                        [  1701,    631],
                        [  1926,    860],
                        [  2173,   1110],
                        [  2445,   1380],
                        [  2742,   1670],
                        [  3062,   1977],
                        [  3411,   2311],
                        [  3778,   2659],
                        [  4076,   2938],
                        [  4224,   3066],
                        [  4199,   3022],
                        [  3993,   2799],
                        [  3581,   2373],
                        [  2946,   1727],
                        [  2185,    960],
                        [  1441,    215],
                        [   756,   -466],
                        [   123,  -1088],
                        [  -447,  -1641],
                        [  -944,  -2117],
                        [ -1363,  -2511],
                        [ -1701,  -2823],
                        [ -1959,  -3053],
                        [ -2136,  -3199],
                        [ -2238,  -3267],
                        [ -2269,  -3260],
                        [ -2239,  -3182],
                        [ -2153,  -3039],
                        [ -2017,  -2836],
                        [ -1836,  -2583],
                        [ -1619,  -2286],
                        [ -1372,  -1953],
                        [ -1102,  -1603],
                        [  -816,  -1241],
                        [  -518,   -882],
                        [  -217,   -531],
                        [    84,   -193],
                        [   379,    128],
                        [   662,    441],
                        [   930,    739],
                        [  1180,   1030],
                        [  1407,   1308],
                        [  1612,   1571],
                        [  1791,   1816],
                        [  1944,   2042],
                        [  2069,   2247],
                        [  2169,   2429],
                        [  2243,   2589],
                        [  2290,   2723],
                        [  2312,   2829],
                        [  2311,   2910],
                        [  2286,   2967],
                        [  2241,   3001],
                        [  2178,   3016],
                        [  2102,   3013],
                        [  2013,   2994],
                        [  1919,   2963],
                        [  1821,   2923],
                        [  1723,   2877],
                        [  1626,   2826],
                        [  1534,   2774],
                        [  1450,   2723],
                        [  1376,   2677],
                        [  1315,   2639],
                        [  1270,   2607],
                        [  1242,   2586],
                        [  1238,   2575],
                        [  1262,   2574],
                        [  1320,   2585],
                        [  1412,   2608],
                        [  1534,   2644],
                        [  1687,   2693],
                        [  1853,   2754],
                        [  2035,   2828],
                        [  2217,   2915],
                        [  2400,   3013],
                        [  2581,   3121],
                        [  2758,   3236],
                        [  2929,   3359],
                        [  3096,   3490],
                        [  3256,   3625],
                        [  3408,   3764],
                        [  3584,   3936],
                        [  3780,   4138],
                        [  4026,   4398],
                        [  4318,   4713],
                        [  4646,   5072],
                        [  5008,   5471],
                        [  5344,   5848],
                        [  5654,   6204],
                        [  5904,   6503],
                        [  6094,   6744],
                        [  6229,   6930],
                        [  6306,   7059],
                        [  6333,   7136],
                        [  6309,   7160],
                        [  6239,   7135],
                        [  6122,   7061],
                        [  5965,   6944],
                        [  5767,   6781],
                        [  5539,   6584],
                        [  5276,   6349],
                        [  4990,   6085],
                        [  4677,   5790],
                        [  4349,   5475],
                        [  4002,   5137],
                        [  3647,   4785],
                        [  3280,   4419],
                        [  2907,   4043],
                        [  2529,   3657],
                        [  2147,   3265],
                        [  1761,   2867],
                        [  1376,   2463],
                        [   990,   2056],
                        [   609,   1648],
                        [   232,   1242],
                        [  -139,    839],
                        [  -503,    440],
                        [  -859,     50],
                        [ -1204,   -334],
                        [ -1537,   -710],
                        [ -1856,  -1075],
                        [ -2159,  -1432],
                        [ -2442,  -1775],
                        [ -2708,  -2106],
                        [ -2956,  -2422],
                        [ -3194,  -2727],
                        [ -3415,  -3012],
                        [ -3624,  -3279],
                        [ -3826,  -3534],
                        [ -4004,  -3761],
                        [ -4078,  -3880],
                        [ -3983,  -3824],
                        [ -3708,  -3586],
                        [ -3248,  -3158],
                        [ -2570,  -2509],
                        [ -1656,  -1621],
                        [  -594,   -582],
                        [   482,    472],
                        [  1532,   1504],
                        [  2559,   2513],
                        [  3545,   3484],
                        [  4470,   4398],
                        [  5325,   5249],
                        [  6104,   6026],
                        [  6797,   6726],
                        [  7399,   7339],
                        [  7906,   7863],
                        [  8322,   8295],
                        [  8647,   8634],
                        [  8881,   8881],
                        [  9026,   9034],
                        [  9084,   9099],
                        [  9059,   9076],
                        [  8954,   8977],
                        [  8774,   8803],
                        [  8524,   8574],
                        [  8209,   8292],
                        [  7834,   7966],
                        [  7405,   7601],
                        [  6928,   7195],
                        [  6408,   6754],
                        [  5852,   6266],
                        [  5267,   5738],
                        [  4656,   5172],
                        [  4026,   4573],
                        [  3384,   3946],
                        [  2734,   3297],
                        [  2082,   2628],
                        [  1430,   1944],
                        [   786,   1255],
                        [   152,    564],
                        [  -464,   -119],
                        [ -1060,   -789],
                        [ -1632,  -1441],
                        [ -2175,  -2071],
                        [ -2687,  -2675],
                        [ -3166,  -3250],
                        [ -3611,  -3794],
                        [ -4019,  -4303],
                        [ -4391,  -4776],
                        [ -4724,  -5211],
                        [ -5018,  -5605],
                        [ -5272,  -5956],
                        [ -5486,  -6264],
                        [ -5659,  -6529],
                        [ -5791,  -6749],
                        [ -5882,  -6925],
                        [ -5939,  -7055],
                        [ -5961,  -7140],
                        [ -5961,  -7181],
                        [ -5938,  -7178],
                        [ -5896,  -7131],
                        [ -5837,  -7041],
                        [ -5753,  -6911],
                        [ -5646,  -6741],
                        [ -5501,  -6534],
                        [ -5321,  -6292],
                        [ -5103,  -6017],
                        [ -4848,  -5710],
                        [ -4558,  -5375],
                        [ -4235,  -5013],
                        [ -3883,  -4628],
                        [ -3504,  -4223],
                        [ -3120,  -3818],
                        [ -2730,  -3413],
                        [ -2390,  -3063],
                        [ -2099,  -2766],
                        [ -1870,  -2535],
                        [ -1704,  -2373],
                        [ -1572,  -2247],
                        [ -1477,  -2160],
                        [ -1348,  -2042],
                        [ -1190,  -1896],
                        [  -997,  -1716],
                        [  -770,  -1503],
                        [  -515,  -1261],
                        [  -231,   -990],
                        [    74,   -697],
                        [   401,   -381],
                        [   742,    -50],
                        [  1098,    296],
                        [  1462,    651],
                        [  1834,   1015],
                        [  2208,   1381],
                        [  2587,   1752],
                        [  2961,   2120],
                        [  3335,   2486],
                        [  3700,   2846],
                        [  4061,   3200],
                        [  4414,   3546],
                        [  4764,   3885],
                        [  5107,   4217],
                        [  5449,   4544],
                        [  5789,   4869],
                        [  6129,   5190],
                        [  6470,   5512],
                        [  6813,   5835],
                        [  7158,   6159],
                        [  7508,   6485],
                        [  7862,   6814],
                        [  8222,   7146],
                        [  8587,   7485],
                        [  8958,   7829],
                        [  9330,   8184],
                        [  9704,   8547],
                        [ 10077,   8920],
                        [ 10447,   9300],
                        [ 10822,   9689],
                        [ 11197,  10085],
                        [ 11578,  10486],
                        [ 11962,  10888],
                        [ 12354,  11298],
                        [ 12735,  11695],
                        [ 13033,  12010],
                        [ 13202,  12195],
                        [ 13236,  12246],
                        [ 13123,  12153],
                        [ 12824,  11875],
                        [ 12309,  11385],
                        [ 11648,  10752],
                        [ 10950,  10085],
                        [ 10241,   9411],
                        [  9518,   8729],
                        [  8800,   8053],
                        [  8098,   7396],
                        [  7421,   6765],
                        [  6776,   6166],
                        [  6170,   5605],
                        [  5608,   5089],
                        [  5090,   4617],
                        [  4617,   4193],
                        [  4188,   3817],
                        [  3799,   3489],
                        [  3454,   3207],
                        [  3149,   2971],
                        [  2881,   2774],
                        [  2649,   2615],
                        [  2448,   2479],
                        [  2275,   2362],
                        [  2129,   2254],
                        [  2004,   2151],
                        [  1901,   2050],
                        [  1814,   1947],
                        [  1744,   1856],
                        [  1684,   1772],
                        [  1634,   1705],
                        [  1593,   1653],
                        [  1558,   1616],
                        [  1527,   1591],
                        [  1501,   1584],
                        [  1477,   1590],
                        [  1457,   1614],
                        [  1438,   1650],
                        [  1422,   1697],
                        [  1407,   1751],
                        [  1394,   1808],
                        [  1384,   1868],
                        [  1376,   1931],
                        [  1371,   1996],
                        [  1372,   2065],
                        [  1377,   2139],
                        [  1393,   2219],
                        [  1419,   2306],
                        [  1454,   2399],
                        [  1502,   2501],
                        [  1564,   2611],
                        [  1639,   2730],
                        [  1727,   2858],
                        [  1829,   2996],
                        [  1946,   3141],
                        [  2078,   3296],
                        [  2234,   3460],
                        [  2411,   3632],
                        [  2616,   3810],
                        [  2847,   3993],
                        [  3101,   4180],
                        [  3379,   4370],
                        [  3661,   4561],
                        [  3950,   4751],
                        [  4228,   4939],
                        [  4497,   5124],
                        [  4748,   5301],
                        [  4981,   5468],
                        [  5190,   5624],
                        [  5379,   5770],
                        [  5545,   5906],
                        [  5689,   6030],
                        [  5856,   6186],
                        [  6040,   6370],
                        [  6274,   6614],
                        [  6555,   6914],
                        [  6877,   7264],
                        [  7241,   7662],
                        [  7574,   8036],
                        [  7880,   8389],
                        [  8113,   8671],
                        [  8271,   8883],
                        [  8361,   9027],
                        [  8379,   9101],
                        [  8330,   9107],
                        [  8212,   9043],
                        [  8034,   8917],
                        [  7795,   8729],
                        [  7504,   8483],
                        [  7162,   8184],
                        [  6777,   7837],
                        [  6351,   7445],
                        [  5892,   7016],
                        [  5405,   6552],
                        [  4898,   6063],
                        [  4374,   5550],
                        [  3840,   5023],
                        [  3298,   4483],
                        [  2755,   3937],
                        [  2212,   3389],
                        [  1671,   2841],
                        [  1138,   2297],
                        [   612,   1760],
                        [    98,   1230],
                        [  -401,    714],
                        [  -882,    214],
                        [ -1344,   -267],
                        [ -1784,   -725],
                        [ -2202,  -1160],
                        [ -2594,  -1571],
                        [ -2955,  -1956],
                        [ -3285,  -2314],
                        [ -3578,  -2649],
                        [ -3833,  -2955],
                        [ -4051,  -3235],
                        [ -4234,  -3486],
                        [ -4390,  -3711],
                        [ -4516,  -3904],
                        [ -4619,  -4068],
                        [ -4705,  -4208],
                        [ -4757,  -4307],
                        [ -4725,  -4316],
                        [ -4589,  -4216],
                        [ -4353,  -4009],
                        [ -4009,  -3686],
                        [ -3517,  -3211],
                        [ -2844,  -2550],
                        [ -2042,  -1756],
                        [ -1198,   -914],
                        [  -334,    -50],
                        [   543,    833],
                        [  1415,   1714],
                        [  2263,   2575],
                        [  3075,   3406],
                        [  3839,   4195],
                        [  4546,   4931],
                        [  5185,   5603],
                        [  5751,   6206],
                        [  6242,   6732],
                        [  6652,   7179],
                        [  6982,   7542],
                        [  7229,   7820],
                        [  7395,   8012],
                        [  7481,   8120],
                        [  7490,   8152],
                        [  7423,   8110],
                        [  7287,   8008],
                        [  7084,   7851],
                        [  6821,   7648],
                        [  6502,   7402],
                        [  6134,   7116],
                        [  5722,   6796],
                        [  5272,   6429],
                        [  4791,   6024],
                        [  4284,   5580],
                        [  3760,   5107],
                        [  3225,   4604],
                        [  2684,   4076],
                        [  2144,   3526],
                        [  1611,   2960],
                        [  1090,   2386],
                        [   584,   1808],
                        [   102,   1241],
                        [  -355,    687],
                        [  -781,    160],
                        [ -1174,   -340],
                        [ -1530,   -807],
                        [ -1847,  -1239],
                        [ -2124,  -1633],
                        [ -2360,  -1987],
                        [ -2557,  -2301],
                        [ -2711,  -2571],
                        [ -2827,  -2797],
                        [ -2901,  -2979],
                        [ -2936,  -3117],
                        [ -2933,  -3212],
                        [ -2893,  -3263],
                        [ -2819,  -3272],
                        [ -2716,  -3242],
                        [ -2587,  -3172],
                        [ -2441,  -3065],
                        [ -2281,  -2923],
                        [ -2113,  -2748],
                        [ -1939,  -2542],
                        [ -1757,  -2308],
                        [ -1569,  -2048],
                        [ -1365,  -1766],
                        [ -1148,  -1464],
                        [  -912,  -1146],
                        [  -662,   -814],
                        [  -395,   -469],
                        [  -115,   -115],
                        [   173,    243],
                        [   470,    604],
                        [   748,    939],
                        [  1008,   1250],
                        [  1195,   1480],
                        [  1311,   1632],
                        [  1345,   1694],
                        [  1294,   1665],
                        [  1188,   1573],
                        [  1023,   1415],
                        [   883,   1276],
                        [   764,   1150],
                        [   675,   1051],
                        [   619,    977],
                        [   599,    936],
                        [   613,    925],
                        [   663,    946],
                        [   747,    997],
                        [   865,   1079],
                        [  1016,   1193],
                        [  1198,   1335],
                        [  1413,   1506],
                        [  1653,   1703],
                        [  1923,   1927],
                        [  2215,   2173],
                        [  2529,   2442],
                        [  2862,   2731],
                        [  3213,   3038],
                        [  3580,   3360],
                        [  3963,   3699],
                        [  4359,   4050],
                        [  4772,   4414],
                        [  5198,   4792],
                        [  5636,   5181],
                        [  6086,   5582],
                        [  6546,   5994],
                        [  7014,   6411],
                        [  7487,   6835],
                        [  7963,   7262],
                        [  8444,   7691],
                        [  8920,   8122],
                        [  9389,   8551],
                        [  9844,   8979],
                        [ 10281,   9403],
                        [ 10697,   9823],
                        [ 11087,  10236],
                        [ 11456,  10637],
                        [ 11802,  11027],
                        [ 12128,  11399],
                        [ 12432,  11750],
                        [ 12716,  12081],
                        [ 12966,  12376],
                        [ 13150,  12608],
                        [ 13268,  12772],
                        [ 13321,  12872],
                        [ 13297,  12893],
                        [ 13151,  12795],
                        [ 12841,  12532],
                        [ 12383,  12122],
                        [ 11834,  11621],
                        [ 11208,  11044],
                        [ 10508,  10394],
                        [  9752,   9686],
                        [  8955,   8936],
                        [  8126,   8152],
                        [  7274,   7344],
                        [  6415,   6524],
                        [  5554,   5701],
                        [  4701,   4883],
                        [  3863,   4076],
                        [  3042,   3288],
                        [  2244,   2524],
                        [  1476,   1788],
                        [   738,   1081],
                        [    34,    409],
                        [  -633,   -229],
                        [ -1261,   -840],
                        [ -1852,  -1422],
                        [ -2403,  -1981],
                        [ -2914,  -2516],
                        [ -3384,  -3028],
                        [ -3815,  -3521],
                        [ -4205,  -3980],
                        [ -4554,  -4409],
                        [ -4864,  -4795],
                        [ -5137,  -5143],
                        [ -5372,  -5446],
                        [ -5573,  -5708],
                        [ -5740,  -5918],
                        [ -5874,  -6081],
                        [ -5978,  -6193],
                        [ -6052,  -6256],
                        [ -6096,  -6279],
                        [ -6113,  -6260],
                        [ -6105,  -6212],
                        [ -6073,  -6134],
                        [ -6017,  -6032],
                        [ -5942,  -5908],
                        [ -5846,  -5761],
                        [ -5731,  -5593],
                        [ -5598,  -5407],
                        [ -5449,  -5205],
                        [ -5283,  -4986],
                        [ -5101,  -4753],
                        [ -4907,  -4509],
                        [ -4700,  -4255],
                        [ -4482,  -3993],
                        [ -4256,  -3724],
                        [ -4022,  -3450],
                        [ -3782,  -3174],
                        [ -3532,  -2898],
                        [ -3274,  -2624],
                        [ -3005,  -2355],
                        [ -2727,  -2091],
                        [ -2442,  -1838],
                        [ -2151,  -1594],
                        [ -1864,  -1364],
                        [ -1584,  -1151],
                        [ -1320,   -952],
                        [ -1076,   -773],
                        [  -859,   -615],
                        [  -670,   -482],
                        [  -509,   -372],
                        [  -379,   -285],
                        [  -275,   -218],
                        [  -197,   -171],
                        [  -101,    -95],
                        [    13,      4],
                        [   169,    153],
                        [   366,    349],
                        [   608,    597],
                        [   895,    897],
                        [  1159,   1180],
                        [  1407,   1451],
                        [  1593,   1663],
                        [  1718,   1818],
                        [  1781,   1914],
                        [  1783,   1952],
                        [  1726,   1929],
                        [  1607,   1847],
                        [  1433,   1708],
                        [  1204,   1513],
                        [   926,   1268],
                        [   601,    973],
                        [   236,    635],
                        [  -167,    258],
                        [  -599,   -152],
                        [ -1059,   -592],
                        [ -1534,  -1055],
                        [ -2026,  -1536],
                        [ -2523,  -2029],
                        [ -3025,  -2530],
                        [ -3526,  -3033],
                        [ -4024,  -3534],
                        [ -4515,  -4028],
                        [ -4998,  -4513],
                        [ -5467,  -4984],
                        [ -5920,  -5439],
                        [ -6354,  -5874],
                        [ -6767,  -6287],
                        [ -7157,  -6673],
                        [ -7521,  -7031],
                        [ -7858,  -7360],
                        [ -8164,  -7657],
                        [ -8433,  -7922],
                        [ -8665,  -8155],
                        [ -8852,  -8357],
                        [ -8994,  -8528],
                        [ -9097,  -8667],
                        [ -9157,  -8775],
                        [ -9185,  -8851],
                        [ -9180,  -8895],
                        [ -9154,  -8908],
                        [ -9107,  -8893],
                        [ -9033,  -8843],
                        [ -8935,  -8767],
                        [ -8837,  -8681],
                        [ -8743,  -8593],
                        [ -8646,  -8495],
                        [ -8508,  -8350],
                        [ -8278,  -8108],
                        [ -7946,  -7759],
                        [ -7542,  -7333],
                        [ -7079,  -6843],
                        [ -6565,  -6299],
                        [ -6016,  -5716],
                        [ -5445,  -5107],
                        [ -4864,  -4487],
                        [ -4284,  -3865],
                        [ -3716,  -3253],
                        [ -3173,  -2663],
                        [ -2661,  -2104],
                        [ -2185,  -1580],
                        [ -1753,  -1101],
                        [ -1367,   -671],
                        [ -1034,   -294],
                        [  -751,     26],
                        [  -522,    290],
                        [  -345,    501],
                        [  -222,    657],
                        [  -147,    770],
                        [  -120,    840],
                        [  -137,    873],
                        [  -196,    873],
                        [  -292,    843],
                        [  -422,    789],
                        [  -581,    701],
                        [  -766,    586],
                        [  -969,    444],
                        [ -1186,    280],
                        [ -1411,     89],
                        [ -1640,   -121],
                        [ -1867,   -354],
                        [ -2088,   -605],
                        [ -2300,   -867],
                        [ -2498,  -1137],
                        [ -2680,  -1402],
                        [ -2841,  -1659],
                        [ -2980,  -1898],
                        [ -3094,  -2114],
                        [ -3181,  -2307],
                        [ -3239,  -2472],
                        [ -3270,  -2608],
                        [ -3270,  -2716],
                        [ -3244,  -2793],
                        [ -3189,  -2840],
                        [ -3109,  -2857],
                        [ -3002,  -2843],
                        [ -2873,  -2800],
                        [ -2722,  -2729],
                        [ -2552,  -2633],
                        [ -2364,  -2511],
                        [ -2165,  -2367],
                        [ -1953,  -2202],
                        [ -1740,  -2019],
                        [ -1524,  -1821],
                        [ -1314,  -1608],
                        [ -1109,  -1384],
                        [  -914,  -1151],
                        [  -730,   -912],
                        [  -552,   -670],
                        [  -381,   -424],
                        [  -216,   -182],
                        [   -55,     60],
                        [   102,    299],
                        [   255,    531],
                        [   401,    754],
                        [   539,    966],
                        [   647,   1142],
                        [   723,   1281],
                        [   731,   1342],
                        [   672,   1329],
                        [   536,   1232],
                        [   324,   1049],
                        [    54,    799],
                        [  -274,    482],
                        [  -585,    171],
                        [  -884,   -135],
                        [ -1156,   -423],
                        [ -1400,   -691],
                        [ -1606,   -929],
                        [ -1773,  -1137],
                        [ -1896,  -1307],
                        [ -1976,  -1439],
                        [ -2009,  -1531],
                        [ -1996,  -1580],
                        [ -1934,  -1585],
                        [ -1825,  -1548],
                        [ -1670,  -1467],
                        [ -1469,  -1342],
                        [ -1228,  -1177],
                        [  -946,   -972],
                        [  -629,   -729],
                        [  -276,   -449],
                        [   105,   -139],
                        [   516,    204],
                        [   952,    572],
                        [  1412,    965],
                        [  1892,   1377],
                        [  2389,   1809],
                        [  2897,   2252],
                        [  3413,   2707],
                        [  3933,   3166],
                        [  4453,   3628],
                        [  4968,   4086],
                        [  5475,   4538],
                        [  5961,   4977],
                        [  6427,   5404],
                        [  6857,   5813],
                        [  7250,   6203],
                        [  7600,   6568],
                        [  7902,   6907],
                        [  8162,   7214],
                        [  8372,   7488],
                        [  8543,   7723],
                        [  8669,   7916],
                        [  8751,   8064],
                        [  8792,   8171],
                        [  8822,   8268],
                        [  8870,   8382],
                        [  8942,   8517],
                        [  9026,   8662],
                        [  9088,   8785],
                        [  9064,   8818],
                        [  8908,   8716],
                        [  8624,   8483],
                        [  8222,   8128],
                        [  7707,   7659],
                        [  7093,   7085],
                        [  6393,   6423],
                        [  5618,   5681],
                        [  4778,   4870],
                        [  3889,   4006],
                        [  2963,   3098],
                        [  2011,   2159],
                        [  1044,   1198],
                        [    73,    228],
                        [  -895,   -743],
                        [ -1849,  -1706],
                        [ -2784,  -2654],
                        [ -3691,  -3581],
                        [ -4565,  -4478],
                        [ -5401,  -5344],
                        [ -6194,  -6177],
                        [ -6940,  -6972],
                        [ -7638,  -7729],
                        [ -8283,  -8447],
                        [ -8873,  -9124],
                        [ -9406,  -9753],
                        [ -9880, -10335],
                        [-10297, -10862],
                        [-10656, -11333],
                        [-10959, -11742],
                        [-11208, -12092],
                        [-11403, -12374],
                        [-11548, -12587],
                        [-11645, -12733],
                        [-11694, -12811],
                        [-11698, -12828],
                        [-11662, -12786],
                        [-11587, -12700],
                        [-11475, -12572],
                        [-11332, -12407],
                        [-11159, -12209],
                        [-10961, -11980],
                        [-10740, -11726],
                        [-10500, -11451],
                        [-10244, -11155],
                        [ -9974, -10844],
                        [ -9694, -10522],
                        [ -9406, -10191],
                        [ -9113,  -9854],
                        [ -8818,  -9515],
                        [ -8524,  -9178],
                        [ -8232,  -8844],
                        [ -7945,  -8517],
                        [ -7665,  -8199],
                        [ -7392,  -7893],
                        [ -7129,  -7603],
                        [ -6875,  -7328],
                        [ -6631,  -7072],
                        [ -6397,  -6837],
                        [ -6173,  -6624],
                        [ -5962,  -6434],
                        [ -5770,  -6268],
                        [ -5596,  -6128],
                        [ -5446,  -6014],
                        [ -5323,  -5930],
                        [ -5224,  -5870],
                        [ -5149,  -5835],
                        [ -5093,  -5819],
                        [ -5057,  -5820],
                        [ -5006,  -5804],
                        [ -4939,  -5770],
                        [ -4844,  -5704],
                        [ -4720,  -5605],
                        [ -4552,  -5458],
                        [ -4340,  -5264],
                        [ -4128,  -5067],
                        [ -3913,  -4863],
                        [ -3729,  -4687],
                        [ -3575,  -4535],
                        [ -3455,  -4414],
                        [ -3366,  -4323],
                        [ -3316,  -4266],
                        [ -3300,  -4243],
                        [ -3319,  -4253],
                        [ -3374,  -4297],
                        [ -3463,  -4371],
                        [ -3582,  -4477],
                        [ -3729,  -4609],
                        [ -3904,  -4768],
                        [ -4100,  -4948],
                        [ -4315,  -5148],
                        [ -4544,  -5363],
                        [ -4784,  -5591],
                        [ -5032,  -5826],
                        [ -5285,  -6069],
                        [ -5536,  -6312],
                        [ -5788,  -6555],
                        [ -6037,  -6791],
                        [ -6281,  -7019],
                        [ -6515,  -7235],
                        [ -6741,  -7439],
                        [ -6953,  -7626],
                        [ -7151,  -7796],
                        [ -7333,  -7945],
                        [ -7499,  -8072],
                        [ -7642,  -8177],
                        [ -7766,  -8257],
                        [ -7860,  -8315],
                        [ -7925,  -8350],
                        [ -7956,  -8362],
                        [ -7954,  -8353],
                        [ -7922,  -8323],
                        [ -7859,  -8272],
                        [ -7776,  -8201],
                        [ -7672,  -8112],
                        [ -7555,  -8004],
                        [ -7425,  -7876],
                        [ -7303,  -7753],
                        [ -7248,  -7693],
                        [ -7300,  -7733],
                        [ -7467,  -7884],
                        [ -7740,  -8136],
                        [ -8094,  -8465],
                        [ -8453,  -8796],
                        [ -8739,  -9048],
                        [ -8935,  -9208],
                        [ -9049,  -9283],
                        [ -9085,  -9277],
                        [ -9050,  -9199],
                        [ -8950,  -9057],
                        [ -8795,  -8860],
                        [ -8590,  -8615],
                        [ -8347,  -8331],
                        [ -8075,  -8019],
                        [ -7781,  -7683],
                        [ -7473,  -7331],
                        [ -7157,  -6972],
                        [ -6836,  -6609],
                        [ -6516,  -6248],
                        [ -6201,  -5892],
                        [ -5896,  -5548],
                        [ -5599,  -5215],
                        [ -5315,  -4895],
                        [ -5042,  -4588],
                        [ -4782,  -4296],
                        [ -4536,  -4015],
                        [ -4302,  -3746],
                        [ -4081,  -3482],
                        [ -3872,  -3224],
                        [ -3673,  -2975],
                        [ -3483,  -2731],
                        [ -3300,  -2494],
                        [ -3122,  -2264],
                        [ -2946,  -2048],
                        [ -2769,  -1840],
                        [ -2590,  -1649],
                        [ -2408,  -1471],
                        [ -2221,  -1305],
                        [ -2030,  -1151],
                        [ -1831,   -999],
                        [ -1624,   -848],
                        [ -1411,   -691],
                        [ -1190,   -527],
                        [  -960,   -354],
                        [  -722,   -172],
                        [  -476,     18],
                        [  -222,    219],
                        [    37,    427],
                        [   304,    644],
                        [   573,    867],
                        [   844,   1096],
                        [  1116,   1329],
                        [  1386,   1567],
                        [  1652,   1804],
                        [  1913,   2042],
                        [  2168,   2277],
                        [  2414,   2508],
                        [  2651,   2734],
                        [  2878,   2953],
                        [  3091,   3164],
                        [  3289,   3365],
                        [  3465,   3553],
                        [  3619,   3729],
                        [  3749,   3891],
                        [  3854,   4038],
                        [  3937,   4170],
                        [  3999,   4288],
                        [  4045,   4391],
                        [  4071,   4478],
                        [  4081,   4547],
                        [  4075,   4599],
                        [  4038,   4617],
                        [  3973,   4604],
                        [  3867,   4543],
                        [  3720,   4435],
                        [  3525,   4273],
                        [  3282,   4055],
                        [  2992,   3785],
                        [  2659,   3461],
                        [  2328,   3132],
                        [  2000,   2797],
                        [  1689,   2471],
                        [  1396,   2153],
                        [  1134,   1860],
                        [   904,   1590],
                        [   713,   1354],
                        [   563,   1151],
                        [   459,    990],
                        [   402,    869],
                        [   392,    794],
                        [   432,    763],
                        [   518,    778],
                        [   653,    839],
                        [   831,    943],
                        [  1053,   1092],
                        [  1312,   1282],
                        [  1608,   1510],
                        [  1935,   1774],
                        [  2290,   2070],
                        [  2667,   2392],
                        [  3065,   2738],
                        [  3476,   3099],
                        [  3898,   3473],
                        [  4323,   3853],
                        [  4748,   4236],
                        [  5164,   4613],
                        [  5571,   4983],
                        [  5959,   5337],
                        [  6325,   5673],
                        [  6657,   5983],
                        [  6953,   6267],
                        [  7202,   6517],
                        [  7400,   6732],
                        [  7542,   6908],
                        [  7628,   7042],
                        [  7655,   7131],
                        [  7625,   7170],
                        [  7543,   7161],
                        [  7408,   7100],
                        [  7215,   6980],
                        [  7007,   6845],
                        [  6862,   6767],
                        [  6820,   6791],
                        [  6887,   6920],
                        [  7061,   7151],
                        [  7324,   7466],
                        [  7589,   7778],
                        [  7750,   7980],
                        [  7778,   8043],
                        [  7683,   7976],
                        [  7469,   7785],
                        [  7143,   7475],
                        [  6710,   7055],
                        [  6182,   6535],
                        [  5567,   5925],
                        [  4882,   5237],
                        [  4136,   4481],
                        [  3343,   3670],
                        [  2516,   2815],
                        [  1666,   1928],
                        [   803,   1021],
                        [   -65,    102],
                        [  -927,   -819],
                        [ -1773,  -1729],
                        [ -2597,  -2623],
                        [ -3391,  -3490],
                        [ -4149,  -4323],
                        [ -4866,  -5116],
                        [ -5538,  -5865],
                        [ -6160,  -6567],
                        [ -6728,  -7222],
                        [ -7240,  -7828],
                        [ -7694,  -8383],
                        [ -8088,  -8885],
                        [ -8425,  -9333],
                        [ -8704,  -9722],
                        [ -8927, -10051],
                        [ -9098, -10315],
                        [ -9215, -10514],
                        [ -9284, -10648],
                        [ -9305, -10719],
                        [ -9283, -10729],
                        [ -9219, -10684],
                        [ -9119, -10593],
                        [ -8984, -10461],
                        [ -8819, -10295],
                        [ -8628, -10098],
                        [ -8414,  -9875],
                        [ -8184,  -9630],
                        [ -7941,  -9368],
                        [ -7687,  -9093],
                        [ -7428,  -8808],
                        [ -7166,  -8517],
                        [ -6906,  -8226],
                        [ -6649,  -7935],
                        [ -6397,  -7649],
                        [ -6154,  -7371],
                        [ -5921,  -7104],
                        [ -5701,  -6849],
                        [ -5498,  -6608],
                        [ -5315,  -6384],
                        [ -5153,  -6178],
                        [ -5015,  -5992],
                        [ -4896,  -5826],
                        [ -4796,  -5679],
                        [ -4706,  -5554],
                        [ -4627,  -5450],
                        [ -4557,  -5367],
                        [ -4496,  -5302],
                        [ -4444,  -5259],
                        [ -4404,  -5236],
                        [ -4373,  -5228],
                        [ -4349,  -5236],
                        [ -4328,  -5252],
                        [ -4313,  -5276],
                        [ -4289,  -5296],
                        [ -4258,  -5310],
                        [ -4214,  -5312],
                        [ -4156,  -5303],
                        [ -4062,  -5255],
                        [ -3929,  -5170],
                        [ -3771,  -5056],
                        [ -3583,  -4912],
                        [ -3388,  -4756],
                        [ -3183,  -4587],
                        [ -2976,  -4413],
                        [ -2767,  -4231],
                        [ -2563,  -4050],
                        [ -2363,  -3870],
                        [ -2174,  -3694],
                        [ -1994,  -3524],
                        [ -1827,  -3362],
                        [ -1671,  -3207],
                        [ -1530,  -3062],
                        [ -1402,  -2927],
                        [ -1289,  -2802],
                        [ -1189,  -2685],
                        [ -1102,  -2579],
                        [ -1027,  -2481],
                        [  -963,  -2393],
                        [  -908,  -2312],
                        [  -863,  -2238],
                        [  -825,  -2170],
                        [  -792,  -2104],
                        [  -766,  -2041],
                        [  -743,  -1976],
                        [  -725,  -1911],
                        [  -708,  -1842],
                        [  -691,  -1769],
                        [  -674,  -1691],
                        [  -657,  -1609],
                        [  -633,  -1519],
                        [  -605,  -1423],
                        [  -566,  -1320],
                        [  -516,  -1210],
                        [  -450,  -1093],
                        [  -372,   -971],
                        [  -280,   -843],
                        [  -169,   -709],
                        [   -53,   -569],
                        [    69,   -427],
                        [   197,   -275],
                        [   332,   -119],
                        [   413,    -13],
                        [   350,    -49],
                        [   106,   -266],
                        [  -327,   -666],
                        [  -947,  -1255],
                        [ -1743,  -2017],
                        [ -2615,  -2856],
                        [ -3435,  -3638],
                        [ -4159,  -4324],
                        [ -4793,  -4920],
                        [ -5332,  -5422],
                        [ -5777,  -5831],
                        [ -6124,  -6146],
                        [ -6378,  -6372],
                        [ -6542,  -6509],
                        [ -6623,  -6566],
                        [ -6626,  -6545],
                        [ -6559,  -6453],
                        [ -6428,  -6294],
                        [ -6241,  -6075],
                        [ -6000,  -5801],
                        [ -5710,  -5478],
                        [ -5379,  -5111],
                        [ -5012,  -4708],
                        [ -4613,  -4274],
                        [ -4186,  -3813],
                        [ -3736,  -3335],
                        [ -3265,  -2843],
                        [ -2779,  -2339],
                        [ -2279,  -1828],
                        [ -1770,  -1304],
                        [ -1255,   -771],
                        [  -735,   -227],
                        [  -214,    328],
                        [   308,    888],
                        [   829,   1453],
                        [  1346,   2013],
                        [  1861,   2568],
                        [  2372,   3111],
                        [  2875,   3642],
                        [  3370,   4157],
                        [  3858,   4654],
                        [  4334,   5135],
                        [  4798,   5601],
                        [  5246,   6052],
                        [  5682,   6491],
                        [  6099,   6915],
                        [  6502,   7325],
                        [  6887,   7719],
                        [  7254,   8097],
                        [  7604,   8458],
                        [  7935,   8802],
                        [  8247,   9126],
                        [  8539,   9432],
                        [  8808,   9717],
                        [  9056,   9980],
                        [  9280,  10222],
                        [  9482,  10441],
                        [  9662,  10638],
                        [  9822,  10812],
                        [  9966,  10962],
                        [ 10097,  11089],
                        [ 10214,  11191],
                        [ 10316,  11271],
                        [ 10396,  11326],
                        [ 10455,  11360],
                        [ 10482,  11370],
                        [ 10480,  11359],
                        [ 10449,  11327],
                        [ 10393,  11277],
                        [ 10314,  11210],
                        [ 10212,  11126],
                        [ 10093,  11026],
                        [  9956,  10910],
                        [  9806,  10783],
                        [  9645,  10644],
                        [  9484,  10503],
                        [  9324,  10362],
                        [  9156,  10210],
                        [  8981,  10047],
                        [  8777,   9852],
                        [  8548,   9627],
                        [  8305,   9384],
                        [  8050,   9125],
                        [  7797,   8860],
                        [  7545,   8592],
                        [  7307,   8332],
                        [  7082,   8080],
                        [  6880,   7847],
                        [  6702,   7633],
                        [  6553,   7445],
                        [  6433,   7282],
                        [  6345,   7151],
                        [  6290,   7049],
                        [  6269,   6981],
                        [  6280,   6944],
                        [  6322,   6938],
                        [  6394,   6962],
                        [  6492,   7015],
                        [  6614,   7096],
                        [  6755,   7200],
                        [  6912,   7326],
                        [  7079,   7467],
                        [  7253,   7620],
                        [  7430,   7777],
                        [  7603,   7937],
                        [  7769,   8089],
                        [  7924,   8233],
                        [  8059,   8361],
                        [  8175,   8471],
                        [  8263,   8556],
                        [  8322,   8616],
                        [  8344,   8643],
                        [  8326,   8636],
                        [  8262,   8590],
                        [  8151,   8504],
                        [  7988,   8376],
                        [  7772,   8205],
                        [  7503,   7987],
                        [  7183,   7724],
                        [  6819,   7417],
                        [  6405,   7061],
                        [  5948,   6658],
                        [  5524,   6286],
                        [  5230,   6040],
                        [  5100,   5952],
                        [  5142,   6030],
                        [  5367,   6287],
                        [  5776,   6720],
                        [  6264,   7226],
                        [  6692,   7663],
                        [  7018,   7991],
                        [  7251,   8220],
                        [  7390,   8348],
                        [  7430,   8374],
                        [  7375,   8302],
                        [  7230,   8136],
                        [  7001,   7884],
                        [  6697,   7550],
                        [  6328,   7144],
                        [  5904,   6675],
                        [  5436,   6149],
                        [  4930,   5579],
                        [  4396,   4973],
                        [  3842,   4339],
                        [  3277,   3687],
                        [  2707,   3028],
                        [  2143,   2369],
                        [  1589,   1724],
                        [  1052,   1099],
                        [   537,    505],
                        [    48,    -53],
                        [  -410,   -574],
                        [  -834,  -1056],
                        [ -1220,  -1504],
                        [ -1569,  -1917],
                        [ -1877,  -2295],
                        [ -2144,  -2637],
                        [ -2373,  -2941],
                        [ -2563,  -3209],
                        [ -2716,  -3433],
                        [ -2832,  -3616],
                        [ -2915,  -3759],
                        [ -2967,  -3861],
                        [ -2989,  -3924],
                        [ -2984,  -3950],
                        [ -2954,  -3946],
                        [ -2901,  -3915],
                        [ -2829,  -3861],
                        [ -2741,  -3789],
                        [ -2639,  -3702],
                        [ -2528,  -3601],
                        [ -2412,  -3492],
                        [ -2294,  -3380],
                        [ -2178,  -3265],
                        [ -2064,  -3150],
                        [ -1956,  -3038],
                        [ -1855,  -2932],
                        [ -1762,  -2833],
                        [ -1678,  -2741],
                        [ -1605,  -2660],
                        [ -1544,  -2590],
                        [ -1502,  -2532],
                        [ -1480,  -2485],
                        [ -1484,  -2451],
                        [ -1514,  -2429],
                        [ -1562,  -2416],
                        [ -1629,  -2415],
                        [ -1699,  -2422],
                        [ -1771,  -2438],
                        [ -1835,  -2459],
                        [ -1890,  -2485],
                        [ -1935,  -2516],
                        [ -1971,  -2549],
                        [ -1996,  -2580],
                        [ -2006,  -2608],
                        [ -2006,  -2635],
                        [ -1994,  -2658],
                        [ -1987,  -2693],
                        [ -1983,  -2738],
                        [ -1988,  -2796],
                        [ -1999,  -2864],
                        [ -1985,  -2910],
                        [ -1948,  -2935],
                        [ -1860,  -2909],
                        [ -1722,  -2832],
                        [ -1543,  -2713],
                        [ -1320,  -2546],
                        [ -1065,  -2344],
                        [  -778,  -2104],
                        [  -469,  -1836],
                        [  -137,  -1540],
                        [   208,  -1225],
                        [   566,   -891],
                        [   926,   -547],
                        [  1292,   -191],
                        [  1653,    168],
                        [  2013,    531],
                        [  2360,    891],
                        [  2698,   1247],
                        [  3022,   1595],
                        [  3330,   1935],
                        [  3621,   2261],
                        [  3893,   2573],
                        [  4148,   2870],
                        [  4384,   3150],
                        [  4603,   3416],
                        [  4803,   3664],
                        [  4985,   3900],
                        [  5148,   4121],
                        [  5295,   4330],
                        [  5425,   4525],
                        [  5540,   4707],
                        [  5640,   4876],
                        [  5727,   5033],
                        [  5801,   5178],
                        [  5866,   5312],
                        [  5922,   5436],
                        [  5974,   5553],
                        [  6019,   5659],
                        [  6065,   5757],
                        [  6112,   5849],
                        [  6156,   5934],
                        [  6195,   6008],
                        [  6238,   6084],
                        [  6276,   6151],
                        [  6223,   6127],
                        [  5991,   5923],
                        [  5557,   5516],
                        [  4916,   4900],
                        [  4050,   4059],
                        [  2959,   2992],
                        [  1757,   1814],
                        [   589,    670],
                        [  -496,   -394],
                        [ -1506,  -1381],
                        [ -2424,  -2280],
                        [ -3242,  -3082],
                        [ -3953,  -3782],
                        [ -4555,  -4378],
                        [ -5048,  -4867],
                        [ -5432,  -5250],
                        [ -5714,  -5526],
                        [ -5896,  -5700],
                        [ -5982,  -5774],
                        [ -5980,  -5753],
                        [ -5890,  -5640],
                        [ -5718,  -5442],
                        [ -5472,  -5165],
                        [ -5158,  -4817],
                        [ -4782,  -4407],
                        [ -4350,  -3943],
                        [ -3868,  -3439],
                        [ -3344,  -2900],
                        [ -2782,  -2335],
                        [ -2190,  -1751],
                        [ -1573,  -1142],
                        [  -936,   -517],
                        [  -287,    130],
                        [   371,    794],
                        [  1033,   1471],
                        [  1692,   2157],
                        [  2348,   2845],
                        [  2995,   3530],
                        [  3629,   4206],
                        [  4247,   4871],
                        [  4844,   5517],
                        [  5420,   6143],
                        [  5971,   6744],
                        [  6494,   7316],
                        [  6984,   7859],
                        [  7443,   8373],
                        [  7867,   8854],
                        [  8256,   9303],
                        [  8609,   9718],
                        [  8929,  10097],
                        [  9214,  10442],
                        [  9466,  10752],
                        [  9683,  11026],
                        [  9869,  11266],
                        [ 10023,  11470],
                        [ 10143,  11639],
                        [ 10232,  11774],
                        [ 10291,  11876],
                        [ 10325,  11945],
                        [ 10337,  11984],
                        [ 10338,  11993],
                        [ 10330,  11975],
                        [ 10318,  11930],
                        [ 10301,  11860],
                        [ 10272,  11766],
                        [ 10234,  11651],
                        [ 10170,  11516],
                        [ 10083,  11363],
                        [  9973,  11196],
                        [  9842,  11016],
                        [  9693,  10825],
                        [  9528,  10626],
                        [  9351,  10420],
                        [  9163,  10211],
                        [  8990,  10021],
                        [  8833,   9851],
                        [  8717,   9727],
                        [  8646,   9651],
                        [  8606,   9609],
                        [  8600,   9605],
                        [  8581,   9589],
                        [  8550,   9564],
                        [  8490,   9510],
                        [  8401,   9427],
                        [  8292,   9323],
                        [  8162,   9198],
                        [  8019,   9061],
                        [  7864,   8909],
                        [  7703,   8750],
                        [  7535,   8583],
                        [  7367,   8416],
                        [  7196,   8245],
                        [  7029,   8078],
                        [  6862,   7911],
                        [  6702,   7749],
                        [  6543,   7590],
                        [  6390,   7434],
                        [  6239,   7281],
                        [  6091,   7133],
                        [  5944,   6986],
                        [  5794,   6840],
                        [  5640,   6694],
                        [  5477,   6544],
                        [  5304,   6389],
                        [  5117,   6221],
                        [  4915,   6041],
                        [  4693,   5842],
                        [  4451,   5623],
                        [  4186,   5381],
                        [  3896,   5116],
                        [  3579,   4824],
                        [  3235,   4505],
                        [  2864,   4157],
                        [  2464,   3780],
                        [  2035,   3370],
                        [  1578,   2932],
                        [  1089,   2463],
                        [   570,   1964],
                        [    17,   1435],
                        [  -563,    880],
                        [ -1164,    304],
                        [ -1793,   -301],
                        [ -2429,   -917],
                        [ -2984,  -1454],
                        [ -3374,  -1832],
                        [ -3578,  -2030],
                        [ -3587,  -2038],
                        [ -3373,  -1827],
                        [ -2921,  -1385],
                        [ -2335,   -816],
                        [ -1756,   -259],
                        [ -1218,    250],
                        [  -717,    719],
                        [  -261,   1137],
                        [   136,   1496],
                        [   473,   1794],
                        [   749,   2030],
                        [   963,   2204],
                        [  1118,   2314],
                        [  1217,   2364],
                        [  1268,   2357],
                        [  1272,   2296],
                        [  1234,   2186],
                        [  1158,   2033],
                        [  1047,   1840],
                        [   910,   1614],
                        [   748,   1363],
                        [   568,   1091],
                        [   374,    814],
                        [   170,    535],
                        [   -41,    267],
                        [  -252,     12],
                        [  -464,   -228],
                        [  -671,   -451],
                        [  -873,   -666],
                        [ -1068,   -871],
                        [ -1254,  -1074],
                        [ -1428,  -1271],
                        [ -1594,  -1463],
                        [ -1748,  -1649],
                        [ -1891,  -1830],
                        [ -2023,  -2004],
                        [ -2146,  -2171],
                        [ -2260,  -2333],
                        [ -2364,  -2485],
                        [ -2460,  -2630],
                        [ -2549,  -2765],
                        [ -2631,  -2893],
                        [ -2706,  -3012],
                        [ -2776,  -3129],
                        [ -2841,  -3240],
                        [ -2905,  -3348],
                        [ -2968,  -3456],
                        [ -3033,  -3564],
                        [ -3100,  -3672],
                        [ -3171,  -3781],
                        [ -3245,  -3893],
                        [ -3323,  -4006],
                        [ -3403,  -4121],
                        [ -3485,  -4237],
                        [ -3569,  -4355],
                        [ -3655,  -4474],
                        [ -3753,  -4591],
                        [ -3862,  -4709],
                        [ -3987,  -4824],
                        [ -4128,  -4935],
                        [ -4281,  -5041],
                        [ -4445,  -5140],
                        [ -4598,  -5229],
                        [ -4740,  -5308],
                        [ -4858,  -5376],
                        [ -4950,  -5429],
                        [ -5014,  -5467],
                        [ -5050,  -5487],
                        [ -5055,  -5488],
                        [ -5030,  -5471],
                        [ -4988,  -5445],
                        [ -4925,  -5409],
                        [ -4887,  -5404],
                        [ -4869,  -5428],
                        [ -4881,  -5485],
                        [ -4921,  -5578],
                        [ -4957,  -5670],
                        [ -4990,  -5761],
                        [ -4962,  -5793],
                        [ -4875,  -5767],
                        [ -4730,  -5681],
                        [ -4526,  -5535],
                        [ -4275,  -5336],
                        [ -3972,  -5083],
                        [ -3633,  -4786],
                        [ -3255,  -4446],
                        [ -2852,  -4075],
                        [ -2422,  -3670],
                        [ -1978,  -3245],
                        [ -1519,  -2798],
                        [ -1057,  -2341],
                        [  -592,  -1874],
                        [  -134,  -1406],
                        [   316,   -937],
                        [   750,   -478],
                        [  1168,    -27],
                        [  1563,    405],
                        [  1938,    821],
                        [  2289,   1213],
                        [  2615,   1582],
                        [  2917,   1926],
                        [  3192,   2245],
                        [  3442,   2540],
                        [  3664,   2810],
                        [  3862,   3055],
                        [  4033,   3275],
                        [  4180,   3472],
                        [  4302,   3643],
                        [  4401,   3791],
                        [  4474,   3914],
                        [  4523,   4016],
                        [  4549,   4097],
                        [  4557,   4162],
                        [  4546,   4207],
                        [  4527,   4239],
                        [  4501,   4257],
                        [  4468,   4262],
                        [  4427,   4251],
                        [  4389,   4240],
                        [  4335,   4206],
                        [  4183,   4073],
                        [  3872,   3777],
                        [  3397,   3314],
                        [  2750,   2676],
                        [  1897,   1831],
                        [   828,    768],
                        [  -360,   -416],
                        [ -1537,  -1589],
                        [ -2667,  -2718],
                        [ -3751,  -3801],
                        [ -4770,  -4823],
                        [ -5709,  -5770],
                        [ -6559,  -6631],
                        [ -7313,  -7400],
                        [ -7969,  -8072],
                        [ -8521,  -8642],
                        [ -8972,  -9106],
                        [ -9323,  -9465],
                        [ -9575,  -9718],
                        [ -9728,  -9868],
                        [ -9787,  -9916],
                        [ -9755,  -9866],
                        [ -9637,  -9726],
                        [ -9440,  -9500],
                        [ -9167,  -9199],
                        [ -8829,  -8831],
                        [ -8429,  -8413],
                        [ -7975,  -7950],
                        [ -7474,  -7454],
                        [ -6934,  -6931],
                        [ -6360,  -6381],
                        [ -5760,  -5809],
                        [ -5142,  -5212],
                        [ -4510,  -4596],
                        [ -3872,  -3960],
                        [ -3233,  -3312],
                        [ -2599,  -2657],
                        [ -1975,  -2000],
                        [ -1367,  -1345],
                        [  -777,   -695],
                        [  -209,    -57],
                        [   332,    564],
                        [   843,   1158],
                        [  1321,   1724],
                        [  1762,   2256],
                        [  2166,   2750],
                        [  2531,   3206],
                        [  2855,   3623],
                        [  3140,   3999],
                        [  3387,   4335],
                        [  3596,   4630],
                        [  3770,   4884],
                        [  3911,   5098],
                        [  4017,   5275],
                        [  4092,   5413],
                        [  4136,   5514],
                        [  4151,   5583],
                        [  4138,   5617],
                        [  4106,   5620],
                        [  4058,   5595],
                        [  4008,   5544],
                        [  3959,   5468],
                        [  3914,   5371],
                        [  3876,   5255],
                        [  3841,   5121],
                        [  3810,   4973],
                        [  3762,   4812],
                        [  3702,   4640],
                        [  3627,   4460],
                        [  3538,   4273],
                        [  3436,   4080],
                        [  3324,   3887],
                        [  3206,   3696],
                        [  3083,   3508],
                        [  2997,   3367],
                        [  2945,   3270],
                        [  2963,   3249],
                        [  3049,   3305],
                        [  3192,   3428],
                        [  3395,   3617],
                        [  3588,   3806],
                        [  3776,   3995],
                        [  3916,   4144],
                        [  4011,   4253],
                        [  4063,   4325],
                        [  4071,   4357],
                        [  4039,   4352],
                        [  3964,   4308],
                        [  3852,   4229],
                        [  3701,   4113],
                        [  3517,   3966],
                        [  3296,   3785],
                        [  3046,   3577],
                        [  2764,   3336],
                        [  2456,   3070],
                        [  2121,   2777],
                        [  1764,   2460],
                        [  1385,   2118],
                        [   984,   1755],
                        [   563,   1371],
                        [   121,    968],
                        [  -340,    546],
                        [  -825,    106],
                        [ -1329,   -353],
                        [ -1854,   -831],
                        [ -2399,  -1328],
                        [ -2962,  -1845],
                        [ -3544,  -2382],
                        [ -4142,  -2938],
                        [ -4756,  -3511],
                        [ -5381,  -4099],
                        [ -6017,  -4701],
                        [ -6657,  -5315],
                        [ -7297,  -5939],
                        [ -7937,  -6572],
                        [ -8573,  -7211],
                        [ -9206,  -7854],
                        [ -9838,  -8501],
                        [-10468,  -9148],
                        [-11092,  -9788],
                        [-11707, -10420],
                        [-12313, -11045],
                        [-12887, -11640],
                        [-13356, -12133],
                        [-13673, -12478],
                        [-13833, -12668],
                        [-13821, -12692],
                        [-13600, -12509],
                        [-13142, -12093],
                        [-12526, -11523],
                        [-11858, -10905],
                        [-11162, -10261],
                        [-10441,  -9592],
                        [ -9710,  -8913],
                        [ -8986,  -8240],
                        [ -8275,  -7579],
                        [ -7587,  -6936],
                        [ -6928,  -6322],
                        [ -6302,  -5741],
                        [ -5712,  -5198],
                        [ -5159,  -4695],
                        [ -4647,  -4236],
                        [ -4177,  -3823],
                        [ -3751,  -3455],
                        [ -3367,  -3133],
                        [ -3027,  -2855],
                        [ -2728,  -2619],
                        [ -2469,  -2420],
                        [ -2250,  -2251],
                        [ -2067,  -2108],
                        [ -1920,  -1982],
                        [ -1806,  -1870],
                        [ -1723,  -1770],
                        [ -1670,  -1683],
                        [ -1644,  -1616],
                        [ -1643,  -1568],
                        [ -1665,  -1550],
                        [ -1709,  -1558],
                        [ -1771,  -1593],
                        [ -1853,  -1654],
                        [ -1949,  -1744],
                        [ -2061,  -1861],
                        [ -2186,  -2005],
                        [ -2322,  -2175],
                        [ -2468,  -2365],
                        [ -2624,  -2573],
                        [ -2785,  -2792],
                        [ -2953,  -3020],
                        [ -3122,  -3253],
                        [ -3293,  -3491],
                        [ -3464,  -3730],
                        [ -3635,  -3972],
                        [ -3805,  -4214],
                        [ -3974,  -4456],
                        [ -4141,  -4695],
                        [ -4305,  -4930],
                        [ -4465,  -5160],
                        [ -4618,  -5384],
                        [ -4763,  -5597],
                        [ -4899,  -5802],
                        [ -5024,  -5995],
                        [ -5137,  -6173],
                        [ -5250,  -6338],
                        [ -5360,  -6486],
                        [ -5471,  -6615],
                        [ -5584,  -6726],
                        [ -5697,  -6814],
                        [ -5809,  -6881],
                        [ -5903,  -6923],
                        [ -5978,  -6940],
                        [ -6020,  -6932],
                        [ -6029,  -6897],
                        [ -6001,  -6831],
                        [ -5939,  -6737],
                        [ -5840,  -6616],
                        [ -5708,  -6470],
                        [ -5563,  -6317],
                        [ -5405,  -6159],
                        [ -5288,  -6049],
                        [ -5210,  -5984],
                        [ -5183,  -5974],
                        [ -5205,  -6021],
                        [ -5247,  -6090],
                        [ -5311,  -6186],
                        [ -5319,  -6227],
                        [ -5279,  -6221],
                        [ -5182,  -6161],
                        [ -5031,  -6047],
                        [ -4832,  -5881],
                        [ -4584,  -5666],
                        [ -4296,  -5406],
                        [ -3968,  -5104],
                        [ -3611,  -4769],
                        [ -3224,  -4401],
                        [ -2818,  -4009],
                        [ -2394,  -3594],
                        [ -1962,  -3166],
                        [ -1523,  -2726],
                        [ -1087,  -2283],
                        [  -655,  -1839],
                        [  -235,  -1400],
                        [   171,   -969],
                        [   560,   -555],
                        [   930,   -155],
                        [  1278,    222],
                        [  1606,    578],
                        [  1912,    908],
                        [  2194,   1213],
                        [  2452,   1493],
                        [  2686,   1747],
                        [  2897,   1976],
                        [  3082,   2180],
                        [  3244,   2358],
                        [  3382,   2511],
                        [  3492,   2639],
                        [  3575,   2741],
                        [  3629,   2821],
                        [  3655,   2880],
                        [  3660,   2921],
                        [  3641,   2943],
                        [  3613,   2952],
                        [  3575,   2949],
                        [  3531,   2932],
                        [  3482,   2901],
                        [  3435,   2869],
                        [  3369,   2811],
                        [  3235,   2683],
                        [  3015,   2464],
                        [  2711,   2159],
                        [  2313,   1756],
                        [  1781,   1218],
                        [  1084,    512],
                        [   280,   -303],
                        [  -548,  -1141],
                        [ -1379,  -1984],
                        [ -2208,  -2826],
                        [ -3015,  -3651],
                        [ -3787,  -4441],
                        [ -4513,  -5188],
                        [ -5186,  -5884],
                        [ -5796,  -6517],
                        [ -6337,  -7082],
                        [ -6810,  -7572],
                        [ -7209,  -7984],
                        [ -7535,  -8318],
                        [ -7785,  -8571],
                        [ -7963,  -8744],
                        [ -8068,  -8838],
                        [ -8104,  -8857],
                        [ -8074,  -8805],
                        [ -7983,  -8692],
                        [ -7835,  -8522],
                        [ -7638,  -8311],
                        [ -7394,  -8063],
                        [ -7110,  -7790],
                        [ -6793,  -7497],
                        [ -6448,  -7185],
                        [ -6081,  -6860],
                        [ -5697,  -6515],
                        [ -5304,  -6156],
                        [ -4904,  -5783],
                        [ -4505,  -5398],
                        [ -4109,  -5005],
                        [ -3722,  -4609],
                        [ -3348,  -4205],
                        [ -2988,  -3800],
                        [ -2647,  -3397],
                        [ -2328,  -3001],
                        [ -2031,  -2619],
                        [ -1760,  -2256],
                        [ -1516,  -1919],
                        [ -1299,  -1609],
                        [ -1110,  -1328],
                        [  -950,  -1077],
                        [  -817,   -856],
                        [  -709,   -663],
                        [  -625,   -499],
                        [  -563,   -363],
                        [  -521,   -253],
                        [  -497,   -167],
                        [  -490,   -104],
                        [  -497,    -63],
                        [  -518,    -41],
                        [  -549,    -36],
                        [  -584,    -46],
                        [  -621,    -70],
                        [  -647,   -104],
                        [  -661,   -146],
                        [  -658,   -197],
                        [  -637,   -252],
                        [  -601,   -310],
                        [  -548,   -371],
                        [  -495,   -433],
                        [  -440,   -494],
                        [  -388,   -555],
                        [  -342,   -617],
                        [  -301,   -676],
                        [  -265,   -731],
                        [  -228,   -777],
                        [  -191,   -814],
                        [  -106,   -792],
                        [    24,   -715],
                        [   224,   -556],
                        [   495,   -314],
                        [   831,      2],
                        [  1233,    396],
                        [  1623,    789],
                        [  2004,   1185],
                        [  2329,   1532],
                        [  2598,   1834],
                        [  2808,   2085],
                        [  2958,   2283],
                        [  3045,   2425],
                        [  3068,   2507],
                        [  3028,   2533],
                        [  2924,   2499],
                        [  2760,   2407],
                        [  2535,   2257],
                        [  2252,   2052],
                        [  1913,   1792],
                        [  1525,   1482],
                        [  1086,   1120],
                        [   605,    713],
                        [    82,    260],
                        [  -476,   -232],
                        [ -1069,   -761],
                        [ -1693,  -1323],
                        [ -2346,  -1914],
                        [ -3023,  -2530],
                        [ -3725,  -3170],
                        [ -4443,  -3829],
                        [ -5176,  -4504],
                        [ -5919,  -5191],
                        [ -6670,  -5889],
                        [ -7421,  -6593],
                        [ -8171,  -7297],
                        [ -8911,  -7999],
                        [ -9635,  -8693],
                        [-10334,  -9374],
                        [-11003, -10040],
                        [-11639, -10687],
                        [-12238, -11311],
                        [-12802, -11909],
                        [-13328, -12479],
                        [-13823, -13019],
                        [-14280, -13520],
                        [-14697, -13981],
                        [-15074, -14402],
                        [-15394, -14766],
                        [-15628, -15043],
                        [-15773, -15234],
                        [-15833, -15339],
                        [-15794, -15346],
                        [-15615, -15211],
                        [-15251, -14893],
                        [-14731, -14418],
                        [-14113, -13843],
                        [-13410, -13183],
                        [-12630, -12443],
                        [-11790, -11641],
                        [-10909, -10794],
                        [ -9998,  -9913],
                        [ -9069,  -9009],
                        [ -8136,  -8095],
                        [ -7206,  -7183],
                        [ -6290,  -6282],
                        [ -5394,  -5402],
                        [ -4526,  -4548],
                        [ -3694,  -3731],
                        [ -2901,  -2952],
                        [ -2154,  -2218],
                        [ -1455,  -1532],
                        [  -808,   -896],
                        [  -215,   -310],
                        [   325,    231],
                        [   808,    725],
                        [  1237,   1180],
                        [  1611,   1597],
                        [  1931,   1975],
                        [  2199,   2317],
                        [  2416,   2616],
                        [  2585,   2874],
                        [  2709,   3081],
                        [  2789,   3240],
                        [  2830,   3349],
                        [  2833,   3413],
                        [  2802,   3423],
                        [  2740,   3385],
                        [  2650,   3298],
                        [  2536,   3164],
                        [  2400,   2992],
                        [  2247,   2786],
                        [  2082,   2557],
                        [  1905,   2308],
                        [  1721,   2049],
                        [  1533,   1783],
                        [  1346,   1512],
                        [  1160,   1240],
                        [   980,    970],
                        [   806,    705],
                        [   641,    449],
                        [   486,    203],
                        [   345,    -28],
                        [   219,   -244],
                        [   110,   -440],
                        [    20,   -617],
                        [   -52,   -771],
                        [  -103,   -901],
                        [  -141,  -1005],
                        [  -165,  -1084],
                        [  -178,  -1135],
                        [  -180,  -1157],
                        [  -174,  -1151],
                        [  -160,  -1116],
                        [  -128,  -1052],
                        [   -80,   -960],
                        [    -5,   -839],
                        [    96,   -690],
                        [   227,   -511],
                        [   384,   -306],
                        [   566,    -80],
                        [   771,    169],
                        [   972,    410],
                        [  1168,    644],
                        [  1311,    819],
                        [  1403,    940],
                        [  1429,    991],
                        [  1389,    973],
                        [  1309,    910],
                        [  1183,    798],
                        [  1090,    715],
                        [  1022,    653],
                        [   989,    625],
                        [   988,    626],
                        [  1024,    661],
                        [  1093,    730],
                        [  1193,    827],
                        [  1324,    956],
                        [  1480,   1109],
                        [  1663,   1289],
                        [  1866,   1488],
                        [  2087,   1707],
                        [  2322,   1939],
                        [  2568,   2184],
                        [  2818,   2435],
                        [  3072,   2693],
                        [  3323,   2951],
                        [  3572,   3208],
                        [  3813,   3459],
                        [  4049,   3703],
                        [  4275,   3937],
                        [  4493,   4158],
                        [  4700,   4366],
                        [  4899,   4560],
                        [  5084,   4738],
                        [  5259,   4901],
                        [  5419,   5049],
                        [  5569,   5181],
                        [  5703,   5297],
                        [  5823,   5397],
                        [  5922,   5480],
                        [  5999,   5545],
                        [  6052,   5597],
                        [  6082,   5632],
                        [  6093,   5656],
                        [  6084,   5666],
                        [  6068,   5670],
                        [  6045,   5663],
                        [  6019,   5649],
                        [  5991,   5625],
                        [  5961,   5596],
                        [  5923,   5554],
                        [  5881,   5505],
                        [  5852,   5465],
                        [  5841,   5441],
                        [  5835,   5420],
                        [  5794,   5363],
                        [  5666,   5218],
                        [  5443,   4978],
                        [  5156,   4674],
                        [  4815,   4315],
                        [  4425,   3909],
                        [  4001,   3469],
                        [  3556,   3006],
                        [  3097,   2531],
                        [  2634,   2052],
                        [  2178,   1580],
                        [  1738,   1123],
                        [  1315,    687],
                        [   916,    279],
                        [   545,    -98],
                        [   208,   -438],
                        [   -97,   -741],
                        [  -364,  -1003],
                        [  -595,  -1225],
                        [  -789,  -1407],
                        [  -947,  -1554],
                        [ -1069,  -1666],
                        [ -1160,  -1753],
                        [ -1219,  -1818],
                        [ -1250,  -1865],
                        [ -1255,  -1899],
                        [ -1239,  -1921],
                        [ -1204,  -1935],
                        [ -1153,  -1934],
                        [ -1090,  -1923],
                        [ -1017,  -1897],
                        [  -938,  -1859],
                        [  -852,  -1806],
                        [  -765,  -1741],
                        [  -678,  -1658],
                        [  -593,  -1558],
                        [  -509,  -1445],
                        [  -431,  -1320],
                        [  -358,  -1189],
                        [  -289,  -1055],
                        [  -228,   -927],
                        [  -174,   -807],
                        [  -126,   -696],
                        [   -85,   -592],
                        [   -50,   -498],
                        [   -20,   -413],
                        [     7,   -334],
                        [    28,   -265],
                        [    50,   -200],
                        [    72,   -141],
                        [    93,    -87],
                        [   116,    -36],
                        [   141,     13],
                        [   170,     60],
                        [   206,    108],
                        [   251,    156],
                        [   310,    206],
                        [   382,    258],
                        [   470,    312],
                        [   576,    371],
                        [   700,    432],
                        [   840,    496],
                        [   989,    565],
                        [  1144,    635],
                        [  1300,    708],
                        [  1452,    778],
                        [  1600,    848],
                        [  1745,    921],
                        [  1889,    999],
                        [  2030,   1082],
                        [  2210,   1214],
                        [  2425,   1389],
                        [  2690,   1625],
                        [  3005,   1919],
                        [  3371,   2277],
                        [  3789,   2697],
                        [  4193,   3113],
                        [  4585,   3529],
                        [  4922,   3899],
                        [  5207,   4226],
                        [  5428,   4500],
                        [  5588,   4719],
                        [  5679,   4877],
                        [  5701,   4973],
                        [  5653,   5004],
                        [  5536,   4969],
                        [  5348,   4868],
                        [  5091,   4700],
                        [  4771,   4470],
                        [  4386,   4177],
                        [  3946,   3826],
                        [  3448,   3417],
                        [  2906,   2959],
                        [  2317,   2450],
                        [  1692,   1900],
                        [  1032,   1309],
                        [   345,    688],
                        [  -367,     37],
                        [ -1096,   -633],
                        [ -1840,  -1321],
                        [ -2589,  -2017],
                        [ -3341,  -2719],
                        [ -4087,  -3419],
                        [ -4823,  -4113],
                        [ -5540,  -4793],
                        [ -6237,  -5457],
                        [ -6899,  -6095],
                        [ -7524,  -6706],
                        [ -8097,  -7279],
                        [ -8617,  -7815],
                        [ -9080,  -8306],
                        [ -9481,  -8751],
                        [ -9824,  -9147],
                        [-10106,  -9491],
                        [-10335,  -9780],
                        [-10508, -10012],
                        [-10623, -10186],
                        [-10676, -10295],
                        [-10679, -10350],
                        [-10659, -10378],
                        [-10646, -10411],
                        [-10646, -10453],
                        [-10648, -10493],
                        [-10618, -10498],
                        [-10493, -10405],
                        [-10232, -10172],
                        [ -9847,  -9809],
                        [ -9346,  -9328],
                        [ -8739,  -8735],
                        [ -8041,  -8048],
                        [ -7266,  -7280],
                        [ -6426,  -6442],
                        [ -5537,  -5549],
                        [ -4614,  -4616],
                        [ -3668,  -3655],
                        [ -2710,  -2676],
                        [ -1752,  -1695],
                        [  -804,   -718],
                        [   127,    241],
                        [  1029,   1177],
                        [  1896,   2079],
                        [  2724,   2942],
                        [  3505,   3761],
                        [  4235,   4531],
                        [  4911,   5253],
                        [  5531,   5922],
                        [  6091,   6542],
                        [  6594,   7112],
                        [  7039,   7632],
                        [  7425,   8104],
                        [  7757,   8526],
                        [  8035,   8899],
                        [  8262,   9217],
                        [  8440,   9483],
                        [  8573,   9696],
                        [  8663,   9858],
                        [  8715,   9964],
                        [  8732,  10017],
                        [  8718,  10017],
                        [  8678,   9968],
                        [  8615,   9876],
                        [  8533,   9745],
                        [  8437,   9590],
                        [  8330,   9414],
                        [  8216,   9228],
                        [  8099,   9035],
                        [  7983,   8839],
                        [  7871,   8644],
                        [  7765,   8455],
                        [  7670,   8274],
                        [  7586,   8105],
                        [  7516,   7950],
                        [  7462,   7812],
                        [  7425,   7694],
                        [  7406,   7595],
                        [  7406,   7520],
                        [  7425,   7467],
                        [  7464,   7438],
                        [  7519,   7434],
                        [  7591,   7455],
                        [  7677,   7498],
                        [  7777,   7566],
                        [  7885,   7655],
                        [  7999,   7768],
                        [  8120,   7900],
                        [  8245,   8050],
                        [  8378,   8218],
                        [  8518,   8403],
                        [  8667,   8601],
                        [  8821,   8812],
                        [  8978,   9029],
                        [  9136,   9250],
                        [  9271,   9450],
                        [  9382,   9627],
                        [  9440,   9752],
                        [  9443,   9821],
                        [  9380,   9821],
                        [  9250,   9752],
                        [  9062,   9622],
                        [  8814,   9430],
                        [  8567,   9232],
                        [  8314,   9025],
                        [  8067,   8820],
                        [  7826,   8613],
                        [  7599,   8417],
                        [  7384,   8228],
                        [  7187,   8052],
                        [  7008,   7888],
                        [  6847,   7737],
                        [  6706,   7603],
                        [  6585,   7483],
                        [  6481,   7378],
                        [  6397,   7289],
                        [  6331,   7213],
                        [  6280,   7151],
                        [  6244,   7102],
                        [  6221,   7064],
                        [  6210,   7036],
                        [  6210,   7018],
                        [  6221,   7009],
                        [  6242,   7006],
                        [  6272,   7010],
                        [  6310,   7018],
                        [  6356,   7031],
                        [  6408,   7045],
                        [  6467,   7061],
                        [  6528,   7078],
                        [  6592,   7094],
                        [  6655,   7109],
                        [  6717,   7122],
                        [  6769,   7132],
                        [  6810,   7139],
                        [  6836,   7139],
                        [  6849,   7135],
                        [  6847,   7127],
                        [  6832,   7113],
                        [  6813,   7096],
                        [  6788,   7074],
                        [  6762,   7047],
                        [  6731,   7013],
                        [  6693,   6969],
                        [  6673,   6941],
                        [  6726,   6983],
                        [  6887,   7131],
                        [  7159,   7387],
                        [  7534,   7746],
                        [  7978,   8172],
                        [  8413,   8591],
                        [  8764,   8924],
                        [  9015,   9159],
                        [  9172,   9300],
                        [  9240,   9353],
                        [  9223,   9323],
                        [  9129,   9219],
                        [  8967,   9047],
                        [  8744,   8816],
                        [  8470,   8531],
                        [  8154,   8204],
                        [  7803,   7840],
                        [  7422,   7446],
                        [  7019,   7029],
                        [  6600,   6596],
                        [  6170,   6151],
                        [  5733,   5701],
                        [  5295,   5249],
                        [  4860,   4800],
                        [  4432,   4355],
                        [  4012,   3918],
                        [  3604,   3488],
                        [  3210,   3067],
                        [  2831,   2656],
                        [  2467,   2255],
                        [  2119,   1860],
                        [  1788,   1473],
                        [  1471,   1097],
                        [  1172,    732],
                        [   890,    384],
                        [   623,     50],
                        [   375,   -260],
                        [   142,   -549],
                        [   -72,   -807],
                        [  -271,  -1034],
                        [  -452,  -1231],
                        [  -618,  -1397],
                        [  -766,  -1536],
                        [  -898,  -1649],
                        [ -1013,  -1745],
                        [ -1113,  -1825],
                        [ -1195,  -1889],
                        [ -1261,  -1939],
                        [ -1311,  -1974],
                        [ -1347,  -1995],
                        [ -1367,  -2002],
                        [ -1374,  -1996],
                        [ -1365,  -1978],
                        [ -1342,  -1949],
                        [ -1307,  -1908],
                        [ -1257,  -1854],
                        [ -1194,  -1790],
                        [ -1120,  -1715],
                        [ -1034,  -1631],
                        [  -938,  -1538],
                        [  -835,  -1437],
                        [  -726,  -1328],
                        [  -608,  -1214],
                        [  -485,  -1094],
                        [  -351,   -971],
                        [  -209,   -846],
                        [   -61,   -720],
                        [    94,   -593],
                        [   246,   -472],
                        [   395,   -358],
                        [   537,   -249],
                        [   674,   -145],
                        [   805,    -45],
                        [   929,     51],
                        [  1067,    165],
                        [  1216,    293],
                        [  1380,    444],
                        [  1558,    614],
                        [  1766,    821],
                        [  2001,   1061],
                        [  2227,   1299],
                        [  2446,   1539],
                        [  2628,   1748],
                        [  2775,   1929],
                        [  2875,   2071],
                        [  2932,   2175],
                        [  2935,   2231],
                        [  2886,   2240],
                        [  2781,   2197],
                        [  2621,   2104],
                        [  2406,   1958],
                        [  2138,   1760],
                        [  1819,   1513],
                        [  1451,   1217],
                        [  1040,    877],
                        [   588,    494],
                        [   102,     74],
                        [  -415,   -379],
                        [  -956,   -860],
                        [ -1516,  -1367],
                        [ -2088,  -1889],
                        [ -2669,  -2426],
                        [ -3251,  -2968],
                        [ -3830,  -3512],
                        [ -4399,  -4048],
                        [ -4953,  -4573],
                        [ -5484,  -5077],
                        [ -5990,  -5560],
                        [ -6462,  -6012],
                        [ -6897,  -6430],
                        [ -7282,  -6808],
                        [ -7619,  -7144],
                        [ -7894,  -7430],
                        [ -8107,  -7665],
                        [ -8256,  -7846],
                        [ -8337,  -7971],
                        [ -8356,  -8040],
                        [ -8309,  -8049],
                        [ -8208,  -8001],
                        [ -8051,  -7895],
                        [ -7838,  -7729],
                        [ -7567,  -7502],
                        [ -7287,  -7260],
                        [ -7074,  -7078],
                        [ -6967,  -6997],
                        [ -6974,  -7023],
                        [ -7094,  -7156],
                        [ -7305,  -7375],
                        [ -7520,  -7591],
                        [ -7637,  -7703],
                        [ -7633,  -7690],
                        [ -7518,  -7562],
                        [ -7296,  -7324],
                        [ -6975,  -6983],
                        [ -6564,  -6551],
                        [ -6074,  -6035],
                        [ -5518,  -5449],
                        [ -4906,  -4800],
                        [ -4252,  -4103],
                        [ -3566,  -3367],
                        [ -2857,  -2604],
                        [ -2136,  -1824],
                        [ -1411,  -1037],
                        [  -689,   -249],
                        [    19,    527],
                        [   709,   1285],
                        [  1372,   2020],
                        [  2004,   2724],
                        [  2602,   3393],
                        [  3160,   4022],
                        [  3678,   4609],
                        [  4153,   5150],
                        [  4586,   5650],
                        [  4976,   6106],
                        [  5326,   6524],
                        [  5636,   6903],
                        [  5908,   7244],
                        [  6143,   7548],
                        [  6344,   7814],
                        [  6514,   8043],
                        [  6654,   8229],
                        [  6768,   8378],
                        [  6860,   8486],
                        [  6932,   8558],
                        [  6988,   8599],
                        [  7032,   8608],
                        [  7066,   8600],
                        [  7092,   8576],
                        [  7112,   8544],
                        [  7131,   8509],
                        [  7150,   8471],
                        [  7171,   8435],
                        [  7198,   8405],
                        [  7232,   8381],
                        [  7274,   8367],
                        [  7326,   8364],
                        [  7388,   8372],
                        [  7460,   8394],
                        [  7541,   8429],
                        [  7633,   8477],
                        [  7733,   8538],
                        [  7842,   8613],
                        [  7962,   8698],
                        [  8091,   8794],
                        [  8228,   8898],
                        [  8375,   9011],
                        [  8522,   9128],
                        [  8668,   9250],
                        [  8803,   9373],
                        [  8925,   9495],
                        [  9030,   9613],
                        [  9120,   9728],
                        [  9192,   9837],
                        [  9245,   9935],
                        [  9275,  10020],
                        [  9283,  10089],
                        [  9258,  10130],
                        [  9198,  10143],
                        [  9102,  10121],
                        [  8966,  10061],
                        [  8779,   9951],
                        [  8541,   9788],
                        [  8242,   9562],
                        [  7881,   9271],
                        [  7489,   8945],
                        [  7065,   8582],
                        [  6620,   8192],
                        [  6156,   7777],
                        [  5687,   7350],
                        [  5211,   6908],
                        [  4738,   6462],
                        [  4270,   6013],
                        [  3815,   5571],
                        [  3373,   5132],
                        [  2949,   4707],
                        [  2547,   4294],
                        [  2168,   3898],
                        [  1813,   3521],
                        [  1484,   3164],
                        [  1184,   2828],
                        [   910,   2516],
                        [   665,   2229],
                        [   448,   1965],
                        [   258,   1727],
                        [    95,   1515],
                        [   -41,   1327],
                        [  -152,   1163],
                        [  -239,   1021],
                        [  -305,    898],
                        [  -349,    795],
                        [  -375,    706],
                        [  -385,    634],
                        [  -384,    573],
                        [  -372,    524],
                        [  -360,    483],
                        [  -347,    449],
                        [  -339,    420],
                        [  -335,    395],
                        [  -340,    371],
                        [  -353,    346],
                        [  -371,    319],
                        [  -396,    289],
                        [  -422,    257],
                        [  -458,    215],
                        [  -505,    163],
                        [  -498,    163],
                        [  -353,    297],
                        [   -36,    605],
                        [   454,   1082],
                        [  1120,   1735],
                        [  1943,   2544],
                        [  2819,   3404],
                        [  3617,   4188],
                        [  4304,   4859],
                        [  4882,   5424],
                        [  5350,   5881],
                        [  5704,   6227],
                        [  5948,   6466],
                        [  6087,   6599],
                        [  6126,   6632],
                        [  6076,   6571],
                        [  5940,   6420],
                        [  5727,   6189],
                        [  5445,   5883],
                        [  5100,   5508],
                        [  4700,   5074],
                        [  4251,   4588],
                        [  3761,   4057],
                        [  3239,   3489],
                        [  2690,   2891],
                        [  2124,   2272],
                        [  1544,   1637],
                        [   959,    997],
                        [   371,    358],
                        [  -212,   -278],
                        [  -789,   -904],
                        [ -1354,  -1522],
                        [ -1906,  -2130],
                        [ -2442,  -2728],
                        [ -2958,  -3314],
                        [ -3450,  -3883],
                        [ -3918,  -4432],
                        [ -4358,  -4955],
                        [ -4770,  -5448],
                        [ -5152,  -5904],
                        [ -5503,  -6324],
                        [ -5822,  -6702],
                        [ -6109,  -7039],
                        [ -6364,  -7334],
                        [ -6587,  -7590],
                        [ -6776,  -7811],
                        [ -6933,  -7997],
                        [ -7057,  -8150],
                        [ -7150,  -8270],
                        [ -7213,  -8361],
                        [ -7248,  -8421],
                        [ -7257,  -8452],
                        [ -7240,  -8458],
                        [ -7200,  -8438],
                        [ -7138,  -8394],
                        [ -7057,  -8329],
                        [ -6957,  -8244],
                        [ -6841,  -8140],
                        [ -6711,  -8019],
                        [ -6573,  -7885],
                        [ -6429,  -7738],
                        [ -6287,  -7582],
                        [ -6150,  -7419],
                        [ -6019,  -7249],
                        [ -5896,  -7078],
                        [ -5775,  -6904],
                        [ -5658,  -6732],
                        [ -5539,  -6565],
                        [ -5419,  -6402],
                        [ -5302,  -6248],
                        [ -5190,  -6107],
                        [ -5084,  -5975],
                        [ -4985,  -5857],
                        [ -4896,  -5753],
                        [ -4818,  -5662],
                        [ -4759,  -5593],
                        [ -4718,  -5545],
                        [ -4698,  -5519],
                        [ -4700,  -5514],
                        [ -4697,  -5506],
                        [ -4692,  -5496],
                        [ -4681,  -5477],
                        [ -4662,  -5450],
                        [ -4650,  -5429],
                        [ -4643,  -5410],
                        [ -4652,  -5404],
                        [ -4674,  -5410],
                        [ -4717,  -5434],
                        [ -4780,  -5475],
                        [ -4868,  -5540],
                        [ -4977,  -5626],
                        [ -5111,  -5735],
                        [ -5269,  -5867],
                        [ -5450,  -6021],
                        [ -5651,  -6196],
                        [ -5871,  -6390],
                        [ -6106,  -6601],
                        [ -6355,  -6824],
                        [ -6612,  -7058],
                        [ -6874,  -7300],
                        [ -7138,  -7544],
                        [ -7397,  -7789],
                        [ -7650,  -8032],
                        [ -7889,  -8265],
                        [ -8112,  -8487],
                        [ -8313,  -8691],
                        [ -8491,  -8873],
                        [ -8639,  -9026],
                        [ -8756,  -9150],
                        [ -8836,  -9237],
                        [ -8878,  -9288],
                        [ -8877,  -9297],
                        [ -8830,  -9264],
                        [ -8734,  -9186],
                        [ -8587,  -9063],
                        [ -8388,  -8894],
                        [ -8138,  -8678],
                        [ -7839,  -8416],
                        [ -7492,  -8108],
                        [ -7105,  -7757],
                        [ -6681,  -7367],
                        [ -6218,  -6931],
                        [ -5722,  -6460],
                        [ -5279,  -6034],
                        [ -4980,  -5744],
                        [ -4860,  -5627],
                        [ -4925,  -5687],
                        [ -5189,  -5939],
                        [ -5648,  -6377],
                        [ -6188,  -6893],
                        [ -6674,  -7349],
                        [ -7070,  -7711],
                        [ -7385,  -7990],
                        [ -7614,  -8182],
                        [ -7755,  -8286],
                        [ -7812,  -8305],
                        [ -7789,  -8243],
                        [ -7695,  -8106],
                        [ -7534,  -7899],
                        [ -7317,  -7628],
                        [ -7048,  -7300],
                        [ -6735,  -6923],
                        [ -6384,  -6504],
                        [ -6000,  -6049],
                        [ -5592,  -5567],
                        [ -5164,  -5064],
                        [ -4724,  -4548],
                        [ -4276,  -4023],
                        [ -3828,  -3497],
                        [ -3380,  -2979],
                        [ -2940,  -2475],
                        [ -2508,  -1991],
                        [ -2087,  -1531],
                        [ -1679,  -1092],
                        [ -1285,   -678],
                        [  -904,   -279],
                        [  -537,    106],
                        [  -184,    479],
                        [   154,    841],
                        [   479,   1190],
                        [   790,   1527],
                        [  1087,   1846],
                        [  1373,   2149],
                        [  1648,   2435],
                        [  1913,   2706],
                        [  2170,   2959],
                        [  2420,   3196],
                        [  2661,   3423],
                        [  2897,   3641],
                        [  3125,   3850],
                        [  3347,   4054],
                        [  3564,   4253],
                        [  3776,   4449],
                        [  3983,   4643],
                        [  4188,   4835],
                        [  4388,   5026],
                        [  4583,   5215],
                        [  4774,   5403],
                        [  4960,   5588],
                        [  5139,   5770],
                        [  5311,   5948],
                        [  5473,   6119],
                        [  5627,   6283],
                        [  5777,   6438],
                        [  5922,   6584],
                        [  6065,   6716],
                        [  6205,   6836],
                        [  6334,   6938],
                        [  6452,   7023],
                        [  6544,   7088],
                        [  6607,   7132],
                        [  6635,   7152],
                        [  6626,   7148],
                        [  6580,   7119],
                        [  6495,   7062],
                        [  6372,   6977],
                        [  6211,   6862],
                        [  6024,   6728],
                        [  5810,   6575],
                        [  5589,   6419],
                        [  5359,   6257],
                        [  5110,   6078],
                        [  4842,   5881],
                        [  4522,   5631],
                        [  4151,   5329],
                        [  3731,   4974],
                        [  3262,   4566],
                        [  2758,   4119],
                        [  2220,   3630],
                        [  1662,   3116],
                        [  1084,   2573],
                        [   501,   2017],
                        [   -87,   1450],
                        [  -669,    879],
                        [ -1242,    309],
                        [ -1799,   -252],
                        [ -2338,   -803],
                        [ -2849,  -1335],
                        [ -3335,  -1848],
                        [ -3788,  -2334],
                        [ -4207,  -2795],
                        [ -4591,  -3226],
                        [ -4937,  -3626],
                        [ -5246,  -3991],
                        [ -5520,  -4323],
                        [ -5758,  -4617],
                        [ -5961,  -4877],
                        [ -6132,  -5102],
                        [ -6270,  -5293],
                        [ -6380,  -5455],
                        [ -6461,  -5589],
                        [ -6519,  -5700],
                        [ -6554,  -5787],
                        [ -6572,  -5857],
                        [ -6573,  -5908],
                        [ -6564,  -5945],
                        [ -6547,  -5970],
                        [ -6528,  -5987],
                        [ -6507,  -5996],
                        [ -6492,  -6002],
                        [ -6484,  -6006],
                        [ -6484,  -6014],
                        [ -6490,  -6024],
                        [ -6502,  -6038],
                        [ -6530,  -6064],
                        [ -6563,  -6095],
                        [ -6513,  -6044],
                        [ -6295,  -5827],
                        [ -5888,  -5422],
                        [ -5290,  -4827],
                        [ -4480,  -4023],
                        [ -3464,  -3014],
                        [ -2358,  -1918],
                        [ -1311,   -882],
                        [  -357,     62],
                        [   505,    913],
                        [  1263,   1665],
                        [  1912,   2308],
                        [  2447,   2841],
                        [  2875,   3262],
                        [  3192,   3573],
                        [  3408,   3772],
                        [  3525,   3868],
                        [  3549,   3862],
                        [  3485,   3760],
                        [  3339,   3569],
                        [  3119,   3296],
                        [  2832,   2949],
                        [  2485,   2535],
                        [  2087,   2065],
                        [  1645,   1544],
                        [  1170,    987],
                        [   667,    400],
                        [   145,   -199],
                        [  -388,   -802],
                        [  -930,  -1402],
                        [ -1471,  -1991],
                        [ -2006,  -2570],
                        [ -2533,  -3135],
                        [ -3045,  -3695],
                        [ -3540,  -4245],
                        [ -4011,  -4778],
                        [ -4457,  -5295],
                        [ -4874,  -5787],
                        [ -5261,  -6251],
                        [ -5615,  -6685],
                        [ -5935,  -7085],
                        [ -6220,  -7449],
                        [ -6470,  -7776],
                        [ -6685,  -8062],
                        [ -6865,  -8308],
                        [ -7009,  -8516],
                        [ -7120,  -8687],
                        [ -7197,  -8822],
                        [ -7243,  -8922],
                        [ -7260,  -8991],
                        [ -7249,  -9030],
                        [ -7216,  -9042],
                        [ -7162,  -9028],
                        [ -7091,  -8993],
                        [ -7005,  -8938],
                        [ -6907,  -8868],
                        [ -6800,  -8783],
                        [ -6687,  -8687],
                        [ -6570,  -8583],
                        [ -6458,  -8473],
                        [ -6353,  -8358],
                        [ -6267,  -8243],
                        [ -6202,  -8129],
                        [ -6160,  -8019],
                        [ -6146,  -7915],
                        [ -6147,  -7818],
                        [ -6169,  -7729],
                        [ -6195,  -7652],
                        [ -6228,  -7586],
                        [ -6264,  -7533],
                        [ -6304,  -7492],
                        [ -6349,  -7465],
                        [ -6398,  -7453],
                        [ -6461,  -7463],
                        [ -6536,  -7494],
                        [ -6654,  -7577],
                        [ -6815,  -7711],
                        [ -7022,  -7900],
                        [ -7276,  -8142],
                        [ -7540,  -8400],
                        [ -7815,  -8676],
                        [ -8058,  -8922],
                        [ -8266,  -9141],
                        [ -8444,  -9331],
                        [ -8586,  -9490],
                        [ -8702,  -9623],
                        [ -8787,  -9728],
                        [ -8849,  -9811],
                        [ -8886,  -9868],
                        [ -8903,  -9906],
                        [ -8898,  -9923],
                        [ -8877,  -9923],
                        [ -8835,  -9903],
                        [ -8780,  -9868],
                        [ -8707,  -9813],
                        [ -8620,  -9744],
                        [ -8517,  -9657],
                        [ -8401,  -9553],
                        [ -8270,  -9432],
                        [ -8122,  -9293],
                        [ -7956,  -9135],
                        [ -7771,  -8959],
                        [ -7564,  -8765],
                        [ -7336,  -8552],
                        [ -7085,  -8318],
                        [ -6810,  -8063],
                        [ -6511,  -7785],
                        [ -6186,  -7480],
                        [ -5836,  -7149],
                        [ -5462,  -6790],
                        [ -5064,  -6404],
                        [ -4642,  -5991],
                        [ -4198,  -5553],
                        [ -3733,  -5090],
                        [ -3247,  -4604],
                        [ -2737,  -4095],
                        [ -2207,  -3569],
                        [ -1656,  -3022],
                        [ -1088,  -2459],
                        [  -509,  -1885],
                        [    76,  -1302],
                        [   671,   -706],
                        [  1256,   -116],
                        [  1736,    375],
                        [  2034,    687],
                        [  2130,    804],
                        [  2015,    717],
                        [  1661,    396],
                        [  1061,   -166],
                        [   328,   -857],
                        [  -399,  -1539],
                        [ -1086,  -2182],
                        [ -1740,  -2791],
                        [ -2345,  -3353],
                        [ -2892,  -3860],
                        [ -3377,  -4307],
                        [ -3798,  -4691],
                        [ -4157,  -5010],
                        [ -4450,  -5262],
                        [ -4682,  -5446],
                        [ -4853,  -5566],
                        [ -4963,  -5623],
                        [ -5016,  -5618],
                        [ -5014,  -5555],
                        [ -4959,  -5437],
                        [ -4856,  -5270],
                        [ -4708,  -5057],
                        [ -4520,  -4803],
                        [ -4297,  -4513],
                        [ -4039,  -4200],
                        [ -3753,  -3868],
                        [ -3441,  -3527],
                        [ -3107,  -3183],
                        [ -2753,  -2835],
                        [ -2381,  -2487],
                        [ -1995,  -2126],
                        [ -1595,  -1753],
                        [ -1185,  -1365],
                        [  -766,   -960],
                        [  -342,   -545],
                        [    87,   -118],
                        [   517,    317],
                        [   947,    758],
                        [  1376,   1203],
                        [  1802,   1653],
                        [  2224,   2100],
                        [  2640,   2543],
                        [  3046,   2980],
                        [  3443,   3410],
                        [  3827,   3829],
                        [  4197,   4236],
                        [  4552,   4629],
                        [  4890,   5009],
                        [  5208,   5373],
                        [  5509,   5722],
                        [  5787,   6052],
                        [  6046,   6364],
                        [  6281,   6656],
                        [  6493,   6926],
                        [  6678,   7171],
                        [  6837,   7394],
                        [  6971,   7588],
                        [  7079,   7755],
                        [  7168,   7892],
                        [  7238,   7999],
                        [  7295,   8074],
                        [  7339,   8116],
                        [  7365,   8125],
                        [  7373,   8101],
                        [  7347,   8041],
                        [  7290,   7946],
                        [  7187,   7816],
                        [  7041,   7651],
                        [  6852,   7449],
                        [  6619,   7214],
                        [  6346,   6948],
                        [  6035,   6651],
                        [  5722,   6359],
                        [  5406,   6071],
                        [  5120,   5817],
                        [  4862,   5597],
                        [  4626,   5400],
                        [  4412,   5228],
                        [  4165,   5025],
                        [  3889,   4795],
                        [  3560,   4509],
                        [  3181,   4173],
                        [  2763,   3795],
                        [  2308,   3376],
                        [  1826,   2926],
                        [  1318,   2446],
                        [   798,   1948],
                        [   266,   1432],
                        [  -267,    911],
                        [  -799,    384],
                        [ -1320,   -137],
                        [ -1830,   -652],
                        [ -2319,  -1152],
                        [ -2788,  -1638],
                        [ -3226,  -2101],
                        [ -3637,  -2543],
                        [ -4015,  -2957],
                        [ -4360,  -3342],
                        [ -4672,  -3696],
                        [ -4951,  -4019],
                        [ -5201,  -4306],
                        [ -5419,  -4561],
                        [ -5610,  -4783],
                        [ -5774,  -4973],
                        [ -5913,  -5136],
                        [ -6027,  -5272],
                        [ -6121,  -5385],
                        [ -6196,  -5480],
                        [ -6253,  -5557],
                        [ -6294,  -5618],
                        [ -6319,  -5666],
                        [ -6333,  -5704],
                        [ -6342,  -5735],
                        [ -6346,  -5757],
                        [ -6356,  -5778],
                        [ -6371,  -5796],
                        [ -6395,  -5819],
                        [ -6426,  -5844],
                        [ -6463,  -5871],
                        [ -6518,  -5913],
                        [ -6565,  -5946],
                        [ -6520,  -5888],
                        [ -6325,  -5683],
                        [ -5974,  -5321],
                        [ -5454,  -4795],
                        [ -4734,  -4073],
                        [ -3804,  -3144],
                        [ -2767,  -2111],
                        [ -1752,  -1101],
                        [  -784,   -140],
                        [   134,    773],
                        [   990,   1623],
                        [  1770,   2397],
                        [  2470,   3091],
                        [  3088,   3699],
                        [  3620,   4217],
                        [  4068,   4643],
                        [  4433,   4978],
                        [  4717,   5223],
                        [  4921,   5380],
                        [  5049,   5453],
                        [  5106,   5445],
                        [  5095,   5364],
                        [  5025,   5215],
                        [  4900,   5004],
                        [  4728,   4741],
                        [  4515,   4436],
                        [  4269,   4097],
                        [  3995,   3744],
                        [  3699,   3382],
                        [  3390,   3021],
                        [  3070,   2667],
                        [  2747,   2321],
                        [  2424,   1986],
                        [  2105,   1649],
                        [  1795,   1318],
                        [  1497,    991],
                        [  1214,    673],
                        [   950,    367],
                        [   705,     75],
                        [   482,   -205],
                        [   281,   -469],
                        [   102,   -716],
                        [   -52,   -944],
                        [  -184,  -1149],
                        [  -293,  -1331],
                        [  -380,  -1488],
                        [  -446,  -1619],
                        [  -492,  -1727],
                        [  -518,  -1810],
                        [  -529,  -1874],
                        [  -525,  -1918],
                        [  -509,  -1948],
                        [  -484,  -1962],
                        [  -454,  -1966],
                        [  -419,  -1961],
                        [  -384,  -1949],
                        [  -349,  -1934],
                        [  -319,  -1917],
                        [  -293,  -1899],
                        [  -282,  -1883],
                        [  -286,  -1871],
                        [  -316,  -1864],
                        [  -374,  -1864],
                        [  -462,  -1871],
                        [  -583,  -1888],
                        [  -726,  -1914],
                        [  -894,  -1949],
                        [ -1067,  -1995],
                        [ -1247,  -2049],
                        [ -1424,  -2110],
                        [ -1599,  -2180],
                        [ -1770,  -2257],
                        [ -1936,  -2342],
                        [ -2115,  -2450],
                        [ -2303,  -2580],
                        [ -2548,  -2778],
                        [ -2845,  -3040],
                        [ -3200,  -3372],
                        [ -3611,  -3772],
                        [ -4037,  -4197],
                        [ -4479,  -4648],
                        [ -4864,  -5051],
                        [ -5194,  -5407],
                        [ -5461,  -5708],
                        [ -5663,  -5951],
                        [ -5804,  -6137],
                        [ -5879,  -6262],
                        [ -5896,  -6332],
                        [ -5850,  -6342],
                        [ -5751,  -6299],
                        [ -5593,  -6200],
                        [ -5387,  -6052],
                        [ -5129,  -5852],
                        [ -4826,  -5606],
                        [ -4479,  -5315],
                        [ -4097,  -4981],
                        [ -3677,  -4607],
                        [ -3227,  -4197],
                        [ -2746,  -3752],
                        [ -2240,  -3276],
                        [ -1709,  -2771],
                        [ -1154,  -2242],
                        [  -575,  -1689],
                        [    22,  -1118],
                        [   637,   -531],
                        [  1266,     72],
                        [  1908,    687],
                        [  2559,   1314],
                        [  3218,   1951],
                        [  3876,   2596],
                        [  4535,   3246],
                        [  5185,   3899],
                        [  5824,   4551],
                        [  6451,   5198],
                        [  7063,   5839],
                        [  7665,   6470],
                        [  8251,   7087],
                        [  8827,   7690],
                        [  9388,   8275],
                        [  9929,   8841],
                        [ 10446,   9381],
                        [ 10944,   9904],
                        [ 11395,  10380],
                        [ 11726,  10737],
                        [ 11894,  10935],
                        [ 11898,  10970],
                        [ 11724,  10828],
                        [ 11332,  10472],
                        [ 10703,   9882],
                        [  9926,   9143],
                        [  9109,   8364],
                        [  8275,   7564],
                        [  7425,   6746],
                        [  6581,   5930],
                        [  5757,   5129],
                        [  4962,   4353],
                        [  4206,   3612],
                        [  3492,   2916],
                        [  2830,   2272],
                        [  2224,   1686],
                        [  1676,   1160],
                        [  1194,    702],
                        [   777,    310],
                        [   427,    -11],
                        [   145,   -263],
                        [   -71,   -446],
                        [  -220,   -562],
                        [  -306,   -614],
                        [  -331,   -605],
                        [  -296,   -547],
                        [  -206,   -444],
                        [   -63,   -308],
                        [   126,   -141],
                        [   360,     54],
                        [   634,    270],
                        [   943,    520],
                        [  1285,    800],
                        [  1654,   1115],
                        [  2048,   1463],
                        [  2460,   1840],
                        [  2888,   2243],
                        [  3328,   2672],
                        [  3774,   3122],
                        [  4224,   3593],
                        [  4673,   4080],
                        [  5117,   4575],
                        [  5554,   5075],
                        [  5978,   5569],
                        [  6388,   6056],
                        [  6778,   6526],
                        [  7146,   6977],
                        [  7488,   7406],
                        [  7802,   7811],
                        [  8087,   8188],
                        [  8340,   8536],
                        [  8558,   8851],
                        [  8743,   9135],
                        [  8890,   9382],
                        [  9003,   9594],
                        [  9079,   9768],
                        [  9116,   9902],
                        [  9118,   9996],
                        [  9085,  10051],
                        [  9024,  10064],
                        [  8939,  10037],
                        [  8836,   9970],
                        [  8717,   9863],
                        [  8578,   9717],
                        [  8426,   9533],
                        [  8245,   9313],
                        [  8040,   9057],
                        [  7797,   8768],
                        [  7517,   8443],
                        [  7204,   8088],
                        [  6859,   7706],
                        [  6490,   7305],
                        [  6097,   6886],
                        [  5733,   6500],
                        [  5397,   6147],
                        [  5122,   5861],
                        [  4909,   5642],
                        [  4756,   5486],
                        [  4663,   5395],
                        [  4560,   5298],
                        [  4453,   5199],
                        [  4305,   5061],
                        [  4116,   4887],
                        [  3894,   4680],
                        [  3640,   4442],
                        [  3358,   4176],
                        [  3050,   3884],
                        [  2724,   3573],
                        [  2378,   3241],
                        [  2024,   2900],
                        [  1659,   2546],
                        [  1293,   2190],
                        [   925,   1831],
                        [   563,   1475],
                        [   207,   1122],
                        [  -134,    779],
                        [  -463,    444],
                        [  -774,    124],
                        [ -1070,   -183],
                        [ -1349,   -473],
                        [ -1612,   -746],
                        [ -1861,   -999],
                        [ -2095,  -1235],
                        [ -2316,  -1450],
                        [ -2524,  -1648],
                        [ -2719,  -1829],
                        [ -2903,  -1995],
                        [ -3075,  -2148],
                        [ -3238,  -2292],
                        [ -3385,  -2427],
                        [ -3517,  -2552],
                        [ -3635,  -2670],
                        [ -3739,  -2781],
                        [ -3837,  -2887],
                        [ -3927,  -2986],
                        [ -4019,  -3083],
                        [ -4115,  -3178],
                        [ -4215,  -3272],
                        [ -4318,  -3364],
                        [ -4422,  -3455],
                        [ -4533,  -3551],
                        [ -4626,  -3629],
                        [ -4650,  -3637],
                        [ -4583,  -3557],
                        [ -4427,  -3391],
                        [ -4167,  -3125],
                        [ -3762,  -2716],
                        [ -3181,  -2135],
                        [ -2486,  -1446],
                        [ -1763,   -730],
                        [ -1024,      1],
                        [  -272,    742],
                        [   475,   1476],
                        [  1203,   2192],
                        [  1905,   2880],
                        [  2577,   3534],
                        [  3210,   4145],
                        [  3801,   4708],
                        [  4345,   5217],
                        [  4843,   5672],
                        [  5289,   6070],
                        [  5683,   6411],
                        [  6027,   6694],
                        [  6322,   6923],
                        [  6568,   7098],
                        [  6769,   7223],
                        [  6927,   7303],
                        [  7046,   7345],
                        [  7128,   7355],
                        [  7178,   7346],
                        [  7200,   7323],
                        [  7196,   7294],
                        [  7172,   7262],
                        [  7131,   7227],
                        [  7077,   7195],
                        [  7010,   7148],
                        [  6936,   7093],
                        [  6853,   7027],
                        [  6767,   6953],
                        [  6676,   6867],
                        [  6584,   6773],
                        [  6490,   6666],
                        [  6398,   6546],
                        [  6304,   6415],
                        [  6212,   6271],
                        [  6119,   6124],
                        [  6026,   5972],
                        [  5934,   5822],
                        [  5841,   5674],
                        [  5748,   5529],
                        [  5653,   5387],
                        [  5558,   5246],
                        [  5458,   5107],
                        [  5355,   4966],
                        [  5247,   4825],
                        [  5133,   4680],
                        [  5011,   4533],
                        [  4881,   4381],
                        [  4741,   4224],
                        [  4592,   4063],
                        [  4433,   3894],
                        [  4258,   3720],
                        [  4067,   3539],
                        [  3854,   3353],
                        [  3617,   3161],
                        [  3355,   2962],
                        [  3068,   2759],
                        [  2763,   2552],
                        [  2441,   2342],
                        [  2118,   2130],
                        [  1796,   1920],
                        [  1487,   1714],
                        [  1188,   1511],
                        [   904,   1314],
                        [   636,   1122],
                        [   361,    912],
                        [    82,    688],
                        [  -249,    401],
                        [  -626,     55],
                        [ -1055,   -355],
                        [ -1535,   -827],
                        [ -2029,  -1324],
                        [ -2537,  -1848],
                        [ -2976,  -2312],
                        [ -3349,  -2719],
                        [ -3646,  -3059],
                        [ -3864,  -3330],
                        [ -4004,  -3526],
                        [ -4062,  -3648],
                        [ -4042,  -3697],
                        [ -3943,  -3670],
                        [ -3771,  -3572],
                        [ -3525,  -3401],
                        [ -3212,  -3165],
                        [ -2832,  -2862],
                        [ -2397,  -2499],
                        [ -1904,  -2078],
                        [ -1366,  -1607],
                        [  -783,  -1086],
                        [  -167,   -524],
                        [   483,     78],
                        [  1157,    710],
                        [  1855,   1372],
                        [  2570,   2052],
                        [  3301,   2751],
                        [  4041,   3459],
                        [  4786,   4174],
                        [  5531,   4888],
                        [  6272,   5601],
                        [  7002,   6305],
                        [  7719,   6999],
                        [  8410,   7678],
                        [  9075,   8340],
                        [  9703,   8980],
                        [ 10291,   9592],
                        [ 10839,  10175],
                        [ 11343,  10723],
                        [ 11808,  11235],
                        [ 12234,  11707],
                        [ 12625,  12139],
                        [ 12977,  12529],
                        [ 13289,  12874],
                        [ 13558,  13175],
                        [ 13790,  13433],
                        [ 13961,  13630],
                        [ 14051,  13742],
                        [ 14055,  13767],
                        [ 13981,  13713],
                        [ 13813,  13562],
                        [ 13511,  13277],
                        [ 13037,  12819],
                        [ 12427,  12223],
                        [ 11741,  11548],
                        [ 10992,  10806],
                        [ 10188,  10007],
                        [  9351,   9168],
                        [  8496,   8309],
                        [  7636,   7440],
                        [  6782,   6575],
                        [  5946,   5726],
                        [  5139,   4905],
                        [  4368,   4121],
                        [  3641,   3382],
                        [  2966,   2696],
                        [  2348,   2069],
                        [  1791,   1504],
                        [  1297,   1004],
                        [   869,    574],
                        [   509,    212],
                        [   215,    -82],
                        [   -13,   -309],
                        [  -176,   -480],
                        [  -278,   -597],
                        [  -322,   -669],
                        [  -312,   -698],
                        [  -253,   -691],
                        [  -149,   -653],
                        [    -5,   -577],
                        [   174,   -468],
                        [   384,   -321],
                        [   618,   -141],
                        [   873,     71],
                        [  1145,    309],
                        [  1426,    575],
                        [  1712,    865],
                        [  2000,   1177],
                        [  2283,   1509],
                        [  2558,   1850],
                        [  2820,   2198],
                        [  3066,   2538],
                        [  3293,   2869],
                        [  3495,   3177],
                        [  3671,   3462],
                        [  3817,   3720],
                        [  3932,   3948],
                        [  4011,   4141],
                        [  4055,   4301],
                        [  4063,   4424],
                        [  4034,   4509],
                        [  3969,   4557],
                        [  3868,   4564],
                        [  3730,   4532],
                        [  3559,   4462],
                        [  3354,   4353],
                        [  3120,   4206],
                        [  2864,   4024],
                        [  2587,   3806],
                        [  2297,   3555],
                        [  1996,   3274],
                        [  1690,   2965],
                        [  1378,   2629],
                        [  1058,   2271],
                        [   733,   1892],
                        [   392,   1494],
                        [    37,   1078],
                        [  -330,    650],
                        [  -702,    215],
                        [ -1073,   -219],
                        [ -1443,   -650],
                        [ -1756,  -1021],
                        [ -2014,  -1336],
                        [ -2193,  -1567],
                        [ -2291,  -1713],
                        [ -2307,  -1771],
                        [ -2237,  -1740],
                        [ -2153,  -1688],
                        [ -2051,  -1613],
                        [ -1970,  -1554],
                        [ -1909,  -1508],
                        [ -1870,  -1480],
                        [ -1854,  -1469],
                        [ -1861,  -1478],
                        [ -1892,  -1506],
                        [ -1947,  -1554],
                        [ -2024,  -1620],
                        [ -2122,  -1704],
                        [ -2241,  -1806],
                        [ -2377,  -1923],
                        [ -2531,  -2056],
                        [ -2698,  -2200],
                        [ -2879,  -2359],
                        [ -3066,  -2525],
                        [ -3263,  -2702],
                        [ -3466,  -2886],
                        [ -3675,  -3077],
                        [ -3889,  -3271],
                        [ -4110,  -3471],
                        [ -4337,  -3673],
                        [ -4570,  -3875],
                        [ -4805,  -4078],
                        [ -5046,  -4282],
                        [ -5289,  -4485],
                        [ -5533,  -4687],
                        [ -5776,  -4889],
                        [ -6016,  -5090],
                        [ -6244,  -5290],
                        [ -6460,  -5488],
                        [ -6662,  -5683],
                        [ -6847,  -5874],
                        [ -7021,  -6058],
                        [ -7182,  -6234],
                        [ -7339,  -6404],
                        [ -7493,  -6564],
                        [ -7641,  -6717],
                        [ -7780,  -6858],
                        [ -7910,  -6989],
                        [ -8031,  -7109],
                        [ -8132,  -7209],
                        [ -8215,  -7291],
                        [ -8294,  -7369],
                        [ -8372,  -7449],
                        [ -8432,  -7512],
                        [ -8431,  -7517],
                        [ -8318,  -7413],
                        [ -8088,  -7196],
                        [ -7775,  -6897],
                        [ -7383,  -6523],
                        [ -6921,  -6079],
                        [ -6402,  -5581],
                        [ -5838,  -5039],
                        [ -5239,  -4464],
                        [ -4614,  -3863],
                        [ -3972,  -3247],
                        [ -3322,  -2624],
                        [ -2670,  -2004],
                        [ -2024,  -1391],
                        [ -1390,   -793],
                        [  -774,   -213],
                        [  -177,    344],
                        [   393,    873],
                        [   937,   1374],
                        [  1449,   1844],
                        [  1928,   2281],
                        [  2373,   2690],
                        [  2784,   3070],
                        [  3159,   3427],
                        [  3500,   3762],
                        [  3808,   4079],
                        [  4084,   4379],
                        [  4328,   4661],
                        [  4543,   4928],
                        [  4727,   5168],
                        [  4883,   5382],
                        [  5011,   5567],
                        [  5111,   5725],
                        [  5182,   5848],
                        [  5228,   5939],
                        [  5248,   5990],
                        [  5242,   6002],
                        [  5212,   5974],
                        [  5159,   5905],
                        [  5082,   5805],
                        [  4983,   5672],
                        [  4862,   5517],
                        [  4721,   5341],
                        [  4560,   5147],
                        [  4379,   4936],
                        [  4181,   4708],
                        [  3967,   4466],
                        [  3738,   4209],
                        [  3494,   3940],
                        [  3236,   3659],
                        [  2966,   3366],
                        [  2685,   3065],
                        [  2394,   2755],
                        [  2094,   2438],
                        [  1787,   2117],
                        [  1471,   1791],
                        [  1148,   1463],
                        [   817,   1134],
                        [   476,    806],
                        [   128,    481],
                        [  -226,    162],
                        [  -585,   -151],
                        [  -947,   -455],
                        [ -1299,   -749],
                        [ -1642,  -1028],
                        [ -1964,  -1289],
                        [ -2266,  -1533],
                        [ -2546,  -1759],
                        [ -2802,  -1965],
                        [ -3057,  -2178],
                        [ -3308,  -2394],
                        [ -3590,  -2647],
                        [ -3902,  -2938],
                        [ -4249,  -3272],
                        [ -4630,  -3648],
                        [ -5020,  -4042],
                        [ -5419,  -4455],
                        [ -5757,  -4812],
                        [ -6035,  -5120],
                        [ -6243,  -5364],
                        [ -6383,  -5546],
                        [ -6446,  -5657],
                        [ -6434,  -5698],
                        [ -6347,  -5668],
                        [ -6186,  -5567],
                        [ -5953,  -5396],
                        [ -5649,  -5157],
                        [ -5281,  -4853],
                        [ -4851,  -4487],
                        [ -4367,  -4066],
                        [ -3831,  -3590],
                        [ -3253,  -3069],
                        [ -2637,  -2504],
                        [ -1992,  -1905],
                        [ -1321,  -1275],
                        [  -632,   -622],
                        [    70,     49],
                        [   779,    729],
                        [  1493,   1416],
                        [  2202,   2100],
                        [  2902,   2777],
                        [  3588,   3440],
                        [  4256,   4086],
                        [  4896,   4708],
                        [  5507,   5302],
                        [  6076,   5863],
                        [  6600,   6389],
                        [  7071,   6874],
                        [  7487,   7317],
                        [  7846,   7711],
                        [  8146,   8057],
                        [  8397,   8352],
                        [  8595,   8592],
                        [  8747,   8780],
                        [  8853,   8914],
                        [  8912,   8994],
                        [  8922,   9022],
                        [  8888,   8998],
                        [  8816,   8930],
                        [  8739,   8852],
                        [  8686,   8791],
                        [  8662,   8755],
                        [  8656,   8732],
                        [  8635,   8689],
                        [  8535,   8563],
                        [  8320,   8320],
                        [  8005,   7974],
                        [  7599,   7534],
                        [  7110,   7010],
                        [  6556,   6416],
                        [  5949,   5768],
                        [  5302,   5077],
                        [  4626,   4354],
                        [  3936,   3614],
                        [  3240,   2868],
                        [  2550,   2127],
                        [  1873,   1400],
                        [  1218,    695],
                        [   592,     22],
                        [     1,   -615],
                        [  -552,  -1211],
                        [ -1060,  -1759],
                        [ -1523,  -2259],
                        [ -1935,  -2708],
                        [ -2300,  -3107],
                        [ -2615,  -3460],
                        [ -2884,  -3766],
                        [ -3107,  -4031],
                        [ -3287,  -4258],
                        [ -3430,  -4452],
                        [ -3538,  -4617],
                        [ -3616,  -4752],
                        [ -3668,  -4861],
                        [ -3697,  -4943],
                        [ -3707,  -5001],
                        [ -3702,  -5035],
                        [ -3686,  -5049],
                        [ -3664,  -5041],
                        [ -3640,  -5015],
                        [ -3616,  -4968],
                        [ -3598,  -4903],
                        [ -3587,  -4830],
                        [ -3589,  -4748],
                        [ -3603,  -4671],
                        [ -3636,  -4600],
                        [ -3686,  -4548],
                        [ -3758,  -4517],
                        [ -3851,  -4506],
                        [ -3968,  -4519],
                        [ -4109,  -4558],
                        [ -4275,  -4625],
                        [ -4463,  -4717],
                        [ -4677,  -4838],
                        [ -4913,  -4987],
                        [ -5172,  -5163],
                        [ -5449,  -5363],
                        [ -5746,  -5588],
                        [ -6056,  -5835],
                        [ -6381,  -6104],
                        [ -6712,  -6389],
                        [ -7050,  -6691],
                        [ -7388,  -7005],
                        [ -7725,  -7330],
                        [ -8054,  -7660],
                        [ -8372,  -7997],
                        [ -8675,  -8333],
                        [ -8962,  -8668],
                        [ -9237,  -9000],
                        [ -9501,  -9329],
                        [ -9748,  -9646],
                        [ -9975,  -9951],
                        [-10177, -10231],
                        [-10353, -10488],
                        [-10464, -10681],
                        [-10514, -10811],
                        [-10489, -10864],
                        [-10389, -10838],
                        [-10203, -10722],
                        [ -9933, -10517],
                        [ -9631, -10272],
                        [ -9295,  -9987],
                        [ -8960,  -9696],
                        [ -8625,  -9396],
                        [ -8299,  -9098],
                        [ -7984,  -8802],
                        [ -7689,  -8518],
                        [ -7413,  -8245],
                        [ -7164,  -7992],
                        [ -6940,  -7756],
                        [ -6747,  -7544],
                        [ -6583,  -7356],
                        [ -6450,  -7192],
                        [ -6351,  -7057],
                        [ -6281,  -6948],
                        [ -6242,  -6867],
                        [ -6233,  -6813],
                        [ -6252,  -6787],
                        [ -6298,  -6785],
                        [ -6370,  -6810],
                        [ -6468,  -6858],
                        [ -6590,  -6931],
                        [ -6734,  -7023],
                        [ -6900,  -7135],
                        [ -7083,  -7265],
                        [ -7282,  -7410],
                        [ -7493,  -7567],
                        [ -7716,  -7735],
                        [ -7939,  -7909],
                        [ -8164,  -8089],
                        [ -8378,  -8271],
                        [ -8580,  -8453],
                        [ -8764,  -8631],
                        [ -8930,  -8803],
                        [ -9078,  -8966],
                        [ -9204,  -9116],
                        [ -9317,  -9250],
                        [ -9414,  -9367],
                        [ -9493,  -9464],
                        [ -9552,  -9540],
                        [ -9588,  -9592],
                        [ -9596,  -9616],
                        [ -9604,  -9639],
                        [ -9663,  -9713],
                        [ -9805,  -9867],
                        [-10032, -10107],
                        [-10333, -10419],
                        [-10673, -10771],
                        [-10971, -11083],
                        [-11156, -11283],
                        [-11219, -11362],
                        [-11165, -11327],
                        [-11000, -11182],
                        [-10732, -10936],
                        [-10372, -10598],
                        [ -9929, -10175],
                        [ -9414,  -9677],
                        [ -8838,  -9115],
                        [ -8209,  -8498],
                        [ -7538,  -7837],
                        [ -6833,  -7139],
                        [ -6105,  -6416],
                        [ -5362,  -5675],
                        [ -4611,  -4922],
                        [ -3860,  -4168],
                        [ -3117,  -3418],
                        [ -2390,  -2680],
                        [ -1683,  -1957],
                        [ -1003,  -1255],
                        [  -353,   -579],
                        [   264,     72],
                        [   844,    692],
                        [  1385,   1282],
                        [  1887,   1840],
                        [  2348,   2366],
                        [  2767,   2859],
                        [  3143,   3313],
                        [  3474,   3731],
                        [  3762,   4105],
                        [  4005,   4436],
                        [  4202,   4718],
                        [  4356,   4953],
                        [  4466,   5130],
                        [  4533,   5253],
                        [  4559,   5318],
                        [  4545,   5328],
                        [  4493,   5288],
                        [  4405,   5199],
                        [  4284,   5072],
                        [  4129,   4910],
                        [  3946,   4717],
                        [  3733,   4496],
                        [  3498,   4250],
                        [  3239,   3980],
                        [  2963,   3693],
                        [  2672,   3388],
                        [  2368,   3070],
                        [  2053,   2742],
                        [  1733,   2407],
                        [  1409,   2068],
                        [  1084,   1727],
                        [   761,   1386],
                        [   441,   1050],
                        [   128,    719],
                        [  -174,    398],
                        [  -464,     88],
                        [  -740,   -209],
                        [ -1000,   -490],
                        [ -1249,   -753],
                        [ -1484,   -997],
                        [ -1705,  -1220],
                        [ -1907,  -1417],
                        [ -2087,  -1588],
                        [ -2245,  -1734],
                        [ -2380,  -1854],
                        [ -2490,  -1948],
                        [ -2594,  -2035],
                        [ -2687,  -2110],
                        [ -2786,  -2194],
                        [ -2889,  -2282],
                        [ -3009,  -2390],
                        [ -3145,  -2517],
                        [ -3294,  -2660],
                        [ -3457,  -2821],
                        [ -3589,  -2955],
                        [ -3693,  -3065],
                        [ -3759,  -3142],
                        [ -3790,  -3187],
                        [ -3777,  -3192],
                        [ -3722,  -3159],
                        [ -3621,  -3083],
                        [ -3478,  -2967],
                        [ -3289,  -2809],
                        [ -3058,  -2611],
                        [ -2789,  -2375],
                        [ -2481,  -2103],
                        [ -2142,  -1798],
                        [ -1772,  -1463],
                        [ -1379,  -1102],
                        [  -964,   -719],
                        [  -536,   -320],
                        [   -94,     93],
                        [   351,    513],
                        [   799,    937],
                        [  1243,   1359],
                        [  1683,   1777],
                        [  2108,   2183],
                        [  2520,   2578],
                        [  2912,   2952],
                        [  3282,   3305],
                        [  3622,   3629],
                        [  3933,   3924],
                        [  4201,   4185],
                        [  4428,   4411],
                        [  4609,   4598],
                        [  4741,   4745],
                        [  4823,   4850],
                        [  4856,   4912],
                        [  4848,   4931],
                        [  4799,   4907],
                        [  4713,   4839],
                        [  4592,   4730],
                        [  4440,   4582],
                        [  4253,   4393],
                        [  4036,   4167],
                        [  3836,   3950],
                        [  3730,   3822],
                        [  3755,   3816],
                        [  3914,   3940],
                        [  4207,   4190],
                        [  4609,   4544],
                        [  5025,   4908],
                        [  5358,   5186],
                        [  5587,   5360],
                        [  5719,   5439],
                        [  5761,   5428],
                        [  5718,   5330],
                        [  5597,   5156],
                        [  5411,   4913],
                        [  5165,   4609],
                        [  4870,   4254],
                        [  4535,   3857],
                        [  4166,   3426],
                        [  3771,   2967],
                        [  3357,   2492],
                        [  2932,   2006],
                        [  2499,   1514],
                        [  2065,   1023],
                        [  1636,    539],
                        [  1216,     66],
                        [   808,   -394],
                        [   414,   -838],
                        [    34,  -1262],
                        [  -327,  -1666],
                        [  -675,  -2051],
                        [ -1007,  -2414],
                        [ -1326,  -2761],
                        [ -1632,  -3093],
                        [ -1928,  -3415],
                        [ -2215,  -3727],
                        [ -2494,  -4031],
                        [ -2769,  -4329],
                        [ -3038,  -4618],
                        [ -3305,  -4902],
                        [ -3571,  -5173],
                        [ -3837,  -5436],
                        [ -4104,  -5686],
                        [ -4375,  -5923],
                        [ -4648,  -6151],
                        [ -4929,  -6372],
                        [ -5213,  -6589],
                        [ -5505,  -6806],
                        [ -5801,  -7029],
                        [ -6104,  -7259],
                        [ -6411,  -7495],
                        [ -6723,  -7739],
                        [ -7037,  -7991],
                        [ -7356,  -8249],
                        [ -7675,  -8514],
                        [ -7996,  -8786],
                        [ -8316,  -9062],
                        [ -8635,  -9341],
                        [ -8949,  -9622],
                        [ -9258,  -9903],
                        [ -9557, -10180],
                        [ -9846, -10453],
                        [-10125, -10718],
                        [-10393, -10974],
                        [-10649, -11217],
                        [-10892, -11447],
                        [-11114, -11659],
                        [-11316, -11854],
                        [-11484, -12028],
                        [-11619, -12179],
                        [-11721, -12307],
                        [-11788, -12412],
                        [-11819, -12489],
                        [-11814, -12538],
                        [-11770, -12552],
                        [-11686, -12534],
                        [-11557, -12471],
                        [-11382, -12364],
                        [-11159, -12209],
                        [-10891, -12008],
                        [-10558, -11739],
                        [-10164, -11404],
                        [ -9728, -11023],
                        [ -9251, -10595],
                        [ -8759, -10144],
                        [ -8249,  -9670],
                        [ -7739,  -9187],
                        [ -7228,  -8694],
                        [ -6730,  -8205],
                        [ -6245,  -7723],
                        [ -5784,  -7256],
                        [ -5349,  -6806],
                        [ -4944,  -6379],
                        [ -4573,  -5978],
                        [ -4239,  -5610],
                        [ -3942,  -5272],
                        [ -3686,  -4969],
                        [ -3469,  -4703],
                        [ -3292,  -4472],
                        [ -3155,  -4279],
                        [ -3055,  -4121],
                        [ -2992,  -3998],
                        [ -2962,  -3909],
                        [ -2965,  -3853],
                        [ -2995,  -3826],
                        [ -3053,  -3829],
                        [ -3131,  -3856],
                        [ -3230,  -3907],
                        [ -3341,  -3973],
                        [ -3465,  -4054],
                        [ -3589,  -4143],
                        [ -3712,  -4237],
                        [ -3824,  -4331],
                        [ -3924,  -4422],
                        [ -4003,  -4504],
                        [ -4060,  -4575],
                        [ -4093,  -4631],
                        [ -4098,  -4669],
                        [ -4081,  -4685],
                        [ -4038,  -4675],
                        [ -3967,  -4637],
                        [ -3868,  -4572],
                        [ -3736,  -4472],
                        [ -3573,  -4340],
                        [ -3445,  -4239],
                        [ -3434,  -4253],
                        [ -3573,  -4413],
                        [ -3863,  -4721],
                        [ -4307,  -5179],
                        [ -4885,  -5768],
                        [ -5486,  -6377],
                        [ -5990,  -6888],
                        [ -6366,  -7271],
                        [ -6621,  -7534],
                        [ -6758,  -7679],
                        [ -6775,  -7706],
                        [ -6684,  -7619],
                        [ -6490,  -7425],
                        [ -6203,  -7131],
                        [ -5831,  -6745],
                        [ -5384,  -6276],
                        [ -4869,  -5734],
                        [ -4298,  -5128],
                        [ -3680,  -4468],
                        [ -3024,  -3765],
                        [ -2340,  -3027],
                        [ -1638,  -2264],
                        [  -927,  -1487],
                        [  -217,   -704],
                        [   486,     78],
                        [  1173,    847],
                        [  1839,   1600],
                        [  2477,   2324],
                        [  3084,   3015],
                        [  3656,   3668],
                        [  4190,   4281],
                        [  4682,   4853],
                        [  5130,   5384],
                        [  5534,   5874],
                        [  5891,   6322],
                        [  6199,   6726],
                        [  6463,   7086],
                        [  6676,   7395],
                        [  6842,   7655],
                        [  6962,   7859],
                        [  7036,   8010],
                        [  7069,   8106],
                        [  7059,   8149],
                        [  7011,   8140],
                        [  6928,   8085],
                        [  6812,   7991],
                        [  6666,   7860],
                        [  6493,   7698],
                        [  6294,   7510],
                        [  6075,   7298],
                        [  5839,   7066],
                        [  5588,   6819],
                        [  5330,   6560],
                        [  5067,   6294],
                        [  4801,   6025],
                        [  4539,   5755],
                        [  4281,   5488],
                        [  4032,   5228],
                        [  3794,   4977],
                        [  3572,   4737],
                        [  3369,   4512],
                        [  3192,   4302],
                        [  3046,   4112],
                        [  2930,   3941],
                        [  2846,   3791],
                        [  2785,   3665],
                        [  2750,   3562],
                        [  2727,   3482],
                        [  2721,   3429],
                        [  2730,   3401],
                        [  2754,   3397],
                        [  2793,   3416],
                        [  2845,   3457],
                        [  2910,   3520],
                        [  2989,   3603],
                        [  3088,   3711],
                        [  3205,   3842],
                        [  3323,   3978],
                        [  3444,   4120],
                        [  3543,   4242],
                        [  3619,   4343],
                        [  3685,   4435],
                        [  3738,   4513],
                        [  3785,   4586],
                        [  3825,   4650],
                        [  3870,   4716],
                        [  3914,   4779],
                        [  3964,   4847],
                        [  4018,   4916],
                        [  4081,   4990],
                        [  4151,   5068],
                        [  4230,   5154],
                        [  4315,   5243],
                        [  4409,   5337],
                        [  4509,   5434],
                        [  4613,   5534],
                        [  4721,   5635],
                        [  4832,   5734],
                        [  4942,   5831],
                        [  5049,   5923],
                        [  5152,   6009],
                        [  5247,   6087],
                        [  5333,   6156],
                        [  5408,   6215],
                        [  5470,   6261],
                        [  5516,   6293],
                        [  5547,   6308],
                        [  5558,   6303],
                        [  5549,   6279],
                        [  5515,   6230],
                        [  5456,   6158],
                        [  5371,   6061],
                        [  5259,   5940],
                        [  5116,   5794],
                        [  4946,   5624],
                        [  4754,   5432],
                        [  4539,   5216],
                        [  4307,   4977],
                        [  4058,   4720],
                        [  3798,   4446],
                        [  3522,   4150],
                        [  3242,   3846],
                        [  3040,   3613],
                        [  3007,   3543],
                        [  3170,   3663],
                        [  3534,   3978],
                        [  4112,   4502],
                        [  4889,   5221],
                        [  5747,   6018],
                        [  6547,   6759],
                        [  7261,   7415],
                        [  7893,   7991],
                        [  8437,   8484],
                        [  8891,   8890],
                        [  9257,   9211],
                        [  9539,   9445],
                        [  9740,   9596],
                        [  9865,   9670],
                        [  9917,   9668],
                        [  9898,   9596],
                        [  9815,   9458],
                        [  9673,   9262],
                        [  9476,   9011],
                        [  9229,   8709],
                        [  8938,   8365],
                        [  8608,   7983],
                        [  8245,   7568],
                        [  7853,   7124],
                        [  7434,   6658],
                        [  6995,   6177],
                        [  6537,   5684],
                        [  6060,   5186],
                        [  5570,   4687],
                        [  5066,   4183],
                        [  4550,   3678],
                        [  4026,   3164],
                        [  3493,   2643],
                        [  2954,   2111],
                        [  2411,   1571],
                        [  1863,   1024],
                        [  1314,    472],
                        [   765,    -79],
                        [   217,   -627],
                        [  -327,  -1168],
                        [  -868,  -1702],
                        [ -1401,  -2224],
                        [ -1928,  -2735],
                        [ -2446,  -3234],
                        [ -2953,  -3719],
                        [ -3446,  -4192],
                        [ -3924,  -4653],
                        [ -4384,  -5099],
                        [ -4825,  -5530],
                        [ -5242,  -5943],
                        [ -5636,  -6340],
                        [ -6008,  -6716],
                        [ -6353,  -7072],
                        [ -6672,  -7406],
                        [ -6966,  -7717],
                        [ -7229,  -8002],
                        [ -7463,  -8262],
                        [ -7667,  -8493],
                        [ -7838,  -8695],
                        [ -7986,  -8864],
                        [ -8109,  -9003],
                        [ -8213,  -9109],
                        [ -8296,  -9180],
                        [ -8355,  -9217],
                        [ -8390,  -9219],
                        [ -8385,  -9186],
                        [ -8341,  -9118],
                        [ -8253,  -9016],
                        [ -8120,  -8881],
                        [ -7945,  -8712],
                        [ -7729,  -8509],
                        [ -7477,  -8279],
                        [ -7193,  -8022],
                        [ -6897,  -7758],
                        [ -6590,  -7486],
                        [ -6281,  -7214],
                        [ -5969,  -6942],
                        [ -5628,  -6640],
                        [ -5262,  -6312],
                        [ -4852,  -5939],
                        [ -4402,  -5523],
                        [ -3924,  -5074],
                        [ -3419,  -4596],
                        [ -2902,  -4099],
                        [ -2374,  -3587],
                        [ -1848,  -3070],
                        [ -1324,  -2551],
                        [  -817,  -2041],
                        [  -324,  -1540],
                        [   145,  -1057],
                        [   589,   -594],
                        [  1003,   -157],
                        [  1385,    254],
                        [  1731,    633],
                        [  2044,    982],
                        [  2320,   1298],
                        [  2559,   1581],
                        [  2765,   1832],
                        [  2939,   2052],
                        [  3083,   2241],
                        [  3201,   2401],
                        [  3296,   2533],
                        [  3370,   2641],
                        [  3429,   2726],
                        [  3473,   2791],
                        [  3511,   2844],
                        [  3542,   2886],
                        [  3574,   2924],
                        [  3611,   2962],
                        [  3657,   3006],
                        [  3715,   3057],
                        [  3792,   3119],
                        [  3890,   3196],
                        [  4015,   3292],
                        [  4167,   3406],
                        [  4344,   3544],
                        [  4549,   3708],
                        [  4782,   3898],
                        [  5038,   4111],
                        [  5329,   4362],
                        [  5636,   4631],
                        [  5867,   4830],
                        [  5940,   4875],
                        [  5834,   4747],
                        [  5541,   4440],
                        [  5042,   3933],
                        [  4344,   3234],
                        [  3572,   2464],
                        [  2862,   1760],
                        [  2246,   1151],
                        [  1717,    631],
                        [  1280,    206],
                        [   942,   -119],
                        [   696,   -345],
                        [   543,   -474],
                        [   474,   -506],
                        [   484,   -449],
                        [   571,   -307],
                        [   729,    -86],
                        [   947,    206],
                        [  1220,    561],
                        [  1541,    970],
                        [  1900,   1428],
                        [  2290,   1921],
                        [  2702,   2442],
                        [  3127,   2984],
                        [  3557,   3536],
                        [  3987,   4088],
                        [  4409,   4633],
                        [  4820,   5155],
                        [  5212,   5652],
                        [  5584,   6114],
                        [  5930,   6537],
                        [  6249,   6927],
                        [  6537,   7278],
                        [  6793,   7599],
                        [  7014,   7889],
                        [  7203,   8148],
                        [  7357,   8376],
                        [  7477,   8570],
                        [  7562,   8730],
                        [  7615,   8855],
                        [  7636,   8945],
                        [  7628,   9001],
                        [  7592,   9025],
                        [  7533,   9016],
                        [  7451,   8977],
                        [  7350,   8912],
                        [  7232,   8825],
                        [  7099,   8718],
                        [  6953,   8594],
                        [  6797,   8457],
                        [  6634,   8311],
                        [  6468,   8160],
                        [  6301,   8006],
                        [  6138,   7853],
                        [  5982,   7704],
                        [  5836,   7563],
                        [  5702,   7430],
                        [  5581,   7309],
                        [  5476,   7201],
                        [  5392,   7108],
                        [  5329,   7031],
                        [  5303,   6970],
                        [  5311,   6927],
                        [  5355,   6901],
                        [  5436,   6892],
                        [  5542,   6901],
                        [  5674,   6928],
                        [  5809,   6970],
                        [  5949,   7028],
                        [  6090,   7100],
                        [  6231,   7183],
                        [  6371,   7278],
                        [  6508,   7382],
                        [  6663,   7516],
                        [  6835,   7677],
                        [  7044,   7886],
                        [  7286,   8138],
                        [  7546,   8415],
                        [  7823,   8718],
                        [  8065,   8993],
                        [  8275,   9240],
                        [  8433,   9440],
                        [  8539,   9592],
                        [  8601,   9702],
                        [  8617,   9767],
                        [  8595,   9795],
                        [  8533,   9781],
                        [  8440,   9735],
                        [  8314,   9653],
                        [  8165,   9544],
                        [  7989,   9406],
                        [  7794,   9245],
                        [  7578,   9060],
                        [  7350,   8857],
                        [  7107,   8634],
                        [  6857,   8396],
                        [  6598,   8143],
                        [  6331,   7876],
                        [  6060,   7599],
                        [  5784,   7312],
                        [  5502,   7015],
                        [  5215,   6713],
                        [  4925,   6405],
                        [  4630,   6093],
                        [  4333,   5779],
                        [  4033,   5462],
                        [  3732,   5145],
                        [  3430,   4824],
                        [  3127,   4500],
                        [  2824,   4172],
                        [  2524,   3842],
                        [  2224,   3509],
                        [  1925,   3175],
                        [  1622,   2839],
                        [  1318,   2505],
                        [  1014,   2173],
                        [   711,   1845],
                        [   410,   1519],
                        [   115,   1200],
                        [  -171,    888],
                        [  -457,    577],
                        [  -716,    287],
                        [  -856,    113],
                        [  -806,    126],
                        [  -551,    341],
                        [   -85,    763],
                        [   621,   1422],
                        [  1561,   2314],
                        [  2614,   3317],
                        [  3639,   4297],
                        [  4611,   5225],
                        [  5528,   6105],
                        [  6378,   6923],
                        [  7150,   7665],
                        [  7839,   8330],
                        [  8446,   8908],
                        [  8965,   9398],
                        [  9395,   9796],
                        [  9735,  10103],
                        [  9985,  10317],
                        [ 10146,  10442],
                        [ 10219,  10478],
                        [ 10208,  10428],
                        [ 10117,  10295],
                        [  9950,  10086],
                        [  9711,   9804],
                        [  9407,   9456],
                        [  9042,   9048],
                        [  8621,   8585],
                        [  8151,   8080],
                        [  7634,   7538],
                        [  7077,   6972],
                        [  6485,   6386],
                        [  5861,   5784],
                        [  5212,   5170],
                        [  4542,   4535],
                        [  3855,   3888],
                        [  3157,   3220],
                        [  2451,   2537],
                        [  1742,   1844],
                        [  1034,   1142],
                        [   332,    439],
                        [  -362,   -262],
                        [ -1043,   -957],
                        [ -1709,  -1645],
                        [ -2353,  -2316],
                        [ -2977,  -2971],
                        [ -3575,  -3602],
                        [ -4145,  -4206],
                        [ -4682,  -4779],
                        [ -5186,  -5322],
                        [ -5652,  -5830],
                        [ -6077,  -6301],
                        [ -6459,  -6734],
                        [ -6799,  -7129],
                        [ -7096,  -7485],
                        [ -7352,  -7798],
                        [ -7564,  -8071],
                        [ -7733,  -8304],
                        [ -7861,  -8494],
                        [ -7947,  -8642],
                        [ -7993,  -8748],
                        [ -7999,  -8812],
                        [ -7978,  -8835],
                        [ -7932,  -8818],
                        [ -7868,  -8760],
                        [ -7789,  -8664],
                        [ -7694,  -8530],
                        [ -7584,  -8361],
                        [ -7443,  -8159],
                        [ -7274,  -7925],
                        [ -7065,  -7659],
                        [ -6820,  -7366],
                        [ -6544,  -7048],
                        [ -6235,  -6705],
                        [ -5914,  -6356],
                        [ -5580,  -6003],
                        [ -5280,  -5688],
                        [ -5012,  -5412],
                        [ -4787,  -5184],
                        [ -4606,  -5004],
                        [ -4434,  -4838],
                        [ -4276,  -4688],
                        [ -4077,  -4501],
                        [ -3842,  -4279],
                        [ -3573,  -4026],
                        [ -3272,  -3740],
                        [ -2947,  -3430],
                        [ -2598,  -3096],
                        [ -2238,  -2749],
                        [ -1865,  -2387],
                        [ -1488,  -2020],
                        [ -1107,  -1648],
                        [  -732,  -1278],
                        [  -361,   -911],
                        [    -1,   -553],
                        [   349,   -203],
                        [   683,    134],
                        [  1003,    458],
                        [  1303,    768],
                        [  1588,   1064],
                        [  1857,   1344],
                        [  2110,   1611],
                        [  2353,   1864],
                        [  2585,   2104],
                        [  2811,   2331],
                        [  3031,   2546],
                        [  3247,   2752],
                        [  3461,   2950],
                        [  3677,   3144],
                        [  3895,   3336],
                        [  4116,   3532],
                        [  4341,   3732],
                        [  4572,   3941],
                        [  4809,   4159],
                        [  5060,   4389],
                        [  5325,   4633],
                        [  5610,   4890],
                        [  5913,   5160],
                        [  6236,   5445],
                        [  6577,   5744],
                        [  6932,   6056],
                        [  7299,   6380],
                        [  7684,   6725],
                        [  8058,   7063],
                        [  8331,   7306],
                        [  8448,   7397],
                        [  8396,   7328],
                        [  8166,   7087],
                        [  7720,   6639],
                        [  7050,   5975],
                        [  6270,   5205],
                        [  5499,   4450],
                        [  4758,   3728],
                        [  4045,   3036],
                        [  3374,   2388],
                        [  2751,   1793],
                        [  2180,   1257],
                        [  1662,    780],
                        [  1197,    368],
                        [   787,     21],
                        [   433,   -262],
                        [   134,   -483],
                        [  -114,   -644],
                        [  -313,   -748],
                        [  -466,   -800],
                        [  -578,   -803],
                        [  -653,   -765],
                        [  -697,   -691],
                        [  -713,   -586],
                        [  -709,   -457],
                        [  -687,   -313],
                        [  -652,   -161],
                        [  -607,    -15],
                        [  -558,    123],
                        [  -506,    242],
                        [  -455,    341],
                        [  -405,    424],
                        [  -362,    488],
                        [  -323,    544],
                        [  -293,    592],
                        [  -270,    637],
                        [  -255,    676],
                        [  -249,    709],
                        [  -249,    738],
                        [  -258,    764],
                        [  -273,    787],
                        [  -293,    809],
                        [  -316,    831],
                        [  -342,    849],
                        [  -368,    865],
                        [  -395,    878],
                        [  -420,    887],
                        [  -444,    895],
                        [  -466,    900],
                        [  -486,    908],
                        [  -502,    917],
                        [  -512,    932],
                        [  -515,    951],
                        [  -509,    979],
                        [  -493,   1015],
                        [  -466,   1060],
                        [  -426,   1115],
                        [  -375,   1181],
                        [  -311,   1256],
                        [  -231,   1342],
                        [  -133,   1437],
                        [    -7,   1541],
                        [   147,   1654],
                        [   328,   1773],
                        [   538,   1897],
                        [   763,   2026],
                        [  1004,   2157],
                        [  1237,   2290],
                        [  1461,   2419],
                        [  1669,   2545],
                        [  1861,   2667],
                        [  2038,   2784],
                        [  2195,   2895],
                        [  2377,   3041],
                        [  2576,   3218],
                        [  2821,   3451],
                        [  3109,   3738],
                        [  3427,   4064],
                        [  3773,   4429],
                        [  4078,   4760],
                        [  4342,   5059],
                        [  4533,   5290],
                        [  4649,   5453],
                        [  4696,   5550],
                        [  4674,   5579],
                        [  4588,   5548],
                        [  4437,   5451],
                        [  4232,   5299],
                        [  3972,   5090],
                        [  3664,   4832],
                        [  3311,   4525],
                        [  2922,   4178],
                        [  2496,   3790],
                        [  2046,   3371],
                        [  1571,   2920],
                        [  1081,   2447],
                        [   577,   1951],
                        [    66,   1441],
                        [  -452,    916],
                        [  -971,    384],
                        [ -1492,   -153],
                        [ -2010,   -690],
                        [ -2525,  -1224],
                        [ -3032,  -1751],
                        [ -3530,  -2267],
                        [ -4015,  -2771],
                        [ -4483,  -3258],
                        [ -4934,  -3729],
                        [ -5362,  -4183],
                        [ -5764,  -4618],
                        [ -6137,  -5034],
                        [ -6483,  -5429],
                        [ -6802,  -5803],
                        [ -7102,  -6154],
                        [ -7378,  -6479],
                        [ -7636,  -6777],
                        [ -7875,  -7049],
                        [ -8094,  -7296],
                        [ -8289,  -7514],
                        [ -8461,  -7704],
                        [ -8617,  -7876],
                        [ -8729,  -8001],
                        [ -8722,  -8008],
                        [ -8564,  -7863],
                        [ -8251,  -7563],
                        [ -7774,  -7099],
                        [ -7094,  -6433],
                        [ -6203,  -5554],
                        [ -5194,  -4558],
                        [ -4180,  -3551],
                        [ -3174,  -2551],
                        [ -2186,  -1563],
                        [ -1233,   -606],
                        [  -331,    302],
                        [   514,   1155],
                        [  1293,   1941],
                        [  1998,   2650],
                        [  2623,   3274],
                        [  3162,   3811],
                        [  3612,   4254],
                        [  3972,   4603],
                        [  4238,   4856],
                        [  4413,   5012],
                        [  4497,   5076],
                        [  4494,   5047],
                        [  4407,   4932],
                        [  4241,   4734],
                        [  4000,   4459],
                        [  3690,   4115],
                        [  3317,   3714],
                        [  2887,   3262],
                        [  2407,   2776],
                        [  1881,   2260],
                        [  1319,   1720],
                        [   725,   1163],
                        [   107,    584],
                        [  -530,     -9],
                        [ -1179,   -625],
                        [ -1834,  -1255],
                        [ -2490,  -1897],
                        [ -3140,  -2546],
                        [ -3780,  -3195],
                        [ -4405,  -3842],
                        [ -5012,  -4487],
                        [ -5593,  -5122],
                        [ -6147,  -5741],
                        [ -6671,  -6342],
                        [ -7161,  -6914],
                        [ -7613,  -7453],
                        [ -8024,  -7953],
                        [ -8392,  -8411],
                        [ -8714,  -8824],
                        [ -8989,  -9191],
                        [ -9215,  -9510],
                        [ -9392,  -9783],
                        [ -9521, -10007],
                        [ -9604, -10183],
                        [ -9642, -10313],
                        [ -9637, -10395],
                        [ -9589, -10432],
                        [ -9501, -10424],
                        [ -9377, -10375],
                        [ -9218, -10284],
                        [ -9038, -10155],
                        [ -8841,  -9989],
                        [ -8634,  -9788],
                        [ -8422,  -9557],
                        [ -8205,  -9295],
                        [ -7989,  -9008],
                        [ -7758,  -8699],
                        [ -7516,  -8369],
                        [ -7252,  -8020],
                        [ -6970,  -7655],
                        [ -6672,  -7280],
                        [ -6362,  -6897],
                        [ -6064,  -6533],
                        [ -5778,  -6187],
                        [ -5560,  -5916],
                        [ -5407,  -5717],
                        [ -5328,  -5600],
                        [ -5325,  -5566],
                        [ -5360,  -5577],
                        [ -5435,  -5636],
                        [ -5474,  -5667],
                        [ -5482,  -5675],
                        [ -5454,  -5652],
                        [ -5389,  -5600],
                        [ -5291,  -5518],
                        [ -5157,  -5406],
                        [ -4993,  -5267],
                        [ -4798,  -5101],
                        [ -4577,  -4913],
                        [ -4330,  -4701],
                        [ -4063,  -4471],
                        [ -3773,  -4222],
                        [ -3468,  -3958],
                        [ -3146,  -3677],
                        [ -2815,  -3387],
                        [ -2471,  -3081],
                        [ -2120,  -2767],
                        [ -1760,  -2442],
                        [ -1394,  -2110],
                        [ -1020,  -1769],
                        [  -636,  -1422],
                        [  -244,  -1068],
                        [   157,   -709],
                        [   566,   -344],
                        [   985,     25],
                        [  1411,    397],
                        [  1841,    774],
                        [  2276,   1154],
                        [  2709,   1540],
                        [  3140,   1932],
                        [  3566,   2329],
                        [  3986,   2732],
                        [  4406,   3140],
                        [  4824,   3549],
                        [  5246,   3959],
                        [  5669,   4366],
                        [  6093,   4769],
                        [  6515,   5168],
                        [  6929,   5556],
                        [  7333,   5934],
                        [  7728,   6307],
                        [  8084,   6644],
                        [  8348,   6893],
                        [  8498,   7035],
                        [  8534,   7068],
                        [  8437,   6976],
                        [  8163,   6714],
                        [  7688,   6257],
                        [  7081,   5672],
                        [  6420,   5039],
                        [  5716,   4366],
                        [  4973,   3658],
                        [  4209,   2932],
                        [  3436,   2198],
                        [  2659,   1467],
                        [  1886,    745],
                        [  1124,     41],
                        [   380,   -637],
                        [  -340,  -1286],
                        [ -1030,  -1900],
                        [ -1689,  -2478],
                        [ -2313,  -3016],
                        [ -2899,  -3512],
                        [ -3447,  -3968],
                        [ -3955,  -4383],
                        [ -4427,  -4759],
                        [ -4858,  -5096],
                        [ -5254,  -5397],
                        [ -5613,  -5668],
                        [ -5939,  -5911],
                        [ -6230,  -6137],
                        [ -6492,  -6349],
                        [ -6723,  -6551],
                        [ -6927,  -6748],
                        [ -7102,  -6933],
                        [ -7252,  -7112],
                        [ -7377,  -7268],
                        [ -7479,  -7406],
                        [ -7559,  -7516],
                        [ -7616,  -7603],
                        [ -7651,  -7664],
                        [ -7666,  -7698],
                        [ -7660,  -7703],
                        [ -7634,  -7675],
                        [ -7588,  -7616],
                        [ -7522,  -7527],
                        [ -7438,  -7412],
                        [ -7334,  -7272],
                        [ -7215,  -7115],
                        [ -7078,  -6940],
                        [ -6928,  -6756],
                        [ -6766,  -6558],
                        [ -6592,  -6349],
                        [ -6407,  -6130],
                        [ -6215,  -5901],
                        [ -6013,  -5665],
                        [ -5804,  -5421],
                        [ -5588,  -5170],
                        [ -5365,  -4914],
                        [ -5137,  -4654],
                        [ -4907,  -4392],
                        [ -4674,  -4129],
                        [ -4436,  -3868],
                        [ -4194,  -3608],
                        [ -3941,  -3354],
                        [ -3678,  -3106],
                        [ -3404,  -2866],
                        [ -3121,  -2637],
                        [ -2835,  -2418],
                        [ -2547,  -2213],
                        [ -2280,  -2026],
                        [ -2033,  -1858],
                        [ -1812,  -1710],
                        [ -1617,  -1580],
                        [ -1444,  -1465],
                        [ -1298,  -1368],
                        [ -1125,  -1236],
                        [  -930,  -1074],
                        [  -691,   -858],
                        [  -406,   -588],
                        [   -84,   -271],
                        [   279,     93],
                        [   602,    427],
                        [   891,    734],
                        [  1107,    973],
                        [  1250,   1145],
                        [  1321,   1251],
                        [  1323,   1290],
                        [  1257,   1263],
                        [  1124,   1172],
                        [   930,   1020],
                        [   678,    808],
                        [   374,    545],
                        [    20,    230],
                        [  -374,   -128],
                        [  -806,   -527],
                        [ -1266,   -960],
                        [ -1752,  -1424],
                        [ -2252,  -1909],
                        [ -2767,  -2416],
                        [ -3288,  -2935],
                        [ -3812,  -3464],
                        [ -4336,  -3995],
                        [ -4856,  -4527],
                        [ -5369,  -5052],
                        [ -5873,  -5569],
                        [ -6363,  -6070],
                        [ -6836,  -6554],
                        [ -7289,  -7018],
                        [ -7719,  -7456],
                        [ -8119,  -7871],
                        [ -8486,  -8258],
                        [ -8815,  -8618],
                        [ -9105,  -8951],
                        [ -9360,  -9254],
                        [ -9578,  -9527],
                        [ -9770,  -9770],
                        [ -9931,  -9979],
                        [-10073, -10156],
                        [-10192, -10301],
                        [-10290, -10414],
                        [-10362, -10493],
                        [-10414, -10544],
                        [-10446, -10568],
                        [-10441, -10551],
                        [-10375, -10467],
                        [-10247, -10320],
                        [-10064, -10116],
                        [ -9812,  -9839],
                        [ -9447,  -9447],
                        [ -8938,  -8911],
                        [ -8325,  -8268],
                        [ -7668,  -7579],
                        [ -6976,  -6853],
                        [ -6260,  -6101],
                        [ -5536,  -5341],
                        [ -4821,  -4587],
                        [ -4125,  -3852],
                        [ -3454,  -3145],
                        [ -2821,  -2479],
                        [ -2234,  -1864],
                        [ -1701,  -1306],
                        [ -1224,   -810],
                        [  -813,   -383],
                        [  -467,    -27],
                        [  -190,    256],
                        [    19,    465],
                        [   158,    601],
                        [   232,    666],
                        [   240,    662],
                        [   189,    596],
                        [    82,    469],
                        [   -76,    296],
                        [  -280,     80],
                        [  -524,   -163],
                        [  -803,   -431],
                        [ -1110,   -717],
                        [ -1440,  -1013],
                        [ -1787,  -1321],
                        [ -2144,  -1636],
                        [ -2506,  -1962],
                        [ -2869,  -2298],
                        [ -3226,  -2637],
                        [ -3573,  -2975],
                        [ -3907,  -3314],
                        [ -4223,  -3650],
                        [ -4518,  -3983],
                        [ -4789,  -4310],
                        [ -5032,  -4626],
                        [ -5246,  -4929],
                        [ -5428,  -5207],
                        [ -5578,  -5458],
                        [ -5692,  -5675],
                        [ -5768,  -5854],
                        [ -5808,  -5995],
                        [ -5809,  -6096],
                        [ -5774,  -6159],
                        [ -5701,  -6182],
                        [ -5593,  -6168],
                        [ -5453,  -6117],
                        [ -5280,  -6029],
                        [ -5080,  -5907],
                        [ -4854,  -5754],
                        [ -4604,  -5571],
                        [ -4336,  -5362],
                        [ -4050,  -5127],
                        [ -3758,  -4870],
                        [ -3463,  -4595],
                        [ -3172,  -4303],
                        [ -2888,  -3998],
                        [ -2617,  -3682],
                        [ -2360,  -3359],
                        [ -2113,  -3032],
                        [ -1872,  -2701],
                        [ -1632,  -2368],
                        [ -1395,  -2037],
                        [ -1163,  -1712],
                        [  -936,  -1395],
                        [  -744,  -1116],
                        [  -585,   -875],
                        [  -506,   -721],
                        [  -503,   -649],
                        [  -584,   -670],
                        [  -750,   -783],
                        [  -965,   -956],
                        [ -1233,  -1190],
                        [ -1471,  -1407],
                        [ -1688,  -1610],
                        [ -1869,  -1788],
                        [ -2015,  -1940],
                        [ -2120,  -2060],
                        [ -2182,  -2144],
                        [ -2199,  -2193],
                        [ -2172,  -2204],
                        [ -2101,  -2177],
                        [ -1983,  -2109],
                        [ -1822,  -2004],
                        [ -1619,  -1861],
                        [ -1376,  -1681],
                        [ -1092,  -1463],
                        [  -774,  -1211],
                        [  -423,   -924],
                        [   -41,   -606],
                        [   370,   -257],
                        [   807,    119],
                        [  1269,    522],
                        [  1754,    947],
                        [  2262,   1395],
                        [  2788,   1858],
                        [  3330,   2338],
                        [  3883,   2828],
                        [  4447,   3330],
                        [  5010,   3836],
                        [  5572,   4345],
                        [  6121,   4856],
                        [  6654,   5364],
                        [  7167,   5868],
                        [  7658,   6364],
                        [  8129,   6848],
                        [  8578,   7318],
                        [  9008,   7767],
                        [  9419,   8193],
                        [  9805,   8592],
                        [ 10166,   8962],
                        [ 10493,   9297],
                        [ 10788,   9596],
                        [ 11044,   9858],
                        [ 11253,  10073],
                        [ 11415,  10244],
                        [ 11541,  10382],
                        [ 11633,  10489],
                        [ 11676,  10550],
                        [ 11622,  10518],
                        [ 11424,  10345],
                        [ 11085,  10034],
                        [ 10638,   9618],
                        [ 10090,   9103],
                        [  9450,   8499],
                        [  8734,   7820],
                        [  7957,   7079],
                        [  7126,   6286],
                        [  6253,   5454],
                        [  5352,   4594],
                        [  4431,   3718],
                        [  3503,   2836],
                        [  2576,   1955],
                        [  1658,   1084],
                        [   757,    232],
                        [  -118,   -596],
                        [  -964,  -1396],
                        [ -1772,  -2160],
                        [ -2540,  -2885],
                        [ -3263,  -3569],
                        [ -3940,  -4210],
                        [ -4569,  -4808],
                        [ -5148,  -5362],
                        [ -5676,  -5877],
                        [ -6154,  -6355],
                        [ -6579,  -6796],
                        [ -6953,  -7202],
                        [ -7276,  -7573],
                        [ -7549,  -7910],
                        [ -7774,  -8202],
                        [ -7951,  -8452],
                        [ -8082,  -8652],
                        [ -8169,  -8806],
                        [ -8212,  -8910],
                        [ -8214,  -8968],
                        [ -8175,  -8969],
                        [ -8097,  -8919],
                        [ -7985,  -8816],
                        [ -7839,  -8661],
                        [ -7661,  -8463],
                        [ -7456,  -8223],
                        [ -7225,  -7955],
                        [ -6970,  -7659],
                        [ -6699,  -7345],
                        [ -6411,  -7013],
                        [ -6111,  -6666],
                        [ -5800,  -6309],
                        [ -5484,  -5944],
                        [ -5163,  -5574],
                        [ -4842,  -5202],
                        [ -4521,  -4832],
                        [ -4204,  -4466],
                        [ -3893,  -4106],
                        [ -3590,  -3754],
                        [ -3296,  -3413],
                        [ -3012,  -3087],
                        [ -2739,  -2776],
                        [ -2473,  -2481],
                        [ -2218,  -2207],
                        [ -1971,  -1954],
                        [ -1732,  -1723],
                        [ -1504,  -1516],
                        [ -1285,  -1333],
                        [ -1089,  -1177],
                        [  -917,  -1050],
                        [  -770,   -949],
                        [  -648,   -874],
                        [  -545,   -817],
                        [  -462,   -778],
                        [  -353,   -712],
                        [  -223,   -619],
                        [   -51,   -483],
                        [   159,   -302],
                        [   415,    -72],
                        [   717,    207],
                        [   997,    471],
                        [  1263,    726],
                        [  1479,    936],
                        [  1646,   1102],
                        [  1763,   1221],
                        [  1831,   1295],
                        [  1846,   1320],
                        [  1812,   1298],
                        [  1730,   1230],
                        [  1601,   1118],
                        [  1432,    966],
                        [  1221,    775],
                        [   977,    550],
                        [   702,    293],
                        [   402,     11],
                        [    80,   -297],
                        [  -254,   -620],
                        [  -603,   -959],
                        [  -956,  -1306],
                        [ -1313,  -1659],
                        [ -1670,  -2013],
                        [ -2024,  -2364],
                        [ -2373,  -2710],
                        [ -2714,  -3045],
                        [ -3042,  -3366],
                        [ -3357,  -3673],
                        [ -3654,  -3959],
                        [ -3930,  -4226],
                        [ -4175,  -4468],
                        [ -4391,  -4687],
                        [ -4570,  -4879],
                        [ -4713,  -5045],
                        [ -4823,  -5185],
                        [ -4900,  -5298],
                        [ -4955,  -5382],
                        [ -4985,  -5438],
                        [ -4998,  -5466],
                        [ -4994,  -5465],
                        [ -4973,  -5436],
                        [ -4934,  -5380],
                        [ -4880,  -5300],
                        [ -4810,  -5195],
                        [ -4734,  -5078],
                        [ -4684,  -4981],
                        [ -4685,  -4930],
                        [ -4742,  -4931],
                        [ -4841,  -4972],
                        [ -4943,  -5013],
                        [ -4985,  -4993],
                        [ -4936,  -4881],
                        [ -4807,  -4691],
                        [ -4607,  -4431],
                        [ -4344,  -4108],
                        [ -4032,  -3737],
                        [ -3681,  -3327],
                        [ -3301,  -2890],
                        [ -2899,  -2434],
                        [ -2487,  -1970],
                        [ -2072,  -1508],
                        [ -1662,  -1054],
                        [ -1262,   -616],
                        [  -880,   -201],
                        [  -520,    188],
                        [  -186,    546],
                        [   119,    870],
                        [   391,   1159],
                        [   632,   1412],
                        [   840,   1629],
                        [  1018,   1811],
                        [  1166,   1960],
                        [  1289,   2082],
                        [  1386,   2180],
                        [  1463,   2260],
                        [  1521,   2327],
                        [  1563,   2386],
                        [  1595,   2439],
                        [  1619,   2490],
                        [  1639,   2543],
                        [  1657,   2591],
                        [  1678,   2638],
                        [  1703,   2685],
                        [  1736,   2735],
                        [  1778,   2781],
                        [  1831,   2828],
                        [  1896,   2871],
                        [  1974,   2910],
                        [  2068,   2949],
                        [  2177,   2988],
                        [  2302,   3036],
                        [  2444,   3096],
                        [  2602,   3170],
                        [  2776,   3264],
                        [  2966,   3375],
                        [  3171,   3506],
                        [  3390,   3654],
                        [  3621,   3819],
                        [  3863,   4000],
                        [  4115,   4195],
                        [  4375,   4403],
                        [  4639,   4622],
                        [  4906,   4849],
                        [  5175,   5084],
                        [  5441,   5323],
                        [  5704,   5565],
                        [  5957,   5805],
                        [  6200,   6044],
                        [  6429,   6278],
                        [  6641,   6505],
                        [  6832,   6724],
                        [  7000,   6933],
                        [  7144,   7130],
                        [  7268,   7316],
                        [  7375,   7490],
                        [  7461,   7650],
                        [  7529,   7792],
                        [  7580,   7918],
                        [  7590,   8001],
                        [  7561,   8043],
                        [  7469,   8018],
                        [  7317,   7927],
                        [  7096,   7760],
                        [  6807,   7519],
                        [  6472,   7222],
                        [  6090,   6870],
                        [  5725,   6525],
                        [  5374,   6184],
                        [  5051,   5862],
                        [  4757,   5559],
                        [  4506,   5289],
                        [  4296,   5051],
                        [  4134,   4854],
                        [  4022,   4698],
                        [  3963,   4587],
                        [  3958,   4523],
                        [  4006,   4508],
                        [  4109,   4541],
                        [  4262,   4623],
                        [  4468,   4754],
                        [  4720,   4930],
                        [  5017,   5153],
                        [  5355,   5416],
                        [  5732,   5721],
                        [  6143,   6060],
                        [  6585,   6434],
                        [  7052,   6836],
                        [  7543,   7264],
                        [  8051,   7710],
                        [  8574,   8173],
                        [  9102,   8647],
                        [  9634,   9128],
                        [ 10154,   9608],
                        [ 10662,  10086],
                        [ 11142,  10552],
                        [ 11594,  11006],
                        [ 12010,  11439],
                        [ 12388,  11850],
                        [ 12728,  12231],
                        [ 13027,  12580],
                        [ 13288,  12890],
                        [ 13510,  13158],
                        [ 13689,  13380],
                        [ 13819,  13553],
                        [ 13903,  13674],
                        [ 13935,  13740],
                        [ 13913,  13750],
                        [ 13865,  13730],
                        [ 13843,  13735],
                        [ 13878,  13795],
                        [ 13970,  13911],
                        [ 14111,  14073],
                        [ 14263,  14247],
                        [ 14348,  14353],
                        [ 14299,  14325],
                        [ 14114,  14161],
                        [ 13803,  13872],
                        [ 13371,  13462],
                        [ 12835,  12944],
                        [ 12205,  12330],
                        [ 11490,  11629],
                        [ 10706,  10853],
                        [  9863,  10017],
                        [  8974,   9132],
                        [  8050,   8210],
                        [  7105,   7261],
                        [  6148,   6299],
                        [  5190,   5334],
                        [  4242,   4374],
                        [  3312,   3426],
                        [  2410,   2504],
                        [  1542,   1612],
                        [   714,    756],
                        [   -67,    -58],
                        [  -800,   -825],
                        [ -1480,  -1543],
                        [ -2106,  -2211],
                        [ -2674,  -2826],
                        [ -3184,  -3388],
                        [ -3634,  -3896],
                        [ -4024,  -4353],
                        [ -4357,  -4761],
                        [ -4630,  -5116],
                        [ -4849,  -5418],
                        [ -5014,  -5665],
                        [ -5127,  -5858],
                        [ -5190,  -5996],
                        [ -5206,  -6081],
                        [ -5177,  -6105],
                        [ -5107,  -6074],
                        [ -4998,  -5987],
                        [ -4855,  -5848],
                        [ -4681,  -5662],
                        [ -4480,  -5433],
                        [ -4256,  -5174],
                        [ -4011,  -4889],
                        [ -3751,  -4586],
                        [ -3479,  -4267],
                        [ -3200,  -3939],
                        [ -2914,  -3605],
                        [ -2628,  -3269],
                        [ -2345,  -2935],
                        [ -2068,  -2606],
                        [ -1799,  -2286],
                        [ -1541,  -1978],
                        [ -1298,  -1684],
                        [ -1071,  -1409],
                        [  -861,  -1151],
                        [  -670,   -914],
                        [  -499,   -700],
                        [  -349,   -509],
                        [  -223,   -342],
                        [  -116,   -200],
                        [   -30,    -84],
                        [    42,     10],
                        [    99,     79],
                        [   141,    122],
                        [   168,    138],
                        [   181,    133],
                        [   183,    109],
                        [   178,     72],
                        [   168,     24],
                        [   178,     -7],
                        [   208,    -21],
                        [   267,     -9],
                        [   353,     30],
                        [   487,    116],
                        [   666,    249],
                        [   856,    392],
                        [  1057,    550],
                        [  1246,    700],
                        [  1426,    842],
                        [  1588,    970],
                        [  1733,   1086],
                        [  1856,   1183],
                        [  1957,   1263],
                        [  2034,   1321],
                        [  2087,   1361],
                        [  2115,   1379],
                        [  2120,   1378],
                        [  2102,   1359],
                        [  2063,   1320],
                        [  2006,   1267],
                        [  1931,   1198],
                        [  1842,   1117],
                        [  1740,   1025],
                        [  1627,    925],
                        [  1507,    818],
                        [  1380,    709],
                        [  1249,    595],
                        [  1115,    483],
                        [   979,    371],
                        [   844,    262],
                        [   712,    158],
                        [   587,     61],
                        [   470,    -29],
                        [   370,   -110],
                        [   286,   -179],
                        [   223,   -235],
                        [   179,   -279],
                        [   154,   -308],
                        [   150,   -323],
                        [   155,   -323],
                        [   171,   -309],
                        [   195,   -278],
                        [   226,   -232],
                        [   265,   -170],
                        [   310,    -94],
                        [   362,     -3],
                        [   419,    102],
                        [   434,    169],
                        [   332,    127],
                        [    83,    -59],
                        [  -316,   -388],
                        [  -858,   -860],
                        [ -1515,  -1444],
                        [ -2182,  -2040],
                        [ -2768,  -2555],
                        [ -3254,  -2974],
                        [ -3647,  -3302],
                        [ -3948,  -3542],
                        [ -4164,  -3699],
                        [ -4302,  -3777],
                        [ -4366,  -3785],
                        [ -4364,  -3725],
                        [ -4301,  -3607],
                        [ -4182,  -3437],
                        [ -4016,  -3222],
                        [ -3808,  -2967],
                        [ -3564,  -2682],
                        [ -3291,  -2368],
                        [ -2993,  -2034],
                        [ -2676,  -1683],
                        [ -2347,  -1319],
                        [ -2005,   -947],
                        [ -1657,   -570],
                        [ -1302,   -191],
                        [  -943,    189],
                        [  -580,    570],
                        [  -216,    947],
                        [   148,   1322],
                        [   512,   1692],
                        [   875,   2061],
                        [  1238,   2430],
                        [  1600,   2803],
                        [  1961,   3181],
                        [  2323,   3560],
                        [  2684,   3942],
                        [  3044,   4323],
                        [  3403,   4704],
                        [  3760,   5077],
                        [  4116,   5443],
                        [  4469,   5794],
                        [  4817,   6131],
                        [  5162,   6452],
                        [  5501,   6758],
                        [  5834,   7050],
                        [  6160,   7331],
                        [  6476,   7604],
                        [  6784,   7871],
                        [  7080,   8129],
                        [  7365,   8378],
                        [  7635,   8619],
                        [  7891,   8851],
                        [  8132,   9072],
                        [  8358,   9282],
                        [  8568,   9479],
                        [  8761,   9666],
                        [  8938,   9839],
                        [  9097,   9997],
                        [  9237,  10141],
                        [  9360,  10268],
                        [  9466,  10380],
                        [  9557,  10473],
                        [  9634,  10549],
                        [  9696,  10607],
                        [  9740,  10647],
                        [  9765,  10669],
                        [  9765,  10673],
                        [  9744,  10661],
                        [  9699,  10634],
                        [  9631,  10591],
                        [  9541,  10531],
                        [  9433,  10456],
                        [  9297,  10356],
                        [  9137,  10233],
                        [  8952,  10083],
                        [  8743,   9909],
                        [  8500,   9698],
                        [  8225,   9452],
                        [  7915,   9166],
                        [  7572,   8841],
                        [  7230,   8511],
                        [  6887,   8175],
                        [  6558,   7845],
                        [  6242,   7522],
                        [  5954,   7222],
                        [  5694,   6940],
                        [  5471,   6690],
                        [  5285,   6470],
                        [  5142,   6287],
                        [  5040,   6142],
                        [  4984,   6037],
                        [  4972,   5973],
                        [  5003,   5949],
                        [  5077,   5966],
                        [  5190,   6021],
                        [  5341,   6114],
                        [  5526,   6241],
                        [  5741,   6399],
                        [  5980,   6585],
                        [  6241,   6795],
                        [  6516,   7023],
                        [  6806,   7267],
                        [  7098,   7521],
                        [  7394,   7781],
                        [  7681,   8042],
                        [  7960,   8301],
                        [  8216,   8548],
                        [  8447,   8782],
                        [  8643,   8994],
                        [  8800,   9180],
                        [  8914,   9335],
                        [  8980,   9455],
                        [  8999,   9536],
                        [  8970,   9573],
                        [  8895,   9565],
                        [  8773,   9507],
                        [  8599,   9397],
                        [  8374,   9236],
                        [  8105,   9023],
                        [  7781,   8751],
                        [  7412,   8426],
                        [  7066,   8119],
                        [  6827,   7915],
                        [  6726,   7841],
                        [  6767,   7902],
                        [  6953,   8104],
                        [  7260,   8423],
                        [  7578,   8749],
                        [  7792,   8968],
                        [  7880,   9059],
                        [  7856,   9035],
                        [  7720,   8897],
                        [  7482,   8649],
                        [  7147,   8299],
                        [  6725,   7854],
                        [  6226,   7325],
                        [  5658,   6720],
                        [  5033,   6051],
                        [  4359,   5328],
                        [  3647,   4561],
                        [  2910,   3764],
                        [  2156,   2942],
                        [  1394,   2109],
                        [   635,   1272],
                        [  -112,    443],
                        [  -839,   -372],
                        [ -1541,  -1164],
                        [ -2212,  -1927],
                        [ -2847,  -2654],
                        [ -3443,  -3342],
                        [ -3995,  -3980],
                        [ -4502,  -4568],
                        [ -4961,  -5101],
                        [ -5371,  -5578],
                        [ -5731,  -6005],
                        [ -6043,  -6382],
                        [ -6307,  -6715],
                        [ -6524,  -7005],
                        [ -6698,  -7251],
                        [ -6829,  -7456],
                        [ -6921,  -7615],
                        [ -6976,  -7733],
                        [ -6996,  -7807],
                        [ -6985,  -7838],
                        [ -6946,  -7828],
                        [ -6883,  -7779],
                        [ -6798,  -7696],
                        [ -6696,  -7582],
                        [ -6578,  -7447],
                        [ -6450,  -7294],
                        [ -6312,  -7129],
                        [ -6169,  -6956],
                        [ -6022,  -6779],
                        [ -5874,  -6600],
                        [ -5730,  -6424],
                        [ -5591,  -6256],
                        [ -5459,  -6095],
                        [ -5338,  -5945],
                        [ -5229,  -5808],
                        [ -5135,  -5687],
                        [ -5055,  -5582],
                        [ -4990,  -5494],
                        [ -4945,  -5424],
                        [ -4918,  -5373],
                        [ -4916,  -5338],
                        [ -4936,  -5320],
                        [ -4978,  -5319],
                        [ -5042,  -5333],
                        [ -5114,  -5361],
                        [ -5196,  -5401],
                        [ -5277,  -5454],
                        [ -5357,  -5517],
                        [ -5431,  -5586],
                        [ -5496,  -5661],
                        [ -5552,  -5735],
                        [ -5597,  -5810],
                        [ -5633,  -5885],
                        [ -5659,  -5958],
                        [ -5674,  -6026],
                        [ -5676,  -6087],
                        [ -5638,  -6111],
                        [ -5561,  -6099],
                        [ -5444,  -6048],
                        [ -5285,  -5956],
                        [ -5100,  -5838],
                        [ -4885,  -5688],
                        [ -4654,  -5520],
                        [ -4405,  -5330],
                        [ -4148,  -5128],
                        [ -3883,  -4912],
                        [ -3618,  -4691],
                        [ -3353,  -4464],
                        [ -3095,  -4237],
                        [ -2843,  -4011],
                        [ -2602,  -3790],
                        [ -2373,  -3574],
                        [ -2159,  -3366],
                        [ -1959,  -3166],
                        [ -1776,  -2975],
                        [ -1610,  -2795],
                        [ -1459,  -2626],
                        [ -1325,  -2468],
                        [ -1206,  -2321],
                        [ -1102,  -2186],
                        [ -1013,  -2061],
                        [  -939,  -1948],
                        [  -878,  -1846],
                        [  -830,  -1757],
                        [  -791,  -1678],
                        [  -761,  -1610],
                        [  -734,  -1549],
                        [  -711,  -1497],
                        [  -688,  -1449],
                        [  -666,  -1405],
                        [  -642,  -1363],
                        [  -616,  -1324],
                        [  -591,  -1285],
                        [  -570,  -1247],
                        [  -549,  -1209],
                        [  -529,  -1168],
                        [  -511,  -1125],
                        [  -499,  -1085],
                        [  -483,  -1034],
                        [  -475,   -988],
                        [  -559,  -1029],
                        [  -820,  -1243],
                        [ -1279,  -1651],
                        [ -1939,  -2257],
                        [ -2809,  -3071],
                        [ -3867,  -4072],
                        [ -4983,  -5135],
                        [ -6028,  -6129],
                        [ -6973,  -7026],
                        [ -7823,  -7832],
                        [ -8572,  -8539],
                        [ -9217,  -9145],
                        [ -9760,  -9647],
                        [-10202, -10047],
                        [-10542, -10345],
                        [-10785, -10544],
                        [-10932, -10647],
                        [-10989, -10659],
                        [-10959, -10584],
                        [-10849, -10429],
                        [-10662, -10198],
                        [-10407,  -9896],
                        [-10089,  -9531],
                        [ -9715,  -9108],
                        [ -9291,  -8636],
                        [ -8823,  -8118],
                        [ -8316,  -7561],
                        [ -7773,  -6970],
                        [ -7202,  -6356],
                        [ -6606,  -5724],
                        [ -5990,  -5083],
                        [ -5359,  -4437],
                        [ -4718,  -3789],
                        [ -4070,  -3141],
                        [ -3419,  -2487],
                        [ -2768,  -1829],
                        [ -2121,  -1169],
                        [ -1480,   -508],
                        [  -850,    149],
                        [  -230,    798],
                        [   374,   1431],
                        [   960,   2048],
                        [  1527,   2640],
                        [  2070,   3207],
                        [  2589,   3744],
                        [  3083,   4250],
                        [  3547,   4723],
                        [  3982,   5163],
                        [  4384,   5572],
                        [  4754,   5949],
                        [  5089,   6292],
                        [  5388,   6602],
                        [  5651,   6877],
                        [  5878,   7121],
                        [  6071,   7331],
                        [  6229,   7509],
                        [  6355,   7655],
                        [  6450,   7769],
                        [  6514,   7854],
                        [  6550,   7909],
                        [  6559,   7936],
                        [  6545,   7936],
                        [  6514,   7909],
                        [  6469,   7859],
                        [  6417,   7784],
                        [  6359,   7686],
                        [  6293,   7568],
                        [  6219,   7433],
                        [  6128,   7279],
                        [  6021,   7113],
                        [  5896,   6933],
                        [  5750,   6742],
                        [  5588,   6543],
                        [  5413,   6337],
                        [  5237,   6136],
                        [  5062,   5942],
                        [  4908,   5772],
                        [  4772,   5626],
                        [  4645,   5490],
                        [  4526,   5365],
                        [  4383,   5218],
                        [  4221,   5051],
                        [  4038,   4865],
                        [  3837,   4661],
                        [  3629,   4448],
                        [  3412,   4227],
                        [  3199,   4006],
                        [  2988,   3787],
                        [  2790,   3578],
                        [  2602,   3378],
                        [  2432,   3192],
                        [  2278,   3023],
                        [  2145,   2871],
                        [  2030,   2738],
                        [  1937,   2625],
                        [  1863,   2530],
                        [  1808,   2453],
                        [  1770,   2393],
                        [  1747,   2347],
                        [  1735,   2312],
                        [  1729,   2288],
                        [  1727,   2269],
                        [  1723,   2253],
                        [  1716,   2237],
                        [  1701,   2217],
                        [  1674,   2191],
                        [  1629,   2155],
                        [  1566,   2106],
                        [  1476,   2039],
                        [  1359,   1953],
                        [  1210,   1840],
                        [  1026,   1699],
                        [   803,   1524],
                        [   538,   1315],
                        [   232,   1068],
                        [  -116,    782],
                        [  -503,    457],
                        [  -929,     93],
                        [ -1393,   -311],
                        [ -1893,   -752],
                        [ -2421,  -1229],
                        [ -2988,  -1749],
                        [ -3568,  -2289],
                        [ -4065,  -2756],
                        [ -4398,  -3066],
                        [ -4545,  -3200],
                        [ -4498,  -3149],
                        [ -4235,  -2890],
                        [ -3769,  -2434],
                        [ -3229,  -1909],
                        [ -2744,  -1443],
                        [ -2337,  -1060],
                        [ -1999,   -748],
                        [ -1736,   -518],
                        [ -1547,   -368],
                        [ -1430,   -300],
                        [ -1380,   -309],
                        [ -1398,   -392],
                        [ -1476,   -545],
                        [ -1613,   -763],
                        [ -1800,  -1038],
                        [ -2031,  -1364],
                        [ -2301,  -1735],
                        [ -2602,  -2141],
                        [ -2927,  -2576],
                        [ -3270,  -3034],
                        [ -3622,  -3504],
                        [ -3980,  -3982],
                        [ -4337,  -4460],
                        [ -4688,  -4933],
                        [ -5030,  -5393],
                        [ -5359,  -5835],
                        [ -5673,  -6247],
                        [ -5966,  -6624],
                        [ -6240,  -6965],
                        [ -6491,  -7265],
                        [ -6719,  -7534],
                        [ -6923,  -7767],
                        [ -7105,  -7979],
                        [ -7265,  -8170],
                        [ -7403,  -8341],
                        [ -7521,  -8495],
                        [ -7620,  -8628],
                        [ -7703,  -8745],
                        [ -7771,  -8842],
                        [ -7826,  -8922],
                        [ -7869,  -8985],
                        [ -7902,  -9035],
                        [ -7928,  -9071],
                        [ -7948,  -9094],
                        [ -7962,  -9107],
                        [ -7972,  -9114],
                        [ -7980,  -9116],
                        [ -7985,  -9116],
                        [ -7989,  -9115],
                        [ -7993,  -9113],
                        [ -7996,  -9115],
                        [ -8002,  -9120],
                        [ -8009,  -9130],
                        [ -8020,  -9146],
                        [ -8036,  -9167],
                        [ -8056,  -9195],
                        [ -8081,  -9229],
                        [ -8110,  -9270],
                        [ -8148,  -9315],
                        [ -8193,  -9364],
                        [ -8253,  -9415],
                        [ -8327,  -9469],
                        [ -8414,  -9520],
                        [ -8514,  -9570],
                        [ -8614,  -9617],
                        [ -8712,  -9657],
                        [ -8791,  -9690],
                        [ -8852,  -9714],
                        [ -8888,  -9726],
                        [ -8897,  -9726],
                        [ -8887,  -9719],
                        [ -8857,  -9705],
                        [ -8838,  -9711],
                        [ -8825,  -9734],
                        [ -8825,  -9777],
                        [ -8834,  -9837],
                        [ -8817,  -9878],
                        [ -8777,  -9901],
                        [ -8675,  -9865],
                        [ -8514,  -9774],
                        [ -8300,  -9629],
                        [ -8032,  -9432],
                        [ -7721,  -9189],
                        [ -7368,  -8902],
                        [ -6985,  -8581],
                        [ -6573,  -8226],
                        [ -6143,  -7847],
                        [ -5694,  -7444],
                        [ -5239,  -7028],
                        [ -4778,  -6598],
                        [ -4320,  -6165],
                        [ -3866,  -5727],
                        [ -3426,  -5294],
                        [ -2997,  -4864],
                        [ -2588,  -4445],
                        [ -2199,  -4037],
                        [ -1831,  -3643],
                        [ -1487,  -3266],
                        [ -1165,  -2907],
                        [  -867,  -2568],
                        [  -593,  -2251],
                        [  -345,  -1956],
                        [  -119,  -1685],
                        [    80,  -1439],
                        [   257,  -1219],
                        [   409,  -1023],
                        [   540,   -850],
                        [   648,   -699],
                        [   739,   -566],
                        [   813,   -453],
                        [   877,   -353],
                        [   931,   -268],
                        [   976,   -196],
                        [  1011,   -136],
                        [  1040,    -85],
                        [  1064,    -42],
                        [  1079,    -10],
                        [  1086,     13],
                        [  1098,     41],
                        [  1085,     45],
                        [   957,    -64],
                        [   645,   -356],
                        [   141,   -837],
                        [  -563,  -1515],
                        [ -1489,  -2416],
                        [ -2628,  -3530],
                        [ -3846,  -4726],
                        [ -5013,  -5874],
                        [ -6106,  -6949],
                        [ -7124,  -7954],
                        [ -8056,  -8872],
                        [ -8892,  -9693],
                        [ -9630, -10412],
                        [-10268, -11027],
                        [-10799, -11533],
                        [-11224, -11928],
                        [-11542, -12212],
                        [-11756, -12388],
                        [-11867, -12459],
                        [-11881, -12427],
                        [-11802, -12298],
                        [-11633, -12077],
                        [-11384, -11771],
                        [-11061, -11386],
                        [-10669, -10931],
                        [-10217, -10411],
                        [ -9711,  -9836],
                        [ -9159,  -9213],
                        [ -8565,  -8558],
                        [ -7939,  -7877],
                        [ -7287,  -7184],
                        [ -6615,  -6487],
                        [ -5930,  -5789],
                        [ -5236,  -5098],
                        [ -4541,  -4405],
                        [ -3849,  -3715],
                        [ -3166,  -3026],
                        [ -2494,  -2340],
                        [ -1839,  -1663],
                        [ -1203,   -999],
                        [  -592,   -353],
                        [    -4,    271],
                        [   554,    871],
                        [  1081,   1444],
                        [  1575,   1986],
                        [  2035,   2496],
                        [  2457,   2967],
                        [  2841,   3400],
                        [  3187,   3794],
                        [  3493,   4148],
                        [  3759,   4459],
                        [  3984,   4730],
                        [  4169,   4961],
                        [  4316,   5154],
                        [  4427,   5310],
                        [  4502,   5429],
                        [  4547,   5514],
                        [  4561,   5568],
                        [  4550,   5592],
                        [  4513,   5588],
                        [  4460,   5558],
                        [  4388,   5506],
                        [  4311,   5432],
                        [  4232,   5340],
                        [  4159,   5230],
                        [  4096,   5106],
                        [  4040,   4969],
                        [  3994,   4823],
                        [  3946,   4669],
                        [  3894,   4507],
                        [  3832,   4342],
                        [  3761,   4175],
                        [  3683,   4011],
                        [  3599,   3849],
                        [  3545,   3726],
                        [  3520,   3642],
                        [  3551,   3621],
                        [  3637,   3665],
                        [  3763,   3756],
                        [  3930,   3898],
                        [  4078,   4026],
                        [  4210,   4145],
                        [  4300,   4230],
                        [  4349,   4281],
                        [  4364,   4302],
                        [  4344,   4293],
                        [  4295,   4258],
                        [  4214,   4197],
                        [  4111,   4115],
                        [  3983,   4010],
                        [  3836,   3888],
                        [  3669,   3748],
                        [  3487,   3595],
                        [  3287,   3426],
                        [  3077,   3244],
                        [  2853,   3049],
                        [  2619,   2843],
                        [  2373,   2624],
                        [  2117,   2392],
                        [  1847,   2147],
                        [  1562,   1888],
                        [  1261,   1615],
                        [   942,   1327],
                        [   604,   1021],
                        [   246,    700],
                        [  -132,    362],
                        [  -529,      7],
                        [  -947,   -364],
                        [ -1384,   -754],
                        [ -1838,  -1162],
                        [ -2311,  -1590],
                        [ -2801,  -2038],
                        [ -3313,  -2507],
                        [ -3846,  -2998],
                        [ -4404,  -3510],
                        [ -4981,  -4041],
                        [ -5576,  -4589],
                        [ -6186,  -5151],
                        [ -6808,  -5727],
                        [ -7435,  -6309],
                        [ -8062,  -6896],
                        [ -8697,  -7493],
                        [ -9302,  -8067],
                        [ -9785,  -8526],
                        [-10091,  -8818],
                        [-10211,  -8933],
                        [-10130,  -8855],
                        [ -9813,  -8549],
                        [ -9259,  -8011],
                        [ -8585,  -7358],
                        [ -7907,  -6705],
                        [ -7239,  -6067],
                        [ -6580,  -5443],
                        [ -5944,  -4847],
                        [ -5337,  -4286],
                        [ -4760,  -3767],
                        [ -4221,  -3291],
                        [ -3721,  -2865],
                        [ -3267,  -2490],
                        [ -2857,  -2166],
                        [ -2493,  -1893],
                        [ -2173,  -1671],
                        [ -1898,  -1497],
                        [ -1665,  -1369],
                        [ -1473,  -1285],
                        [ -1318,  -1241],
                        [ -1197,  -1232],
                        [ -1107,  -1255],
                        [ -1046,  -1305],
                        [ -1009,  -1380],
                        [  -996,  -1471],
                        [ -1003,  -1575],
                        [ -1028,  -1679],
                        [ -1068,  -1781],
                        [ -1122,  -1873],
                        [ -1187,  -1954],
                        [ -1263,  -2030],
                        [ -1346,  -2097],
                        [ -1437,  -2173],
                        [ -1535,  -2254],
                        [ -1640,  -2346],
                        [ -1750,  -2446],
                        [ -1866,  -2556],
                        [ -1987,  -2675],
                        [ -2113,  -2802],
                        [ -2245,  -2940],
                        [ -2381,  -3087],
                        [ -2521,  -3244],
                        [ -2663,  -3407],
                        [ -2808,  -3576],
                        [ -2953,  -3746],
                        [ -3098,  -3918],
                        [ -3241,  -4088],
                        [ -3382,  -4257],
                        [ -3518,  -4422],
                        [ -3648,  -4583],
                        [ -3772,  -4742],
                        [ -3887,  -4895],
                        [ -3995,  -5043],
                        [ -4094,  -5185],
                        [ -4185,  -5319],
                        [ -4266,  -5446],
                        [ -4336,  -5563],
                        [ -4396,  -5670],
                        [ -4448,  -5763],
                        [ -4493,  -5844],
                        [ -4539,  -5909],
                        [ -4586,  -5957],
                        [ -4633,  -5987],
                        [ -4682,  -5998],
                        [ -4721,  -5988],
                        [ -4749,  -5956],
                        [ -4749,  -5899],
                        [ -4721,  -5818],
                        [ -4658,  -5714],
                        [ -4561,  -5585],
                        [ -4450,  -5452],
                        [ -4323,  -5314],
                        [ -4229,  -5216],
                        [ -4164,  -5158],
                        [ -4136,  -5144],
                        [ -4145,  -5174],
                        [ -4151,  -5207],
                        [ -4158,  -5247],
                        [ -4098,  -5226],
                        [ -3978,  -5148],
                        [ -3800,  -5013],
                        [ -3561,  -4821],
                        [ -3272,  -4577],
                        [ -2933,  -4283],
                        [ -2555,  -3946],
                        [ -2138,  -3569],
                        [ -1693,  -3161],
                        [ -1224,  -2722],
                        [  -739,  -2264],
                        [  -241,  -1788],
                        [   260,  -1302],
                        [   762,   -809],
                        [  1255,   -318],
                        [  1736,    172],
                        [  2201,    652],
                        [  2646,   1123],
                        [  3070,   1576],
                        [  3473,   2013],
                        [  3850,   2429],
                        [  4205,   2823],
                        [  4534,   3191],
                        [  4836,   3533],
                        [  5111,   3846],
                        [  5359,   4132],
                        [  5576,   4388],
                        [  5763,   4613],
                        [  5920,   4812],
                        [  6045,   4982],
                        [  6147,   5129],
                        [  6222,   5252],
                        [  6286,   5357],
                        [  6335,   5442],
                        [  6377,   5511],
                        [  6407,   5563],
                        [  6433,   5603],
                        [  6453,   5630],
                        [  6465,   5642],
                        [  6472,   5643],
                        [  6481,   5644],
                        [  6460,   5611],
                        [  6338,   5476],
                        [  6081,   5207],
                        [  5691,   4805],
                        [  5153,   4257],
                        [  4432,   3525],
                        [  3521,   2602],
                        [  2526,   1594],
                        [  1545,    600],
                        [   594,   -366],
                        [  -325,  -1298],
                        [ -1194,  -2178],
                        [ -2002,  -2992],
                        [ -2744,  -3734],
                        [ -3412,  -4396],
                        [ -3998,  -4970],
                        [ -4498,  -5452],
                        [ -4910,  -5838],
                        [ -5232,  -6128],
                        [ -5463,  -6320],
                        [ -5605,  -6418],
                        [ -5662,  -6424],
                        [ -5634,  -6339],
                        [ -5528,  -6172],
                        [ -5350,  -5926],
                        [ -5105,  -5609],
                        [ -4799,  -5226],
                        [ -4439,  -4786],
                        [ -4032,  -4297],
                        [ -3584,  -3775],
                        [ -3101,  -3226],
                        [ -2593,  -2668],
                        [ -2064,  -2104],
                        [ -1521,  -1544],
                        [  -969,   -992],
                        [  -416,   -443],
                        [   134,     98],
                        [   676,    637],
                        [  1207,   1169],
                        [  1720,   1692],
                        [  2213,   2202],
                        [  2686,   2697],
                        [  3134,   3174],
                        [  3555,   3635],
                        [  3948,   4076],
                        [  4310,   4496],
                        [  4641,   4893],
                        [  4940,   5259],
                        [  5205,   5595],
                        [  5437,   5896],
                        [  5637,   6162],
                        [  5803,   6392],
                        [  5937,   6585],
                        [  6040,   6746],
                        [  6114,   6875],
                        [  6160,   6974],
                        [  6182,   7043],
                        [  6181,   7087],
                        [  6161,   7106],
                        [  6125,   7105],
                        [  6076,   7084],
                        [  6018,   7048],
                        [  5954,   6996],
                        [  5894,   6933],
                        [  5841,   6861],
                        [  5805,   6781],
                        [  5787,   6695],
                        [  5789,   6606],
                        [  5809,   6515],
                        [  5837,   6421],
                        [  5872,   6326],
                        [  5902,   6234],
                        [  5930,   6144],
                        [  5960,   6065],
                        [  5989,   5995],
                        [  6067,   5985],
                        [  6190,   6031],
                        [  6385,   6160],
                        [  6649,   6369],
                        [  6970,   6647],
                        [  7348,   6994],
                        [  7704,   7330],
                        [  8041,   7659],
                        [  8320,   7941],
                        [  8542,   8175],
                        [  8705,   8362],
                        [  8810,   8500],
                        [  8856,   8587],
                        [  8842,   8620],
                        [  8773,   8604],
                        [  8647,   8538],
                        [  8470,   8422],
                        [  8237,   8257],
                        [  7957,   8049],
                        [  7628,   7793],
                        [  7258,   7495],
                        [  6846,   7155],
                        [  6400,   6778],
                        [  5917,   6362],
                        [  5403,   5912],
                        [  4859,   5428],
                        [  4284,   4913],
                        [  3681,   4370],
                        [  3053,   3801],
                        [  2399,   3207],
                        [  1726,   2594],
                        [  1034,   1961],
                        [   332,   1316],
                        [  -379,    658],
                        [ -1090,     -7],
                        [ -1798,   -678],
                        [ -2500,  -1354],
                        [ -3194,  -2030],
                        [ -3881,  -2703],
                        [ -4560,  -3374],
                        [ -5234,  -4038],
                        [ -5900,  -4691],
                        [ -6550,  -5329],
                        [ -7183,  -5949],
                        [ -7796,  -6547],
                        [ -8380,  -7115],
                        [ -8933,  -7652],
                        [ -9457,  -8161],
                        [ -9915,  -8608],
                        [-10256,  -8941],
                        [-10459,  -9141],
                        [-10525,  -9211],
                        [-10436,  -9129],
                        [-10146,  -8852],
                        [ -9638,  -8361],
                        [ -8987,  -7729],
                        [ -8272,  -7036],
                        [ -7501,  -6290],
                        [ -6680,  -5497],
                        [ -5828,  -4677],
                        [ -4955,  -3842],
                        [ -4072,  -3002],
                        [ -3189,  -2167],
                        [ -2316,  -1348],
                        [ -1463,   -553],
                        [  -636,    211],
                        [   158,    939],
                        [   912,   1625],
                        [  1623,   2264],
                        [  2287,   2856],
                        [  2901,   3397],
                        [  3465,   3886],
                        [  3976,   4323],
                        [  4435,   4708],
                        [  4842,   5042],
                        [  5198,   5327],
                        [  5503,   5567],
                        [  5760,   5766],
                        [  5970,   5935],
                        [  6134,   6074],
                        [  6255,   6191],
                        [  6336,   6289],
                        [  6377,   6364],
                        [  6383,   6420],
                        [  6355,   6444],
                        [  6297,   6439],
                        [  6209,   6400],
                        [  6096,   6331],
                        [  5959,   6231],
                        [  5800,   6102],
                        [  5623,   5943],
                        [  5427,   5755],
                        [  5219,   5539],
                        [  4999,   5295],
                        [  4772,   5033],
                        [  4539,   4753],
                        [  4305,   4467],
                        [  4073,   4175],
                        [  3845,   3886],
                        [  3623,   3603],
                        [  3413,   3327],
                        [  3214,   3062],
                        [  3031,   2809],
                        [  2865,   2571],
                        [  2717,   2349],
                        [  2589,   2146],
                        [  2481,   1963],
                        [  2395,   1802],
                        [  2332,   1664],
                        [  2291,   1552],
                        [  2269,   1464],
                        [  2268,   1403],
                        [  2275,   1370],
                        [  2294,   1364],
                        [  2319,   1387],
                        [  2353,   1439],
                        [  2397,   1518],
                        [  2453,   1627],
                        [  2537,   1766],
                        [  2644,   1931],
                        [  2779,   2121],
                        [  2943,   2335],
                        [  3103,   2542],
                        [  3261,   2741],
                        [  3368,   2884],
                        [  3424,   2970],
                        [  3420,   2990],
                        [  3356,   2945],
                        [  3267,   2872],
                        [  3153,   2767],
                        [  3088,   2706],
                        [  3066,   2685],
                        [  3090,   2706],
                        [  3159,   2769],
                        [  3273,   2875],
                        [  3430,   3021],
                        [  3621,   3202],
                        [  3850,   3419],
                        [  4105,   3664],
                        [  4387,   3936],
                        [  4687,   4227],
                        [  5006,   4538],
                        [  5332,   4859],
                        [  5666,   5191],
                        [  5996,   5525],
                        [  6325,   5861],
                        [  6644,   6194],
                        [  6954,   6520],
                        [  7251,   6837],
                        [  7534,   7144],
                        [  7803,   7434],
                        [  8058,   7710],
                        [  8296,   7966],
                        [  8517,   8204],
                        [  8719,   8422],
                        [  8901,   8617],
                        [  9056,   8791],
                        [  9185,   8943],
                        [  9286,   9072],
                        [  9361,   9181],
                        [  9413,   9271],
                        [  9444,   9342],
                        [  9466,   9398],
                        [  9479,   9438],
                        [  9488,   9465],
                        [  9492,   9478],
                        [  9492,   9479],
                        [  9490,   9468],
                        [  9484,   9444],
                        [  9475,   9408],
                        [  9466,   9367],
                        [  9436,   9297],
                        [  9358,   9178],
                        [  9235,   9011],
                        [  9070,   8803],
                        [  8845,   8535],
                        [  8517,   8165],
                        [  8056,   7660],
                        [  7505,   7068],
                        [  6920,   6443],
                        [  6309,   5795],
                        [  5679,   5129],
                        [  5043,   4462],
                        [  4418,   3811],
                        [  3806,   3180],
                        [  3218,   2582],
                        [  2663,   2024],
                        [  2150,   1514],
                        [  1680,   1055],
                        [  1261,    654],
                        [   895,    314],
                        [   584,     34],
                        [   328,   -184],
                        [   129,   -339],
                        [   -17,   -436],
                        [  -111,   -475],
                        [  -157,   -462],
                        [  -157,   -399],
                        [  -116,   -292],
                        [   -40,   -146],
                        [    71,     26],
                        [   209,    220],
                        [   370,    423],
                        [   550,    632],
                        [   744,    839],
                        [   949,   1038],
                        [  1161,   1236],
                        [  1374,   1428],
                        [  1587,   1620],
                        [  1794,   1809],
                        [  1996,   1995],
                        [  2187,   2177],
                        [  2368,   2355],
                        [  2537,   2529],
                        [  2695,   2702],
                        [  2838,   2875],
                        [  2967,   3046],
                        [  3081,   3213],
                        [  3180,   3372],
                        [  3263,   3521],
                        [  3332,   3651],
                        [  3387,   3767],
                        [  3426,   3863],
                        [  3453,   3942],
                        [  3468,   4005],
                        [  3472,   4053],
                        [  3466,   4087],
                        [  3452,   4108],
                        [  3431,   4119],
                        [  3407,   4120],
                        [  3379,   4113],
                        [  3352,   4101],
                        [  3326,   4084],
                        [  3302,   4063],
                        [  3289,   4041],
                        [  3288,   4017],
                        [  3304,   3993],
                        [  3340,   3971],
                        [  3395,   3950],
                        [  3470,   3930],
                        [  3556,   3911],
                        [  3649,   3891],
                        [  3741,   3872],
                        [  3833,   3858],
                        [  3928,   3852],
                        [  4025,   3856],
                        [  4172,   3920],
                        [  4365,   4037],
                        [  4621,   4230],
                        [  4937,   4495],
                        [  5308,   4826],
                        [  5734,   5224],
                        [  6134,   5610],
                        [  6513,   5987],
                        [  6828,   6311],
                        [  7081,   6585],
                        [  7266,   6803],
                        [  7382,   6962],
                        [  7424,   7057],
                        [  7394,   7089],
                        [  7290,   7054],
                        [  7113,   6954],
                        [  6866,   6790],
                        [  6550,   6560],
                        [  6170,   6271],
                        [  5726,   5919],
                        [  5227,   5513],
                        [  4674,   5051],
                        [  4075,   4540],
                        [  3432,   3982],
                        [  2752,   3384],
                        [  2037,   2745],
                        [  1292,   2076],
                        [   520,   1376],
                        [  -271,    655],
                        [ -1081,    -88],
                        [ -1900,   -841],
                        [ -2724,  -1605],
                        [ -3540,  -2369],
                        [ -4346,  -3131],
                        [ -5129,  -3885],
                        [ -5883,  -4627],
                        [ -6607,  -5351],
                        [ -7295,  -6052],
                        [ -7950,  -6728],
                        [ -8569,  -7373],
                        [ -9157,  -7985],
                        [ -9709,  -8559],
                        [-10220,  -9090],
                        [-10687,  -9575],
                        [-11107, -10010],
                        [-11477, -10389],
                        [-11793, -10714],
                        [-12055, -10978],
                        [-12252, -11176],
                        [-12384, -11308],
                        [-12466, -11390],
                        [-12500, -11425],
                        [-12469, -11395],
                        [-12329, -11258],
                        [-12035, -10967],
                        [-11598, -10535],
                        [-11053,  -9996],
                        [-10408,  -9357],
                        [ -9674,  -8629],
                        [ -8870,  -7830],
                        [ -8008,  -6977],
                        [ -7100,  -6080],
                        [ -6161,  -5154],
                        [ -5203,  -4210],
                        [ -4240,  -3264],
                        [ -3283,  -2323],
                        [ -2340,  -1399],
                        [ -1424,   -501],
                        [  -540,    362],
                        [   302,   1186],
                        [  1097,   1963],
                        [  1840,   2688],
                        [  2529,   3358],
                        [  3158,   3971],
                        [  3729,   4523],
                        [  4240,   5016],
                        [  4688,   5451],
                        [  5077,   5829],
                        [  5405,   6157],
                        [  5674,   6437],
                        [  5887,   6674],
                        [  6047,   6871],
                        [  6155,   7030],
                        [  6215,   7153],
                        [  6230,   7233],
                        [  6204,   7275],
                        [  6143,   7276],
                        [  6048,   7239],
                        [  5925,   7163],
                        [  5776,   7054],
                        [  5605,   6907],
                        [  5416,   6727],
                        [  5214,   6512],
                        [  5001,   6267],
                        [  4782,   6000],
                        [  4561,   5712],
                        [  4342,   5418],
                        [  4128,   5120],
                        [  3923,   4829],
                        [  3729,   4547],
                        [  3550,   4278],
                        [  3389,   4024],
                        [  3246,   3790],
                        [  3126,   3576],
                        [  3028,   3385],
                        [  2954,   3219],
                        [  2906,   3080],
                        [  2882,   2968],
                        [  2883,   2884],
                        [  2910,   2828],
                        [  2958,   2802],
                        [  3027,   2804],
                        [  3111,   2832],
                        [  3208,   2889],
                        [  3313,   2971],
                        [  3427,   3079],
                        [  3544,   3208],
                        [  3668,   3361],
                        [  3803,   3535],
                        [  3946,   3726],
                        [  4097,   3930],
                        [  4256,   4145],
                        [  4391,   4339],
                        [  4502,   4509],
                        [  4552,   4617],
                        [  4541,   4663],
                        [  4457,   4634],
                        [  4299,   4529],
                        [  4096,   4375],
                        [  3843,   4170],
                        [  3610,   3978],
                        [  3391,   3797],
                        [  3192,   3633],
                        [  3015,   3485],
                        [  2865,   3360],
                        [  2739,   3256],
                        [  2640,   3173],
                        [  2565,   3112],
                        [  2516,   3072],
                        [  2490,   3053],
                        [  2485,   3050],
                        [  2502,   3066],
                        [  2533,   3097],
                        [  2581,   3142],
                        [  2638,   3197],
                        [  2706,   3262],
                        [  2780,   3334],
                        [  2860,   3412],
                        [  2944,   3492],
                        [  3032,   3576],
                        [  3123,   3660],
                        [  3218,   3743],
                        [  3313,   3824],
                        [  3409,   3904],
                        [  3501,   3980],
                        [  3589,   4050],
                        [  3663,   4114],
                        [  3724,   4173],
                        [  3769,   4225],
                        [  3800,   4271],
                        [  3819,   4308],
                        [  3825,   4338],
                        [  3832,   4361],
                        [  3837,   4377],
                        [  3842,   4386],
                        [  3849,   4387],
                        [  3855,   4380],
                        [  3860,   4364],
                        [  3863,   4337],
                        [  3866,   4300],
                        [  3863,   4251],
                        [  3866,   4200],
                        [  3902,   4180],
                        [  3993,   4210],
                        [  4141,   4298],
                        [  4331,   4426],
                        [  4516,   4552],
                        [  4634,   4613],
                        [  4656,   4583],
                        [  4598,   4473],
                        [  4462,   4289],
                        [  4258,   4038],
                        [  3993,   3733],
                        [  3680,   3382],
                        [  3324,   2996],
                        [  2935,   2581],
                        [  2520,   2147],
                        [  2090,   1703],
                        [  1650,   1255],
                        [  1207,    810],
                        [   768,    373],
                        [   337,    -52],
                        [   -81,   -459],
                        [  -483,   -847],
                        [  -867,  -1214],
                        [ -1230,  -1556],
                        [ -1572,  -1874],
                        [ -1893,  -2168],
                        [ -2191,  -2438],
                        [ -2469,  -2685],
                        [ -2726,  -2915],
                        [ -2962,  -3129],
                        [ -3179,  -3332],
                        [ -3377,  -3525],
                        [ -3559,  -3713],
                        [ -3725,  -3899],
                        [ -3876,  -4080],
                        [ -4016,  -4259],
                        [ -4144,  -4429],
                        [ -4262,  -4592],
                        [ -4369,  -4744],
                        [ -4468,  -4888],
                        [ -4558,  -5016],
                        [ -4639,  -5129],
                        [ -4712,  -5220],
                        [ -4775,  -5288],
                        [ -4828,  -5333],
                        [ -4872,  -5355],
                        [ -4905,  -5360],
                        [ -4929,  -5347],
                        [ -4943,  -5324],
                        [ -4947,  -5293],
                        [ -4942,  -5254],
                        [ -4925,  -5207],
                        [ -4899,  -5153],
                        [ -4862,  -5092],
                        [ -4815,  -5024],
                        [ -4758,  -4949],
                        [ -4692,  -4867],
                        [ -4617,  -4779],
                        [ -4533,  -4686],
                        [ -4440,  -4587],
                        [ -4340,  -4482],
                        [ -4233,  -4373],
                        [ -4117,  -4261],
                        [ -3993,  -4145],
                        [ -3859,  -4027],
                        [ -3720,  -3907],
                        [ -3569,  -3788],
                        [ -3410,  -3668],
                        [ -3248,  -3554],
                        [ -3083,  -3446],
                        [ -2922,  -3343],
                        [ -2764,  -3244],
                        [ -2607,  -3144],
                        [ -2454,  -3046],
                        [ -2269,  -2911],
                        [ -2059,  -2746],
                        [ -1814,  -2539],
                        [ -1536,  -2292],
                        [ -1220,  -1999],
                        [  -868,  -1662],
                        [  -539,  -1338],
                        [  -230,  -1026],
                        [    24,   -760],
                        [   227,   -536],
                        [   368,   -366],
                        [   447,   -249],
                        [   457,   -194],
                        [   400,   -199],
                        [   273,   -268],
                        [    76,   -401],
                        [  -188,   -597],
                        [  -518,   -856],
                        [  -909,  -1172],
                        [ -1359,  -1548],
                        [ -1862,  -1976],
                        [ -2416,  -2455],
                        [ -3008,  -2977],
                        [ -3641,  -3542],
                        [ -4302,  -4140],
                        [ -4989,  -4768],
                        [ -5695,  -5418],
                        [ -6416,  -6086],
                        [ -7143,  -6764],
                        [ -7873,  -7449],
                        [ -8595,  -8131],
                        [ -9306,  -8808],
                        [ -9991,  -9469],
                        [-10646, -10113],
                        [-11258, -10732],
                        [-11825, -11321],
                        [-12342, -11873],
                        [-12806, -12386],
                        [-13218, -12852],
                        [-13576, -13270],
                        [-13886, -13635],
                        [-14142, -13944],
                        [-14344, -14194],
                        [-14488, -14384],
                        [-14574, -14508],
                        [-14601, -14568],
                        [-14571, -14561],
                        [-14480, -14485],
                        [-14359, -14374],
                        [-14263, -14280],
                        [-14221, -14234],
                        [-14237, -14242],
                        [-14298, -14294],
                        [-14370, -14353],
                        [-14372, -14341],
                        [-14247, -14201],
                        [-13998, -13935],
                        [-13634, -13552],
                        [-13167, -13061],
                        [-12609, -12477],
                        [-11972, -11812],
                        [-11267, -11077],
                        [-10506, -10285],
                        [ -9704,  -9452],
                        [ -8872,  -8587],
                        [ -8020,  -7703],
                        [ -7161,  -6812],
                        [ -6308,  -5924],
                        [ -5467,  -5048],
                        [ -4648,  -4193],
                        [ -3858,  -3368],
                        [ -3104,  -2578],
                        [ -2391,  -1831],
                        [ -1723,  -1129],
                        [ -1100,   -477],
                        [  -530,    122],
                        [   -11,    669],
                        [   457,   1161],
                        [   870,   1602],
                        [  1233,   1992],
                        [  1545,   2334],
                        [  1808,   2631],
                        [  2026,   2887],
                        [  2199,   3105],
                        [  2334,   3286],
                        [  2433,   3432],
                        [  2499,   3543],
                        [  2538,   3623],
                        [  2554,   3673],
                        [  2548,   3694],
                        [  2528,   3685],
                        [  2493,   3647],
                        [  2448,   3580],
                        [  2398,   3489],
                        [  2344,   3378],
                        [  2291,   3252],
                        [  2242,   3122],
                        [  2199,   2990],
                        [  2164,   2865],
                        [  2139,   2749],
                        [  2127,   2645],
                        [  2129,   2556],
                        [  2145,   2484],
                        [  2177,   2431],
                        [  2225,   2397],
                        [  2290,   2384],
                        [  2373,   2390],
                        [  2471,   2418],
                        [  2585,   2467],
                        [  2713,   2535],
                        [  2854,   2622],
                        [  3006,   2727],
                        [  3166,   2847],
                        [  3335,   2980],
                        [  3506,   3126],
                        [  3679,   3279],
                        [  3842,   3439],
                        [  3999,   3607],
                        [  4145,   3777],
                        [  4277,   3945],
                        [  4392,   4107],
                        [  4491,   4262],
                        [  4551,   4385],
                        [  4571,   4476],
                        [  4538,   4516],
                        [  4449,   4505],
                        [  4292,   4426],
                        [  4066,   4279],
                        [  3781,   4071],
                        [  3434,   3801],
                        [  3075,   3513],
                        [  2698,   3205],
                        [  2316,   2887],
                        [  1926,   2558],
                        [  1545,   2230],
                        [  1168,   1900],
                        [   807,   1580],
                        [   458,   1264],
                        [   129,    962],
                        [  -179,    674],
                        [  -464,    401],
                        [  -726,    146],
                        [  -963,    -91],
                        [ -1175,   -308],
                        [ -1363,   -506],
                        [ -1525,   -683],
                        [ -1663,   -840],
                        [ -1778,   -977],
                        [ -1870,  -1095],
                        [ -1939,  -1194],
                        [ -1985,  -1274],
                        [ -2009,  -1337],
                        [ -2014,  -1383],
                        [ -2000,  -1413],
                        [ -1974,  -1429],
                        [ -1933,  -1430],
                        [ -1891,  -1419],
                        [ -1845,  -1397],
                        [ -1800,  -1365],
                        [ -1756,  -1324],
                        [ -1713,  -1280],
                        [ -1671,  -1230],
                        [ -1624,  -1180],
                        [ -1573,  -1129],
                        [ -1519,  -1079],
                        [ -1464,  -1033],
                        [ -1411,   -992],
                        [ -1357,   -960],
                        [ -1306,   -934],
                        [ -1261,   -923],
                        [ -1222,   -924],
                        [ -1138,   -886],
                        [  -941,   -740],
                        [  -605,   -458],
                        [  -132,    -40],
                        [   472,    509],
                        [  1169,   1155],
                        [  1857,   1794],
                        [  2444,   2337],
                        [  2919,   2769],
                        [  3288,   3096],
                        [  3553,   3322],
                        [  3719,   3449],
                        [  3792,   3483],
                        [  3776,   3431],
                        [  3677,   3299],
                        [  3505,   3095],
                        [  3266,   2828],
                        [  2968,   2502],
                        [  2618,   2126],
                        [  2226,   1708],
                        [  1797,   1255],
                        [  1340,    774],
                        [   860,    270],
                        [   365,   -249],
                        [  -142,   -779],
                        [  -656,  -1314],
                        [ -1171,  -1849],
                        [ -1683,  -2382],
                        [ -2188,  -2908],
                        [ -2683,  -3425],
                        [ -3166,  -3928],
                        [ -3632,  -4417],
                        [ -4080,  -4888],
                        [ -4509,  -5344],
                        [ -4916,  -5784],
                        [ -5299,  -6208],
                        [ -5659,  -6617],
                        [ -5995,  -7007],
                        [ -6305,  -7378],
                        [ -6591,  -7728],
                        [ -6851,  -8054],
                        [ -7086,  -8351],
                        [ -7295,  -8618],
                        [ -7477,  -8848],
                        [ -7633,  -9041],
                        [ -7762,  -9195],
                        [ -7865,  -9312],
                        [ -7941,  -9393],
                        [ -7993,  -9442],
                        [ -8021,  -9465],
                        [ -8025,  -9463],
                        [ -8006,  -9438],
                        [ -7967,  -9391],
                        [ -7906,  -9324],
                        [ -7827,  -9241],
                        [ -7730,  -9141],
                        [ -7618,  -9027],
                        [ -7493,  -8900],
                        [ -7357,  -8763],
                        [ -7213,  -8617],
                        [ -7063,  -8464],
                        [ -6908,  -8305],
                        [ -6751,  -8145],
                        [ -6596,  -7982],
                        [ -6446,  -7820],
                        [ -6304,  -7660],
                        [ -6173,  -7503],
                        [ -6049,  -7352],
                        [ -5935,  -7207],
                        [ -5824,  -7073],
                        [ -5719,  -6951],
                        [ -5619,  -6840],
                        [ -5527,  -6741],
                        [ -5438,  -6650],
                        [ -5355,  -6569],
                        [ -5271,  -6488],
                        [ -5185,  -6407],
                        [ -5098,  -6323],
                        [ -5007,  -6237],
                        [ -4897,  -6127],
                        [ -4767,  -5996],
                        [ -4642,  -5866],
                        [ -4518,  -5736],
                        [ -4418,  -5625],
                        [ -4338,  -5532],
                        [ -4290,  -5466],
                        [ -4273,  -5428],
                        [ -4293,  -5423],
                        [ -4350,  -5451],
                        [ -4448,  -5517],
                        [ -4586,  -5618],
                        [ -4763,  -5758],
                        [ -4979,  -5934],
                        [ -5231,  -6144],
                        [ -5516,  -6387],
                        [ -5831,  -6661],
                        [ -6173,  -6961],
                        [ -6535,  -7282],
                        [ -6916,  -7625],
                        [ -7306,  -7980],
                        [ -7703,  -8344],
                        [ -8101,  -8713],
                        [ -8496,  -9082],
                        [ -8881,  -9445],
                        [ -9254,  -9796],
                        [ -9605, -10132],
                        [ -9930, -10449],
                        [-10220, -10740],
                        [-10472, -11003],
                        [-10678, -11233],
                        [-10835, -11428],
                        [-10939, -11581],
                        [-10989, -11691],
                        [-10987, -11753],
                        [-10933, -11764],
                        [-10830, -11724],
                        [-10679, -11630],
                        [-10477, -11482],
                        [-10225, -11280],
                        [ -9928, -11023],
                        [ -9588, -10715],
                        [ -9199, -10349],
                        [ -8774,  -9938],
                        [ -8387,  -9553],
                        [ -8119,  -9277],
                        [ -7999,  -9141],
                        [ -8031,  -9150],
                        [ -8218,  -9310],
                        [ -8532,  -9593],
                        [ -8860,  -9888],
                        [ -9095, -10086],
                        [ -9223, -10173],
                        [ -9253, -10159],
                        [ -9191, -10045],
                        [ -9041,  -9836],
                        [ -8809,  -9541],
                        [ -8504,  -9167],
                        [ -8131,  -8724],
                        [ -7699,  -8218],
                        [ -7220,  -7663],
                        [ -6699,  -7064],
                        [ -6147,  -6433],
                        [ -5574,  -5778],
                        [ -4985,  -5107],
                        [ -4388,  -4427],
                        [ -3791,  -3747],
                        [ -3201,  -3075],
                        [ -2621,  -2416],
                        [ -2056,  -1776],
                        [ -1510,  -1158],
                        [  -986,   -566],
                        [  -486,     -3],
                        [   -13,    527],
                        [   432,   1021],
                        [   849,   1478],
                        [  1238,   1899],
                        [  1600,   2283],
                        [  1935,   2638],
                        [  2246,   2965],
                        [  2533,   3271],
                        [  2799,   3557],
                        [  3049,   3825],
                        [  3282,   4078],
                        [  3502,   4314],
                        [  3712,   4536],
                        [  3911,   4739],
                        [  4105,   4925],
                        [  4292,   5093],
                        [  4476,   5246],
                        [  4657,   5386],
                        [  4837,   5513],
                        [  5016,   5636],
                        [  5195,   5756],
                        [  5376,   5875],
                        [  5558,   5996],
                        [  5741,   6120],
                        [  5925,   6247],
                        [  6108,   6379],
                        [  6292,   6515],
                        [  6474,   6657],
                        [  6656,   6802],
                        [  6835,   6952],
                        [  7012,   7103],
                        [  7184,   7256],
                        [  7352,   7409],
                        [  7514,   7560],
                        [  7670,   7707],
                        [  7824,   7850],
                        [  7973,   7985],
                        [  8116,   8110],
                        [  8251,   8223],
                        [  8366,   8320],
                        [  8461,   8404],
                        [  8524,   8470],
                        [  8552,   8514],
                        [  8544,   8535],
                        [  8500,   8533],
                        [  8418,   8503],
                        [  8300,   8446],
                        [  8152,   8366],
                        [  7971,   8260],
                        [  7747,   8113],
                        [  7478,   7924],
                        [  7149,   7677],
                        [  6760,   7369],
                        [  6332,   7020],
                        [  5863,   6628],
                        [  5367,   6206],
                        [  4845,   5754],
                        [  4314,   5286],
                        [  3771,   4801],
                        [  3231,   4312],
                        [  2695,   3819],
                        [  2173,   3331],
                        [  1667,   2852],
                        [  1185,   2386],
                        [   726,   1938],
                        [   297,   1511],
                        [   -99,   1108],
                        [  -462,    732],
                        [  -788,    384],
                        [ -1080,     65],
                        [ -1334,   -222],
                        [ -1553,   -478],
                        [ -1736,   -701],
                        [ -1885,   -895],
                        [ -2000,  -1056],
                        [ -2083,  -1190],
                        [ -2135,  -1293],
                        [ -2163,  -1368],
                        [ -2167,  -1418],
                        [ -2155,  -1442],
                        [ -2126,  -1443],
                        [ -2087,  -1425],
                        [ -2040,  -1389],
                        [ -1987,  -1340],
                        [ -1931,  -1280],
                        [ -1870,  -1216],
                        [ -1806,  -1146],
                        [ -1741,  -1077],
                        [ -1677,  -1010],
                        [ -1619,   -950],
                        [ -1564,   -895],
                        [ -1512,   -848],
                        [ -1476,   -820],
                        [ -1439,   -797],
                        [ -1317,   -693],
                        [ -1031,   -430],
                        [  -561,     14],
                        [    90,    640],
                        [   934,   1458],
                        [  1940,   2441],
                        [  2981,   3459],
                        [  3928,   4386],
                        [  4763,   5202],
                        [  5493,   5910],
                        [  6113,   6505],
                        [  6621,   6983],
                        [  7018,   7347],
                        [  7307,   7599],
                        [  7490,   7742],
                        [  7572,   7781],
                        [  7558,   7723],
                        [  7456,   7573],
                        [  7274,   7339],
                        [  7018,   7027],
                        [  6696,   6647],
                        [  6317,   6206],
                        [  5888,   5712],
                        [  5419,   5175],
                        [  4916,   4602],
                        [  4386,   4002],
                        [  3837,   3379],
                        [  3275,   2745],
                        [  2707,   2104],
                        [  2141,   1467],
                        [  1580,    839],
                        [  1030,    232],
                        [   497,   -353],
                        [   -17,   -912],
                        [  -507,  -1442],
                        [  -971,  -1949],
                        [ -1406,  -2429],
                        [ -1811,  -2886],
                        [ -2183,  -3317],
                        [ -2523,  -3720],
                        [ -2830,  -4093],
                        [ -3102,  -4431],
                        [ -3341,  -4732],
                        [ -3545,  -4994],
                        [ -3715,  -5215],
                        [ -3850,  -5394],
                        [ -3951,  -5533],
                        [ -4021,  -5632],
                        [ -4060,  -5694],
                        [ -4070,  -5723],
                        [ -4053,  -5722],
                        [ -4011,  -5691],
                        [ -3945,  -5632],
                        [ -3856,  -5552],
                        [ -3749,  -5450],
                        [ -3624,  -5332],
                        [ -3486,  -5198],
                        [ -3337,  -5052],
                        [ -3182,  -4897],
                        [ -3023,  -4736],
                        [ -2862,  -4571],
                        [ -2706,  -4406],
                        [ -2554,  -4242],
                        [ -2417,  -4083],
                        [ -2299,  -3930],
                        [ -2205,  -3785],
                        [ -2139,  -3650],
                        [ -2095,  -3525],
                        [ -2079,  -3414],
                        [ -2073,  -3317],
                        [ -2079,  -3235],
                        [ -2091,  -3169],
                        [ -2108,  -3118],
                        [ -2137,  -3086],
                        [ -2175,  -3075],
                        [ -2243,  -3101],
                        [ -2337,  -3161],
                        [ -2459,  -3257],
                        [ -2610,  -3387],
                        [ -2755,  -3516],
                        [ -2897,  -3647],
                        [ -3014,  -3758],
                        [ -3109,  -3849],
                        [ -3189,  -3928],
                        [ -3251,  -3993],
                        [ -3304,  -4051],
                        [ -3344,  -4099],
                        [ -3383,  -4145],
                        [ -3416,  -4185],
                        [ -3449,  -4226],
                        [ -3482,  -4265],
                        [ -3517,  -4306],
                        [ -3551,  -4347],
                        [ -3589,  -4389],
                        [ -3626,  -4430],
                        [ -3664,  -4470],
                        [ -3701,  -4507],
                        [ -3733,  -4540],
                        [ -3761,  -4566],
                        [ -3779,  -4584],
                        [ -3785,  -4591],
                        [ -3777,  -4585],
                        [ -3751,  -4562],
                        [ -3705,  -4521],
                        [ -3638,  -4458],
                        [ -3546,  -4373],
                        [ -3426,  -4263],
                        [ -3277,  -4128],
                        [ -3096,  -3966],
                        [ -2880,  -3776],
                        [ -2628,  -3556],
                        [ -2339,  -3305],
                        [ -2013,  -3023],
                        [ -1650,  -2707],
                        [ -1252,  -2358],
                        [  -823,  -1974],
                        [  -366,  -1559],
                        [   120,  -1112],
                        [   633,   -635],
                        [  1164,   -131],
                        [  1710,    395],
                        [  2276,    951],
                        [  2837,   1509],
                        [  3294,   1971],
                        [  3565,   2259],
                        [  3638,   2355],
                        [  3500,   2247],
                        [  3136,   1917],
                        [  2560,   1377],
                        [  1907,    764],
                        [  1303,    202],
                        [   764,   -291],
                        [   284,   -720],
                        [  -132,  -1077],
                        [  -482,  -1359],
                        [  -762,  -1567],
                        [  -975,  -1700],
                        [ -1120,  -1762],
                        [ -1201,  -1756],
                        [ -1218,  -1684],
                        [ -1177,  -1552],
                        [ -1083,  -1363],
                        [  -940,  -1124],
                        [  -751,   -838],
                        [  -521,   -512],
                        [  -256,   -152],
                        [    38,    237],
                        [   361,    651],
                        [   705,   1083],
                        [  1069,   1531],
                        [  1448,   1989],
                        [  1839,   2452],
                        [  2238,   2916],
                        [  2645,   3372],
                        [  3056,   3817],
                        [  3469,   4248],
                        [  3882,   4662],
                        [  4297,   5066],
                        [  4708,   5458],
                        [  5119,   5850],
                        [  5527,   6241],
                        [  5933,   6632],
                        [  6338,   7027],
                        [  6738,   7419],
                        [  7136,   7811],
                        [  7530,   8198],
                        [  7920,   8579],
                        [  8303,   8953],
                        [  8680,   9321],
                        [  9049,   9678],
                        [  9409,  10025],
                        [  9758,  10361],
                        [ 10097,  10688],
                        [ 10423,  11004],
                        [ 10736,  11306],
                        [ 11031,  11595],
                        [ 11308,  11870],
                        [ 11565,  12129],
                        [ 11801,  12374],
                        [ 12013,  12601],
                        [ 12201,  12811],
                        [ 12366,  13000],
                        [ 12507,  13169],
                        [ 12621,  13317],
                        [ 12708,  13442],
                        [ 12773,  13542],
                        [ 12814,  13618],
                        [ 12841,  13665],
                        [ 12852,  13686],
                        [ 12850,  13677],
                        [ 12833,  13639],
                        [ 12790,  13568],
                        [ 12721,  13466],
                        [ 12609,  13333],
                        [ 12456,  13167],
                        [ 12261,  12972],
                        [ 12023,  12745],
                        [ 11769,  12512],
                        [ 11499,  12271],
                        [ 11234,  12045],
                        [ 10976,  11834],
                        [ 10711,  11620],
                        [ 10441,  11405],
                        [ 10121,  11143],
                        [  9757,  10839],
                        [  9340,  10483],
                        [  8872,  10076],
                        [  8367,   9631],
                        [  7827,   9148],
                        [  7265,   8639],
                        [  6682,   8106],
                        [  6093,   7562],
                        [  5499,   7007],
                        [  4912,   6452],
                        [  4333,   5898],
                        [  3773,   5357],
                        [  3233,   4827],
                        [  2721,   4319],
                        [  2239,   3832],
                        [  1792,   3372],
                        [  1379,   2940],
                        [  1003,   2541],
                        [   665,   2173],
                        [   364,   1838],
                        [    98,   1537],
                        [  -132,   1270],
                        [  -329,   1035],
                        [  -494,    832],
                        [  -628,    661],
                        [  -734,    518],
                        [  -814,    404],
                        [  -872,    316],
                        [  -908,    254],
                        [  -931,    211],
                        [  -942,    189],
                        [  -948,    179],
                        [  -951,    180],
                        [  -956,    186],
                        [  -960,    196],
                        [  -968,    205],
                        [  -982,    210],
                        [ -1004,    209],
                        [ -1032,    202],
                        [ -1066,    189],
                        [ -1118,    156],
                        [ -1159,    132],
                        [ -1090,    216],
                        [  -851,    466],
                        [  -431,    892],
                        [   172,   1503],
                        [   989,   2325],
                        [  2001,   3343],
                        [  3074,   4422],
                        [  4085,   5436],
                        [  5017,   6371],
                        [  5876,   7225],
                        [  6650,   7986],
                        [  7331,   8647],
                        [  7919,   9202],
                        [  8409,   9654],
                        [  8802,  10000],
                        [  9097,  10242],
                        [  9297,  10381],
                        [  9407,  10424],
                        [  9432,  10374],
                        [  9375,  10236],
                        [  9246,  10018],
                        [  9049,   9726],
                        [  8792,   9370],
                        [  8483,   8956],
                        [  8129,   8495],
                        [  7737,   7993],
                        [  7316,   7458],
                        [  6871,   6900],
                        [  6411,   6325],
                        [  5942,   5748],
                        [  5470,   5176],
                        [  5000,   4622],
                        [  4539,   4093],
                        [  4091,   3590],
                        [  3659,   3119],
                        [  3247,   2672],
                        [  2858,   2252],
                        [  2492,   1852],
                        [  2153,   1473],
                        [  1842,   1117],
                        [  1558,    786],
                        [  1302,    482],
                        [  1075,    206],
                        [   876,    -44],
                        [   704,   -265],
                        [   560,   -458],
                        [   441,   -625],
                        [   348,   -763],
                        [   276,   -873],
                        [   226,   -960],
                        [   193,  -1025],
                        [   179,  -1065],
                        [   177,  -1086],
                        [   190,  -1091],
                        [   214,  -1081],
                        [   245,  -1060],
                        [   284,  -1031],
                        [   325,   -998],
                        [   366,   -960],
                        [   402,   -922],
                        [   433,   -887],
                        [   455,   -856],
                        [   466,   -831],
                        [   452,   -815],
                        [   414,   -808],
                        [   344,   -812],
                        [   240,   -826],
                        [   104,   -853],
                        [   -63,   -892],
                        [  -241,   -942],
                        [  -431,  -1003],
                        [  -622,  -1077],
                        [  -813,  -1160],
                        [ -1018,  -1271],
                        [ -1235,  -1405],
                        [ -1502,  -1601],
                        [ -1814,  -1857],
                        [ -2173,  -2170],
                        [ -2577,  -2542],
                        [ -2984,  -2926],
                        [ -3393,  -3323],
                        [ -3749,  -3677],
                        [ -4053,  -3988],
                        [ -4305,  -4255],
                        [ -4500,  -4474],
                        [ -4646,  -4651],
                        [ -4739,  -4781],
                        [ -4787,  -4869],
                        [ -4786,  -4915],
                        [ -4747,  -4922],
                        [ -4664,  -4890],
                        [ -4545,  -4822],
                        [ -4389,  -4718],
                        [ -4203,  -4583],
                        [ -3985,  -4413],
                        [ -3740,  -4215],
                        [ -3469,  -3986],
                        [ -3174,  -3731],
                        [ -2855,  -3448],
                        [ -2513,  -3140],
                        [ -2147,  -2806],
                        [ -1758,  -2450],
                        [ -1347,  -2069],
                        [  -916,  -1667],
                        [  -465,  -1243],
                        [     3,   -800],
                        [   488,   -338],
                        [   985,    141],
                        [  1492,    633],
                        [  2010,   1137],
                        [  2536,   1652],
                        [  3075,   2177],
                        [  3625,   2709],
                        [  4184,   3250],
                        [  4753,   3796],
                        [  5324,   4348],
                        [  5897,   4902],
                        [  6468,   5456],
                        [  7036,   6009],
                        [  7591,   6554],
                        [  8132,   7088],
                        [  8664,   7618],
                        [  9149,   8106],
                        [  9494,   8460],
                        [  9649,   8629],
                        [  9610,   8608],
                        [  9361,   8382],
                        [  8871,   7916],
                        [  8144,   7216],
                        [  7306,   6404],
                        [  6468,   5596],
                        [  5642,   4803],
                        [  4828,   4026],
                        [  4041,   3283],
                        [  3290,   2585],
                        [  2584,   1938],
                        [  1928,   1346],
                        [  1330,    817],
                        [   793,    353],
                        [   321,    -44],
                        [   -86,   -372],
                        [  -427,   -631],
                        [  -700,   -823],
                        [  -906,   -947],
                        [ -1049,  -1005],
                        [ -1129,  -1003],
                        [ -1151,   -943],
                        [ -1116,   -826],
                        [ -1027,   -659],
                        [  -889,   -444],
                        [  -704,   -188],
                        [  -478,    105],
                        [  -212,    429],
                        [    87,    769],
                        [   417,   1125],
                        [   774,   1484],
                        [  1155,   1848],
                        [  1554,   2215],
                        [  1970,   2584],
                        [  2399,   2967],
                        [  2839,   3361],
                        [  3285,   3768],
                        [  3735,   4186],
                        [  4186,   4612],
                        [  4636,   5042],
                        [  5081,   5476],
                        [  5518,   5911],
                        [  5943,   6343],
                        [  6354,   6773],
                        [  6747,   7192],
                        [  7122,   7601],
                        [  7475,   7992],
                        [  7802,   8363],
                        [  8104,   8709],
                        [  8376,   9031],
                        [  8616,   9322],
                        [  8821,   9581],
                        [  8989,   9809],
                        [  9119,  10003],
                        [  9211,  10162],
                        [  9263,  10285],
                        [  9277,  10372],
                        [  9251,  10423],
                        [  9188,  10436],
                        [  9085,  10411],
                        [  8952,  10349],
                        [  8789,  10249],
                        [  8607,  10111],
                        [  8406,   9937],
                        [  8193,   9726],
                        [  7967,   9481],
                        [  7721,   9201],
                        [  7455,   8886],
                        [  7154,   8539],
                        [  6822,   8163],
                        [  6459,   7765],
                        [  6069,   7344],
                        [  5696,   6951],
                        [  5341,   6582],
                        [  5033,   6267],
                        [  4772,   6005],
                        [  4548,   5786],
                        [  4362,   5611],
                        [  4149,   5411],
                        [  3913,   5194],
                        [  3629,   4930],
                        [  3299,   4624],
                        [  2932,   4283],
                        [  2531,   3907],
                        [  2103,   3505],
                        [  1649,   3078],
                        [  1183,   2635],
                        [   703,   2177],
                        [   220,   1713],
                        [  -265,   1245],
                        [  -742,    780],
                        [ -1211,    319],
                        [ -1663,   -129],
                        [ -2098,   -567],
                        [ -2510,   -986],
                        [ -2898,  -1388],
                        [ -3262,  -1768],
                        [ -3602,  -2126],
                        [ -3916,  -2460],
                        [ -4207,  -2771],
                        [ -4477,  -3060],
                        [ -4725,  -3325],
                        [ -4950,  -3567],
                        [ -5155,  -3788],
                        [ -5337,  -3988],
                        [ -5497,  -4169],
                        [ -5638,  -4331],
                        [ -5759,  -4475],
                        [ -5871,  -4606],
                        [ -5973,  -4722],
                        [ -6074,  -4830],
                        [ -6177,  -4929],
                        [ -6284,  -5026],
                        [ -6395,  -5119],
                        [ -6512,  -5214],
                        [ -6636,  -5311],
                        [ -6767,  -5412],
                        [ -6901,  -5514],
                        [ -7040,  -5619],
                        [ -7190,  -5733],
                        [ -7313,  -5822],
                        [ -7337,  -5810],
                        [ -7229,  -5670],
                        [ -6988,  -5399],
                        [ -6599,  -4983],
                        [ -6024,  -4380],
                        [ -5259,  -3591],
                        [ -4410,  -2721],
                        [ -3572,  -1866],
                        [ -2753,  -1034],
                        [ -1951,   -230],
                        [ -1183,    530],
                        [  -461,   1233],
                        [   212,   1876],
                        [   830,   2451],
                        [  1384,   2954],
                        [  1873,   3382],
                        [  2295,   3733],
                        [  2651,   4010],
                        [  2940,   4210],
                        [  3164,   4339],
                        [  3326,   4397],
                        [  3428,   4392],
                        [  3477,   4324],
                        [  3475,   4202],
                        [  3429,   4032],
                        [  3343,   3818],
                        [  3222,   3568],
                        [  3070,   3287],
                        [  2894,   2983],
                        [  2698,   2668],
                        [  2489,   2349],
                        [  2268,   2039],
                        [  2041,   1744],
                        [  1811,   1465],
                        [  1582,   1210],
                        [  1355,    968],
                        [  1133,    743],
                        [   919,    523],
                        [   713,    310],
                        [   514,    104],
                        [   327,    -95],
                        [   149,   -288],
                        [   -20,   -473],
                        [  -176,   -654],
                        [  -325,   -832],
                        [  -464,  -1008],
                        [  -596,  -1181],
                        [  -720,  -1350],
                        [  -839,  -1513],
                        [  -955,  -1669],
                        [ -1067,  -1818],
                        [ -1176,  -1961],
                        [ -1285,  -2096],
                        [ -1393,  -2227],
                        [ -1501,  -2355],
                        [ -1610,  -2481],
                        [ -1723,  -2608],
                        [ -1839,  -2737],
                        [ -1961,  -2868],
                        [ -2090,  -3003],
                        [ -2227,  -3143],
                        [ -2375,  -3288],
                        [ -2533,  -3439],
                        [ -2713,  -3597],
                        [ -2914,  -3761],
                        [ -3143,  -3931],
                        [ -3397,  -4106],
                        [ -3677,  -4287],
                        [ -3980,  -4470],
                        [ -4285,  -4652],
                        [ -4595,  -4834],
                        [ -4895,  -5014],
                        [ -5183,  -5192],
                        [ -5482,  -5393],
                        [ -5788,  -5612],
                        [ -6147,  -5897],
                        [ -6553,  -6243],
                        [ -7008,  -6651],
                        [ -7510,  -7120],
                        [ -8012,  -7601],
                        [ -8514,  -8095],
                        [ -8941,  -8525],
                        [ -9293,  -8892],
                        [ -9567,  -9192],
                        [ -9760,  -9420],
                        [ -9873,  -9577],
                        [ -9904,  -9660],
                        [ -9859,  -9673],
                        [ -9736,  -9614],
                        [ -9544,  -9490],
                        [ -9282,  -9297],
                        [ -8957,  -9046],
                        [ -8571,  -8733],
                        [ -8133,  -8366],
                        [ -7643,  -7946],
                        [ -7113,  -7482],
                        [ -6542,  -6971],
                        [ -5939,  -6424],
                        [ -5305,  -5840],
                        [ -4644,  -5228],
                        [ -3960,  -4588],
                        [ -3258,  -3928],
                        [ -2539,  -3248],
                        [ -1810,  -2556],
                        [ -1074,  -1853],
                        [  -340,  -1146],
                        [   388,   -436],
                        [  1103,    271],
                        [  1799,    969],
                        [  2477,   1657],
                        [  3131,   2329],
                        [  3770,   2983],
                        [  4388,   3616],
                        [  4988,   4226],
                        [  5567,   4809],
                        [  6122,   5367],
                        [  6648,   5894],
                        [  7145,   6390],
                        [  7610,   6853],
                        [  8036,   7275],
                        [  8424,   7659],
                        [  8777,   8005],
                        [  9059,   8279],
                        [  9219,   8431],
                        [  9241,   8444],
                        [  9130,   8324],
                        [  8867,   8051],
                        [  8409,   7583],
                        [  7744,   6909],
                        [  6957,   6112],
                        [  6124,   5267],
                        [  5250,   4385],
                        [  4346,   3475],
                        [  3428,   2558],
                        [  2513,   1649],
                        [  1611,    758],
                        [   734,   -102],
                        [  -107,   -922],
                        [  -902,  -1692],
                        [ -1643,  -2404],
                        [ -2325,  -3055],
                        [ -2942,  -3638],
                        [ -3491,  -4149],
                        [ -3968,  -4587],
                        [ -4373,  -4951],
                        [ -4705,  -5240],
                        [ -4966,  -5456],
                        [ -5156,  -5600],
                        [ -5278,  -5675],
                        [ -5334,  -5683],
                        [ -5327,  -5627],
                        [ -5261,  -5518],
                        [ -5141,  -5356],
                        [ -4970,  -5160],
                        [ -4755,  -4933],
                        [ -4499,  -4684],
                        [ -4207,  -4418],
                        [ -3887,  -4138],
                        [ -3540,  -3848],
                        [ -3174,  -3538],
                        [ -2793,  -3213],
                        [ -2402,  -2870],
                        [ -2005,  -2514],
                        [ -1608,  -2148],
                        [ -1215,  -1777],
                        [  -831,  -1401],
                        [  -461,  -1023],
                        [  -107,   -644],
                        [   227,   -267],
                        [   536,     99],
                        [   819,    454],
                        [  1071,    786],
                        [  1292,   1093],
                        [  1476,   1367],
                        [  1626,   1607],
                        [  1735,   1809],
                        [  1803,   1970],
                        [  1831,   2092],
                        [  1814,   2172],
                        [  1757,   2210],
                        [  1657,   2206],
                        [  1517,   2160],
                        [  1337,   2074],
                        [  1120,   1946],
                        [   867,   1779],
                        [   587,   1575],
                        [   283,   1335],
                        [   -37,   1061],
                        [  -367,    756],
                        [  -702,    422],
                        [ -1039,     61],
                        [ -1382,   -326],
                        [ -1730,   -736],
                        [ -2091,  -1165],
                        [ -2464,  -1609],
                        [ -2840,  -2055],
                        [ -3220,  -2503],
                        [ -3547,  -2894],
                        [ -3823,  -3230],
                        [ -4022,  -3484],
                        [ -4145,  -3655],
                        [ -4194,  -3749],
                        [ -4171,  -3764],
                        [ -4152,  -3777],
                        [ -4131,  -3784],
                        [ -4143,  -3817],
                        [ -4186,  -3876],
                        [ -4258,  -3958],
                        [ -4358,  -4063],
                        [ -4486,  -4193],
                        [ -4640,  -4343],
                        [ -4815,  -4512],
                        [ -5011,  -4699],
                        [ -5223,  -4899],
                        [ -5451,  -5113],
                        [ -5688,  -5335],
                        [ -5935,  -5566],
                        [ -6184,  -5800],
                        [ -6437,  -6039],
                        [ -6687,  -6278],
                        [ -6936,  -6517],
                        [ -7181,  -6754],
                        [ -7423,  -6988],
                        [ -7663,  -7216],
                        [ -7900,  -7442],
                        [ -8134,  -7660],
                        [ -8366,  -7875],
                        [ -8592,  -8084],
                        [ -8813,  -8288],
                        [ -9021,  -8486],
                        [ -9217,  -8679],
                        [ -9399,  -8865],
                        [ -9568,  -9046],
                        [ -9731,  -9222],
                        [ -9887,  -9391],
                        [-10049,  -9556],
                        [-10214,  -9716],
                        [-10381,  -9873],
                        [-10552, -10026],
                        [-10724, -10176],
                        [-10898, -10324],
                        [-11072, -10467],
                        [-11241, -10602],
                        [-11405, -10729],
                        [-11566, -10850],
                        [-11695, -10939],
                        [-11768, -10970],
                        [-11784, -10944],
                        [-11741, -10862],
                        [-11624, -10707],
                        [-11382, -10430],
                        [-10987, -10005],
                        [-10489,  -9481],
                        [ -9938,  -8910],
                        [ -9340,  -8297],
                        [ -8697,  -7650],
                        [ -8027,  -6983],
                        [ -7341,  -6312],
                        [ -6645,  -5642],
                        [ -5952,  -4983],
                        [ -5267,  -4344],
                        [ -4600,  -3732],
                        [ -3957,  -3152],
                        [ -3343,  -2607],
                        [ -2761,  -2102],
                        [ -2214,  -1639],
                        [ -1705,  -1219],
                        [ -1235,   -843],
                        [  -803,   -509],
                        [  -410,   -219],
                        [   -54,     30],
                        [   262,    241],
                        [   543,    414],
                        [   789,    553],
                        [  1003,    661],
                        [  1185,    748],
                        [  1337,    817],
                        [  1463,    879],
                        [  1565,    935],
                        [  1641,    990],
                        [  1698,   1046],
                        [  1733,   1096],
                        [  1750,   1145],
                        [  1749,   1177],
                        [  1731,   1194],
                        [  1697,   1195],
                        [  1648,   1183],
                        [  1584,   1151],
                        [  1509,   1102],
                        [  1419,   1027],
                        [  1317,    930],
                        [  1202,    806],
                        [  1074,    658],
                        [   934,    492],
                        [   780,    306],
                        [   614,    108],
                        [   438,   -100],
                        [   249,   -316],
                        [    51,   -540],
                        [  -155,   -769],
                        [  -371,  -1005],
                        [  -594,  -1246],
                        [  -824,  -1493],
                        [ -1060,  -1743],
                        [ -1301,  -1997],
                        [ -1546,  -2253],
                        [ -1795,  -2511],
                        [ -2047,  -2770],
                        [ -2303,  -3029],
                        [ -2567,  -3285],
                        [ -2839,  -3538],
                        [ -3121,  -3787],
                        [ -3411,  -4029],
                        [ -3710,  -4264],
                        [ -4014,  -4487],
                        [ -4310,  -4696],
                        [ -4600,  -4892],
                        [ -4872,  -5074],
                        [ -5124,  -5241],
                        [ -5385,  -5423],
                        [ -5650,  -5618],
                        [ -5959,  -5865],
                        [ -6307,  -6164],
                        [ -6701,  -6517],
                        [ -7137,  -6925],
                        [ -7574,  -7344],
                        [ -8015,  -7777],
                        [ -8383,  -8148],
                        [ -8678,  -8457],
                        [ -8898,  -8699],
                        [ -9037,  -8872],
                        [ -9094,  -8969],
                        [ -9070,  -8992],
                        [ -8964,  -8940],
                        [ -8780,  -8815],
                        [ -8521,  -8619],
                        [ -8187,  -8353],
                        [ -7787,  -8021],
                        [ -7322,  -7626],
                        [ -6803,  -7176],
                        [ -6230,  -6671],
                        [ -5617,  -6119],
                        [ -4963,  -5523],
                        [ -4279,  -4893],
                        [ -3567,  -4228],
                        [ -2835,  -3541],
                        [ -2085,  -2832],
                        [ -1325,  -2109],
                        [  -557,  -1377],
                        [   209,   -643],
                        [   971,     91],
                        [  1713,    816],
                        [  2433,   1530],
                        [  3121,   2225],
                        [  3773,   2900],
                        [  4388,   3547],
                        [  4963,   4166],
                        [  5504,   4748],
                        [  6008,   5293],
                        [  6480,   5800],
                        [  6914,   6263],
                        [  7311,   6682],
                        [  7667,   7056],
                        [  7981,   7383],
                        [  8253,   7662],
                        [  8479,   7889],
                        [  8661,   8065],
                        [  8799,   8190],
                        [  8881,   8253],
                        [  8914,   8260],
                        [  8910,   8225],
                        [  8873,   8153],
                        [  8786,   8027],
                        [  8606,   7805],
                        [  8290,   7446],
                        [  7857,   6969],
                        [  7342,   6407],
                        [  6752,   5770],
                        [  6098,   5070],
                        [  5397,   4326],
                        [  4662,   3551],
                        [  3907,   2759],
                        [  3144,   1964],
                        [  2387,   1178],
                        [  1646,    414],
                        [   932,   -323],
                        [   252,  -1021],
                        [  -385,  -1671],
                        [  -974,  -2271],
                        [ -1510,  -2815],
                        [ -1991,  -3298],
                        [ -2414,  -3719],
                        [ -2778,  -4076],
                        [ -3082,  -4368],
                        [ -3327,  -4597],
                        [ -3514,  -4765],
                        [ -3646,  -4873],
                        [ -3725,  -4929],
                        [ -3753,  -4933],
                        [ -3738,  -4901],
                        [ -3680,  -4835],
                        [ -3586,  -4745],
                        [ -3462,  -4634],
                        [ -3311,  -4509],
                        [ -3139,  -4375],
                        [ -2950,  -4226],
                        [ -2750,  -4067],
                        [ -2543,  -3895],
                        [ -2335,  -3716],
                        [ -2132,  -3532],
                        [ -1937,  -3347],
                        [ -1754,  -3158],
                        [ -1587,  -2970],
                        [ -1440,  -2780],
                        [ -1314,  -2592],
                        [ -1213,  -2411],
                        [ -1138,  -2240],
                        [ -1092,  -2088],
                        [ -1077,  -1959],
                        [ -1092,  -1859],
                        [ -1138,  -1791],
                        [ -1218,  -1757],
                        [ -1331,  -1756],
                        [ -1476,  -1790],
                        [ -1652,  -1859],
                        [ -1859,  -1961],
                        [ -2095,  -2096],
                        [ -2357,  -2263],
                        [ -2644,  -2459],
                        [ -2952,  -2683],
                        [ -3279,  -2933],
                        [ -3618,  -3205],
                        [ -3967,  -3499],
                        [ -4317,  -3808],
                        [ -4665,  -4134],
                        [ -5005,  -4469],
                        [ -5333,  -4812],
                        [ -5649,  -5162],
                        [ -5951,  -5517],
                        [ -6240,  -5870],
                        [ -6514,  -6216],
                        [ -6765,  -6544],
                        [ -6992,  -6852],
                        [ -7150,  -7090],
                        [ -7237,  -7257],
                        [ -7239,  -7337],
                        [ -7154,  -7328],
                        [ -6982,  -7226],
                        [ -6721,  -7032],
                        [ -6445,  -6816],
                        [ -6147,  -6572],
                        [ -5863,  -6335],
                        [ -5590,  -6102],
                        [ -5336,  -5881],
                        [ -5102,  -5672],
                        [ -4892,  -5480],
                        [ -4708,  -5307],
                        [ -4553,  -5155],
                        [ -4427,  -5024],
                        [ -4328,  -4916],
                        [ -4260,  -4831],
                        [ -4219,  -4769],
                        [ -4206,  -4730],
                        [ -4219,  -4713],
                        [ -4255,  -4719],
                        [ -4314,  -4745],
                        [ -4394,  -4792],
                        [ -4495,  -4859],
                        [ -4616,  -4943],
                        [ -4756,  -5045],
                        [ -4916,  -5163],
                        [ -5091,  -5294],
                        [ -5285,  -5441],
                        [ -5484,  -5597],
                        [ -5694,  -5766],
                        [ -5900,  -5943],
                        [ -6104,  -6128],
                        [ -6300,  -6317],
                        [ -6489,  -6511],
                        [ -6674,  -6704],
                        [ -6853,  -6898],
                        [ -7035,  -7088],
                        [ -7218,  -7274],
                        [ -7398,  -7453],
                        [ -7573,  -7622],
                        [ -7741,  -7781],
                        [ -7900,  -7926],
                        [ -8046,  -8055],
                        [ -8177,  -8166],
                        [ -8290,  -8253],
                        [ -8382,  -8317],
                        [ -8458,  -8361],
                        [ -8547,  -8417],
                        [ -8668,  -8503],
                        [ -8820,  -8619],
                        [ -8982,  -8750],
                        [ -9112,  -8849],
                        [ -9144,  -8855],
                        [ -9057,  -8745],
                        [ -8864,  -8535],
                        [ -8573,  -8228],
                        [ -8188,  -7833],
                        [ -7721,  -7361],
                        [ -7184,  -6825],
                        [ -6585,  -6232],
                        [ -5933,  -5594],
                        [ -5241,  -4922],
                        [ -4521,  -4225],
                        [ -3777,  -3512],
                        [ -3023,  -2789],
                        [ -2264,  -2065],
                        [ -1508,  -1348],
                        [  -761,   -642],
                        [   -29,     46],
                        [   683,    713],
                        [  1371,   1353],
                        [  2030,   1964],
                        [  2658,   2542],
                        [  3252,   3088],
                        [  3807,   3598],
                        [  4324,   4071],
                        [  4800,   4513],
                        [  5236,   4921],
                        [  5629,   5300],
                        [  5981,   5651],
                        [  6290,   5976],
                        [  6558,   6276],
                        [  6784,   6550],
                        [  6970,   6798],
                        [  7115,   7011],
                        [  7222,   7190],
                        [  7291,   7334],
                        [  7324,   7443],
                        [  7322,   7512],
                        [  7287,   7544],
                        [  7222,   7530],
                        [  7126,   7473],
                        [  7001,   7371],
                        [  6849,   7227],
                        [  6672,   7047],
                        [  6472,   6831],
                        [  6250,   6591],
                        [  6008,   6329],
                        [  5750,   6051],
                        [  5478,   5757],
                        [  5194,   5453],
                        [  4900,   5139],
                        [  4600,   4819],
                        [  4295,   4496],
                        [  3989,   4170],
                        [  3683,   3846],
                        [  3381,   3526],
                        [  3084,   3213],
                        [  2795,   2907],
                        [  2516,   2612],
                        [  2246,   2331],
                        [  1986,   2065],
                        [  1738,   1816],
                        [  1502,   1585],
                        [  1278,   1376],
                        [  1069,   1190],
                        [   878,   1031],
                        [   703,    895],
                        [   550,    784],
                        [   420,    698],
                        [   288,    609],
                        [   157,    521],
                        [     3,    407],
                        [  -172,    267],
                        [  -377,     93],
                        [  -613,   -117],
                        [  -855,   -339],
                        [ -1104,   -574],
                        [ -1302,   -765],
                        [ -1454,   -915],
                        [ -1551,  -1016],
                        [ -1593,  -1067],
                        [ -1572,  -1062],
                        [ -1492,  -1003],
                        [ -1349,   -885],
                        [ -1146,   -713],
                        [  -886,   -486],
                        [  -568,   -205],
                        [  -199,    125],
                        [   219,    501],
                        [   678,    921],
                        [  1178,   1380],
                        [  1708,   1870],
                        [  2264,   2391],
                        [  2841,   2934],
                        [  3433,   3497],
                        [  4034,   4071],
                        [  4641,   4653],
                        [  5248,   5237],
                        [  5852,   5818],
                        [  6443,   6389],
                        [  7019,   6948],
                        [  7565,   7488],
                        [  8080,   8007],
                        [  8554,   8498],
                        [  8986,   8960],
                        [  9374,   9389],
                        [  9715,   9783],
                        [ 10018,  10136],
                        [ 10281,  10447],
                        [ 10507,  10714],
                        [ 10694,  10936],
                        [ 10841,  11112],
                        [ 10948,  11239],
                        [ 11017,  11321],
                        [ 11045,  11354],
                        [ 11037,  11340],
                        [ 10990,  11277],
                        [ 10905,  11167],
                        [ 10818,  11044],
                        [ 10778,  10961],
                        [ 10814,  10944],
                        [ 10929,  11001],
                        [ 11110,  11120],
                        [ 11319,  11264],
                        [ 11476,  11353],
                        [ 11529,  11337],
                        [ 11482,  11217],
                        [ 11343,  11005],
                        [ 11122,  10708],
                        [ 10827,  10338],
                        [ 10471,   9906],
                        [ 10060,   9422],
                        [  9607,   8898],
                        [  9124,   8346],
                        [  8619,   7776],
                        [  8101,   7198],
                        [  7582,   6620],
                        [  7066,   6051],
                        [  6560,   5496],
                        [  6069,   4961],
                        [  5598,   4452],
                        [  5150,   3972],
                        [  4729,   3525],
                        [  4335,   3113],
                        [  3971,   2736],
                        [  3636,   2395],
                        [  3332,   2091],
                        [  3057,   1818],
                        [  2809,   1577],
                        [  2585,   1362],
                        [  2387,   1170],
                        [  2208,    998],
                        [  2047,    841],
                        [  1899,    692],
                        [  1763,    548],
                        [  1634,    409],
                        [  1510,    271],
                        [  1387,    137],
                        [  1263,      1],
                        [  1133,   -134],
                        [   997,   -272],
                        [   852,   -407],
                        [   693,   -543],
                        [   523,   -672],
                        [   338,   -799],
                        [   140,   -925],
                        [   -74,  -1051],
                        [  -301,  -1185],
                        [  -544,  -1327],
                        [  -800,  -1483],
                        [ -1069,  -1654],
                        [ -1351,  -1840],
                        [ -1645,  -2039],
                        [ -1945,  -2251],
                        [ -2253,  -2478],
                        [ -2566,  -2715],
                        [ -2883,  -2962],
                        [ -3200,  -3216],
                        [ -3517,  -3475],
                        [ -3829,  -3738],
                        [ -4137,  -4002],
                        [ -4435,  -4265],
                        [ -4721,  -4524],
                        [ -4994,  -4777],
                        [ -5251,  -5021],
                        [ -5486,  -5252],
                        [ -5699,  -5470],
                        [ -5885,  -5675],
                        [ -6043,  -5862],
                        [ -6168,  -6029],
                        [ -6257,  -6171],
                        [ -6306,  -6281],
                        [ -6315,  -6357],
                        [ -6258,  -6372],
                        [ -6138,  -6327],
                        [ -5948,  -6214],
                        [ -5691,  -6032],
                        [ -5354,  -5769],
                        [ -4939,  -5424],
                        [ -4493,  -5044],
                        [ -4014,  -4625],
                        [ -3530,  -4195],
                        [ -3040,  -3753],
                        [ -2560,  -3313],
                        [ -2089,  -2875],
                        [ -1640,  -2449],
                        [ -1211,  -2037],
                        [  -815,  -1648],
                        [  -450,  -1281],
                        [  -123,   -945],
                        [   166,   -639],
                        [   415,   -365],
                        [   623,   -126],
                        [   791,     78],
                        [   917,    245],
                        [  1004,    376],
                        [  1053,    471],
                        [  1065,    531],
                        [  1042,    557],
                        [   985,    553],
                        [   895,    516],
                        [   777,    454],
                        [   632,    365],
                        [   471,    254],
                        [   297,    124],
                        [   117,    -23],
                        [   -65,   -184],
                        [  -243,   -353],
                        [  -415,   -531],
                        [  -581,   -711],
                        [  -739,   -891],
                        [  -892,  -1066],
                        [ -1038,  -1233],
                        [ -1172,  -1385],
                        [ -1290,  -1521],
                        [ -1391,  -1637],
                        [ -1471,  -1729],
                        [ -1527,  -1794],
                        [ -1559,  -1832],
                        [ -1560,  -1833],
                        [ -1532,  -1801],
                        [ -1527,  -1786],
                        [ -1610,  -1857],
                        [ -1806,  -2037],
                        [ -2113,  -2326],
                        [ -2520,  -2719],
                        [ -2993,  -3179],
                        [ -3428,  -3600],
                        [ -3742,  -3902],
                        [ -3928,  -4076],
                        [ -3995,  -4129],
                        [ -3946,  -4064],
                        [ -3786,  -3887],
                        [ -3524,  -3607],
                        [ -3166,  -3231],
                        [ -2724,  -2770],
                        [ -2207,  -2234],
                        [ -1627,  -1635],
                        [  -993,   -981],
                        [  -316,   -283],
                        [   394,    450],
                        [  1128,   1207],
                        [  1877,   1981],
                        [  2633,   2762],
                        [  3387,   3541],
                        [  4132,   4310],
                        [  4860,   5064],
                        [  5565,   5796],
                        [  6241,   6500],
                        [  6883,   7172],
                        [  7486,   7808],
                        [  8048,   8405],
                        [  8563,   8958],
                        [  9031,   9466],
                        [  9449,   9928],
                        [  9817,  10344],
                        [ 10133,  10714],
                        [ 10398,  11042],
                        [ 10611,  11329],
                        [ 10775,  11572],
                        [ 10890,  11772],
                        [ 10957,  11927],
                        [ 10979,  12039],
                        [ 10958,  12105],
                        [ 10896,  12125],
                        [ 10797,  12095],
                        [ 10663,  12017],
                        [ 10496,  11891],
                        [ 10299,  11720],
                        [ 10076,  11511],
                        [  9828,  11263],
                        [  9561,  10991],
                        [  9276,  10695],
                        [  8978,  10383],
                        [  8669,  10056],
                        [  8354,   9722],
                        [  8034,   9380],
                        [  7713,   9038],
                        [  7395,   8698],
                        [  7081,   8362],
                        [  6776,   8035],
                        [  6484,   7720],
                        [  6205,   7417],
                        [  5945,   7132],
                        [  5705,   6866],
                        [  5488,   6621],
                        [  5298,   6399],
                        [  5135,   6201],
                        [  5003,   6030],
                        [  4895,   5883],
                        [  4817,   5767],
                        [  4760,   5679],
                        [  4721,   5617],
                        [  4701,   5581],
                        [  4697,   5571],
                        [  4699,   5571],
                        [  4706,   5584],
                        [  4713,   5602],
                        [  4722,   5625],
                        [  4716,   5636],
                        [  4694,   5632],
                        [  4653,   5612],
                        [  4593,   5571],
                        [  4544,   5541],
                        [  4501,   5518],
                        [  4474,   5509],
                        [  4461,   5513],
                        [  4472,   5537],
                        [  4503,   5581],
                        [  4561,   5649],
                        [  4642,   5736],
                        [  4750,   5848],
                        [  4882,   5982],
                        [  5038,   6138],
                        [  5218,   6312],
                        [  5415,   6504],
                        [  5631,   6712],
                        [  5860,   6932],
                        [  6099,   7163],
                        [  6346,   7399],
                        [  6596,   7640],
                        [  6845,   7880],
                        [  7092,   8117],
                        [  7332,   8347],
                        [  7564,   8568],
                        [  7780,   8774],
                        [  7980,   8964],
                        [  8153,   9136],
                        [  8300,   9287],
                        [  8414,   9414],
                        [  8496,   9515],
                        [  8543,   9591],
                        [  8554,   9639],
                        [  8538,   9658],
                        [  8493,   9648],
                        [  8420,   9605],
                        [  8321,   9530],
                        [  8197,   9423],
                        [  8046,   9283],
                        [  7872,   9110],
                        [  7677,   8906],
                        [  7464,   8674],
                        [  7226,   8409],
                        [  6979,   8121],
                        [  6797,   7889],
                        [  6755,   7789],
                        [  6880,   7849],
                        [  7173,   8072],
                        [  7635,   8462],
                        [  8234,   8987],
                        [  8851,   9528],
                        [  9386,   9983],
                        [  9825,  10340],
                        [ 10176,  10606],
                        [ 10440,  10779],
                        [ 10617,  10866],
                        [ 10712,  10867],
                        [ 10728,  10791],
                        [ 10673,  10643],
                        [ 10552,  10430],
                        [ 10372,  10160],
                        [ 10140,   9841],
                        [  9861,   9479],
                        [  9541,   9080],
                        [  9188,   8651],
                        [  8802,   8196],
                        [  8392,   7723],
                        [  7962,   7236],
                        [  7516,   6741],
                        [  7057,   6240],
                        [  6590,   5737],
                        [  6117,   5234],
                        [  5640,   4734],
                        [  5162,   4238],
                        [  4683,   3749],
                        [  4206,   3269],
                        [  3729,   2798],
                        [  3254,   2338],
                        [  2781,   1889],
                        [  2311,   1442],
                        [  1841,    999],
                        [  1374,    553],
                        [   907,    102],
                        [   441,   -349],
                        [   -24,   -804],
                        [  -488,  -1260],
                        [  -952,  -1716],
                        [ -1415,  -2166],
                        [ -1879,  -2610],
                        [ -2338,  -3043],
                        [ -2797,  -3465],
                        [ -3252,  -3874],
                        [ -3702,  -4271],
                        [ -4145,  -4656],
                        [ -4580,  -5032],
                        [ -5005,  -5398],
                        [ -5420,  -5757],
                        [ -5822,  -6104],
                        [ -6208,  -6439],
                        [ -6576,  -6763],
                        [ -6923,  -7074],
                        [ -7250,  -7369],
                        [ -7554,  -7649],
                        [ -7833,  -7911],
                        [ -8087,  -8154],
                        [ -8314,  -8377],
                        [ -8516,  -8577],
                        [ -8692,  -8755],
                        [ -8842,  -8908],
                        [ -8970,  -9036],
                        [ -9076,  -9138],
                        [ -9158,  -9212],
                        [ -9216,  -9258],
                        [ -9244,  -9276],
                        [ -9241,  -9267],
                        [ -9198,  -9228],
                        [ -9114,  -9158],
                        [ -8990,  -9056],
                        [ -8826,  -8925],
                        [ -8630,  -8765],
                        [ -8399,  -8580],
                        [ -8138,  -8366],
                        [ -7847,  -8126],
                        [ -7505,  -7834],
                        [ -7113,  -7494],
                        [ -6682,  -7112],
                        [ -6212,  -6689],
                        [ -5722,  -6242],
                        [ -5213,  -5773],
                        [ -4701,  -5295],
                        [ -4187,  -4809],
                        [ -3684,  -4329],
                        [ -3193,  -3855],
                        [ -2728,  -3399],
                        [ -2287,  -2960],
                        [ -1880,  -2548],
                        [ -1507,  -2164],
                        [ -1174,  -1812],
                        [  -880,  -1493],
                        [  -627,  -1211],
                        [  -417,   -965],
                        [  -246,   -757],
                        [  -116,   -586],
                        [   -24,   -451],
                        [    33,   -353],
                        [    58,   -285],
                        [    51,   -250],
                        [    19,   -242],
                        [   -38,   -259],
                        [  -109,   -297],
                        [  -193,   -352],
                        [  -280,   -422],
                        [  -369,   -502],
                        [  -453,   -589],
                        [  -528,   -680],
                        [  -591,   -769],
                        [  -640,   -855],
                        [  -675,   -931],
                        [  -694,   -995],
                        [  -691,  -1038],
                        [  -666,  -1063],
                        [  -616,  -1059],
                        [  -538,  -1027],
                        [  -434,   -964],
                        [  -303,   -871],
                        [  -136,   -737],
                        [    49,   -579],
                        [   163,   -487],
                        [   130,   -537],
                        [   -67,   -749],
                        [  -432,  -1126],
                        [  -973,  -1679],
                        [ -1663,  -2380],
                        [ -2369,  -3095],
                        [ -2977,  -3707],
                        [ -3474,  -4202],
                        [ -3868,  -4587],
                        [ -4158,  -4859],
                        [ -4341,  -5016],
                        [ -4422,  -5064],
                        [ -4404,  -5006],
                        [ -4296,  -4851],
                        [ -4103,  -4604],
                        [ -3834,  -4275],
                        [ -3499,  -3872],
                        [ -3104,  -3408],
                        [ -2661,  -2888],
                        [ -2178,  -2325],
                        [ -1662,  -1725],
                        [ -1123,  -1100],
                        [  -570,   -459],
                        [   -12,    189],
                        [   544,    837],
                        [  1090,   1476],
                        [  1619,   2100],
                        [  2126,   2702],
                        [  2606,   3278],
                        [  3052,   3816],
                        [  3462,   4314],
                        [  3833,   4762],
                        [  4162,   5161],
                        [  4448,   5510],
                        [  4691,   5805],
                        [  4889,   6059],
                        [  5043,   6269],
                        [  5154,   6442],
                        [  5223,   6577],
                        [  5252,   6676],
                        [  5243,   6737],
                        [  5198,   6762],
                        [  5120,   6753],
                        [  5012,   6704],
                        [  4878,   6620],
                        [  4721,   6503],
                        [  4544,   6356],
                        [  4349,   6181],
                        [  4141,   5981],
                        [  3922,   5765],
                        [  3696,   5536],
                        [  3467,   5297],
                        [  3235,   5051],
                        [  3006,   4803],
                        [  2780,   4556],
                        [  2559,   4314],
                        [  2347,   4081],
                        [  2146,   3858],
                        [  1959,   3649],
                        [  1788,   3454],
                        [  1634,   3278],
                        [  1502,   3121],
                        [  1393,   2984],
                        [  1314,   2868],
                        [  1264,   2776],
                        [  1250,   2705],
                        [  1272,   2657],
                        [  1324,   2631],
                        [  1405,   2628],
                        [  1501,   2644],
                        [  1611,   2680],
                        [  1727,   2732],
                        [  1846,   2800],
                        [  1978,   2893],
                        [  2121,   3009],
                        [  2286,   3156],
                        [  2470,   3334],
                        [  2654,   3520],
                        [  2838,   3715],
                        [  2987,   3880],
                        [  3100,   4015],
                        [  3179,   4123],
                        [  3222,   4197],
                        [  3237,   4248],
                        [  3222,   4270],
                        [  3187,   4274],
                        [  3127,   4255],
                        [  3055,   4222],
                        [  2967,   4172],
                        [  2871,   4112],
                        [  2763,   4038],
                        [  2652,   3957],
                        [  2533,   3864],
                        [  2413,   3767],
                        [  2289,   3660],
                        [  2163,   3548],
                        [  2035,   3429],
                        [  1905,   3305],
                        [  1772,   3175],
                        [  1636,   3040],
                        [  1496,   2898],
                        [  1353,   2751],
                        [  1206,   2597],
                        [  1053,   2436],
                        [   895,   2268],
                        [   730,   2092],
                        [   557,   1909],
                        [   375,   1719],
                        [   184,   1523],
                        [   -20,   1320],
                        [  -234,   1112],
                        [  -456,    898],
                        [  -684,    679],
                        [  -919,    453],
                        [ -1159,    221],
                        [ -1402,    -19],
                        [ -1649,   -266],
                        [ -1897,   -522],
                        [ -2143,   -781],
                        [ -2386,  -1045],
                        [ -2632,  -1321],
                        [ -2854,  -1580],
                        [ -2954,  -1725],
                        [ -2863,  -1681],
                        [ -2565,  -1434],
                        [ -2058,   -980],
                        [ -1321,   -296],
                        [  -382,    591],
                        [   620,   1538],
                        [  1563,   2425],
                        [  2435,   3236],
                        [  3237,   3972],
                        [  3961,   4625],
                        [  4598,   5186],
                        [  5146,   5654],
                        [  5602,   6029],
                        [  5967,   6309],
                        [  6242,   6497],
                        [  6428,   6596],
                        [  6526,   6608],
                        [  6543,   6539],
                        [  6480,   6393],
                        [  6341,   6172],
                        [  6130,   5883],
                        [  5852,   5531],
                        [  5514,   5121],
                        [  5118,   4661],
                        [  4672,   4153],
                        [  4180,   3604],
                        [  3647,   3018],
                        [  3078,   2401],
                        [  2478,   1759],
                        [  1851,   1096],
                        [  1203,    426],
                        [   536,   -249],
                        [  -145,   -924],
                        [  -838,  -1594],
                        [ -1536,  -2263],
                        [ -2240,  -2927],
                        [ -2945,  -3598],
                        [ -3647,  -4271],
                        [ -4344,  -4944],
                        [ -5034,  -5618],
                        [ -5712,  -6287],
                        [ -6377,  -6949],
                        [ -7026,  -7599],
                        [ -7657,  -8232],
                        [ -8267,  -8846],
                        [ -8855,  -9438],
                        [ -9418, -10004],
                        [ -9954, -10542],
                        [-10459, -11051],
                        [-10934, -11529],
                        [-11375, -11974],
                        [-11781, -12387],
                        [-12150, -12763],
                        [-12480, -13102],
                        [-12768, -13404],
                        [-13015, -13670],
                        [-13219, -13895],
                        [-13379, -14084],
                        [-13497, -14233],
                        [-13573, -14344],
                        [-13609, -14416],
                        [-13606, -14451],
                        [-13570, -14448],
                        [-13502, -14408],
                        [-13413, -14333],
                        [-13302, -14223],
                        [-13175, -14079],
                        [-13032, -13904],
                        [-12865, -13697],
                        [-12677, -13462],
                        [-12454, -13198],
                        [-12200, -12908],
                        [-11923, -12605],
                        [-11624, -12288],
                        [-11337, -11991],
                        [-11061, -11713],
                        [-10801, -11458],
                        [-10561, -11227],
                        [-10303, -10985],
                        [-10034, -10735],
                        [ -9723, -10446],
                        [ -9371, -10118],
                        [ -8991,  -9763],
                        [ -8581,  -9380],
                        [ -8154,  -8980],
                        [ -7711,  -8562],
                        [ -7265,  -8140],
                        [ -6816,  -7713],
                        [ -6376,  -7293],
                        [ -5943,  -6877],
                        [ -5529,  -6476],
                        [ -5133,  -6089],
                        [ -4760,  -5722],
                        [ -4409,  -5375],
                        [ -4088,  -5051],
                        [ -3793,  -4750],
                        [ -3526,  -4475],
                        [ -3284,  -4223],
                        [ -3067,  -3995],
                        [ -2872,  -3790],
                        [ -2696,  -3607],
                        [ -2536,  -3442],
                        [ -2390,  -3292],
                        [ -2257,  -3158],
                        [ -2131,  -3033],
                        [ -2011,  -2917],
                        [ -1893,  -2805],
                        [ -1774,  -2696],
                        [ -1646,  -2585],
                        [ -1507,  -2472],
                        [ -1352,  -2354],
                        [ -1181,  -2229],
                        [  -990,  -2091],
                        [  -778,  -1939],
                        [  -545,  -1770],
                        [  -292,  -1583],
                        [   -15,  -1372],
                        [   285,  -1137],
                        [   602,   -879],
                        [   938,   -600],
                        [  1301,   -288],
                        [  1653,     20],
                        [  1896,    225],
                        [  1970,    264],
                        [  1866,    128],
                        [  1571,   -194],
                        [  1060,   -730],
                        [   350,  -1463],
                        [  -426,  -2255],
                        [ -1149,  -2987],
                        [ -1816,  -3650],
                        [ -2428,  -4246],
                        [ -2975,  -4765],
                        [ -3450,  -5201],
                        [ -3853,  -5552],
                        [ -4184,  -5819],
                        [ -4443,  -6003],
                        [ -4632,  -6105],
                        [ -4755,  -6132],
                        [ -4815,  -6088],
                        [ -4818,  -5979],
                        [ -4769,  -5812],
                        [ -4674,  -5592],
                        [ -4539,  -5328],
                        [ -4370,  -5027],
                        [ -4175,  -4695],
                        [ -3958,  -4342],
                        [ -3727,  -3973],
                        [ -3487,  -3595],
                        [ -3245,  -3214],
                        [ -3004,  -2836],
                        [ -2770,  -2468],
                        [ -2546,  -2121],
                        [ -2336,  -1798],
                        [ -2143,  -1510],
                        [ -1967,  -1259],
                        [ -1811,  -1046],
                        [ -1676,   -874],
                        [ -1562,   -729],
                        [ -1469,   -614],
                        [ -1397,   -517],
                        [ -1344,   -438],
                        [ -1310,   -376],
                        [ -1294,   -329],
                        [ -1293,   -297],
                        [ -1307,   -277],
                        [ -1330,   -271],
                        [ -1363,   -275],
                        [ -1402,   -288],
                        [ -1445,   -306],
                        [ -1491,   -332],
                        [ -1535,   -361],
                        [ -1577,   -392],
                        [ -1615,   -424],
                        [ -1648,   -456],
                        [ -1672,   -485],
                        [ -1691,   -510],
                        [ -1701,   -530],
                        [ -1701,   -540],
                        [ -1692,   -541],
                        [ -1673,   -531],
                        [ -1643,   -511],
                        [ -1600,   -477],
                        [ -1544,   -430],
                        [ -1473,   -371],
                        [ -1385,   -298],
                        [ -1276,   -213],
                        [ -1142,   -116],
                        [  -981,     -9],
                        [  -791,    108],
                        [  -579,    233],
                        [  -349,    364],
                        [  -115,    500],
                        [   123,    637],
                        [   349,    778],
                        [   566,    920],
                        [   802,   1096],
                        [  1055,   1302],
                        [  1345,   1558],
                        [  1667,   1860],
                        [  2005,   2189],
                        [  2356,   2543],
                        [  2658,   2858],
                        [  2912,   3135],
                        [  3099,   3352],
                        [  3217,   3509],
                        [  3273,   3609],
                        [  3265,   3652],
                        [  3204,   3644],
                        [  3086,   3583],
                        [  2923,   3477],
                        [  2714,   3325],
                        [  2468,   3135],
                        [  2186,   2907],
                        [  1877,   2649],
                        [  1541,   2360],
                        [  1187,   2046],
                        [   815,   1708],
                        [   433,   1354],
                        [    41,    982],
                        [  -357,    600],
                        [  -761,    205],
                        [ -1166,   -195],
                        [ -1575,   -600],
                        [ -1982,  -1008],
                        [ -2388,  -1419],
                        [ -2787,  -1827],
                        [ -3179,  -2233],
                        [ -3560,  -2635],
                        [ -3928,  -3031],
                        [ -4286,  -3421],
                        [ -4631,  -3801],
                        [ -4970,  -4170],
                        [ -5300,  -4526],
                        [ -5622,  -4869],
                        [ -5935,  -5196],
                        [ -6238,  -5510],
                        [ -6530,  -5810],
                        [ -6809,  -6096],
                        [ -7074,  -6369],
                        [ -7327,  -6631],
                        [ -7560,  -6875],
                        [ -7776,  -7105],
                        [ -7982,  -7327],
                        [ -8138,  -7503],
                        [ -8154,  -7541],
                        [ -7989,  -7396],
                        [ -7638,  -7064],
                        [ -7092,  -6534],
                        [ -6315,  -5770],
                        [ -5324,  -4791],
                        [ -4249,  -3726],
                        [ -3195,  -2687],
                        [ -2173,  -1684],
                        [ -1185,   -721],
                        [  -252,    184],
                        [   616,   1016],
                        [  1411,   1770],
                        [  2125,   2439],
                        [  2753,   3017],
                        [  3290,   3499],
                        [  3733,   3885],
                        [  4082,   4173],
                        [  4337,   4366],
                        [  4497,   4462],
                        [  4566,   4467],
                        [  4546,   4383],
                        [  4441,   4212],
                        [  4255,   3963],
                        [  3994,   3638],
                        [  3664,   3244],
                        [  3269,   2787],
                        [  2816,   2274],
                        [  2312,   1710],
                        [  1762,   1107],
                        [  1174,    469],
                        [   553,   -186],
                        [   -94,   -853],
                        [  -761,  -1521],
                        [ -1444,  -2185],
                        [ -2135,  -2845],
                        [ -2830,  -3496],
                        [ -3523,  -4148],
                        [ -4210,  -4795],
                        [ -4885,  -5438],
                        [ -5543,  -6074],
                        [ -6180,  -6699],
                        [ -6792,  -7309],
                        [ -7375,  -7899],
                        [ -7928,  -8468],
                        [ -8446,  -9011],
                        [ -8928,  -9528],
                        [ -9371, -10013],
                        [ -9774, -10466],
                        [-10133, -10878],
                        [-10449, -11249],
                        [-10719, -11576],
                        [-10944, -11858],
                        [-11122, -12092],
                        [-11252, -12277],
                        [-11333, -12415],
                        [-11366, -12506],
                        [-11351, -12550],
                        [-11291, -12549],
                        [-11187, -12504],
                        [-11040, -12416],
                        [-10857, -12288],
                        [-10637, -12122],
                        [-10390, -11918],
                        [-10120, -11681],
                        [ -9838, -11412],
                        [ -9548, -11114],
                        [ -9256, -10791],
                        [ -8963, -10442],
                        [ -8664, -10072],
                        [ -8362,  -9683],
                        [ -8044,  -9280],
                        [ -7712,  -8863],
                        [ -7387,  -8460],
                        [ -7069,  -8070],
                        [ -6806,  -7744],
                        [ -6597,  -7480],
                        [ -6447,  -7282],
                        [ -6358,  -7154],
                        [ -6286,  -7050],
                        [ -6234,  -6975],
                        [ -6140,  -6866],
                        [ -6010,  -6726],
                        [ -5844,  -6558],
                        [ -5642,  -6359],
                        [ -5408,  -6134],
                        [ -5145,  -5884],
                        [ -4859,  -5614],
                        [ -4548,  -5326],
                        [ -4225,  -5025],
                        [ -3885,  -4710],
                        [ -3538,  -4390],
                        [ -3180,  -4060],
                        [ -2822,  -3729],
                        [ -2459,  -3394],
                        [ -2100,  -3060],
                        [ -1743,  -2726],
                        [ -1389,  -2394],
                        [ -1036,  -2063],
                        [  -685,  -1735],
                        [  -334,  -1407],
                        [    18,  -1083],
                        [   372,   -759],
                        [   728,   -435],
                        [  1086,   -109],
                        [  1441,    219],
                        [  1797,    549],
                        [  2154,    885],
                        [  2511,   1224],
                        [  2876,   1570],
                        [  3249,   1921],
                        [  3637,   2277],
                        [  4038,   2637],
                        [  4453,   3005],
                        [  4882,   3378],
                        [  5320,   3758],
                        [  5768,   4143],
                        [  6225,   4538],
                        [  6687,   4938],
                        [  7147,   5341],
                        [  7606,   5745],
                        [  8067,   6156],
                        [  8485,   6532],
                        [  8786,   6793],
                        [  8939,   6909],
                        [  8942,   6878],
                        [  8775,   6680],
                        [  8395,   6272],
                        [  7804,   5659],
                        [  7111,   4951],
                        [  6404,   4238],
                        [  5683,   3525],
                        [  4953,   2815],
                        [  4230,   2125],
                        [  3524,   1465],
                        [  2840,    841],
                        [  2185,    259],
                        [  1566,   -275],
                        [   986,   -759],
                        [   448,  -1191],
                        [   -48,  -1571],
                        [  -500,  -1900],
                        [  -908,  -2178],
                        [ -1273,  -2408],
                        [ -1597,  -2592],
                        [ -1880,  -2732],
                        [ -2127,  -2833],
                        [ -2338,  -2899],
                        [ -2519,  -2932],
                        [ -2670,  -2936],
                        [ -2795,  -2917],
                        [ -2895,  -2876],
                        [ -2975,  -2820],
                        [ -3036,  -2759],
                        [ -3080,  -2696],
                        [ -3109,  -2641],
                        [ -3126,  -2595],
                        [ -3129,  -2562],
                        [ -3121,  -2542],
                        [ -3103,  -2527],
                        [ -3075,  -2515],
                        [ -3036,  -2494],
                        [ -2989,  -2467],
                        [ -2935,  -2429],
                        [ -2871,  -2379],
                        [ -2799,  -2317],
                        [ -2718,  -2243],
                        [ -2628,  -2154],
                        [ -2528,  -2048],
                        [ -2416,  -1925],
                        [ -2294,  -1783],
                        [ -2160,  -1627],
                        [ -2016,  -1455],
                        [ -1860,  -1274],
                        [ -1693,  -1083],
                        [ -1516,   -884],
                        [ -1329,   -678],
                        [ -1136,   -467],
                        [  -935,   -251],
                        [  -730,    -30],
                        [  -520,    197],
                        [  -307,    426],
                        [   -93,    659],
                        [   124,    894],
                        [   341,   1129],
                        [   560,   1363],
                        [   779,   1597],
                        [  1008,   1826],
                        [  1241,   2049],
                        [  1489,   2267],
                        [  1746,   2477],
                        [  2011,   2676],
                        [  2278,   2860],
                        [  2537,   3031],
                        [  2786,   3187],
                        [  3016,   3333],
                        [  3225,   3467],
                        [  3462,   3639],
                        [  3722,   3846],
                        [  4026,   4108],
                        [  4373,   4424],
                        [  4747,   4778],
                        [  5149,   5172],
                        [  5499,   5523],
                        [  5800,   5836],
                        [  6022,   6079],
                        [  6165,   6251],
                        [  6234,   6356],
                        [  6229,   6393],
                        [  6152,   6363],
                        [  6007,   6268],
                        [  5802,   6115],
                        [  5537,   5904],
                        [  5223,   5643],
                        [  4860,   5333],
                        [  4461,   4984],
                        [  4024,   4595],
                        [  3564,   4177],
                        [  3082,   3729],
                        [  2585,   3261],
                        [  2077,   2774],
                        [  1564,   2277],
                        [  1047,   1770],
                        [   530,   1261],
                        [    15,    751],
                        [  -492,    246],
                        [  -989,   -252],
                        [ -1467,   -739],
                        [ -1923,  -1213],
                        [ -2353,  -1671],
                        [ -2753,  -2113],
                        [ -3127,  -2532],
                        [ -3472,  -2930],
                        [ -3797,  -3304],
                        [ -4098,  -3650],
                        [ -4382,  -3968],
                        [ -4646,  -4258],
                        [ -4891,  -4521],
                        [ -5112,  -4754],
                        [ -5312,  -4960],
                        [ -5492,  -5140],
                        [ -5649,  -5295],
                        [ -5781,  -5421],
                        [ -5891,  -5523],
                        [ -5983,  -5605],
                        [ -6021,  -5629],
                        [ -5954,  -5546],
                        [ -5775,  -5345],
                        [ -5485,  -5028],
                        [ -5066,  -4577],
                        [ -4475,  -3950],
                        [ -3707,  -3144],
                        [ -2852,  -2247],
                        [ -1977,  -1334],
                        [ -1090,   -414],
                        [  -200,    505],
                        [   674,   1402],
                        [  1515,   2260],
                        [  2317,   3071],
                        [  3066,   3824],
                        [  3754,   4509],
                        [  4372,   5119],
                        [  4916,   5647],
                        [  5381,   6091],
                        [  5765,   6449],
                        [  6065,   6718],
                        [  6283,   6899],
                        [  6420,   6995],
                        [  6476,   7005],
                        [  6455,   6936],
                        [  6361,   6790],
                        [  6199,   6572],
                        [  5974,   6289],
                        [  5692,   5946],
                        [  5358,   5550],
                        [  4978,   5112],
                        [  4561,   4639],
                        [  4110,   4146],
                        [  3635,   3640],
                        [  3140,   3134],
                        [  2633,   2633],
                        [  2117,   2140],
                        [  1601,   1661],
                        [  1091,   1188],
                        [   591,    727],
                        [   107,    275],
                        [  -358,   -165],
                        [  -795,   -587],
                        [ -1205,   -990],
                        [ -1582,  -1372],
                        [ -1923,  -1732],
                        [ -2228,  -2070],
                        [ -2494,  -2385],
                        [ -2719,  -2672],
                        [ -2904,  -2932],
                        [ -3048,  -3154],
                        [ -3149,  -3340],
                        [ -3209,  -3485],
                        [ -3228,  -3589],
                        [ -3206,  -3649],
                        [ -3144,  -3666],
                        [ -3043,  -3641],
                        [ -2904,  -3576],
                        [ -2730,  -3473],
                        [ -2522,  -3335],
                        [ -2284,  -3161],
                        [ -2019,  -2958],
                        [ -1731,  -2725],
                        [ -1422,  -2466],
                        [ -1103,  -2185],
                        [  -774,  -1883],
                        [  -449,  -1566],
                        [  -131,  -1233],
                        [   174,   -891],
                        [   466,   -537],
                        [   745,   -177],
                        [  1008,    186],
                        [  1268,    548],
                        [  1522,    908],
                        [  1743,   1230],
                        [  1931,   1515],
                        [  2038,   1714],
                        [  2068,   1828],
                        [  2016,   1852],
                        [  1880,   1783],
                        [  1709,   1668],
                        [  1499,   1506],
                        [  1326,   1369],
                        [  1187,   1257],
                        [  1087,   1173],
                        [  1028,   1121],
                        [  1012,   1103],
                        [  1040,   1119],
                        [  1111,   1170],
                        [  1224,   1256],
                        [  1378,   1375],
                        [  1572,   1529],
                        [  1801,   1714],
                        [  2069,   1930],
                        [  2365,   2175],
                        [  2693,   2449],
                        [  3047,   2748],
                        [  3426,   3073],
                        [  3828,   3421],
                        [  4253,   3792],
                        [  4696,   4181],
                        [  5163,   4591],
                        [  5647,   5017],
                        [  6151,   5460],
                        [  6664,   5916],
                        [  7189,   6385],
                        [  7714,   6866],
                        [  8239,   7356],
                        [  8760,   7854],
                        [  9279,   8357],
                        [  9796,   8864],
                        [ 10312,   9371],
                        [ 10832,   9876],
                        [ 11354,  10376],
                        [ 11872,  10870],
                        [ 12387,  11353],
                        [ 12893,  11824],
                        [ 13387,  12279],
                        [ 13865,  12718],
                        [ 14324,  13139],
                        [ 14757,  13535],
                        [ 15163,  13907],
                        [ 15539,  14251],
                        [ 15857,  14540],
                        [ 16088,  14744],
                        [ 16233,  14863],
                        [ 16291,  14897],
                        [ 16238,  14821],
                        [ 16026,  14590],
                        [ 15632,  14179],
                        [ 15108,  13646],
                        [ 14504,  13039],
                        [ 13821,  12364],
                        [ 13069,  11629],
                        [ 12266,  10853],
                        [ 11422,  10047],
                        [ 10550,   9224],
                        [  9659,   8391],
                        [  8761,   7560],
                        [  7867,   6741],
                        [  6983,   5941],
                        [  6117,   5164],
                        [  5276,   4418],
                        [  4462,   3707],
                        [  3682,   3033],
                        [  2940,   2400],
                        [  2238,   1809],
                        [  1578,   1264],
                        [   964,    764],
                        [   395,    308],
                        [  -127,   -102],
                        [  -602,   -467],
                        [ -1030,   -791],
                        [ -1411,  -1073],
                        [ -1747,  -1322],
                        [ -2037,  -1539],
                        [ -2282,  -1732],
                        [ -2485,  -1904],
                        [ -2645,  -2057],
                        [ -2763,  -2195],
                        [ -2843,  -2308],
                        [ -2884,  -2399],
                        [ -2891,  -2457],
                        [ -2862,  -2485],
                        [ -2802,  -2480],
                        [ -2712,  -2443],
                        [ -2595,  -2373],
                        [ -2451,  -2270],
                        [ -2283,  -2130],
                        [ -2093,  -1956],
                        [ -1883,  -1745],
                        [ -1653,  -1501],
                        [ -1406,  -1229],
                        [ -1145,   -931],
                        [  -871,   -618],
                        [  -587,   -292],
                        [  -295,     42],
                        [     2,    384],
                        [   301,    725],
                        [   599,   1065],
                        [   893,   1402],
                        [  1182,   1735],
                        [  1463,   2060],
                        [  1735,   2375],
                        [  1994,   2678],
                        [  2240,   2967],
                        [  2474,   3241],
                        [  2692,   3498],
                        [  2901,   3734],
                        [  3100,   3950],
                        [  3291,   4145],
                        [  3477,   4316],
                        [  3652,   4461],
                        [  3817,   4578],
                        [  3967,   4669],
                        [  4100,   4734],
                        [  4214,   4783],
                        [  4310,   4816],
                        [  4438,   4885],
                        [  4593,   4986],
                        [  4795,   5140],
                        [  5042,   5345],
                        [  5328,   5597],
                        [  5656,   5897],
                        [  5943,   6166],
                        [  6199,   6409],
                        [  6388,   6593],
                        [  6514,   6721],
                        [  6575,   6789],
                        [  6572,   6801],
                        [  6507,   6753],
                        [  6382,   6649],
                        [  6200,   6492],
                        [  5963,   6282],
                        [  5679,   6028],
                        [  5349,   5727],
                        [  4984,   5391],
                        [  4583,   5018],
                        [  4160,   4617],
                        [  3714,   4191],
                        [  3255,   3747],
                        [  2784,   3287],
                        [  2308,   2819],
                        [  1829,   2344],
                        [  1351,   1870],
                        [   876,   1396],
                        [   411,    931],
                        [   -41,    476],
                        [  -470,     36],
                        [  -875,   -389],
                        [ -1246,   -794],
                        [ -1586,  -1179],
                        [ -1896,  -1540],
                        [ -2173,  -1877],
                        [ -2430,  -2186],
                        [ -2663,  -2468],
                        [ -2879,  -2722],
                        [ -3075,  -2945],
                        [ -3252,  -3140],
                        [ -3405,  -3303],
                        [ -3540,  -3438],
                        [ -3656,  -3543],
                        [ -3753,  -3624],
                        [ -3829,  -3675],
                        [ -3887,  -3702],
                        [ -3926,  -3703],
                        [ -3938,  -3670],
                        [ -3926,  -3607],
                        [ -3905,  -3527],
                        [ -3876,  -3432],
                        [ -3821,  -3306],
                        [ -3693,  -3102],
                        [ -3455,  -2785],
                        [ -3127,  -2377],
                        [ -2740,  -1911],
                        [ -2301,  -1395],
                        [ -1818,   -840],
                        [ -1309,   -263],
                        [  -785,    323],
                        [  -257,    907],
                        [   266,   1478],
                        [   769,   2025],
                        [  1249,   2539],
                        [  1696,   3013],
                        [  2104,   3441],
                        [  2469,   3817],
                        [  2789,   4140],
                        [  3062,   4405],
                        [  3285,   4615],
                        [  3458,   4766],
                        [  3582,   4862],
                        [  3658,   4902],
                        [  3689,   4891],
                        [  3676,   4832],
                        [  3625,   4730],
                        [  3538,   4587],
                        [  3421,   4414],
                        [  3277,   4214],
                        [  3110,   4001],
                        [  2927,   3778],
                        [  2731,   3556],
                        [  2526,   3340],
                        [  2319,   3134],
                        [  2113,   2943],
                        [  1911,   2762],
                        [  1719,   2595],
                        [  1541,   2439],
                        [  1379,   2298],
                        [  1237,   2170],
                        [  1116,   2061],
                        [  1021,   1962],
                        [   951,   1879],
                        [   908,   1805],
                        [   894,   1744],
                        [   906,   1693],
                        [   945,   1655],
                        [  1010,   1638],
                        [  1101,   1641],
                        [  1216,   1669],
                        [  1354,   1721],
                        [  1514,   1799],
                        [  1695,   1900],
                        [  1895,   2027],
                        [  2111,   2175],
                        [  2342,   2342],
                        [  2584,   2527],
                        [  2835,   2726],
                        [  3093,   2940],
                        [  3355,   3162],
                        [  3618,   3394],
                        [  3877,   3630],
                        [  4131,   3870],
                        [  4369,   4110],
                        [  4591,   4349],
                        [  4792,   4583],
                        [  4974,   4815],
                        [  5133,   5042],
                        [  5267,   5259],
                        [  5381,   5463],
                        [  5477,   5655],
                        [  5526,   5798],
                        [  5528,   5896],
                        [  5454,   5912],
                        [  5303,   5848],
                        [  5071,   5695],
                        [  4758,   5454],
                        [  4403,   5163],
                        [  4005,   4817],
                        [  3634,   4491],
                        [  3289,   4177],
                        [  2979,   3889],
                        [  2706,   3627],
                        [  2481,   3401],
                        [  2303,   3213],
                        [  2178,   3066],
                        [  2105,   2962],
                        [  2087,   2903],
                        [  2122,   2891],
                        [  2211,   2925],
                        [  2353,   3005],
                        [  2542,   3131],
                        [  2781,   3300],
                        [  3062,   3512],
                        [  3386,   3764],
                        [  3746,   4054],
                        [  4144,   4382],
                        [  4573,   4739],
                        [  5034,   5129],
                        [  5519,   5544],
                        [  6030,   5982],
                        [  6550,   6438],
                        [  7079,   6911],
                        [  7604,   7394],
                        [  8123,   7885],
                        [  8630,   8378],
                        [  9124,   8871],
                        [  9603,   9358],
                        [ 10068,   9835],
                        [ 10520,  10298],
                        [ 10957,  10743],
                        [ 11373,  11165],
                        [ 11762,  11559],
                        [ 12123,  11922],
                        [ 12450,  12249],
                        [ 12741,  12539],
                        [ 12991,  12786],
                        [ 13196,  12988],
                        [ 13354,  13142],
                        [ 13462,  13244],
                        [ 13525,  13302],
                        [ 13572,  13342],
                        [ 13621,  13383],
                        [ 13670,  13425],
                        [ 13700,  13447],
                        [ 13667,  13405],
                        [ 13510,  13241],
                        [ 13215,  12938],
                        [ 12797,  12515],
                        [ 12261,  11979],
                        [ 11619,  11340],
                        [ 10883,  10613],
                        [ 10069,   9810],
                        [  9189,   8945],
                        [  8253,   8028],
                        [  7277,   7074],
                        [  6273,   6094],
                        [  5251,   5100],
                        [  4223,   4104],
                        [  3199,   3114],
                        [  2187,   2141],
                        [  1195,   1190],
                        [   232,    268],
                        [  -696,   -616],
                        [ -1582,  -1458],
                        [ -2422,  -2253],
                        [ -3210,  -2998],
                        [ -3944,  -3690],
                        [ -4620,  -4326],
                        [ -5236,  -4906],
                        [ -5792,  -5429],
                        [ -6285,  -5899],
                        [ -6717,  -6315],
                        [ -7087,  -6683],
                        [ -7397,  -7004],
                        [ -7647,  -7282],
                        [ -7840,  -7516],
                        [ -7976,  -7710],
                        [ -8061,  -7863],
                        [ -8095,  -7971],
                        [ -8082,  -8037],
                        [ -8026,  -8059],
                        [ -7931,  -8041],
                        [ -7799,  -7980],
                        [ -7635,  -7880],
                        [ -7443,  -7737],
                        [ -7226,  -7551],
                        [ -6988,  -7326],
                        [ -6732,  -7064],
                        [ -6463,  -6772],
                        [ -6182,  -6455],
                        [ -5893,  -6123],
                        [ -5600,  -5779],
                        [ -5306,  -5433],
                        [ -5014,  -5086],
                        [ -4729,  -4744],
                        [ -4453,  -4409],
                        [ -4188,  -4087],
                        [ -3936,  -3779],
                        [ -3700,  -3486],
                        [ -3482,  -3213],
                        [ -3283,  -2962],
                        [ -3105,  -2734],
                        [ -2949,  -2529],
                        [ -2817,  -2351],
                        [ -2705,  -2199],
                        [ -2615,  -2076],
                        [ -2542,  -1979],
                        [ -2490,  -1910],
                        [ -2455,  -1872],
                        [ -2437,  -1864],
                        [ -2432,  -1881],
                        [ -2439,  -1924],
                        [ -2453,  -1978],
                        [ -2474,  -2045],
                        [ -2464,  -2084],
                        [ -2423,  -2096],
                        [ -2342,  -2068],
                        [ -2218,  -1997],
                        [ -2045,  -1877],
                        [ -1823,  -1705],
                        [ -1612,  -1540],
                        [ -1406,  -1377],
                        [ -1231,  -1243],
                        [ -1086,  -1133],
                        [  -975,  -1055],
                        [  -899,  -1008],
                        [  -862,   -995],
                        [  -861,  -1014],
                        [  -899,  -1067],
                        [  -973,  -1152],
                        [ -1081,  -1269],
                        [ -1221,  -1415],
                        [ -1389,  -1587],
                        [ -1584,  -1783],
                        [ -1799,  -2000],
                        [ -2034,  -2237],
                        [ -2281,  -2486],
                        [ -2541,  -2750],
                        [ -2809,  -3019],
                        [ -3083,  -3296],
                        [ -3361,  -3575],
                        [ -3641,  -3855],
                        [ -3915,  -4129],
                        [ -4184,  -4400],
                        [ -4437,  -4661],
                        [ -4672,  -4913],
                        [ -4885,  -5153],
                        [ -5075,  -5379],
                        [ -5245,  -5590],
                        [ -5393,  -5784],
                        [ -5529,  -5962],
                        [ -5653,  -6123],
                        [ -5767,  -6264],
                        [ -5871,  -6387],
                        [ -5964,  -6489],
                        [ -6044,  -6572],
                        [ -6115,  -6636],
                        [ -6175,  -6677],
                        [ -6225,  -6700],
                        [ -6266,  -6703],
                        [ -6295,  -6687],
                        [ -6316,  -6652],
                        [ -6359,  -6632],
                        [ -6474,  -6679],
                        [ -6685,  -6814],
                        [ -6993,  -7040],
                        [ -7382,  -7343],
                        [ -7808,  -7681],
                        [ -8191,  -7971],
                        [ -8482,  -8166],
                        [ -8682,  -8271],
                        [ -8798,  -8292],
                        [ -8833,  -8234],
                        [ -8796,  -8108],
                        [ -8696,  -7923],
                        [ -8540,  -7685],
                        [ -8337,  -7404],
                        [ -8096,  -7090],
                        [ -7822,  -6750],
                        [ -7525,  -6393],
                        [ -7209,  -6025],
                        [ -6881,  -5653],
                        [ -6544,  -5282],
                        [ -6203,  -4917],
                        [ -5862,  -4560],
                        [ -5526,  -4215],
                        [ -5197,  -3885],
                        [ -4876,  -3572],
                        [ -4565,  -3274],
                        [ -4266,  -2994],
                        [ -3978,  -2731],
                        [ -3701,  -2484],
                        [ -3435,  -2249],
                        [ -3179,  -2026],
                        [ -2933,  -1811],
                        [ -2694,  -1602],
                        [ -2463,  -1395],
                        [ -2236,  -1188],
                        [ -2014,   -975],
                        [ -1795,   -757],
                        [ -1577,   -533],
                        [ -1359,   -301],
                        [ -1141,    -67],
                        [  -920,    174],
                        [  -697,    415],
                        [  -470,    661],
                        [  -241,    901],
                        [    -6,   1138],
                        [   232,   1364],
                        [   475,   1580],
                        [   720,   1783],
                        [   967,   1975],
                        [  1213,   2160],
                        [  1458,   2338],
                        [  1700,   2513],
                        [  1939,   2686],
                        [  2172,   2856],
                        [  2400,   3023],
                        [  2620,   3185],
                        [  2830,   3343],
                        [  3029,   3496],
                        [  3215,   3642],
                        [  3388,   3781],
                        [  3547,   3911],
                        [  3690,   4032],
                        [  3819,   4143],
                        [  3932,   4241],
                        [  4028,   4329],
                        [  4109,   4405],
                        [  4171,   4466],
                        [  4217,   4515],
                        [  4249,   4554],
                        [  4258,   4582],
                        [  4244,   4595],
                        [  4206,   4593],
                        [  4147,   4578],
                        [  4048,   4526],
                        [  3911,   4439],
                        [  3724,   4304],
                        [  3491,   4122],
                        [  3201,   3880],
                        [  2858,   3580],
                        [  2477,   3239],
                        [  2062,   2857],
                        [  1661,   2481],
                        [  1272,   2111],
                        [   908,   1759],
                        [   572,   1426],
                        [   276,   1125],
                        [    21,    856],
                        [  -185,    627],
                        [  -343,    439],
                        [  -447,    297],
                        [  -496,    202],
                        [  -492,    154],
                        [  -434,    155],
                        [  -326,    204],
                        [  -167,    299],
                        [    37,    438],
                        [   284,    620],
                        [   570,    841],
                        [   891,   1099],
                        [  1242,   1386],
                        [  1621,   1703],
                        [  2019,   2042],
                        [  2435,   2401],
                        [  2853,   2771],
                        [  3271,   3152],
                        [  3677,   3533],
                        [  4067,   3914],
                        [  4434,   4285],
                        [  4775,   4645],
                        [  5091,   4988],
                        [  5378,   5308],
                        [  5637,   5601],
                        [  5865,   5864],
                        [  6055,   6091],
                        [  6203,   6277],
                        [  6309,   6420],
                        [  6370,   6515],
                        [  6382,   6558],
                        [  6343,   6547],
                        [  6256,   6483],
                        [  6112,   6358],
                        [  5919,   6178],
                        [  5728,   6000],
                        [  5607,   5886],
                        [  5579,   5861],
                        [  5643,   5927],
                        [  5794,   6078],
                        [  5994,   6274],
                        [  6142,   6413],
                        [  6164,   6422],
                        [  6056,   6299],
                        [  5830,   6052],
                        [  5489,   5688],
                        [  5044,   5217],
                        [  4503,   4648],
                        [  3878,   3992],
                        [  3181,   3261],
                        [  2424,   2468],
                        [  1618,   1623],
                        [   775,    740],
                        [   -93,   -169],
                        [  -977,  -1092],
                        [ -1867,  -2019],
                        [ -2754,  -2941],
                        [ -3626,  -3848],
                        [ -4475,  -4731],
                        [ -5295,  -5584],
                        [ -6077,  -6399],
                        [ -6817,  -7171],
                        [ -7509,  -7895],
                        [ -8149,  -8568],
                        [ -8734,  -9186],
                        [ -9263,  -9747],
                        [ -9731, -10251],
                        [-10142, -10694],
                        [-10492, -11080],
                        [-10784, -11408],
                        [-11018, -11681],
                        [-11196, -11902],
                        [-11322, -12078],
                        [-11397, -12209],
                        [-11424, -12297],
                        [-11407, -12346],
                        [-11351, -12357],
                        [-11259, -12331],
                        [-11135, -12270],
                        [-10983, -12175],
                        [-10810, -12045],
                        [-10618, -11883],
                        [-10412, -11688],
                        [-10195, -11464],
                        [ -9972, -11219],
                        [ -9744, -10955],
                        [ -9516, -10684],
                        [ -9290, -10407],
                        [ -9071, -10134],
                        [ -8858,  -9864],
                        [ -8656,  -9603],
                        [ -8467,  -9352],
                        [ -8290,  -9116],
                        [ -8128,  -8899],
                        [ -7982,  -8699],
                        [ -7853,  -8518],
                        [ -7740,  -8360],
                        [ -7646,  -8224],
                        [ -7572,  -8110],
                        [ -7517,  -8019],
                        [ -7483,  -7950],
                        [ -7471,  -7904],
                        [ -7479,  -7879],
                        [ -7510,  -7874],
                        [ -7557,  -7889],
                        [ -7618,  -7924],
                        [ -7681,  -7974],
                        [ -7742,  -8036],
                        [ -7796,  -8101],
                        [ -7840,  -8170],
                        [ -7860,  -8225],
                        [ -7859,  -8266],
                        [ -7826,  -8283],
                        [ -7763,  -8277],
                        [ -7650,  -8224],
                        [ -7485,  -8124],
                        [ -7296,  -8001],
                        [ -7079,  -7851],
                        [ -6853,  -7692],
                        [ -6615,  -7521],
                        [ -6377,  -7348],
                        [ -6137,  -7172],
                        [ -5905,  -7000],
                        [ -5679,  -6829],
                        [ -5469,  -6669],
                        [ -5271,  -6516],
                        [ -5090,  -6376],
                        [ -4925,  -6246],
                        [ -4778,  -6130],
                        [ -4649,  -6026],
                        [ -4538,  -5935],
                        [ -4444,  -5858],
                        [ -4366,  -5793],
                        [ -4304,  -5740],
                        [ -4256,  -5697],
                        [ -4223,  -5665],
                        [ -4201,  -5641],
                        [ -4193,  -5626],
                        [ -4192,  -5617],
                        [ -4197,  -5614],
                        [ -4203,  -5615],
                        [ -4209,  -5620],
                        [ -4210,  -5627],
                        [ -4208,  -5634],
                        [ -4202,  -5642],
                        [ -4193,  -5649],
                        [ -4186,  -5655],
                        [ -4182,  -5660],
                        [ -4180,  -5662],
                        [ -4179,  -5662],
                        [ -4178,  -5657],
                        [ -4179,  -5649],
                        [ -4179,  -5632],
                        [ -4180,  -5608],
                        [ -4180,  -5575],
                        [ -4183,  -5535],
                        [ -4180,  -5480],
                        [ -4183,  -5423],
                        [ -4265,  -5442],
                        [ -4500,  -5609],
                        [ -4907,  -5943],
                        [ -5484,  -6446],
                        [ -6234,  -7119],
                        [ -7115,  -7922],
                        [ -8006,  -8732],
                        [ -8808,  -9449],
                        [ -9510, -10064],
                        [-10117, -10582],
                        [-10625, -11000],
                        [-11034, -11319],
                        [-11347, -11543],
                        [-11568, -11676],
                        [-11702, -11722],
                        [-11752, -11687],
                        [-11725, -11578],
                        [-11626, -11400],
                        [-11460, -11161],
                        [-11234, -10868],
                        [-10951, -10525],
                        [-10617, -10140],
                        [-10241,  -9718],
                        [ -9826,  -9265],
                        [ -9379,  -8786],
                        [ -8904,  -8284],
                        [ -8407,  -7765],
                        [ -7891,  -7233],
                        [ -7360,  -6689],
                        [ -6818,  -6138],
                        [ -6268,  -5583],
                        [ -5714,  -5025],
                        [ -5155,  -4470],
                        [ -4597,  -3920],
                        [ -4042,  -3376],
                        [ -3490,  -2841],
                        [ -2944,  -2309],
                        [ -2405,  -1783],
                        [ -1876,  -1258],
                        [ -1357,   -735],
                        [  -851,   -218],
                        [  -356,    296],
                        [   124,    799],
                        [   589,   1293],
                        [  1039,   1768],
                        [  1473,   2225],
                        [  1891,   2656],
                        [  2290,   3061],
                        [  2671,   3437],
                        [  3032,   3785],
                        [  3372,   4105],
                        [  3690,   4398],
                        [  3985,   4668],
                        [  4256,   4915],
                        [  4503,   5136],
                        [  4726,   5333],
                        [  4922,   5506],
                        [  5094,   5657],
                        [  5238,   5785],
                        [  5356,   5891],
                        [  5448,   5975],
                        [  5515,   6038],
                        [  5559,   6080],
                        [  5581,   6102],
                        [  5586,   6106],
                        [  5575,   6092],
                        [  5557,   6061],
                        [  5530,   6015],
                        [  5499,   5955],
                        [  5466,   5883],
                        [  5421,   5801],
                        [  5366,   5709],
                        [  5292,   5607],
                        [  5202,   5496],
                        [  5095,   5376],
                        [  4974,   5249],
                        [  4847,   5120],
                        [  4715,   4990],
                        [  4562,   4843],
                        [  4392,   4680],
                        [  4192,   4488],
                        [  3963,   4268],
                        [  3728,   4040],
                        [  3484,   3802],
                        [  3245,   3567],
                        [  3011,   3335],
                        [  2795,   3116],
                        [  2595,   2912],
                        [  2423,   2730],
                        [  2277,   2572],
                        [  2164,   2441],
                        [  2082,   2338],
                        [  2036,   2269],
                        [  2022,   2229],
                        [  2043,   2221],
                        [  2095,   2243],
                        [  2175,   2292],
                        [  2282,   2369],
                        [  2411,   2469],
                        [  2560,   2589],
                        [  2723,   2727],
                        [  2897,   2878],
                        [  3075,   3037],
                        [  3254,   3202],
                        [  3425,   3366],
                        [  3583,   3526],
                        [  3721,   3676],
                        [  3837,   3812],
                        [  3922,   3929],
                        [  3974,   4025],
                        [  3993,   4093],
                        [  3976,   4134],
                        [  3924,   4141],
                        [  3833,   4115],
                        [  3700,   4050],
                        [  3525,   3945],
                        [  3309,   3797],
                        [  3048,   3605],
                        [  2744,   3365],
                        [  2400,   3079],
                        [  2017,   2746],
                        [  1588,   2360],
                        [  1136,   1944],
                        [   754,   1593],
                        [   514,   1378],
                        [   436,   1323],
                        [   528,   1432],
                        [   800,   1717],
                        [  1225,   2147],
                        [  1665,   2585],
                        [  2018,   2925],
                        [  2274,   3158],
                        [  2443,   3295],
                        [  2520,   3331],
                        [  2507,   3269],
                        [  2411,   3114],
                        [  2237,   2873],
                        [  1991,   2553],
                        [  1681,   2161],
                        [  1315,   1706],
                        [   901,   1200],
                        [   448,    649],
                        [   -37,     67],
                        [  -545,   -540],
                        [ -1069,  -1162],
                        [ -1600,  -1790],
                        [ -2130,  -2416],
                        [ -2651,  -3032],
                        [ -3158,  -3634],
                        [ -3646,  -4214],
                        [ -4108,  -4766],
                        [ -4541,  -5287],
                        [ -4943,  -5774],
                        [ -5310,  -6222],
                        [ -5640,  -6627],
                        [ -5933,  -6988],
                        [ -6188,  -7298],
                        [ -6406,  -7559],
                        [ -6587,  -7772],
                        [ -6732,  -7941],
                        [ -6843,  -8074],
                        [ -6920,  -8172],
                        [ -6969,  -8245],
                        [ -6988,  -8295],
                        [ -6984,  -8322],
                        [ -6958,  -8331],
                        [ -6914,  -8321],
                        [ -6856,  -8295],
                        [ -6786,  -8249],
                        [ -6708,  -8187],
                        [ -6625,  -8109],
                        [ -6541,  -8019],
                        [ -6455,  -7918],
                        [ -6372,  -7809],
                        [ -6291,  -7699],
                        [ -6216,  -7590],
                        [ -6147,  -7482],
                        [ -6086,  -7382],
                        [ -6033,  -7285],
                        [ -5987,  -7196],
                        [ -5948,  -7117],
                        [ -5917,  -7048],
                        [ -5890,  -6990],
                        [ -5870,  -6943],
                        [ -5856,  -6906],
                        [ -5847,  -6879],
                        [ -5844,  -6863],
                        [ -5848,  -6855],
                        [ -5865,  -6855],
                        [ -5891,  -6862],
                        [ -5934,  -6873],
                        [ -5989,  -6888],
                        [ -6052,  -6904],
                        [ -6121,  -6921],
                        [ -6177,  -6935],
                        [ -6219,  -6944],
                        [ -6242,  -6949],
                        [ -6246,  -6949],
                        [ -6245,  -6957],
                        [ -6237,  -6970],
                        [ -6220,  -6983],
                        [ -6193,  -6999],
                        [ -6123,  -6979],
                        [ -6011,  -6924],
                        [ -5846,  -6821],
                        [ -5626,  -6668],
                        [ -5363,  -6476],
                        [ -5055,  -6242],
                        [ -4718,  -5978],
                        [ -4348,  -5681],
                        [ -3960,  -5364],
                        [ -3552,  -5024],
                        [ -3138,  -4672],
                        [ -2716,  -4308],
                        [ -2297,  -3941],
                        [ -1881,  -3569],
                        [ -1474,  -3201],
                        [ -1077,  -2837],
                        [  -699,  -2483],
                        [  -335,  -2137],
                        [     9,  -1805],
                        [   332,  -1485],
                        [   634,  -1182],
                        [   913,   -895],
                        [  1171,   -626],
                        [  1406,   -375],
                        [  1619,   -141],
                        [  1812,     73],
                        [  1986,    271],
                        [  2139,    449],
                        [  2279,    613],
                        [  2403,    760],
                        [  2515,    891],
                        [  2614,   1008],
                        [  2699,   1112],
                        [  2771,   1200],
                        [  2832,   1277],
                        [  2882,   1341],
                        [  2923,   1397],
                        [  2954,   1442],
                        [  2979,   1484],
                        [  2997,   1523],
                        [  3007,   1559],
                        [  3010,   1594],
                        [  3018,   1640],
                        [  3000,   1665],
                        [  2862,   1571],
                        [  2535,   1291],
                        [  2015,    817],
                        [  1293,    137],
                        [   352,   -760],
                        [  -775,  -1842],
                        [ -1942,  -2962],
                        [ -3034,  -4002],
                        [ -4041,  -4951],
                        [ -4961,  -5809],
                        [ -5782,  -6563],
                        [ -6497,  -7210],
                        [ -7105,  -7746],
                        [ -7607,  -8170],
                        [ -7997,  -8482],
                        [ -8279,  -8683],
                        [ -8457,  -8777],
                        [ -8533,  -8769],
                        [ -8510,  -8662],
                        [ -8394,  -8464],
                        [ -8188,  -8180],
                        [ -7901,  -7817],
                        [ -7539,  -7382],
                        [ -7110,  -6884],
                        [ -6620,  -6327],
                        [ -6076,  -5718],
                        [ -5486,  -5067],
                        [ -4856,  -4378],
                        [ -4194,  -3659],
                        [ -3506,  -2915],
                        [ -2797,  -2156],
                        [ -2075,  -1385],
                        [ -1343,   -618],
                        [  -607,    144],
                        [   128,    889],
                        [   856,   1614],
                        [  1574,   2323],
                        [  2277,   3010],
                        [  2962,   3686],
                        [  3625,   4345],
                        [  4263,   4990],
                        [  4876,   5617],
                        [  5458,   6222],
                        [  6010,   6804],
                        [  6530,   7356],
                        [  7018,   7879],
                        [  7471,   8366],
                        [  7890,   8816],
                        [  8275,   9229],
                        [  8626,   9605],
                        [  8939,   9941],
                        [  9219,  10238],
                        [  9463,  10498],
                        [  9673,  10723],
                        [  9848,  10910],
                        [  9991,  11061],
                        [ 10099,  11177],
                        [ 10175,  11261],
                        [ 10220,  11315],
                        [ 10235,  11339],
                        [ 10222,  11338],
                        [ 10184,  11312],
                        [ 10124,  11262],
                        [ 10043,  11193],
                        [  9952,  11105],
                        [  9852,  11001],
                        [  9757,  10884],
                        [  9666,  10755],
                        [  9588,  10618],
                        [  9520,  10474],
                        [  9456,  10324],
                        [  9397,  10172],
                        [  9331,  10019],
                        [  9259,   9867],
                        [  9204,   9742],
                        [  9167,   9644],
                        [  9164,   9588],
                        [  9198,   9578],
                        [  9249,   9592],
                        [  9318,   9633],
                        [  9359,   9653],
                        [  9375,   9653],
                        [  9359,   9628],
                        [  9310,   9576],
                        [  9238,   9505],
                        [  9141,   9414],
                        [  9029,   9310],
                        [  8900,   9192],
                        [  8764,   9068],
                        [  8618,   8936],
                        [  8471,   8803],
                        [  8320,   8667],
                        [  8171,   8532],
                        [  8021,   8397],
                        [  7874,   8265],
                        [  7728,   8132],
                        [  7583,   8002],
                        [  7438,   7871],
                        [  7291,   7739],
                        [  7140,   7604],
                        [  6982,   7464],
                        [  6814,   7320],
                        [  6636,   7165],
                        [  6443,   7001],
                        [  6234,   6822],
                        [  6009,   6628],
                        [  5763,   6416],
                        [  5495,   6186],
                        [  5198,   5932],
                        [  4874,   5656],
                        [  4518,   5355],
                        [  4134,   5030],
                        [  3719,   4680],
                        [  3276,   4305],
                        [  2803,   3906],
                        [  2304,   3483],
                        [  1781,   3036],
                        [  1233,   2565],
                        [   666,   2068],
                        [    85,   1551],
                        [  -509,   1015],
                        [ -1121,    451],
                        [ -1711,    -98],
                        [ -2176,   -527],
                        [ -2459,   -779],
                        [ -2549,   -843],
                        [ -2431,   -703],
                        [ -2076,   -329],
                        [ -1503,    252],
                        [  -856,    899],
                        [  -241,   1503],
                        [   340,   2057],
                        [   886,   2564],
                        [  1384,   3012],
                        [  1828,   3395],
                        [  2221,   3714],
                        [  2557,   3967],
                        [  2839,   4155],
                        [  3066,   4278],
                        [  3239,   4340],
                        [  3363,   4344],
                        [  3440,   4297],
                        [  3473,   4203],
                        [  3466,   4067],
                        [  3424,   3894],
                        [  3352,   3693],
                        [  3253,   3467],
                        [  3135,   3220],
                        [  2998,   2960],
                        [  2851,   2690],
                        [  2693,   2414],
                        [  2531,   2137],
                        [  2365,   1861],
                        [  2199,   1592],
                        [  2035,   1337],
                        [  1873,   1096],
                        [  1715,    882],
                        [  1562,    694],
                        [  1414,    531],
                        [  1272,    396],
                        [  1137,    275],
                        [  1008,    168],
                        [   884,     63],
                        [   767,    -40],
                        [   653,   -144],
                        [   544,   -248],
                        [   436,   -353],
                        [   332,   -460],
                        [   227,   -566],
                        [   120,   -673],
                        [    14,   -782],
                        [   -95,   -893],
                        [  -205,  -1004],
                        [  -318,  -1117],
                        [  -431,  -1229],
                        [  -545,  -1342],
                        [  -661,  -1454],
                        [  -775,  -1565],
                        [  -887,  -1672],
                        [  -997,  -1776],
                        [ -1099,  -1877],
                        [ -1195,  -1975],
                        [ -1281,  -2067],
                        [ -1358,  -2155],
                        [ -1424,  -2236],
                        [ -1476,  -2309],
                        [ -1519,  -2373],
                        [ -1550,  -2428],
                        [ -1580,  -2470],
                        [ -1607,  -2500],
                        [ -1637,  -2516],
                        [ -1668,  -2517],
                        [ -1697,  -2500],
                        [ -1722,  -2467],
                        [ -1725,  -2414],
                        [ -1707,  -2342],
                        [ -1674,  -2267],
                        [ -1623,  -2186],
                        [ -1594,  -2138],
                        [ -1581,  -2119],
                        [ -1588,  -2130],
                        [ -1613,  -2169],
                        [ -1614,  -2194],
                        [ -1593,  -2206],
                        [ -1505,  -2157],
                        [ -1351,  -2051],
                        [ -1140,  -1891],
                        [  -869,  -1676],
                        [  -551,  -1415],
                        [  -184,  -1109],
                        [   216,   -768],
                        [   651,   -392],
                        [  1106,      9],
                        [  1581,    433],
                        [  2064,    869],
                        [  2554,   1320],
                        [  3040,   1771],
                        [  3521,   2225],
                        [  3987,   2672],
                        [  4438,   3112],
                        [  4869,   3538],
                        [  5279,   3951],
                        [  5664,   4345],
                        [  6025,   4719],
                        [  6359,   5070],
                        [  6666,   5397],
                        [  6942,   5701],
                        [  7188,   5978],
                        [  7403,   6230],
                        [  7586,   6457],
                        [  7742,   6659],
                        [  7872,   6836],
                        [  7982,   6990],
                        [  8073,   7122],
                        [  8147,   7230],
                        [  8204,   7318],
                        [  8248,   7386],
                        [  8278,   7434],
                        [  8297,   7467],
                        [  8305,   7482],
                        [  8305,   7486],
                        [  8298,   7482],
                        [  8280,   7469],
                        [  8257,   7450],
                        [  8237,   7438],
                        [  8179,   7386],
                        [  7996,   7209],
                        [  7646,   6864],
                        [  7131,   6350],
                        [  6437,   5651],
                        [  5527,   4736],
                        [  4425,   3629],
                        [  3265,   2467],
                        [  2147,   1352],
                        [  1080,    294],
                        [    67,   -702],
                        [  -872,  -1618],
                        [ -1727,  -2442],
                        [ -2493,  -3170],
                        [ -3163,  -3796],
                        [ -3733,  -4315],
                        [ -4200,  -4725],
                        [ -4565,  -5025],
                        [ -4827,  -5216],
                        [ -4988,  -5302],
                        [ -5051,  -5286],
                        [ -5020,  -5174],
                        [ -4899,  -4969],
                        [ -4697,  -4681],
                        [ -4418,  -4314],
                        [ -4071,  -3879],
                        [ -3660,  -3380],
                        [ -3196,  -2826],
                        [ -2686,  -2225],
                        [ -2136,  -1584],
                        [ -1554,   -912],
                        [  -947,   -219],
                        [  -322,    489],
                        [   314,   1192],
                        [   957,   1886],
                        [  1597,   2559],
                        [  2233,   3205],
                        [  2856,   3825],
                        [  3462,   4414],
                        [  4048,   4984],
                        [  4608,   5531],
                        [  5140,   6058],
                        [  5641,   6563],
                        [  6109,   7042],
                        [  6543,   7494],
                        [  6941,   7916],
                        [  7303,   8307],
                        [  7629,   8668],
                        [  7918,   8996],
                        [  8170,   9292],
                        [  8387,   9557],
                        [  8570,   9786],
                        [  8720,   9980],
                        [  8837,  10140],
                        [  8922,  10265],
                        [  8978,  10356],
                        [  9006,  10412],
                        [  9007,  10438],
                        [  8981,  10433],
                        [  8933,  10403],
                        [  8862,  10350],
                        [  8772,  10275],
                        [  8665,  10181],
                        [  8544,  10071],
                        [  8413,   9947],
                        [  8282,   9812],
                        [  8151,   9667],
                        [  8036,   9516],
                        [  7936,   9360],
                        [  7858,   9202],
                        [  7801,   9041],
                        [  7757,   8880],
                        [  7730,   8723],
                        [  7707,   8574],
                        [  7690,   8435],
                        [  7718,   8351],
                        [  7788,   8319],
                        [  7923,   8362],
                        [  8119,   8479],
                        [  8358,   8651],
                        [  8642,   8878],
                        [  8894,   9087],
                        [  9119,   9280],
                        [  9290,   9432],
                        [  9408,   9540],
                        [  9476,   9609],
                        [  9490,   9636],
                        [  9458,   9624],
                        [  9375,   9571],
                        [  9249,   9481],
                        [  9077,   9353],
                        [  8868,   9191],
                        [  8620,   8994],
                        [  8339,   8767],
                        [  8023,   8509],
                        [  7678,   8222],
                        [  7304,   7906],
                        [  6905,   7566],
                        [  6480,   7199],
                        [  6030,   6808],
                        [  5555,   6393],
                        [  5057,   5956],
                        [  4534,   5497],
                        [  3990,   5015],
                        [  3426,   4513],
                        [  2849,   3991],
                        [  2257,   3450],
                        [  1653,   2891],
                        [  1037,   2315],
                        [   405,   1723],
                        [  -242,   1116],
                        [  -907,    496],
                        [ -1584,   -134],
                        [ -2274,   -771],
                        [ -2971,  -1413],
                        [ -3675,  -2056],
                        [ -4380,  -2698],
                        [ -5081,  -3335],
                        [ -5778,  -3968],
                        [ -6463,  -4595],
                        [ -7132,  -5207],
                        [ -7782,  -5809],
                        [ -8414,  -6399],
                        [ -8984,  -6931],
                        [ -9414,  -7330],
                        [ -9674,  -7561],
                        [ -9762,  -7625],
                        [ -9657,  -7498],
                        [ -9315,  -7136],
                        [ -8743,  -6553],
                        [ -8056,  -5861],
                        [ -7335,  -5149],
                        [ -6586,  -4418],
                        [ -5814,  -3677],
                        [ -5038,  -2943],
                        [ -4268,  -2227],
                        [ -3512,  -1536],
                        [ -2780,   -877],
                        [ -2077,   -258],
                        [ -1410,    316],
                        [  -782,    843],
                        [  -199,   1318],
                        [   338,   1740],
                        [   826,   2110],
                        [  1264,   2427],
                        [  1653,   2693],
                        [  1992,   2911],
                        [  2284,   3080],
                        [  2529,   3205],
                        [  2730,   3286],
                        [  2887,   3326],
                        [  3004,   3330],
                        [  3082,   3300],
                        [  3123,   3239],
                        [  3131,   3148],
                        [  3105,   3039],
                        [  3049,   2914],
                        [  2965,   2787],
                        [  2854,   2658],
                        [  2720,   2530],
                        [  2565,   2407],
                        [  2392,   2276],
                        [  2201,   2142],
                        [  1996,   1989],
                        [  1779,   1818],
                        [  1550,   1632],
                        [  1312,   1430],
                        [  1067,   1214],
                        [   815,    984],
                        [   560,    742],
                        [   301,    487],
                        [    44,    219],
                        [  -215,    -59],
                        [  -470,   -341],
                        [  -721,   -630],
                        [  -964,   -914],
                        [ -1201,  -1195],
                        [ -1425,  -1467],
                        [ -1639,  -1727],
                        [ -1837,  -1972],
                        [ -2017,  -2200],
                        [ -2178,  -2411],
                        [ -2318,  -2602],
                        [ -2434,  -2774],
                        [ -2525,  -2923],
                        [ -2592,  -3049],
                        [ -2631,  -3152],
                        [ -2647,  -3229],
                        [ -2639,  -3281],
                        [ -2617,  -3306],
                        [ -2581,  -3304],
                        [ -2540,  -3277],
                        [ -2490,  -3221],
                        [ -2431,  -3137],
                        [ -2367,  -3026],
                        [ -2283,  -2891],
                        [ -2180,  -2731],
                        [ -2078,  -2577],
                        [ -1975,  -2429],
                        [ -1920,  -2336],
                        [ -1909,  -2293],
                        [ -1945,  -2307],
                        [ -2030,  -2377],
                        [ -2118,  -2456],
                        [ -2212,  -2550],
                        [ -2245,  -2588],
                        [ -2221,  -2577],
                        [ -2143,  -2518],
                        [ -2011,  -2410],
                        [ -1829,  -2256],
                        [ -1601,  -2058],
                        [ -1334,  -1824],
                        [ -1030,  -1554],
                        [  -700,  -1257],
                        [  -343,   -932],
                        [    28,   -592],
                        [   412,   -234],
                        [   799,    131],
                        [  1187,    502],
                        [  1567,    871],
                        [  1940,   1238],
                        [  2298,   1596],
                        [  2640,   1944],
                        [  2966,   2277],
                        [  3272,   2595],
                        [  3558,   2893],
                        [  3822,   3173],
                        [  4056,   3430],
                        [  4262,   3665],
                        [  4436,   3878],
                        [  4579,   4069],
                        [  4697,   4236],
                        [  4788,   4383],
                        [  4864,   4509],
                        [  4926,   4614],
                        [  4977,   4700],
                        [  5016,   4765],
                        [  5047,   4813],
                        [  5071,   4843],
                        [  5086,   4858],
                        [  5095,   4856],
                        [  5101,   4845],
                        [  5101,   4821],
                        [  5094,   4789],
                        [  5084,   4751],
                        [  5077,   4712],
                        [  5030,   4632],
                        [  4900,   4465],
                        [  4674,   4197],
                        [  4354,   3832],
                        [  3919,   3347],
                        [  3322,   2698],
                        [  2564,   1887],
                        [  1735,   1009],
                        [   899,    129],
                        [    63,   -745],
                        [  -766,  -1604],
                        [ -1568,  -2428],
                        [ -2332,  -3205],
                        [ -3051,  -3927],
                        [ -3714,  -4585],
                        [ -4315,  -5172],
                        [ -4848,  -5681],
                        [ -5311,  -6109],
                        [ -5701,  -6455],
                        [ -6016,  -6718],
                        [ -6257,  -6897],
                        [ -6424,  -6996],
                        [ -6521,  -7018],
                        [ -6550,  -6966],
                        [ -6516,  -6846],
                        [ -6423,  -6664],
                        [ -6277,  -6424],
                        [ -6083,  -6133],
                        [ -5847,  -5798],
                        [ -5574,  -5425],
                        [ -5271,  -5021],
                        [ -4943,  -4596],
                        [ -4595,  -4154],
                        [ -4232,  -3713],
                        [ -3861,  -3281],
                        [ -3485,  -2865],
                        [ -3108,  -2471],
                        [ -2736,  -2101],
                        [ -2373,  -1761],
                        [ -2021,  -1433],
                        [ -1683,  -1124],
                        [ -1362,   -826],
                        [ -1060,   -544],
                        [  -779,   -275],
                        [  -519,    -25],
                        [  -280,    212],
                        [   -65,    433],
                        [   128,    643],
                        [   298,    841],
                        [   447,   1027],
                        [   575,   1203],
                        [   685,   1363],
                        [   776,   1509],
                        [   850,   1634],
                        [   908,   1742],
                        [   952,   1830],
                        [   982,   1899],
                        [   999,   1950],
                        [  1005,   1984],
                        [  1001,   2004],
                        [   988,   2012],
                        [   968,   2009],
                        [   940,   1995],
                        [   909,   1973],
                        [   876,   1944],
                        [   847,   1910],
                        [   823,   1871],
                        [   816,   1830],
                        [   825,   1786],
                        [   852,   1739],
                        [   896,   1688],
                        [   956,   1636],
                        [  1030,   1584],
                        [  1113,   1541],
                        [  1204,   1507],
                        [  1350,   1536],
                        [  1547,   1622],
                        [  1810,   1787],
                        [  2140,   2027],
                        [  2519,   2329],
                        [  2948,   2693],
                        [  3339,   3033],
                        [  3698,   3353],
                        [  3989,   3619],
                        [  4212,   3832],
                        [  4366,   3986],
                        [  4446,   4082],
                        [  4453,   4115],
                        [  4388,   4087],
                        [  4252,   3997],
                        [  4044,   3845],
                        [  3770,   3634],
                        [  3431,   3363],
                        [  3034,   3038],
                        [  2577,   2657],
                        [  2071,   2227],
                        [  1514,   1748],
                        [   916,   1226],
                        [   275,    661],
                        [  -401,     61],
                        [ -1112,   -575],
                        [ -1853,  -1241],
                        [ -2620,  -1934],
                        [ -3404,  -2649],
                        [ -4203,  -3384],
                        [ -5003,  -4133],
                        [ -5803,  -4894],
                        [ -6598,  -5662],
                        [ -7386,  -6433],
                        [ -8168,  -7201],
                        [ -8942,  -7966],
                        [ -9710,  -8721],
                        [-10470,  -9463],
                        [-11213, -10186],
                        [-11936, -10888],
                        [-12636, -11562],
                        [-13307, -12205],
                        [-13946, -12812],
                        [-14549, -13383],
                        [-15110, -13912],
                        [-15625, -14397],
                        [-16093, -14837],
                        [-16512, -15230],
                        [-16851, -15546],
                        [-17085, -15758],
                        [-17214, -15867],
                        [-17239, -15871],
                        [-17134, -15746],
                        [-16853, -15446],
                        [-16376, -14952],
                        [-15763, -14327],
                        [-15065, -13622],
                        [-14282, -12840],
                        [-13431, -11997],
                        [-12528, -11110],
                        [-11590, -10196],
                        [-10628,  -9266],
                        [ -9656,  -8332],
                        [ -8685,  -7407],
                        [ -7726,  -6502],
                        [ -6788,  -5623],
                        [ -5880,  -4782],
                        [ -5009,  -3983],
                        [ -4183,  -3235],
                        [ -3405,  -2539],
                        [ -2681,  -1900],
                        [ -2014,  -1320],
                        [ -1407,   -800],
                        [  -860,   -341],
                        [  -377,     55],
                        [    46,    392],
                        [   408,    669],
                        [   709,    887],
                        [   951,   1051],
                        [  1138,   1162],
                        [  1268,   1230],
                        [  1346,   1259],
                        [  1376,   1259],
                        [  1361,   1232],
                        [  1303,   1186],
                        [  1207,   1125],
                        [  1077,   1042],
                        [   917,    943],
                        [   731,    816],
                        [   523,    665],
                        [   297,    489],
                        [    55,    295],
                        [  -196,     82],
                        [  -454,   -148],
                        [  -715,   -395],
                        [  -977,   -657],
                        [ -1233,   -933],
                        [ -1483,  -1222],
                        [ -1723,  -1515],
                        [ -1952,  -1813],
                        [ -2165,  -2101],
                        [ -2361,  -2380],
                        [ -2537,  -2641],
                        [ -2693,  -2884],
                        [ -2823,  -3103],
                        [ -2929,  -3295],
                        [ -3007,  -3460],
                        [ -3057,  -3596],
                        [ -3078,  -3703],
                        [ -3068,  -3778],
                        [ -3030,  -3823],
                        [ -2961,  -3837],
                        [ -2867,  -3820],
                        [ -2746,  -3772],
                        [ -2609,  -3696],
                        [ -2455,  -3590],
                        [ -2295,  -3456],
                        [ -2123,  -3295],
                        [ -1946,  -3106],
                        [ -1768,  -2896],
                        [ -1584,  -2667],
                        [ -1393,  -2420],
                        [ -1229,  -2196],
                        [ -1087,  -1994],
                        [ -1010,  -1857],
                        [  -996,  -1785],
                        [ -1055,  -1788],
                        [ -1186,  -1866],
                        [ -1346,  -1978],
                        [ -1540,  -2129],
                        [ -1697,  -2247],
                        [ -1823,  -2341],
                        [ -1914,  -2404],
                        [ -1970,  -2439],
                        [ -1990,  -2442],
                        [ -1974,  -2415],
                        [ -1926,  -2358],
                        [ -1845,  -2274],
                        [ -1738,  -2167],
                        [ -1604,  -2035],
                        [ -1451,  -1887],
                        [ -1279,  -1718],
                        [ -1095,  -1539],
                        [  -900,  -1346],
                        [  -701,  -1148],
                        [  -497,   -943],
                        [  -295,   -738],
                        [   -92,   -531],
                        [   108,   -327],
                        [   306,   -128],
                        [   496,     67],
                        [   678,    254],
                        [   845,    433],
                        [   995,    604],
                        [  1125,    764],
                        [  1237,    915],
                        [  1334,   1055],
                        [  1417,   1185],
                        [  1498,   1306],
                        [  1578,   1416],
                        [  1656,   1517],
                        [  1735,   1607],
                        [  1812,   1688],
                        [  1889,   1759],
                        [  1965,   1820],
                        [  2042,   1870],
                        [  2117,   1913],
                        [  2192,   1945],
                        [  2264,   1969],
                        [  2334,   1986],
                        [  2401,   1996],
                        [  2453,   1986],
                        [  2493,   1961],
                        [  2532,   1932],
                        [  2570,   1899],
                        [  2585,   1838],
                        [  2525,   1702],
                        [  2356,   1454],
                        [  2099,   1120],
                        [  1783,    732],
                        [  1411,    293],
                        [   995,   -184],
                        [   546,   -686],
                        [    78,  -1198],
                        [  -403,  -1715],
                        [  -886,  -2225],
                        [ -1363,  -2719],
                        [ -1827,  -3191],
                        [ -2272,  -3633],
                        [ -2693,  -4040],
                        [ -3087,  -4409],
                        [ -3448,  -4735],
                        [ -3775,  -5018],
                        [ -4067,  -5257],
                        [ -4323,  -5452],
                        [ -4543,  -5603],
                        [ -4726,  -5714],
                        [ -4875,  -5786],
                        [ -4991,  -5822],
                        [ -5078,  -5824],
                        [ -5137,  -5796],
                        [ -5170,  -5744],
                        [ -5180,  -5670],
                        [ -5170,  -5582],
                        [ -5142,  -5488],
                        [ -5100,  -5394],
                        [ -5046,  -5305],
                        [ -4982,  -5224],
                        [ -4912,  -5158],
                        [ -4838,  -5106],
                        [ -4760,  -5059],
                        [ -4683,  -5020],
                        [ -4605,  -4981],
                        [ -4531,  -4948],
                        [ -4459,  -4916],
                        [ -4390,  -4886],
                        [ -4326,  -4852],
                        [ -4265,  -4817],
                        [ -4209,  -4773],
                        [ -4157,  -4720],
                        [ -4109,  -4656],
                        [ -4064,  -4582],
                        [ -4021,  -4502],
                        [ -3980,  -4418],
                        [ -3939,  -4334],
                        [ -3898,  -4250],
                        [ -3856,  -4169],
                        [ -3813,  -4089],
                        [ -3768,  -4014],
                        [ -3722,  -3941],
                        [ -3673,  -3869],
                        [ -3622,  -3798],
                        [ -3569,  -3729],
                        [ -3512,  -3661],
                        [ -3452,  -3595],
                        [ -3391,  -3528],
                        [ -3323,  -3463],
                        [ -3250,  -3398],
                        [ -3166,  -3335],
                        [ -3075,  -3273],
                        [ -2974,  -3216],
                        [ -2864,  -3166],
                        [ -2746,  -3118],
                        [ -2620,  -3073],
                        [ -2482,  -3021],
                        [ -2337,  -2964],
                        [ -2143,  -2854],
                        [ -1905,  -2698],
                        [ -1613,  -2479],
                        [ -1268,  -2201],
                        [  -878,  -1868],
                        [  -441,  -1480],
                        [   -38,  -1115],
                        [   336,   -769],
                        [   648,   -470],
                        [   899,   -223],
                        [  1080,    -34],
                        [  1191,     98],
                        [  1228,    164],
                        [  1190,    167],
                        [  1076,    102],
                        [   887,    -28],
                        [   627,   -222],
                        [   297,   -481],
                        [   -98,   -800],
                        [  -555,  -1179],
                        [ -1065,  -1612],
                        [ -1628,  -2096],
                        [ -2235,  -2626],
                        [ -2883,  -3199],
                        [ -3564,  -3806],
                        [ -4275,  -4446],
                        [ -5009,  -5111],
                        [ -5762,  -5796],
                        [ -6520,  -6496],
                        [ -7277,  -7205],
                        [ -8019,  -7915],
                        [ -8747,  -8625],
                        [ -9450,  -9325],
                        [-10128, -10013],
                        [-10780, -10680],
                        [-11406, -11325],
                        [-12005, -11940],
                        [-12573, -12521],
                        [-13104, -13063],
                        [-13595, -13563],
                        [-14041, -14016],
                        [-14440, -14418],
                        [-14788, -14766],
                        [-15082, -15057],
                        [-15321, -15289],
                        [-15500, -15458],
                        [-15620, -15564],
                        [-15677, -15607],
                        [-15683, -15597],
                        [-15663, -15559],
                        [-15638, -15515],
                        [-15608, -15463],
                        [-15556, -15385],
                        [-15434, -15234],
                        [-15186, -14953],
                        [-14805, -14536],
                        [-14307, -14004],
                        [-13700, -13363],
                        [-12998, -12629],
                        [-12216, -11816],
                        [-11369, -10942],
                        [-10468, -10017],
                        [ -9530,  -9057],
                        [ -8566,  -8075],
                        [ -7590,  -7084],
                        [ -6611,  -6095],
                        [ -5640,  -5121],
                        [ -4688,  -4171],
                        [ -3765,  -3254],
                        [ -2876,  -2377],
                        [ -2030,  -1546],
                        [ -1233,   -769],
                        [  -490,    -48],
                        [   197,    613],
                        [   825,   1214],
                        [  1392,   1752],
                        [  1896,   2227],
                        [  2340,   2639],
                        [  2723,   2992],
                        [  3046,   3284],
                        [  3312,   3525],
                        [  3522,   3717],
                        [  3681,   3868],
                        [  3791,   3979],
                        [  3857,   4058],
                        [  3883,   4111],
                        [  3874,   4140],
                        [  3833,   4145],
                        [  3766,   4127],
                        [  3677,   4086],
                        [  3571,   4026],
                        [  3452,   3950],
                        [  3324,   3856],
                        [  3193,   3752],
                        [  3062,   3633],
                        [  2935,   3499],
                        [  2815,   3355],
                        [  2706,   3200],
                        [  2611,   3040],
                        [  2531,   2878],
                        [  2468,   2726],
                        [  2425,   2586],
                        [  2402,   2464],
                        [  2401,   2360],
                        [  2421,   2279],
                        [  2466,   2223],
                        [  2533,   2192],
                        [  2622,   2186],
                        [  2732,   2207],
                        [  2864,   2254],
                        [  3015,   2324],
                        [  3185,   2420],
                        [  3370,   2537],
                        [  3571,   2676],
                        [  3781,   2835],
                        [  3998,   3010],
                        [  4218,   3200],
                        [  4440,   3407],
                        [  4657,   3625],
                        [  4866,   3850],
                        [  5062,   4077],
                        [  5243,   4305],
                        [  5381,   4499],
                        [  5475,   4658],
                        [  5502,   4754],
                        [  5460,   4787],
                        [  5338,   4743],
                        [  5136,   4619],
                        [  4882,   4444],
                        [  4574,   4213],
                        [  4271,   3984],
                        [  3966,   3751],
                        [  3670,   3522],
                        [  3382,   3296],
                        [  3112,   3083],
                        [  2859,   2882],
                        [  2629,   2698],
                        [  2421,   2529],
                        [  2238,   2378],
                        [  2078,   2247],
                        [  1944,   2134],
                        [  1834,   2041],
                        [  1745,   1967],
                        [  1679,   1912],
                        [  1632,   1874],
                        [  1606,   1855],
                        [  1597,   1850],
                        [  1606,   1861],
                        [  1632,   1887],
                        [  1675,   1926],
                        [  1730,   1976],
                        [  1796,   2038],
                        [  1864,   2108],
                        [  1935,   2189],
                        [  2004,   2277],
                        [  2073,   2373],
                        [  2143,   2472],
                        [  2217,   2579],
                        [  2300,   2688],
                        [  2394,   2800],
                        [  2498,   2913],
                        [  2609,   3027],
                        [  2727,   3140],
                        [  2850,   3252],
                        [  2977,   3361],
                        [  3106,   3465],
                        [  3237,   3562],
                        [  3368,   3651],
                        [  3495,   3731],
                        [  3618,   3799],
                        [  3733,   3856],
                        [  3874,   3936],
                        [  4086,   4084],
                        [  4391,   4324],
                        [  4784,   4651],
                        [  5252,   5049],
                        [  5745,   5469],
                        [  6181,   5829],
                        [  6513,   6085],
                        [  6745,   6241],
                        [  6880,   6304],
                        [  6926,   6278],
                        [  6888,   6175],
                        [  6776,   6002],
                        [  6595,   5766],
                        [  6356,   5477],
                        [  6065,   5144],
                        [  5731,   4774],
                        [  5360,   4376],
                        [  4960,   3957],
                        [  4537,   3525],
                        [  4097,   3084],
                        [  3649,   2641],
                        [  3195,   2203],
                        [  2742,   1771],
                        [  2295,   1352],
                        [  1856,    946],
                        [  1428,    555],
                        [  1016,    181],
                        [   619,   -173],
                        [   241,   -508],
                        [  -118,   -824],
                        [  -455,  -1121],
                        [  -772,  -1399],
                        [ -1066,  -1662],
                        [ -1339,  -1910],
                        [ -1588,  -2144],
                        [ -1816,  -2366],
                        [ -2022,  -2580],
                        [ -2206,  -2786],
                        [ -2368,  -2981],
                        [ -2510,  -3166],
                        [ -2631,  -3335],
                        [ -2732,  -3492],
                        [ -2815,  -3632],
                        [ -2879,  -3755],
                        [ -2924,  -3855],
                        [ -2953,  -3934],
                        [ -2965,  -3983],
                        [ -2961,  -4003],
                        [ -2942,  -3993],
                        [ -2909,  -3954],
                        [ -2861,  -3891],
                        [ -2801,  -3805],
                        [ -2726,  -3704],
                        [ -2639,  -3589],
                        [ -2541,  -3460],
                        [ -2431,  -3322],
                        [ -2312,  -3174],
                        [ -2184,  -3020],
                        [ -2047,  -2860],
                        [ -1903,  -2696],
                        [ -1753,  -2529],
                        [ -1600,  -2361],
                        [ -1445,  -2194],
                        [ -1289,  -2028],
                        [ -1135,  -1865],
                        [  -985,  -1708],
                        [  -839,  -1556],
                        [  -701,  -1411],
                        [  -573,  -1279],
                        [  -454,  -1159],
                        [  -340,  -1051],
                        [  -232,   -955],
                        [  -120,   -862],
                        [    -9,   -775],
                        [   125,   -667],
                        [   279,   -542],
                        [   457,   -391],
                        [   660,   -215],
                        [   894,     -5],
                        [  1159,    241],
                        [  1406,    472],
                        [  1637,    692],
                        [  1828,    879],
                        [  1980,   1034],
                        [  2083,   1146],
                        [  2138,   1217],
                        [  2136,   1239],
                        [  2080,   1213],
                        [  1966,   1135],
                        [  1796,   1008],
                        [  1571,    830],
                        [  1292,    602],
                        [   964,    329],
                        [   591,     11],
                        [   176,   -347],
                        [  -275,   -743],
                        [  -756,  -1170],
                        [ -1263,  -1624],
                        [ -1788,  -2100],
                        [ -2329,  -2594],
                        [ -2876,  -3096],
                        [ -3426,  -3606],
                        [ -3963,  -4113],
                        [ -4486,  -4616],
                        [ -4981,  -5106],
                        [ -5448,  -5579],
                        [ -5878,  -6030],
                        [ -6269,  -6455],
                        [ -6624,  -6845],
                        [ -6940,  -7201],
                        [ -7218,  -7516],
                        [ -7456,  -7788],
                        [ -7646,  -8013],
                        [ -7789,  -8189],
                        [ -7882,  -8313],
                        [ -7925,  -8384],
                        [ -7916,  -8399],
                        [ -7855,  -8357],
                        [ -7742,  -8257],
                        [ -7579,  -8100],
                        [ -7360,  -7881],
                        [ -7094,  -7611],
                        [ -6839,  -7347],
                        [ -6659,  -7154],
                        [ -6579,  -7057],
                        [ -6599,  -7057],
                        [ -6718,  -7147],
                        [ -6892,  -7285],
                        [ -7018,  -7369],
                        [ -7031,  -7331],
                        [ -6931,  -7174],
                        [ -6725,  -6907],
                        [ -6420,  -6537],
                        [ -6026,  -6074],
                        [ -5553,  -5530],
                        [ -5010,  -4914],
                        [ -4407,  -4238],
                        [ -3757,  -3515],
                        [ -3068,  -2755],
                        [ -2351,  -1970],
                        [ -1615,  -1168],
                        [  -871,   -362],
                        [  -126,    440],
                        [   611,   1231],
                        [  1333,   2000],
                        [  2031,   2740],
                        [  2703,   3448],
                        [  3343,   4119],
                        [  3946,   4750],
                        [  4510,   5338],
                        [  5034,   5882],
                        [  5516,   6380],
                        [  5956,   6833],
                        [  6355,   7241],
                        [  6715,   7607],
                        [  7033,   7931],
                        [  7316,   8216],
                        [  7563,   8463],
                        [  7777,   8680],
                        [  7963,   8869],
                        [  8123,   9038],
                        [  8262,   9190],
                        [  8381,   9327],
                        [  8484,   9451],
                        [  8576,   9564],
                        [  8659,   9669],
                        [  8736,   9764],
                        [  8812,   9853],
                        [  8887,   9931],
                        [  8966,  10000],
                        [  9050,  10059],
                        [  9142,  10108],
                        [  9242,  10152],
                        [  9354,  10190],
                        [  9474,  10233],
                        [  9605,  10281],
                        [  9745,  10337],
                        [  9896,  10402],
                        [ 10053,  10476],
                        [ 10220,  10558],
                        [ 10392,  10653],
                        [ 10569,  10756],
                        [ 10746,  10867],
                        [ 10925,  10987],
                        [ 11101,  11113],
                        [ 11274,  11243],
                        [ 11442,  11375],
                        [ 11606,  11510],
                        [ 11762,  11642],
                        [ 11912,  11771],
                        [ 12053,  11893],
                        [ 12187,  12011],
                        [ 12303,  12121],
                        [ 12400,  12217],
                        [ 12467,  12296],
                        [ 12504,  12358],
                        [ 12492,  12386],
                        [ 12433,  12378],
                        [ 12322,  12328],
                        [ 12158,  12235],
                        [ 11927,  12080],
                        [ 11628,  11864],
                        [ 11267,  11590],
                        [ 10844,  11254],
                        [ 10394,  10892],
                        [  9913,  10499],
                        [  9419,  10090],
                        [  8908,   9662],
                        [  8398,   9229],
                        [  7887,   8791],
                        [  7387,   8358],
                        [  6900,   7931],
                        [  6434,   7516],
                        [  5990,   7117],
                        [  5572,   6737],
                        [  5183,   6378],
                        [  4825,   6044],
                        [  4498,   5736],
                        [  4205,   5456],
                        [  3946,   5204],
                        [  3720,   4981],
                        [  3530,   4788],
                        [  3372,   4623],
                        [  3248,   4488],
                        [  3152,   4380],
                        [  3083,   4301],
                        [  3035,   4245],
                        [  3007,   4214],
                        [  2995,   4206],
                        [  3000,   4219],
                        [  3018,   4249],
                        [  3051,   4297],
                        [  3103,   4357],
                        [  3172,   4431],
                        [  3253,   4513],
                        [  3346,   4604],
                        [  3446,   4698],
                        [  3551,   4796],
                        [  3661,   4895],
                        [  3772,   4990],
                        [  3880,   5079],
                        [  3985,   5159],
                        [  4085,   5230],
                        [  4171,   5280],
                        [  4253,   5324],
                        [  4407,   5440],
                        [  4701,   5695],
                        [  5152,   6105],
                        [  5760,   6671],
                        [  6523,   7391],
                        [  7399,   8218],
                        [  8260,   9025],
                        [  9013,   9722],
                        [  9652,  10300],
                        [ 10177,  10762],
                        [ 10589,  11110],
                        [ 10889,  11344],
                        [ 11081,  11470],
                        [ 11167,  11491],
                        [ 11156,  11415],
                        [ 11051,  11248],
                        [ 10862,  10999],
                        [ 10593,  10673],
                        [ 10255,  10281],
                        [  9853,   9830],
                        [  9398,   9328],
                        [  8896,   8786],
                        [  8357,   8210],
                        [  7790,   7609],
                        [  7200,   6990],
                        [  6597,   6360],
                        [  5984,   5723],
                        [  5371,   5087],
                        [  4760,   4455],
                        [  4159,   3833],
                        [  3572,   3223],
                        [  3002,   2632],
                        [  2452,   2061],
                        [  1928,   1516],
                        [  1431,   1000],
                        [   964,    516],
                        [   528,     65],
                        [   126,   -358],
                        [  -243,   -752],
                        [  -576,  -1121],
                        [  -874,  -1463],
                        [ -1138,  -1778],
                        [ -1367,  -2067],
                        [ -1561,  -2326],
                        [ -1723,  -2558],
                        [ -1853,  -2755],
                        [ -1952,  -2919],
                        [ -2023,  -3044],
                        [ -2067,  -3134],
                        [ -2086,  -3184],
                        [ -2082,  -3200],
                        [ -2056,  -3185],
                        [ -2013,  -3141],
                        [ -1952,  -3076],
                        [ -1874,  -2991],
                        [ -1784,  -2888],
                        [ -1683,  -2769],
                        [ -1571,  -2639],
                        [ -1453,  -2499],
                        [ -1328,  -2355],
                        [ -1199,  -2207],
                        [ -1069,  -2058],
                        [  -938,  -1910],
                        [  -813,  -1767],
                        [  -691,  -1630],
                        [  -583,  -1502],
                        [  -489,  -1384],
                        [  -416,  -1277],
                        [  -367,  -1185],
                        [  -344,  -1110],
                        [  -346,  -1051],
                        [  -366,  -1011],
                        [  -405,   -988],
                        [  -451,   -982],
                        [  -505,   -991],
                        [  -570,  -1020],
                        [  -645,  -1066],
                        [  -727,  -1125],
                        [  -816,  -1197],
                        [  -885,  -1254],
                        [  -935,  -1298],
                        [  -977,  -1334],
                        [ -1008,  -1363],
                        [ -1042,  -1395],
                        [ -1077,  -1429],
                        [ -1121,  -1475],
                        [ -1175,  -1529],
                        [ -1246,  -1599],
                        [ -1331,  -1683],
                        [ -1437,  -1785],
                        [ -1561,  -1905],
                        [ -1705,  -2042],
                        [ -1866,  -2195],
                        [ -2047,  -2366],
                        [ -2241,  -2550],
                        [ -2448,  -2748],
                        [ -2666,  -2955],
                        [ -2889,  -3169],
                        [ -3116,  -3387],
                        [ -3339,  -3604],
                        [ -3559,  -3819],
                        [ -3767,  -4025],
                        [ -3962,  -4222],
                        [ -4133,  -4402],
                        [ -4281,  -4565],
                        [ -4397,  -4704],
                        [ -4482,  -4818],
                        [ -4527,  -4903],
                        [ -4535,  -4956],
                        [ -4506,  -4975],
                        [ -4439,  -4958],
                        [ -4335,  -4901],
                        [ -4193,  -4806],
                        [ -4013,  -4670],
                        [ -3793,  -4495],
                        [ -3536,  -4279],
                        [ -3243,  -4024],
                        [ -2913,  -3730],
                        [ -2549,  -3396],
                        [ -2156,  -3025],
                        [ -1735,  -2619],
                        [ -1276,  -2168],
                        [  -813,  -1704],
                        [  -434,  -1320],
                        [  -215,  -1092],
                        [  -175,  -1037],
                        [  -319,  -1161],
                        [  -663,  -1476],
                        [ -1168,  -1943],
                        [ -1698,  -2424],
                        [ -2152,  -2818],
                        [ -2522,  -3119],
                        [ -2816,  -3335],
                        [ -3029,  -3464],
                        [ -3163,  -3505],
                        [ -3220,  -3465],
                        [ -3205,  -3346],
                        [ -3121,  -3157],
                        [ -2975,  -2901],
                        [ -2771,  -2589],
                        [ -2516,  -2224],
                        [ -2215,  -1816],
                        [ -1877,  -1372],
                        [ -1506,   -899],
                        [ -1108,   -403],
                        [  -692,    106],
                        [  -262,    623],
                        [   176,   1142],
                        [   618,   1659],
                        [  1058,   2169],
                        [  1495,   2669],
                        [  1926,   3157],
                        [  2348,   3629],
                        [  2760,   4086],
                        [  3160,   4525],
                        [  3547,   4942],
                        [  3923,   5337],
                        [  4284,   5705],
                        [  4632,   6047],
                        [  4968,   6368],
                        [  5290,   6665],
                        [  5601,   6951],
                        [  5903,   7226],
                        [  6195,   7497],
                        [  6478,   7765],
                        [  6754,   8030],
                        [  7024,   8293],
                        [  7287,   8553],
                        [  7547,   8811],
                        [  7802,   9059],
                        [  8053,   9300],
                        [  8301,   9530],
                        [  8546,   9750],
                        [  8786,   9959],
                        [  9023,  10157],
                        [  9254,  10347],
                        [  9479,  10530],
                        [  9694,  10704],
                        [  9900,  10869],
                        [ 10095,  11022],
                        [ 10275,  11164],
                        [ 10438,  11294],
                        [ 10584,  11412],
                        [ 10707,  11515],
                        [ 10809,  11603],
                        [ 10884,  11673],
                        [ 10934,  11727],
                        [ 10960,  11760],
                        [ 10959,  11773],
                        [ 10940,  11763],
                        [ 10900,  11731],
                        [ 10844,  11674],
                        [ 10775,  11593],
                        [ 10684,  11486],
                        [ 10571,  11352],
                        [ 10423,  11191],
                        [ 10242,  11004],
                        [ 10031,  10800],
                        [  9791,  10579],
                        [  9532,  10351],
                        [  9257,  10117],
                        [  8948,   9856],
                        [  8605,   9572],
                        [  8205,   9233],
                        [  7750,   8844],
                        [  7248,   8412],
                        [  6702,   7937],
                        [  6125,   7432],
                        [  5519,   6897],
                        [  4901,   6347],
                        [  4271,   5783],
                        [  3642,   5215],
                        [  3017,   4645],
                        [  2408,   4084],
                        [  1815,   3534],
                        [  1250,   3004],
                        [   711,   2493],
                        [   207,   2009],
                        [  -262,   1553],
                        [  -692,   1129],
                        [ -1082,    739],
                        [ -1432,    383],
                        [ -1741,     63],
                        [ -2011,   -221],
                        [ -2242,   -469],
                        [ -2437,   -683],
                        [ -2596,   -861],
                        [ -2724,  -1009],
                        [ -2823,  -1126],
                        [ -2897,  -1216],
                        [ -2949,  -1279],
                        [ -2982,  -1321],
                        [ -2998,  -1342],
                        [ -2999,  -1348],
                        [ -2984,  -1339],
                        [ -2961,  -1320],
                        [ -2930,  -1293],
                        [ -2897,  -1261],
                        [ -2861,  -1225],
                        [ -2827,  -1190],
                        [ -2797,  -1156],
                        [ -2774,  -1133],
                        [ -2756,  -1115],
                        [ -2750,  -1111],
                        [ -2764,  -1132],
                        [ -2769,  -1142],
                        [ -2665,  -1044],
                        [ -2391,   -775],
                        [ -1936,   -325],
                        [ -1294,    310],
                        [  -445,   1149],
                        [   574,   2152],
                        [  1613,   3166],
                        [  2563,   4086],
                        [  3416,   4902],
                        [  4174,   5615],
                        [  4827,   6217],
                        [  5371,   6703],
                        [  5805,   7074],
                        [  6130,   7330],
                        [  6347,   7474],
                        [  6460,   7510],
                        [  6475,   7443],
                        [  6395,   7278],
                        [  6229,   7025],
                        [  5982,   6689],
                        [  5662,   6279],
                        [  5278,   5804],
                        [  4839,   5273],
                        [  4354,   4697],
                        [  3832,   4084],
                        [  3280,   3443],
                        [  2707,   2780],
                        [  2121,   2104],
                        [  1528,   1422],
                        [   933,    739],
                        [   345,     63],
                        [  -232,   -598],
                        [  -793,  -1241],
                        [ -1333,  -1852],
                        [ -1849,  -2429],
                        [ -2335,  -2965],
                        [ -2792,  -3458],
                        [ -3214,  -3912],
                        [ -3603,  -4326],
                        [ -3955,  -4708],
                        [ -4272,  -5058],
                        [ -4553,  -5380],
                        [ -4799,  -5674],
                        [ -5012,  -5939],
                        [ -5190,  -6176],
                        [ -5338,  -6382],
                        [ -5456,  -6559],
                        [ -5547,  -6705],
                        [ -5613,  -6821],
                        [ -5657,  -6909],
                        [ -5683,  -6970],
                        [ -5692,  -7007],
                        [ -5686,  -7022],
                        [ -5670,  -7022],
                        [ -5644,  -7008],
                        [ -5612,  -6979],
                        [ -5575,  -6941],
                        [ -5536,  -6895],
                        [ -5497,  -6842],
                        [ -5458,  -6789],
                        [ -5419,  -6736],
                        [ -5384,  -6686],
                        [ -5355,  -6641],
                        [ -5332,  -6602],
                        [ -5319,  -6571],
                        [ -5321,  -6549],
                        [ -5341,  -6537],
                        [ -5389,  -6537],
                        [ -5465,  -6548],
                        [ -5571,  -6572],
                        [ -5706,  -6607],
                        [ -5861,  -6654],
                        [ -6034,  -6715],
                        [ -6221,  -6796],
                        [ -6420,  -6897],
                        [ -6654,  -7046],
                        [ -6919,  -7238],
                        [ -7213,  -7470],
                        [ -7534,  -7742],
                        [ -7841,  -8008],
                        [ -8135,  -8272],
                        [ -8383,  -8500],
                        [ -8587,  -8691],
                        [ -8750,  -8850],
                        [ -8869,  -8973],
                        [ -8954,  -9068],
                        [ -9001,  -9133],
                        [ -9020,  -9173],
                        [ -9007,  -9186],
                        [ -8971,  -9179],
                        [ -8909,  -9149],
                        [ -8828,  -9100],
                        [ -8725,  -9032],
                        [ -8608,  -8947],
                        [ -8472,  -8845],
                        [ -8322,  -8727],
                        [ -8158,  -8593],
                        [ -7978,  -8445],
                        [ -7782,  -8280],
                        [ -7569,  -8099],
                        [ -7339,  -7902],
                        [ -7091,  -7688],
                        [ -6823,  -7456],
                        [ -6538,  -7205],
                        [ -6235,  -6936],
                        [ -5911,  -6648],
                        [ -5567,  -6340],
                        [ -5200,  -6012],
                        [ -4810,  -5664],
                        [ -4398,  -5296],
                        [ -3966,  -4909],
                        [ -3516,  -4503],
                        [ -3049,  -4080],
                        [ -2566,  -3642],
                        [ -2069,  -3188],
                        [ -1561,  -2724],
                        [ -1046,  -2250],
                        [  -524,  -1768],
                        [     1,  -1279],
                        [   522,   -787],
                        [  1041,   -293],
                        [  1566,    212],
                        [  2048,    680],
                        [  2388,   1010],
                        [  2530,   1146],
                        [  2466,   1081],
                        [  2180,    799],
                        [  1640,    271],
                        [   880,   -468],
                        [    47,  -1270],
                        [  -757,  -2032],
                        [ -1526,  -2749],
                        [ -2256,  -3419],
                        [ -2936,  -4029],
                        [ -3559,  -4573],
                        [ -4118,  -5046],
                        [ -4613,  -5448],
                        [ -5038,  -5775],
                        [ -5394,  -6029],
                        [ -5679,  -6209],
                        [ -5896,  -6319],
                        [ -6044,  -6359],
                        [ -6127,  -6333],
                        [ -6147,  -6244],
                        [ -6108,  -6099],
                        [ -6015,  -5901],
                        [ -5870,  -5657],
                        [ -5680,  -5372],
                        [ -5447,  -5051],
                        [ -5176,  -4695],
                        [ -4870,  -4312],
                        [ -4534,  -3902],
                        [ -4171,  -3473],
                        [ -3784,  -3027],
                        [ -3376,  -2566],
                        [ -2952,  -2103],
                        [ -2513,  -1637],
                        [ -2064,  -1181],
                        [ -1606,   -735],
                        [ -1145,   -302],
                        [  -680,    116],
                        [  -215,    530],
                        [   249,    937],
                        [   709,   1345],
                        [  1164,   1753],
                        [  1610,   2162],
                        [  2048,   2569],
                        [  2473,   2971],
                        [  2888,   3369],
                        [  3286,   3755],
                        [  3668,   4130],
                        [  4032,   4490],
                        [  4377,   4835],
                        [  4700,   5160],
                        [  5000,   5465],
                        [  5276,   5746],
                        [  5525,   6004],
                        [  5745,   6234],
                        [  5936,   6437],
                        [  6093,   6608],
                        [  6218,   6745],
                        [  6305,   6849],
                        [  6356,   6920],
                        [  6367,   6957],
                        [  6338,   6960],
                        [  6268,   6927],
                        [  6159,   6861],
                        [  6013,   6758],
                        [  5831,   6621],
                        [  5624,   6450],
                        [  5393,   6247],
                        [  5149,   6009],
                        [  4890,   5740],
                        [  4617,   5441],
                        [  4330,   5112],
                        [  4021,   4761],
                        [  3692,   4388],
                        [  3369,   4032],
                        [  3052,   3692],
                        [  2763,   3389],
                        [  2502,   3124],
                        [  2251,   2880],
                        [  2016,   2657],
                        [  1738,   2399],
                        [  1423,   2109],
                        [  1059,   1777],
                        [   650,   1404],
                        [   206,    999],
                        [  -271,    565],
                        [  -767,    111],
                        [ -1285,   -361],
                        [ -1808,   -841],
                        [ -2337,  -1328],
                        [ -2859,  -1811],
                        [ -3374,  -2291],
                        [ -3872,  -2758],
                        [ -4351,  -3211],
                        [ -4804,  -3643],
                        [ -5229,  -4054],
                        [ -5623,  -4440],
                        [ -5985,  -4800],
                        [ -6314,  -5130],
                        [ -6612,  -5432],
                        [ -6879,  -5703],
                        [ -7113,  -5945],
                        [ -7317,  -6160],
                        [ -7490,  -6346],
                        [ -7633,  -6507],
                        [ -7749,  -6643],
                        [ -7845,  -6758],
                        [ -7922,  -6854],
                        [ -7988,  -6934],
                        [ -8044,  -6999],
                        [ -8094,  -7054],
                        [ -8139,  -7100],
                        [ -8183,  -7139],
                        [ -8227,  -7176],
                        [ -8276,  -7211],
                        [ -8327,  -7244],
                        [ -8384,  -7279],
                        [ -8449,  -7317],
                        [ -8523,  -7362],
                        [ -8601,  -7411],
                        [ -8693,  -7471],
                        [ -8802,  -7550],
                        [ -8883,  -7600],
                        [ -8847,  -7532],
                        [ -8654,  -7308],
                        [ -8301,  -6923],
                        [ -7767,  -6362],
                        [ -7018,  -5590],
                        [ -6080,  -4636],
                        [ -5090,  -3638],
                        [ -4141,  -2693],
                        [ -3240,  -1802],
                        [ -2389,   -972],
                        [ -1602,   -216],
                        [  -889,    456],
                        [  -252,   1040],
                        [   304,   1534],
                        [   777,   1935],
                        [  1165,   2242],
                        [  1471,   2457],
                        [  1695,   2584],
                        [  1840,   2624],
                        [  1913,   2583],
                        [  1915,   2466],
                        [  1854,   2281],
                        [  1736,   2035],
                        [  1569,   1736],
                        [  1358,   1391],
                        [  1110,   1009],
                        [   832,    596],
                        [   531,    160],
                        [   211,   -293],
                        [  -119,   -757],
                        [  -457,  -1225],
                        [  -797,  -1689],
                        [ -1134,  -2144],
                        [ -1465,  -2576],
                        [ -1783,  -2980],
                        [ -2088,  -3350],
                        [ -2377,  -3682],
                        [ -2647,  -3981],
                        [ -2897,  -4244],
                        [ -3127,  -4483],
                        [ -3337,  -4700],
                        [ -3526,  -4899],
                        [ -3695,  -5084],
                        [ -3845,  -5252],
                        [ -3976,  -5406],
                        [ -4092,  -5546],
                        [ -4193,  -5674],
                        [ -4279,  -5790],
                        [ -4355,  -5896],
                        [ -4423,  -5996],
                        [ -4483,  -6090],
                        [ -4540,  -6177],
                        [ -4595,  -6259],
                        [ -4648,  -6336],
                        [ -4704,  -6411],
                        [ -4760,  -6481],
                        [ -4823,  -6549],
                        [ -4889,  -6615],
                        [ -4961,  -6680],
                        [ -5038,  -6748],
                        [ -5120,  -6820],
                        [ -5209,  -6896],
                        [ -5303,  -6977],
                        [ -5406,  -7064],
                        [ -5514,  -7158],
                        [ -5639,  -7258],
                        [ -5776,  -7365],
                        [ -5939,  -7477],
                        [ -6127,  -7594],
                        [ -6339,  -7716],
                        [ -6576,  -7841],
                        [ -6828,  -7970],
                        [ -7094,  -8100],
                        [ -7379,  -8256],
                        [ -7681,  -8435],
                        [ -8032,  -8678],
                        [ -8430,  -8981],
                        [ -8871,  -9339],
                        [ -9354,  -9752],
                        [ -9823, -10168],
                        [-10283, -10585],
                        [-10669, -10942],
                        [-10983, -11241],
                        [-11226, -11480],
                        [-11394, -11656],
                        [-11490, -11772],
                        [-11512, -11824],
                        [-11468, -11819],
                        [-11355, -11753],
                        [-11182, -11633],
                        [-10949, -11459],
                        [-10664, -11235],
                        [-10326, -10961],
                        [ -9945, -10643],
                        [ -9520, -10282],
                        [ -9060,  -9884],
                        [ -8565,  -9448],
                        [ -8040,  -8981],
                        [ -7486,  -8483],
                        [ -6906,  -7959],
                        [ -6303,  -7411],
                        [ -5683,  -6842],
                        [ -5047,  -6253],
                        [ -4405,  -5649],
                        [ -3755,  -5033],
                        [ -3103,  -4405],
                        [ -2447,  -3768],
                        [ -1788,  -3127],
                        [ -1125,  -2483],
                        [  -458,  -1837],
                        [   208,  -1194],
                        [   869,   -557],
                        [  1523,     74],
                        [  2168,    694],
                        [  2801,   1300],
                        [  3417,   1889],
                        [  4013,   2456],
                        [  4589,   3004],
                        [  5139,   3525],
                        [  5660,   4018],
                        [  6151,   4484],
                        [  6619,   4929],
                        [  7013,   5299],
                        [  7258,   5524],
                        [  7330,   5576],
                        [  7226,   5457],
                        [  6924,   5141],
                        [  6381,   4590],
                        [  5616,   3823],
                        [  4751,   2963],
                        [  3864,   2090],
                        [  2964,   1210],
                        [  2059,    331],
                        [  1168,   -526],
                        [   306,  -1347],
                        [  -522,  -2125],
                        [ -1303,  -2849],
                        [ -2029,  -3512],
                        [ -2693,  -4108],
                        [ -3290,  -4630],
                        [ -3816,  -5078],
                        [ -4266,  -5447],
                        [ -4643,  -5738],
                        [ -4942,  -5948],
                        [ -5163,  -6082],
                        [ -5312,  -6140],
                        [ -5388,  -6126],
                        [ -5394,  -6045],
                        [ -5334,  -5900],
                        [ -5212,  -5696],
                        [ -5032,  -5436],
                        [ -4797,  -5127],
                        [ -4512,  -4771],
                        [ -4184,  -4375],
                        [ -3814,  -3946],
                        [ -3411,  -3493],
                        [ -2977,  -3023],
                        [ -2521,  -2550],
                        [ -2045,  -2077],
                        [ -1557,  -1610],
                        [ -1058,  -1155],
                        [  -557,   -704],
                        [   -54,   -262],
                        [   444,    180],
                        [   933,    619],
                        [  1410,   1055],
                        [  1870,   1483],
                        [  2312,   1900],
                        [  2729,   2306],
                        [  3121,   2695],
                        [  3484,   3068],
                        [  3816,   3422],
                        [  4114,   3757],
                        [  4375,   4065],
                        [  4600,   4349],
                        [  4786,   4599],
                        [  4934,   4815],
                        [  5040,   4992],
                        [  5105,   5131],
                        [  5128,   5226],
                        [  5109,   5278],
                        [  5046,   5288],
                        [  4941,   5254],
                        [  4792,   5180],
                        [  4602,   5064],
                        [  4371,   4910],
                        [  4102,   4717],
                        [  3801,   4489],
                        [  3466,   4226],
                        [  3116,   3932],
                        [  2750,   3608],
                        [  2380,   3257],
                        [  2005,   2878],
                        [  1634,   2480],
                        [  1266,   2063],
                        [   902,   1640],
                        [   544,   1214],
                        [   232,    839],
                        [   -33,    516],
                        [  -230,    267],
                        [  -356,     96],
                        [  -427,    -14],
                        [  -439,    -59],
                        [  -472,   -119],
                        [  -519,   -184],
                        [  -605,   -283],
                        [  -726,   -410],
                        [  -880,   -564],
                        [ -1064,   -742],
                        [ -1274,   -941],
                        [ -1510,  -1160],
                        [ -1762,  -1392],
                        [ -2031,  -1638],
                        [ -2308,  -1892],
                        [ -2596,  -2153],
                        [ -2882,  -2415],
                        [ -3170,  -2679],
                        [ -3449,  -2938],
                        [ -3723,  -3194],
                        [ -3985,  -3442],
                        [ -4238,  -3681],
                        [ -4480,  -3911],
                        [ -4713,  -4132],
                        [ -4931,  -4340],
                        [ -5140,  -4539],
                        [ -5331,  -4726],
                        [ -5506,  -4903],
                        [ -5665,  -5070],
                        [ -5809,  -5230],
                        [ -5945,  -5383],
                        [ -6075,  -5529],
                        [ -6207,  -5671],
                        [ -6341,  -5809],
                        [ -6481,  -5945],
                        [ -6625,  -6079],
                        [ -6775,  -6213],
                        [ -6931,  -6346],
                        [ -7093,  -6481],
                        [ -7261,  -6613],
                        [ -7433,  -6745],
                        [ -7610,  -6875],
                        [ -7790,  -7007],
                        [ -7969,  -7132],
                        [ -8153,  -7261],
                        [ -8339,  -7390],
                        [ -8486,  -7478],
                        [ -8541,  -7475],
                        [ -8493,  -7371],
                        [ -8340,  -7162],
                        [ -8055,  -6825],
                        [ -7591,  -6313],
                        [ -6949,  -5631],
                        [ -6223,  -4874],
                        [ -5476,  -4103],
                        [ -4708,  -3321],
                        [ -3928,  -2536],
                        [ -3153,  -1766],
                        [ -2393,  -1024],
                        [ -1655,   -315],
                        [  -946,    353],
                        [  -273,    971],
                        [   358,   1535],
                        [   943,   2043],
                        [  1480,   2493],
                        [  1967,   2881],
                        [  2402,   3209],
                        [  2787,   3478],
                        [  3122,   3690],
                        [  3410,   3848],
                        [  3651,   3955],
                        [  3851,   4017],
                        [  4011,   4037],
                        [  4134,   4019],
                        [  4223,   3969],
                        [  4282,   3889],
                        [  4314,   3785],
                        [  4321,   3661],
                        [  4307,   3524],
                        [  4275,   3377],
                        [  4228,   3231],
                        [  4169,   3092],
                        [  4098,   2966],
                        [  4020,   2857],
                        [  3933,   2759],
                        [  3840,   2678],
                        [  3742,   2600],
                        [  3638,   2525],
                        [  3529,   2446],
                        [  3416,   2361],
                        [  3297,   2270],
                        [  3174,   2173],
                        [  3046,   2065],
                        [  2913,   1950],
                        [  2773,   1819],
                        [  2628,   1676],
                        [  2476,   1516],
                        [  2316,   1341],
                        [  2150,   1154],
                        [  1976,    954],
                        [  1793,    748],
                        [  1603,    535],
                        [  1406,    321],
                        [  1199,    102],
                        [   988,   -119],
                        [   771,   -338],
                        [   552,   -558],
                        [   330,   -778],
                        [   107,   -997],
                        [  -115,  -1214],
                        [  -335,  -1428],
                        [  -553,  -1638],
                        [  -771,  -1843],
                        [  -990,  -2041],
                        [ -1218,  -2231],
                        [ -1451,  -2411],
                        [ -1690,  -2576],
                        [ -1936,  -2729],
                        [ -2183,  -2870],
                        [ -2430,  -2996],
                        [ -2694,  -3142],
                        [ -2971,  -3304],
                        [ -3296,  -3525],
                        [ -3667,  -3800],
                        [ -4081,  -4131],
                        [ -4539,  -4517],
                        [ -4985,  -4903],
                        [ -5420,  -5293],
                        [ -5774,  -5613],
                        [ -6046,  -5864],
                        [ -6234,  -6045],
                        [ -6338,  -6152],
                        [ -6353,  -6185],
                        [ -6282,  -6142],
                        [ -6129,  -6026],
                        [ -5892,  -5837],
                        [ -5582,  -5582],
                        [ -5197,  -5259],
                        [ -4747,  -4873],
                        [ -4233,  -4430],
                        [ -3668,  -3933],
                        [ -3053,  -3385],
                        [ -2398,  -2796],
                        [ -1703,  -2165],
                        [  -980,  -1503],
                        [  -229,   -811],
                        [   540,    -98],
                        [  1328,    635],
                        [  2119,   1380],
                        [  2910,   2134],
                        [  3690,   2889],
                        [  4457,   3645],
                        [  5208,   4394],
                        [  5939,   5133],
                        [  6654,   5860],
                        [  7352,   6567],
                        [  8032,   7254],
                        [  8691,   7918],
                        [  9324,   8552],
                        [  9930,   9156],
                        [ 10504,   9726],
                        [ 11045,  10261],
                        [ 11550,  10755],
                        [ 12016,  11208],
                        [ 12443,  11618],
                        [ 12828,  11982],
                        [ 13169,  12299],
                        [ 13466,  12570],
                        [ 13722,  12798],
                        [ 13905,  12950],
                        [ 13992,  13004],
                        [ 13986,  12964],
                        [ 13886,  12831],
                        [ 13670,  12579],
                        [ 13288,  12164],
                        [ 12731,  11576],
                        [ 12064,  10881],
                        [ 11336,  10125],
                        [ 10553,   9319],
                        [  9728,   8471],
                        [  8881,   7608],
                        [  8027,   6741],
                        [  7177,   5887],
                        [  6342,   5054],
                        [  5536,   4256],
                        [  4769,   3504],
                        [  4047,   2803],
                        [  3378,   2163],
                        [  2771,   1588],
                        [  2227,   1084],
                        [  1751,    652],
                        [  1345,    294],
                        [  1008,     11],
                        [   743,   -198],
                        [   545,   -337],
                        [   414,   -407],
                        [   349,   -412],
                        [   342,   -357],
                        [   393,   -245],
                        [   497,    -80],
                        [   648,    128],
                        [   841,    377],
                        [  1069,    653],
                        [  1330,    954],
                        [  1614,   1262],
                        [  1917,   1574],
                        [  2234,   1881],
                        [  2558,   2179],
                        [  2884,   2469],
                        [  3209,   2747],
                        [  3525,   3019],
                        [  3832,   3283],
                        [  4122,   3538],
                        [  4392,   3781],
                        [  4639,   4008],
                        [  4859,   4219],
                        [  5050,   4416],
                        [  5209,   4595],
                        [  5333,   4759],
                        [  5423,   4905],
                        [  5475,   5031],
                        [  5490,   5136],
                        [  5468,   5211],
                        [  5409,   5257],
                        [  5314,   5267],
                        [  5182,   5244],
                        [  5016,   5185],
                        [  4817,   5089],
                        [  4585,   4958],
                        [  4323,   4793],
                        [  4031,   4596],
                        [  3713,   4370],
                        [  3373,   4118],
                        [  3011,   3841],
                        [  2635,   3543],
                        [  2244,   3224],
                        [  1855,   2890],
                        [  1467,   2543],
                        [  1088,   2185],
                        [   722,   1817],
                        [   375,   1446],
                        [    52,   1077],
                        [  -240,    723],
                        [  -500,    387],
                        [  -683,    126],
                        [  -792,    -62],
                        [  -810,   -157],
                        [  -736,   -158],
                        [  -579,    -73],
                        [  -340,    100],
                        [   -99,    279],
                        [   149,    469],
                        [   372,    644],
                        [   574,    803],
                        [   748,    943],
                        [   895,   1063],
                        [  1012,   1161],
                        [  1098,   1237],
                        [  1155,   1290],
                        [  1181,   1321],
                        [  1180,   1329],
                        [  1150,   1315],
                        [  1098,   1280],
                        [  1021,   1224],
                        [   925,   1150],
                        [   808,   1055],
                        [   675,    947],
                        [   525,    819],
                        [   358,    679],
                        [   175,    524],
                        [   -20,    357],
                        [  -225,    176],
                        [  -431,    -14],
                        [  -641,   -215],
                        [  -850,   -424],
                        [ -1060,   -643],
                        [ -1274,   -869],
                        [ -1494,  -1100],
                        [ -1727,  -1338],
                        [ -1972,  -1580],
                        [ -2225,  -1825],
                        [ -2488,  -2072],
                        [ -2756,  -2318],
                        [ -3028,  -2563],
                        [ -3302,  -2804],
                        [ -3574,  -3038],
                        [ -3844,  -3264],
                        [ -4108,  -3480],
                        [ -4362,  -3681],
                        [ -4603,  -3866],
                        [ -4830,  -4035],
                        [ -5039,  -4183],
                        [ -5215,  -4298],
                        [ -5358,  -4381],
                        [ -5479,  -4442],
                        [ -5571,  -4478],
                        [ -5610,  -4461],
                        [ -5544,  -4344],
                        [ -5336,  -4089],
                        [ -5016,  -3727],
                        [ -4610,  -3286],
                        [ -4124,  -2767],
                        [ -3566,  -2186],
                        [ -2952,  -1554],
                        [ -2292,   -887],
                        [ -1595,   -193],
                        [  -870,    516],
                        [  -130,   1230],
                        [   618,   1940],
                        [  1364,   2640],
                        [  2103,   3321],
                        [  2826,   3976],
                        [  3527,   4603],
                        [  4203,   5195],
                        [  4848,   5750],
                        [  5460,   6265],
                        [  6034,   6738],
                        [  6571,   7170],
                        [  7066,   7558],
                        [  7521,   7905],
                        [  7931,   8210],
                        [  8301,   8475],
                        [  8626,   8701],
                        [  8911,   8889],
                        [  9154,   9043],
                        [  9356,   9164],
                        [  9518,   9263],
                        [  9644,   9338],
                        [  9731,   9397],
                        [  9783,   9441],
                        [  9801,   9471],
                        [  9786,   9490],
                        [  9738,   9488],
                        [  9660,   9469],
                        [  9552,   9423],
                        [  9416,   9352],
                        [  9254,   9255],
                        [  9067,   9134],
                        [  8855,   8985],
                        [  8624,   8811],
                        [  8371,   8603],
                        [  8101,   8365],
                        [  7815,   8097],
                        [  7516,   7798],
                        [  7204,   7477],
                        [  6882,   7135],
                        [  6551,   6784],
                        [  6212,   6422],
                        [  5870,   6056],
                        [  5523,   5687],
                        [  5179,   5321],
                        [  4836,   4960],
                        [  4499,   4605],
                        [  4169,   4259],
                        [  3849,   3925],
                        [  3541,   3603],
                        [  3247,   3298],
                        [  2968,   3010],
                        [  2706,   2740],
                        [  2459,   2492],
                        [  2225,   2266],
                        [  2009,   2067],
                        [  1808,   1896],
                        [  1620,   1751],
                        [  1445,   1632],
                        [  1282,   1538],
                        [  1109,   1436],
                        [   926,   1327],
                        [   709,   1179],
                        [   457,    995],
                        [   166,    764],
                        [  -164,    488],
                        [  -489,    210],
                        [  -813,    -76],
                        [ -1069,   -301],
                        [ -1262,   -472],
                        [ -1386,   -584],
                        [ -1440,   -635],
                        [ -1420,   -622],
                        [ -1328,   -544],
                        [ -1163,   -403],
                        [  -928,   -201],
                        [  -627,     62],
                        [  -262,    382],
                        [   157,    754],
                        [   631,   1177],
                        [  1148,   1644],
                        [  1706,   2152],
                        [  2296,   2693],
                        [  2915,   3265],
                        [  3554,   3859],
                        [  4209,   4474],
                        [  4873,   5098],
                        [  5542,   5732],
                        [  6200,   6365],
                        [  6846,   6996],
                        [  7468,   7618],
                        [  8064,   8227],
                        [  8631,   8817],
                        [  9166,   9387],
                        [  9675,   9930],
                        [ 10158,  10444],
                        [ 10612,  10925],
                        [ 11037,  11371],
                        [ 11427,  11779],
                        [ 11782,  12147],
                        [ 12101,  12473],
                        [ 12381,  12755],
                        [ 12621,  12993],
                        [ 12822,  13183],
                        [ 12982,  13327],
                        [ 13102,  13424],
                        [ 13180,  13473],
                        [ 13217,  13475],
                        [ 13213,  13430],
                        [ 13179,  13351],
                        [ 13145,  13268],
                        [ 13128,  13198],
                        [ 13131,  13144],
                        [ 13133,  13084],
                        [ 13085,  12972],
                        [ 12933,  12752],
                        [ 12675,  12423],
                        [ 12327,  12003],
                        [ 11899,  11500],
                        [ 11401,  10926],
                        [ 10848,  10299],
                        [ 10252,   9631],
                        [  9622,   8936],
                        [  8972,   8225],
                        [  8313,   7512],
                        [  7654,   6807],
                        [  7004,   6118],
                        [  6372,   5455],
                        [  5766,   4825],
                        [  5191,   4234],
                        [  4652,   3687],
                        [  4154,   3187],
                        [  3699,   2738],
                        [  3289,   2342],
                        [  2923,   1996],
                        [  2604,   1703],
                        [  2329,   1458],
                        [  2096,   1261],
                        [  1903,   1107],
                        [  1748,    993],
                        [  1626,    915],
                        [  1534,    868],
                        [  1467,    843],
                        [  1422,    839],
                        [  1393,    843],
                        [  1376,    852],
                        [  1367,    858],
                        [  1362,    858],
                        [  1355,    847],
                        [  1346,    823],
                        [  1328,    790],
                        [  1298,    745],
                        [  1256,    688],
                        [  1198,    618],
                        [  1120,    536],
                        [  1022,    439],
                        [   902,    332],
                        [   759,    215],
                        [   592,     93],
                        [   401,    -37],
                        [   185,   -172],
                        [   -54,   -315],
                        [  -314,   -473],
                        [  -596,   -644],
                        [  -896,   -834],
                        [ -1213,  -1040],
                        [ -1544,  -1263],
                        [ -1887,  -1500],
                        [ -2239,  -1752],
                        [ -2599,  -2017],
                        [ -2963,  -2292],
                        [ -3328,  -2576],
                        [ -3690,  -2863],
                        [ -4046,  -3154],
                        [ -4395,  -3446],
                        [ -4733,  -3734],
                        [ -5054,  -4017],
                        [ -5358,  -4293],
                        [ -5639,  -4561],
                        [ -5899,  -4820],
                        [ -6125,  -5062],
                        [ -6319,  -5288],
                        [ -6464,  -5480],
                        [ -6562,  -5640],
                        [ -6579,  -5727],
                        [ -6519,  -5741],
                        [ -6371,  -5672],
                        [ -6136,  -5519],
                        [ -5815,  -5280],
                        [ -5409,  -4954],
                        [ -4986,  -4607],
                        [ -4540,  -4236],
                        [ -4104,  -3866],
                        [ -3674,  -3498],
                        [ -3265,  -3142],
                        [ -2876,  -2800],
                        [ -2519,  -2480],
                        [ -2193,  -2182],
                        [ -1905,  -1912],
                        [ -1655,  -1674],
                        [ -1447,  -1468],
                        [ -1281,  -1296],
                        [ -1156,  -1161],
                        [ -1074,  -1063],
                        [ -1033,  -1000],
                        [ -1032,   -975],
                        [ -1068,   -985],
                        [ -1145,  -1030],
                        [ -1255,  -1109],
                        [ -1402,  -1221],
                        [ -1575,  -1362],
                        [ -1774,  -1532],
                        [ -1988,  -1727],
                        [ -2218,  -1946],
                        [ -2457,  -2183],
                        [ -2705,  -2440],
                        [ -2964,  -2710],
                        [ -3231,  -2992],
                        [ -3512,  -3282],
                        [ -3805,  -3577],
                        [ -4102,  -3872],
                        [ -4401,  -4166],
                        [ -4698,  -4453],
                        [ -4990,  -4731],
                        [ -5271,  -4996],
                        [ -5540,  -5246],
                        [ -5792,  -5475],
                        [ -6024,  -5681],
                        [ -6231,  -5860],
                        [ -6412,  -6009],
                        [ -6559,  -6123],
                        [ -6672,  -6203],
                        [ -6784,  -6282],
                        [ -6940,  -6407],
                        [ -7160,  -6593],
                        [ -7438,  -6840],
                        [ -7759,  -7129],
                        [ -8072,  -7408],
                        [ -8292,  -7596],
                        [ -8384,  -7655],
                        [ -8353,  -7591],
                        [ -8205,  -7410],
                        [ -7947,  -7121],
                        [ -7590,  -6734],
                        [ -7144,  -6264],
                        [ -6615,  -5717],
                        [ -6018,  -5107],
                        [ -5362,  -4445],
                        [ -4657,  -3744],
                        [ -3916,  -3011],
                        [ -3149,  -2259],
                        [ -2367,  -1497],
                        [ -1578,   -733],
                        [  -791,     24],
                        [   -15,    766],
                        [   743,   1485],
                        [  1474,   2176],
                        [  2175,   2832],
                        [  2838,   3451],
                        [  3460,   4028],
                        [  4037,   4561],
                        [  4567,   5048],
                        [  5046,   5488],
                        [  5471,   5878],
                        [  5844,   6220],
                        [  6162,   6514],
                        [  6425,   6762],
                        [  6636,   6966],
                        [  6792,   7126],
                        [  6897,   7248],
                        [  6951,   7332],
                        [  6957,   7382],
                        [  6916,   7397],
                        [  6830,   7379],
                        [  6702,   7325],
                        [  6536,   7238],
                        [  6333,   7117],
                        [  6097,   6965],
                        [  5831,   6778],
                        [  5540,   6562],
                        [  5225,   6308],
                        [  4893,   6023],
                        [  4545,   5705],
                        [  4187,   5360],
                        [  3821,   4993],
                        [  3450,   4606],
                        [  3079,   4214],
                        [  2707,   3819],
                        [  2342,   3424],
                        [  1984,   3032],
                        [  1637,   2651],
                        [  1304,   2282],
                        [   986,   1928],
                        [   686,   1593],
                        [   405,   1278],
                        [   145,    986],
                        [   -90,    721],
                        [  -301,    481],
                        [  -487,    269],
                        [  -644,     86],
                        [  -771,    -66],
                        [  -866,   -184],
                        [  -930,   -270],
                        [  -967,   -326],
                        [  -986,   -353],
                        [  -984,   -352],
                        [  -988,   -349],
                        [  -997,   -342],
                        [ -1023,   -349],
                        [ -1068,   -369],
                        [ -1143,   -419],
                        [ -1252,   -500],
                        [ -1372,   -594],
                        [ -1509,   -704],
                        [ -1615,   -786],
                        [ -1698,   -847],
                        [ -1747,   -878],
                        [ -1766,   -882],
                        [ -1745,   -852],
                        [ -1688,   -789],
                        [ -1589,   -690],
                        [ -1454,   -558],
                        [ -1279,   -392],
                        [ -1067,   -193],
                        [  -821,     37],
                        [  -545,    297],
                        [  -241,    583],
                        [    88,    892],
                        [   435,   1220],
                        [   799,   1566],
                        [  1174,   1923],
                        [  1558,   2290],
                        [  1943,   2661],
                        [  2327,   3035],
                        [  2697,   3404],
                        [  3053,   3769],
                        [  3386,   4121],
                        [  3697,   4461],
                        [  3981,   4783],
                        [  4238,   5086],
                        [  4475,   5365],
                        [  4690,   5619],
                        [  4882,   5846],
                        [  5051,   6043],
                        [  5194,   6208],
                        [  5310,   6341],
                        [  5399,   6441],
                        [  5461,   6507],
                        [  5494,   6538],
                        [  5501,   6535],
                        [  5479,   6498],
                        [  5432,   6426],
                        [  5358,   6320],
                        [  5252,   6177],
                        [  5127,   6008],
                        [  5039,   5874],
                        [  5054,   5834],
                        [  5190,   5911],
                        [  5451,   6106],
                        [  5828,   6410],
                        [  6273,   6775],
                        [  6682,   7096],
                        [  6991,   7311],
                        [  7200,   7419],
                        [  7316,   7430],
                        [  7343,   7345],
                        [  7285,   7177],
                        [  7152,   6931],
                        [  6949,   6619],
                        [  6682,   6247],
                        [  6362,   5827],
                        [  5995,   5366],
                        [  5589,   4873],
                        [  5152,   4355],
                        [  4691,   3820],
                        [  4213,   3275],
                        [  3722,   2726],
                        [  3224,   2178],
                        [  2725,   1636],
                        [  2229,   1105],
                        [  1736,    587],
                        [  1251,     85],
                        [   777,   -399],
                        [   311,   -867],
                        [  -143,  -1317],
                        [  -586,  -1751],
                        [ -1018,  -2169],
                        [ -1441,  -2572],
                        [ -1853,  -2963],
                        [ -2256,  -3343],
                        [ -2653,  -3713],
                        [ -3044,  -4075],
                        [ -3430,  -4434],
                        [ -3814,  -4790],
                        [ -4194,  -5150],
                        [ -4574,  -5515],
                        [ -4955,  -5884],
                        [ -5335,  -6260],
                        [ -5715,  -6638],
                        [ -6097,  -7020],
                        [ -6480,  -7404],
                        [ -6865,  -7788],
                        [ -7249,  -8165],
                        [ -7635,  -8535],
                        [ -8021,  -8891],
                        [ -8405,  -9233],
                        [ -8788,  -9561],
                        [ -9167,  -9873],
                        [ -9541, -10173],
                        [ -9908, -10461],
                        [-10265, -10740],
                        [-10611, -11009],
                        [-10943, -11266],
                        [-11259, -11508],
                        [-11557, -11737],
                        [-11835, -11953],
                        [-12088, -12151],
                        [-12318, -12332],
                        [-12520, -12495],
                        [-12693, -12638],
                        [-12837, -12760],
                        [-12952, -12861],
                        [-13039, -12938],
                        [-13101, -12993],
                        [-13140, -13025],
                        [-13154, -13034],
                        [-13139, -13018],
                        [-13093, -12976],
                        [-13003, -12903],
                        [-12870, -12798],
                        [-12682, -12648],
                        [-12440, -12456],
                        [-12144, -12217],
                        [-11794, -11930],
                        [-11378, -11580],
                        [-10898, -11169],
                        [-10390, -10730],
                        [ -9854, -10263],
                        [ -9311,  -9787],
                        [ -8764,  -9303],
                        [ -8227,  -8825],
                        [ -7703,  -8355],
                        [ -7205,  -7903],
                        [ -6733,  -7471],
                        [ -6298,  -7069],
                        [ -5900,  -6697],
                        [ -5545,  -6360],
                        [ -5236,  -6060],
                        [ -4973,  -5801],
                        [ -4758,  -5584],
                        [ -4591,  -5408],
                        [ -4470,  -5275],
                        [ -4396,  -5184],
                        [ -4365,  -5133],
                        [ -4375,  -5120],
                        [ -4423,  -5145],
                        [ -4501,  -5202],
                        [ -4607,  -5293],
                        [ -4732,  -5409],
                        [ -4875,  -5549],
                        [ -5027,  -5709],
                        [ -5188,  -5884],
                        [ -5355,  -6069],
                        [ -5526,  -6263],
                        [ -5702,  -6457],
                        [ -5879,  -6650],
                        [ -6051,  -6836],
                        [ -6213,  -7010],
                        [ -6362,  -7170],
                        [ -6494,  -7311],
                        [ -6603,  -7430],
                        [ -6689,  -7524],
                        [ -6748,  -7588],
                        [ -6776,  -7620],
                        [ -6772,  -7620],
                        [ -6735,  -7583],
                        [ -6650,  -7501],
                        [ -6539,  -7391],
                        [ -6478,  -7332],
                        [ -6535,  -7391],
                        [ -6727,  -7583],
                        [ -7055,  -7909],
                        [ -7521,  -8369],
                        [ -8076,  -8913],
                        [ -8596,  -9414],
                        [ -8996,  -9791],
                        [ -9275, -10040],
                        [ -9437, -10167],
                        [ -9484, -10174],
                        [ -9422, -10067],
                        [ -9255,  -9854],
                        [ -8991,  -9543],
                        [ -8639,  -9145],
                        [ -8208,  -8667],
                        [ -7708,  -8123],
                        [ -7149,  -7520],
                        [ -6544,  -6871],
                        [ -5901,  -6185],
                        [ -5232,  -5473],
                        [ -4544,  -4744],
                        [ -3852,  -4011],
                        [ -3161,  -3280],
                        [ -2482,  -2561],
                        [ -1821,  -1862],
                        [ -1186,  -1190],
                        [  -582,   -550],
                        [   -15,     53],
                        [   512,    616],
                        [   993,   1134],
                        [  1426,   1606],
                        [  1809,   2030],
                        [  2142,   2403],
                        [  2422,   2724],
                        [  2650,   2992],
                        [  2827,   3207],
                        [  2953,   3369],
                        [  3032,   3486],
                        [  3065,   3560],
                        [  3054,   3598],
                        [  3003,   3603],
                        [  2914,   3577],
                        [  2791,   3523],
                        [  2637,   3443],
                        [  2457,   3338],
                        [  2255,   3208],
                        [  2034,   3056],
                        [  1800,   2880],
                        [  1556,   2681],
                        [  1306,   2463],
                        [  1055,   2229],
                        [   805,   1983],
                        [   561,   1730],
                        [   327,   1479],
                        [   103,   1233],
                        [  -106,    995],
                        [  -299,    768],
                        [  -473,    554],
                        [  -627,    358],
                        [  -761,    180],
                        [  -873,     24],
                        [  -964,   -109],
                        [ -1033,   -218],
                        [ -1079,   -301],
                        [ -1102,   -358],
                        [ -1099,   -390],
                        [ -1069,   -397],
                        [ -1006,   -377],
                        [  -908,   -331],
                        [  -778,   -260],
                        [  -620,   -168],
                        [  -447,    -57],
                        [  -257,     73],
                        [   -66,    216],
                        [   126,    371],
                        [   318,    538],
                        [   509,    715],
                        [   678,    878],
                        [   823,   1027],
                        [   932,   1147],
                        [  1004,   1236],
                        [  1057,   1311],
                        [  1087,   1367],
                        [  1105,   1413],
                        [  1107,   1445],
                        [  1103,   1474],
                        [  1090,   1495],
                        [  1079,   1516],
                        [  1066,   1535],
                        [  1055,   1554],
                        [  1048,   1575],
                        [  1047,   1600],
                        [  1048,   1625],
                        [  1056,   1654],
                        [  1068,   1684],
                        [  1082,   1717],
                        [  1101,   1750],
                        [  1120,   1783],
                        [  1138,   1814],
                        [  1154,   1844],
                        [  1164,   1869],
                        [  1165,   1889],
                        [  1156,   1903],
                        [  1134,   1909],
                        [  1099,   1905],
                        [  1049,   1891],
                        [   983,   1864],
                        [   908,   1825],
                        [   823,   1772],
                        [   729,   1705],
                        [   626,   1623],
                        [   513,   1524],
                        [   391,   1412],
                        [   258,   1283],
                        [   117,   1140],
                        [   -33,    982],
                        [  -189,    813],
                        [  -354,    627],
                        [  -523,    433],
                        [  -698,    228],
                        [  -887,      2],
                        [ -1063,   -213],
                        [ -1128,   -321],
                        [ -1017,   -258],
                        [  -715,     -7],
                        [  -215,    435],
                        [   492,   1076],
                        [  1357,   1867],
                        [  2240,   2667],
                        [  3040,   3377],
                        [  3755,   3993],
                        [  4383,   4517],
                        [  4921,   4943],
                        [  5363,   5273],
                        [  5714,   5507],
                        [  5970,   5649],
                        [  6137,   5701],
                        [  6216,   5669],
                        [  6211,   5556],
                        [  6127,   5369],
                        [  5971,   5114],
                        [  5747,   4795],
                        [  5460,   4420],
                        [  5116,   3993],
                        [  4721,   3521],
                        [  4282,   3012],
                        [  3803,   2470],
                        [  3291,   1902],
                        [  2748,   1312],
                        [  2181,    706],
                        [  1592,     85],
                        [   986,   -546],
                        [   365,  -1184],
                        [  -265,  -1827],
                        [  -902,  -2471],
                        [ -1543,  -3113],
                        [ -2185,  -3749],
                        [ -2825,  -4373],
                        [ -3463,  -4982],
                        [ -4095,  -5577],
                        [ -4721,  -6157],
                        [ -5336,  -6728],
                        [ -5941,  -7289],
                        [ -6533,  -7846],
                        [ -7110,  -8396],
                        [ -7670,  -8935],
                        [ -8213,  -9466],
                        [ -8734,  -9980],
                        [ -9237, -10480],
                        [ -9714, -10955],
                        [-10169, -11406],
                        [-10598, -11826],
                        [-11001, -12214],
                        [-11375, -12569],
                        [-11721, -12888],
                        [-12036, -13174],
                        [-12319, -13427],
                        [-12569, -13648],
                        [-12786, -13836],
                        [-12968, -13989],
                        [-13114, -14106],
                        [-13223, -14188],
                        [-13294, -14236],
                        [-13327, -14250],
                        [-13319, -14231],
                        [-13273, -14180],
                        [-13188, -14096],
                        [-13067, -13982],
                        [-12911, -13837],
                        [-12731, -13663],
                        [-12530, -13462],
                        [-12315, -13236],
                        [-12088, -12985],
                        [-11845, -12712],
                        [-11590, -12417],
                        [-11313, -12107],
                        [-11017, -11782],
                        [-10714, -11463],
                        [-10406, -11148],
                        [-10090, -10834],
                        [ -9770, -10526],
                        [ -9417, -10191],
                        [ -9033,  -9833],
                        [ -8616,  -9444],
                        [ -8165,  -9027],
                        [ -7697,  -8592],
                        [ -7211,  -8143],
                        [ -6723,  -7691],
                        [ -6233,  -7236],
                        [ -5753,  -6790],
                        [ -5285,  -6353],
                        [ -4838,  -5936],
                        [ -4414,  -5537],
                        [ -4019,  -5164],
                        [ -3655,  -4817],
                        [ -3326,  -4500],
                        [ -3031,  -4213],
                        [ -2773,  -3959],
                        [ -2550,  -3735],
                        [ -2361,  -3543],
                        [ -2204,  -3382],
                        [ -2076,  -3248],
                        [ -1974,  -3140],
                        [ -1892,  -3057],
                        [ -1831,  -2994],
                        [ -1780,  -2949],
                        [ -1740,  -2918],
                        [ -1703,  -2895],
                        [ -1666,  -2880],
                        [ -1625,  -2863],
                        [ -1578,  -2847],
                        [ -1523,  -2823],
                        [ -1459,  -2790],
                        [ -1380,  -2743],
                        [ -1284,  -2680],
                        [ -1166,  -2597],
                        [ -1027,  -2491],
                        [  -863,  -2361],
                        [  -674,  -2207],
                        [  -457,  -2024],
                        [  -212,  -1814],
                        [    59,  -1578],
                        [   357,  -1314],
                        [   695,  -1009],
                        [  1029,   -709],
                        [  1260,   -511],
                        [  1325,   -479],
                        [  1212,   -621],
                        [   909,   -948],
                        [   396,  -1478],
                        [  -285,  -2166],
                        [  -986,  -2862],
                        [ -1607,  -3469],
                        [ -2147,  -3983],
                        [ -2606,  -4407],
                        [ -2979,  -4735],
                        [ -3266,  -4966],
                        [ -3466,  -5104],
                        [ -3582,  -5150],
                        [ -3618,  -5111],
                        [ -3579,  -4990],
                        [ -3470,  -4795],
                        [ -3300,  -4532],
                        [ -3075,  -4210],
                        [ -2802,  -3838],
                        [ -2490,  -3422],
                        [ -2147,  -2971],
                        [ -1782,  -2495],
                        [ -1401,  -2002],
                        [ -1012,  -1500],
                        [  -622,   -997],
                        [  -238,   -501],
                        [   136,    -16],
                        [   494,    451],
                        [   834,    898],
                        [  1150,   1319],
                        [  1440,   1713],
                        [  1701,   2075],
                        [  1933,   2405],
                        [  2134,   2693],
                        [  2304,   2939],
                        [  2444,   3140],
                        [  2554,   3296],
                        [  2635,   3413],
                        [  2690,   3492],
                        [  2722,   3551],
                        [  2732,   3590],
                        [  2723,   3616],
                        [  2697,   3631],
                        [  2658,   3636],
                        [  2608,   3634],
                        [  2552,   3624],
                        [  2492,   3610],
                        [  2431,   3589],
                        [  2373,   3564],
                        [  2319,   3538],
                        [  2273,   3511],
                        [  2238,   3486],
                        [  2214,   3465],
                        [  2204,   3453],
                        [  2211,   3452],
                        [  2233,   3460],
                        [  2272,   3479],
                        [  2329,   3511],
                        [  2402,   3553],
                        [  2490,   3610],
                        [  2593,   3681],
                        [  2707,   3766],
                        [  2836,   3865],
                        [  2974,   3978],
                        [  3120,   4103],
                        [  3282,   4240],
                        [  3457,   4387],
                        [  3655,   4543],
                        [  3874,   4707],
                        [  4114,   4876],
                        [  4371,   5047],
                        [  4636,   5224],
                        [  4906,   5400],
                        [  5188,   5600],
                        [  5478,   5819],
                        [  5785,   6070],
                        [  6108,   6352],
                        [  6421,   6637],
                        [  6724,   6926],
                        [  6971,   7168],
                        [  7162,   7367],
                        [  7294,   7516],
                        [  7364,   7612],
                        [  7382,   7664],
                        [  7343,   7668],
                        [  7263,   7633],
                        [  7137,   7559],
                        [  6977,   7453],
                        [  6781,   7315],
                        [  6561,   7152],
                        [  6315,   6966],
                        [  6053,   6761],
                        [  5775,   6537],
                        [  5488,   6303],
                        [  5194,   6055],
                        [  4895,   5800],
                        [  4593,   5537],
                        [  4291,   5272],
                        [  3989,   5003],
                        [  3689,   4733],
                        [  3391,   4463],
                        [  3097,   4195],
                        [  2809,   3929],
                        [  2525,   3666],
                        [  2247,   3406],
                        [  1970,   3150],
                        [  1698,   2897],
                        [  1431,   2647],
                        [  1172,   2403],
                        [   918,   2161],
                        [   674,   1926],
                        [   436,   1692],
                        [   208,   1464],
                        [   -12,   1240],
                        [  -223,   1021],
                        [  -425,    810],
                        [  -618,    604],
                        [  -803,    403],
                        [  -973,    214],
                        [ -1138,     30],
                        [ -1301,   -155],
                        [ -1420,   -296],
                        [ -1393,   -290],
                        [ -1171,    -93],
                        [  -749,    303],
                        [  -115,    908],
                        [   761,   1747],
                        [  1833,   2776],
                        [  2950,   3842],
                        [  4013,   4846],
                        [  5016,   5783],
                        [  5952,   6650],
                        [  6811,   7431],
                        [  7580,   8119],
                        [  8256,   8711],
                        [  8833,   9202],
                        [  9308,   9589],
                        [  9679,   9873],
                        [  9948,  10053],
                        [ 10116,  10132],
                        [ 10185,  10113],
                        [ 10157,  10000],
                        [ 10038,   9796],
                        [  9832,   9509],
                        [  9546,   9142],
                        [  9186,   8706],
                        [  8759,   8205],
                        [  8270,   7646],
                        [  7725,   7040],
                        [  7134,   6390],
                        [  6499,   5703],
                        [  5830,   4986],
                        [  5132,   4247],
                        [  4411,   3489],
                        [  3675,   2719],
                        [  2930,   1948],
                        [  2179,   1181],
                        [  1432,    433],
                        [   689,   -293],
                        [   -41,   -990],
                        [  -757,  -1655],
                        [ -1454,  -2298],
                        [ -2128,  -2913],
                        [ -2775,  -3511],
                        [ -3393,  -4089],
                        [ -3977,  -4644],
                        [ -4528,  -5175],
                        [ -5041,  -5677],
                        [ -5514,  -6149],
                        [ -5948,  -6586],
                        [ -6339,  -6988],
                        [ -6688,  -7350],
                        [ -6993,  -7673],
                        [ -7254,  -7954],
                        [ -7471,  -8193],
                        [ -7643,  -8389],
                        [ -7773,  -8543],
                        [ -7859,  -8654],
                        [ -7902,  -8725],
                        [ -7903,  -8750],
                        [ -7863,  -8732],
                        [ -7783,  -8673],
                        [ -7664,  -8574],
                        [ -7504,  -8438],
                        [ -7308,  -8266],
                        [ -7075,  -8062],
                        [ -6809,  -7826],
                        [ -6514,  -7562],
                        [ -6192,  -7271],
                        [ -5860,  -6958],
                        [ -5519,  -6623],
                        [ -5181,  -6269],
                        [ -4847,  -5900],
                        [ -4519,  -5518],
                        [ -4200,  -5124],
                        [ -3893,  -4743],
                        [ -3601,  -4375],
                        [ -3352,  -4058],
                        [ -3145,  -3792],
                        [ -2980,  -3577],
                        [ -2858,  -3416],
                        [ -2734,  -3261],
                        [ -2612,  -3117],
                        [ -2451,  -2940],
                        [ -2252,  -2734],
                        [ -2022,  -2503],
                        [ -1762,  -2247],
                        [ -1479,  -1974],
                        [ -1172,  -1684],
                        [  -852,  -1382],
                        [  -518,  -1071],
                        [  -179,   -757],
                        [   167,   -440],
                        [   509,   -126],
                        [   852,    188],
                        [  1185,    494],
                        [  1513,    795],
                        [  1831,   1088],
                        [  2139,   1375],
                        [  2438,   1651],
                        [  2728,   1922],
                        [  3013,   2184],
                        [  3293,   2441],
                        [  3568,   2693],
                        [  3838,   2942],
                        [  4107,   3190],
                        [  4375,   3437],
                        [  4650,   3687],
                        [  4932,   3941],
                        [  5227,   4203],
                        [  5536,   4472],
                        [  5858,   4752],
                        [  6195,   5043],
                        [  6547,   5347],
                        [  6914,   5664],
                        [  7297,   5995],
                        [  7695,   6342],
                        [  8107,   6701],
                        [  8532,   7071],
                        [  8969,   7455],
                        [  9416,   7846],
                        [  9867,   8244],
                        [ 10325,   8647],
                        [ 10795,   9063],
                        [ 11221,   9436],
                        [ 11511,   9674],
                        [ 11626,   9740],
                        [ 11559,   9631],
                        [ 11291,   9323],
                        [ 10779,   8783],
                        [ 10060,   8046],
                        [  9269,   7252],
                        [  8496,   6487],
                        [  7737,   5751],
                        [  7001,   5046],
                        [  6299,   4388],
                        [  5637,   3784],
                        [  5022,   3237],
                        [  4455,   2750],
                        [  3941,   2325],
                        [  3482,   1965],
                        [  3076,   1669],
                        [  2723,   1433],
                        [  2421,   1257],
                        [  2168,   1137],
                        [  1961,   1068],
                        [  1796,   1048],
                        [  1670,   1070],
                        [  1576,   1130],
                        [  1514,   1221],
                        [  1476,   1340],
                        [  1462,   1479],
                        [  1466,   1636],
                        [  1486,   1805],
                        [  1519,   1983],
                        [  1564,   2167],
                        [  1615,   2355],
                        [  1673,   2542],
                        [  1734,   2725],
                        [  1798,   2894],
                        [  1864,   3045],
                        [  1932,   3175],
                        [  2001,   3283],
                        [  2073,   3372],
                        [  2146,   3442],
                        [  2223,   3512],
                        [  2303,   3583],
                        [  2387,   3660],
                        [  2477,   3747],
                        [  2574,   3843],
                        [  2678,   3950],
                        [  2790,   4067],
                        [  2911,   4196],
                        [  3041,   4336],
                        [  3181,   4487],
                        [  3330,   4651],
                        [  3491,   4828],
                        [  3663,   5014],
                        [  3845,   5211],
                        [  4036,   5415],
                        [  4237,   5627],
                        [  4447,   5844],
                        [  4664,   6065],
                        [  4886,   6287],
                        [  5111,   6508],
                        [  5337,   6729],
                        [  5562,   6949],
                        [  5783,   7165],
                        [  5998,   7378],
                        [  6203,   7583],
                        [  6399,   7782],
                        [  6590,   7971],
                        [  6775,   8151],
                        [  6965,   8317],
                        [  7155,   8467],
                        [  7348,   8602],
                        [  7545,   8721],
                        [  7739,   8828],
                        [  7930,   8921],
                        [  8146,   9046],
                        [  8383,   9200],
                        [  8652,   9398],
                        [  8953,   9641],
                        [  9262,   9907],
                        [  9581,  10194],
                        [  9835,  10429],
                        [ 10029,  10617],
                        [ 10144,  10736],
                        [ 10180,  10788],
                        [ 10144,  10775],
                        [ 10034,  10699],
                        [  9861,  10567],
                        [  9623,  10376],
                        [  9333,  10139],
                        [  8990,   9854],
                        [  8606,   9530],
                        [  8182,   9168],
                        [  7732,   8778],
                        [  7254,   8359],
                        [  6762,   7921],
                        [  6255,   7464],
                        [  5744,   6997],
                        [  5228,   6521],
                        [  4713,   6041],
                        [  4201,   5559],
                        [  3699,   5081],
                        [  3207,   4609],
                        [  2734,   4144],
                        [  2281,   3690],
                        [  1845,   3248],
                        [  1430,   2819],
                        [  1029,   2406],
                        [   644,   2009],
                        [   275,   1628],
                        [   -79,   1265],
                        [  -416,    918],
                        [  -735,    591],
                        [ -1035,    280],
                        [ -1318,    -13],
                        [ -1584,   -288],
                        [ -1831,   -545],
                        [ -2060,   -783],
                        [ -2273,  -1003],
                        [ -2469,  -1206],
                        [ -2646,  -1385],
                        [ -2810,  -1551],
                        [ -2965,  -1704],
                        [ -3062,  -1794],
                        [ -3027,  -1751],
                        [ -2842,  -1557],
                        [ -2506,  -1209],
                        [ -1996,   -690],
                        [ -1276,     40],
                        [  -368,    951],
                        [   600,   1918],
                        [  1551,   2863],
                        [  2484,   3785],
                        [  3386,   4673],
                        [  4239,   5507],
                        [  5032,   6276],
                        [  5755,   6970],
                        [  6402,   7583],
                        [  6964,   8107],
                        [  7434,   8535],
                        [  7815,   8866],
                        [  8099,   9099],
                        [  8290,   9232],
                        [  8386,   9269],
                        [  8391,   9211],
                        [  8308,   9062],
                        [  8142,   8826],
                        [  7898,   8511],
                        [  7582,   8122],
                        [  7200,   7666],
                        [  6759,   7152],
                        [  6267,   6586],
                        [  5728,   5978],
                        [  5152,   5332],
                        [  4544,   4659],
                        [  3915,   3964],
                        [  3269,   3255],
                        [  2615,   2546],
                        [  1958,   1844],
                        [  1307,   1165],
                        [   666,    514],
                        [    41,   -101],
                        [  -564,   -676],
                        [ -1144,  -1217],
                        [ -1694,  -1719],
                        [ -2212,  -2195],
                        [ -2693,  -2642],
                        [ -3135,  -3058],
                        [ -3537,  -3442],
                        [ -3896,  -3792],
                        [ -4210,  -4107],
                        [ -4480,  -4386],
                        [ -4705,  -4630],
                        [ -4883,  -4838],
                        [ -5016,  -5012],
                        [ -5105,  -5150],
                        [ -5150,  -5254],
                        [ -5153,  -5318],
                        [ -5116,  -5345],
                        [ -5040,  -5333],
                        [ -4928,  -5287],
                        [ -4782,  -5202],
                        [ -4604,  -5080],
                        [ -4396,  -4926],
                        [ -4162,  -4740],
                        [ -3901,  -4526],
                        [ -3616,  -4288],
                        [ -3313,  -4026],
                        [ -2991,  -3745],
                        [ -2657,  -3448],
                        [ -2313,  -3138],
                        [ -1977,  -2818],
                        [ -1645,  -2487],
                        [ -1333,  -2151],
                        [ -1040,  -1811],
                        [  -772,  -1473],
                        [  -530,  -1138],
                        [  -333,   -841],
                        [  -182,   -583],
                        [  -110,   -407],
                        [  -115,   -314],
                        [  -197,   -306],
                        [  -354,   -383],
                        [  -532,   -489],
                        [  -734,   -629],
                        [  -893,   -737],
                        [ -1012,   -815],
                        [ -1091,   -862],
                        [ -1128,   -876],
                        [ -1121,   -858],
                        [ -1072,   -807],
                        [  -983,   -726],
                        [  -853,   -613],
                        [  -689,   -474],
                        [  -488,   -306],
                        [  -258,   -113],
                        [     3,    106],
                        [   288,    345],
                        [   598,    607],
                        [   927,    888],
                        [  1278,   1190],
                        [  1645,   1508],
                        [  2033,   1844],
                        [  2433,   2195],
                        [  2849,   2560],
                        [  3273,   2940],
                        [  3704,   3332],
                        [  4142,   3737],
                        [  4586,   4152],
                        [  5041,   4578],
                        [  5506,   5014],
                        [  5985,   5458],
                        [  6479,   5910],
                        [  6982,   6368],
                        [  7495,   6832],
                        [  8013,   7298],
                        [  8534,   7765],
                        [  9055,   8231],
                        [  9574,   8695],
                        [ 10085,   9150],
                        [ 10587,   9596],
                        [ 11077,  10031],
                        [ 11550,  10449],
                        [ 11999,  10843],
                        [ 12427,  11217],
                        [ 12832,  11568],
                        [ 13163,  11845],
                        [ 13369,  12002],
                        [ 13440,  12027],
                        [ 13371,  11915],
                        [ 13134,  11643],
                        [ 12680,  11162],
                        [ 12021,  10485],
                        [ 11253,   9709],
                        [ 10433,   8893],
                        [  9563,   8036],
                        [  8654,   7149],
                        [  7722,   6250],
                        [  6779,   5351],
                        [  5835,   4461],
                        [  4898,   3590],
                        [  3980,   2749],
                        [  3086,   1943],
                        [  2225,   1178],
                        [  1401,    460],
                        [   618,   -209],
                        [  -119,   -825],
                        [  -809,  -1386],
                        [ -1450,  -1893],
                        [ -2039,  -2345],
                        [ -2578,  -2742],
                        [ -3066,  -3088],
                        [ -3504,  -3382],
                        [ -3892,  -3628],
                        [ -4232,  -3827],
                        [ -4523,  -3982],
                        [ -4769,  -4096],
                        [ -4970,  -4171],
                        [ -5129,  -4210],
                        [ -5246,  -4217],
                        [ -5324,  -4193],
                        [ -5367,  -4154],
                        [ -5376,  -4100],
                        [ -5350,  -4038],
                        [ -5293,  -3970],
                        [ -5207,  -3896],
                        [ -5092,  -3818],
                        [ -4951,  -3720],
                        [ -4786,  -3607],
                        [ -4596,  -3469],
                        [ -4386,  -3309],
                        [ -4156,  -3126],
                        [ -3907,  -2922],
                        [ -3643,  -2698],
                        [ -3365,  -2453],
                        [ -3076,  -2187],
                        [ -2777,  -1902],
                        [ -2472,  -1599],
                        [ -2160,  -1277],
                        [ -1845,   -947],
                        [ -1530,   -606],
                        [ -1216,   -264],
                        [  -907,     76],
                        [  -603,    411],
                        [  -307,    739],
                        [   -22,   1052],
                        [   249,   1350],
                        [   505,   1632],
                        [   741,   1896],
                        [   956,   2139],
                        [  1149,   2359],
                        [  1317,   2555],
                        [  1459,   2727],
                        [  1581,   2873],
                        [  1682,   2992],
                        [  1769,   3081],
                        [  1839,   3139],
                        [  1901,   3168],
                        [  1955,   3170],
                        [  2005,   3154],
                        [  2053,   3121],
                        [  2139,   3127],
                        [  2259,   3167],
                        [  2427,   3262],
                        [  2641,   3411],
                        [  2886,   3599],
                        [  3164,   3829],
                        [  3389,   4015],
                        [  3568,   4164],
                        [  3675,   4250],
                        [  3712,   4276],
                        [  3682,   4243],
                        [  3586,   4150],
                        [  3426,   4002],
                        [  3205,   3801],
                        [  2930,   3551],
                        [  2602,   3253],
                        [  2233,   2918],
                        [  1822,   2544],
                        [  1382,   2140],
                        [   914,   1708],
                        [   430,   1256],
                        [   -71,    785],
                        [  -578,    302],
                        [ -1090,   -190],
                        [ -1602,   -685],
                        [ -2111,  -1181],
                        [ -2605,  -1674],
                        [ -3085,  -2160],
                        [ -3543,  -2637],
                        [ -3976,  -3101],
                        [ -4387,  -3551],
                        [ -4777,  -3986],
                        [ -5151,  -4403],
                        [ -5509,  -4801],
                        [ -5853,  -5180],
                        [ -6184,  -5539],
                        [ -6499,  -5878],
                        [ -6797,  -6196],
                        [ -7079,  -6494],
                        [ -7346,  -6771],
                        [ -7595,  -7027],
                        [ -7828,  -7263],
                        [ -8045,  -7478],
                        [ -8247,  -7672],
                        [ -8432,  -7845],
                        [ -8600,  -7993],
                        [ -8756,  -8124],
                        [ -8895,  -8233],
                        [ -8990,  -8292],
                        [ -9017,  -8277],
                        [ -8979,  -8194],
                        [ -8876,  -8043],
                        [ -8681,  -7798],
                        [ -8347,  -7412],
                        [ -7867,  -6882],
                        [ -7312,  -6277],
                        [ -6723,  -5640],
                        [ -6103,  -4974],
                        [ -5465,  -4292],
                        [ -4825,  -3612],
                        [ -4196,  -2947],
                        [ -3586,  -2307],
                        [ -3007,  -1704],
                        [ -2468,  -1148],
                        [ -1974,   -647],
                        [ -1533,   -205],
                        [ -1150,    173],
                        [  -826,    482],
                        [  -563,    722],
                        [  -364,    891],
                        [  -226,    992],
                        [  -148,   1025],
                        [  -128,    995],
                        [  -163,    904],
                        [  -247,    758],
                        [  -378,    561],
                        [  -550,    320],
                        [  -758,     40],
                        [  -997,   -272],
                        [ -1261,   -611],
                        [ -1544,   -969],
                        [ -1840,  -1341],
                        [ -2145,  -1713],
                        [ -2452,  -2082],
                        [ -2756,  -2432],
                        [ -3052,  -2760],
                        [ -3337,  -3059],
                        [ -3607,  -3324],
                        [ -3858,  -3559],
                        [ -4087,  -3760],
                        [ -4292,  -3940],
                        [ -4472,  -4094],
                        [ -4624,  -4226],
                        [ -4747,  -4334],
                        [ -4840,  -4418],
                        [ -4903,  -4479],
                        [ -4937,  -4520],
                        [ -4940,  -4542],
                        [ -4914,  -4550],
                        [ -4860,  -4543],
                        [ -4778,  -4522],
                        [ -4671,  -4490],
                        [ -4541,  -4439],
                        [ -4388,  -4371],
                        [ -4218,  -4285],
                        [ -4029,  -4181],
                        [ -3826,  -4059],
                        [ -3612,  -3920],
                        [ -3386,  -3766],
                        [ -3152,  -3599],
                        [ -2913,  -3420],
                        [ -2668,  -3232],
                        [ -2423,  -3038],
                        [ -2177,  -2838],
                        [ -1935,  -2636],
                        [ -1701,  -2433],
                        [ -1480,  -2231],
                        [ -1274,  -2028],
                        [ -1090,  -1827],
                        [  -930,  -1632],
                        [  -800,  -1446],
                        [  -700,  -1268],
                        [  -658,  -1140],
                        [  -675,  -1058],
                        [  -778,  -1063],
                        [  -962,  -1151],
                        [ -1230,  -1327],
                        [ -1581,  -1591],
                        [ -1958,  -1890],
                        [ -2365,  -2227],
                        [ -2729,  -2530],
                        [ -3053,  -2804],
                        [ -3330,  -3041],
                        [ -3556,  -3239],
                        [ -3725,  -3392],
                        [ -3837,  -3500],
                        [ -3891,  -3560],
                        [ -3885,  -3572],
                        [ -3820,  -3535],
                        [ -3696,  -3450],
                        [ -3519,  -3319],
                        [ -3286,  -3140],
                        [ -3005,  -2919],
                        [ -2676,  -2651],
                        [ -2307,  -2347],
                        [ -1895,  -2001],
                        [ -1449,  -1623],
                        [  -967,  -1211],
                        [  -461,   -770],
                        [    71,   -302],
                        [   612,    187],
                        [  1164,    696],
                        [  1722,   1220],
                        [  2282,   1757],
                        [  2849,   2303],
                        [  3420,   2853],
                        [  3997,   3402],
                        [  4577,   3949],
                        [  5153,   4489],
                        [  5722,   5019],
                        [  6277,   5532],
                        [  6818,   6029],
                        [  7336,   6502],
                        [  7828,   6950],
                        [  8290,   7367],
                        [  8717,   7750],
                        [  9106,   8096],
                        [  9453,   8399],
                        [  9751,   8655],
                        [ 10002,   8864],
                        [ 10201,   9020],
                        [ 10331,   9111],
                        [ 10394,   9136],
                        [ 10400,   9107],
                        [ 10346,   9022],
                        [ 10203,   8852],
                        [  9924,   8551],
                        [  9480,   8089],
                        [  8905,   7501],
                        [  8228,   6816],
                        [  7453,   6039],
                        [  6593,   5181],
                        [  5667,   4264],
                        [  4687,   3299],
                        [  3664,   2300],
                        [  2614,   1280],
                        [  1550,    256],
                        [   484,   -763],
                        [  -574,  -1766],
                        [ -1614,  -2742],
                        [ -2626,  -3683],
                        [ -3602,  -4583],
                        [ -4533,  -5435],
                        [ -5416,  -6233],
                        [ -6244,  -6972],
                        [ -7014,  -7651],
                        [ -7720,  -8265],
                        [ -8364,  -8813],
                        [ -8940,  -9296],
                        [ -9449,  -9712],
                        [ -9891, -10064],
                        [-10264, -10351],
                        [-10571, -10576],
                        [-10814, -10742],
                        [-10992, -10853],
                        [-11111, -10910],
                        [-11173, -10926],
                        [-11178, -10902],
                        [-11134, -10846],
                        [-11039, -10761],
                        [-10901, -10652],
                        [-10722, -10521],
                        [-10504, -10363],
                        [-10253, -10180],
                        [ -9972,  -9968],
                        [ -9664,  -9731],
                        [ -9335,  -9469],
                        [ -8986,  -9188],
                        [ -8625,  -8886],
                        [ -8253,  -8566],
                        [ -7874,  -8226],
                        [ -7493,  -7869],
                        [ -7113,  -7495],
                        [ -6739,  -7108],
                        [ -6372,  -6715],
                        [ -6017,  -6319],
                        [ -5677,  -5932],
                        [ -5354,  -5555],
                        [ -5048,  -5194],
                        [ -4765,  -4853],
                        [ -4505,  -4535],
                        [ -4271,  -4242],
                        [ -4064,  -3976],
                        [ -3885,  -3741],
                        [ -3735,  -3534],
                        [ -3614,  -3360],
                        [ -3521,  -3216],
                        [ -3460,  -3105],
                        [ -3422,  -3024],
                        [ -3411,  -2975],
                        [ -3421,  -2961],
                        [ -3452,  -2979],
                        [ -3495,  -3023],
                        [ -3549,  -3096],
                        [ -3598,  -3179],
                        [ -3642,  -3272],
                        [ -3639,  -3324],
                        [ -3590,  -3338],
                        [ -3486,  -3297],
                        [ -3326,  -3200],
                        [ -3113,  -3050],
                        [ -2847,  -2845],
                        [ -2605,  -2661],
                        [ -2381,  -2490],
                        [ -2197,  -2355],
                        [ -2054,  -2256],
                        [ -1955,  -2195],
                        [ -1897,  -2171],
                        [ -1886,  -2186],
                        [ -1916,  -2238],
                        [ -1987,  -2325],
                        [ -2100,  -2449],
                        [ -2247,  -2602],
                        [ -2429,  -2786],
                        [ -2638,  -2995],
                        [ -2873,  -3229],
                        [ -3127,  -3482],
                        [ -3399,  -3754],
                        [ -3682,  -4037],
                        [ -3977,  -4335],
                        [ -4276,  -4638],
                        [ -4578,  -4948],
                        [ -4872,  -5259],
                        [ -5158,  -5572],
                        [ -5429,  -5881],
                        [ -5686,  -6186],
                        [ -5930,  -6485],
                        [ -6163,  -6777],
                        [ -6392,  -7058],
                        [ -6616,  -7330],
                        [ -6838,  -7589],
                        [ -7058,  -7837],
                        [ -7273,  -8071],
                        [ -7481,  -8292],
                        [ -7683,  -8498],
                        [ -7880,  -8690],
                        [ -8069,  -8868],
                        [ -8249,  -9029],
                        [ -8422,  -9176],
                        [ -8585,  -9307],
                        [ -8738,  -9421],
                        [ -8882,  -9517],
                        [ -9016,  -9597],
                        [ -9138,  -9658],
                        [ -9259,  -9713],
                        [ -9406,  -9788],
                        [ -9592,  -9900],
                        [ -9815, -10045],
                        [-10054, -10203],
                        [-10256, -10320],
                        [-10368, -10346],
                        [-10389, -10280],
                        [-10334, -10134],
                        [-10206,  -9916],
                        [-10013,  -9634],
                        [ -9768,  -9302],
                        [ -9478,  -8929],
                        [ -9152,  -8526],
                        [ -8799,  -8103],
                        [ -8429,  -7671],
                        [ -8049,  -7239],
                        [ -7665,  -6811],
                        [ -7285,  -6398],
                        [ -6913,  -6002],
                        [ -6554,  -5628],
                        [ -6210,  -5280],
                        [ -5884,  -4957],
                        [ -5579,  -4665],
                        [ -5294,  -4403],
                        [ -5032,  -4170],
                        [ -4790,  -3966],
                        [ -4569,  -3790],
                        [ -4366,  -3638],
                        [ -4181,  -3509],
                        [ -4011,  -3400],
                        [ -3855,  -3305],
                        [ -3709,  -3223],
                        [ -3572,  -3152],
                        [ -3439,  -3081],
                        [ -3310,  -3010],
                        [ -3183,  -2931],
                        [ -3053,  -2841],
                        [ -2920,  -2736],
                        [ -2783,  -2611],
                        [ -2640,  -2470],
                        [ -2490,  -2309],
                        [ -2333,  -2138],
                        [ -2167,  -1952],
                        [ -1993,  -1759],
                        [ -1812,  -1557],
                        [ -1622,  -1349],
                        [ -1424,  -1135],
                        [ -1220,   -922],
                        [ -1009,   -712],
                        [  -794,   -511],
                        [  -574,   -321],
                        [  -351,   -141],
                        [  -126,     26],
                        [   100,    187],
                        [   324,    338],
                        [   546,    488],
                        [   765,    635],
                        [   977,    778],
                        [  1183,    916],
                        [  1382,   1051],
                        [  1571,   1181],
                        [  1749,   1306],
                        [  1918,   1424],
                        [  2072,   1537],
                        [  2214,   1644],
                        [  2342,   1742],
                        [  2455,   1833],
                        [  2553,   1917],
                        [  2638,   1996],
                        [  2708,   2069],
                        [  2759,   2134],
                        [  2789,   2191],
                        [  2797,   2239],
                        [  2752,   2244],
                        [  2659,   2211],
                        [  2501,   2117],
                        [  2280,   1962],
                        [  1991,   1740],
                        [  1635,   1449],
                        [  1252,   1128],
                        [   842,    775],
                        [   464,    449],
                        [   116,    144],
                        [  -190,   -127],
                        [  -453,   -363],
                        [  -663,   -555],
                        [  -819,   -702],
                        [  -915,   -800],
                        [  -951,   -847],
                        [  -925,   -843],
                        [  -839,   -785],
                        [  -693,   -676],
                        [  -489,   -516],
                        [  -232,   -307],
                        [    76,    -50],
                        [   430,    249],
                        [   828,    591],
                        [  1261,    968],
                        [  1728,   1379],
                        [  2216,   1817],
                        [  2721,   2279],
                        [  3231,   2759],
                        [  3745,   3255],
                        [  4253,   3756],
                        [  4755,   4263],
                        [  5250,   4766],
                        [  5736,   5263],
                        [  6213,   5746],
                        [  6677,   6212],
                        [  7120,   6654],
                        [  7539,   7071],
                        [  7928,   7455],
                        [  8284,   7803],
                        [  8601,   8112],
                        [  8876,   8378],
                        [  9103,   8595],
                        [  9282,   8763],
                        [  9407,   8878],
                        [  9477,   8938],
                        [  9492,   8942],
                        [  9446,   8886],
                        [  9344,   8772],
                        [  9220,   8637],
                        [  9120,   8526],
                        [  9060,   8459],
                        [  9043,   8434],
                        [  9050,   8433],
                        [  9033,   8407],
                        [  8916,   8279],
                        [  8669,   8018],
                        [  8301,   7633],
                        [  7821,   7135],
                        [  7238,   6533],
                        [  6564,   5841],
                        [  5813,   5072],
                        [  4996,   4239],
                        [  4128,   3356],
                        [  3221,   2440],
                        [  2288,   1502],
                        [  1343,    555],
                        [   396,   -391],
                        [  -540,  -1321],
                        [ -1458,  -2230],
                        [ -2347,  -3107],
                        [ -3198,  -3944],
                        [ -4004,  -4734],
                        [ -4760,  -5471],
                        [ -5458,  -6151],
                        [ -6097,  -6769],
                        [ -6673,  -7323],
                        [ -7183,  -7811],
                        [ -7627,  -8232],
                        [ -8004,  -8587],
                        [ -8314,  -8876],
                        [ -8558,  -9102],
                        [ -8738,  -9268],
                        [ -8858,  -9376],
                        [ -8919,  -9433],
                        [ -8925,  -9441],
                        [ -8881,  -9406],
                        [ -8790,  -9333],
                        [ -8656,  -9229],
                        [ -8483,  -9098],
                        [ -8277,  -8941],
                        [ -8041,  -8763],
                        [ -7781,  -8563],
                        [ -7501,  -8345],
                        [ -7205,  -8112],
                        [ -6899,  -7867],
                        [ -6587,  -7609],
                        [ -6272,  -7344],
                        [ -5959,  -7066],
                        [ -5653,  -6778],
                        [ -5355,  -6481],
                        [ -5070,  -6178],
                        [ -4801,  -5874],
                        [ -4551,  -5573],
                        [ -4320,  -5285],
                        [ -4112,  -5012],
                        [ -3928,  -4760],
                        [ -3768,  -4528],
                        [ -3633,  -4320],
                        [ -3524,  -4136],
                        [ -3440,  -3978],
                        [ -3381,  -3848],
                        [ -3344,  -3743],
                        [ -3330,  -3664],
                        [ -3335,  -3610],
                        [ -3360,  -3582],
                        [ -3400,  -3574],
                        [ -3457,  -3590],
                        [ -3532,  -3628],
                        [ -3621,  -3686],
                        [ -3716,  -3759],
                        [ -3818,  -3844],
                        [ -3904,  -3928],
                        [ -3976,  -4008],
                        [ -4002,  -4056],
                        [ -3985,  -4071],
                        [ -3913,  -4040],
                        [ -3787,  -3964],
                        [ -3598,  -3830],
                        [ -3344,  -3637],
                        [ -3079,  -3434],
                        [ -2797,  -3217],
                        [ -2518,  -3003],
                        [ -2240,  -2791],
                        [ -1976,  -2589],
                        [ -1723,  -2397],
                        [ -1489,  -2221],
                        [ -1274,  -2060],
                        [ -1083,  -1918],
                        [  -915,  -1796],
                        [  -774,  -1694],
                        [  -657,  -1613],
                        [  -565,  -1552],
                        [  -498,  -1512],
                        [  -454,  -1493],
                        [  -434,  -1494],
                        [  -434,  -1514],
                        [  -455,  -1551],
                        [  -490,  -1604],
                        [  -540,  -1673],
                        [  -597,  -1755],
                        [  -662,  -1851],
                        [  -729,  -1957],
                        [  -799,  -2074],
                        [  -874,  -2198],
                        [  -955,  -2329],
                        [ -1047,  -2464],
                        [ -1152,  -2602],
                        [ -1268,  -2743],
                        [ -1395,  -2884],
                        [ -1530,  -3024],
                        [ -1672,  -3163],
                        [ -1821,  -3297],
                        [ -1974,  -3426],
                        [ -2129,  -3549],
                        [ -2284,  -3664],
                        [ -2438,  -3771],
                        [ -2587,  -3868],
                        [ -2732,  -3954],
                        [ -2872,  -4028],
                        [ -3000,  -4083],
                        [ -3127,  -4132],
                        [ -3308,  -4235],
                        [ -3600,  -4445],
                        [ -4020,  -4780],
                        [ -4564,  -5238],
                        [ -5222,  -5806],
                        [ -5939,  -6429],
                        [ -6608,  -7001],
                        [ -7174,  -7464],
                        [ -7631,  -7816],
                        [ -7984,  -8061],
                        [ -8234,  -8203],
                        [ -8386,  -8247],
                        [ -8443,  -8199],
                        [ -8412,  -8067],
                        [ -8299,  -7859],
                        [ -8114,  -7584],
                        [ -7860,  -7250],
                        [ -7547,  -6864],
                        [ -7182,  -6433],
                        [ -6772,  -5968],
                        [ -6322,  -5471],
                        [ -5839,  -4948],
                        [ -5328,  -4407],
                        [ -4798,  -3854],
                        [ -4251,  -3291],
                        [ -3692,  -2724],
                        [ -3127,  -2158],
                        [ -2555,  -1593],
                        [ -1984,  -1035],
                        [ -1414,   -483],
                        [  -848,     59],
                        [  -288,    592],
                        [   265,   1115],
                        [   808,   1627],
                        [  1341,   2129],
                        [  1862,   2619],
                        [  2371,   3098],
                        [  2867,   3565],
                        [  3349,   4023],
                        [  3816,   4471],
                        [  4268,   4912],
                        [  4704,   5348],
                        [  5123,   5774],
                        [  5525,   6192],
                        [  5909,   6598],
                        [  6275,   6990],
                        [  6621,   7366],
                        [  6949,   7726],
                        [  7258,   8062],
                        [  7547,   8374],
                        [  7815,   8655],
                        [  8064,   8903],
                        [  8292,   9120],
                        [  8502,   9304],
                        [  8691,   9460],
                        [  8860,   9589],
                        [  9011,   9699],
                        [  9143,   9790],
                        [  9256,   9861],
                        [  9351,   9913],
                        [  9428,   9948],
                        [  9488,   9969],
                        [  9531,   9976],
                        [  9557,   9969],
                        [  9567,   9950],
                        [  9562,   9921],
                        [  9541,   9882],
                        [  9509,   9836],
                        [  9471,   9783],
                        [  9428,   9728],
                        [  9386,   9669],
                        [  9343,   9607],
                        [  9294,   9541],
                        [  9242,   9472],
                        [  9166,   9386],
                        [  9068,   9286],
                        [  8943,   9166],
                        [  8794,   9029],
                        [  8605,   8856],
                        [  8379,   8652],
                        [  8128,   8422],
                        [  7850,   8168],
                        [  7583,   7924],
                        [  7323,   7685],
                        [  7083,   7463],
                        [  6864,   7259],
                        [  6676,   7083],
                        [  6520,   6933],
                        [  6403,   6818],
                        [  6322,   6736],
                        [  6285,   6691],
                        [  6289,   6682],
                        [  6335,   6710],
                        [  6421,   6775],
                        [  6546,   6875],
                        [  6705,   7007],
                        [  6895,   7169],
                        [  7114,   7359],
                        [  7353,   7572],
                        [  7612,   7804],
                        [  7875,   8051],
                        [  8143,   8309],
                        [  8405,   8572],
                        [  8659,   8838],
                        [  8896,   9098],
                        [  9115,   9352],
                        [  9315,   9591],
                        [  9497,   9813],
                        [  9655,  10011],
                        [  9789,  10182],
                        [  9893,  10322],
                        [  9965,  10428],
                        [ 10001,  10495],
                        [ 10000,  10522],
                        [  9956,  10505],
                        [  9870,  10443],
                        [  9739,  10334],
                        [  9562,  10178],
                        [  9338,   9973],
                        [  9068,   9722],
                        [  8754,   9423],
                        [  8389,   9072],
                        [  7995,   8691],
                        [  7655,   8365],
                        [  7434,   8156],
                        [  7350,   8081],
                        [  7405,   8145],
                        [  7601,   8346],
                        [  7893,   8634],
                        [  8153,   8883],
                        [  8309,   9020],
                        [  8361,   9045],
                        [  8317,   8967],
                        [  8179,   8787],
                        [  7954,   8514],
                        [  7646,   8155],
                        [  7268,   7721],
                        [  6826,   7221],
                        [  6332,   6667],
                        [  5794,   6069],
                        [  5223,   5438],
                        [  4630,   4784],
                        [  4023,   4118],
                        [  3411,   3447],
                        [  2802,   2780],
                        [  2205,   2125],
                        [  1627,   1489],
                        [  1075,    881],
                        [   553,    305],
                        [    66,   -235],
                        [  -383,   -733],
                        [  -791,  -1187],
                        [ -1155,  -1597],
                        [ -1476,  -1958],
                        [ -1753,  -2275],
                        [ -1987,  -2545],
                        [ -2178,  -2771],
                        [ -2326,  -2953],
                        [ -2436,  -3093],
                        [ -2510,  -3192],
                        [ -2550,  -3254],
                        [ -2561,  -3280],
                        [ -2544,  -3279],
                        [ -2503,  -3256],
                        [ -2443,  -3217],
                        [ -2367,  -3166],
                        [ -2278,  -3107],
                        [ -2180,  -3043],
                        [ -2077,  -2975],
                        [ -1971,  -2906],
                        [ -1866,  -2835],
                        [ -1766,  -2765],
                        [ -1670,  -2690],
                        [ -1583,  -2614],
                        [ -1506,  -2533],
                        [ -1442,  -2451],
                        [ -1391,  -2369],
                        [ -1355,  -2290],
                        [ -1333,  -2219],
                        [ -1328,  -2158],
                        [ -1337,  -2110],
                        [ -1362,  -2076],
                        [ -1399,  -2053],
                        [ -1450,  -2041],
                        [ -1510,  -2042],
                        [ -1580,  -2053],
                        [ -1653,  -2075],
                        [ -1731,  -2105],
                        [ -1808,  -2143],
                        [ -1885,  -2187],
                        [ -1962,  -2234],
                        [ -2039,  -2285],
                        [ -2121,  -2338],
                        [ -2204,  -2390],
                        [ -2286,  -2437],
                        [ -2364,  -2478],
                        [ -2425,  -2509],
                        [ -2466,  -2528],
                        [ -2481,  -2533],
                        [ -2468,  -2524],
                        [ -2420,  -2492],
                        [ -2337,  -2437],
                        [ -2195,  -2334],
                        [ -1993,  -2181],
                        [ -1749,  -1992],
                        [ -1460,  -1766],
                        [ -1142,  -1514],
                        [  -795,  -1237],
                        [  -433,   -946],
                        [   -55,   -641],
                        [   326,   -332],
                        [   710,    -19],
                        [  1086,    289],
                        [  1453,    592],
                        [  1802,    882],
                        [  2134,   1160],
                        [  2442,   1419],
                        [  2727,   1660],
                        [  2983,   1879],
                        [  3209,   2074],
                        [  3408,   2246],
                        [  3576,   2393],
                        [  3718,   2514],
                        [  3834,   2611],
                        [  3926,   2682],
                        [  3993,   2728],
                        [  4041,   2753],
                        [  4069,   2754],
                        [  4076,   2734],
                        [  4063,   2693],
                        [  4028,   2637],
                        [  3969,   2564],
                        [  3890,   2479],
                        [  3792,   2382],
                        [  3677,   2277],
                        [  3547,   2165],
                        [  3408,   2050],
                        [  3257,   1932],
                        [  3101,   1816],
                        [  2940,   1701],
                        [  2780,   1593],
                        [  2622,   1490],
                        [  2468,   1394],
                        [  2319,   1307],
                        [  2189,   1240],
                        [  2043,   1159],
                        [  1792,    973],
                        [  1375,    619],
                        [   785,     92],
                        [    16,   -613],
                        [  -937,  -1501],
                        [ -2017,  -2512],
                        [ -3082,  -3503],
                        [ -4041,  -4382],
                        [ -4887,  -5144],
                        [ -5624,  -5792],
                        [ -6241,  -6319],
                        [ -6739,  -6724],
                        [ -7117,  -7009],
                        [ -7377,  -7178],
                        [ -7523,  -7235],
                        [ -7560,  -7185],
                        [ -7493,  -7035],
                        [ -7328,  -6792],
                        [ -7073,  -6462],
                        [ -6735,  -6054],
                        [ -6321,  -5575],
                        [ -5839,  -5031],
                        [ -5299,  -4434],
                        [ -4708,  -3789],
                        [ -4074,  -3105],
                        [ -3404,  -2390],
                        [ -2706,  -1651],
                        [ -1987,   -895],
                        [ -1254,   -129],
                        [  -510,    642],
                        [   235,   1412],
                        [   978,   2176],
                        [  1713,   2931],
                        [  2436,   3671],
                        [  3142,   4392],
                        [  3829,   5089],
                        [  4492,   5755],
                        [  5129,   6389],
                        [  5738,   6988],
                        [  6316,   7552],
                        [  6862,   8088],
                        [  7374,   8592],
                        [  7852,   9072],
                        [  8295,   9523],
                        [  8701,   9947],
                        [  9072,  10344],
                        [  9406,  10709],
                        [  9704,  11044],
                        [  9967,  11343],
                        [ 10196,  11607],
                        [ 10391,  11830],
                        [ 10554,  12014],
                        [ 10687,  12159],
                        [ 10790,  12266],
                        [ 10865,  12338],
                        [ 10914,  12378],
                        [ 10940,  12391],
                        [ 10944,  12383],
                        [ 10927,  12349],
                        [ 10892,  12295],
                        [ 10840,  12222],
                        [ 10774,  12131],
                        [ 10691,  12026],
                        [ 10597,  11909],
                        [ 10489,  11782],
                        [ 10372,  11647],
                        [ 10249,  11507],
                        [ 10122,  11363],
                        [ 10003,  11217],
                        [  9893,  11074],
                        [  9800,  10931],
                        [  9722,  10791],
                        [  9657,  10655],
                        [  9604,  10525],
                        [  9562,  10411],
                        [  9534,  10316],
                        [  9522,  10246],
                        [  9526,  10202],
                        [  9524,  10162],
                        [  9518,  10127],
                        [  9483,  10070],
                        [  9419,   9991],
                        [  9334,   9899],
                        [  9227,   9789],
                        [  9107,   9672],
                        [  8975,   9545],
                        [  8839,   9417],
                        [  8697,   9287],
                        [  8558,   9161],
                        [  8418,   9037],
                        [  8287,   8920],
                        [  8159,   8810],
                        [  8041,   8708],
                        [  7932,   8613],
                        [  7829,   8526],
                        [  7733,   8444],
                        [  7642,   8367],
                        [  7552,   8293],
                        [  7461,   8219],
                        [  7365,   8145],
                        [  7260,   8065],
                        [  7143,   7979],
                        [  7009,   7883],
                        [  6858,   7775],
                        [  6683,   7651],
                        [  6481,   7510],
                        [  6256,   7348],
                        [  6005,   7164],
                        [  5728,   6954],
                        [  5425,   6718],
                        [  5094,   6452],
                        [  4734,   6156],
                        [  4349,   5829],
                        [  3934,   5471],
                        [  3492,   5081],
                        [  3023,   4660],
                        [  2529,   4210],
                        [  2009,   3730],
                        [  1464,   3223],
                        [   902,   2695],
                        [   322,   2146],
                        [  -281,   1571],
                        [  -861,   1016],
                        [ -1313,    589],
                        [ -1579,    345],
                        [ -1649,    294],
                        [ -1507,    449],
                        [ -1137,    827],
                        [  -583,   1377],
                        [     0,   1948],
                        [   527,   2448],
                        [   996,   2880],
                        [  1409,   3244],
                        [  1757,   3534],
                        [  2039,   3749],
                        [  2256,   3891],
                        [  2410,   3963],
                        [  2502,   3967],
                        [  2536,   3908],
                        [  2517,   3792],
                        [  2450,   3624],
                        [  2339,   3411],
                        [  2191,   3157],
                        [  2009,   2870],
                        [  1801,   2555],
                        [  1573,   2219],
                        [  1328,   1867],
                        [  1073,   1504],
                        [   810,   1137],
                        [   546,    769],
                        [   281,    405],
                        [    20,     47],
                        [  -236,   -300],
                        [  -484,   -634],
                        [  -724,   -955],
                        [  -955,  -1260],
                        [ -1174,  -1549],
                        [ -1384,  -1822],
                        [ -1582,  -2071],
                        [ -1770,  -2299],
                        [ -1950,  -2502],
                        [ -2121,  -2680],
                        [ -2286,  -2841],
                        [ -2444,  -2988],
                        [ -2597,  -3129],
                        [ -2746,  -3268],
                        [ -2893,  -3410],
                        [ -3040,  -3556],
                        [ -3186,  -3707],
                        [ -3333,  -3863],
                        [ -3480,  -4021],
                        [ -3629,  -4184],
                        [ -3780,  -4345],
                        [ -3933,  -4506],
                        [ -4086,  -4664],
                        [ -4242,  -4818],
                        [ -4398,  -4968],
                        [ -4555,  -5112],
                        [ -4711,  -5254],
                        [ -4865,  -5393],
                        [ -5016,  -5529],
                        [ -5164,  -5663],
                        [ -5305,  -5788],
                        [ -5437,  -5905],
                        [ -5558,  -6013],
                        [ -5666,  -6111],
                        [ -5757,  -6197],
                        [ -5830,  -6270],
                        [ -5884,  -6329],
                        [ -5918,  -6374],
                        [ -5938,  -6402],
                        [ -5943,  -6413],
                        [ -5944,  -6407],
                        [ -5938,  -6381],
                        [ -5924,  -6336],
                        [ -5901,  -6270],
                        [ -5869,  -6196],
                        [ -5825,  -6112],
                        [ -5787,  -6044],
                        [ -5753,  -5991],
                        [ -5716,  -5949],
                        [ -5678,  -5918],
                        [ -5600,  -5859],
                        [ -5484,  -5773],
                        [ -5309,  -5636],
                        [ -5077,  -5451],
                        [ -4799,  -5227],
                        [ -4475,  -4962],
                        [ -4120,  -4668],
                        [ -3733,  -4346],
                        [ -3327,  -4006],
                        [ -2904,  -3651],
                        [ -2477,  -3291],
                        [ -2047,  -2925],
                        [ -1625,  -2565],
                        [ -1214,  -2211],
                        [  -822,  -1870],
                        [  -453,  -1545],
                        [  -111,  -1241],
                        [   205,   -956],
                        [   488,   -698],
                        [   741,   -466],
                        [   962,   -260],
                        [  1151,    -82],
                        [  1307,     67],
                        [  1430,    189],
                        [  1527,    284],
                        [  1594,    351],
                        [  1639,    395],
                        [  1660,    414],
                        [  1658,    414],
                        [  1636,    392],
                        [  1595,    358],
                        [  1537,    309],
                        [  1465,    249],
                        [  1380,    181],
                        [  1286,    109],
                        [  1185,     34],
                        [  1083,    -40],
                        [   978,   -113],
                        [   879,   -180],
                        [   783,   -241],
                        [   694,   -297],
                        [   613,   -343],
                        [   553,   -371],
                        [   461,   -433],
                        [   241,   -626],
                        [  -151,   -996],
                        [  -716,  -1540],
                        [ -1469,  -2274],
                        [ -2435,  -3220],
                        [ -3561,  -4324],
                        [ -4696,  -5431],
                        [ -5748,  -6450],
                        [ -6718,  -7379],
                        [ -7599,  -8214],
                        [ -8378,  -8943],
                        [ -9048,  -9560],
                        [ -9607, -10062],
                        [-10053, -10449],
                        [-10385, -10719],
                        [-10605, -10873],
                        [-10715, -10918],
                        [-10721, -10855],
                        [-10627, -10691],
                        [-10438, -10432],
                        [-10163, -10084],
                        [ -9807,  -9656],
                        [ -9380,  -9155],
                        [ -8890,  -8591],
                        [ -8347,  -7971],
                        [ -7756,  -7305],
                        [ -7127,  -6601],
                        [ -6468,  -5865],
                        [ -5785,  -5109],
                        [ -5085,  -4337],
                        [ -4378,  -3560],
                        [ -3668,  -2781],
                        [ -2961,  -2009],
                        [ -2263,  -1246],
                        [ -1581,   -507],
                        [  -918,    207],
                        [  -278,    883],
                        [   335,   1519],
                        [   919,   2111],
                        [  1470,   2656],
                        [  1987,   3162],
                        [  2468,   3629],
                        [  2914,   4067],
                        [  3321,   4472],
                        [  3691,   4849],
                        [  4025,   5197],
                        [  4323,   5514],
                        [  4584,   5801],
                        [  4810,   6056],
                        [  5003,   6281],
                        [  5163,   6472],
                        [  5294,   6633],
                        [  5397,   6764],
                        [  5472,   6865],
                        [  5525,   6939],
                        [  5555,   6986],
                        [  5566,   7012],
                        [  5560,   7018],
                        [  5539,   7005],
                        [  5504,   6976],
                        [  5458,   6930],
                        [  5402,   6868],
                        [  5334,   6795],
                        [  5259,   6712],
                        [  5177,   6621],
                        [  5089,   6523],
                        [  5002,   6421],
                        [  4917,   6316],
                        [  4847,   6208],
                        [  4791,   6099],
                        [  4758,   5991],
                        [  4747,   5882],
                        [  4755,   5780],
                        [  4781,   5684],
                        [  4846,   5631],
                        [  4947,   5618],
                        [  5094,   5660],
                        [  5284,   5758],
                        [  5492,   5886],
                        [  5718,   6044],
                        [  5903,   6171],
                        [  6046,   6269],
                        [  6136,   6326],
                        [  6172,   6340],
                        [  6160,   6314],
                        [  6096,   6248],
                        [  5988,   6147],
                        [  5835,   6008],
                        [  5642,   5838],
                        [  5409,   5635],
                        [  5144,   5406],
                        [  4844,   5147],
                        [  4519,   4865],
                        [  4167,   4559],
                        [  3793,   4233],
                        [  3395,   3884],
                        [  2979,   3517],
                        [  2541,   3130],
                        [  2084,   2725],
                        [  1607,   2302],
                        [  1115,   1862],
                        [   607,   1406],
                        [    82,    934],
                        [  -458,    444],
                        [ -1019,    -60],
                        [ -1597,   -579],
                        [ -2195,  -1112],
                        [ -2810,  -1659],
                        [ -3439,  -2219],
                        [ -4080,  -2790],
                        [ -4731,  -3373],
                        [ -5391,  -3965],
                        [ -6054,  -4565],
                        [ -6721,  -5171],
                        [ -7388,  -5783],
                        [ -8050,  -6394],
                        [ -8707,  -7005],
                        [ -9356,  -7613],
                        [ -9994,  -8214],
                        [-10614,  -8799],
                        [-11217,  -9373],
                        [-11803,  -9934],
                        [-12315, -10421],
                        [-12660, -10744],
                        [-12803, -10869],
                        [-12740, -10790],
                        [-12450, -10489],
                        [-11898,  -9933],
                        [-11126,  -9164],
                        [-10277,  -8329],
                        [ -9428,  -7508],
                        [ -8580,  -6700],
                        [ -7742,  -5913],
                        [ -6928,  -5159],
                        [ -6149,  -4449],
                        [ -5409,  -3788],
                        [ -4715,  -3180],
                        [ -4072,  -2632],
                        [ -3486,  -2144],
                        [ -2954,  -1719],
                        [ -2481,  -1359],
                        [ -2068,  -1060],
                        [ -1713,   -825],
                        [ -1415,   -650],
                        [ -1172,   -531],
                        [  -982,   -469],
                        [  -843,   -456],
                        [  -751,   -492],
                        [  -704,   -570],
                        [  -698,   -690],
                        [  -731,   -845],
                        [  -800,  -1033],
                        [  -903,  -1248],
                        [ -1035,  -1488],
                        [ -1195,  -1749],
                        [ -1380,  -2029],
                        [ -1586,  -2321],
                        [ -1811,  -2624],
                        [ -2052,  -2927],
                        [ -2308,  -3228],
                        [ -2575,  -3518],
                        [ -2853,  -3797],
                        [ -3139,  -4067],
                        [ -3431,  -4327],
                        [ -3729,  -4587],
                        [ -4029,  -4848],
                        [ -4331,  -5116],
                        [ -4633,  -5390],
                        [ -4932,  -5669],
                        [ -5228,  -5950],
                        [ -5518,  -6231],
                        [ -5801,  -6513],
                        [ -6074,  -6790],
                        [ -6338,  -7062],
                        [ -6587,  -7327],
                        [ -6823,  -7582],
                        [ -7042,  -7824],
                        [ -7244,  -8053],
                        [ -7426,  -8263],
                        [ -7588,  -8457],
                        [ -7728,  -8630],
                        [ -7844,  -8784],
                        [ -7935,  -8912],
                        [ -8000,  -9014],
                        [ -8036,  -9088],
                        [ -8044,  -9135],
                        [ -8020,  -9153],
                        [ -7965,  -9143],
                        [ -7880,  -9105],
                        [ -7765,  -9038],
                        [ -7634,  -8944],
                        [ -7484,  -8821],
                        [ -7326,  -8672],
                        [ -7163,  -8496],
                        [ -6995,  -8296],
                        [ -6823,  -8074],
                        [ -6662,  -7859],
                        [ -6511,  -7649],
                        [ -6403,  -7490],
                        [ -6335,  -7378],
                        [ -6307,  -7314],
                        [ -6318,  -7300],
                        [ -6318,  -7286],
                        [ -6313,  -7274],
                        [ -6251,  -7213],
                        [ -6135,  -7109],
                        [ -5974,  -6964],
                        [ -5766,  -6780],
                        [ -5521,  -6563],
                        [ -5239,  -6315],
                        [ -4930,  -6043],
                        [ -4596,  -5749],
                        [ -4249,  -5444],
                        [ -3888,  -5125],
                        [ -3526,  -4805],
                        [ -3163,  -4482],
                        [ -2811,  -4164],
                        [ -2469,  -3853],
                        [ -2145,  -3554],
                        [ -1838,  -3267],
                        [ -1552,  -2997],
                        [ -1287,  -2742],
                        [ -1050,  -2507],
                        [  -837,  -2292],
                        [  -653,  -2096],
                        [  -496,  -1920],
                        [  -361,  -1763],
                        [  -248,  -1624],
                        [  -147,  -1502],
                        [   -59,  -1397],
                        [    18,  -1304],
                        [    87,  -1224],
                        [   149,  -1153],
                        [   204,  -1090],
                        [   256,  -1033],
                        [   306,   -978],
                        [   355,   -925],
                        [   405,   -869],
                        [   460,   -811],
                        [   518,   -750],
                        [   584,   -683],
                        [   657,   -609],
                        [   735,   -532],
                        [   826,   -448],
                        [   930,   -352],
                        [   990,   -305],
                        [   939,   -371],
                        [   758,   -574],
                        [   445,   -911],
                        [   -24,  -1406],
                        [  -687,  -2095],
                        [ -1512,  -2945],
                        [ -2373,  -3825],
                        [ -3203,  -4668],
                        [ -4004,  -5475],
                        [ -4766,  -6236],
                        [ -5473,  -6936],
                        [ -6116,  -7566],
                        [ -6689,  -8119],
                        [ -7187,  -8591],
                        [ -7605,  -8977],
                        [ -7939,  -9273],
                        [ -8192,  -9480],
                        [ -8363,  -9598],
                        [ -8452,  -9628],
                        [ -8465,  -9575],
                        [ -8404,  -9441],
                        [ -8273,  -9233],
                        [ -8080,  -8956],
                        [ -7830,  -8618],
                        [ -7529,  -8224],
                        [ -7184,  -7782],
                        [ -6802,  -7300],
                        [ -6389,  -6783],
                        [ -5951,  -6241],
                        [ -5494,  -5679],
                        [ -5025,  -5107],
                        [ -4550,  -4529],
                        [ -4074,  -3954],
                        [ -3602,  -3383],
                        [ -3140,  -2832],
                        [ -2690,  -2302],
                        [ -2257,  -1808],
                        [ -1844,  -1351],
                        [ -1453,   -938],
                        [ -1085,   -567],
                        [  -742,   -234],
                        [  -424,     60],
                        [  -133,    331],
                        [   132,    577],
                        [   371,    801],
                        [   584,   1006],
                        [   774,   1191],
                        [   941,   1358],
                        [  1086,   1508],
                        [  1211,   1643],
                        [  1316,   1764],
                        [  1406,   1874],
                        [  1480,   1974],
                        [  1541,   2063],
                        [  1589,   2142],
                        [  1629,   2211],
                        [  1661,   2272],
                        [  1686,   2325],
                        [  1707,   2369],
                        [  1724,   2407],
                        [  1738,   2436],
                        [  1750,   2459],
                        [  1760,   2475],
                        [  1766,   2485],
                        [  1771,   2494],
                        [  1775,   2497],
                        [  1784,   2498],
                        [  1801,   2496],
                        [  1831,   2489],
                        [  1875,   2477],
                        [  1939,   2463],
                        [  2024,   2445],
                        [  2128,   2433],
                        [  2251,   2427],
                        [  2427,   2477],
                        [  2653,   2580],
                        [  2936,   2751],
                        [  3277,   2990],
                        [  3649,   3272],
                        [  4052,   3599],
                        [  4403,   3885],
                        [  4704,   4136],
                        [  4930,   4327],
                        [  5083,   4457],
                        [  5161,   4525],
                        [  5163,   4531],
                        [  5090,   4474],
                        [  4944,   4355],
                        [  4729,   4179],
                        [  4443,   3942],
                        [  4097,   3654],
                        [  3689,   3310],
                        [  3229,   2921],
                        [  2718,   2483],
                        [  2165,   2006],
                        [  1569,   1488],
                        [   940,    936],
                        [   276,    351],
                        [  -410,   -261],
                        [ -1121,   -899],
                        [ -1845,  -1557],
                        [ -2580,  -2234],
                        [ -3322,  -2923],
                        [ -4068,  -3625],
                        [ -4821,  -4334],
                        [ -5579,  -5046],
                        [ -6342,  -5759],
                        [ -7105,  -6468],
                        [ -7864,  -7172],
                        [ -8616,  -7865],
                        [ -9354,  -8547],
                        [-10075,  -9211],
                        [-10775,  -9857],
                        [-11451, -10481],
                        [-12098, -11080],
                        [-12712, -11650],
                        [-13291, -12188],
                        [-13832, -12692],
                        [-14331, -13158],
                        [-14781, -13579],
                        [-15188, -13960],
                        [-15546, -14292],
                        [-15806, -14528],
                        [-15919, -14619],
                        [-15877, -14556],
                        [-15679, -14338],
                        [-15298, -13942],
                        [-14690, -13322],
                        [-13876, -12501],
                        [-12959, -11583],
                        [-11992, -10623],
                        [-10974,  -9623],
                        [ -9924,  -8598],
                        [ -8859,  -7564],
                        [ -7794,  -6539],
                        [ -6738,  -5529],
                        [ -5706,  -4548],
                        [ -4708,  -3609],
                        [ -3755,  -2719],
                        [ -2849,  -1883],
                        [ -2001,  -1112],
                        [ -1215,   -407],
                        [  -496,    226],
                        [   156,    787],
                        [   735,   1272],
                        [  1244,   1685],
                        [  1681,   2024],
                        [  2048,   2290],
                        [  2347,   2487],
                        [  2578,   2618],
                        [  2745,   2685],
                        [  2849,   2690],
                        [  2896,   2641],
                        [  2888,   2539],
                        [  2828,   2392],
                        [  2724,   2204],
                        [  2577,   1980],
                        [  2394,   1727],
                        [  2178,   1456],
                        [  1935,   1173],
                        [  1668,    890],
                        [  1381,    608],
                        [  1081,    330],
                        [   769,     60],
                        [   450,   -210],
                        [   128,   -479],
                        [  -192,   -752],
                        [  -509,  -1026],
                        [  -817,  -1299],
                        [ -1116,  -1569],
                        [ -1399,  -1833],
                        [ -1666,  -2090],
                        [ -1913,  -2338],
                        [ -2139,  -2577],
                        [ -2340,  -2806],
                        [ -2516,  -3021],
                        [ -2662,  -3219],
                        [ -2780,  -3400],
                        [ -2868,  -3555],
                        [ -2924,  -3684],
                        [ -2949,  -3785],
                        [ -2942,  -3859],
                        [ -2904,  -3901],
                        [ -2833,  -3909],
                        [ -2731,  -3885],
                        [ -2598,  -3828],
                        [ -2433,  -3739],
                        [ -2239,  -3621],
                        [ -2021,  -3473],
                        [ -1779,  -3300],
                        [ -1529,  -3100],
                        [ -1267,  -2875],
                        [ -1005,  -2627],
                        [  -747,  -2360],
                        [  -497,  -2079],
                        [  -258,  -1786],
                        [   -57,  -1522],
                        [   107,  -1288],
                        [   197,  -1129],
                        [   215,  -1042],
                        [   159,  -1035],
                        [    27,  -1107],
                        [  -125,  -1206],
                        [  -302,  -1335],
                        [  -439,  -1430],
                        [  -540,  -1497],
                        [  -607,  -1534],
                        [  -638,  -1542],
                        [  -634,  -1522],
                        [  -596,  -1472],
                        [  -527,  -1398],
                        [  -429,  -1299],
                        [  -307,  -1181],
                        [  -162,  -1044],
                        [    -2,   -893],
                        [   175,   -727],
                        [   358,   -554],
                        [   548,   -371],
                        [   742,   -184],
                        [   938,      7],
                        [  1132,    200],
                        [  1324,    394],
                        [  1507,    587],
                        [  1682,    782],
                        [  1845,    973],
                        [  1998,   1163],
                        [  2146,   1351],
                        [  2288,   1538],
                        [  2438,   1724],
                        [  2593,   1909],
                        [  2755,   2094],
                        [  2926,   2279],
                        [  3105,   2466],
                        [  3292,   2654],
                        [  3487,   2845],
                        [  3690,   3038],
                        [  3901,   3235],
                        [  4119,   3435],
                        [  4344,   3638],
                        [  4574,   3845],
                        [  4812,   4054],
                        [  5053,   4265],
                        [  5294,   4472],
                        [  5540,   4681],
                        [  5785,   4886],
                        [  5993,   5049],
                        [  6143,   5150],
                        [  6236,   5191],
                        [  6268,   5170],
                        [  6211,   5057],
                        [  6013,   4804],
                        [  5676,   4414],
                        [  5267,   3954],
                        [  4823,   3465],
                        [  4342,   2946],
                        [  3836,   2410],
                        [  3321,   1870],
                        [  2806,   1337],
                        [  2299,    818],
                        [  1809,    323],
                        [  1343,   -138],
                        [   908,   -560],
                        [   508,   -938],
                        [   145,  -1268],
                        [  -175,  -1546],
                        [  -453,  -1773],
                        [  -687,  -1947],
                        [  -878,  -2069],
                        [ -1026,  -2143],
                        [ -1135,  -2168],
                        [ -1205,  -2149],
                        [ -1240,  -2089],
                        [ -1241,  -1991],
                        [ -1212,  -1857],
                        [ -1155,  -1695],
                        [ -1076,  -1507],
                        [  -975,  -1298],
                        [  -857,  -1073],
                        [  -725,   -836],
                        [  -582,   -592],
                        [  -431,   -348],
                        [  -275,   -106],
                        [  -115,    119],
                        [    47,    327],
                        [   209,    513],
                        [   369,    676],
                        [   527,    821],
                        [   683,    945],
                        [   835,   1064],
                        [   984,   1175],
                        [  1130,   1284],
                        [  1272,   1390],
                        [  1411,   1496],
                        [  1548,   1601],
                        [  1682,   1710],
                        [  1814,   1823],
                        [  1944,   1945],
                        [  2073,   2075],
                        [  2200,   2215],
                        [  2327,   2364],
                        [  2452,   2518],
                        [  2577,   2676],
                        [  2702,   2835],
                        [  2824,   2992],
                        [  2946,   3148],
                        [  3067,   3302],
                        [  3186,   3449],
                        [  3302,   3590],
                        [  3414,   3724],
                        [  3521,   3850],
                        [  3622,   3968],
                        [  3716,   4076],
                        [  3809,   4175],
                        [  3901,   4262],
                        [  3993,   4335],
                        [  4085,   4392],
                        [  4182,   4435],
                        [  4284,   4464],
                        [  4396,   4492],
                        [  4517,   4517],
                        [  4687,   4592],
                        [  4900,   4713],
                        [  5166,   4893],
                        [  5483,   5131],
                        [  5833,   5412],
                        [  6216,   5736],
                        [  6546,   6018],
                        [  6825,   6261],
                        [  7029,   6442],
                        [  7158,   6559],
                        [  7206,   6608],
                        [  7174,   6589],
                        [  7062,   6502],
                        [  6870,   6345],
                        [  6601,   6122],
                        [  6255,   5834],
                        [  5841,   5484],
                        [  5359,   5075],
                        [  4821,   4613],
                        [  4226,   4099],
                        [  3587,   3542],
                        [  2905,   2942],
                        [  2191,   2309],
                        [  1445,   1645],
                        [   685,    956],
                        [   -89,    248],
                        [  -862,   -474],
                        [ -1633,  -1206],
                        [ -2396,  -1939],
                        [ -3147,  -2673],
                        [ -3889,  -3399],
                        [ -4617,  -4115],
                        [ -5333,  -4813],
                        [ -6034,  -5491],
                        [ -6709,  -6143],
                        [ -7358,  -6767],
                        [ -7976,  -7356],
                        [ -8557,  -7910],
                        [ -9098,  -8422],
                        [ -9597,  -8892],
                        [-10049,  -9316],
                        [-10451,  -9692],
                        [-10801, -10016],
                        [-11096, -10288],
                        [-11334, -10504],
                        [-11512, -10662],
                        [-11633, -10764],
                        [-11692, -10803],
                        [-11677, -10769],
                        [-11590, -10662],
                        [-11446, -10497],
                        [-11239, -10269],
                        [-10947,  -9956],
                        [-10519,  -9509],
                        [ -9939,  -8907],
                        [ -9244,  -8193],
                        [ -8461,  -7396],
                        [ -7598,  -6520],
                        [ -6667,  -5582],
                        [ -5689,  -4599],
                        [ -4680,  -3586],
                        [ -3650,  -2556],
                        [ -2615,  -1524],
                        [ -1587,   -503],
                        [  -580,    492],
                        [   398,   1454],
                        [  1337,   2370],
                        [  2229,   3234],
                        [  3066,   4039],
                        [  3844,   4780],
                        [  4558,   5452],
                        [  5206,   6054],
                        [  5785,   6584],
                        [  6294,   7041],
                        [  6734,   7426],
                        [  7105,   7740],
                        [  7408,   7984],
                        [  7647,   8162],
                        [  7824,   8278],
                        [  7943,   8335],
                        [  8009,   8339],
                        [  8023,   8294],
                        [  7995,   8208],
                        [  7926,   8086],
                        [  7824,   7940],
                        [  7692,   7776],
                        [  7536,   7603],
                        [  7360,   7426],
                        [  7172,   7252],
                        [  6974,   7083],
                        [  6771,   6918],
                        [  6567,   6758],
                        [  6367,   6599],
                        [  6174,   6444],
                        [  5992,   6295],
                        [  5823,   6155],
                        [  5672,   6023],
                        [  5540,   5903],
                        [  5429,   5788],
                        [  5341,   5683],
                        [  5277,   5584],
                        [  5240,   5495],
                        [  5227,   5415],
                        [  5242,   5349],
                        [  5285,   5303],
                        [  5353,   5279],
                        [  5446,   5276],
                        [  5565,   5296],
                        [  5705,   5339],
                        [  5867,   5406],
                        [  6047,   5495],
                        [  6246,   5605],
                        [  6458,   5734],
                        [  6683,   5881],
                        [  6915,   6043],
                        [  7152,   6217],
                        [  7383,   6402],
                        [  7612,   6598],
                        [  7828,   6801],
                        [  8026,   7005],
                        [  8200,   7206],
                        [  8348,   7403],
                        [  8437,   7551],
                        [  8468,   7653],
                        [  8413,   7675],
                        [  8274,   7615],
                        [  8044,   7465],
                        [  7720,   7224],
                        [  7355,   6940],
                        [  6943,   6607],
                        [  6548,   6288],
                        [  6167,   5978],
                        [  5805,   5683],
                        [  5466,   5405],
                        [  5155,   5149],
                        [  4872,   4915],
                        [  4622,   4708],
                        [  4404,   4526],
                        [  4219,   4371],
                        [  4069,   4245],
                        [  3950,   4145],
                        [  3864,   4071],
                        [  3807,   4025],
                        [  3779,   4005],
                        [  3777,   4009],
                        [  3802,   4039],
                        [  3847,   4091],
                        [  3915,   4167],
                        [  3994,   4264],
                        [  4088,   4382],
                        [  4192,   4520],
                        [  4307,   4677],
                        [  4438,   4851],
                        [  4582,   5042],
                        [  4751,   5247],
                        [  4943,   5468],
                        [  5157,   5701],
                        [  5391,   5944],
                        [  5644,   6199],
                        [  5913,   6460],
                        [  6197,   6728],
                        [  6494,   7001],
                        [  6798,   7275],
                        [  7111,   7551],
                        [  7426,   7826],
                        [  7742,   8097],
                        [  8056,   8361],
                        [  8364,   8617],
                        [  8661,   8860],
                        [  8947,   9089],
                        [  9218,   9302],
                        [  9481,   9504],
                        [  9760,   9720],
                        [ 10067,   9964],
                        [ 10396,  10229],
                        [ 10720,  10489],
                        [ 10986,  10691],
                        [ 11142,  10784],
                        [ 11190,  10771],
                        [ 11143,  10667],
                        [ 11002,  10472],
                        [ 10777,  10199],
                        [ 10480,   9858],
                        [ 10121,   9459],
                        [  9706,   9011],
                        [  9248,   8525],
                        [  8756,   8011],
                        [  8238,   7480],
                        [  7702,   6940],
                        [  7156,   6398],
                        [  6607,   5863],
                        [  6061,   5339],
                        [  5524,   4831],
                        [  4999,   4343],
                        [  4492,   3880],
                        [  4005,   3443],
                        [  3542,   3036],
                        [  3104,   2658],
                        [  2694,   2312],
                        [  2312,   1997],
                        [  1961,   1714],
                        [  1638,   1463],
                        [  1346,   1242],
                        [  1083,   1051],
                        [   850,    886],
                        [   645,    746],
                        [   468,    627],
                        [   318,    528],
                        [   193,    441],
                        [    94,    365],
                        [    19,    296],
                        [   -33,    233],
                        [   -64,    176],
                        [   -74,    123],
                        [   -64,     82],
                        [   -36,     53],
                        [    11,     40],
                        [    74,     40],
                        [   152,     55],
                        [   245,     84],
                        [   349,    132],
                        [   466,    199],
                        [   592,    288],
                        [   726,    401],
                        [   866,    534],
                        [  1012,    689],
                        [  1160,    855],
                        [  1311,   1033],
                        [  1458,   1211],
                        [  1605,   1392],
                        [  1746,   1570],
                        [  1883,   1744],
                        [  2012,   1911],
                        [  2132,   2067],
                        [  2242,   2212],
                        [  2341,   2343],
                        [  2425,   2459],
                        [  2494,   2558],
                        [  2550,   2638],
                        [  2592,   2698],
                        [  2615,   2735],
                        [  2623,   2747],
                        [  2619,   2737],
                        [  2602,   2704],
                        [  2587,   2663],
                        [  2572,   2612],
                        [  2588,   2589],
                        [  2633,   2594],
                        [  2714,   2635],
                        [  2832,   2713],
                        [  2981,   2827],
                        [  3164,   2978],
                        [  3309,   3098],
                        [  3425,   3193],
                        [  3487,   3243],
                        [  3499,   3248],
                        [  3451,   3201],
                        [  3345,   3105],
                        [  3179,   2954],
                        [  2953,   2753],
                        [  2668,   2498],
                        [  2327,   2195],
                        [  1932,   1844],
                        [  1487,   1448],
                        [  1000,   1012],
                        [   472,    538],
                        [   -87,     34],
                        [  -674,   -498],
                        [ -1280,  -1051],
                        [ -1900,  -1623],
                        [ -2520,  -2204],
                        [ -3136,  -2792],
                        [ -3739,  -3378],
                        [ -4324,  -3962],
                        [ -4886,  -4534],
                        [ -5423,  -5092],
                        [ -5936,  -5628],
                        [ -6424,  -6141],
                        [ -6886,  -6624],
                        [ -7321,  -7074],
                        [ -7720,  -7487],
                        [ -8083,  -7861],
                        [ -8407,  -8190],
                        [ -8689,  -8474],
                        [ -8926,  -8709],
                        [ -9117,  -8894],
                        [ -9259,  -9028],
                        [ -9353,  -9109],
                        [ -9395,  -9137],
                        [ -9385,  -9112],
                        [ -9324,  -9033],
                        [ -9212,  -8902],
                        [ -9046,  -8716],
                        [ -8836,  -8483],
                        [ -8618,  -8240],
                        [ -8439,  -8032],
                        [ -8315,  -7881],
                        [ -8247,  -7781],
                        [ -8218,  -7720],
                        [ -8175,  -7641],
                        [ -8048,  -7473],
                        [ -7810,  -7192],
                        [ -7472,  -6810],
                        [ -7041,  -6333],
                        [ -6529,  -5774],
                        [ -5948,  -5144],
                        [ -5309,  -4456],
                        [ -4623,  -3720],
                        [ -3904,  -2952],
                        [ -3163,  -2163],
                        [ -2410,  -1366],
                        [ -1656,   -570],
                        [  -910,    212],
                        [  -181,    972],
                        [   524,   1703],
                        [  1199,   2399],
                        [  1839,   3054],
                        [  2438,   3664],
                        [  2993,   4225],
                        [  3503,   4735],
                        [  3965,   5194],
                        [  4379,   5600],
                        [  4746,   5954],
                        [  5066,   6256],
                        [  5341,   6511],
                        [  5574,   6717],
                        [  5767,   6881],
                        [  5923,   7005],
                        [  6046,   7096],
                        [  6140,   7157],
                        [  6208,   7196],
                        [  6255,   7215],
                        [  6284,   7222],
                        [  6299,   7222],
                        [  6304,   7220],
                        [  6303,   7221],
                        [  6299,   7226],
                        [  6294,   7239],
                        [  6293,   7256],
                        [  6296,   7279],
                        [  6307,   7308],
                        [  6326,   7347],
                        [  6355,   7391],
                        [  6397,   7443],
                        [  6450,   7493],
                        [  6515,   7544],
                        [  6593,   7590],
                        [  6684,   7635],
                        [  6787,   7677],
                        [  6901,   7716],
                        [  7025,   7761],
                        [  7159,   7811],
                        [  7298,   7867],
                        [  7444,   7929],
                        [  7591,   7995],
                        [  7739,   8064],
                        [  7883,   8136],
                        [  8022,   8207],
                        [  8153,   8277],
                        [  8273,   8344],
                        [  8380,   8406],
                        [  8473,   8461],
                        [  8550,   8507],
                        [  8611,   8546],
                        [  8652,   8574],
                        [  8669,   8587],
                        [  8650,   8581],
                        [  8598,   8556],
                        [  8485,   8482],
                        [  8312,   8361],
                        [  8068,   8178],
                        [  7754,   7933],
                        [  7358,   7612],
                        [  6882,   7214],
                        [  6355,   6768],
                        [  5775,   6272],
                        [  5192,   5770],
                        [  4602,   5261],
                        [  4019,   4756],
                        [  3445,   4255],
                        [  2893,   3772],
                        [  2364,   3305],
                        [  1866,   2864],
                        [  1402,   2450],
                        [   977,   2069],
                        [   595,   1721],
                        [   256,   1411],
                        [   -37,   1139],
                        [  -284,    908],
                        [  -485,    717],
                        [  -641,    566],
                        [  -751,    457],
                        [  -823,    388],
                        [  -854,    360],
                        [  -856,    368],
                        [  -825,    415],
                        [  -767,    495],
                        [  -682,    609],
                        [  -569,    752],
                        [  -430,    924],
                        [  -258,   1119],
                        [   -55,   1337],
                        [   172,   1573],
                        [   423,   1825],
                        [   693,   2087],
                        [   980,   2358],
                        [  1277,   2632],
                        [  1583,   2907],
                        [  1892,   3178],
                        [  2200,   3443],
                        [  2503,   3698],
                        [  2797,   3938],
                        [  3075,   4161],
                        [  3335,   4364],
                        [  3574,   4544],
                        [  3783,   4694],
                        [  3974,   4825],
                        [  4205,   4997],
                        [  4528,   5262],
                        [  4956,   5633],
                        [  5485,   6106],
                        [  6100,   6667],
                        [  6744,   7254],
                        [  7310,   7766],
                        [  7748,   8149],
                        [  8059,   8405],
                        [  8248,   8538],
                        [  8317,   8553],
                        [  8273,   8457],
                        [  8124,   8256],
                        [  7879,   7959],
                        [  7545,   7577],
                        [  7135,   7121],
                        [  6654,   6599],
                        [  6117,   6025],
                        [  5531,   5406],
                        [  4906,   4755],
                        [  4250,   4077],
                        [  3574,   3384],
                        [  2885,   2682],
                        [  2191,   1979],
                        [  1501,   1282],
                        [   819,    597],
                        [   152,    -72],
                        [  -494,   -717],
                        [ -1115,  -1336],
                        [ -1707,  -1925],
                        [ -2268,  -2481],
                        [ -2793,  -3001],
                        [ -3283,  -3485],
                        [ -3732,  -3931],
                        [ -4141,  -4339],
                        [ -4510,  -4709],
                        [ -4838,  -5043],
                        [ -5126,  -5340],
                        [ -5374,  -5601],
                        [ -5583,  -5829],
                        [ -5754,  -6025],
                        [ -5889,  -6197],
                        [ -5990,  -6346],
                        [ -6058,  -6471],
                        [ -6095,  -6573],
                        [ -6104,  -6652],
                        [ -6088,  -6710],
                        [ -6049,  -6747],
                        [ -5990,  -6765],
                        [ -5913,  -6759],
                        [ -5821,  -6733],
                        [ -5717,  -6681],
                        [ -5604,  -6606],
                        [ -5485,  -6508],
                        [ -5363,  -6389],
                        [ -5240,  -6259],
                        [ -5119,  -6118],
                        [ -5003,  -5978],
                        [ -4894,  -5842],
                        [ -4793,  -5709],
                        [ -4701,  -5580],
                        [ -4621,  -5462],
                        [ -4552,  -5355],
                        [ -4496,  -5261],
                        [ -4455,  -5182],
                        [ -4431,  -5120],
                        [ -4424,  -5075],
                        [ -4440,  -5049],
                        [ -4478,  -5044],
                        [ -4544,  -5061],
                        [ -4636,  -5102],
                        [ -4747,  -5162],
                        [ -4878,  -5242],
                        [ -5012,  -5334],
                        [ -5148,  -5437],
                        [ -5272,  -5536],
                        [ -5387,  -5634],
                        [ -5484,  -5718],
                        [ -5560,  -5788],
                        [ -5605,  -5830],
                        [ -5615,  -5840],
                        [ -5627,  -5853],
                        [ -5636,  -5865],
                        [ -5656,  -5889],
                        [ -5687,  -5923],
                        [ -5736,  -5976],
                        [ -5803,  -6044],
                        [ -5893,  -6134],
                        [ -6003,  -6243],
                        [ -6138,  -6376],
                        [ -6296,  -6528],
                        [ -6477,  -6701],
                        [ -6679,  -6892],
                        [ -6899,  -7101],
                        [ -7135,  -7325],
                        [ -7383,  -7560],
                        [ -7640,  -7806],
                        [ -7898,  -8057],
                        [ -8158,  -8310],
                        [ -8404,  -8563],
                        [ -8638,  -8811],
                        [ -8852,  -9050],
                        [ -9045,  -9278],
                        [ -9211,  -9490],
                        [ -9351,  -9684],
                        [ -9468,  -9856],
                        [ -9559, -10005],
                        [ -9627, -10125],
                        [ -9669, -10216],
                        [ -9682, -10276],
                        [ -9666, -10301],
                        [ -9620, -10291],
                        [ -9545, -10245],
                        [ -9438, -10161],
                        [ -9300, -10039],
                        [ -9130,  -9880],
                        [ -8930,  -9683],
                        [ -8698,  -9450],
                        [ -8435,  -9179],
                        [ -8141,  -8875],
                        [ -7821,  -8539],
                        [ -7467,  -8166],
                        [ -7109,  -7786],
                        [ -6827,  -7481],
                        [ -6688,  -7314],
                        [ -6702,  -7300],
                        [ -6874,  -7439],
                        [ -7202,  -7731],
                        [ -7626,  -8117],
                        [ -8025,  -8471],
                        [ -8329,  -8725],
                        [ -8542,  -8882],
                        [ -8667,  -8947],
                        [ -8707,  -8921],
                        [ -8665,  -8809],
                        [ -8547,  -8617],
                        [ -8359,  -8353],
                        [ -8109,  -8025],
                        [ -7803,  -7642],
                        [ -7451,  -7211],
                        [ -7057,  -6742],
                        [ -6632,  -6243],
                        [ -6180,  -5722],
                        [ -5708,  -5186],
                        [ -5222,  -4640],
                        [ -4729,  -4091],
                        [ -4234,  -3546],
                        [ -3742,  -3007],
                        [ -3254,  -2478],
                        [ -2776,  -1965],
                        [ -2311,  -1467],
                        [ -1857,   -988],
                        [ -1419,   -530],
                        [  -995,    -93],
                        [  -588,    323],
                        [  -197,    716],
                        [   178,   1090],
                        [   538,   1444],
                        [   882,   1779],
                        [  1214,   2097],
                        [  1532,   2397],
                        [  1839,   2678],
                        [  2136,   2945],
                        [  2423,   3201],
                        [  2702,   3450],
                        [  2973,   3698],
                        [  3238,   3946],
                        [  3495,   4193],
                        [  3748,   4441],
                        [  3994,   4687],
                        [  4234,   4932],
                        [  4467,   5170],
                        [  4695,   5403],
                        [  4913,   5621],
                        [  5124,   5825],
                        [  5325,   6008],
                        [  5517,   6171],
                        [  5697,   6312],
                        [  5865,   6433],
                        [  6019,   6537],
                        [  6159,   6627],
                        [  6281,   6702],
                        [  6385,   6762],
                        [  6468,   6801],
                        [  6528,   6822],
                        [  6561,   6823],
                        [  6568,   6805],
                        [  6546,   6763],
                        [  6497,   6702],
                        [  6423,   6617],
                        [  6323,   6511],
                        [  6206,   6382],
                        [  6073,   6233],
                        [  5920,   6061],
                        [  5747,   5867],
                        [  5544,   5649],
                        [  5311,   5408],
                        [  5039,   5142],
                        [  4730,   4851],
                        [  4388,   4540],
                        [  4015,   4208],
                        [  3596,   3836],
                        [  3132,   3428],
                        [  2622,   2979],
                        [  2068,   2488],
                        [  1494,   1982],
                        [   903,   1458],
                        [   307,    931],
                        [  -290,    401],
                        [  -873,   -117],
                        [ -1444,   -625],
                        [ -1987,  -1110],
                        [ -2501,  -1571],
                        [ -2977,  -2000],
                        [ -3414,  -2396],
                        [ -3804,  -2752],
                        [ -4149,  -3069],
                        [ -4441,  -3343],
                        [ -4684,  -3572],
                        [ -4877,  -3756],
                        [ -5022,  -3896],
                        [ -5121,  -3991],
                        [ -5176,  -4043],
                        [ -5194,  -4054],
                        [ -5175,  -4024],
                        [ -5124,  -3960],
                        [ -5043,  -3861],
                        [ -4935,  -3733],
                        [ -4801,  -3577],
                        [ -4641,  -3399],
                        [ -4456,  -3201],
                        [ -4253,  -2991],
                        [ -4036,  -2770],
                        [ -3809,  -2544],
                        [ -3574,  -2316],
                        [ -3339,  -2093],
                        [ -3105,  -1876],
                        [ -2878,  -1672],
                        [ -2659,  -1483],
                        [ -2458,  -1314],
                        [ -2274,  -1167],
                        [ -2116,  -1047],
                        [ -1980,   -953],
                        [ -1874,   -888],
                        [ -1806,   -862],
                        [ -1740,   -836],
                        [ -1583,   -717],
                        [ -1276,   -447],
                        [  -813,    -18],
                        [  -191,    573],
                        [   598,   1330],
                        [  1489,   2191],
                        [  2342,   3010],
                        [  3074,   3704],
                        [  3687,   4277],
                        [  4184,   4730],
                        [  4561,   5058],
                        [  4821,   5265],
                        [  4968,   5354],
                        [  5004,   5331],
                        [  4938,   5202],
                        [  4778,   4977],
                        [  4530,   4662],
                        [  4205,   4270],
                        [  3810,   3808],
                        [  3357,   3288],
                        [  2854,   2717],
                        [  2310,   2107],
                        [  1735,   1465],
                        [  1138,    802],
                        [   530,    126],
                        [   -85,   -556],
                        [  -696,  -1235],
                        [ -1298,  -1906],
                        [ -1886,  -2562],
                        [ -2453,  -3196],
                        [ -2995,  -3805],
                        [ -3509,  -4383],
                        [ -3990,  -4929],
                        [ -4436,  -5439],
                        [ -4845,  -5911],
                        [ -5215,  -6342],
                        [ -5546,  -6732],
                        [ -5839,  -7076],
                        [ -6092,  -7373],
                        [ -6308,  -7625],
                        [ -6488,  -7833],
                        [ -6634,  -8010],
                        [ -6747,  -8155],
                        [ -6832,  -8278],
                        [ -6888,  -8381],
                        [ -6921,  -8465],
                        [ -6931,  -8532],
                        [ -6925,  -8584],
                        [ -6902,  -8622],
                        [ -6868,  -8645],
                        [ -6825,  -8655],
                        [ -6777,  -8647],
                        [ -6727,  -8628],
                        [ -6676,  -8595],
                        [ -6630,  -8553],
                        [ -6590,  -8508],
                        [ -6559,  -8461],
                        [ -6538,  -8421],
                        [ -6533,  -8391],
                        [ -6539,  -8370],
                        [ -6560,  -8360],
                        [ -6595,  -8361],
                        [ -6645,  -8376],
                        [ -6708,  -8404],
                        [ -6787,  -8448],
                        [ -6884,  -8506],
                        [ -6997,  -8580],
                        [ -7139,  -8669],
                        [ -7308,  -8775],
                        [ -7508,  -8896],
                        [ -7735,  -9031],
                        [ -7981,  -9178],
                        [ -8246,  -9336],
                        [ -8514,  -9507],
                        [ -8785,  -9688],
                        [ -9065,  -9892],
                        [ -9354, -10117],
                        [ -9642, -10352],
                        [ -9927, -10596],
                        [-10177, -10814],
                        [-10390, -11005],
                        [-10560, -11161],
                        [-10686, -11282],
                        [-10775, -11373],
                        [-10826, -11432],
                        [-10848, -11468],
                        [-10837, -11477],
                        [-10803, -11467],
                        [-10741, -11434],
                        [-10662, -11385],
                        [-10563, -11319],
                        [-10450, -11239],
                        [-10320, -11143],
                        [-10181, -11037],
                        [-10029, -10917],
                        [ -9865, -10785],
                        [ -9691, -10642],
                        [ -9501, -10487],
                        [ -9299, -10320],
                        [ -9079, -10139],
                        [ -8843,  -9947],
                        [ -8588,  -9740],
                        [ -8315,  -9519],
                        [ -8021,  -9283],
                        [ -7707,  -9033],
                        [ -7376,  -8766],
                        [ -7029,  -8483],
                        [ -6669,  -8184],
                        [ -6296,  -7869],
                        [ -5910,  -7537],
                        [ -5513,  -7189],
                        [ -5106,  -6825],
                        [ -4690,  -6446],
                        [ -4266,  -6050],
                        [ -3835,  -5640],
                        [ -3399,  -5218],
                        [ -2959,  -4783],
                        [ -2515,  -4336],
                        [ -2068,  -3880],
                        [ -1623,  -3420],
                        [ -1177,  -2954],
                        [  -725,  -2479],
                        [  -320,  -2047],
                        [   -63,  -1761],
                        [    -8,  -1675],
                        [  -161,  -1796],
                        [  -531,  -2135],
                        [ -1135,  -2705],
                        [ -1910,  -3443],
                        [ -2705,  -4196],
                        [ -3434,  -4877],
                        [ -4097,  -5485],
                        [ -4696,  -6021],
                        [ -5219,  -6476],
                        [ -5662,  -6846],
                        [ -6026,  -7131],
                        [ -6308,  -7331],
                        [ -6511,  -7448],
                        [ -6636,  -7485],
                        [ -6684,  -7444],
                        [ -6661,  -7332],
                        [ -6569,  -7153],
                        [ -6414,  -6912],
                        [ -6199,  -6613],
                        [ -5930,  -6262],
                        [ -5611,  -5865],
                        [ -5250,  -5428],
                        [ -4851,  -4955],
                        [ -4418,  -4452],
                        [ -3956,  -3924],
                        [ -3470,  -3375],
                        [ -2964,  -2810],
                        [ -2442,  -2233],
                        [ -1906,  -1648],
                        [ -1361,  -1060],
                        [  -812,   -470],
                        [  -259,    118],
                        [   293,    700],
                        [   840,   1274],
                        [  1382,   1831],
                        [  1916,   2370],
                        [  2440,   2884],
                        [  2952,   3373],
                        [  3449,   3838],
                        [  3932,   4280],
                        [  4396,   4710],
                        [  4842,   5126],
                        [  5267,   5531],
                        [  5671,   5922],
                        [  6051,   6299],
                        [  6406,   6659],
                        [  6734,   6998],
                        [  7035,   7317],
                        [  7308,   7605],
                        [  7551,   7865],
                        [  7761,   8090],
                        [  7941,   8282],
                        [  8088,   8437],
                        [  8202,   8557],
                        [  8283,   8645],
                        [  8329,   8700],
                        [  8341,   8725],
                        [  8318,   8720],
                        [  8257,   8679],
                        [  8162,   8605],
                        [  8027,   8497],
                        [  7855,   8357],
                        [  7650,   8185],
                        [  7410,   7983],
                        [  7148,   7752],
                        [  6866,   7493],
                        [  6575,   7209],
                        [  6277,   6901],
                        [  5974,   6572],
                        [  5664,   6223],
                        [  5341,   5859],
                        [  5007,   5482],
                        [  4675,   5119],
                        [  4347,   4769],
                        [  4037,   4449],
                        [  3749,   4160],
                        [  3461,   3880],
                        [  3177,   3611],
                        [  2858,   3314],
                        [  2509,   2994],
                        [  2134,   2651],
                        [  1731,   2287],
                        [  1317,   1913],
                        [   890,   1530],
                        [   463,   1148],
                        [    37,    769],
                        [  -375,    401],
                        [  -775,     46],
                        [ -1151,   -288],
                        [ -1503,   -601],
                        [ -1822,   -886],
                        [ -2108,  -1144],
                        [ -2358,  -1370],
                        [ -2572,  -1565],
                        [ -2748,  -1727],
                        [ -2888,  -1856],
                        [ -2996,  -1952],
                        [ -3070,  -2019],
                        [ -3114,  -2056],
                        [ -3131,  -2067],
                        [ -3126,  -2053],
                        [ -3102,  -2019],
                        [ -3064,  -1966],
                        [ -3014,  -1899],
                        [ -2953,  -1821],
                        [ -2886,  -1735],
                        [ -2815,  -1646],
                        [ -2743,  -1557],
                        [ -2675,  -1472],
                        [ -2610,  -1394],
                        [ -2554,  -1328],
                        [ -2509,  -1275],
                        [ -2478,  -1239],
                        [ -2462,  -1221],
                        [ -2465,  -1226],
                        [ -2488,  -1255],
                        [ -2533,  -1308],
                        [ -2598,  -1383],
                        [ -2689,  -1484],
                        [ -2809,  -1616],
                        [ -2901,  -1718],
                        [ -2864,  -1692],
                        [ -2660,  -1494],
                        [ -2282,  -1120],
                        [ -1714,   -555],
                        [  -934,    223],
                        [     2,   1154],
                        [   938,   2083],
                        [  1797,   2931],
                        [  2585,   3697],
                        [  3296,   4379],
                        [  3921,   4968],
                        [  4457,   5460],
                        [  4905,   5855],
                        [  5262,   6153],
                        [  5531,   6355],
                        [  5714,   6467],
                        [  5817,   6491],
                        [  5844,   6434],
                        [  5800,   6303],
                        [  5693,   6103],
                        [  5529,   5842],
                        [  5315,   5527],
                        [  5059,   5166],
                        [  4768,   4769],
                        [  4449,   4340],
                        [  4110,   3888],
                        [  3756,   3420],
                        [  3394,   2941],
                        [  3028,   2459],
                        [  2663,   1978],
                        [  2305,   1504],
                        [  1957,   1042],
                        [  1620,    595],
                        [  1300,    167],
                        [   999,   -241],
                        [   717,   -620],
                        [   456,   -970],
                        [   215,  -1283],
                        [    -6,  -1557],
                        [  -206,  -1793],
                        [  -387,  -1991],
                        [  -551,  -2164],
                        [  -699,  -2312],
                        [  -832,  -2450],
                        [  -954,  -2579],
                        [ -1066,  -2702],
                        [ -1170,  -2822],
                        [ -1268,  -2938],
                        [ -1363,  -3053],
                        [ -1456,  -3167],
                        [ -1550,  -3280],
                        [ -1648,  -3391],
                        [ -1749,  -3503],
                        [ -1857,  -3613],
                        [ -1972,  -3726],
                        [ -2095,  -3843],
                        [ -2229,  -3964],
                        [ -2371,  -4094],
                        [ -2524,  -4233],
                        [ -2686,  -4379],
                        [ -2857,  -4533],
                        [ -3033,  -4689],
                        [ -3214,  -4850],
                        [ -3400,  -5014],
                        [ -3590,  -5181],
                        [ -3785,  -5350],
                        [ -3989,  -5521],
                        [ -4210,  -5691],
                        [ -4448,  -5860],
                        [ -4703,  -6025],
                        [ -4973,  -6184],
                        [ -5248,  -6338],
                        [ -5527,  -6484],
                        [ -5809,  -6639],
                        [ -6089,  -6803],
                        [ -6394,  -7005],
                        [ -6722,  -7243],
                        [ -7063,  -7508],
                        [ -7417,  -7801],
                        [ -7732,  -8067],
                        [ -8010,  -8310],
                        [ -8211,  -8488],
                        [ -8335,  -8601],
                        [ -8386,  -8655],
                        [ -8364,  -8645],
                        [ -8274,  -8578],
                        [ -8115,  -8452],
                        [ -7898,  -8277],
                        [ -7621,  -8048],
                        [ -7295,  -7776],
                        [ -6918,  -7459],
                        [ -6503,  -7105],
                        [ -6049,  -6714],
                        [ -5566,  -6293],
                        [ -5055,  -5843],
                        [ -4522,  -5369],
                        [ -3967,  -4874],
                        [ -3399,  -4362],
                        [ -2815,  -3833],
                        [ -2222,  -3292],
                        [ -1623,  -2741],
                        [ -1018,  -2183],
                        [  -410,  -1618],
                        [   205,  -1050],
                        [   823,   -479],
                        [  1442,     91],
                        [  2060,    661],
                        [  2673,   1226],
                        [  3280,   1788],
                        [  3878,   2343],
                        [  4466,   2893],
                        [  5040,   3433],
                        [  5598,   3963],
                        [  6142,   4483],
                        [  6666,   4991],
                        [  7171,   5486],
                        [  7655,   5966],
                        [  8119,   6434],
                        [  8560,   6884],
                        [  8974,   7314],
                        [  9367,   7726],
                        [  9741,   8122],
                        [ 10031,   8435],
                        [ 10152,   8580],
                        [ 10073,   8524],
                        [  9796,   8267],
                        [  9297,   7789],
                        [  8552,   7062],
                        [  7611,   6141],
                        [  6623,   5176],
                        [  5664,   4242],
                        [  4729,   3340],
                        [  3829,   2480],
                        [  2982,   1677],
                        [  2196,    942],
                        [  1480,    280],
                        [   837,   -303],
                        [   275,   -802],
                        [  -202,  -1216],
                        [  -596,  -1541],
                        [  -903,  -1779],
                        [ -1124,  -1929],
                        [ -1262,  -1994],
                        [ -1317,  -1976],
                        [ -1294,  -1880],
                        [ -1198,  -1709],
                        [ -1033,  -1469],
                        [  -804,  -1164],
                        [  -515,   -802],
                        [  -174,   -387],
                        [   215,     76],
                        [   646,    579],
                        [  1114,   1119],
                        [  1612,   1685],
                        [  2134,   2275],
                        [  2676,   2880],
                        [  3230,   3497],
                        [  3790,   4116],
                        [  4353,   4734],
                        [  4912,   5335],
                        [  5465,   5916],
                        [  6006,   6466],
                        [  6531,   6983],
                        [  7036,   7466],
                        [  7519,   7912],
                        [  7975,   8334],
                        [  8402,   8728],
                        [  8799,   9101],
                        [  9162,   9449],
                        [  9488,   9770],
                        [  9776,  10065],
                        [ 10027,  10330],
                        [ 10238,  10563],
                        [ 10407,  10761],
                        [ 10535,  10924],
                        [ 10621,  11051],
                        [ 10666,  11142],
                        [ 10670,  11196],
                        [ 10632,  11213],
                        [ 10556,  11195],
                        [ 10441,  11142],
                        [ 10287,  11054],
                        [ 10097,  10934],
                        [  9869,  10779],
                        [  9608,  10590],
                        [  9313,  10368],
                        [  8988,  10116],
                        [  8636,   9836],
                        [  8262,   9530],
                        [  7880,   9202],
                        [  7493,   8853],
                        [  7114,   8487],
                        [  6745,   8105],
                        [  6386,   7712],
                        [  6043,   7311],
                        [  5709,   6914],
                        [  5389,   6521],
                        [  5117,   6183],
                        [  4892,   5900],
                        [  4733,   5689],
                        [  4641,   5553],
                        [  4593,   5468],
                        [  4591,   5439],
                        [  4568,   5393],
                        [  4526,   5338],
                        [  4453,   5259],
                        [  4350,   5155],
                        [  4223,   5033],
                        [  4071,   4895],
                        [  3901,   4743],
                        [  3712,   4578],
                        [  3515,   4407],
                        [  3306,   4229],
                        [  3096,   4051],
                        [  2883,   3871],
                        [  2676,   3694],
                        [  2472,   3521],
                        [  2278,   3354],
                        [  2091,   3192],
                        [  1916,   3040],
                        [  1749,   2894],
                        [  1595,   2756],
                        [  1450,   2624],
                        [  1317,   2499],
                        [  1193,   2379],
                        [  1071,   2262],
                        [   949,   2147],
                        [   821,   2031],
                        [   687,   1914],
                        [   545,   1794],
                        [   394,   1668],
                        [   232,   1535],
                        [    61,   1394],
                        [  -123,   1243],
                        [  -317,   1082],
                        [  -523,    909],
                        [  -743,    723],
                        [  -973,    523],
                        [ -1214,    312],
                        [ -1466,     86],
                        [ -1728,   -152],
                        [ -1998,   -401],
                        [ -2271,   -656],
                        [ -2553,   -921],
                        [ -2839,  -1194],
                        [ -3066,  -1407],
                        [ -3165,  -1493],
                        [ -3117,  -1430],
                        [ -2918,  -1214],
                        [ -2540,   -820],
                        [ -1946,   -209],
                        [ -1177,    574],
                        [  -358,   1402],
                        [   450,   2212],
                        [  1252,   3009],
                        [  2039,   3780],
                        [  2797,   4511],
                        [  3518,   5196],
                        [  4195,   5828],
                        [  4824,   6404],
                        [  5400,   6918],
                        [  5918,   7367],
                        [  6380,   7751],
                        [  6784,   8071],
                        [  7129,   8324],
                        [  7417,   8514],
                        [  7651,   8643],
                        [  7833,   8714],
                        [  7967,   8731],
                        [  8054,   8698],
                        [  8100,   8620],
                        [  8107,   8500],
                        [  8080,   8344],
                        [  8022,   8154],
                        [  7936,   7937],
                        [  7824,   7694],
                        [  7692,   7433],
                        [  7540,   7154],
                        [  7372,   6862],
                        [  7191,   6562],
                        [  6998,   6254],
                        [  6796,   5949],
                        [  6585,   5648],
                        [  6367,   5362],
                        [  6143,   5091],
                        [  5911,   4838],
                        [  5673,   4605],
                        [  5431,   4381],
                        [  5181,   4166],
                        [  4926,   3945],
                        [  4665,   3720],
                        [  4396,   3485],
                        [  4122,   3241],
                        [  3841,   2988],
                        [  3553,   2724],
                        [  3258,   2452],
                        [  2957,   2170],
                        [  2650,   1879],
                        [  2336,   1577],
                        [  2018,   1268],
                        [  1697,    949],
                        [  1372,    625],
                        [  1044,    295],
                        [   717,    -36],
                        [   391,   -368],
                        [    69,   -698],
                        [  -248,  -1025],
                        [  -556,  -1341],
                        [  -852,  -1648],
                        [ -1137,  -1940],
                        [ -1408,  -2219],
                        [ -1670,  -2481],
                        [ -1921,  -2724],
                        [ -2173,  -2949],
                        [ -2422,  -3150],
                        [ -2668,  -3327],
                        [ -2912,  -3481],
                        [ -3144,  -3608],
                        [ -3365,  -3711],
                        [ -3587,  -3822],
                        [ -3809,  -3937],
                        [ -4066,  -4099],
                        [ -4353,  -4302],
                        [ -4669,  -4545],
                        [ -5010,  -4827],
                        [ -5319,  -5090],
                        [ -5597,  -5334],
                        [ -5786,  -5501],
                        [ -5887,  -5593],
                        [ -5904,  -5613],
                        [ -5835,  -5558],
                        [ -5683,  -5432],
                        [ -5450,  -5236],
                        [ -5144,  -4975],
                        [ -4765,  -4650],
                        [ -4324,  -4270],
                        [ -3823,  -3833],
                        [ -3274,  -3352],
                        [ -2679,  -2826],
                        [ -2050,  -2264],
                        [ -1389,  -1668],
                        [  -704,  -1049],
                        [     0,   -406],
                        [   713,    251],
                        [  1433,    921],
                        [  2149,   1597],
                        [  2860,   2277],
                        [  3562,   2953],
                        [  4253,   3627],
                        [  4936,   4291],
                        [  5608,   4944],
                        [  6268,   5583],
                        [  6915,   6204],
                        [  7542,   6806],
                        [  8149,   7386],
                        [  8732,   7944],
                        [  9290,   8476],
                        [  9820,   8981],
                        [ 10320,   9458],
                        [ 10790,   9908],
                        [ 11228,  10327],
                        [ 11633,  10716],
                        [ 12002,  11074],
                        [ 12340,  11402],
                        [ 12643,  11698],
                        [ 12907,  11959],
                        [ 13140,  12191],
                        [ 13337,  12387],
                        [ 13448,  12498],
                        [ 13427,  12476],
                        [ 13271,  12316],
                        [ 12981,  12018],
                        [ 12528,  11552],
                        [ 11872,  10883],
                        [ 11044,  10041],
                        [ 10148,   9132],
                        [  9237,   8210],
                        [  8309,   7274],
                        [  7379,   6342],
                        [  6467,   5433],
                        [  5584,   4559],
                        [  4743,   3729],
                        [  3950,   2953],
                        [  3218,   2242],
                        [  2552,   1599],
                        [  1957,   1032],
                        [  1437,    544],
                        [   994,    138],
                        [   631,   -184],
                        [   346,   -423],
                        [   138,   -579],
                        [     5,   -657],
                        [   -58,   -660],
                        [   -53,   -592],
                        [    14,   -458],
                        [   138,   -263],
                        [   314,    -14],
                        [   537,    284],
                        [   799,    625],
                        [  1094,    999],
                        [  1417,   1404],
                        [  1759,   1828],
                        [  2116,   2268],
                        [  2480,   2713],
                        [  2845,   3157],
                        [  3207,   3584],
                        [  3559,   3990],
                        [  3897,   4364],
                        [  4216,   4701],
                        [  4513,   4999],
                        [  4784,   5253],
                        [  5025,   5475],
                        [  5235,   5664],
                        [  5411,   5824],
                        [  5551,   5956],
                        [  5653,   6056],
                        [  5717,   6126],
                        [  5742,   6166],
                        [  5730,   6176],
                        [  5678,   6156],
                        [  5588,   6108],
                        [  5462,   6034],
                        [  5299,   5936],
                        [  5103,   5813],
                        [  4874,   5666],
                        [  4615,   5495],
                        [  4328,   5300],
                        [  4016,   5082],
                        [  3680,   4843],
                        [  3323,   4582],
                        [  2948,   4301],
                        [  2557,   4002],
                        [  2154,   3686],
                        [  1745,   3357],
                        [  1333,   3018],
                        [   934,   2673],
                        [   549,   2324],
                        [   187,   1971],
                        [  -150,   1617],
                        [  -457,   1268],
                        [  -734,    925],
                        [  -976,    608],
                        [ -1184,    314],
                        [ -1310,    103],
                        [ -1359,    -28],
                        [ -1314,    -62],
                        [ -1176,      2],
                        [  -966,    143],
                        [  -683,    364],
                        [  -414,    579],
                        [  -152,    793],
                        [    77,    983],
                        [   275,   1150],
                        [   438,   1290],
                        [   565,   1404],
                        [   656,   1490],
                        [   710,   1547],
                        [   730,   1577],
                        [   714,   1579],
                        [   669,   1555],
                        [   592,   1502],
                        [   489,   1427],
                        [   360,   1327],
                        [   208,   1204],
                        [    32,   1058],
                        [  -161,    894],
                        [  -373,    707],
                        [  -596,    504],
                        [  -831,    281],
                        [ -1075,     42],
                        [ -1329,   -215],
                        [ -1599,   -486],
                        [ -1884,   -774],
                        [ -2191,  -1075],
                        [ -2518,  -1391],
                        [ -2863,  -1719],
                        [ -3225,  -2059],
                        [ -3602,  -2408],
                        [ -3992,  -2767],
                        [ -4392,  -3134],
                        [ -4800,  -3505],
                        [ -5213,  -3881],
                        [ -5629,  -4258],
                        [ -6044,  -4635],
                        [ -6456,  -5007],
                        [ -6860,  -5376],
                        [ -7256,  -5736],
                        [ -7636,  -6086],
                        [ -7997,  -6419],
                        [ -8340,  -6737],
                        [ -8656,  -7031],
                        [ -8907,  -7262],
                        [ -9069,  -7406],
                        [ -9144,  -7462],
                        [ -9127,  -7427],
                        [ -8985,  -7268],
                        [ -8670,  -6936],
                        [ -8188,  -6442],
                        [ -7613,  -5858],
                        [ -6978,  -5221],
                        [ -6284,  -4530],
                        [ -5541,  -3800],
                        [ -4769,  -3049],
                        [ -3977,  -2286],
                        [ -3175,  -1520],
                        [ -2375,   -763],
                        [ -1586,    -24],
                        [  -817,    690],
                        [   -73,   1372],
                        [   638,   2013],
                        [  1310,   2611],
                        [  1939,   3158],
                        [  2523,   3655],
                        [  3057,   4097],
                        [  3542,   4483],
                        [  3975,   4814],
                        [  4355,   5090],
                        [  4682,   5311],
                        [  4959,   5478],
                        [  5182,   5592],
                        [  5356,   5657],
                        [  5479,   5672],
                        [  5555,   5641],
                        [  5584,   5566],
                        [  5569,   5451],
                        [  5512,   5298],
                        [  5415,   5111],
                        [  5281,   4899],
                        [  5112,   4663],
                        [  4909,   4414],
                        [  4674,   4154],
                        [  4411,   3890],
                        [  4121,   3623],
                        [  3806,   3348],
                        [  3469,   3068],
                        [  3110,   2771],
                        [  2733,   2460],
                        [  2341,   2133],
                        [  1935,   1790],
                        [  1516,   1433],
                        [  1089,   1064],
                        [   654,    683],
                        [   216,    290],
                        [  -223,   -115],
                        [  -662,   -531],
                        [ -1097,   -956],
                        [ -1525,  -1387],
                        [ -1944,  -1818],
                        [ -2353,  -2250],
                        [ -2745,  -2671],
                        [ -3122,  -3079],
                        [ -3478,  -3471],
                        [ -3812,  -3847],
                        [ -4122,  -4198],
                        [ -4405,  -4522],
                        [ -4661,  -4818],
                        [ -4888,  -5084],
                        [ -5090,  -5318],
                        [ -5264,  -5519],
                        [ -5421,  -5684],
                        [ -5556,  -5812],
                        [ -5672,  -5902],
                        [ -5771,  -5956],
                        [ -5849,  -5978],
                        [ -5906,  -5963],
                        [ -5971,  -5958],
                        [ -6041,  -5959],
                        [ -6151,  -6004],
                        [ -6296,  -6091],
                        [ -6482,  -6224],
                        [ -6707,  -6404],
                        [ -6915,  -6576],
                        [ -7111,  -6744],
                        [ -7230,  -6845],
                        [ -7279,  -6884],
                        [ -7256,  -6860],
                        [ -7159,  -6773],
                        [ -6991,  -6622],
                        [ -6750,  -6407],
                        [ -6443,  -6133],
                        [ -6071,  -5801],
                        [ -5641,  -5418],
                        [ -5156,  -4983],
                        [ -4628,  -4506],
                        [ -4057,  -3987],
                        [ -3454,  -3435],
                        [ -2820,  -2852],
                        [ -2169,  -2247],
                        [ -1500,  -1622],
                        [  -829,   -986],
                        [  -158,   -340],
                        [   504,    308],
                        [  1152,    956],
                        [  1786,   1596],
                        [  2401,   2228],
                        [  3003,   2845],
                        [  3592,   3447],
                        [  4165,   4027],
                        [  4720,   4586],
                        [  5253,   5118],
                        [  5762,   5623],
                        [  6245,   6098],
                        [  6700,   6542],
                        [  7125,   6953],
                        [  7518,   7330],
                        [  7880,   7672],
                        [  8208,   7978],
                        [  8502,   8249],
                        [  8761,   8481],
                        [  8986,   8680],
                        [  9174,   8840],
                        [  9325,   8964],
                        [  9441,   9052],
                        [  9521,   9101],
                        [  9548,   9097],
                        [  9529,   9043],
                        [  9475,   8951],
                        [  9383,   8816],
                        [  9224,   8613],
                        [  8951,   8292],
                        [  8546,   7838],
                        [  8054,   7296],
                        [  7499,   6691],
                        [  6884,   6030],
                        [  6227,   5327],
                        [  5540,   4598],
                        [  4838,   3856],
                        [  4128,   3112],
                        [  3424,   2377],
                        [  2737,   1662],
                        [  2074,    973],
                        [  1443,    322],
                        [   849,   -287],
                        [   298,   -846],
                        [  -207,  -1353],
                        [  -665,  -1804],
                        [ -1072,  -2199],
                        [ -1430,  -2536],
                        [ -1738,  -2817],
                        [ -1999,  -3044],
                        [ -2215,  -3219],
                        [ -2389,  -3346],
                        [ -2523,  -3428],
                        [ -2622,  -3470],
                        [ -2690,  -3476],
                        [ -2732,  -3451],
                        [ -2753,  -3400],
                        [ -2755,  -3327],
                        [ -2745,  -3239],
                        [ -2728,  -3145],
                        [ -2709,  -3048],
                        [ -2689,  -2960],
                        [ -2676,  -2885],
                        [ -2670,  -2833],
                        [ -2676,  -2806],
                        [ -2695,  -2809],
                        [ -2732,  -2843],
                        [ -2786,  -2902],
                        [ -2860,  -2988],
                        [ -2956,  -3093],
                        [ -3072,  -3219],
                        [ -3211,  -3363],
                        [ -3370,  -3525],
                        [ -3550,  -3703],
                        [ -3751,  -3895],
                        [ -3970,  -4096],
                        [ -4206,  -4305],
                        [ -4460,  -4516],
                        [ -4726,  -4726],
                        [ -5006,  -4938],
                        [ -5296,  -5147],
                        [ -5594,  -5359],
                        [ -5897,  -5571],
                        [ -6203,  -5787],
                        [ -6508,  -6004],
                        [ -6810,  -6221],
                        [ -7109,  -6434],
                        [ -7398,  -6647],
                        [ -7679,  -6857],
                        [ -7945,  -7060],
                        [ -8197,  -7256],
                        [ -8422,  -7443],
                        [ -8623,  -7618],
                        [ -8795,  -7785],
                        [ -8934,  -7941],
                        [ -9038,  -8080],
                        [ -9105,  -8205],
                        [ -9126,  -8294],
                        [ -9102,  -8350],
                        [ -8993,  -8323],
                        [ -8801,  -8218],
                        [ -8520,  -8021],
                        [ -8148,  -7735],
                        [ -7701,  -7370],
                        [ -7178,  -6926],
                        [ -6664,  -6484],
                        [ -6154,  -6040],
                        [ -5674,  -5618],
                        [ -5224,  -5220],
                        [ -4816,  -4855],
                        [ -4449,  -4522],
                        [ -4131,  -4230],
                        [ -3862,  -3977],
                        [ -3646,  -3768],
                        [ -3483,  -3605],
                        [ -3371,  -3486],
                        [ -3313,  -3415],
                        [ -3302,  -3388],
                        [ -3343,  -3408],
                        [ -3427,  -3470],
                        [ -3559,  -3576],
                        [ -3727,  -3720],
                        [ -3933,  -3905],
                        [ -4165,  -4124],
                        [ -4424,  -4379],
                        [ -4704,  -4663],
                        [ -5003,  -4976],
                        [ -5327,  -5312],
                        [ -5673,  -5672],
                        [ -6043,  -6049],
                        [ -6437,  -6442],
                        [ -6846,  -6847],
                        [ -7269,  -7259],
                        [ -7702,  -7674],
                        [ -8140,  -8091],
                        [ -8577,  -8503],
                        [ -9010,  -8908],
                        [ -9434,  -9302],
                        [ -9845,  -9680],
                        [-10238, -10039],
                        [-10610, -10375],
                        [-10955, -10685],
                        [-11270, -10965],
                        [-11549, -11211],
                        [-11789, -11421],
                        [-11988, -11591],
                        [-12140, -11718],
                        [-12257, -11811],
                        [-12359, -11893],
                        [-12461, -11974],
                        [-12556, -12049],
                        [-12615, -12092],
                        [-12585, -12047],
                        [-12421, -11871],
                        [-12131, -11572],
                        [-11733, -11168],
                        [-11230, -10662],
                        [-10638, -10070],
                        [ -9969,  -9406],
                        [ -9236,  -8682],
                        [ -8451,  -7909],
                        [ -7627,  -7100],
                        [ -6777,  -6267],
                        [ -5913,  -5423],
                        [ -5046,  -4578],
                        [ -4185,  -3743],
                        [ -3340,  -2929],
                        [ -2521,  -2144],
                        [ -1733,  -1393],
                        [  -985,   -687],
                        [  -282,    -29],
                        [   371,    577],
                        [   971,   1127],
                        [  1513,   1618],
                        [  1996,   2048],
                        [  2417,   2418],
                        [  2776,   2726],
                        [  3073,   2973],
                        [  3308,   3158],
                        [  3481,   3284],
                        [  3595,   3352],
                        [  3651,   3365],
                        [  3651,   3326],
                        [  3599,   3244],
                        [  3499,   3119],
                        [  3351,   2962],
                        [  3161,   2775],
                        [  2932,   2565],
                        [  2667,   2335],
                        [  2372,   2089],
                        [  2048,   1829],
                        [  1701,   1552],
                        [  1334,   1261],
                        [   953,    956],
                        [   560,    639],
                        [   160,    312],
                        [  -245,    -21],
                        [  -648,   -361],
                        [ -1047,   -704],
                        [ -1438,  -1055],
                        [ -1817,  -1411],
                        [ -2180,  -1768],
                        [ -2524,  -2125],
                        [ -2847,  -2474],
                        [ -3146,  -2815],
                        [ -3418,  -3132],
                        [ -3662,  -3426],
                        [ -3876,  -3695],
                        [ -4059,  -3936],
                        [ -4210,  -4145],
                        [ -4327,  -4319],
                        [ -4409,  -4460],
                        [ -4457,  -4563],
                        [ -4470,  -4630],
                        [ -4451,  -4661],
                        [ -4402,  -4655],
                        [ -4322,  -4609],
                        [ -4218,  -4526],
                        [ -4093,  -4409],
                        [ -3951,  -4263],
                        [ -3793,  -4089],
                        [ -3651,  -3924],
                        [ -3523,  -3770],
                        [ -3432,  -3649],
                        [ -3379,  -3564],
                        [ -3374,  -3526],
                        [ -3418,  -3539],
                        [ -3471,  -3563],
                        [ -3538,  -3602],
                        [ -3567,  -3608],
                        [ -3563,  -3585],
                        [ -3522,  -3528],
                        [ -3446,  -3440],
                        [ -3328,  -3315],
                        [ -3170,  -3156],
                        [ -2973,  -2961],
                        [ -2738,  -2733],
                        [ -2468,  -2474],
                        [ -2166,  -2185],
                        [ -1835,  -1870],
                        [ -1478,  -1530],
                        [ -1101,  -1169],
                        [  -707,   -791],
                        [  -301,   -401],
                        [   111,      1],
                        [   521,    408],
                        [   925,    819],
                        [  1317,   1229],
                        [  1696,   1636],
                        [  2059,   2036],
                        [  2407,   2427],
                        [  2746,   2806],
                        [  3076,   3170],
                        [  3395,   3518],
                        [  3703,   3849],
                        [  3998,   4158],
                        [  4277,   4447],
                        [  4541,   4713],
                        [  4787,   4954],
                        [  5014,   5169],
                        [  5223,   5359],
                        [  5411,   5523],
                        [  5579,   5660],
                        [  5724,   5770],
                        [  5848,   5851],
                        [  5950,   5905],
                        [  6028,   5932],
                        [  6082,   5932],
                        [  6108,   5902],
                        [  6117,   5851],
                        [  6142,   5815],
                        [  6228,   5837],
                        [  6390,   5932],
                        [  6620,   6095],
                        [  6901,   6306],
                        [  7172,   6507],
                        [  7359,   6625],
                        [  7442,   6638],
                        [  7430,   6558],
                        [  7330,   6386],
                        [  7148,   6136],
                        [  6895,   5816],
                        [  6579,   5435],
                        [  6208,   5001],
                        [  5794,   4526],
                        [  5343,   4018],
                        [  4865,   3485],
                        [  4366,   2937],
                        [  3855,   2381],
                        [  3336,   1825],
                        [  2816,   1274],
                        [  2299,    734],
                        [  1787,    208],
                        [  1286,   -299],
                        [   799,   -785],
                        [   325,  -1250],
                        [  -134,  -1691],
                        [  -576,  -2110],
                        [ -1003,  -2507],
                        [ -1413,  -2881],
                        [ -1809,  -3235],
                        [ -2189,  -3569],
                        [ -2557,  -3885],
                        [ -2913,  -4186],
                        [ -3259,  -4473],
                        [ -3595,  -4748],
                        [ -3926,  -5016],
                        [ -4249,  -5280],
                        [ -4569,  -5544],
                        [ -4884,  -5809],
                        [ -5197,  -6080],
                        [ -5506,  -6358],
                        [ -5816,  -6645],
                        [ -6122,  -6939],
                        [ -6428,  -7240],
                        [ -6730,  -7543],
                        [ -7031,  -7849],
                        [ -7328,  -8153],
                        [ -7620,  -8455],
                        [ -7907,  -8749],
                        [ -8188,  -9037],
                        [ -8461,  -9309],
                        [ -8725,  -9563],
                        [ -8978,  -9794],
                        [ -9220, -10000],
                        [ -9449, -10181],
                        [ -9665, -10336],
                        [ -9865, -10471],
                        [-10047, -10584],
                        [-10208, -10680],
                        [-10348, -10758],
                        [-10464, -10815],
                        [-10556, -10853],
                        [-10624, -10874],
                        [-10668, -10874],
                        [-10689, -10856],
                        [-10688, -10818],
                        [-10662, -10762],
                        [-10614, -10688],
                        [-10542, -10598],
                        [-10447, -10493],
                        [-10320, -10370],
                        [-10165, -10230],
                        [ -9969, -10061],
                        [ -9734,  -9865],
                        [ -9439,  -9615],
                        [ -9085,  -9315],
                        [ -8671,  -8955],
                        [ -8198,  -8540],
                        [ -7665,  -8066],
                        [ -7075,  -7534],
                        [ -6487,  -7001],
                        [ -5898,  -6465],
                        [ -5332,  -5947],
                        [ -4787,  -5446],
                        [ -4279,  -4977],
                        [ -3809,  -4539],
                        [ -3387,  -4144],
                        [ -3013,  -3789],
                        [ -2693,  -3482],
                        [ -2428,  -3223],
                        [ -2219,  -3014],
                        [ -2067,  -2858],
                        [ -1970,  -2751],
                        [ -1930,  -2697],
                        [ -1939,  -2690],
                        [ -2000,  -2732],
                        [ -2100,  -2817],
                        [ -2238,  -2945],
                        [ -2407,  -3112],
                        [ -2602,  -3314],
                        [ -2819,  -3545],
                        [ -3054,  -3804],
                        [ -3309,  -4084],
                        [ -3580,  -4382],
                        [ -3868,  -4692],
                        [ -4170,  -5011],
                        [ -4477,  -5331],
                        [ -4787,  -5650],
                        [ -5094,  -5961],
                        [ -5393,  -6260],
                        [ -5680,  -6543],
                        [ -5951,  -6806],
                        [ -6199,  -7043],
                        [ -6421,  -7251],
                        [ -6613,  -7425],
                        [ -6771,  -7564],
                        [ -6892,  -7663],
                        [ -6972,  -7719],
                        [ -7009,  -7731],
                        [ -7001,  -7698],
                        [ -6940,  -7613],
                        [ -6843,  -7492],
                        [ -6771,  -7399],
                        [ -6779,  -7385],
                        [ -6878,  -7463],
                        [ -7065,  -7631],
                        [ -7326,  -7876],
                        [ -7601,  -8137],
                        [ -7789,  -8313],
                        [ -7846,  -8358],
                        [ -7783,  -8281],
                        [ -7606,  -8089],
                        [ -7323,  -7789],
                        [ -6944,  -7392],
                        [ -6481,  -6908],
                        [ -5942,  -6347],
                        [ -5341,  -5722],
                        [ -4689,  -5043],
                        [ -3999,  -4325],
                        [ -3281,  -3577],
                        [ -2546,  -2814],
                        [ -1806,  -2043],
                        [ -1071,  -1279],
                        [  -348,   -528],
                        [   353,    200],
                        [  1025,    896],
                        [  1659,   1555],
                        [  2254,   2173],
                        [  2801,   2743],
                        [  3297,   3263],
                        [  3742,   3729],
                        [  4131,   4142],
                        [  4464,   4498],
                        [  4740,   4797],
                        [  4960,   5040],
                        [  5124,   5228],
                        [  5237,   5363],
                        [  5296,   5446],
                        [  5308,   5484],
                        [  5275,   5476],
                        [  5201,   5430],
                        [  5089,   5348],
                        [  4943,   5237],
                        [  4769,   5100],
                        [  4570,   4947],
                        [  4351,   4780],
                        [  4116,   4603],
                        [  3870,   4422],
                        [  3618,   4235],
                        [  3363,   4048],
                        [  3110,   3861],
                        [  2862,   3678],
                        [  2624,   3498],
                        [  2399,   3323],
                        [  2191,   3149],
                        [  2002,   2980],
                        [  1836,   2815],
                        [  1694,   2659],
                        [  1580,   2515],
                        [  1493,   2384],
                        [  1435,   2279],
                        [  1405,   2199],
                        [  1401,   2146],
                        [  1425,   2120],
                        [  1477,   2121],
                        [  1555,   2151],
                        [  1663,   2208],
                        [  1798,   2292],
                        [  1965,   2403],
                        [  2160,   2538],
                        [  2382,   2699],
                        [  2633,   2885],
                        [  2900,   3093],
                        [  3179,   3317],
                        [  3460,   3556],
                        [  3742,   3805],
                        [  4002,   4045],
                        [  4242,   4275],
                        [  4453,   4485],
                        [  4635,   4675],
                        [  4769,   4822],
                        [  4851,   4925],
                        [  4898,   4995],
                        [  4903,   5029],
                        [  4899,   5055],
                        [  4882,   5070],
                        [  4861,   5082],
                        [  4835,   5090],
                        [  4812,   5102],
                        [  4792,   5116],
                        [  4782,   5138],
                        [  4779,   5166],
                        [  4789,   5204],
                        [  4809,   5251],
                        [  4843,   5309],
                        [  4890,   5376],
                        [  4947,   5454],
                        [  5017,   5541],
                        [  5093,   5637],
                        [  5176,   5741],
                        [  5259,   5852],
                        [  5342,   5969],
                        [  5422,   6088],
                        [  5499,   6212],
                        [  5572,   6336],
                        [  5642,   6461],
                        [  5715,   6584],
                        [  5792,   6704],
                        [  5870,   6820],
                        [  5950,   6931],
                        [  6031,   7035],
                        [  6112,   7131],
                        [  6192,   7217],
                        [  6271,   7292],
                        [  6346,   7356],
                        [  6416,   7408],
                        [  6481,   7446],
                        [  6541,   7470],
                        [  6592,   7477],
                        [  6635,   7469],
                        [  6666,   7443],
                        [  6687,   7400],
                        [  6694,   7340],
                        [  6681,   7256],
                        [  6676,   7178],
                        [  6762,   7187],
                        [  6993,   7341],
                        [  7380,   7651],
                        [  7919,   8115],
                        [  8605,   8729],
                        [  9369,   9423],
                        [ 10082,  10069],
                        [ 10682,  10604],
                        [ 11170,  11027],
                        [ 11552,  11343],
                        [ 11828,  11551],
                        [ 11998,  11655],
                        [ 12069,  11658],
                        [ 12043,  11566],
                        [ 11928,  11385],
                        [ 11728,  11122],
                        [ 11453,  10785],
                        [ 11107,  10381],
                        [ 10698,   9917],
                        [ 10233,   9402],
                        [  9720,   8844],
                        [  9163,   8248],
                        [  8569,   7623],
                        [  7946,   6975],
                        [  7300,   6307],
                        [  6634,   5628],
                        [  5954,   4941],
                        [  5265,   4249],
                        [  4571,   3556],
                        [  3876,   2866],
                        [  3183,   2182],
                        [  2494,   1506],
                        [  1814,    841],
                        [  1144,    189],
                        [   487,   -447],
                        [  -156,  -1065],
                        [  -782,  -1666],
                        [ -1391,  -2247],
                        [ -1980,  -2807],
                        [ -2548,  -3343],
                        [ -3095,  -3856],
                        [ -3619,  -4349],
                        [ -4119,  -4821],
                        [ -4593,  -5276],
                        [ -5042,  -5714],
                        [ -5462,  -6133],
                        [ -5856,  -6533],
                        [ -6220,  -6910],
                        [ -6554,  -7265],
                        [ -6858,  -7591],
                        [ -7131,  -7890],
                        [ -7372,  -8152],
                        [ -7581,  -8378],
                        [ -7760,  -8563],
                        [ -7907,  -8708],
                        [ -8022,  -8811],
                        [ -8106,  -8873],
                        [ -8157,  -8900],
                        [ -8176,  -8893],
                        [ -8161,  -8857],
                        [ -8112,  -8794],
                        [ -8031,  -8700],
                        [ -7917,  -8579],
                        [ -7775,  -8431],
                        [ -7605,  -8257],
                        [ -7417,  -8061],
                        [ -7211,  -7842],
                        [ -6995,  -7605],
                        [ -6771,  -7350],
                        [ -6540,  -7083],
                        [ -6301,  -6801],
                        [ -6045,  -6508],
                        [ -5774,  -6205],
                        [ -5482,  -5890],
                        [ -5171,  -5566],
                        [ -4843,  -5234],
                        [ -4500,  -4897],
                        [ -4141,  -4549],
                        [ -3765,  -4192],
                        [ -3355,  -3803],
                        [ -2914,  -3387],
                        [ -2462,  -2961],
                        [ -1998,  -2525],
                        [ -1540,  -2095],
                        [ -1086,  -1671],
                        [  -651,  -1263],
                        [  -234,   -874],
                        [   153,   -513],
                        [   511,   -178],
                        [   831,    122],
                        [  1116,    388],
                        [  1358,    618],
                        [  1559,    810],
                        [  1719,    964],
                        [  1840,   1081],
                        [  1922,   1162],
                        [  1970,   1208],
                        [  1991,   1222],
                        [  1985,   1206],
                        [  1959,   1164],
                        [  1916,   1099],
                        [  1863,   1016],
                        [  1802,    917],
                        [  1734,    809],
                        [  1662,    694],
                        [  1587,    578],
                        [  1511,    464],
                        [  1442,    358],
                        [  1380,    263],
                        [  1332,    184],
                        [  1298,    124],
                        [  1285,     88],
                        [  1292,     76],
                        [  1324,     95],
                        [  1384,    144],
                        [  1472,    228],
                        [  1591,    345],
                        [  1743,    501],
                        [  1928,    695],
                        [  2145,    923],
                        [  2396,   1190],
                        [  2689,   1500],
                        [  2976,   1808],
                        [  3163,   2016],
                        [  3192,   2067],
                        [  3054,   1952],
                        [  2744,   1662],
                        [  2256,   1194],
                        [  1659,    615],
                        [  1094,     68],
                        [   635,   -374],
                        [   271,   -715],
                        [    -2,   -960],
                        [  -184,  -1106],
                        [  -279,  -1157],
                        [  -291,  -1121],
                        [  -227,  -1002],
                        [   -93,   -807],
                        [   102,   -546],
                        [   349,   -227],
                        [   641,    142],
                        [   969,    549],
                        [  1324,    988],
                        [  1699,   1448],
                        [  2086,   1921],
                        [  2477,   2399],
                        [  2864,   2873],
                        [  3243,   3339],
                        [  3607,   3790],
                        [  3952,   4223],
                        [  4274,   4630],
                        [  4570,   5012],
                        [  4837,   5366],
                        [  5075,   5688],
                        [  5281,   5977],
                        [  5456,   6233],
                        [  5600,   6456],
                        [  5714,   6646],
                        [  5797,   6804],
                        [  5855,   6930],
                        [  5887,   7026],
                        [  5899,   7090],
                        [  5891,   7125],
                        [  5867,   7135],
                        [  5831,   7125],
                        [  5787,   7104],
                        [  5735,   7074],
                        [  5680,   7046],
                        [  5627,   7022],
                        [  5577,   7007],
                        [  5532,   7000],
                        [  5497,   7003],
                        [  5473,   7017],
                        [  5461,   7040],
                        [  5466,   7075],
                        [  5487,   7117],
                        [  5526,   7165],
                        [  5584,   7222],
                        [  5663,   7288],
                        [  5761,   7364],
                        [  5878,   7449],
                        [  6009,   7551],
                        [  6157,   7671],
                        [  6316,   7804],
                        [  6487,   7952],
                        [  6667,   8110],
                        [  6855,   8279],
                        [  7057,   8455],
                        [  7269,   8639],
                        [  7498,   8828],
                        [  7742,   9020],
                        [  8002,   9214],
                        [  8277,   9409],
                        [  8552,   9601],
                        [  8825,   9788],
                        [  9081,   9969],
                        [  9319,  10141],
                        [  9542,  10311],
                        [  9748,  10479],
                        [  9943,  10648],
                        [ 10126,  10816],
                        [ 10271,  10957],
                        [ 10380,  11072],
                        [ 10429,  11136],
                        [ 10420,  11148],
                        [ 10361,  11118],
                        [ 10252,  11044],
                        [ 10104,  10936],
                        [  9917,  10793],
                        [  9703,  10627],
                        [  9459,  10433],
                        [  9200,  10226],
                        [  8924,  10002],
                        [  8643,   9770],
                        [  8354,   9531],
                        [  8069,   9289],
                        [  7786,   9046],
                        [  7510,   8807],
                        [  7239,   8571],
                        [  6979,   8344],
                        [  6726,   8124],
                        [  6482,   7914],
                        [  6248,   7715],
                        [  6025,   7526],
                        [  5810,   7349],
                        [  5605,   7183],
                        [  5410,   7029],
                        [  5228,   6884],
                        [  5060,   6750],
                        [  4907,   6624],
                        [  4766,   6507],
                        [  4639,   6395],
                        [  4525,   6290],
                        [  4420,   6188],
                        [  4327,   6090],
                        [  4240,   5991],
                        [  4162,   5894],
                        [  4089,   5793],
                        [  4019,   5691],
                        [  3953,   5583],
                        [  3886,   5469],
                        [  3816,   5345],
                        [  3745,   5216],
                        [  3667,   5076],
                        [  3575,   4918],
                        [  3522,   4799],
                        [  3610,   4817],
                        [  3881,   5021],
                        [  4344,   5418],
                        [  4999,   6014],
                        [  5862,   6822],
                        [  6857,   7767],
                        [  7827,   8693],
                        [  8695,   9518],
                        [  9461,  10243],
                        [ 10127,  10866],
                        [ 10684,  11376],
                        [ 11128,  11771],
                        [ 11460,  12051],
                        [ 11677,  12216],
                        [ 11783,  12268],
                        [ 11781,  12211],
                        [ 11676,  12050],
                        [ 11471,  11790],
                        [ 11174,  11438],
                        [ 10789,  11000],
                        [ 10325,  10484],
                        [  9790,   9898],
                        [  9189,   9250],
                        [  8535,   8550],
                        [  7831,   7802],
                        [  7087,   7018],
                        [  6310,   6201],
                        [  5508,   5361],
                        [  4686,   4504],
                        [  3854,   3636],
                        [  3016,   2763],
                        [  2179,   1893],
                        [  1349,   1029],
                        [   531,    180],
                        [  -270,   -652],
                        [ -1047,  -1459],
                        [ -1800,  -2238],
                        [ -2522,  -2979],
                        [ -3213,  -3682],
                        [ -3865,  -4336],
                        [ -4482,  -4941],
                        [ -5057,  -5501],
                        [ -5591,  -6012],
                        [ -6081,  -6484],
                        [ -6528,  -6917],
                        [ -6928,  -7314],
                        [ -7284,  -7677],
                        [ -7593,  -8001],
                        [ -7857,  -8288],
                        [ -8075,  -8534],
                        [ -8250,  -8741],
                        [ -8381,  -8903],
                        [ -8470,  -9024],
                        [ -8519,  -9100],
                        [ -8529,  -9133],
                        [ -8501,  -9125],
                        [ -8439,  -9076],
                        [ -8340,  -8994],
                        [ -8210,  -8877],
                        [ -8045,  -8734],
                        [ -7850,  -8565],
                        [ -7627,  -8370],
                        [ -7377,  -8151],
                        [ -7107,  -7910],
                        [ -6819,  -7648],
                        [ -6529,  -7371],
                        [ -6238,  -7079],
                        [ -5958,  -6776],
                        [ -5690,  -6464],
                        [ -5433,  -6148],
                        [ -5190,  -5827],
                        [ -4947,  -5506],
                        [ -4707,  -5185],
                        [ -4473,  -4879],
                        [ -4247,  -4590],
                        [ -4053,  -4343],
                        [ -3891,  -4138],
                        [ -3756,  -3969],
                        [ -3651,  -3837],
                        [ -3534,  -3703],
                        [ -3408,  -3567],
                        [ -3254,  -3409],
                        [ -3074,  -3231],
                        [ -2875,  -3040],
                        [ -2655,  -2835],
                        [ -2426,  -2625],
                        [ -2186,  -2409],
                        [ -1944,  -2195],
                        [ -1699,  -1981],
                        [ -1459,  -1774],
                        [ -1224,  -1572],
                        [ -1000,  -1380],
                        [  -786,  -1196],
                        [  -583,  -1024],
                        [  -392,   -860],
                        [  -209,   -707],
                        [   -35,   -563],
                        [   133,   -427],
                        [   297,   -298],
                        [   457,   -174],
                        [   615,    -54],
                        [   778,     67],
                        [   948,    188],
                        [  1125,    313],
                        [  1312,    444],
                        [  1508,    583],
                        [  1714,    734],
                        [  1934,    897],
                        [  2165,   1075],
                        [  2412,   1270],
                        [  2672,   1482],
                        [  2948,   1714],
                        [  3239,   1964],
                        [  3545,   2235],
                        [  3865,   2527],
                        [  4200,   2837],
                        [  4547,   3167],
                        [  4907,   3516],
                        [  5277,   3881],
                        [  5653,   4259],
                        [  6039,   4652],
                        [  6433,   5059],
                        [  6771,   5416],
                        [  6953,   5618],
                        [  6936,   5626],
                        [  6717,   5432],
                        [  6277,   5016],
                        [  5597,   4357],
                        [  4740,   3523],
                        [  3863,   2668],
                        [  3040,   1868],
                        [  2260,   1120],
                        [  1530,    426],
                        [   856,   -202],
                        [   241,   -762],
                        [  -312,  -1252],
                        [  -803,  -1671],
                        [ -1232,  -2022],
                        [ -1600,  -2303],
                        [ -1909,  -2521],
                        [ -2164,  -2678],
                        [ -2366,  -2778],
                        [ -2520,  -2826],
                        [ -2631,  -2828],
                        [ -2702,  -2786],
                        [ -2737,  -2708],
                        [ -2743,  -2599],
                        [ -2723,  -2464],
                        [ -2680,  -2306],
                        [ -2620,  -2130],
                        [ -2542,  -1939],
                        [ -2454,  -1736],
                        [ -2354,  -1524],
                        [ -2246,  -1306],
                        [ -2132,  -1083],
                        [ -2012,   -859],
                        [ -1889,   -633],
                        [ -1763,   -410],
                        [ -1634,   -189],
                        [ -1502,     27],
                        [ -1367,    236],
                        [ -1230,    428],
                        [ -1088,    607],
                        [  -941,    773],
                        [  -788,    925],
                        [  -629,   1073],
                        [  -463,   1218],
                        [  -289,   1375],
                        [  -107,   1542],
                        [    84,   1723],
                        [   284,   1918],
                        [   492,   2123],
                        [   709,   2342],
                        [   934,   2569],
                        [  1168,   2806],
                        [  1409,   3048],
                        [  1658,   3296],
                        [  1911,   3547],
                        [  2170,   3802],
                        [  2429,   4056],
                        [  2690,   4310],
                        [  2945,   4564],
                        [  3196,   4818],
                        [  3435,   5068],
                        [  3664,   5312],
                        [  3881,   5545],
                        [  4083,   5766],
                        [  4279,   5971],
                        [  4465,   6160],
                        [  4652,   6332],
                        [  4840,   6484],
                        [  5029,   6615],
                        [  5215,   6723],
                        [  5389,   6809],
                        [  5549,   6870],
                        [  5681,   6911],
                        [  5786,   6932],
                        [  5895,   6970],
                        [  6004,   7019],
                        [  6129,   7095],
                        [  6265,   7196],
                        [  6390,   7296],
                        [  6504,   7397],
                        [  6552,   7441],
                        [  6537,   7431],
                        [  6453,   7362],
                        [  6303,   7233],
                        [  6095,   7054],
                        [  5829,   6824],
                        [  5518,   6554],
                        [  5161,   6245],
                        [  4774,   5906],
                        [  4356,   5539],
                        [  3922,   5152],
                        [  3471,   4747],
                        [  3015,   4334],
                        [  2555,   3911],
                        [  2097,   3489],
                        [  1642,   3066],
                        [  1198,   2650],
                        [   763,   2239],
                        [   345,   1841],
                        [   -56,   1455],
                        [  -440,   1085],
                        [  -805,    729],
                        [ -1157,    389],
                        [ -1493,     67],
                        [ -1812,   -240],
                        [ -2115,   -529],
                        [ -2401,   -804],
                        [ -2670,  -1063],
                        [ -2923,  -1310],
                        [ -3161,  -1543],
                        [ -3384,  -1766],
                        [ -3592,  -1978],
                        [ -3789,  -2182],
                        [ -3973,  -2378],
                        [ -4148,  -2570],
                        [ -4314,  -2755],
                        [ -4472,  -2938],
                        [ -4625,  -3119],
                        [ -4775,  -3301],
                        [ -4918,  -3479],
                        [ -5064,  -3664],
                        [ -5212,  -3851],
                        [ -5298,  -3977],
                        [ -5235,  -3955],
                        [ -5001,  -3758],
                        [ -4591,  -3382],
                        [ -3990,  -2810],
                        [ -3170,  -2011],
                        [ -2198,  -1054],
                        [ -1220,    -85],
                        [  -308,    820],
                        [   543,   1666],
                        [  1326,   2441],
                        [  2028,   3130],
                        [  2639,   3725],
                        [  3157,   4222],
                        [  3577,   4617],
                        [  3896,   4906],
                        [  4113,   5091],
                        [  4230,   5173],
                        [  4249,   5154],
                        [  4173,   5037],
                        [  4006,   4826],
                        [  3755,   4528],
                        [  3426,   4149],
                        [  3024,   3696],
                        [  2560,   3177],
                        [  2039,   2599],
                        [  1471,   1970],
                        [   862,   1299],
                        [   220,    594],
                        [  -447,   -140],
                        [ -1130,   -892],
                        [ -1824,  -1658],
                        [ -2520,  -2427],
                        [ -3213,  -3195],
                        [ -3893,  -3953],
                        [ -4557,  -4696],
                        [ -5201,  -5416],
                        [ -5817,  -6108],
                        [ -6403,  -6758],
                        [ -6953,  -7365],
                        [ -7467,  -7915],
                        [ -7941,  -8409],
                        [ -8372,  -8846],
                        [ -8760,  -9225],
                        [ -9105,  -9560],
                        [ -9405,  -9849],
                        [ -9658, -10102],
                        [ -9867, -10318],
                        [-10032, -10496],
                        [-10153, -10638],
                        [-10233, -10744],
                        [-10272, -10815],
                        [-10272, -10851],
                        [-10238, -10855],
                        [-10168, -10828],
                        [-10069, -10772],
                        [ -9939, -10689],
                        [ -9783, -10580],
                        [ -9601, -10450],
                        [ -9396, -10298],
                        [ -9168, -10128],
                        [ -8922,  -9943],
                        [ -8659,  -9744],
                        [ -8382,  -9531],
                        [ -8098,  -9306],
                        [ -7810,  -9069],
                        [ -7534,  -8824],
                        [ -7272,  -8574],
                        [ -7034,  -8319],
                        [ -6820,  -8062],
                        [ -6629,  -7804],
                        [ -6465,  -7548],
                        [ -6310,  -7296],
                        [ -6165,  -7050],
                        [ -6051,  -6840],
                        [ -5965,  -6666],
                        [ -5944,  -6565],
                        [ -5987,  -6537],
                        [ -6086,  -6575],
                        [ -6243,  -6681],
                        [ -6400,  -6796],
                        [ -6559,  -6923],
                        [ -6670,  -7014],
                        [ -6735,  -7067],
                        [ -6756,  -7086],
                        [ -6731,  -7069],
                        [ -6663,  -7019],
                        [ -6552,  -6934],
                        [ -6404,  -6820],
                        [ -6217,  -6676],
                        [ -6002,  -6505],
                        [ -5754,  -6307],
                        [ -5484,  -6086],
                        [ -5188,  -5841],
                        [ -4871,  -5577],
                        [ -4533,  -5293],
                        [ -4177,  -4991],
                        [ -3803,  -4673],
                        [ -3417,  -4340],
                        [ -3018,  -3990],
                        [ -2610,  -3629],
                        [ -2191,  -3256],
                        [ -1758,  -2871],
                        [ -1311,  -2474],
                        [  -848,  -2066],
                        [  -371,  -1650],
                        [   119,  -1224],
                        [   618,   -788],
                        [  1126,   -346],
                        [  1640,    103],
                        [  2158,    557],
                        [  2677,   1016],
                        [  3196,   1477],
                        [  3710,   1939],
                        [  4219,   2400],
                        [  4720,   2858],
                        [  5207,   3309],
                        [  5681,   3751],
                        [  6138,   4185],
                        [  6574,   4605],
                        [  6983,   5006],
                        [  7371,   5392],
                        [  7729,   5756],
                        [  7992,   6030],
                        [  8088,   6142],
                        [  8000,   6074],
                        [  7727,   5823],
                        [  7238,   5358],
                        [  6502,   4643],
                        [  5567,   3732],
                        [  4568,   2757],
                        [  3560,   1773],
                        [  2537,    782],
                        [  1515,   -205],
                        [   505,  -1168],
                        [  -481,  -2100],
                        [ -1436,  -2992],
                        [ -2352,  -3837],
                        [ -3220,  -4628],
                        [ -4037,  -5361],
                        [ -4798,  -6034],
                        [ -5500,  -6642],
                        [ -6139,  -7185],
                        [ -6717,  -7662],
                        [ -7230,  -8070],
                        [ -7681,  -8413],
                        [ -8070,  -8691],
                        [ -8398,  -8907],
                        [ -8667,  -9063],
                        [ -8879,  -9162],
                        [ -9036,  -9206],
                        [ -9141,  -9197],
                        [ -9195,  -9139],
                        [ -9202,  -9034],
                        [ -9163,  -8887],
                        [ -9083,  -8699],
                        [ -8963,  -8475],
                        [ -8806,  -8217],
                        [ -8616,  -7929],
                        [ -8395,  -7615],
                        [ -8145,  -7282],
                        [ -7868,  -6935],
                        [ -7569,  -6585],
                        [ -7247,  -6234],
                        [ -6906,  -5888],
                        [ -6547,  -5547],
                        [ -6174,  -5207],
                        [ -5787,  -4869],
                        [ -5392,  -4519],
                        [ -4987,  -4160],
                        [ -4577,  -3790],
                        [ -4162,  -3412],
                        [ -3747,  -3027],
                        [ -3332,  -2638],
                        [ -2922,  -2248],
                        [ -2516,  -1857],
                        [ -2118,  -1468],
                        [ -1731,  -1081],
                        [ -1356,   -700],
                        [  -995,   -325],
                        [  -654,     38],
                        [  -332,    388],
                        [   -33,    722],
                        [   240,   1037],
                        [   484,   1329],
                        [   699,   1600],
                        [   885,   1840],
                        [  1039,   2052],
                        [  1173,   2231],
                        [  1285,   2377],
                        [  1387,   2491],
                        [  1477,   2572],
                        [  1558,   2617],
                        [  1629,   2628],
                        [  1681,   2606],
                        [  1716,   2551],
                        [  1731,   2480],
                        [  1725,   2390],
                        [  1748,   2337],
                        [  1798,   2317],
                        [  1890,   2348],
                        [  2024,   2430],
                        [  2178,   2542],
                        [  2355,   2683],
                        [  2475,   2777],
                        [  2544,   2830],
                        [  2549,   2826],
                        [  2490,   2767],
                        [  2374,   2656],
                        [  2199,   2497],
                        [  1977,   2294],
                        [  1706,   2049],
                        [  1400,   1771],
                        [  1058,   1461],
                        [   693,   1125],
                        [   306,    767],
                        [   -94,    394],
                        [  -506,      7],
                        [  -922,   -388],
                        [ -1341,   -788],
                        [ -1755,  -1188],
                        [ -2162,  -1587],
                        [ -2553,  -1978],
                        [ -2930,  -2364],
                        [ -3292,  -2740],
                        [ -3640,  -3105],
                        [ -3980,  -3458],
                        [ -4312,  -3798],
                        [ -4635,  -4126],
                        [ -4951,  -4441],
                        [ -5257,  -4745],
                        [ -5553,  -5036],
                        [ -5841,  -5316],
                        [ -6120,  -5587],
                        [ -6392,  -5849],
                        [ -6656,  -6102],
                        [ -6913,  -6348],
                        [ -7164,  -6589],
                        [ -7410,  -6824],
                        [ -7651,  -7055],
                        [ -7888,  -7282],
                        [ -8123,  -7508],
                        [ -8353,  -7732],
                        [ -8578,  -7950],
                        [ -8805,  -8172],
                        [ -9027,  -8390],
                        [ -9189,  -8548],
                        [ -9246,  -8600],
                        [ -9197,  -8543],
                        [ -9034,  -8371],
                        [ -8731,  -8054],
                        [ -8246,  -7551],
                        [ -7618,  -6900],
                        [ -6952,  -6206],
                        [ -6291,  -5518],
                        [ -5638,  -4834],
                        [ -4999,  -4171],
                        [ -4392,  -3543],
                        [ -3824,  -2962],
                        [ -3303,  -2431],
                        [ -2835,  -1961],
                        [ -2427,  -1556],
                        [ -2083,  -1220],
                        [ -1804,   -954],
                        [ -1591,   -760],
                        [ -1444,   -636],
                        [ -1362,   -584],
                        [ -1342,   -600],
                        [ -1380,   -681],
                        [ -1473,   -823],
                        [ -1614,  -1019],
                        [ -1800,  -1265],
                        [ -2023,  -1555],
                        [ -2278,  -1883],
                        [ -2560,  -2243],
                        [ -2863,  -2627],
                        [ -3181,  -3031],
                        [ -3507,  -3447],
                        [ -3837,  -3869],
                        [ -4164,  -4292],
                        [ -4483,  -4711],
                        [ -4791,  -5120],
                        [ -5081,  -5511],
                        [ -5351,  -5882],
                        [ -5599,  -6216],
                        [ -5821,  -6515],
                        [ -6015,  -6764],
                        [ -6181,  -6966],
                        [ -6316,  -7117],
                        [ -6420,  -7218],
                        [ -6494,  -7282],
                        [ -6537,  -7309],
                        [ -6550,  -7311],
                        [ -6533,  -7287],
                        [ -6489,  -7239],
                        [ -6420,  -7170],
                        [ -6325,  -7080],
                        [ -6207,  -6971],
                        [ -6069,  -6849],
                        [ -5911,  -6714],
                        [ -5739,  -6572],
                        [ -5552,  -6425],
                        [ -5353,  -6274],
                        [ -5144,  -6121],
                        [ -4926,  -5963],
                        [ -4702,  -5804],
                        [ -4472,  -5640],
                        [ -4239,  -5477],
                        [ -4004,  -5313],
                        [ -3768,  -5148],
                        [ -3537,  -4980],
                        [ -3313,  -4811],
                        [ -3111,  -4642],
                        [ -2929,  -4474],
                        [ -2775,  -4309],
                        [ -2645,  -4141],
                        [ -2541,  -3976],
                        [ -2464,  -3814],
                        [ -2399,  -3657],
                        [ -2345,  -3504],
                        [ -2335,  -3399],
                        [ -2367,  -3337],
                        [ -2472,  -3356],
                        [ -2651,  -3456],
                        [ -2899,  -3632],
                        [ -3214,  -3885],
                        [ -3532,  -4150],
                        [ -3855,  -4431],
                        [ -4119,  -4663],
                        [ -4325,  -4849],
                        [ -4471,  -4986],
                        [ -4556,  -5073],
                        [ -4577,  -5107],
                        [ -4532,  -5085],
                        [ -4427,  -5011],
                        [ -4259,  -4883],
                        [ -4037,  -4705],
                        [ -3759,  -4477],
                        [ -3433,  -4202],
                        [ -3058,  -3881],
                        [ -2641,  -3520],
                        [ -2181,  -3118],
                        [ -1688,  -2681],
                        [ -1163,  -2211],
                        [  -618,  -1714],
                        [   -54,  -1188],
                        [   523,   -643],
                        [  1113,    -78],
                        [  1717,    500],
                        [  2333,   1090],
                        [  2962,   1686],
                        [  3601,   2287],
                        [  4244,   2888],
                        [  4886,   3488],
                        [  5524,   4081],
                        [  6153,   4665],
                        [  6769,   5236],
                        [  7368,   5790],
                        [  7944,   6325],
                        [  8496,   6836],
                        [  9017,   7322],
                        [  9506,   7779],
                        [  9958,   8202],
                        [ 10369,   8591],
                        [ 10739,   8942],
                        [ 11061,   9251],
                        [ 11332,   9516],
                        [ 11555,   9739],
                        [ 11721,   9909],
                        [ 11791,   9990],
                        [ 11743,   9956],
                        [ 11581,   9811],
                        [ 11299,   9550],
                        [ 10868,   9140],
                        [ 10242,   8536],
                        [  9439,   7755],
                        [  8538,   6876],
                        [  7573,   5935],
                        [  6549,   4935],
                        [  5480,   3895],
                        [  4384,   2835],
                        [  3277,   1768],
                        [  2169,    706],
                        [  1074,   -338],
                        [     7,  -1352],
                        [ -1027,  -2328],
                        [ -2015,  -3256],
                        [ -2951,  -4129],
                        [ -3827,  -4939],
                        [ -4638,  -5683],
                        [ -5379,  -6354],
                        [ -6047,  -6949],
                        [ -6641,  -7468],
                        [ -7158,  -7907],
                        [ -7599,  -8268],
                        [ -7963,  -8551],
                        [ -8251,  -8757],
                        [ -8464,  -8888],
                        [ -8605,  -8947],
                        [ -8677,  -8938],
                        [ -8681,  -8862],
                        [ -8623,  -8724],
                        [ -8506,  -8530],
                        [ -8334,  -8280],
                        [ -8112,  -7983],
                        [ -7844,  -7642],
                        [ -7535,  -7269],
                        [ -7190,  -6865],
                        [ -6812,  -6449],
                        [ -6407,  -6024],
                        [ -5978,  -5597],
                        [ -5532,  -5172],
                        [ -5071,  -4749],
                        [ -4600,  -4333],
                        [ -4123,  -3912],
                        [ -3644,  -3489],
                        [ -3168,  -3066],
                        [ -2698,  -2643],
                        [ -2238,  -2226],
                        [ -1790,  -1816],
                        [ -1359,  -1415],
                        [  -947,  -1024],
                        [  -557,   -641],
                        [  -190,   -271],
                        [   149,     89],
                        [   460,    436],
                        [   741,    764],
                        [   990,   1072],
                        [  1206,   1352],
                        [  1388,   1606],
                        [  1535,   1828],
                        [  1647,   2020],
                        [  1725,   2178],
                        [  1769,   2303],
                        [  1790,   2391],
                        [  1786,   2444],
                        [  1769,   2464],
                        [  1737,   2452],
                        [  1695,   2406],
                        [  1645,   2327],
                        [  1584,   2223],
                        [  1515,   2092],
                        [  1442,   1958],
                        [  1370,   1818],
                        [  1349,   1732],
                        [  1378,   1697],
                        [  1471,   1727],
                        [  1629,   1827],
                        [  1835,   1979],
                        [  2092,   2187],
                        [  2316,   2368],
                        [  2516,   2530],
                        [  2668,   2652],
                        [  2778,   2737],
                        [  2842,   2784],
                        [  2862,   2793],
                        [  2840,   2766],
                        [  2777,   2702],
                        [  2678,   2606],
                        [  2544,   2477],
                        [  2382,   2321],
                        [  2192,   2138],
                        [  1980,   1933],
                        [  1745,   1706],
                        [  1496,   1463],
                        [  1232,   1203],
                        [   963,    932],
                        [   691,    649],
                        [   420,    360],
                        [   153,     64],
                        [  -115,   -235],
                        [  -383,   -538],
                        [  -659,   -842],
                        [  -943,  -1147],
                        [ -1233,  -1451],
                        [ -1534,  -1756],
                        [ -1839,  -2059],
                        [ -2149,  -2360],
                        [ -2464,  -2660],
                        [ -2783,  -2958],
                        [ -3104,  -3254],
                        [ -3426,  -3547],
                        [ -3751,  -3836],
                        [ -4076,  -4123],
                        [ -4401,  -4405],
                        [ -4723,  -4682],
                        [ -5042,  -4954],
                        [ -5358,  -5220],
                        [ -5666,  -5478],
                        [ -5965,  -5726],
                        [ -6258,  -5967],
                        [ -6535,  -6194],
                        [ -6780,  -6388],
                        [ -6996,  -6553],
                        [ -7191,  -6695],
                        [ -7356,  -6809],
                        [ -7460,  -6859],
                        [ -7450,  -6796],
                        [ -7314,  -6607],
                        [ -7096,  -6335],
                        [ -6818,  -6004],
                        [ -6481,  -5614],
                        [ -6097,  -5181],
                        [ -5679,  -4719],
                        [ -5237,  -4237],
                        [ -4776,  -3746],
                        [ -4308,  -3252],
                        [ -3842,  -2766],
                        [ -3381,  -2291],
                        [ -2934,  -1835],
                        [ -2503,  -1402],
                        [ -2095,   -996],
                        [ -1709,   -620],
                        [ -1349,   -277],
                        [ -1015,     32],
                        [  -707,    306],
                        [  -426,    545],
                        [  -170,    753],
                        [    62,    930],
                        [   271,   1077],
                        [   461,   1199],
                        [   631,   1298],
                        [   787,   1377],
                        [   929,   1439],
                        [  1060,   1486],
                        [  1182,   1523],
                        [  1299,   1552],
                        [  1412,   1575],
                        [  1524,   1597],
                        [  1636,   1619],
                        [  1750,   1654],
                        [  1867,   1703],
                        [  1987,   1772],
                        [  2112,   1861],
                        [  2240,   1976],
                        [  2374,   2115],
                        [  2511,   2268],
                        [  2654,   2437],
                        [  2799,   2609],
                        [  2948,   2785],
                        [  3099,   2964],
                        [  3252,   3143],
                        [  3405,   3321],
                        [  3559,   3495],
                        [  3711,   3660],
                        [  3862,   3816],
                        [  4011,   3957],
                        [  4154,   4080],
                        [  4294,   4186],
                        [  4428,   4275],
                        [  4557,   4352],
                        [  4679,   4415],
                        [  4795,   4474],
                        [  4904,   4523],
                        [  5007,   4565],
                        [  5105,   4601],
                        [  5194,   4634],
                        [  5273,   4665],
                        [  5338,   4693],
                        [  5389,   4719],
                        [  5421,   4745],
                        [  5442,   4775],
                        [  5446,   4807],
                        [  5432,   4839],
                        [  5409,   4871],
                        [  5380,   4903],
                        [  5307,   4894],
                        [  5197,   4847],
                        [  5024,   4735],
                        [  4791,   4561],
                        [  4496,   4318],
                        [  4138,   4009],
                        [  3777,   3689],
                        [  3412,   3356],
                        [  3100,   3068],
                        [  2841,   2823],
                        [  2640,   2629],
                        [  2498,   2485],
                        [  2424,   2399],
                        [  2414,   2369],
                        [  2469,   2398],
                        [  2589,   2485],
                        [  2771,   2628],
                        [  3011,   2829],
                        [  3307,   3080],
                        [  3657,   3385],
                        [  4052,   3733],
                        [  4493,   4128],
                        [  4966,   4558],
                        [  5470,   5025],
                        [  5990,   5518],
                        [  6524,   6038],
                        [  7066,   6574],
                        [  7613,   7126],
                        [  8167,   7685],
                        [  8724,   8249],
                        [  9284,   8809],
                        [  9844,   9364],
                        [ 10394,   9907],
                        [ 10932,  10434],
                        [ 11451,  10940],
                        [ 11948,  11421],
                        [ 12417,  11874],
                        [ 12853,  12294],
                        [ 13254,  12677],
                        [ 13614,  13020],
                        [ 13932,  13319],
                        [ 14203,  13574],
                        [ 14424,  13780],
                        [ 14595,  13936],
                        [ 14710,  14039],
                        [ 14770,  14089],
                        [ 14772,  14084],
                        [ 14717,  14024],
                        [ 14603,  13908],
                        [ 14441,  13746],
                        [ 14256,  13564],
                        [ 14063,  13375],
                        [ 13856,  13175],
                        [ 13607,  12935],
                        [ 13267,  12604],
                        [ 12794,  12143],
                        [ 12209,  11568],
                        [ 11526,  10895],
                        [ 10757,  10136],
                        [  9916,   9304],
                        [  9020,   8419],
                        [  8083,   7494],
                        [  7117,   6541],
                        [  6137,   5575],
                        [  5157,   4611],
                        [  4188,   3658],
                        [  3244,   2728],
                        [  2330,   1830],
                        [  1460,    974],
                        [   639,    170],
                        [  -125,   -577],
                        [  -829,  -1260],
                        [ -1465,  -1874],
                        [ -2033,  -2417],
                        [ -2529,  -2885],
                        [ -2953,  -3280],
                        [ -3304,  -3599],
                        [ -3583,  -3845],
                        [ -3792,  -4019],
                        [ -3933,  -4124],
                        [ -4007,  -4164],
                        [ -4020,  -4141],
                        [ -3976,  -4060],
                        [ -3878,  -3924],
                        [ -3733,  -3740],
                        [ -3543,  -3511],
                        [ -3316,  -3248],
                        [ -3055,  -2954],
                        [ -2767,  -2645],
                        [ -2456,  -2322],
                        [ -2128,  -1996],
                        [ -1787,  -1668],
                        [ -1439,  -1349],
                        [ -1087,  -1040],
                        [  -737,   -735],
                        [  -392,   -438],
                        [   -57,   -150],
                        [   265,    128],
                        [   570,    392],
                        [   857,    641],
                        [  1122,    876],
                        [  1362,   1094],
                        [  1576,   1301],
                        [  1762,   1495],
                        [  1921,   1679],
                        [  2050,   1850],
                        [  2152,   2005],
                        [  2225,   2145],
                        [  2270,   2260],
                        [  2289,   2353],
                        [  2282,   2420],
                        [  2249,   2461],
                        [  2192,   2479],
                        [  2113,   2474],
                        [  2017,   2444],
                        [  1906,   2391],
                        [  1786,   2321],
                        [  1656,   2230],
                        [  1523,   2120],
                        [  1390,   1994],
                        [  1263,   1857],
                        [  1143,   1713],
                        [  1043,   1579],
                        [   964,   1458],
                        [   946,   1392],
                        [   986,   1378],
                        [  1094,   1432],
                        [  1274,   1554],
                        [  1518,   1740],
                        [  1827,   1991],
                        [  2131,   2241],
                        [  2437,   2494],
                        [  2724,   2732],
                        [  2993,   2958],
                        [  3235,   3160],
                        [  3451,   3340],
                        [  3634,   3494],
                        [  3787,   3620],
                        [  3906,   3716],
                        [  3992,   3783],
                        [  4044,   3818],
                        [  4063,   3823],
                        [  4049,   3798],
                        [  4001,   3742],
                        [  3926,   3658],
                        [  3822,   3545],
                        [  3699,   3405],
                        [  3555,   3239],
                        [  3396,   3051],
                        [  3221,   2837],
                        [  3028,   2605],
                        [  2815,   2351],
                        [  2577,   2081],
                        [  2313,   1793],
                        [  2026,   1493],
                        [  1715,   1177],
                        [  1385,    852],
                        [  1037,    515],
                        [   673,    172],
                        [   295,   -176],
                        [   -93,   -528],
                        [  -491,   -882],
                        [  -893,  -1234],
                        [ -1299,  -1584],
                        [ -1705,  -1928],
                        [ -2108,  -2264],
                        [ -2503,  -2591],
                        [ -2890,  -2905],
                        [ -3263,  -3203],
                        [ -3621,  -3483],
                        [ -3956,  -3742],
                        [ -4275,  -3982],
                        [ -4612,  -4241],
                        [ -5004,  -4557],
                        [ -5461,  -4940],
                        [ -5975,  -5383],
                        [ -6520,  -5860],
                        [ -7032,  -6309],
                        [ -7439,  -6656],
                        [ -7724,  -6885],
                        [ -7893,  -7001],
                        [ -7953,  -7009],
                        [ -7911,  -6918],
                        [ -7776,  -6739],
                        [ -7558,  -6478],
                        [ -7262,  -6146],
                        [ -6899,  -5750],
                        [ -6481,  -5302],
                        [ -6012,  -4808],
                        [ -5502,  -4278],
                        [ -4960,  -3717],
                        [ -4392,  -3135],
                        [ -3804,  -2540],
                        [ -3202,  -1935],
                        [ -2594,  -1331],
                        [ -1984,   -731],
                        [ -1376,   -139],
                        [  -774,    441],
                        [  -183,   1006],
                        [   397,   1553],
                        [   962,   2081],
                        [  1510,   2589],
                        [  2040,   3075],
                        [  2550,   3540],
                        [  3039,   3982],
                        [  3507,   4402],
                        [  3953,   4799],
                        [  4377,   5172],
                        [  4778,   5523],
                        [  5158,   5853],
                        [  5514,   6166],
                        [  5850,   6463],
                        [  6163,   6745],
                        [  6453,   7014],
                        [  6722,   7274],
                        [  6969,   7526],
                        [  7195,   7768],
                        [  7399,   8001],
                        [  7582,   8217],
                        [  7745,   8417],
                        [  7889,   8600],
                        [  8013,   8765],
                        [  8119,   8912],
                        [  8208,   9039],
                        [  8279,   9143],
                        [  8336,   9224],
                        [  8378,   9275],
                        [  8405,   9297],
                        [  8418,   9292],
                        [  8418,   9261],
                        [  8405,   9211],
                        [  8380,   9142],
                        [  8345,   9066],
                        [  8301,   8981],
                        [  8253,   8890],
                        [  8199,   8791],
                        [  8144,   8692],
                        [  8087,   8592],
                        [  8032,   8494],
                        [  7979,   8399],
                        [  7929,   8309],
                        [  7885,   8231],
                        [  7838,   8160],
                        [  7788,   8097],
                        [  7736,   8041],
                        [  7682,   7993],
                        [  7603,   7924],
                        [  7499,   7837],
                        [  7361,   7720],
                        [  7191,   7572],
                        [  6975,   7379],
                        [  6716,   7143],
                        [  6449,   6896],
                        [  6169,   6634],
                        [  5921,   6400],
                        [  5700,   6190],
                        [  5515,   6014],
                        [  5368,   5870],
                        [  5265,   5766],
                        [  5205,   5701],
                        [  5191,   5678],
                        [  5221,   5696],
                        [  5295,   5758],
                        [  5411,   5859],
                        [  5566,   5998],
                        [  5758,   6173],
                        [  5982,   6380],
                        [  6234,   6616],
                        [  6502,   6876],
                        [  6784,   7157],
                        [  7069,   7454],
                        [  7355,   7762],
                        [  7636,   8075],
                        [  7910,   8391],
                        [  8178,   8700],
                        [  8437,   9003],
                        [  8686,   9291],
                        [  8925,   9562],
                        [  9141,   9811],
                        [  9336,  10034],
                        [  9505,  10227],
                        [  9648,  10388],
                        [  9755,  10511],
                        [  9827,  10596],
                        [  9862,  10639],
                        [  9858,  10639],
                        [  9812,  10593],
                        [  9722,  10502],
                        [  9589,  10364],
                        [  9413,  10179],
                        [  9190,   9946],
                        [  8924,   9667],
                        [  8614,   9342],
                        [  8257,   8968],
                        [  7874,   8567],
                        [  7528,   8202],
                        [  7272,   7927],
                        [  7119,   7755],
                        [  7068,   7687],
                        [  7105,   7709],
                        [  7167,   7757],
                        [  7156,   7735],
                        [  7036,   7604],
                        [  6815,   7373],
                        [  6504,   7049],
                        [  6112,   6642],
                        [  5650,   6163],
                        [  5129,   5620],
                        [  4559,   5026],
                        [  3950,   4392],
                        [  3314,   3729],
                        [  2663,   3048],
                        [  2004,   2357],
                        [  1347,   1666],
                        [   701,    986],
                        [    75,    323],
                        [  -527,   -313],
                        [ -1097,   -917],
                        [ -1631,  -1481],
                        [ -2124,  -2002],
                        [ -2574,  -2477],
                        [ -2979,  -2905],
                        [ -3336,  -3283],
                        [ -3646,  -3610],
                        [ -3908,  -3889],
                        [ -4126,  -4119],
                        [ -4299,  -4305],
                        [ -4430,  -4447],
                        [ -4522,  -4548],
                        [ -4577,  -4611],
                        [ -4600,  -4640],
                        [ -4595,  -4638],
                        [ -4565,  -4609],
                        [ -4513,  -4559],
                        [ -4446,  -4492],
                        [ -4366,  -4411],
                        [ -4275,  -4324],
                        [ -4180,  -4235],
                        [ -4083,  -4150],
                        [ -3987,  -4075],
                        [ -3894,  -4009],
                        [ -3809,  -3955],
                        [ -3733,  -3913],
                        [ -3668,  -3885],
                        [ -3616,  -3869],
                        [ -3580,  -3868],
                        [ -3559,  -3878],
                        [ -3555,  -3902],
                        [ -3567,  -3929],
                        [ -3597,  -3963],
                        [ -3642,  -3998],
                        [ -3701,  -4035],
                        [ -3772,  -4074],
                        [ -3854,  -4116],
                        [ -3944,  -4167],
                        [ -4041,  -4225],
                        [ -4145,  -4292],
                        [ -4252,  -4367],
                        [ -4364,  -4447],
                        [ -4480,  -4529],
                        [ -4600,  -4613],
                        [ -4724,  -4700],
                        [ -4849,  -4784],
                        [ -4976,  -4867],
                        [ -5095,  -4949],
                        [ -5207,  -5027],
                        [ -5294,  -5096],
                        [ -5360,  -5156],
                        [ -5393,  -5196],
                        [ -5392,  -5213],
                        [ -5345,  -5194],
                        [ -5253,  -5139],
                        [ -5107,  -5037],
                        [ -4909,  -4889],
                        [ -4648,  -4682],
                        [ -4327,  -4418],
                        [ -3985,  -4133],
                        [ -3619,  -3826],
                        [ -3248,  -3512],
                        [ -2872,  -3192],
                        [ -2506,  -2879],
                        [ -2148,  -2572],
                        [ -1811,  -2283],
                        [ -1494,  -2010],
                        [ -1207,  -1764],
                        [  -951,  -1544],
                        [  -730,  -1355],
                        [  -545,  -1198],
                        [  -400,  -1077],
                        [  -294,   -991],
                        [  -225,   -942],
                        [  -193,   -930],
                        [  -195,   -954],
                        [  -230,  -1016],
                        [  -294,  -1112],
                        [  -388,  -1244],
                        [  -514,  -1407],
                        [  -670,  -1601],
                        [  -863,  -1823],
                        [ -1090,  -2072],
                        [ -1346,  -2342],
                        [ -1632,  -2635],
                        [ -1942,  -2943],
                        [ -2275,  -3266],
                        [ -2625,  -3598],
                        [ -2992,  -3937],
                        [ -3368,  -4280],
                        [ -3752,  -4623],
                        [ -4138,  -4962],
                        [ -4523,  -5293],
                        [ -4903,  -5613],
                        [ -5274,  -5919],
                        [ -5630,  -6205],
                        [ -5968,  -6471],
                        [ -6285,  -6712],
                        [ -6578,  -6927],
                        [ -6836,  -7105],
                        [ -7087,  -7278],
                        [ -7412,  -7525],
                        [ -7864,  -7899],
                        [ -8446,  -8408],
                        [ -9158,  -9050],
                        [ -9986,  -9817],
                        [-10859, -10636],
                        [-11649, -11377],
                        [-12296, -11984],
                        [-12806, -12457],
                        [-13182, -12800],
                        [-13428, -13013],
                        [-13548, -13101],
                        [-13548, -13069],
                        [-13436, -12924],
                        [-13219, -12677],
                        [-12903, -12331],
                        [-12500, -11898],
                        [-12018, -11386],
                        [-11464, -10805],
                        [-10850, -10163],
                        [-10183,  -9469],
                        [ -9471,  -8733],
                        [ -8725,  -7965],
                        [ -7954,  -7174],
                        [ -7163,  -6368],
                        [ -6360,  -5552],
                        [ -5553,  -4734],
                        [ -4748,  -3920],
                        [ -3950,  -3116],
                        [ -3166,  -2325],
                        [ -2398,  -1551],
                        [ -1652,   -800],
                        [  -931,    -72],
                        [  -239,    626],
                        [   421,   1294],
                        [  1048,   1928],
                        [  1639,   2527],
                        [  2194,   3090],
                        [  2711,   3613],
                        [  3189,   4097],
                        [  3628,   4539],
                        [  4029,   4940],
                        [  4392,   5306],
                        [  4716,   5637],
                        [  5003,   5939],
                        [  5254,   6214],
                        [  5471,   6459],
                        [  5653,   6678],
                        [  5805,   6869],
                        [  5926,   7033],
                        [  6019,   7170],
                        [  6087,   7282],
                        [  6133,   7366],
                        [  6156,   7423],
                        [  6160,   7448],
                        [  6147,   7444],
                        [  6117,   7412],
                        [  6071,   7356],
                        [  6012,   7280],
                        [  5939,   7187],
                        [  5858,   7087],
                        [  5769,   6981],
                        [  5677,   6870],
                        [  5584,   6755],
                        [  5497,   6638],
                        [  5419,   6523],
                        [  5357,   6409],
                        [  5311,   6299],
                        [  5283,   6195],
                        [  5273,   6101],
                        [  5267,   6016],
                        [  5268,   5938],
                        [  5265,   5868],
                        [  5260,   5805],
                        [  5249,   5747],
                        [  5233,   5693],
                        [  5212,   5642],
                        [  5188,   5596],
                        [  5138,   5529],
                        [  5064,   5444],
                        [  4963,   5336],
                        [  4834,   5206],
                        [  4698,   5070],
                        [  4552,   4927],
                        [  4405,   4786],
                        [  4258,   4643],
                        [  4115,   4509],
                        [  3979,   4382],
                        [  3854,   4266],
                        [  3738,   4161],
                        [  3635,   4069],
                        [  3543,   3988],
                        [  3463,   3920],
                        [  3392,   3863],
                        [  3328,   3815],
                        [  3270,   3775],
                        [  3209,   3740],
                        [  3145,   3708],
                        [  3074,   3677],
                        [  2993,   3644],
                        [  2899,   3606],
                        [  2789,   3560],
                        [  2667,   3504],
                        [  2533,   3435],
                        [  2385,   3350],
                        [  2221,   3247],
                        [  2039,   3122],
                        [  1840,   2977],
                        [  1620,   2806],
                        [  1380,   2610],
                        [  1120,   2386],
                        [   837,   2135],
                        [   531,   1856],
                        [   205,   1547],
                        [  -145,   1211],
                        [  -514,    846],
                        [  -904,    454],
                        [ -1314,     37],
                        [ -1743,   -406],
                        [ -2186,   -870],
                        [ -2644,  -1354],
                        [ -3123,  -1865],
                        [ -3573,  -2351],
                        [ -3894,  -2713],
                        [ -4037,  -2897],
                        [ -3989,  -2894],
                        [ -3745,  -2693],
                        [ -3304,  -2295],
                        [ -2739,  -1769],
                        [ -2195,  -1259],
                        [ -1736,   -835],
                        [ -1357,   -489],
                        [ -1053,   -221],
                        [  -827,    -33],
                        [  -672,     77],
                        [  -585,    114],
                        [  -561,     82],
                        [  -597,    -13],
                        [  -686,   -165],
                        [  -820,   -366],
                        [  -995,   -613],
                        [ -1205,   -895],
                        [ -1444,  -1209],
                        [ -1705,  -1547],
                        [ -1983,  -1902],
                        [ -2273,  -2269],
                        [ -2570,  -2639],
                        [ -2869,  -3010],
                        [ -3166,  -3377],
                        [ -3460,  -3738],
                        [ -3746,  -4089],
                        [ -4024,  -4429],
                        [ -4292,  -4756],
                        [ -4549,  -5070],
                        [ -4794,  -5370],
                        [ -5027,  -5656],
                        [ -5247,  -5927],
                        [ -5457,  -6186],
                        [ -5656,  -6431],
                        [ -5844,  -6664],
                        [ -6024,  -6882],
                        [ -6196,  -7087],
                        [ -6362,  -7276],
                        [ -6523,  -7450],
                        [ -6679,  -7611],
                        [ -6833,  -7760],
                        [ -6984,  -7908],
                        [ -7135,  -8055],
                        [ -7282,  -8207],
                        [ -7431,  -8365],
                        [ -7580,  -8527],
                        [ -7729,  -8695],
                        [ -7876,  -8866],
                        [ -8025,  -9041],
                        [ -8174,  -9215],
                        [ -8321,  -9389],
                        [ -8465,  -9555],
                        [ -8606,  -9714],
                        [ -8740,  -9860],
                        [ -8867,  -9992],
                        [ -8982, -10110],
                        [ -9085, -10212],
                        [ -9172, -10304],
                        [ -9244, -10385],
                        [ -9299, -10454],
                        [ -9339, -10511],
                        [ -9365, -10551],
                        [ -9378, -10575],
                        [ -9387, -10580],
                        [ -9389, -10567],
                        [ -9388, -10536],
                        [ -9383, -10485],
                        [ -9367, -10418],
                        [ -9338, -10331],
                        [ -9280, -10225],
                        [ -9193, -10099],
                        [ -9081,  -9960],
                        [ -8940,  -9805],
                        [ -8788,  -9650],
                        [ -8625,  -9493],
                        [ -8446,  -9329],
                        [ -8250,  -9158],
                        [ -8012,  -8950],
                        [ -7733,  -8706],
                        [ -7417,  -8431],
                        [ -7065,  -8121],
                        [ -6691,  -7793],
                        [ -6297,  -7446],
                        [ -5898,  -7094],
                        [ -5493,  -6736],
                        [ -5098,  -6385],
                        [ -4713,  -6043],
                        [ -4349,  -5718],
                        [ -4008,  -5413],
                        [ -3697,  -5133],
                        [ -3417,  -4881],
                        [ -3172,  -4661],
                        [ -2962,  -4474],
                        [ -2789,  -4322],
                        [ -2653,  -4205],
                        [ -2553,  -4124],
                        [ -2489,  -4080],
                        [ -2457,  -4069],
                        [ -2457,  -4093],
                        [ -2487,  -4149],
                        [ -2546,  -4234],
                        [ -2637,  -4346],
                        [ -2754,  -4483],
                        [ -2897,  -4639],
                        [ -3061,  -4812],
                        [ -3242,  -4999],
                        [ -3439,  -5195],
                        [ -3647,  -5395],
                        [ -3862,  -5597],
                        [ -4078,  -5796],
                        [ -4295,  -5988],
                        [ -4505,  -6168],
                        [ -4706,  -6333],
                        [ -4894,  -6481],
                        [ -5065,  -6608],
                        [ -5215,  -6709],
                        [ -5342,  -6784],
                        [ -5445,  -6829],
                        [ -5517,  -6843],
                        [ -5549,  -6814],
                        [ -5603,  -6806],
                        [ -5774,  -6915],
                        [ -6107,  -7187],
                        [ -6604,  -7627],
                        [ -7276,  -8245],
                        [ -8128,  -9051],
                        [ -9084,  -9969],
                        [ -9985, -10839],
                        [-10761, -11593],
                        [-11419, -12231],
                        [-11955, -12752],
                        [-12370, -13150],
                        [-12660, -13420],
                        [-12832, -13569],
                        [-12887, -13596],
                        [-12829, -13509],
                        [-12666, -13313],
                        [-12404, -13015],
                        [-12050, -12621],
                        [-11614, -12141],
                        [-11103, -11584],
                        [-10526, -10959],
                        [ -9892, -10277],
                        [ -9214,  -9546],
                        [ -8497,  -8779],
                        [ -7754,  -7983],
                        [ -6990,  -7166],
                        [ -6216,  -6338],
                        [ -5437,  -5506],
                        [ -4663,  -4675],
                        [ -3898,  -3855],
                        [ -3149,  -3049],
                        [ -2422,  -2262],
                        [ -1721,  -1500],
                        [ -1049,   -766],
                        [  -411,    -65],
                        [   190,    601],
                        [   753,   1228],
                        [  1277,   1814],
                        [  1760,   2349],
                        [  2202,   2836],
                        [  2603,   3269],
                        [  2964,   3649],
                        [  3286,   3981],
                        [  3569,   4266],
                        [  3816,   4518],
                        [  4028,   4736],
                        [  4208,   4928],
                        [  4358,   5095],
                        [  4480,   5239],
                        [  4578,   5362],
                        [  4653,   5464],
                        [  4710,   5549],
                        [  4750,   5616],
                        [  4775,   5667],
                        [  4788,   5700],
                        [  4791,   5718],
                        [  4784,   5721],
                        [  4769,   5713],
                        [  4745,   5695],
                        [  4717,   5670],
                        [  4685,   5646],
                        [  4652,   5623],
                        [  4622,   5601],
                        [  4598,   5579],
                        [  4590,   5558],
                        [  4598,   5540],
                        [  4632,   5523],
                        [  4692,   5510],
                        [  4773,   5499],
                        [  4878,   5492],
                        [  4987,   5488],
                        [  5103,   5488],
                        [  5211,   5492],
                        [  5314,   5501],
                        [  5432,   5536],
                        [  5562,   5597],
                        [  5714,   5689],
                        [  5886,   5813],
                        [  6048,   5939],
                        [  6203,   6067],
                        [  6307,   6155],
                        [  6363,   6204],
                        [  6371,   6213],
                        [  6328,   6180],
                        [  6242,   6112],
                        [  6112,   6005],
                        [  5948,   5870],
                        [  5747,   5702],
                        [  5519,   5511],
                        [  5260,   5293],
                        [  4981,   5055],
                        [  4677,   4797],
                        [  4355,   4522],
                        [  4012,   4230],
                        [  3652,   3924],
                        [  3275,   3602],
                        [  2883,   3268],
                        [  2477,   2921],
                        [  2056,   2563],
                        [  1620,   2192],
                        [  1169,   1812],
                        [   702,   1420],
                        [   223,   1018],
                        [  -267,    607],
                        [  -765,    185],
                        [ -1272,   -245],
                        [ -1785,   -685],
                        [ -2303,  -1133],
                        [ -2823,  -1588],
                        [ -3346,  -2052],
                        [ -3869,  -2522],
                        [ -4390,  -2997],
                        [ -4908,  -3477],
                        [ -5421,  -3960],
                        [ -5929,  -4445],
                        [ -6427,  -4929],
                        [ -6915,  -5411],
                        [ -7391,  -5891],
                        [ -7854,  -6364],
                        [ -8297,  -6827],
                        [ -8727,  -7282],
                        [ -9141,  -7730],
                        [ -9471,  -8099],
                        [ -9618,  -8292],
                        [ -9547,  -8270],
                        [ -9251,  -8026],
                        [ -8717,  -7543],
                        [ -7924,  -6801],
                        [ -6955,  -5877],
                        [ -5962,  -4925],
                        [ -5018,  -4019],
                        [ -4118,  -3154],
                        [ -3267,  -2341],
                        [ -2477,  -1588],
                        [ -1748,   -906],
                        [ -1085,   -294],
                        [  -489,    245],
                        [    36,    707],
                        [   489,   1094],
                        [   873,   1406],
                        [  1189,   1647],
                        [  1438,   1818],
                        [  1623,   1923],
                        [  1748,   1965],
                        [  1814,   1949],
                        [  1829,   1880],
                        [  1794,   1762],
                        [  1714,   1600],
                        [  1594,   1398],
                        [  1437,   1160],
                        [  1247,    891],
                        [  1028,    592],
                        [   782,    269],
                        [   514,    -76],
                        [   228,   -437],
                        [   -76,   -816],
                        [  -392,  -1206],
                        [  -718,  -1606],
                        [ -1052,  -2011],
                        [ -1391,  -2421],
                        [ -1733,  -2826],
                        [ -2076,  -3225],
                        [ -2418,  -3608],
                        [ -2758,  -3972],
                        [ -3092,  -4314],
                        [ -3421,  -4635],
                        [ -3742,  -4942],
                        [ -4053,  -5233],
                        [ -4353,  -5518],
                        [ -4641,  -5795],
                        [ -4914,  -6065],
                        [ -5172,  -6326],
                        [ -5414,  -6576],
                        [ -5637,  -6814],
                        [ -5841,  -7039],
                        [ -6026,  -7249],
                        [ -6187,  -7439],
                        [ -6326,  -7609],
                        [ -6438,  -7755],
                        [ -6524,  -7878],
                        [ -6579,  -7973],
                        [ -6604,  -8042],
                        [ -6598,  -8087],
                        [ -6561,  -8106],
                        [ -6495,  -8101],
                        [ -6402,  -8072],
                        [ -6289,  -8015],
                        [ -6157,  -7930],
                        [ -6019,  -7817],
                        [ -5877,  -7677],
                        [ -5733,  -7513],
                        [ -5588,  -7323],
                        [ -5435,  -7110],
                        [ -5276,  -6877],
                        [ -5094,  -6625],
                        [ -4890,  -6356],
                        [ -4687,  -6095],
                        [ -4481,  -5841],
                        [ -4309,  -5631],
                        [ -4170,  -5462],
                        [ -4060,  -5330],
                        [ -3980,  -5237],
                        [ -3885,  -5137],
                        [ -3778,  -5031],
                        [ -3629,  -4888],
                        [ -3439,  -4713],
                        [ -3222,  -4512],
                        [ -2975,  -4287],
                        [ -2711,  -4046],
                        [ -2430,  -3791],
                        [ -2147,  -3532],
                        [ -1857,  -3268],
                        [ -1576,  -3009],
                        [ -1302,  -2754],
                        [ -1042,  -2513],
                        [  -797,  -2285],
                        [  -570,  -2074],
                        [  -362,  -1881],
                        [  -179,  -1709],
                        [   -18,  -1557],
                        [   118,  -1426],
                        [   229,  -1317],
                        [   320,  -1229],
                        [   392,  -1159],
                        [   449,  -1107],
                        [   494,  -1073],
                        [   527,  -1050],
                        [   550,  -1039],
                        [   566,  -1036],
                        [   577,  -1038],
                        [   586,  -1041],
                        [   594,  -1044],
                        [   605,  -1041],
                        [   622,  -1030],
                        [   646,  -1008],
                        [   681,   -973],
                        [   730,   -919],
                        [   795,   -847],
                        [   877,   -756],
                        [   975,   -642],
                        [  1097,   -502],
                        [  1238,   -339],
                        [  1399,   -154],
                        [  1586,     62],
                        [  1798,    304],
                        [  1961,    501],
                        [  1993,    567],
                        [  1867,    478],
                        [  1581,    226],
                        [  1112,   -212],
                        [   433,   -864],
                        [  -384,  -1659],
                        [ -1189,  -2450],
                        [ -1923,  -3176],
                        [ -2593,  -3841],
                        [ -3189,  -4434],
                        [ -3705,  -4943],
                        [ -4135,  -5363],
                        [ -4481,  -5692],
                        [ -4740,  -5927],
                        [ -4912,  -6069],
                        [ -4997,  -6117],
                        [ -4999,  -6078],
                        [ -4924,  -5954],
                        [ -4773,  -5751],
                        [ -4554,  -5474],
                        [ -4272,  -5129],
                        [ -3935,  -4723],
                        [ -3549,  -4266],
                        [ -3122,  -3763],
                        [ -2660,  -3222],
                        [ -2171,  -2651],
                        [ -1662,  -2057],
                        [ -1140,  -1446],
                        [  -609,   -825],
                        [   -76,   -198],
                        [   454,    427],
                        [   977,   1047],
                        [  1488,   1656],
                        [  1983,   2251],
                        [  2459,   2828],
                        [  2914,   3385],
                        [  3346,   3915],
                        [  3752,   4419],
                        [  4132,   4882],
                        [  4487,   5307],
                        [  4816,   5685],
                        [  5119,   6017],
                        [  5397,   6307],
                        [  5653,   6554],
                        [  5885,   6776],
                        [  6096,   6972],
                        [  6288,   7152],
                        [  6463,   7316],
                        [  6622,   7469],
                        [  6767,   7611],
                        [  6901,   7744],
                        [  7024,   7871],
                        [  7139,   7992],
                        [  7248,   8108],
                        [  7348,   8221],
                        [  7444,   8331],
                        [  7533,   8438],
                        [  7616,   8543],
                        [  7694,   8646],
                        [  7765,   8747],
                        [  7833,   8847],
                        [  7898,   8948],
                        [  7963,   9046],
                        [  8030,   9141],
                        [  8110,   9232],
                        [  8203,   9315],
                        [  8314,   9391],
                        [  8444,   9458],
                        [  8587,   9517],
                        [  8741,   9564],
                        [  8889,   9601],
                        [  9030,   9626],
                        [  9159,   9648],
                        [  9274,   9666],
                        [  9419,   9722],
                        [  9588,   9816],
                        [  9792,   9956],
                        [ 10031,  10144],
                        [ 10273,  10347],
                        [ 10519,  10567],
                        [ 10697,  10731],
                        [ 10809,  10842],
                        [ 10845,  10888],
                        [ 10803,  10866],
                        [ 10689,  10782],
                        [ 10502,  10634],
                        [ 10251,  10428],
                        [  9935,  10164],
                        [  9565,   9848],
                        [  9138,   9481],
                        [  8666,   9071],
                        [  8148,   8617],
                        [  7590,   8126],
                        [  6994,   7601],
                        [  6370,   7047],
                        [  5718,   6465],
                        [  5050,   5863],
                        [  4365,   5241],
                        [  3670,   4604],
                        [  2966,   3954],
                        [  2251,   3297],
                        [  1530,   2635],
                        [   804,   1971],
                        [    74,   1307],
                        [  -651,    647],
                        [ -1370,     -7],
                        [ -2078,   -651],
                        [ -2774,  -1284],
                        [ -3452,  -1904],
                        [ -4110,  -2508],
                        [ -4745,  -3095],
                        [ -5355,  -3662],
                        [ -5936,  -4206],
                        [ -6488,  -4728],
                        [ -7007,  -5224],
                        [ -7490,  -5692],
                        [ -7937,  -6130],
                        [ -8345,  -6539],
                        [ -8713,  -6915],
                        [ -9036,  -7253],
                        [ -9323,  -7562],
                        [ -9564,  -7831],
                        [ -9693,  -7994],
                        [ -9641,  -7984],
                        [ -9399,  -7785],
                        [ -8961,  -7394],
                        [ -8302,  -6782],
                        [ -7391,  -5917],
                        [ -6295,  -4861],
                        [ -5146,  -3748],
                        [ -3998,  -2633],
                        [ -2850,  -1514],
                        [ -1718,   -411],
                        [  -621,    659],
                        [   436,   1682],
                        [  1445,   2652],
                        [  2394,   3558],
                        [  3276,   4392],
                        [  4087,   5150],
                        [  4821,   5829],
                        [  5475,   6424],
                        [  6049,   6936],
                        [  6541,   7364],
                        [  6952,   7707],
                        [  7281,   7969],
                        [  7534,   8152],
                        [  7711,   8257],
                        [  7816,   8290],
                        [  7855,   8253],
                        [  7830,   8153],
                        [  7747,   7993],
                        [  7610,   7776],
                        [  7424,   7511],
                        [  7193,   7200],
                        [  6923,   6850],
                        [  6619,   6466],
                        [  6289,   6052],
                        [  5935,   5614],
                        [  5564,   5159],
                        [  5180,   4690],
                        [  4787,   4219],
                        [  4391,   3751],
                        [  3994,   3300],
                        [  3602,   2871],
                        [  3217,   2468],
                        [  2843,   2096],
                        [  2484,   1751],
                        [  2141,   1433],
                        [  1818,   1133],
                        [  1517,    854],
                        [  1241,    593],
                        [   990,    352],
                        [   769,    132],
                        [   576,    -67],
                        [   413,   -243],
                        [   280,   -396],
                        [   180,   -526],
                        [   111,   -633],
                        [    76,   -716],
                        [    76,   -775],
                        [   108,   -808],
                        [   175,   -817],
                        [   274,   -800],
                        [   404,   -756],
                        [   559,   -690],
                        [   740,   -600],
                        [   934,   -483],
                        [  1141,   -345],
                        [  1344,   -182],
                        [  1542,      3],
                        [  1732,    206],
                        [  1914,    427],
                        [  2092,    665],
                        [  2264,    914],
                        [  2441,   1170],
                        [  2622,   1431],
                        [  2771,   1655],
                        [  2888,   1844],
                        [  2932,   1954],
                        [  2905,   1988],
                        [  2810,   1947],
                        [  2643,   1828],
                        [  2468,   1693],
                        [  2280,   1538],
                        [  2130,   1415],
                        [  2017,   1320],
                        [  1937,   1253],
                        [  1889,   1211],
                        [  1869,   1195],
                        [  1876,   1203],
                        [  1904,   1229],
                        [  1953,   1276],
                        [  2017,   1337],
                        [  2095,   1413],
                        [  2185,   1497],
                        [  2286,   1593],
                        [  2394,   1694],
                        [  2509,   1802],
                        [  2623,   1914],
                        [  2737,   2031],
                        [  2849,   2152],
                        [  2959,   2276],
                        [  3071,   2403],
                        [  3187,   2535],
                        [  3313,   2670],
                        [  3452,   2811],
                        [  3603,   2958],
                        [  3767,   3111],
                        [  3944,   3273],
                        [  4134,   3443],
                        [  4338,   3625],
                        [  4557,   3819],
                        [  4790,   4026],
                        [  5037,   4246],
                        [  5298,   4481],
                        [  5575,   4731],
                        [  5866,   4996],
                        [  6171,   5276],
                        [  6487,   5571],
                        [  6814,   5878],
                        [  7152,   6199],
                        [  7497,   6530],
                        [  7846,   6868],
                        [  8204,   7218],
                        [  8558,   7569],
                        [  8851,   7862],
                        [  9036,   8050],
                        [  9107,   8127],
                        [  9057,   8085],
                        [  8852,   7889],
                        [  8454,   7498],
                        [  7906,   6954],
                        [  7314,   6364],
                        [  6716,   5763],
                        [  6110,   5154],
                        [  5510,   4550],
                        [  4926,   3966],
                        [  4367,   3412],
                        [  3837,   2893],
                        [  3343,   2417],
                        [  2892,   1991],
                        [  2485,   1617],
                        [  2127,   1297],
                        [  1818,   1032],
                        [  1558,    822],
                        [  1349,    667],
                        [  1187,    565],
                        [  1072,    514],
                        [   999,    510],
                        [   968,    553],
                        [   974,    637],
                        [  1015,    760],
                        [  1086,    917],
                        [  1183,   1103],
                        [  1306,   1317],
                        [  1448,   1554],
                        [  1607,   1809],
                        [  1781,   2079],
                        [  1965,   2361],
                        [  2159,   2653],
                        [  2358,   2950],
                        [  2559,   3252],
                        [  2764,   3551],
                        [  2968,   3847],
                        [  3172,   4129],
                        [  3374,   4395],
                        [  3574,   4636],
                        [  3772,   4853],
                        [  3967,   5046],
                        [  4158,   5213],
                        [  4347,   5369],
                        [  4533,   5512],
                        [  4716,   5653],
                        [  4895,   5791],
                        [  5072,   5929],
                        [  5246,   6068],
                        [  5417,   6208],
                        [  5586,   6349],
                        [  5751,   6494],
                        [  5913,   6643],
                        [  6069,   6797],
                        [  6222,   6957],
                        [  6367,   7120],
                        [  6504,   7287],
                        [  6632,   7452],
                        [  6749,   7615],
                        [  6855,   7771],
                        [  6949,   7920],
                        [  7037,   8059],
                        [  7116,   8187],
                        [  7196,   8297],
                        [  7275,   8390],
                        [  7359,   8462],
                        [  7444,   8513],
                        [  7525,   8539],
                        [  7599,   8539],
                        [  7655,   8515],
                        [  7692,   8465],
                        [  7713,   8405],
                        [  7719,   8333],
                        [  7760,   8305],
                        [  7833,   8314],
                        [  7947,   8375],
                        [  8101,   8487],
                        [  8271,   8624],
                        [  8457,   8787],
                        [  8572,   8892],
                        [  8623,   8944],
                        [  8592,   8925],
                        [  8482,   8836],
                        [  8292,   8678],
                        [  8023,   8448],
                        [  7685,   8153],
                        [  7275,   7794],
                        [  6803,   7374],
                        [  6271,   6897],
                        [  5686,   6372],
                        [  5051,   5796],
                        [  4375,   5183],
                        [  3658,   4531],
                        [  2917,   3851],
                        [  2153,   3145],
                        [  1382,   2422],
                        [   605,   1683],
                        [  -172,    938],
                        [  -947,    187],
                        [ -1718,   -561],
                        [ -2485,  -1303],
                        [ -3245,  -2033],
                        [ -3996,  -2747],
                        [ -4728,  -3443],
                        [ -5441,  -4115],
                        [ -6127,  -4761],
                        [ -6785,  -5378],
                        [ -7411,  -5963],
                        [ -8002,  -6514],
                        [ -8554,  -7028],
                        [ -9066,  -7504],
                        [ -9534,  -7940],
                        [ -9959,  -8335],
                        [-10337,  -8688],
                        [-10666,  -8996],
                        [-10947,  -9260],
                        [-11178,  -9480],
                        [-11360,  -9655],
                        [-11489,  -9780],
                        [-11572,  -9866],
                        [-11599,  -9900],
                        [-11533,  -9843],
                        [-11353,  -9680],
                        [-11067,  -9413],
                        [-10669,  -9037],
                        [-10131,  -8521],
                        [ -9410,  -7821],
                        [ -8532,  -6962],
                        [ -7579,  -6025],
                        [ -6584,  -5042],
                        [ -5550,  -4019],
                        [ -4499,  -2975],
                        [ -3447,  -1931],
                        [ -2406,   -900],
                        [ -1387,    106],
                        [  -403,   1072],
                        [   535,   1990],
                        [  1420,   2849],
                        [  2243,   3645],
                        [  2999,   4370],
                        [  3682,   5021],
                        [  4291,   5594],
                        [  4821,   6087],
                        [  5276,   6501],
                        [  5652,   6833],
                        [  5952,   7086],
                        [  6177,   7261],
                        [  6334,   7362],
                        [  6423,   7392],
                        [  6449,   7356],
                        [  6416,   7259],
                        [  6331,   7105],
                        [  6198,   6901],
                        [  6022,   6652],
                        [  5811,   6365],
                        [  5570,   6046],
                        [  5303,   5699],
                        [  5019,   5332],
                        [  4721,   4950],
                        [  4416,   4565],
                        [  4107,   4181],
                        [  3800,   3814],
                        [  3499,   3466],
                        [  3208,   3148],
                        [  2929,   2861],
                        [  2667,   2605],
                        [  2424,   2381],
                        [  2203,   2182],
                        [  2006,   2009],
                        [  1834,   1857],
                        [  1689,   1727],
                        [  1571,   1620],
                        [  1482,   1536],
                        [  1420,   1473],
                        [  1386,   1431],
                        [  1380,   1404],
                        [  1399,   1391],
                        [  1444,   1391],
                        [  1514,   1402],
                        [  1606,   1424],
                        [  1720,   1458],
                        [  1853,   1506],
                        [  2005,   1567],
                        [  2169,   1641],
                        [  2344,   1726],
                        [  2516,   1820],
                        [  2687,   1923],
                        [  2843,   2035],
                        [  2983,   2154],
                        [  3104,   2277],
                        [  3205,   2406],
                        [  3291,   2534],
                        [  3356,   2661],
                        [  3407,   2779],
                        [  3444,   2888],
                        [  3422,   2940],
                        [  3343,   2936],
                        [  3177,   2842],
                        [  2923,   2659],
                        [  2581,   2383],
                        [  2148,   2014],
                        [  1693,   1615],
                        [  1211,   1183],
                        [   760,    776],
                        [   339,    392],
                        [   -49,     34],
                        [  -401,   -295],
                        [  -717,   -592],
                        [  -993,   -853],
                        [ -1232,  -1081],
                        [ -1432,  -1272],
                        [ -1594,  -1429],
                        [ -1716,  -1549],
                        [ -1801,  -1635],
                        [ -1847,  -1684],
                        [ -1858,  -1701],
                        [ -1835,  -1684],
                        [ -1786,  -1635],
                        [ -1712,  -1554],
                        [ -1616,  -1444],
                        [ -1496,  -1302],
                        [ -1350,  -1135],
                        [ -1177,   -940],
                        [  -969,   -720],
                        [  -727,   -474],
                        [  -454,   -205],
                        [  -151,     85],
                        [   179,    396],
                        [   536,    726],
                        [   916,   1073],
                        [  1316,   1435],
                        [  1735,   1812],
                        [  2169,   2201],
                        [  2615,   2600],
                        [  3071,   3005],
                        [  3534,   3417],
                        [  3998,   3829],
                        [  4461,   4241],
                        [  4919,   4650],
                        [  5370,   5053],
                        [  5807,   5444],
                        [  6227,   5821],
                        [  6629,   6183],
                        [  7002,   6521],
                        [  7327,   6814],
                        [  7604,   7065],
                        [  7838,   7278],
                        [  8021,   7442],
                        [  8117,   7523],
                        [  8075,   7468],
                        [  7889,   7269],
                        [  7603,   6973],
                        [  7238,   6598],
                        [  6797,   6147],
                        [  6294,   5635],
                        [  5744,   5077],
                        [  5155,   4486],
                        [  4536,   3869],
                        [  3899,   3239],
                        [  3254,   2607],
                        [  2609,   1978],
                        [  1971,   1362],
                        [  1347,    763],
                        [   743,    189],
                        [   164,   -359],
                        [  -387,   -874],
                        [  -904,  -1355],
                        [ -1387,  -1796],
                        [ -1833,  -2198],
                        [ -2241,  -2556],
                        [ -2610,  -2872],
                        [ -2939,  -3146],
                        [ -3229,  -3378],
                        [ -3480,  -3569],
                        [ -3693,  -3720],
                        [ -3868,  -3832],
                        [ -4006,  -3908],
                        [ -4111,  -3950],
                        [ -4184,  -3959],
                        [ -4225,  -3938],
                        [ -4237,  -3888],
                        [ -4223,  -3815],
                        [ -4184,  -3717],
                        [ -4120,  -3609],
                        [ -4035,  -3489],
                        [ -3930,  -3366],
                        [ -3807,  -3244],
                        [ -3668,  -3123],
                        [ -3513,  -3008],
                        [ -3347,  -2890],
                        [ -3169,  -2772],
                        [ -2982,  -2646],
                        [ -2787,  -2514],
                        [ -2587,  -2374],
                        [ -2383,  -2229],
                        [ -2178,  -2077],
                        [ -1971,  -1920],
                        [ -1766,  -1755],
                        [ -1563,  -1584],
                        [ -1366,  -1402],
                        [ -1176,  -1212],
                        [  -995,  -1016],
                        [  -825,   -817],
                        [  -669,   -620],
                        [  -528,   -428],
                        [  -406,   -249],
                        [  -303,    -85],
                        [  -219,     62],
                        [  -151,    189],
                        [   -98,    293],
                        [   -60,    372],
                        [   -34,    423],
                        [   -23,    444],
                        [   -29,    432],
                        [   -54,    388],
                        [  -104,    313],
                        [  -177,    206],
                        [  -262,     89],
                        [  -358,    -42],
                        [  -419,   -137],
                        [  -449,   -199],
                        [  -439,   -215],
                        [  -387,   -187],
                        [  -309,   -125],
                        [  -202,    -30],
                        [  -147,     20],
                        [  -137,     33],
                        [  -189,     -8],
                        [  -299,   -103],
                        [  -471,   -254],
                        [  -704,   -459],
                        [  -994,   -720],
                        [ -1338,  -1033],
                        [ -1734,  -1395],
                        [ -2177,  -1804],
                        [ -2663,  -2255],
                        [ -3189,  -2745],
                        [ -3747,  -3267],
                        [ -4335,  -3818],
                        [ -4935,  -4391],
                        [ -5549,  -4983],
                        [ -6158,  -5585],
                        [ -6765,  -6195],
                        [ -7363,  -6806],
                        [ -7949,  -7414],
                        [ -8525,  -8012],
                        [ -9090,  -8598],
                        [ -9643,  -9165],
                        [-10180,  -9710],
                        [-10694, -10229],
                        [-11185, -10719],
                        [-11646, -11177],
                        [-12077, -11599],
                        [-12473, -11984],
                        [-12833, -12331],
                        [-13154, -12638],
                        [-13435, -12901],
                        [-13674, -13121],
                        [-13872, -13298],
                        [-14025, -13431],
                        [-14134, -13518],
                        [-14199, -13561],
                        [-14220, -13561],
                        [-14196, -13516],
                        [-14128, -13428],
                        [-14017, -13299],
                        [-13862, -13127],
                        [-13675, -12927],
                        [-13481, -12721],
                        [-13294, -12526],
                        [-13107, -12331],
                        [-12894, -12112],
                        [-12602, -11814],
                        [-12197, -11403],
                        [-11697, -10896],
                        [-11118, -10311],
                        [-10468,  -9655],
                        [ -9764,  -8942],
                        [ -9020,  -8189],
                        [ -8249,  -7408],
                        [ -7460,  -6611],
                        [ -6667,  -5812],
                        [ -5880,  -5021],
                        [ -5109,  -4249],
                        [ -4362,  -3502],
                        [ -3647,  -2789],
                        [ -2971,  -2115],
                        [ -2335,  -1486],
                        [ -1747,   -906],
                        [ -1208,   -378],
                        [  -721,     95],
                        [  -286,    512],
                        [    98,    872],
                        [   429,   1176],
                        [   712,   1424],
                        [   947,   1622],
                        [  1139,   1770],
                        [  1289,   1874],
                        [  1402,   1935],
                        [  1482,   1961],
                        [  1532,   1954],
                        [  1558,   1919],
                        [  1562,   1861],
                        [  1550,   1784],
                        [  1527,   1693],
                        [  1495,   1595],
                        [  1458,   1493],
                        [  1419,   1398],
                        [  1381,   1314],
                        [  1347,   1246],
                        [  1320,   1197],
                        [  1300,   1168],
                        [  1290,   1164],
                        [  1292,   1175],
                        [  1306,   1204],
                        [  1333,   1246],
                        [  1373,   1301],
                        [  1426,   1367],
                        [  1492,   1445],
                        [  1568,   1530],
                        [  1655,   1622],
                        [  1749,   1711],
                        [  1852,   1797],
                        [  1957,   1875],
                        [  2066,   1944],
                        [  2177,   2003],
                        [  2286,   2051],
                        [  2395,   2095],
                        [  2502,   2134],
                        [  2601,   2167],
                        [  2693,   2194],
                        [  2769,   2212],
                        [  2832,   2222],
                        [  2872,   2225],
                        [  2891,   2217],
                        [  2884,   2200],
                        [  2855,   2176],
                        [  2801,   2140],
                        [  2719,   2091],
                        [  2611,   2026],
                        [  2478,   1942],
                        [  2282,   1802],
                        [  2027,   1608],
                        [  1697,   1341],
                        [  1292,   1000],
                        [   805,    579],
                        [   239,     76],
                        [  -354,   -457],
                        [  -977,  -1023],
                        [ -1576,  -1571],
                        [ -2153,  -2101],
                        [ -2698,  -2605],
                        [ -3209,  -3081],
                        [ -3676,  -3517],
                        [ -4098,  -3914],
                        [ -4472,  -4266],
                        [ -4795,  -4570],
                        [ -5063,  -4824],
                        [ -5275,  -5025],
                        [ -5430,  -5174],
                        [ -5527,  -5269],
                        [ -5571,  -5313],
                        [ -5562,  -5302],
                        [ -5513,  -5243],
                        [ -5419,  -5133],
                        [ -5284,  -4975],
                        [ -5110,  -4772],
                        [ -4895,  -4526],
                        [ -4639,  -4240],
                        [ -4338,  -3919],
                        [ -3993,  -3562],
                        [ -3612,  -3178],
                        [ -3195,  -2765],
                        [ -2750,  -2332],
                        [ -2277,  -1880],
                        [ -1783,  -1415],
                        [ -1273,   -938],
                        [  -752,   -457],
                        [  -223,     28],
                        [   306,    508],
                        [   833,    982],
                        [  1351,   1444],
                        [  1857,   1892],
                        [  2343,   2319],
                        [  2808,   2723],
                        [  3244,   3098],
                        [  3651,   3443],
                        [  4019,   3753],
                        [  4348,   4024],
                        [  4636,   4260],
                        [  4923,   4497],
                        [  5241,   4771],
                        [  5601,   5091],
                        [  5996,   5449],
                        [  6400,   5821],
                        [  6748,   6141],
                        [  6972,   6342],
                        [  7061,   6410],
                        [  7022,   6356],
                        [  6865,   6186],
                        [  6598,   5907],
                        [  6238,   5536],
                        [  5792,   5080],
                        [  5273,   4552],
                        [  4693,   3963],
                        [  4063,   3328],
                        [  3395,   2655],
                        [  2699,   1956],
                        [  1985,   1239],
                        [  1263,    514],
                        [   541,   -210],
                        [  -172,   -925],
                        [  -870,  -1625],
                        [ -1544,  -2299],
                        [ -2190,  -2945],
                        [ -2802,  -3553],
                        [ -3377,  -4122],
                        [ -3910,  -4648],
                        [ -4400,  -5128],
                        [ -4844,  -5562],
                        [ -5241,  -5948],
                        [ -5591,  -6285],
                        [ -5893,  -6574],
                        [ -6147,  -6817],
                        [ -6356,  -7014],
                        [ -6520,  -7165],
                        [ -6640,  -7274],
                        [ -6719,  -7344],
                        [ -6759,  -7375],
                        [ -6763,  -7375],
                        [ -6733,  -7344],
                        [ -6672,  -7291],
                        [ -6585,  -7217],
                        [ -6472,  -7131],
                        [ -6338,  -7034],
                        [ -6186,  -6928],
                        [ -6021,  -6817],
                        [ -5846,  -6697],
                        [ -5664,  -6573],
                        [ -5479,  -6445],
                        [ -5293,  -6316],
                        [ -5110,  -6186],
                        [ -4933,  -6060],
                        [ -4764,  -5934],
                        [ -4605,  -5809],
                        [ -4459,  -5683],
                        [ -4327,  -5556],
                        [ -4212,  -5431],
                        [ -4115,  -5309],
                        [ -4041,  -5198],
                        [ -3990,  -5099],
                        [ -3966,  -5023],
                        [ -3969,  -4970],
                        [ -4000,  -4941],
                        [ -4058,  -4936],
                        [ -4144,  -4957],
                        [ -4257,  -5006],
                        [ -4393,  -5081],
                        [ -4554,  -5187],
                        [ -4738,  -5324],
                        [ -4941,  -5488],
                        [ -5161,  -5676],
                        [ -5398,  -5890],
                        [ -5634,  -6108],
                        [ -5869,  -6333],
                        [ -6075,  -6533],
                        [ -6254,  -6710],
                        [ -6393,  -6851],
                        [ -6492,  -6953],
                        [ -6548,  -7014],
                        [ -6560,  -7030],
                        [ -6582,  -7055],
                        [ -6609,  -7084],
                        [ -6653,  -7129],
                        [ -6712,  -7187],
                        [ -6794,  -7265],
                        [ -6897,  -7364],
                        [ -7020,  -7483],
                        [ -7164,  -7622],
                        [ -7328,  -7782],
                        [ -7511,  -7962],
                        [ -7711,  -8159],
                        [ -7927,  -8372],
                        [ -8154,  -8598],
                        [ -8391,  -8835],
                        [ -8624,  -9079],
                        [ -8854,  -9328],
                        [ -9073,  -9576],
                        [ -9280,  -9824],
                        [ -9473, -10064],
                        [ -9650, -10298],
                        [ -9817, -10519],
                        [ -9972, -10726],
                        [-10115, -10914],
                        [-10246, -11084],
                        [-10359, -11231],
                        [-10454, -11355],
                        [-10531, -11451],
                        [-10587, -11521],
                        [-10620, -11562],
                        [-10631, -11574],
                        [-10617, -11556],
                        [-10579, -11507],
                        [-10515, -11427],
                        [-10427, -11317],
                        [-10311, -11175],
                        [-10172, -11003],
                        [-10006, -10801],
                        [ -9815, -10570],
                        [ -9600, -10311],
                        [ -9360, -10025],
                        [ -9091,  -9709],
                        [ -8815,  -9385],
                        [ -8595,  -9119],
                        [ -8479,  -8957],
                        [ -8478,  -8912],
                        [ -8591,  -8981],
                        [ -8801,  -9149],
                        [ -9037,  -9345],
                        [ -9203,  -9475],
                        [ -9265,  -9505],
                        [ -9230,  -9440],
                        [ -9102,  -9286],
                        [ -8893,  -9050],
                        [ -8608,  -8739],
                        [ -8259,  -8363],
                        [ -7853,  -7928],
                        [ -7399,  -7447],
                        [ -6906,  -6927],
                        [ -6382,  -6375],
                        [ -5835,  -5801],
                        [ -5272,  -5211],
                        [ -4700,  -4613],
                        [ -4122,  -4012],
                        [ -3547,  -3413],
                        [ -2979,  -2823],
                        [ -2421,  -2247],
                        [ -1878,  -1689],
                        [ -1350,  -1152],
                        [  -843,   -639],
                        [  -355,   -150],
                        [   111,    314],
                        [   557,    753],
                        [   982,   1168],
                        [  1385,   1557],
                        [  1768,   1925],
                        [  2133,   2271],
                        [  2478,   2597],
                        [  2807,   2905],
                        [  3120,   3195],
                        [  3419,   3469],
                        [  3705,   3730],
                        [  3978,   3978],
                        [  4240,   4215],
                        [  4492,   4444],
                        [  4732,   4665],
                        [  4964,   4883],
                        [  5187,   5099],
                        [  5402,   5315],
                        [  5607,   5529],
                        [  5805,   5742],
                        [  5993,   5949],
                        [  6172,   6152],
                        [  6340,   6347],
                        [  6498,   6535],
                        [  6641,   6710],
                        [  6772,   6871],
                        [  6885,   7008],
                        [  6982,   7122],
                        [  7058,   7207],
                        [  7113,   7263],
                        [  7148,   7290],
                        [  7161,   7288],
                        [  7153,   7265],
                        [  7126,   7222],
                        [  7079,   7157],
                        [  7011,   7073],
                        [  6926,   6966],
                        [  6823,   6840],
                        [  6702,   6694],
                        [  6562,   6528],
                        [  6401,   6346],
                        [  6222,   6149],
                        [  6020,   5938],
                        [  5792,   5709],
                        [  5539,   5464],
                        [  5261,   5204],
                        [  4944,   4912],
                        [  4589,   4591],
                        [  4197,   4236],
                        [  3767,   3849],
                        [  3287,   3414],
                        [  2758,   2935],
                        [  2207,   2431],
                        [  1632,   1904],
                        [  1069,   1385],
                        [   518,    877],
                        [    -8,    390],
                        [  -508,    -73],
                        [  -967,   -501],
                        [ -1387,   -892],
                        [ -1758,  -1238],
                        [ -2080,  -1539],
                        [ -2346,  -1787],
                        [ -2556,  -1983],
                        [ -2709,  -2123],
                        [ -2803,  -2208],
                        [ -2845,  -2238],
                        [ -2832,  -2213],
                        [ -2773,  -2136],
                        [ -2668,  -2008],
                        [ -2523,  -1832],
                        [ -2337,  -1610],
                        [ -2112,  -1349],
                        [ -1850,  -1049],
                        [ -1549,   -717],
                        [ -1210,   -355],
                        [  -844,     28],
                        [  -453,    431],
                        [   -43,    846],
                        [   384,   1270],
                        [   818,   1697],
                        [  1258,   2121],
                        [  1695,   2538],
                        [  2127,   2945],
                        [  2546,   3332],
                        [  2949,   3699],
                        [  3330,   4040],
                        [  3686,   4351],
                        [  4011,   4628],
                        [  4304,   4868],
                        [  4557,   5068],
                        [  4773,   5226],
                        [  4943,   5340],
                        [  5062,   5402],
                        [  5162,   5446],
                        [  5324,   5555],
                        [  5598,   5779],
                        [  5992,   6125],
                        [  6507,   6596],
                        [  7131,   7178],
                        [  7790,   7802],
                        [  8360,   8340],
                        [  8790,   8744],
                        [  9086,   9022],
                        [  9257,   9176],
                        [  9303,   9210],
                        [  9238,   9130],
                        [  9068,   8945],
                        [  8806,   8663],
                        [  8460,   8295],
                        [  8041,   7853],
                        [  7560,   7344],
                        [  7027,   6782],
                        [  6454,   6176],
                        [  5848,   5536],
                        [  5221,   4871],
                        [  4583,   4193],
                        [  3942,   3509],
                        [  3308,   2832],
                        [  2685,   2165],
                        [  2082,   1520],
                        [  1506,    900],
                        [   958,    312],
                        [   445,   -241],
                        [   -32,   -757],
                        [  -468,  -1233],
                        [  -864,  -1667],
                        [ -1216,  -2059],
                        [ -1528,  -2408],
                        [ -1795,  -2715],
                        [ -2022,  -2982],
                        [ -2208,  -3208],
                        [ -2358,  -3395],
                        [ -2471,  -3545],
                        [ -2551,  -3659],
                        [ -2602,  -3738],
                        [ -2626,  -3788],
                        [ -2626,  -3809],
                        [ -2607,  -3810],
                        [ -2572,  -3794],
                        [ -2524,  -3769],
                        [ -2469,  -3739],
                        [ -2408,  -3707],
                        [ -2347,  -3677],
                        [ -2287,  -3651],
                        [ -2233,  -3630],
                        [ -2186,  -3616],
                        [ -2150,  -3613],
                        [ -2124,  -3614],
                        [ -2111,  -3622],
                        [ -2112,  -3634],
                        [ -2127,  -3651],
                        [ -2157,  -3673],
                        [ -2205,  -3700],
                        [ -2273,  -3742],
                        [ -2360,  -3796],
                        [ -2469,  -3871],
                        [ -2602,  -3966],
                        [ -2761,  -4079],
                        [ -2945,  -4208],
                        [ -3157,  -4354],
                        [ -3395,  -4515],
                        [ -3653,  -4689],
                        [ -3933,  -4878],
                        [ -4223,  -5081],
                        [ -4521,  -5293],
                        [ -4817,  -5512],
                        [ -5109,  -5736],
                        [ -5388,  -5959],
                        [ -5653,  -6177],
                        [ -5901,  -6387],
                        [ -6130,  -6588],
                        [ -6328,  -6767],
                        [ -6494,  -6922],
                        [ -6606,  -7029],
                        [ -6664,  -7087],
                        [ -6686,  -7116],
                        [ -6670,  -7109],
                        [ -6627,  -7078],
                        [ -6554,  -7020],
                        [ -6463,  -6945],
                        [ -6351,  -6852],
                        [ -6225,  -6746],
                        [ -6085,  -6627],
                        [ -5937,  -6502],
                        [ -5780,  -6368],
                        [ -5617,  -6230],
                        [ -5448,  -6087],
                        [ -5274,  -5943],
                        [ -5094,  -5795],
                        [ -4906,  -5645],
                        [ -4709,  -5493],
                        [ -4503,  -5338],
                        [ -4288,  -5181],
                        [ -4063,  -5018],
                        [ -3829,  -4852],
                        [ -3593,  -4681],
                        [ -3354,  -4505],
                        [ -3113,  -4323],
                        [ -2871,  -4133],
                        [ -2628,  -3936],
                        [ -2383,  -3731],
                        [ -2136,  -3517],
                        [ -1888,  -3293],
                        [ -1637,  -3060],
                        [ -1385,  -2818],
                        [ -1130,  -2564],
                        [  -873,  -2301],
                        [  -613,  -2026],
                        [  -350,  -1742],
                        [   -85,  -1446],
                        [   184,  -1142],
                        [   456,   -826],
                        [   730,   -499],
                        [  1008,   -167],
                        [  1290,    176],
                        [  1584,    531],
                        [  1837,    849],
                        [  1957,   1033],
                        [  1894,   1034],
                        [  1643,    847],
                        [  1198,    466],
                        [   562,   -111],
                        [  -183,   -798],
                        [  -890,  -1454],
                        [ -1497,  -2018],
                        [ -2009,  -2494],
                        [ -2426,  -2880],
                        [ -2745,  -3170],
                        [ -2967,  -3366],
                        [ -3099,  -3470],
                        [ -3144,  -3486],
                        [ -3107,  -3417],
                        [ -2992,  -3269],
                        [ -2805,  -3046],
                        [ -2551,  -2756],
                        [ -2236,  -2403],
                        [ -1866,  -1996],
                        [ -1448,  -1538],
                        [  -986,  -1038],
                        [  -491,   -502],
                        [    36,     63],
                        [   586,    652],
                        [  1155,   1256],
                        [  1739,   1872],
                        [  2332,   2495],
                        [  2931,   3122],
                        [  3531,   3748],
                        [  4129,   4371],
                        [  4723,   4989],
                        [  5309,   5597],
                        [  5883,   6196],
                        [  6445,   6781],
                        [  6990,   7352],
                        [  7518,   7905],
                        [  8028,   8439],
                        [  8515,   8950],
                        [  8981,   9437],
                        [  9423,   9893],
                        [  9839,  10318],
                        [ 10230,  10710],
                        [ 10594,  11070],
                        [ 10931,  11403],
                        [ 11239,  11709],
                        [ 11516,  11993],
                        [ 11766,  12253],
                        [ 11984,  12491],
                        [ 12173,  12706],
                        [ 12329,  12894],
                        [ 12454,  13059],
                        [ 12546,  13194],
                        [ 12604,  13300],
                        [ 12626,  13368],
                        [ 12612,  13400],
                        [ 12564,  13393],
                        [ 12478,  13349],
                        [ 12360,  13266],
                        [ 12209,  13147],
                        [ 12029,  13002],
                        [ 11822,  12831],
                        [ 11594,  12635],
                        [ 11347,  12416],
                        [ 11089,  12173],
                        [ 10823,  11908],
                        [ 10552,  11623],
                        [ 10277,  11318],
                        [  9995,  10999],
                        [  9706,  10667],
                        [  9403,  10325],
                        [  9085,   9973],
                        [  8756,   9616],
                        [  8413,   9254],
                        [  8071,   8903],
                        [  7731,   8560],
                        [  7402,   8236],
                        [  7085,   7930],
                        [  6758,   7621],
                        [  6427,   7312],
                        [  6074,   6985],
                        [  5703,   6642],
                        [  5329,   6298],
                        [  4951,   5951],
                        [  4584,   5613],
                        [  4227,   5285],
                        [  3892,   4977],
                        [  3579,   4689],
                        [  3298,   4431],
                        [  3047,   4202],
                        [  2834,   4009],
                        [  2655,   3850],
                        [  2517,   3729],
                        [  2416,   3647],
                        [  2352,   3604],
                        [  2325,   3598],
                        [  2329,   3628],
                        [  2365,   3692],
                        [  2428,   3786],
                        [  2515,   3910],
                        [  2624,   4057],
                        [  2751,   4227],
                        [  2899,   4412],
                        [  3062,   4610],
                        [  3236,   4816],
                        [  3417,   5026],
                        [  3601,   5236],
                        [  3785,   5440],
                        [  3963,   5633],
                        [  4134,   5814],
                        [  4291,   5976],
                        [  4433,   6118],
                        [  4555,   6234],
                        [  4654,   6322],
                        [  4727,   6379],
                        [  4774,   6403],
                        [  4792,   6393],
                        [  4779,   6346],
                        [  4733,   6260],
                        [  4657,   6142],
                        [  4544,   5982],
                        [  4392,   5782],
                        [  4264,   5605],
                        [  4261,   5551],
                        [  4423,   5663],
                        [  4759,   5948],
                        [  5281,   6421],
                        [  5998,   7089],
                        [  6824,   7870],
                        [  7608,   8613],
                        [  8284,   9256],
                        [  8861,   9806],
                        [  9339,  10260],
                        [  9712,  10614],
                        [  9986,  10866],
                        [ 10165,  11020],
                        [ 10256,  11080],
                        [ 10264,  11051],
                        [ 10194,  10939],
                        [ 10052,  10751],
                        [  9848,  10495],
                        [  9588,  10177],
                        [  9281,   9809],
                        [  8933,   9393],
                        [  8552,   8942],
                        [  8147,   8464],
                        [  7725,   7967],
                        [  7293,   7456],
                        [  6856,   6940],
                        [  6420,   6426],
                        [  5990,   5917],
                        [  5569,   5418],
                        [  5161,   4931],
                        [  4768,   4461],
                        [  4393,   4009],
                        [  4038,   3577],
                        [  3703,   3164],
                        [  3389,   2773],
                        [  3096,   2403],
                        [  2823,   2055],
                        [  2570,   1728],
                        [  2334,   1423],
                        [  2113,   1143],
                        [  1907,    887],
                        [  1713,    659],
                        [  1528,    455],
                        [  1351,    271],
                        [  1178,    105],
                        [  1008,    -59],
                        [   836,   -219],
                        [   663,   -385],
                        [   485,   -560],
                        [   301,   -743],
                        [   111,   -938],
                        [   -89,  -1144],
                        [  -297,  -1362],
                        [  -512,  -1587],
                        [  -735,  -1820],
                        [  -964,  -2057],
                        [ -1201,  -2301],
                        [ -1441,  -2546],
                        [ -1688,  -2793],
                        [ -1941,  -3045],
                        [ -2201,  -3303],
                        [ -2468,  -3568],
                        [ -2744,  -3840],
                        [ -3033,  -4114],
                        [ -3335,  -4388],
                        [ -3654,  -4659],
                        [ -3987,  -4924],
                        [ -4327,  -5181],
                        [ -4674,  -5428],
                        [ -5009,  -5665],
                        [ -5332,  -5887],
                        [ -5629,  -6092],
                        [ -5900,  -6281],
                        [ -6154,  -6463],
                        [ -6386,  -6634],
                        [ -6618,  -6817],
                        [ -6845,  -7008],
                        [ -7058,  -7196],
                        [ -7256,  -7379],
                        [ -7398,  -7516],
                        [ -7482,  -7605],
                        [ -7496,  -7631],
                        [ -7439,  -7594],
                        [ -7321,  -7500],
                        [ -7140,  -7350],
                        [ -6910,  -7153],
                        [ -6628,  -6908],
                        [ -6308,  -6625],
                        [ -5948,  -6303],
                        [ -5556,  -5954],
                        [ -5135,  -5575],
                        [ -4692,  -5178],
                        [ -4227,  -4761],
                        [ -3750,  -4333],
                        [ -3258,  -3893],
                        [ -2761,  -3447],
                        [ -2258,  -2997],
                        [ -1753,  -2546],
                        [ -1246,  -2096],
                        [  -739,  -1649],
                        [  -233,  -1206],
                        [   266,   -769],
                        [   756,   -338],
                        [  1236,     85],
                        [  1705,    498],
                        [  2159,    902],
                        [  2598,   1297],
                        [  3023,   1682],
                        [  3430,   2056],
                        [  3822,   2421],
                        [  4197,   2776],
                        [  4556,   3123],
                        [  4897,   3460],
                        [  5223,   3789],
                        [  5532,   4110],
                        [  5826,   4422],
                        [  6103,   4727],
                        [  6368,   5026],
                        [  6619,   5319],
                        [  6854,   5601],
                        [  7081,   5881],
                        [  7302,   6158],
                        [  7443,   6359],
                        [  7414,   6389],
                        [  7181,   6217],
                        [  6744,   5841],
                        [  6083,   5243],
                        [  5188,   4407],
                        [  4144,   3419],
                        [  3114,   2438],
                        [  2157,   1522],
                        [  1275,    672],
                        [   475,   -103],
                        [  -234,   -791],
                        [  -845,  -1385],
                        [ -1362,  -1881],
                        [ -1781,  -2277],
                        [ -2103,  -2572],
                        [ -2329,  -2768],
                        [ -2461,  -2867],
                        [ -2502,  -2871],
                        [ -2455,  -2785],
                        [ -2328,  -2615],
                        [ -2124,  -2364],
                        [ -1849,  -2042],
                        [ -1513,  -1655],
                        [ -1120,  -1209],
                        [  -678,   -713],
                        [  -193,   -175],
                        [   325,    400],
                        [   873,   1004],
                        [  1441,   1631],
                        [  2026,   2273],
                        [  2620,   2926],
                        [  3218,   3584],
                        [  3812,   4241],
                        [  4400,   4894],
                        [  4973,   5534],
                        [  5529,   6160],
                        [  6064,   6767],
                        [  6572,   7349],
                        [  7053,   7898],
                        [  7501,   8413],
                        [  7915,   8881],
                        [  8292,   9298],
                        [  8630,   9662],
                        [  8930,   9972],
                        [  9189,  10233],
                        [  9406,  10445],
                        [  9581,  10619],
                        [  9714,  10758],
                        [  9806,  10861],
                        [  9856,  10931],
                        [  9865,  10968],
                        [  9832,  10972],
                        [  9759,  10941],
                        [  9647,  10879],
                        [  9494,  10780],
                        [  9303,  10649],
                        [  9075,  10483],
                        [  8812,  10285],
                        [  8517,  10057],
                        [  8194,   9800],
                        [  7848,   9523],
                        [  7483,   9228],
                        [  7109,   8916],
                        [  6730,   8591],
                        [  6357,   8252],
                        [  5995,   7902],
                        [  5646,   7541],
                        [  5315,   7172],
                        [  4994,   6799],
                        [  4682,   6424],
                        [  4370,   6048],
                        [  4060,   5677],
                        [  3757,   5318],
                        [  3461,   4973],
                        [  3211,   4680],
                        [  3004,   4439],
                        [  2854,   4262],
                        [  2761,   4151],
                        [  2698,   4077],
                        [  2666,   4042],
                        [  2613,   3991],
                        [  2542,   3928],
                        [  2450,   3850],
                        [  2338,   3754],
                        [  2213,   3647],
                        [  2076,   3530],
                        [  1935,   3408],
                        [  1788,   3281],
                        [  1642,   3155],
                        [  1496,   3029],
                        [  1354,   2909],
                        [  1214,   2792],
                        [  1081,   2684],
                        [   952,   2581],
                        [   834,   2489],
                        [   725,   2403],
                        [   624,   2325],
                        [   530,   2252],
                        [   437,   2185],
                        [   345,   2120],
                        [   250,   2056],
                        [   150,   1991],
                        [    46,   1922],
                        [   -64,   1849],
                        [  -182,   1768],
                        [  -310,   1678],
                        [  -448,   1575],
                        [  -597,   1458],
                        [  -760,   1326],
                        [  -936,   1177],
                        [ -1129,   1006],
                        [ -1335,    817],
                        [ -1557,    608],
                        [ -1796,    376],
                        [ -2050,    123],
                        [ -2317,   -151],
                        [ -2600,   -445],
                        [ -2896,   -761],
                        [ -3204,  -1094],
                        [ -3517,  -1438],
                        [ -3845,  -1802],
                        [ -4177,  -2177],
                        [ -4439,  -2484],
                        [ -4545,  -2640],
                        [ -4472,  -2618],
                        [ -4214,  -2414],
                        [ -3742,  -1999],
                        [ -3034,  -1348],
                        [ -2169,   -539],
                        [ -1294,    284],
                        [  -465,   1068],
                        [   326,   1818],
                        [  1067,   2522],
                        [  1747,   3170],
                        [  2364,   3752],
                        [  2915,   4267],
                        [  3403,   4712],
                        [  3824,   5083],
                        [  4177,   5382],
                        [  4465,   5610],
                        [  4688,   5766],
                        [  4851,   5857],
                        [  4954,   5886],
                        [  5002,   5853],
                        [  4999,   5767],
                        [  4950,   5631],
                        [  4859,   5449],
                        [  4730,   5228],
                        [  4566,   4971],
                        [  4374,   4683],
                        [  4154,   4368],
                        [  3912,   4031],
                        [  3649,   3672],
                        [  3369,   3296],
                        [  3074,   2906],
                        [  2765,   2504],
                        [  2446,   2091],
                        [  2118,   1669],
                        [  1783,   1240],
                        [  1441,    806],
                        [  1092,    370],
                        [   739,    -69],
                        [   379,   -500],
                        [    15,   -921],
                        [  -355,  -1325],
                        [  -730,  -1714],
                        [ -1108,  -2085],
                        [ -1493,  -2441],
                        [ -1882,  -2795],
                        [ -2276,  -3147],
                        [ -2674,  -3508],
                        [ -3077,  -3876],
                        [ -3482,  -4253],
                        [ -3890,  -4638],
                        [ -4299,  -5029],
                        [ -4707,  -5427],
                        [ -5111,  -5827],
                        [ -5509,  -6229],
                        [ -5899,  -6631],
                        [ -6279,  -7030],
                        [ -6648,  -7420],
                        [ -7004,  -7801],
                        [ -7345,  -8172],
                        [ -7673,  -8532],
                        [ -7989,  -8880],
                        [ -8291,  -9215],
                        [ -8590,  -9532],
                        [ -8883,  -9830],
                        [ -9175, -10102],
                        [ -9464, -10347],
                        [ -9743, -10563],
                        [-10010, -10745],
                        [-10246, -10896],
                        [-10450, -11013],
                        [-10615, -11096],
                        [-10738, -11143],
                        [-10848, -11189],
                        [-10943, -11227],
                        [-11054, -11295],
                        [-11181, -11388],
                        [-11316, -11501],
                        [-11459, -11633],
                        [-11551, -11724],
                        [-11598, -11780],
                        [-11557, -11756],
                        [-11431, -11656],
                        [-11230, -11486],
                        [-10953, -11246],
                        [-10612, -10943],
                        [-10205, -10577],
                        [ -9744, -10160],
                        [ -9232,  -9691],
                        [ -8675,  -9181],
                        [ -8078,  -8633],
                        [ -7451,  -8055],
                        [ -6794,  -7451],
                        [ -6122,  -6830],
                        [ -5436,  -6193],
                        [ -4750,  -5549],
                        [ -4063,  -4900],
                        [ -3380,  -4254],
                        [ -2703,  -3610],
                        [ -2033,  -2976],
                        [ -1372,  -2352],
                        [  -722,  -1742],
                        [   -87,  -1149],
                        [   529,   -574],
                        [  1125,    -20],
                        [  1699,    512],
                        [  2249,   1022],
                        [  2773,   1510],
                        [  3270,   1972],
                        [  3742,   2412],
                        [  4184,   2828],
                        [  4600,   3221],
                        [  4986,   3590],
                        [  5347,   3939],
                        [  5679,   4265],
                        [  5986,   4570],
                        [  6266,   4856],
                        [  6523,   5123],
                        [  6755,   5370],
                        [  6961,   5596],
                        [  7149,   5809],
                        [  7314,   6004],
                        [  7384,   6105],
                        [  7298,   6053],
                        [  7045,   5836],
                        [  6623,   5449],
                        [  6002,   4866],
                        [  5156,   4055],
                        [  4156,   3088],
                        [  3139,   2098],
                        [  2149,   1129],
                        [  1190,    183],
                        [   275,   -726],
                        [  -580,  -1579],
                        [ -1366,  -2367],
                        [ -2080,  -3081],
                        [ -2716,  -3714],
                        [ -3270,  -4260],
                        [ -3739,  -4717],
                        [ -4122,  -5083],
                        [ -4418,  -5358],
                        [ -4631,  -5546],
                        [ -4761,  -5646],
                        [ -4813,  -5664],
                        [ -4791,  -5604],
                        [ -4701,  -5471],
                        [ -4549,  -5271],
                        [ -4341,  -5011],
                        [ -4084,  -4697],
                        [ -3785,  -4338],
                        [ -3452,  -3938],
                        [ -3088,  -3508],
                        [ -2703,  -3052],
                        [ -2303,  -2576],
                        [ -1895,  -2089],
                        [ -1484,  -1597],
                        [ -1077,  -1103],
                        [  -681,   -616],
                        [  -299,   -141],
                        [    63,    319],
                        [   403,    757],
                        [   715,   1164],
                        [   997,   1538],
                        [  1246,   1863],
                        [  1461,   2137],
                        [  1639,   2354],
                        [  1780,   2513],
                        [  1883,   2620],
                        [  1948,   2672],
                        [  1975,   2689],
                        [  1965,   2672],
                        [  1918,   2624],
                        [  1835,   2546],
                        [  1720,   2442],
                        [  1573,   2313],
                        [  1393,   2162],
                        [  1186,   1991],
                        [   950,   1801],
                        [   687,   1597],
                        [   403,   1377],
                        [    97,   1143],
                        [  -225,    895],
                        [  -560,    636],
                        [  -902,    371],
                        [ -1250,    103],
                        [ -1587,   -167],
                        [ -1913,   -435],
                        [ -2215,   -702],
                        [ -2490,   -966],
                        [ -2735,  -1227],
                        [ -2947,  -1484],
                        [ -3139,  -1736],
                        [ -3307,  -1982],
                        [ -3466,  -2217],
                        [ -3612,  -2440],
                        [ -3734,  -2637],
                        [ -3833,  -2805],
                        [ -3856,  -2893],
                        [ -3808,  -2904],
                        [ -3677,  -2824],
                        [ -3465,  -2655],
                        [ -3200,  -2426],
                        [ -2883,  -2137],
                        [ -2594,  -1867],
                        [ -2327,  -1613],
                        [ -2098,  -1390],
                        [ -1907,  -1200],
                        [ -1752,  -1042],
                        [ -1634,   -919],
                        [ -1550,   -827],
                        [ -1503,   -769],
                        [ -1489,   -742],
                        [ -1510,   -747],
                        [ -1562,   -778],
                        [ -1648,   -840],
                        [ -1761,   -928],
                        [ -1901,  -1042],
                        [ -2059,  -1177],
                        [ -2238,  -1338],
                        [ -2432,  -1520],
                        [ -2644,  -1723],
                        [ -2876,  -1945],
                        [ -3131,  -2187],
                        [ -3409,  -2448],
                        [ -3713,  -2728],
                        [ -4037,  -3023],
                        [ -4383,  -3336],
                        [ -4745,  -3663],
                        [ -5125,  -4005],
                        [ -5520,  -4360],
                        [ -5928,  -4728],
                        [ -6346,  -5107],
                        [ -6773,  -5496],
                        [ -7205,  -5892],
                        [ -7642,  -6295],
                        [ -8079,  -6703],
                        [ -8514,  -7114],
                        [ -8945,  -7525],
                        [ -9367,  -7934],
                        [ -9779,  -8338],
                        [-10179,  -8736],
                        [-10562,  -9122],
                        [-10920,  -9492],
                        [-11262,  -9850],
                        [-11570, -10182],
                        [-11785, -10426],
                        [-11860, -10537],
                        [-11794, -10511],
                        [-11576, -10336],
                        [-11172,  -9980],
                        [-10546,  -9403],
                        [ -9752,  -8658],
                        [ -8894,  -7849],
                        [ -8012,  -7012],
                        [ -7105,  -6146],
                        [ -6190,  -5269],
                        [ -5284,  -4396],
                        [ -4395,  -3542],
                        [ -3532,  -2713],
                        [ -2701,  -1922],
                        [ -1911,  -1176],
                        [ -1168,   -481],
                        [  -477,    157],
                        [   158,    735],
                        [   733,   1250],
                        [  1246,   1701],
                        [  1697,   2086],
                        [  2082,   2404],
                        [  2407,   2657],
                        [  2667,   2845],
                        [  2867,   2968],
                        [  3008,   3030],
                        [  3092,   3033],
                        [  3119,   2980],
                        [  3095,   2873],
                        [  3019,   2715],
                        [  2896,   2509],
                        [  2728,   2259],
                        [  2516,   1965],
                        [  2268,   1634],
                        [  1983,   1268],
                        [  1666,    869],
                        [  1319,    440],
                        [   946,    -11],
                        [   548,   -485],
                        [   130,   -965],
                        [  -308,  -1451],
                        [  -760,  -1931],
                        [ -1225,  -2400],
                        [ -1701,  -2857],
                        [ -2185,  -3297],
                        [ -2672,  -3733],
                        [ -3161,  -4161],
                        [ -3650,  -4592],
                        [ -4136,  -5025],
                        [ -4614,  -5454],
                        [ -5085,  -5882],
                        [ -5543,  -6305],
                        [ -5987,  -6723],
                        [ -6411,  -7135],
                        [ -6814,  -7538],
                        [ -7193,  -7930],
                        [ -7544,  -8309],
                        [ -7866,  -8666],
                        [ -8158,  -9002],
                        [ -8418,  -9310],
                        [ -8644,  -9590],
                        [ -8842,  -9840],
                        [ -9008, -10061],
                        [ -9154, -10248],
                        [ -9280, -10402],
                        [ -9388, -10516],
                        [ -9479, -10593],
                        [ -9550, -10627],
                        [ -9596, -10616],
                        [ -9604, -10563],
                        [ -9574, -10472],
                        [ -9503, -10342],
                        [ -9392, -10175],
                        [ -9284, -10019],
                        [ -9180,  -9869],
                        [ -9112,  -9766],
                        [ -9082,  -9707],
                        [ -9088,  -9692],
                        [ -9132,  -9725],
                        [ -9150,  -9739],
                        [ -9146,  -9739],
                        [ -9069,  -9674],
                        [ -8924,  -9548],
                        [ -8717,  -9363],
                        [ -8448,  -9121],
                        [ -8122,  -8824],
                        [ -7741,  -8474],
                        [ -7313,  -8079],
                        [ -6840,  -7638],
                        [ -6328,  -7161],
                        [ -5778,  -6650],
                        [ -5202,  -6113],
                        [ -4599,  -5552],
                        [ -3988,  -4976],
                        [ -3368,  -4385],
                        [ -2752,  -3789],
                        [ -2140,  -3188],
                        [ -1536,  -2590],
                        [  -941,  -1996],
                        [  -351,  -1411],
                        [   232,   -835],
                        [   806,   -275],
                        [  1369,    271],
                        [  1918,    796],
                        [  2451,   1303],
                        [  2966,   1790],
                        [  3462,   2254],
                        [  3937,   2696],
                        [  4392,   3115],
                        [  4825,   3512],
                        [  5234,   3887],
                        [  5620,   4240],
                        [  5984,   4570],
                        [  6325,   4880],
                        [  6643,   5168],
                        [  6937,   5435],
                        [  7209,   5683],
                        [  7460,   5912],
                        [  7688,   6120],
                        [  7891,   6307],
                        [  8075,   6480],
                        [  8229,   6627],
                        [  8312,   6706],
                        [  8307,   6702],
                        [  8218,   6615],
                        [  8040,   6441],
                        [  7737,   6143],
                        [  7267,   5680],
                        [  6661,   5081],
                        [  6001,   4425],
                        [  5312,   3737],
                        [  4599,   3021],
                        [  3876,   2293],
                        [  3163,   1571],
                        [  2467,    863],
                        [  1795,    183],
                        [  1158,   -462],
                        [   561,  -1060],
                        [     9,  -1609],
                        [  -494,  -2103],
                        [  -943,  -2540],
                        [ -1337,  -2918],
                        [ -1676,  -3235],
                        [ -1961,  -3494],
                        [ -2192,  -3694],
                        [ -2374,  -3839],
                        [ -2507,  -3930],
                        [ -2598,  -3972],
                        [ -2650,  -3967],
                        [ -2666,  -3922],
                        [ -2652,  -3841],
                        [ -2613,  -3730],
                        [ -2554,  -3593],
                        [ -2479,  -3436],
                        [ -2393,  -3264],
                        [ -2301,  -3082],
                        [ -2207,  -2895],
                        [ -2116,  -2706],
                        [ -2031,  -2521],
                        [ -1957,  -2344],
                        [ -1896,  -2177],
                        [ -1849,  -2028],
                        [ -1819,  -1900],
                        [ -1808,  -1807],
                        [ -1817,  -1749],
                        [ -1847,  -1731],
                        [ -1898,  -1755],
                        [ -1969,  -1817],
                        [ -2061,  -1918],
                        [ -2172,  -2040],
                        [ -2301,  -2183],
                        [ -2446,  -2340],
                        [ -2607,  -2510],
                        [ -2781,  -2688],
                        [ -2967,  -2872],
                        [ -3162,  -3057],
                        [ -3365,  -3239],
                        [ -3574,  -3415],
                        [ -3787,  -3582],
                        [ -4002,  -3741],
                        [ -4217,  -3891],
                        [ -4429,  -4036],
                        [ -4636,  -4172],
                        [ -4834,  -4300],
                        [ -5023,  -4418],
                        [ -5189,  -4522],
                        [ -5331,  -4611],
                        [ -5442,  -4687],
                        [ -5521,  -4750],
                        [ -5563,  -4800],
                        [ -5570,  -4839],
                        [ -5553,  -4869],
                        [ -5512,  -4887],
                        [ -5456,  -4893],
                        [ -5386,  -4886],
                        [ -5285,  -4847],
                        [ -5153,  -4777],
                        [ -4942,  -4625],
                        [ -4656,  -4393],
                        [ -4288,  -4074],
                        [ -3838,  -3668],
                        [ -3334,  -3200],
                        [ -2775,  -2670],
                        [ -2248,  -2166],
                        [ -1751,  -1684],
                        [ -1301,  -1243],
                        [  -899,   -845],
                        [  -549,   -496],
                        [  -256,   -198],
                        [   -17,     47],
                        [   163,    238],
                        [   287,    375],
                        [   350,    456],
                        [   356,    484],
                        [   303,    458],
                        [   203,    384],
                        [    53,    258],
                        [  -133,     87],
                        [  -358,   -129],
                        [  -613,   -384],
                        [  -899,   -678],
                        [ -1220,  -1006],
                        [ -1574,  -1366],
                        [ -1961,  -1753],
                        [ -2382,  -2165],
                        [ -2828,  -2596],
                        [ -3297,  -3045],
                        [ -3783,  -3506],
                        [ -4284,  -3978],
                        [ -4793,  -4455],
                        [ -5307,  -4934],
                        [ -5821,  -5410],
                        [ -6331,  -5882],
                        [ -6831,  -6344],
                        [ -7318,  -6793],
                        [ -7786,  -7226],
                        [ -8234,  -7641],
                        [ -8655,  -8032],
                        [ -9047,  -8395],
                        [ -9406,  -8728],
                        [ -9729,  -9029],
                        [-10010,  -9294],
                        [-10246,  -9519],
                        [-10438,  -9706],
                        [-10574,  -9843],
                        [-10636,  -9914],
                        [-10628,  -9918],
                        [-10557,  -9865],
                        [-10413,  -9744],
                        [-10164,  -9520],
                        [ -9761,  -9146],
                        [ -9208,  -8621],
                        [ -8552,  -7995],
                        [ -7815,  -7288],
                        [ -7004,  -6505],
                        [ -6138,  -5665],
                        [ -5233,  -4783],
                        [ -4304,  -3876],
                        [ -3362,  -2955],
                        [ -2420,  -2035],
                        [ -1489,  -1129],
                        [  -582,   -246],
                        [   294,    604],
                        [  1130,   1412],
                        [  1918,   2173],
                        [  2650,   2877],
                        [  3323,   3522],
                        [  3932,   4102],
                        [  4474,   4614],
                        [  4947,   5055],
                        [  5350,   5422],
                        [  5682,   5717],
                        [  5943,   5939],
                        [  6135,   6089],
                        [  6259,   6170],
                        [  6317,   6185],
                        [  6312,   6135],
                        [  6246,   6025],
                        [  6123,   5857],
                        [  5948,   5636],
                        [  5724,   5367],
                        [  5458,   5054],
                        [  5150,   4700],
                        [  4808,   4314],
                        [  4436,   3897],
                        [  4039,   3465],
                        [  3621,   3022],
                        [  3186,   2578],
                        [  2740,   2139],
                        [  2287,   1710],
                        [  1832,   1298],
                        [  1380,    899],
                        [   933,    514],
                        [   496,    139],
                        [    74,   -223],
                        [  -332,   -572],
                        [  -717,   -905],
                        [ -1077,  -1223],
                        [ -1412,  -1523],
                        [ -1717,  -1809],
                        [ -1990,  -2080],
                        [ -2228,  -2331],
                        [ -2430,  -2561],
                        [ -2594,  -2762],
                        [ -2719,  -2932],
                        [ -2803,  -3067],
                        [ -2846,  -3166],
                        [ -2854,  -3228],
                        [ -2824,  -3255],
                        [ -2767,  -3245],
                        [ -2681,  -3200],
                        [ -2573,  -3118],
                        [ -2444,  -3001],
                        [ -2294,  -2845],
                        [ -2121,  -2650],
                        [ -1919,  -2420],
                        [ -1689,  -2160],
                        [ -1436,  -1875],
                        [ -1159,  -1567],
                        [  -907,  -1282],
                        [  -677,  -1022],
                        [  -498,   -817],
                        [  -371,   -664],
                        [  -303,   -575],
                        [  -296,   -550],
                        [  -290,   -532],
                        [  -293,   -528],
                        [  -256,   -488],
                        [  -182,   -414],
                        [   -71,   -306],
                        [    76,   -166],
                        [   259,     11],
                        [   478,    223],
                        [   730,    466],
                        [  1016,    742],
                        [  1333,   1045],
                        [  1680,   1376],
                        [  2049,   1730],
                        [  2441,   2104],
                        [  2839,   2495],
                        [  3246,   2902],
                        [  3651,   3318],
                        [  4057,   3744],
                        [  4460,   4174],
                        [  4860,   4606],
                        [  5266,   5038],
                        [  5676,   5468],
                        [  6087,   5892],
                        [  6500,   6311],
                        [  6910,   6719],
                        [  7318,   7119],
                        [  7720,   7506],
                        [  8117,   7880],
                        [  8504,   8242],
                        [  8884,   8588],
                        [  9252,   8920],
                        [  9609,   9237],
                        [  9952,   9536],
                        [ 10281,   9819],
                        [ 10594,  10085],
                        [ 10891,  10333],
                        [ 11170,  10562],
                        [ 11434,  10772],
                        [ 11676,  10963],
                        [ 11897,  11134],
                        [ 12093,  11282],
                        [ 12265,  11409],
                        [ 12409,  11512],
                        [ 12535,  11603],
                        [ 12666,  11702],
                        [ 12810,  11817],
                        [ 12959,  11941],
                        [ 13080,  12040],
                        [ 13117,  12057],
                        [ 13039,  11961],
                        [ 12864,  11770],
                        [ 12604,  11496],
                        [ 12262,  11143],
                        [ 11854,  10725],
                        [ 11393,  10253],
                        [ 10888,   9737],
                        [ 10347,   9188],
                        [  9783,   8616],
                        [  9202,   8031],
                        [  8612,   7440],
                        [  8019,   6849],
                        [  7430,   6267],
                        [  6852,   5696],
                        [  6286,   5141],
                        [  5737,   4606],
                        [  5207,   4093],
                        [  4699,   3608],
                        [  4213,   3148],
                        [  3749,   2719],
                        [  3307,   2316],
                        [  2888,   1943],
                        [  2489,   1596],
                        [  2110,   1272],
                        [  1750,    972],
                        [  1408,    692],
                        [  1081,    431],
                        [   767,    187],
                        [   466,    -43],
                        [   175,   -261],
                        [  -108,   -469],
                        [  -381,   -666],
                        [  -648,   -856],
                        [  -909,  -1044],
                        [ -1164,  -1229],
                        [ -1415,  -1419],
                        [ -1659,  -1614],
                        [ -1899,  -1817],
                        [ -2134,  -2028],
                        [ -2362,  -2251],
                        [ -2585,  -2482],
                        [ -2800,  -2711],
                        [ -3007,  -2940],
                        [ -3205,  -3161],
                        [ -3391,  -3373],
                        [ -3565,  -3570],
                        [ -3726,  -3753],
                        [ -3872,  -3911],
                        [ -4003,  -4046],
                        [ -4116,  -4151],
                        [ -4211,  -4227],
                        [ -4289,  -4275],
                        [ -4349,  -4297],
                        [ -4392,  -4299],
                        [ -4416,  -4280],
                        [ -4422,  -4244],
                        [ -4409,  -4189],
                        [ -4373,  -4114],
                        [ -4314,  -4019],
                        [ -4228,  -3907],
                        [ -4119,  -3778],
                        [ -3980,  -3634],
                        [ -3816,  -3479],
                        [ -3634,  -3317],
                        [ -3433,  -3146],
                        [ -3220,  -2966],
                        [ -2997,  -2780],
                        [ -2746,  -2568],
                        [ -2472,  -2332],
                        [ -2139,  -2038],
                        [ -1750,  -1688],
                        [ -1302,  -1276],
                        [  -794,   -803],
                        [  -242,   -280],
                        [   353,    290],
                        [   919,    836],
                        [  1458,   1359],
                        [  1953,   1844],
                        [  2404,   2288],
                        [  2800,   2680],
                        [  3140,   3021],
                        [  3421,   3304],
                        [  3642,   3530],
                        [  3799,   3695],
                        [  3893,   3800],
                        [  3924,   3846],
                        [  3891,   3832],
                        [  3808,   3763],
                        [  3673,   3638],
                        [  3499,   3464],
                        [  3284,   3239],
                        [  3037,   2974],
                        [  2758,   2667],
                        [  2446,   2328],
                        [  2104,   1958],
                        [  1731,   1564],
                        [  1330,   1151],
                        [   912,    723],
                        [   477,    287],
                        [    33,   -153],
                        [  -415,   -593],
                        [  -862,  -1025],
                        [ -1302,  -1446],
                        [ -1731,  -1851],
                        [ -2143,  -2237],
                        [ -2533,  -2598],
                        [ -2897,  -2932],
                        [ -3231,  -3233],
                        [ -3532,  -3499],
                        [ -3795,  -3728],
                        [ -4019,  -3915],
                        [ -4198,  -4058],
                        [ -4333,  -4158],
                        [ -4418,  -4209],
                        [ -4453,  -4212],
                        [ -4434,  -4166],
                        [ -4367,  -4077],
                        [ -4292,  -3985],
                        [ -4247,  -3926],
                        [ -4243,  -3912],
                        [ -4273,  -3934],
                        [ -4313,  -3970],
                        [ -4301,  -3955],
                        [ -4177,  -3829],
                        [ -3933,  -3587],
                        [ -3584,  -3240],
                        [ -3134,  -2796],
                        [ -2602,  -2268],
                        [ -1998,  -1669],
                        [ -1338,  -1013],
                        [  -636,   -310],
                        [    95,    422],
                        [   842,   1172],
                        [  1594,   1929],
                        [  2340,   2682],
                        [  3070,   3421],
                        [  3772,   4136],
                        [  4443,   4821],
                        [  5072,   5466],
                        [  5653,   6065],
                        [  6182,   6611],
                        [  6655,   7100],
                        [  7070,   7528],
                        [  7423,   7893],
                        [  7714,   8193],
                        [  7944,   8431],
                        [  8113,   8604],
                        [  8222,   8717],
                        [  8274,   8771],
                        [  8271,   8769],
                        [  8217,   8716],
                        [  8115,   8613],
                        [  7971,   8467],
                        [  7789,   8283],
                        [  7572,   8062],
                        [  7326,   7813],
                        [  7057,   7538],
                        [  6768,   7249],
                        [  6466,   6948],
                        [  6156,   6644],
                        [  5842,   6341],
                        [  5529,   6048],
                        [  5223,   5770],
                        [  4925,   5510],
                        [  4643,   5271],
                        [  4377,   5051],
                        [  4132,   4853],
                        [  3910,   4678],
                        [  3712,   4526],
                        [  3542,   4395],
                        [  3399,   4284],
                        [  3286,   4189],
                        [  3203,   4112],
                        [  3151,   4054],
                        [  3131,   4015],
                        [  3145,   4002],
                        [  3194,   4015],
                        [  3274,   4059],
                        [  3389,   4136],
                        [  3533,   4239],
                        [  3706,   4368],
                        [  3903,   4523],
                        [  4125,   4701],
                        [  4364,   4900],
                        [  4617,   5117],
                        [  4879,   5354],
                        [  5150,   5611],
                        [  5428,   5881],
                        [  5710,   6161],
                        [  5990,   6443],
                        [  6268,   6728],
                        [  6509,   6979],
                        [  6713,   7197],
                        [  6867,   7366],
                        [  6967,   7486],
                        [  7001,   7537],
                        [  6966,   7521],
                        [  6900,   7473],
                        [  6799,   7387],
                        [  6701,   7303],
                        [  6601,   7216],
                        [  6508,   7135],
                        [  6420,   7057],
                        [  6347,   6993],
                        [  6286,   6940],
                        [  6242,   6905],
                        [  6217,   6885],
                        [  6213,   6884],
                        [  6229,   6901],
                        [  6264,   6939],
                        [  6319,   6995],
                        [  6383,   7071],
                        [  6459,   7165],
                        [  6543,   7278],
                        [  6636,   7406],
                        [  6738,   7550],
                        [  6851,   7707],
                        [  6981,   7877],
                        [  7130,   8058],
                        [  7292,   8247],
                        [  7472,   8445],
                        [  7664,   8647],
                        [  7868,   8853],
                        [  8082,   9060],
                        [  8305,   9268],
                        [  8532,   9475],
                        [  8764,   9678],
                        [  8998,   9876],
                        [  9232,  10068],
                        [  9461,  10251],
                        [  9686,  10424],
                        [  9903,  10584],
                        [ 10112,  10731],
                        [ 10307,  10861],
                        [ 10490,  10974],
                        [ 10654,  11066],
                        [ 10799,  11139],
                        [ 10918,  11188],
                        [ 11007,  11208],
                        [ 11085,  11222],
                        [ 11214,  11291],
                        [ 11437,  11457],
                        [ 11761,  11728],
                        [ 12180,  12098],
                        [ 12673,  12545],
                        [ 13166,  12995],
                        [ 13561,  13353],
                        [ 13830,  13587],
                        [ 13975,  13706],
                        [ 14000,  13711],
                        [ 13912,  13608],
                        [ 13720,  13404],
                        [ 13431,  13106],
                        [ 13054,  12721],
                        [ 12599,  12260],
                        [ 12076,  11730],
                        [ 11493,  11141],
                        [ 10857,  10500],
                        [ 10178,   9815],
                        [  9463,   9094],
                        [  8719,   8345],
                        [  7954,   7576],
                        [  7174,   6792],
                        [  6385,   6003],
                        [  5593,   5212],
                        [  4804,   4428],
                        [  4019,   3653],
                        [  3245,   2893],
                        [  2485,   2151],
                        [  1741,   1428],
                        [  1017,    727],
                        [   314,     50],
                        [  -366,   -603],
                        [ -1019,  -1229],
                        [ -1646,  -1829],
                        [ -2244,  -2399],
                        [ -2815,  -2941],
                        [ -3354,  -3454],
                        [ -3863,  -3937],
                        [ -4341,  -4388],
                        [ -4788,  -4810],
                        [ -5203,  -5202],
                        [ -5587,  -5563],
                        [ -5938,  -5897],
                        [ -6257,  -6202],
                        [ -6546,  -6485],
                        [ -6802,  -6745],
                        [ -7027,  -6980],
                        [ -7222,  -7193],
                        [ -7383,  -7379],
                        [ -7515,  -7541],
                        [ -7614,  -7672],
                        [ -7681,  -7774],
                        [ -7718,  -7838],
                        [ -7723,  -7866],
                        [ -7698,  -7855],
                        [ -7645,  -7807],
                        [ -7566,  -7728],
                        [ -7463,  -7616],
                        [ -7339,  -7484],
                        [ -7198,  -7332],
                        [ -7040,  -7163],
                        [ -6867,  -6979],
                        [ -6685,  -6781],
                        [ -6495,  -6571],
                        [ -6297,  -6349],
                        [ -6095,  -6118],
                        [ -5882,  -5879],
                        [ -5663,  -5638],
                        [ -5437,  -5397],
                        [ -5205,  -5156],
                        [ -4968,  -4916],
                        [ -4730,  -4679],
                        [ -4479,  -4435],
                        [ -4221,  -4186],
                        [ -3941,  -3920],
                        [ -3642,  -3638],
                        [ -3318,  -3333],
                        [ -2970,  -3005],
                        [ -2592,  -2646],
                        [ -2186,  -2260],
                        [ -1793,  -1884],
                        [ -1412,  -1519],
                        [ -1055,  -1178],
                        [  -724,   -860],
                        [  -428,   -576],
                        [  -168,   -326],
                        [    50,   -117],
                        [   228,     52],
                        [   359,    177],
                        [   446,    260],
                        [   488,    298],
                        [   487,    294],
                        [   450,    249],
                        [   379,    164],
                        [   280,     43],
                        [   156,   -111],
                        [    11,   -294],
                        [  -151,   -504],
                        [  -332,   -732],
                        [  -531,   -979],
                        [  -746,  -1236],
                        [  -973,  -1500],
                        [ -1206,  -1765],
                        [ -1442,  -2029],
                        [ -1676,  -2283],
                        [ -1905,  -2527],
                        [ -2124,  -2754],
                        [ -2329,  -2961],
                        [ -2515,  -3144],
                        [ -2680,  -3302],
                        [ -2821,  -3428],
                        [ -2934,  -3523],
                        [ -3018,  -3583],
                        [ -3069,  -3607],
                        [ -3088,  -3592],
                        [ -3073,  -3540],
                        [ -3021,  -3447],
                        [ -2933,  -3315],
                        [ -2808,  -3145],
                        [ -2645,  -2936],
                        [ -2438,  -2685],
                        [ -2227,  -2431],
                        [ -2098,  -2261],
                        [ -2097,  -2223],
                        [ -2236,  -2325],
                        [ -2515,  -2569],
                        [ -2927,  -2945],
                        [ -3391,  -3376],
                        [ -3789,  -3742],
                        [ -4078,  -4002],
                        [ -4265,  -4166],
                        [ -4355,  -4237],
                        [ -4353,  -4220],
                        [ -4268,  -4123],
                        [ -4110,  -3951],
                        [ -3889,  -3714],
                        [ -3616,  -3422],
                        [ -3301,  -3083],
                        [ -2953,  -2708],
                        [ -2582,  -2306],
                        [ -2195,  -1883],
                        [ -1801,  -1450],
                        [ -1408,  -1013],
                        [ -1022,   -579],
                        [  -650,   -158],
                        [  -298,    245],
                        [    31,    625],
                        [   332,    977],
                        [   605,   1297],
                        [   845,   1584],
                        [  1052,   1835],
                        [  1227,   2051],
                        [  1368,   2233],
                        [  1479,   2381],
                        [  1558,   2498],
                        [  1610,   2586],
                        [  1636,   2648],
                        [  1639,   2685],
                        [  1623,   2702],
                        [  1588,   2702],
                        [  1542,   2685],
                        [  1486,   2657],
                        [  1424,   2619],
                        [  1359,   2574],
                        [  1297,   2524],
                        [  1238,   2472],
                        [  1188,   2426],
                        [  1149,   2389],
                        [  1122,   2368],
                        [  1111,   2367],
                        [  1115,   2386],
                        [  1138,   2430],
                        [  1178,   2494],
                        [  1237,   2580],
                        [  1314,   2680],
                        [  1408,   2797],
                        [  1518,   2922],
                        [  1644,   3057],
                        [  1785,   3199],
                        [  1942,   3350],
                        [  2115,   3513],
                        [  2302,   3686],
                        [  2504,   3874],
                        [  2719,   4076],
                        [  2949,   4286],
                        [  3192,   4504],
                        [  3447,   4726],
                        [  3715,   4951],
                        [  3986,   5174],
                        [  4260,   5392],
                        [  4524,   5605],
                        [  4778,   5813],
                        [  5013,   6009],
                        [  5228,   6193],
                        [  5419,   6360],
                        [  5586,   6510],
                        [  5721,   6633],
                        [  5822,   6732],
                        [  5890,   6801],
                        [  5923,   6841],
                        [  5900,   6830],
                        [  5822,   6766],
                        [  5692,   6653],
                        [  5510,   6489],
                        [  5300,   6298],
                        [  5059,   6076],
                        [  4799,   5835],
                        [  4521,   5575],
                        [  4236,   5307],
                        [  3944,   5032],
                        [  3656,   4760],
                        [  3372,   4492],
                        [  3100,   4234],
                        [  2840,   3986],
                        [  2595,   3756],
                        [  2367,   3543],
                        [  2155,   3350],
                        [  1959,   3179],
                        [  1781,   3031],
                        [  1622,   2907],
                        [  1481,   2806],
                        [  1361,   2728],
                        [  1268,   2673],
                        [  1200,   2639],
                        [  1158,   2624],
                        [  1141,   2630],
                        [  1146,   2651],
                        [  1175,   2688],
                        [  1223,   2737],
                        [  1290,   2797],
                        [  1372,   2867],
                        [  1468,   2941],
                        [  1575,   3019],
                        [  1688,   3100],
                        [  1806,   3177],
                        [  1927,   3250],
                        [  2045,   3315],
                        [  2160,   3371],
                        [  2267,   3414],
                        [  2363,   3441],
                        [  2442,   3449],
                        [  2507,   3440],
                        [  2546,   3406],
                        [  2555,   3343],
                        [  2584,   3304],
                        [  2728,   3382],
                        [  3025,   3616],
                        [  3482,   4013],
                        [  4101,   4575],
                        [  4877,   5298],
                        [  5721,   6091],
                        [  6489,   6813],
                        [  7125,   7410],
                        [  7632,   7887],
                        [  8009,   8243],
                        [  8253,   8474],
                        [  8369,   8583],
                        [  8359,   8573],
                        [  8234,   8445],
                        [  7998,   8206],
                        [  7661,   7864],
                        [  7230,   7425],
                        [  6714,   6898],
                        [  6120,   6291],
                        [  5458,   5613],
                        [  4737,   4872],
                        [  3966,   4079],
                        [  3153,   3242],
                        [  2310,   2373],
                        [  1443,   1479],
                        [   561,    570],
                        [  -328,   -347],
                        [ -1218,  -1263],
                        [ -2102,  -2173],
                        [ -2975,  -3070],
                        [ -3829,  -3948],
                        [ -4661,  -4804],
                        [ -5465,  -5635],
                        [ -6237,  -6435],
                        [ -6974,  -7201],
                        [ -7672,  -7931],
                        [ -8328,  -8621],
                        [ -8941,  -9270],
                        [ -9509,  -9874],
                        [-10031, -10430],
                        [-10506, -10938],
                        [-10933, -11390],
                        [-11313, -11790],
                        [-11646, -12134],
                        [-11933, -12424],
                        [-12175, -12669],
                        [-12372, -12868],
                        [-12526, -13031],
                        [-12637, -13159],
                        [-12707, -13254],
                        [-12738, -13317],
                        [-12730, -13346],
                        [-12685, -13342],
                        [-12603, -13301],
                        [-12487, -13227],
                        [-12340, -13117],
                        [-12165, -12976],
                        [-11966, -12807],
                        [-11746, -12613],
                        [-11510, -12404],
                        [-11263, -12182],
                        [-11009, -11950],
                        [-10753, -11711],
                        [-10504, -11468],
                        [-10264, -11222],
                        [-10037, -10974],
                        [ -9824, -10726],
                        [ -9617, -10477],
                        [ -9419, -10232],
                        [ -9223,  -9992],
                        [ -9026,  -9757],
                        [ -8829,  -9530],
                        [ -8635,  -9310],
                        [ -8448,  -9102],
                        [ -8267,  -8908],
                        [ -8105,  -8739],
                        [ -7961,  -8594],
                        [ -7824,  -8463],
                        [ -7698,  -8347],
                        [ -7551,  -8214],
                        [ -7386,  -8066],
                        [ -7207,  -7905],
                        [ -7011,  -7729],
                        [ -6810,  -7550],
                        [ -6602,  -7363],
                        [ -6395,  -7180],
                        [ -6190,  -6998],
                        [ -5993,  -6825],
                        [ -5801,  -6658],
                        [ -5622,  -6505],
                        [ -5452,  -6362],
                        [ -5294,  -6234],
                        [ -5148,  -6117],
                        [ -5013,  -6017],
                        [ -4886,  -5926],
                        [ -4767,  -5850],
                        [ -4654,  -5783],
                        [ -4542,  -5726],
                        [ -4431,  -5675],
                        [ -4323,  -5627],
                        [ -4214,  -5583],
                        [ -4106,  -5536],
                        [ -3998,  -5486],
                        [ -3887,  -5430],
                        [ -3771,  -5365],
                        [ -3648,  -5288],
                        [ -3518,  -5198],
                        [ -3378,  -5093],
                        [ -3228,  -4972],
                        [ -3066,  -4830],
                        [ -2889,  -4669],
                        [ -2700,  -4488],
                        [ -2497,  -4287],
                        [ -2278,  -4063],
                        [ -2048,  -3817],
                        [ -1803,  -3551],
                        [ -1546,  -3265],
                        [ -1276,  -2959],
                        [  -994,  -2636],
                        [  -704,  -2300],
                        [  -401,  -1947],
                        [   -84,  -1578],
                        [   175,  -1267],
                        [   277,  -1110],
                        [   182,  -1149],
                        [  -116,  -1391],
                        [  -631,  -1848],
                        [ -1370,  -2529],
                        [ -2241,  -3339],
                        [ -3092,  -4132],
                        [ -3867,  -4852],
                        [ -4570,  -5508],
                        [ -5199,  -6094],
                        [ -5747,  -6606],
                        [ -6215,  -7043],
                        [ -6606,  -7404],
                        [ -6925,  -7692],
                        [ -7176,  -7908],
                        [ -7365,  -8056],
                        [ -7494,  -8141],
                        [ -7570,  -8167],
                        [ -7597,  -8139],
                        [ -7581,  -8063],
                        [ -7525,  -7943],
                        [ -7435,  -7785],
                        [ -7317,  -7597],
                        [ -7177,  -7382],
                        [ -7016,  -7145],
                        [ -6840,  -6892],
                        [ -6650,  -6628],
                        [ -6451,  -6353],
                        [ -6243,  -6072],
                        [ -6030,  -5787],
                        [ -5810,  -5498],
                        [ -5588,  -5208],
                        [ -5363,  -4914],
                        [ -5134,  -4618],
                        [ -4904,  -4322],
                        [ -4672,  -4022],
                        [ -4437,  -3721],
                        [ -4200,  -3418],
                        [ -3959,  -3115],
                        [ -3712,  -2811],
                        [ -3461,  -2512],
                        [ -3205,  -2217],
                        [ -2941,  -1931],
                        [ -2670,  -1653],
                        [ -2392,  -1380],
                        [ -2106,  -1112],
                        [ -1814,   -837],
                        [ -1512,   -556],
                        [ -1206,   -262],
                        [  -894,     45],
                        [  -579,    360],
                        [  -262,    685],
                        [    52,   1011],
                        [   365,   1339],
                        [   671,   1662],
                        [   971,   1982],
                        [  1263,   2291],
                        [  1547,   2591],
                        [  1823,   2882],
                        [  2090,   3163],
                        [  2349,   3436],
                        [  2598,   3699],
                        [  2845,   3951],
                        [  3088,   4189],
                        [  3330,   4411],
                        [  3572,   4617],
                        [  3804,   4799],
                        [  4027,   4958],
                        [  4224,   5092],
                        [  4396,   5200],
                        [  4534,   5281],
                        [  4635,   5334],
                        [  4705,   5363],
                        [  4743,   5367],
                        [  4772,   5371],
                        [  4790,   5371],
                        [  4806,   5378],
                        [  4821,   5392],
                        [  4809,   5383],
                        [  4772,   5355],
                        [  4677,   5273],
                        [  4526,   5140],
                        [  4331,   4962],
                        [  4088,   4739],
                        [  3811,   4483],
                        [  3502,   4194],
                        [  3172,   3885],
                        [  2822,   3556],
                        [  2463,   3218],
                        [  2095,   2872],
                        [  1730,   2529],
                        [  1367,   2187],
                        [  1014,   1857],
                        [   673,   1538],
                        [   349,   1237],
                        [    44,    953],
                        [  -242,    691],
                        [  -508,    451],
                        [  -754,    235],
                        [  -980,     41],
                        [ -1183,   -129],
                        [ -1363,   -279],
                        [ -1519,   -407],
                        [ -1655,   -515],
                        [ -1770,   -608],
                        [ -1865,   -685],
                        [ -1944,   -750],
                        [ -2008,   -804],
                        [ -2060,   -853],
                        [ -2103,   -898],
                        [ -2140,   -943],
                        [ -2173,   -989],
                        [ -2205,  -1041],
                        [ -2240,  -1100],
                        [ -2281,  -1172],
                        [ -2328,  -1256],
                        [ -2386,  -1356],
                        [ -2459,  -1476],
                        [ -2549,  -1615],
                        [ -2652,  -1773],
                        [ -2783,  -1958],
                        [ -2937,  -2168],
                        [ -3040,  -2327],
                        [ -3001,  -2342],
                        [ -2792,  -2185],
                        [ -2408,  -1853],
                        [ -1832,  -1327],
                        [ -1051,   -596],
                        [  -161,    248],
                        [   687,   1051],
                        [  1432,   1760],
                        [  2083,   2381],
                        [  2629,   2907],
                        [  3062,   3330],
                        [  3381,   3644],
                        [  3585,   3851],
                        [  3681,   3949],
                        [  3670,   3937],
                        [  3560,   3823],
                        [  3356,   3608],
                        [  3064,   3302],
                        [  2689,   2909],
                        [  2243,   2438],
                        [  1731,   1896],
                        [  1163,   1293],
                        [   548,    637],
                        [  -106,    -61],
                        [  -787,   -792],
                        [ -1489,  -1547],
                        [ -2203,  -2316],
                        [ -2920,  -3092],
                        [ -3635,  -3868],
                        [ -4341,  -4635],
                        [ -5030,  -5388],
                        [ -5698,  -6121],
                        [ -6339,  -6830],
                        [ -6948,  -7509],
                        [ -7521,  -8156],
                        [ -8053,  -8765],
                        [ -8543,  -9336],
                        [ -8989,  -9862],
                        [ -9389, -10344],
                        [ -9743, -10773],
                        [-10050, -11152],
                        [-10310, -11468],
                        [-10524, -11725],
                        [-10693, -11920],
                        [-10818, -12053],
                        [-10901, -12135],
                        [-10944, -12167],
                        [-10948, -12165],
                        [-10917, -12130],
                        [-10851, -12069],
                        [-10753, -11985],
                        [-10624, -11876],
                        [-10467, -11746],
                        [-10283, -11596],
                        [-10075, -11427],
                        [ -9846, -11240],
                        [ -9600, -11038],
                        [ -9341, -10822],
                        [ -9072, -10594],
                        [ -8800, -10363],
                        [ -8527, -10129],
                        [ -8262,  -9897],
                        [ -8008,  -9668],
                        [ -7776,  -9445],
                        [ -7568,  -9230],
                        [ -7386,  -9021],
                        [ -7231,  -8820],
                        [ -7092,  -8622],
                        [ -6970,  -8431],
                        [ -6849,  -8245],
                        [ -6731,  -8066],
                        [ -6612,  -7893],
                        [ -6494,  -7727],
                        [ -6398,  -7590],
                        [ -6323,  -7482],
                        [ -6296,  -7431],
                        [ -6315,  -7434],
                        [ -6368,  -7478],
                        [ -6457,  -7567],
                        [ -6528,  -7643],
                        [ -6583,  -7709],
                        [ -6593,  -7735],
                        [ -6558,  -7720],
                        [ -6486,  -7671],
                        [ -6373,  -7582],
                        [ -6226,  -7462],
                        [ -6043,  -7308],
                        [ -5831,  -7127],
                        [ -5586,  -6917],
                        [ -5317,  -6685],
                        [ -5020,  -6429],
                        [ -4704,  -6156],
                        [ -4367,  -5862],
                        [ -4018,  -5555],
                        [ -3654,  -5233],
                        [ -3280,  -4900],
                        [ -2894,  -4556],
                        [ -2496,  -4202],
                        [ -2084,  -3839],
                        [ -1662,  -3469],
                        [ -1229,  -3092],
                        [  -789,  -2707],
                        [  -343,  -2316],
                        [   108,  -1919],
                        [   563,  -1517],
                        [  1020,  -1111],
                        [  1476,   -700],
                        [  1932,   -284],
                        [  2386,    132],
                        [  2834,    553],
                        [  3278,    973],
                        [  3714,   1393],
                        [  4141,   1811],
                        [  4557,   2228],
                        [  4962,   2639],
                        [  5351,   3044],
                        [  5725,   3441],
                        [  6082,   3829],
                        [  6419,   4205],
                        [  6732,   4563],
                        [  7029,   4911],
                        [  7300,   5237],
                        [  7464,   5460],
                        [  7441,   5500],
                        [  7209,   5334],
                        [  6766,   4959],
                        [  6082,   4346],
                        [  5140,   3477],
                        [  4028,   2439],
                        [  2896,   1380],
                        [  1791,    346],
                        [   715,   -665],
                        [  -321,  -1644],
                        [ -1300,  -2573],
                        [ -2217,  -3447],
                        [ -3066,  -4255],
                        [ -3843,  -4996],
                        [ -4548,  -5659],
                        [ -5180,  -6246],
                        [ -5737,  -6753],
                        [ -6218,  -7180],
                        [ -6624,  -7529],
                        [ -6957,  -7799],
                        [ -7217,  -7994],
                        [ -7408,  -8115],
                        [ -7533,  -8167],
                        [ -7595,  -8153],
                        [ -7599,  -8076],
                        [ -7546,  -7941],
                        [ -7440,  -7753],
                        [ -7287,  -7516],
                        [ -7087,  -7232],
                        [ -6846,  -6907],
                        [ -6565,  -6544],
                        [ -6249,  -6145],
                        [ -5902,  -5714],
                        [ -5525,  -5254],
                        [ -5124,  -4769],
                        [ -4701,  -4262],
                        [ -4259,  -3734],
                        [ -3800,  -3192],
                        [ -3327,  -2638],
                        [ -2843,  -2078],
                        [ -2351,  -1521],
                        [ -1851,   -969],
                        [ -1347,   -435],
                        [  -841,     82],
                        [  -336,    579],
                        [   167,   1055],
                        [   665,   1521],
                        [  1156,   1974],
                        [  1637,   2425],
                        [  2106,   2869],
                        [  2558,   3305],
                        [  2992,   3733],
                        [  3404,   4149],
                        [  3794,   4552],
                        [  4154,   4936],
                        [  4488,   5302],
                        [  4794,   5642],
                        [  5071,   5956],
                        [  5320,   6243],
                        [  5541,   6503],
                        [  5738,   6737],
                        [  5909,   6944],
                        [  6066,   7125],
                        [  6209,   7280],
                        [  6343,   7408],
                        [  6468,   7507],
                        [  6580,   7575],
                        [  6678,   7614],
                        [  6745,   7619],
                        [  6784,   7591],
                        [  6785,   7534],
                        [  6751,   7447],
                        [  6695,   7344],
                        [  6616,   7226],
                        [  6563,   7140],
                        [  6533,   7086],
                        [  6538,   7076],
                        [  6581,   7111],
                        [  6634,   7161],
                        [  6699,   7230],
                        [  6713,   7253],
                        [  6681,   7235],
                        [  6601,   7169],
                        [  6472,   7057],
                        [  6305,   6907],
                        [  6099,   6719],
                        [  5863,   6503],
                        [  5598,   6259],
                        [  5311,   5995],
                        [  5003,   5712],
                        [  4685,   5420],
                        [  4357,   5119],
                        [  4029,   4817],
                        [  3703,   4512],
                        [  3387,   4213],
                        [  3081,   3918],
                        [  2784,   3633],
                        [  2498,   3356],
                        [  2217,   3092],
                        [  1944,   2837],
                        [  1678,   2595],
                        [  1419,   2364],
                        [  1168,   2142],
                        [   925,   1929],
                        [   689,   1723],
                        [   458,   1525],
                        [   232,   1329],
                        [    11,   1137],
                        [  -210,    943],
                        [  -428,    749],
                        [  -649,    549],
                        [  -871,    345],
                        [ -1098,    132],
                        [ -1330,    -91],
                        [ -1570,   -326],
                        [ -1815,   -570],
                        [ -2070,   -830],
                        [ -2335,  -1103],
                        [ -2609,  -1389],
                        [ -2889,  -1686],
                        [ -3187,  -2004],
                        [ -3486,  -2325],
                        [ -3716,  -2580],
                        [ -3812,  -2702],
                        [ -3764,  -2682],
                        [ -3566,  -2513],
                        [ -3186,  -2164],
                        [ -2596,  -1606],
                        [ -1873,   -915],
                        [ -1146,   -219],
                        [  -456,    444],
                        [   200,   1077],
                        [   808,   1670],
                        [  1353,   2208],
                        [  1831,   2684],
                        [  2239,   3095],
                        [  2576,   3434],
                        [  2838,   3698],
                        [  3031,   3885],
                        [  3154,   3998],
                        [  3209,   4037],
                        [  3199,   4007],
                        [  3129,   3911],
                        [  3004,   3754],
                        [  2829,   3541],
                        [  2611,   3279],
                        [  2356,   2974],
                        [  2071,   2632],
                        [  1762,   2260],
                        [  1436,   1865],
                        [  1098,   1455],
                        [   754,   1035],
                        [   410,    613],
                        [    70,    191],
                        [  -262,   -224],
                        [  -579,   -629],
                        [  -879,  -1020],
                        [ -1157,  -1392],
                        [ -1412,  -1744],
                        [ -1640,  -2070],
                        [ -1842,  -2370],
                        [ -2014,  -2641],
                        [ -2158,  -2876],
                        [ -2272,  -3076],
                        [ -2357,  -3230],
                        [ -2414,  -3337],
                        [ -2443,  -3395],
                        [ -2447,  -3404],
                        [ -2426,  -3375],
                        [ -2383,  -3307],
                        [ -2319,  -3218],
                        [ -2235,  -3109],
                        [ -2135,  -2991],
                        [ -2019,  -2863],
                        [ -1887,  -2730],
                        [ -1743,  -2594],
                        [ -1587,  -2459],
                        [ -1419,  -2325],
                        [ -1246,  -2189],
                        [ -1067,  -2055],
                        [  -886,  -1920],
                        [  -704,  -1786],
                        [  -529,  -1655],
                        [  -359,  -1529],
                        [  -206,  -1411],
                        [   -68,  -1302],
                        [    42,  -1203],
                        [   126,  -1112],
                        [   182,  -1031],
                        [   212,   -957],
                        [   228,   -886],
                        [   230,   -816],
                        [   237,   -744],
                        [   245,   -674],
                        [   259,   -605],
                        [   280,   -535],
                        [   269,   -505],
                        [   231,   -509],
                        [   132,   -583],
                        [   -24,   -722],
                        [  -229,   -918],
                        [  -483,  -1172],
                        [  -717,  -1413],
                        [  -935,  -1645],
                        [ -1088,  -1817],
                        [ -1177,  -1930],
                        [ -1207,  -1984],
                        [ -1172,  -1979],
                        [ -1078,  -1916],
                        [  -922,  -1794],
                        [  -709,  -1619],
                        [  -436,  -1388],
                        [  -111,  -1109],
                        [   266,   -782],
                        [   682,   -414],
                        [  1138,     -4],
                        [  1622,    438],
                        [  2131,    913],
                        [  2661,   1415],
                        [  3211,   1940],
                        [  3779,   2483],
                        [  4366,   3044],
                        [  4968,   3613],
                        [  5585,   4193],
                        [  6208,   4776],
                        [  6836,   5361],
                        [  7461,   5944],
                        [  8084,   6523],
                        [  8696,   7092],
                        [  9297,   7652],
                        [  9882,   8198],
                        [ 10446,   8727],
                        [ 10989,   9238],
                        [ 11506,   9729],
                        [ 11993,  10195],
                        [ 12449,  10636],
                        [ 12872,  11051],
                        [ 13261,  11435],
                        [ 13609,  11788],
                        [ 13917,  12107],
                        [ 14186,  12393],
                        [ 14408,  12641],
                        [ 14584,  12848],
                        [ 14721,  13023],
                        [ 14802,  13148],
                        [ 14766,  13162],
                        [ 14575,  13024],
                        [ 14226,  12733],
                        [ 13714,  12283],
                        [ 13004,  11637],
                        [ 12067,  10767],
                        [ 10963,   9732],
                        [  9804,   8642],
                        [  8622,   7528],
                        [  7425,   6393],
                        [  6232,   5255],
                        [  5061,   4135],
                        [  3925,   3042],
                        [  2834,   1990],
                        [  1800,    990],
                        [   828,     55],
                        [   -75,   -808],
                        [  -902,  -1595],
                        [ -1649,  -2299],
                        [ -2312,  -2918],
                        [ -2891,  -3448],
                        [ -3382,  -3890],
                        [ -3786,  -4243],
                        [ -4105,  -4506],
                        [ -4340,  -4681],
                        [ -4493,  -4771],
                        [ -4569,  -4779],
                        [ -4569,  -4710],
                        [ -4499,  -4567],
                        [ -4362,  -4357],
                        [ -4162,  -4082],
                        [ -3907,  -3750],
                        [ -3597,  -3364],
                        [ -3241,  -2930],
                        [ -2844,  -2453],
                        [ -2411,  -1939],
                        [ -1948,  -1393],
                        [ -1458,   -821],
                        [  -950,   -229],
                        [  -427,    375],
                        [   108,    987],
                        [   648,   1593],
                        [  1190,   2189],
                        [  1727,   2760],
                        [  2259,   3304],
                        [  2779,   3818],
                        [  3286,   4297],
                        [  3775,   4751],
                        [  4244,   5173],
                        [  4689,   5578],
                        [  5108,   5961],
                        [  5497,   6322],
                        [  5856,   6662],
                        [  6180,   6983],
                        [  6468,   7282],
                        [  6719,   7555],
                        [  6931,   7805],
                        [  7108,   8022],
                        [  7245,   8206],
                        [  7349,   8356],
                        [  7417,   8472],
                        [  7458,   8556],
                        [  7471,   8611],
                        [  7469,   8637],
                        [  7450,   8636],
                        [  7425,   8610],
                        [  7391,   8560],
                        [  7349,   8484],
                        [  7299,   8384],
                        [  7225,   8257],
                        [  7132,   8106],
                        [  7015,   7934],
                        [  6876,   7745],
                        [  6736,   7559],
                        [  6597,   7378],
                        [  6511,   7258],
                        [  6480,   7199],
                        [  6515,   7212],
                        [  6619,   7299],
                        [  6763,   7434],
                        [  6953,   7619],
                        [  7105,   7772],
                        [  7229,   7898],
                        [  7311,   7986],
                        [  7353,   8036],
                        [  7356,   8049],
                        [  7321,   8023],
                        [  7248,   7963],
                        [  7138,   7869],
                        [  6995,   7745],
                        [  6817,   7590],
                        [  6614,   7412],
                        [  6384,   7207],
                        [  6142,   6983],
                        [  5885,   6739],
                        [  5620,   6479],
                        [  5348,   6203],
                        [  5066,   5915],
                        [  4773,   5614],
                        [  4464,   5304],
                        [  4140,   4985],
                        [  3800,   4657],
                        [  3444,   4320],
                        [  3077,   3976],
                        [  2696,   3624],
                        [  2303,   3264],
                        [  1899,   2897],
                        [  1484,   2522],
                        [  1060,   2139],
                        [   627,   1749],
                        [   186,   1351],
                        [  -262,    944],
                        [  -718,    530],
                        [ -1179,    108],
                        [ -1646,   -320],
                        [ -2117,   -755],
                        [ -2589,  -1193],
                        [ -3060,  -1635],
                        [ -3530,  -2079],
                        [ -3993,  -2522],
                        [ -4448,  -2960],
                        [ -4900,  -3400],
                        [ -5328,  -3820],
                        [ -5693,  -4182],
                        [ -5972,  -4462],
                        [ -6169,  -4663],
                        [ -6271,  -4773],
                        [ -6240,  -4754],
                        [ -6035,  -4564],
                        [ -5690,  -4235],
                        [ -5281,  -3845],
                        [ -4833,  -3413],
                        [ -4344,  -2941],
                        [ -3835,  -2444],
                        [ -3316,  -1935],
                        [ -2797,  -1422],
                        [ -2286,   -913],
                        [ -1791,   -420],
                        [ -1317,     51],
                        [  -867,    493],
                        [  -444,    904],
                        [   -52,   1281],
                        [   306,   1621],
                        [   630,   1923],
                        [   921,   2187],
                        [  1178,   2413],
                        [  1403,   2602],
                        [  1599,   2754],
                        [  1767,   2871],
                        [  1909,   2958],
                        [  2029,   3014],
                        [  2128,   3046],
                        [  2210,   3056],
                        [  2276,   3046],
                        [  2329,   3021],
                        [  2372,   2983],
                        [  2406,   2933],
                        [  2434,   2875],
                        [  2459,   2811],
                        [  2481,   2744],
                        [  2504,   2674],
                        [  2528,   2605],
                        [  2552,   2537],
                        [  2578,   2478],
                        [  2607,   2426],
                        [  2637,   2394],
                        [  2670,   2378],
                        [  2704,   2386],
                        [  2741,   2416],
                        [  2777,   2464],
                        [  2814,   2529],
                        [  2850,   2598],
                        [  2886,   2672],
                        [  2921,   2740],
                        [  2953,   2802],
                        [  2986,   2851],
                        [  3016,   2887],
                        [  3045,   2909],
                        [  3073,   2915],
                        [  3099,   2912],
                        [  3124,   2898],
                        [  3147,   2881],
                        [  3167,   2861],
                        [  3183,   2837],
                        [  3196,   2811],
                        [  3196,   2780],
                        [  3187,   2745],
                        [  3161,   2709],
                        [  3119,   2669],
                        [  3062,   2628],
                        [  2991,   2588],
                        [  2917,   2555],
                        [  2843,   2533],
                        [  2782,   2520],
                        [  2732,   2518],
                        [  2693,   2524],
                        [  2670,   2538],
                        [  2614,   2515],
                        [  2531,   2459],
                        [  2391,   2340],
                        [  2197,   2160],
                        [  1951,   1922],
                        [  1652,   1623],
                        [  1370,   1336],
                        [  1101,   1055],
                        [   895,    834],
                        [   751,    671],
                        [   670,    569],
                        [   651,    527],
                        [   697,    547],
                        [   808,    630],
                        [   983,    772],
                        [  1220,    972],
                        [  1513,   1224],
                        [  1861,   1530],
                        [  2249,   1880],
                        [  2676,   2273],
                        [  3128,   2703],
                        [  3603,   3167],
                        [  4096,   3655],
                        [  4604,   4167],
                        [  5126,   4693],
                        [  5662,   5232],
                        [  6208,   5774],
                        [  6763,   6319],
                        [  7317,   6858],
                        [  7867,   7391],
                        [  8405,   7908],
                        [  8932,   8409],
                        [  9438,   8888],
                        [  9921,   9342],
                        [ 10376,   9768],
                        [ 10801,  10162],
                        [ 11190,  10524],
                        [ 11542,  10849],
                        [ 11853,  11135],
                        [ 12122,  11381],
                        [ 12348,  11586],
                        [ 12528,  11748],
                        [ 12660,  11867],
                        [ 12743,  11940],
                        [ 12777,  11969],
                        [ 12757,  11950],
                        [ 12686,  11887],
                        [ 12568,  11780],
                        [ 12391,  11622],
                        [ 12142,  11396],
                        [ 11826,  11108],
                        [ 11451,  10765],
                        [ 11012,  10362],
                        [ 10473,   9861],
                        [  9791,   9222],
                        [  8976,   8450],
                        [  8081,   7599],
                        [  7126,   6689],
                        [  6120,   5726],
                        [  5082,   4728],
                        [  4032,   3714],
                        [  2982,   2696],
                        [  1947,   1689],
                        [   939,    706],
                        [   -29,   -238],
                        [  -951,  -1136],
                        [ -1815,  -1978],
                        [ -2617,  -2757],
                        [ -3349,  -3467],
                        [ -4006,  -4103],
                        [ -4587,  -4662],
                        [ -5090,  -5142],
                        [ -5511,  -5538],
                        [ -5853,  -5851],
                        [ -6117,  -6082],
                        [ -6305,  -6233],
                        [ -6419,  -6307],
                        [ -6462,  -6307],
                        [ -6440,  -6240],
                        [ -6356,  -6108],
                        [ -6216,  -5919],
                        [ -6024,  -5676],
                        [ -5787,  -5386],
                        [ -5509,  -5055],
                        [ -5198,  -4689],
                        [ -4860,  -4293],
                        [ -4499,  -3875],
                        [ -4123,  -3439],
                        [ -3735,  -2994],
                        [ -3342,  -2545],
                        [ -2949,  -2104],
                        [ -2559,  -1675],
                        [ -2179,  -1272],
                        [ -1812,   -895],
                        [ -1461,   -553],
                        [ -1129,   -248],
                        [  -820,     25],
                        [  -534,    262],
                        [  -275,    474],
                        [   -44,    657],
                        [   158,    819],
                        [   329,    959],
                        [   468,   1081],
                        [   575,   1185],
                        [   651,   1269],
                        [   694,   1334],
                        [   707,   1374],
                        [   689,   1389],
                        [   644,   1376],
                        [   573,   1336],
                        [   483,   1273],
                        [   375,   1190],
                        [   258,   1091],
                        [   135,    977],
                        [    11,    850],
                        [  -111,    713],
                        [  -230,    566],
                        [  -345,    411],
                        [  -467,    245],
                        [  -592,     72],
                        [  -721,   -103],
                        [  -851,   -280],
                        [  -960,   -433],
                        [ -1048,   -562],
                        [ -1066,   -618],
                        [ -1017,   -605],
                        [  -891,   -509],
                        [  -687,   -331],
                        [  -423,    -89],
                        [   -99,    217],
                        [   206,    508],
                        [   496,    788],
                        [   759,   1042],
                        [   994,   1271],
                        [  1192,   1465],
                        [  1354,   1625],
                        [  1476,   1748],
                        [  1554,   1831],
                        [  1589,   1876],
                        [  1579,   1880],
                        [  1529,   1844],
                        [  1440,   1769],
                        [  1320,   1654],
                        [  1168,   1501],
                        [   990,   1311],
                        [   782,   1083],
                        [   545,    822],
                        [   275,    527],
                        [   -32,    203],
                        [  -378,   -153],
                        [  -758,   -535],
                        [ -1173,   -944],
                        [ -1619,  -1376],
                        [ -2094,  -1831],
                        [ -2594,  -2303],
                        [ -3120,  -2794],
                        [ -3664,  -3300],
                        [ -4227,  -3818],
                        [ -4802,  -4346],
                        [ -5389,  -4882],
                        [ -5982,  -5423],
                        [ -6580,  -5966],
                        [ -7178,  -6509],
                        [ -7776,  -7048],
                        [ -8366,  -7581],
                        [ -8945,  -8103],
                        [ -9509,  -8613],
                        [-10053,  -9106],
                        [-10571,  -9578],
                        [-11062, -10025],
                        [-11521, -10447],
                        [-11943, -10837],
                        [-12336, -11203],
                        [-12717, -11564],
                        [-13095, -11924],
                        [-13456, -12274],
                        [-13765, -12574],
                        [-13963, -12769],
                        [-14025, -12830],
                        [-13968, -12777],
                        [-13804, -12620],
                        [-13539, -12361],
                        [-13183, -12014],
                        [-12751, -11593],
                        [-12253, -11104],
                        [-11698, -10559],
                        [-11098,  -9969],
                        [-10464,  -9344],
                        [ -9804,  -8694],
                        [ -9124,  -8025],
                        [ -8434,  -7346],
                        [ -7739,  -6663],
                        [ -7047,  -5982],
                        [ -6360,  -5309],
                        [ -5687,  -4651],
                        [ -5029,  -4011],
                        [ -4390,  -3394],
                        [ -3772,  -2804],
                        [ -3179,  -2243],
                        [ -2612,  -1713],
                        [ -2073,  -1214],
                        [ -1562,   -747],
                        [ -1080,   -313],
                        [  -628,     90],
                        [  -206,    461],
                        [   185,    800],
                        [   546,   1107],
                        [   879,   1385],
                        [  1183,   1632],
                        [  1458,   1851],
                        [  1707,   2042],
                        [  1929,   2207],
                        [  2126,   2349],
                        [  2297,   2471],
                        [  2446,   2578],
                        [  2571,   2672],
                        [  2674,   2758],
                        [  2756,   2835],
                        [  2817,   2907],
                        [  2860,   2975],
                        [  2884,   3031],
                        [  2890,   3077],
                        [  2881,   3105],
                        [  2857,   3115],
                        [  2819,   3102],
                        [  2769,   3067],
                        [  2709,   3010],
                        [  2641,   2932],
                        [  2568,   2838],
                        [  2492,   2732],
                        [  2414,   2624],
                        [  2337,   2516],
                        [  2260,   2407],
                        [  2184,   2300],
                        [  2108,   2195],
                        [  2034,   2095],
                        [  1958,   1999],
                        [  1883,   1909],
                        [  1808,   1827],
                        [  1731,   1752],
                        [  1662,   1691],
                        [  1604,   1645],
                        [  1561,   1616],
                        [  1532,   1603],
                        [  1515,   1600],
                        [  1511,   1610],
                        [  1483,   1590],
                        [  1431,   1547],
                        [  1337,   1458],
                        [  1202,   1326],
                        [  1017,   1140],
                        [   783,    902],
                        [   554,    664],
                        [   324,    422],
                        [   137,    220],
                        [   -13,     55],
                        [  -119,    -67],
                        [  -184,   -149],
                        [  -199,   -184],
                        [  -170,   -175],
                        [   -92,   -120],
                        [    33,    -22],
                        [   199,    117],
                        [   405,    295],
                        [   637,    508],
                        [   895,    753],
                        [  1167,   1025],
                        [  1451,   1321],
                        [  1744,   1635],
                        [  2043,   1964],
                        [  2351,   2300],
                        [  2664,   2643],
                        [  2982,   2984],
                        [  3303,   3320],
                        [  3616,   3645],
                        [  3921,   3958],
                        [  4214,   4251],
                        [  4492,   4524],
                        [  4747,   4772],
                        [  4980,   4991],
                        [  5184,   5180],
                        [  5359,   5335],
                        [  5502,   5455],
                        [  5611,   5539],
                        [  5685,   5585],
                        [  5723,   5593],
                        [  5724,   5562],
                        [  5686,   5493],
                        [  5608,   5383],
                        [  5491,   5234],
                        [  5333,   5046],
                        [  5135,   4821],
                        [  4898,   4561],
                        [  4619,   4262],
                        [  4313,   3940],
                        [  4017,   3632],
                        [  3769,   3376],
                        [  3581,   3182],
                        [  3446,   3044],
                        [  3338,   2936],
                        [  3195,   2795],
                        [  2960,   2563],
                        [  2632,   2238],
                        [  2221,   1833],
                        [  1736,   1355],
                        [  1190,    817],
                        [   596,    231],
                        [   -37,   -392],
                        [  -692,  -1040],
                        [ -1359,  -1702],
                        [ -2026,  -2367],
                        [ -2683,  -3024],
                        [ -3322,  -3666],
                        [ -3933,  -4284],
                        [ -4513,  -4872],
                        [ -5054,  -5424],
                        [ -5552,  -5935],
                        [ -6004,  -6401],
                        [ -6406,  -6815],
                        [ -6757,  -7177],
                        [ -7057,  -7484],
                        [ -7306,  -7737],
                        [ -7505,  -7937],
                        [ -7656,  -8085],
                        [ -7762,  -8186],
                        [ -7825,  -8240],
                        [ -7848,  -8253],
                        [ -7834,  -8227],
                        [ -7789,  -8169],
                        [ -7716,  -8080],
                        [ -7620,  -7967],
                        [ -7505,  -7833],
                        [ -7375,  -7682],
                        [ -7235,  -7520],
                        [ -7088,  -7352],
                        [ -6940,  -7179],
                        [ -6792,  -7011],
                        [ -6650,  -6850],
                        [ -6514,  -6702],
                        [ -6389,  -6572],
                        [ -6275,  -6462],
                        [ -6175,  -6376],
                        [ -6089,  -6315],
                        [ -6019,  -6281],
                        [ -5964,  -6265],
                        [ -5925,  -6269],
                        [ -5901,  -6284],
                        [ -5892,  -6309],
                        [ -5898,  -6339],
                        [ -5917,  -6373],
                        [ -5951,  -6411],
                        [ -6004,  -6459],
                        [ -6072,  -6518],
                        [ -6152,  -6587],
                        [ -6243,  -6667],
                        [ -6342,  -6756],
                        [ -6445,  -6849],
                        [ -6550,  -6945],
                        [ -6651,  -7040],
                        [ -6748,  -7131],
                        [ -6834,  -7215],
                        [ -6906,  -7291],
                        [ -6960,  -7355],
                        [ -6996,  -7408],
                        [ -7018,  -7451],
                        [ -7022,  -7482],
                        [ -7010,  -7499],
                        [ -6979,  -7499],
                        [ -6917,  -7468],
                        [ -6825,  -7407],
                        [ -6676,  -7291],
                        [ -6473,  -7120],
                        [ -6209,  -6885],
                        [ -5883,  -6589],
                        [ -5504,  -6235],
                        [ -5070,  -5825],
                        [ -4641,  -5416],
                        [ -4214,  -5008],
                        [ -3807,  -4617],
                        [ -3417,  -4241],
                        [ -3060,  -3896],
                        [ -2736,  -3581],
                        [ -2454,  -3305],
                        [ -2218,  -3072],
                        [ -2031,  -2884],
                        [ -1896,  -2742],
                        [ -1805,  -2649],
                        [ -1763,  -2605],
                        [ -1763,  -2611],
                        [ -1805,  -2665],
                        [ -1887,  -2769],
                        [ -2010,  -2920],
                        [ -2174,  -3116],
                        [ -2381,  -3357],
                        [ -2636,  -3638],
                        [ -2937,  -3958],
                        [ -3278,  -4310],
                        [ -3659,  -4696],
                        [ -4074,  -5108],
                        [ -4526,  -5549],
                        [ -5004,  -6010],
                        [ -5508,  -6488],
                        [ -6028,  -6977],
                        [ -6563,  -7474],
                        [ -7106,  -7973],
                        [ -7655,  -8473],
                        [ -8201,  -8965],
                        [ -8743,  -9449],
                        [ -9272,  -9917],
                        [ -9788, -10367],
                        [-10283, -10793],
                        [-10753, -11194],
                        [-11189, -11562],
                        [-11590, -11897],
                        [-11950, -12193],
                        [-12274, -12456],
                        [-12544, -12669],
                        [-12786, -12859],
                        [-13056, -13082],
                        [-13395, -13379],
                        [-13809, -13756],
                        [-14291, -14207],
                        [-14818, -14705],
                        [-15314, -15176],
                        [-15686, -15527],
                        [-15912, -15734],
                        [-15997, -15806],
                        [-15945, -15745],
                        [-15763, -15561],
                        [-15463, -15263],
                        [-15053, -14860],
                        [-14544, -14359],
                        [-13950, -13774],
                        [-13284, -13114],
                        [-12555, -12391],
                        [-11775, -11613],
                        [-10956, -10793],
                        [-10105,  -9941],
                        [ -9235,  -9065],
                        [ -8352,  -8174],
                        [ -7467,  -7280],
                        [ -6587,  -6391],
                        [ -5719,  -5515],
                        [ -4869,  -4660],
                        [ -4044,  -3831],
                        [ -3248,  -3033],
                        [ -2485,  -2272],
                        [ -1760,  -1549],
                        [ -1075,   -869],
                        [  -431,   -231],
                        [   168,    362],
                        [   723,    911],
                        [  1233,   1413],
                        [  1696,   1870],
                        [  2114,   2280],
                        [  2489,   2646],
                        [  2820,   2966],
                        [  3109,   3246],
                        [  3360,   3485],
                        [  3572,   3686],
                        [  3749,   3851],
                        [  3893,   3984],
                        [  4005,   4089],
                        [  4089,   4167],
                        [  4146,   4228],
                        [  4180,   4273],
                        [  4192,   4305],
                        [  4184,   4326],
                        [  4160,   4330],
                        [  4121,   4321],
                        [  4069,   4293],
                        [  4006,   4249],
                        [  3938,   4190],
                        [  3866,   4119],
                        [  3794,   4041],
                        [  3725,   3959],
                        [  3664,   3883],
                        [  3610,   3816],
                        [  3567,   3756],
                        [  3536,   3707],
                        [  3520,   3669],
                        [  3520,   3644],
                        [  3535,   3632],
                        [  3567,   3633],
                        [  3608,   3647],
                        [  3660,   3673],
                        [  3722,   3712],
                        [  3794,   3768],
                        [  3876,   3837],
                        [  3965,   3917],
                        [  4058,   4004],
                        [  4155,   4098],
                        [  4236,   4177],
                        [  4300,   4243],
                        [  4340,   4287],
                        [  4356,   4307],
                        [  4327,   4284],
                        [  4256,   4217],
                        [  4162,   4128],
                        [  4044,   4015],
                        [  3928,   3903],
                        [  3812,   3790],
                        [  3702,   3685],
                        [  3595,   3584],
                        [  3502,   3495],
                        [  3418,   3417],
                        [  3350,   3352],
                        [  3296,   3301],
                        [  3254,   3265],
                        [  3224,   3241],
                        [  3200,   3230],
                        [  3180,   3231],
                        [  3159,   3240],
                        [  3137,   3258],
                        [  3113,   3282],
                        [  3083,   3309],
                        [  3056,   3336],
                        [  3028,   3364],
                        [  3001,   3386],
                        [  2971,   3402],
                        [  2938,   3409],
                        [  2898,   3405],
                        [  2851,   3387],
                        [  2796,   3353],
                        [  2728,   3302],
                        [  2648,   3232],
                        [  2554,   3141],
                        [  2445,   3031],
                        [  2320,   2897],
                        [  2179,   2742],
                        [  2022,   2564],
                        [  1851,   2365],
                        [  1662,   2144],
                        [  1455,   1902],
                        [  1232,   1639],
                        [   992,   1357],
                        [   734,   1055],
                        [   460,    739],
                        [   169,    405],
                        [  -141,     54],
                        [  -427,   -272],
                        [  -607,   -489],
                        [  -636,   -553],
                        [  -505,   -457],
                        [  -214,   -197],
                        [   224,    210],
                        [   725,    682],
                        [  1171,   1099],
                        [  1523,   1424],
                        [  1791,   1666],
                        [  1974,   1828],
                        [  2074,   1913],
                        [  2098,   1926],
                        [  2050,   1874],
                        [  1941,   1761],
                        [  1779,   1595],
                        [  1572,   1381],
                        [  1330,   1128],
                        [  1059,    841],
                        [   765,    527],
                        [   456,    193],
                        [   134,   -158],
                        [  -193,   -516],
                        [  -519,   -878],
                        [  -843,  -1237],
                        [ -1160,  -1590],
                        [ -1467,  -1932],
                        [ -1762,  -2262],
                        [ -2044,  -2576],
                        [ -2312,  -2875],
                        [ -2565,  -3157],
                        [ -2803,  -3422],
                        [ -3026,  -3673],
                        [ -3236,  -3907],
                        [ -3431,  -4128],
                        [ -3615,  -4336],
                        [ -3786,  -4530],
                        [ -3948,  -4713],
                        [ -4102,  -4887],
                        [ -4248,  -5052],
                        [ -4388,  -5209],
                        [ -4524,  -5360],
                        [ -4656,  -5503],
                        [ -4786,  -5641],
                        [ -4913,  -5772],
                        [ -5040,  -5896],
                        [ -5163,  -6020],
                        [ -5286,  -6142],
                        [ -5405,  -6269],
                        [ -5522,  -6403],
                        [ -5633,  -6538],
                        [ -5740,  -6675],
                        [ -5837,  -6804],
                        [ -5926,  -6926],
                        [ -6006,  -7034],
                        [ -6076,  -7130],
                        [ -6137,  -7210],
                        [ -6188,  -7275],
                        [ -6229,  -7330],
                        [ -6262,  -7375],
                        [ -6284,  -7411],
                        [ -6297,  -7436],
                        [ -6302,  -7450],
                        [ -6299,  -7451],
                        [ -6290,  -7438],
                        [ -6275,  -7413],
                        [ -6249,  -7373],
                        [ -6210,  -7318],
                        [ -6150,  -7245],
                        [ -6072,  -7157],
                        [ -5974,  -7054],
                        [ -5854,  -6935],
                        [ -5714,  -6800],
                        [ -5555,  -6649],
                        [ -5372,  -6479],
                        [ -5168,  -6290],
                        [ -4942,  -6083],
                        [ -4697,  -5861],
                        [ -4427,  -5612],
                        [ -4130,  -5339],
                        [ -3795,  -5028],
                        [ -3425,  -4679],
                        [ -3045,  -4320],
                        [ -2655,  -3949],
                        [ -2270,  -3581],
                        [ -1891,  -3216],
                        [ -1531,  -2869],
                        [ -1190,  -2540],
                        [  -881,  -2241],
                        [  -604,  -1970],
                        [  -366,  -1738],
                        [  -170,  -1545],
                        [   -15,  -1393],
                        [    99,  -1286],
                        [   171,  -1225],
                        [   201,  -1210],
                        [   191,  -1240],
                        [   144,  -1315],
                        [    54,  -1432],
                        [   -75,  -1592],
                        [  -245,  -1789],
                        [  -456,  -2022],
                        [  -700,  -2284],
                        [  -979,  -2575],
                        [ -1284,  -2885],
                        [ -1613,  -3215],
                        [ -1960,  -3556],
                        [ -2321,  -3904],
                        [ -2689,  -4254],
                        [ -3062,  -4601],
                        [ -3431,  -4939],
                        [ -3794,  -5264],
                        [ -4144,  -5570],
                        [ -4478,  -5853],
                        [ -4789,  -6109],
                        [ -5074,  -6333],
                        [ -5327,  -6523],
                        [ -5545,  -6673],
                        [ -5722,  -6781],
                        [ -5854,  -6845],
                        [ -5941,  -6863],
                        [ -5977,  -6831],
                        [ -5955,  -6745],
                        [ -5935,  -6663],
                        [ -6008,  -6677],
                        [ -6215,  -6827],
                        [ -6559,  -7118],
                        [ -7045,  -7556],
                        [ -7670,  -8135],
                        [ -8339,  -8759],
                        [ -8915,  -9293],
                        [ -9354,  -9691],
                        [ -9661,  -9963],
                        [ -9835, -10109],
                        [ -9879, -10132],
                        [ -9795, -10035],
                        [ -9592,  -9825],
                        [ -9275,  -9508],
                        [ -8860,  -9091],
                        [ -8355,  -8584],
                        [ -7772,  -7995],
                        [ -7124,  -7334],
                        [ -6418,  -6611],
                        [ -5665,  -5837],
                        [ -4876,  -5021],
                        [ -4059,  -4173],
                        [ -3226,  -3306],
                        [ -2387,  -2428],
                        [ -1548,  -1549],
                        [  -717,   -676],
                        [    98,    181],
                        [   892,   1017],
                        [  1658,   1827],
                        [  2394,   2605],
                        [  3095,   3348],
                        [  3756,   4051],
                        [  4378,   4715],
                        [  4956,   5336],
                        [  5491,   5913],
                        [  5981,   6446],
                        [  6428,   6934],
                        [  6831,   7378],
                        [  7191,   7777],
                        [  7512,   8135],
                        [  7796,   8450],
                        [  8043,   8725],
                        [  8257,   8958],
                        [  8439,   9151],
                        [  8595,   9306],
                        [  8724,   9427],
                        [  8830,   9525],
                        [  8916,   9601],
                        [  8984,   9669],
                        [  9037,   9728],
                        [  9073,   9778],
                        [  9099,   9821],
                        [  9115,   9854],
                        [  9123,   9880],
                        [  9127,   9899],
                        [  9128,   9913],
                        [  9134,   9927],
                        [  9145,   9943],
                        [  9163,   9966],
                        [  9189,   9999],
                        [  9229,  10041],
                        [  9284,  10092],
                        [  9361,  10155],
                        [  9458,  10228],
                        [  9575,  10311],
                        [  9713,  10406],
                        [  9859,  10506],
                        [ 10013,  10613],
                        [ 10165,  10723],
                        [ 10315,  10836],
                        [ 10458,  10948],
                        [ 10592,  11059],
                        [ 10715,  11165],
                        [ 10827,  11265],
                        [ 10934,  11368],
                        [ 11034,  11468],
                        [ 11128,  11569],
                        [ 11215,  11669],
                        [ 11268,  11737],
                        [ 11286,  11774],
                        [ 11256,  11764],
                        [ 11175,  11706],
                        [ 11056,  11608],
                        [ 10894,  11470],
                        [ 10700,  11301],
                        [ 10471,  11098],
                        [ 10216,  10870],
                        [  9932,  10617],
                        [  9631,  10346],
                        [  9309,  10055],
                        [  8972,   9752],
                        [  8621,   9435],
                        [  8259,   9110],
                        [  7883,   8776],
                        [  7498,   8437],
                        [  7103,   8093],
                        [  6699,   7746],
                        [  6287,   7396],
                        [  5874,   7045],
                        [  5460,   6693],
                        [  5049,   6342],
                        [  4639,   5991],
                        [  4235,   5639],
                        [  3834,   5289],
                        [  3440,   4938],
                        [  3053,   4587],
                        [  2671,   4236],
                        [  2298,   3887],
                        [  1931,   3538],
                        [  1574,   3190],
                        [  1225,   2843],
                        [   886,   2498],
                        [   558,   2155],
                        [   240,   1814],
                        [   -69,   1476],
                        [  -366,   1142],
                        [  -652,    813],
                        [  -930,    489],
                        [ -1199,    171],
                        [ -1454,   -137],
                        [ -1704,   -442],
                        [ -1944,   -739],
                        [ -2106,   -957],
                        [ -2091,   -999],
                        [ -1868,   -830],
                        [ -1429,   -447],
                        [  -765,    163],
                        [   127,    999],
                        [  1143,   1961],
                        [  2136,   2897],
                        [  3053,   3761],
                        [  3898,   4555],
                        [  4661,   5276],
                        [  5337,   5915],
                        [  5922,   6472],
                        [  6416,   6945],
                        [  6820,   7334],
                        [  7138,   7640],
                        [  7376,   7863],
                        [  7538,   8006],
                        [  7629,   8074],
                        [  7655,   8070],
                        [  7616,   7998],
                        [  7521,   7864],
                        [  7373,   7673],
                        [  7178,   7432],
                        [  6944,   7147],
                        [  6672,   6823],
                        [  6371,   6465],
                        [  6043,   6080],
                        [  5692,   5670],
                        [  5322,   5243],
                        [  4937,   4799],
                        [  4542,   4345],
                        [  4138,   3883],
                        [  3729,   3415],
                        [  3318,   2945],
                        [  2908,   2475],
                        [  2501,   2008],
                        [  2099,   1545],
                        [  1704,   1092],
                        [  1317,    648],
                        [   941,    217],
                        [   575,   -202],
                        [   223,   -596],
                        [  -115,   -969],
                        [  -437,  -1312],
                        [  -743,  -1624],
                        [ -1029,  -1908],
                        [ -1297,  -2162],
                        [ -1543,  -2399],
                        [ -1766,  -2616],
                        [ -1963,  -2819],
                        [ -2134,  -3005],
                        [ -2278,  -3168],
                        [ -2393,  -3309],
                        [ -2478,  -3426],
                        [ -2536,  -3517],
                        [ -2567,  -3580],
                        [ -2572,  -3616],
                        [ -2555,  -3631],
                        [ -2515,  -3624],
                        [ -2455,  -3596],
                        [ -2377,  -3548],
                        [ -2290,  -3482],
                        [ -2197,  -3397],
                        [ -2102,  -3297],
                        [ -2007,  -3183],
                        [ -1906,  -3053],
                        [ -1802,  -2910],
                        [ -1682,  -2754],
                        [ -1547,  -2585],
                        [ -1394,  -2402],
                        [ -1224,  -2208],
                        [ -1039,  -2004],
                        [  -841,  -1793],
                        [  -645,  -1592],
                        [  -453,  -1398],
                        [  -288,  -1237],
                        [  -150,  -1109],
                        [   -32,  -1003],
                        [    65,   -924],
                        [   176,   -829],
                        [   300,   -723],
                        [   444,   -597],
                        [   606,   -451],
                        [   777,   -295],
                        [   956,   -130],
                        [  1133,     33],
                        [  1311,    196],
                        [  1477,    348],
                        [  1633,    490],
                        [  1770,    613],
                        [  1891,    721],
                        [  1987,    804],
                        [  2061,    867],
                        [  2110,    904],
                        [  2135,    917],
                        [  2139,    904],
                        [  2122,    869],
                        [  2086,    812],
                        [  2031,    734],
                        [  1959,    638],
                        [  1871,    527],
                        [  1770,    404],
                        [  1659,    271],
                        [  1541,    136],
                        [  1419,     -1],
                        [  1297,   -133],
                        [  1178,   -258],
                        [  1067,   -369],
                        [   966,   -466],
                        [   881,   -540],
                        [   811,   -593],
                        [   763,   -618],
                        [   739,   -614],
                        [   741,   -578],
                        [   771,   -508],
                        [   833,   -401],
                        [   925,   -258],
                        [  1055,    -75],
                        [  1220,    145],
                        [  1418,    401],
                        [  1657,    698],
                        [  1931,   1030],
                        [  2157,   1315],
                        [  2247,   1462],
                        [  2169,   1441],
                        [  1920,   1249],
                        [  1478,    861],
                        [   831,    269],
                        [    80,   -427],
                        [  -626,  -1080],
                        [ -1242,  -1643],
                        [ -1775,  -2126],
                        [ -2215,  -2524],
                        [ -2556,  -2832],
                        [ -2797,  -3049],
                        [ -2941,  -3176],
                        [ -2990,  -3216],
                        [ -2952,  -3169],
                        [ -2831,  -3040],
                        [ -2638,  -2835],
                        [ -2379,  -2557],
                        [ -2061,  -2215],
                        [ -1690,  -1817],
                        [ -1275,  -1367],
                        [  -823,   -877],
                        [  -344,   -352],
                        [   158,    200],
                        [   675,    771],
                        [  1200,   1356],
                        [  1729,   1947],
                        [  2256,   2537],
                        [  2775,   3124],
                        [  3283,   3700],
                        [  3777,   4263],
                        [  4253,   4809],
                        [  4709,   5337],
                        [  5142,   5842],
                        [  5552,   6324],
                        [  5936,   6781],
                        [  6295,   7213],
                        [  6629,   7620],
                        [  6940,   8001],
                        [  7226,   8356],
                        [  7492,   8682],
                        [  7737,   8983],
                        [  7962,   9245],
                        [  8169,   9475],
                        [  8360,   9669],
                        [  8536,   9830],
                        [  8699,   9969],
                        [  8850,  10086],
                        [  8989,  10199],
                        [  9118,  10309],
                        [  9237,  10417],
                        [  9345,  10524],
                        [  9445,  10629],
                        [  9537,  10734],
                        [  9625,  10837],
                        [  9710,  10940],
                        [  9793,  11040],
                        [  9878,  11141],
                        [  9961,  11243],
                        [ 10047,  11347],
                        [ 10141,  11452],
                        [ 10243,  11557],
                        [ 10361,  11663],
                        [ 10493,  11771],
                        [ 10640,  11876],
                        [ 10798,  11978],
                        [ 10953,  12073],
                        [ 11102,  12160],
                        [ 11230,  12232],
                        [ 11337,  12288],
                        [ 11418,  12327],
                        [ 11473,  12348],
                        [ 11505,  12355],
                        [ 11513,  12347],
                        [ 11530,  12356],
                        [ 11551,  12378],
                        [ 11587,  12422],
                        [ 11634,  12487],
                        [ 11661,  12535],
                        [ 11669,  12571],
                        [ 11609,  12542],
                        [ 11481,  12448],
                        [ 11287,  12289],
                        [ 11025,  12064],
                        [ 10703,  11781],
                        [ 10320,  11440],
                        [  9884,  11050],
                        [  9395,  10610],
                        [  8866,  10132],
                        [  8296,   9614],
                        [  7697,   9069],
                        [  7069,   8495],
                        [  6425,   7902],
                        [  5766,   7291],
                        [  5095,   6669],
                        [  4417,   6039],
                        [  3733,   5406],
                        [  3044,   4773],
                        [  2360,   4145],
                        [  1679,   3522],
                        [  1008,   2911],
                        [   350,   2312],
                        [  -291,   1727],
                        [  -914,   1160],
                        [ -1515,    610],
                        [ -2093,     79],
                        [ -2646,   -432],
                        [ -3171,   -923],
                        [ -3669,  -1392],
                        [ -4138,  -1839],
                        [ -4578,  -2264],
                        [ -4986,  -2665],
                        [ -5365,  -3044],
                        [ -5713,  -3401],
                        [ -6030,  -3735],
                        [ -6316,  -4045],
                        [ -6573,  -4333],
                        [ -6802,  -4599],
                        [ -7003,  -4842],
                        [ -7171,  -5057],
                        [ -7322,  -5259],
                        [ -7442,  -5432],
                        [ -7449,  -5496],
                        [ -7268,  -5374],
                        [ -6885,  -5051],
                        [ -6294,  -4521],
                        [ -5472,  -3761],
                        [ -4405,  -2758],
                        [ -3191,  -1609],
                        [ -1977,   -461],
                        [  -808,    644],
                        [   319,   1706],
                        [  1382,   2714],
                        [  2369,   3652],
                        [  3271,   4514],
                        [  4083,   5295],
                        [  4799,   5987],
                        [  5416,   6585],
                        [  5940,   7087],
                        [  6368,   7492],
                        [  6703,   7800],
                        [  6947,   8012],
                        [  7102,   8132],
                        [  7173,   8162],
                        [  7164,   8107],
                        [  7081,   7973],
                        [  6929,   7766],
                        [  6715,   7491],
                        [  6445,   7157],
                        [  6125,   6767],
                        [  5761,   6330],
                        [  5358,   5852],
                        [  4922,   5341],
                        [  4461,   4802],
                        [  3980,   4240],
                        [  3482,   3663],
                        [  2977,   3075],
                        [  2468,   2481],
                        [  1959,   1888],
                        [  1456,   1299],
                        [   962,    721],
                        [   481,    156],
                        [    17,   -390],
                        [  -428,   -916],
                        [  -852,  -1406],
                        [ -1250,  -1860],
                        [ -1622,  -2266],
                        [ -1965,  -2624],
                        [ -2279,  -2935],
                        [ -2561,  -3196],
                        [ -2810,  -3421],
                        [ -3025,  -3612],
                        [ -3205,  -3777],
                        [ -3347,  -3916],
                        [ -3452,  -4030],
                        [ -3522,  -4119],
                        [ -3556,  -4181],
                        [ -3558,  -4219],
                        [ -3529,  -4227],
                        [ -3473,  -4212],
                        [ -3391,  -4173],
                        [ -3287,  -4112],
                        [ -3168,  -4033],
                        [ -3035,  -3937],
                        [ -2903,  -3829],
                        [ -2775,  -3709],
                        [ -2657,  -3582],
                        [ -2551,  -3452],
                        [ -2455,  -3315],
                        [ -2368,  -3177],
                        [ -2277,  -3035],
                        [ -2181,  -2889],
                        [ -2077,  -2742],
                        [ -1968,  -2594],
                        [ -1857,  -2451],
                        [ -1743,  -2313],
                        [ -1664,  -2217],
                        [ -1618,  -2160],
                        [ -1639,  -2177],
                        [ -1726,  -2267],
                        [ -1873,  -2421],
                        [ -2081,  -2641],
                        [ -2290,  -2864],
                        [ -2504,  -3095],
                        [ -2688,  -3296],
                        [ -2841,  -3466],
                        [ -2971,  -3613],
                        [ -3072,  -3734],
                        [ -3150,  -3833],
                        [ -3204,  -3910],
                        [ -3238,  -3969],
                        [ -3251,  -4011],
                        [ -3252,  -4039],
                        [ -3237,  -4052],
                        [ -3218,  -4056],
                        [ -3189,  -4048],
                        [ -3158,  -4032],
                        [ -3122,  -4006],
                        [ -3078,  -3973],
                        [ -3023,  -3931],
                        [ -2957,  -3881],
                        [ -2875,  -3820],
                        [ -2780,  -3751],
                        [ -2671,  -3669],
                        [ -2546,  -3575],
                        [ -2407,  -3468],
                        [ -2254,  -3346],
                        [ -2082,  -3207],
                        [ -1895,  -3049],
                        [ -1689,  -2871],
                        [ -1465,  -2672],
                        [ -1222,  -2451],
                        [  -960,  -2207],
                        [  -678,  -1939],
                        [  -377,  -1646],
                        [   -57,  -1330],
                        [   282,   -990],
                        [   639,   -626],
                        [  1010,   -241],
                        [  1398,    164],
                        [  1800,    590],
                        [  2212,   1029],
                        [  2632,   1480],
                        [  3065,   1948],
                        [  3493,   2413],
                        [  3837,   2798],
                        [  4036,   3040],
                        [  4077,   3125],
                        [  3953,   3047],
                        [  3627,   2768],
                        [  3075,   2265],
                        [  2381,   1621],
                        [  1670,    962],
                        [   973,    319],
                        [   293,   -314],
                        [  -361,   -921],
                        [  -970,  -1493],
                        [ -1531,  -2023],
                        [ -2038,  -2508],
                        [ -2486,  -2942],
                        [ -2875,  -3318],
                        [ -3205,  -3637],
                        [ -3478,  -3896],
                        [ -3694,  -4095],
                        [ -3856,  -4236],
                        [ -3965,  -4319],
                        [ -4024,  -4349],
                        [ -4037,  -4327],
                        [ -4006,  -4256],
                        [ -3938,  -4142],
                        [ -3835,  -3989],
                        [ -3703,  -3799],
                        [ -3543,  -3578],
                        [ -3361,  -3330],
                        [ -3157,  -3058],
                        [ -2938,  -2768],
                        [ -2704,  -2462],
                        [ -2459,  -2143],
                        [ -2206,  -1814],
                        [ -1947,  -1476],
                        [ -1684,  -1134],
                        [ -1418,   -788],
                        [ -1151,   -441],
                        [  -883,    -94],
                        [  -616,    251],
                        [  -349,    596],
                        [   -83,    931],
                        [   182,   1259],
                        [   447,   1567],
                        [   711,   1855],
                        [   973,   2119],
                        [  1236,   2361],
                        [  1495,   2585],
                        [  1753,   2793],
                        [  2007,   3001],
                        [  2257,   3210],
                        [  2499,   3424],
                        [  2736,   3642],
                        [  2962,   3863],
                        [  3180,   4089],
                        [  3388,   4310],
                        [  3587,   4530],
                        [  3776,   4741],
                        [  3954,   4944],
                        [  4120,   5137],
                        [  4275,   5319],
                        [  4427,   5488],
                        [  4574,   5645],
                        [  4724,   5788],
                        [  4873,   5917],
                        [  5022,   6030],
                        [  5168,   6122],
                        [  5293,   6191],
                        [  5398,   6235],
                        [  5463,   6247],
                        [  5489,   6224],
                        [  5475,   6169],
                        [  5417,   6080],
                        [  5333,   5973],
                        [  5221,   5846],
                        [  5131,   5750],
                        [  5059,   5682],
                        [  5019,   5652],
                        [  5008,   5660],
                        [  4997,   5672],
                        [  4986,   5692],
                        [  4905,   5642],
                        [  4756,   5529],
                        [  4535,   5345],
                        [  4240,   5090],
                        [  3876,   4768],
                        [  3445,   4382],
                        [  2954,   3940],
                        [  2403,   3441],
                        [  1804,   2897],
                        [  1159,   2308],
                        [   483,   1686],
                        [  -220,   1031],
                        [  -937,    356],
                        [ -1666,   -340],
                        [ -2402,  -1047],
                        [ -3140,  -1762],
                        [ -3876,  -2473],
                        [ -4611,  -3181],
                        [ -5337,  -3876],
                        [ -6055,  -4558],
                        [ -6754,  -5219],
                        [ -7434,  -5858],
                        [ -8088,  -6472],
                        [ -8716,  -7058],
                        [ -9311,  -7614],
                        [ -9874,  -8138],
                        [-10401,  -8630],
                        [-10891,  -9086],
                        [-11342,  -9509],
                        [-11754,  -9896],
                        [-12126, -10249],
                        [-12458, -10566],
                        [-12751, -10849],
                        [-13004, -11100],
                        [-13219, -11317],
                        [-13392, -11500],
                        [-13528, -11653],
                        [-13629, -11775],
                        [-13693, -11867],
                        [-13720, -11926],
                        [-13722, -11964],
                        [-13679, -11963],
                        [-13538, -11867],
                        [-13260, -11639],
                        [-12851, -11282],
                        [-12301, -10787],
                        [-11583, -10125],
                        [-10669,  -9270],
                        [ -9628,  -8288],
                        [ -8560,  -7282],
                        [ -7496,  -6281],
                        [ -6437,  -5283],
                        [ -5407,  -4309],
                        [ -4418,  -3371],
                        [ -3484,  -2481],
                        [ -2611,  -1645],
                        [ -1809,   -873],
                        [ -1086,   -173],
                        [  -439,    449],
                        [   128,    992],
                        [   613,   1452],
                        [  1018,   1827],
                        [  1342,   2120],
                        [  1588,   2332],
                        [  1759,   2464],
                        [  1860,   2520],
                        [  1895,   2506],
                        [  1868,   2424],
                        [  1786,   2280],
                        [  1655,   2082],
                        [  1480,   1835],
                        [  1264,   1545],
                        [  1018,   1220],
                        [   745,    865],
                        [   451,    488],
                        [   142,     92],
                        [  -176,   -315],
                        [  -497,   -729],
                        [  -817,  -1143],
                        [ -1133,  -1554],
                        [ -1438,  -1954],
                        [ -1730,  -2342],
                        [ -2005,  -2713],
                        [ -2262,  -3062],
                        [ -2497,  -3378],
                        [ -2710,  -3658],
                        [ -2897,  -3892],
                        [ -3060,  -4081],
                        [ -3196,  -4222],
                        [ -3305,  -4314],
                        [ -3387,  -4372],
                        [ -3442,  -4396],
                        [ -3469,  -4403],
                        [ -3469,  -4390],
                        [ -3444,  -4364],
                        [ -3393,  -4326],
                        [ -3319,  -4275],
                        [ -3224,  -4214],
                        [ -3112,  -4140],
                        [ -2985,  -4054],
                        [ -2846,  -3955],
                        [ -2698,  -3846],
                        [ -2549,  -3734],
                        [ -2400,  -3617],
                        [ -2269,  -3503],
                        [ -2153,  -3390],
                        [ -2061,  -3284],
                        [ -1994,  -3186],
                        [ -1948,  -3095],
                        [ -1926,  -3014],
                        [ -1909,  -2940],
                        [ -1896,  -2871],
                        [ -1887,  -2808],
                        [ -1882,  -2755],
                        [ -1883,  -2715],
                        [ -1892,  -2688],
                        [ -1955,  -2721],
                        [ -2068,  -2810],
                        [ -2265,  -2991],
                        [ -2543,  -3258],
                        [ -2898,  -3607],
                        [ -3330,  -4038],
                        [ -3766,  -4477],
                        [ -4211,  -4928],
                        [ -4614,  -5338],
                        [ -4976,  -5709],
                        [ -5295,  -6039],
                        [ -5569,  -6328],
                        [ -5793,  -6571],
                        [ -5967,  -6767],
                        [ -6093,  -6919],
                        [ -6169,  -7024],
                        [ -6202,  -7087],
                        [ -6190,  -7105],
                        [ -6146,  -7082],
                        [ -6067,  -7017],
                        [ -5957,  -6914],
                        [ -5817,  -6772],
                        [ -5643,  -6598],
                        [ -5436,  -6387],
                        [ -5191,  -6146],
                        [ -4908,  -5874],
                        [ -4592,  -5575],
                        [ -4244,  -5250],
                        [ -3867,  -4901],
                        [ -3463,  -4529],
                        [ -3036,  -4138],
                        [ -2588,  -3728],
                        [ -2122,  -3301],
                        [ -1640,  -2859],
                        [ -1147,  -2405],
                        [  -643,  -1940],
                        [  -132,  -1467],
                        [   385,   -988],
                        [   903,   -505],
                        [  1419,    -20],
                        [  1932,    465],
                        [  2436,    946],
                        [  2928,   1420],
                        [  3407,   1886],
                        [  3868,   2339],
                        [  4308,   2777],
                        [  4725,   3196],
                        [  5120,   3599],
                        [  5478,   3967],
                        [  5761,   4268],
                        [  5958,   4485],
                        [  6068,   4620],
                        [  6083,   4664],
                        [  5973,   4585],
                        [  5708,   4353],
                        [  5321,   4003],
                        [  4873,   3595],
                        [  4380,   3142],
                        [  3848,   2649],
                        [  3288,   2127],
                        [  2715,   1589],
                        [  2139,   1042],
                        [  1566,    494],
                        [  1005,    -47],
                        [   464,   -573],
                        [   -54,  -1078],
                        [  -544,  -1556],
                        [ -1005,  -2004],
                        [ -1431,  -2415],
                        [ -1821,  -2789],
                        [ -2173,  -3122],
                        [ -2485,  -3414],
                        [ -2759,  -3662],
                        [ -2993,  -3867],
                        [ -3187,  -4026],
                        [ -3344,  -4142],
                        [ -3463,  -4216],
                        [ -3546,  -4249],
                        [ -3594,  -4245],
                        [ -3608,  -4203],
                        [ -3590,  -4128],
                        [ -3542,  -4020],
                        [ -3466,  -3883],
                        [ -3365,  -3719],
                        [ -3241,  -3529],
                        [ -3096,  -3317],
                        [ -2933,  -3086],
                        [ -2754,  -2838],
                        [ -2560,  -2576],
                        [ -2355,  -2303],
                        [ -2140,  -2025],
                        [ -1918,  -1745],
                        [ -1689,  -1477],
                        [ -1457,  -1220],
                        [ -1223,   -984],
                        [  -989,   -768],
                        [  -758,   -571],
                        [  -531,   -397],
                        [  -314,   -228],
                        [  -104,    -67],
                        [    92,     93],
                        [   274,    251],
                        [   439,    406],
                        [   587,    559],
                        [   714,    699],
                        [   821,    827],
                        [   906,    936],
                        [   969,   1025],
                        [  1011,   1093],
                        [  1029,   1138],
                        [  1035,   1165],
                        [  1028,   1170],
                        [  1012,   1155],
                        [   986,   1118],
                        [   953,   1060],
                        [   913,    982],
                        [   853,    881],
                        [   772,    754],
                        [   657,    599],
                        [   511,    417],
                        [   336,    211],
                        [   130,    -19],
                        [   -81,   -248],
                        [  -299,   -476],
                        [  -469,   -650],
                        [  -594,   -773],
                        [  -661,   -831],
                        [  -670,   -826],
                        [  -645,   -782],
                        [  -583,   -696],
                        [  -562,   -650],
                        [  -579,   -638],
                        [  -640,   -670],
                        [  -748,   -745],
                        [  -904,   -865],
                        [ -1104,  -1027],
                        [ -1349,  -1229],
                        [ -1635,  -1468],
                        [ -1953,  -1740],
                        [ -2305,  -2043],
                        [ -2674,  -2372],
                        [ -3060,  -2723],
                        [ -3450,  -3089],
                        [ -3843,  -3471],
                        [ -4236,  -3859],
                        [ -4627,  -4253],
                        [ -5020,  -4646],
                        [ -5412,  -5037],
                        [ -5802,  -5419],
                        [ -6189,  -5791],
                        [ -6567,  -6149],
                        [ -6932,  -6491],
                        [ -7282,  -6814],
                        [ -7616,  -7117],
                        [ -7928,  -7397],
                        [ -8219,  -7655],
                        [ -8486,  -7887],
                        [ -8730,  -8095],
                        [ -8947,  -8278],
                        [ -9141,  -8435],
                        [ -9308,  -8568],
                        [ -9449,  -8675],
                        [ -9565,  -8760],
                        [ -9654,  -8821],
                        [ -9718,  -8860],
                        [ -9754,  -8876],
                        [ -9765,  -8872],
                        [ -9752,  -8848],
                        [ -9713,  -8804],
                        [ -9651,  -8742],
                        [ -9569,  -8664],
                        [ -9459,  -8562],
                        [ -9313,  -8429],
                        [ -9133,  -8267],
                        [ -8926,  -8082],
                        [ -8686,  -7867],
                        [ -8391,  -7600],
                        [ -8010,  -7252],
                        [ -7557,  -6832],
                        [ -7064,  -6374],
                        [ -6541,  -5887],
                        [ -5992,  -5376],
                        [ -5432,  -4851],
                        [ -4868,  -4323],
                        [ -4308,  -3794],
                        [ -3759,  -3274],
                        [ -3230,  -2770],
                        [ -2725,  -2286],
                        [ -2247,  -1826],
                        [ -1800,  -1394],
                        [ -1384,   -994],
                        [ -1003,   -628],
                        [  -656,   -297],
                        [  -344,     -2],
                        [   -66,    257],
                        [   179,    478],
                        [   391,    662],
                        [   574,    813],
                        [   729,    930],
                        [   858,   1016],
                        [   965,   1076],
                        [  1052,   1111],
                        [  1121,   1126],
                        [  1177,   1123],
                        [  1220,   1106],
                        [  1254,   1077],
                        [  1282,   1038],
                        [  1307,    995],
                        [  1330,    947],
                        [  1355,    900],
                        [  1384,    854],
                        [  1418,    812],
                        [  1457,    776],
                        [  1503,    749],
                        [  1556,    739],
                        [  1618,    746],
                        [  1687,    778],
                        [  1764,    834],
                        [  1848,    917],
                        [  1939,   1027],
                        [  2037,   1154],
                        [  2141,   1297],
                        [  2249,   1437],
                        [  2362,   1578],
                        [  2479,   1710],
                        [  2598,   1833],
                        [  2720,   1948],
                        [  2842,   2054],
                        [  2963,   2156],
                        [  3082,   2254],
                        [  3196,   2349],
                        [  3305,   2438],
                        [  3403,   2520],
                        [  3486,   2593],
                        [  3548,   2653],
                        [  3588,   2701],
                        [  3602,   2734],
                        [  3589,   2754],
                        [  3551,   2759],
                        [  3486,   2750],
                        [  3413,   2731],
                        [  3331,   2703],
                        [  3242,   2666],
                        [  3145,   2618],
                        [  3038,   2556],
                        [  2921,   2481],
                        [  2749,   2347],
                        [  2526,   2156],
                        [  2230,   1888],
                        [  1862,   1543],
                        [  1421,   1120],
                        [   908,    622],
                        [   389,    114],
                        [  -137,   -405],
                        [  -622,   -886],
                        [ -1067,  -1328],
                        [ -1463,  -1727],
                        [ -1811,  -2080],
                        [ -2101,  -2381],
                        [ -2334,  -2628],
                        [ -2507,  -2822],
                        [ -2621,  -2959],
                        [ -2683,  -3042],
                        [ -2690,  -3070],
                        [ -2655,  -3045],
                        [ -2577,  -2967],
                        [ -2459,  -2841],
                        [ -2303,  -2668],
                        [ -2104,  -2452],
                        [ -1866,  -2194],
                        [ -1583,  -1900],
                        [ -1256,  -1571],
                        [  -895,  -1214],
                        [  -499,   -829],
                        [   -76,   -423],
                        [   374,      4],
                        [   841,    444],
                        [  1325,    895],
                        [  1819,   1353],
                        [  2321,   1814],
                        [  2823,   2275],
                        [  3327,   2733],
                        [  3825,   3184],
                        [  4315,   3625],
                        [  4793,   4054],
                        [  5256,   4468],
                        [  5699,   4863],
                        [  6120,   5238],
                        [  6513,   5590],
                        [  6877,   5917],
                        [  7210,   6217],
                        [  7509,   6488],
                        [  7773,   6728],
                        [  8001,   6937],
                        [  8188,   7111],
                        [  8343,   7256],
                        [  8473,   7383],
                        [  8582,   7495],
                        [  8668,   7586],
                        [  8710,   7638],
                        [  8681,   7621],
                        [  8570,   7527],
                        [  8394,   7368],
                        [  8157,   7150],
                        [  7865,   6880],
                        [  7528,   6565],
                        [  7155,   6214],
                        [  6752,   5833],
                        [  6329,   5429],
                        [  5891,   5011],
                        [  5449,   4583],
                        [  5006,   4153],
                        [  4570,   3725],
                        [  4144,   3305],
                        [  3734,   2900],
                        [  3342,   2509],
                        [  2972,   2141],
                        [  2627,   1798],
                        [  2309,   1484],
                        [  2020,   1202],
                        [  1761,    953],
                        [  1532,    738],
                        [  1335,    557],
                        [  1168,    411],
                        [  1032,    298],
                        [   926,    217],
                        [   848,    167],
                        [   798,    147],
                        [   773,    154],
                        [   772,    188],
                        [   791,    244],
                        [   830,    323],
                        [   885,    418],
                        [   953,    530],
                        [  1033,    654],
                        [  1121,    790],
                        [  1216,    929],
                        [  1314,   1069],
                        [  1415,   1202],
                        [  1515,   1324],
                        [  1612,   1430],
                        [  1705,   1518],
                        [  1792,   1583],
                        [  1870,   1625],
                        [  1937,   1657],
                        [  1992,   1675],
                        [  2035,   1691],
                        [  2061,   1701],
                        [  2069,   1704],
                        [  2060,   1701],
                        [  2029,   1685],
                        [  1977,   1654],
                        [  1904,   1603],
                        [  1809,   1532],
                        [  1694,   1441],
                        [  1560,   1330],
                        [  1412,   1203],
                        [  1251,   1059],
                        [  1081,    899],
                        [   901,    726],
                        [   719,    541],
                        [   534,    345],
                        [   340,    136],
                        [   140,    -84],
                        [   -73,   -314],
                        [  -297,   -556],
                        [  -527,   -802],
                        [  -766,  -1054],
                        [  -986,  -1285],
                        [ -1189,  -1494],
                        [ -1333,  -1645],
                        [ -1424,  -1736],
                        [ -1445,  -1754],
                        [ -1397,  -1701],
                        [ -1292,  -1590],
                        [ -1129,  -1417],
                        [  -977,  -1252],
                        [  -828,  -1090],
                        [  -696,   -943],
                        [  -579,   -808],
                        [  -488,   -696],
                        [  -418,   -603],
                        [  -375,   -533],
                        [  -358,   -485],
                        [  -363,   -461],
                        [  -391,   -459],
                        [  -431,   -479],
                        [  -483,   -519],
                        [  -541,   -577],
                        [  -606,   -652],
                        [  -678,   -742],
                        [  -755,   -844],
                        [  -846,   -957],
                        [  -950,  -1079],
                        [ -1065,  -1207],
                        [ -1194,  -1339],
                        [ -1328,  -1473],
                        [ -1469,  -1609],
                        [ -1614,  -1742],
                        [ -1761,  -1874],
                        [ -1908,  -2000],
                        [ -2054,  -2121],
                        [ -2196,  -2234],
                        [ -2336,  -2342],
                        [ -2470,  -2439],
                        [ -2599,  -2528],
                        [ -2722,  -2607],
                        [ -2838,  -2678],
                        [ -2945,  -2739],
                        [ -3044,  -2790],
                        [ -3131,  -2832],
                        [ -3207,  -2865],
                        [ -3270,  -2888],
                        [ -3322,  -2902],
                        [ -3361,  -2907],
                        [ -3387,  -2903],
                        [ -3398,  -2889],
                        [ -3400,  -2870],
                        [ -3409,  -2862],
                        [ -3439,  -2879],
                        [ -3491,  -2924],
                        [ -3564,  -2994],
                        [ -3645,  -3074],
                        [ -3703,  -3135],
                        [ -3716,  -3153],
                        [ -3685,  -3128],
                        [ -3612,  -3065],
                        [ -3500,  -2964],
                        [ -3353,  -2830],
                        [ -3176,  -2669],
                        [ -2972,  -2482],
                        [ -2745,  -2276],
                        [ -2501,  -2051],
                        [ -2244,  -1812],
                        [ -1978,  -1561],
                        [ -1706,  -1301],
                        [ -1432,  -1034],
                        [ -1155,   -763],
                        [  -878,   -489],
                        [  -603,   -215],
                        [  -331,     55],
                        [   -63,    321],
                        [   201,    579],
                        [   458,    830],
                        [   711,   1073],
                        [   958,   1306],
                        [  1198,   1531],
                        [  1433,   1748],
                        [  1663,   1957],
                        [  1887,   2158],
                        [  2106,   2352],
                        [  2320,   2539],
                        [  2529,   2719],
                        [  2733,   2893],
                        [  2933,   3061],
                        [  3131,   3224],
                        [  3325,   3381],
                        [  3515,   3534],
                        [  3701,   3681],
                        [  3884,   3825],
                        [  4061,   3967],
                        [  4233,   4110],
                        [  4399,   4256],
                        [  4557,   4404],
                        [  4708,   4558],
                        [  4852,   4718],
                        [  4985,   4877],
                        [  5106,   5036],
                        [  5215,   5180],
                        [  5312,   5310],
                        [  5397,   5419],
                        [  5471,   5510],
                        [  5532,   5583],
                        [  5583,   5636],
                        [  5622,   5679],
                        [  5651,   5711],
                        [  5668,   5732],
                        [  5674,   5744],
                        [  5665,   5743],
                        [  5644,   5730],
                        [  5607,   5705],
                        [  5556,   5666],
                        [  5487,   5615],
                        [  5402,   5551],
                        [  5297,   5475],
                        [  5172,   5385],
                        [  5039,   5289],
                        [  4895,   5184],
                        [  4742,   5072],
                        [  4582,   4951],
                        [  4412,   4821],
                        [  4232,   4681],
                        [  4015,   4500],
                        [  3763,   4285],
                        [  3467,   4023],
                        [  3130,   3716],
                        [  2740,   3354],
                        [  2299,   2937],
                        [  1850,   2511],
                        [  1392,   2072],
                        [   959,   1656],
                        [   551,   1261],
                        [   179,    898],
                        [  -159,    566],
                        [  -453,    274],
                        [  -701,     21],
                        [  -903,   -187],
                        [ -1057,   -351],
                        [ -1168,   -469],
                        [ -1237,   -541],
                        [ -1271,   -570],
                        [ -1268,   -554],
                        [ -1233,   -497],
                        [ -1166,   -400],
                        [ -1064,   -267],
                        [  -927,    -98],
                        [  -753,     99],
                        [  -542,    326],
                        [  -304,    574],
                        [   -38,    844],
                        [   249,   1129],
                        [   557,   1428],
                        [   878,   1734],
                        [  1210,   2046],
                        [  1547,   2358],
                        [  1889,   2669],
                        [  2230,   2974],
                        [  2567,   3270],
                        [  2897,   3554],
                        [  3219,   3825],
                        [  3528,   4080],
                        [  3822,   4316],
                        [  4095,   4532],
                        [  4349,   4728],
                        [  4578,   4901],
                        [  4781,   5050],
                        [  4956,   5174],
                        [  5106,   5274],
                        [  5225,   5348],
                        [  5315,   5395],
                        [  5384,   5426],
                        [  5453,   5462],
                        [  5538,   5518],
                        [  5640,   5596],
                        [  5761,   5695],
                        [  5890,   5807],
                        [  6004,   5905],
                        [  6071,   5959],
                        [  6088,   5965],
                        [  6058,   5926],
                        [  5985,   5845],
                        [  5872,   5728],
                        [  5723,   5579],
                        [  5543,   5402],
                        [  5337,   5202],
                        [  5109,   4982],
                        [  4867,   4747],
                        [  4616,   4500],
                        [  4360,   4245],
                        [  4105,   3983],
                        [  3851,   3720],
                        [  3603,   3457],
                        [  3363,   3200],
                        [  3134,   2951],
                        [  2916,   2713],
                        [  2713,   2490],
                        [  2524,   2281],
                        [  2351,   2089],
                        [  2194,   1914],
                        [  2053,   1757],
                        [  1926,   1616],
                        [  1816,   1492],
                        [  1719,   1384],
                        [  1635,   1290],
                        [  1562,   1211],
                        [  1501,   1143],
                        [  1447,   1088],
                        [  1402,   1042],
                        [  1360,   1003],
                        [  1322,    969],
                        [  1285,    941],
                        [  1248,    916],
                        [  1209,    890],
                        [  1168,    862],
                        [  1121,    829],
                        [  1070,    789],
                        [  1013,    739],
                        [   949,    676],
                        [   878,    596],
                        [   797,    500],
                        [   710,    394],
                        [   616,    277],
                        [   513,    157],
                        [   400,     31],
                        [   276,    -98],
                        [   142,   -228],
                        [    -5,   -367],
                        [  -164,   -515],
                        [  -334,   -675],
                        [  -516,   -847],
                        [  -707,  -1029],
                        [  -908,  -1219],
                        [ -1116,  -1414],
                        [ -1333,  -1614],
                        [ -1555,  -1817],
                        [ -1780,  -2022],
                        [ -2000,  -2225],
                        [ -2215,  -2425],
                        [ -2420,  -2620],
                        [ -2615,  -2810],
                        [ -2801,  -2992],
                        [ -2975,  -3168],
                        [ -3137,  -3332],
                        [ -3286,  -3485],
                        [ -3408,  -3614],
                        [ -3504,  -3719],
                        [ -3563,  -3788],
                        [ -3586,  -3820],
                        [ -3562,  -3807],
                        [ -3493,  -3748],
                        [ -3375,  -3640],
                        [ -3209,  -3482],
                        [ -3025,  -3307],
                        [ -2823,  -3113],
                        [ -2613,  -2909],
                        [ -2394,  -2695],
                        [ -2177,  -2481],
                        [ -1961,  -2267],
                        [ -1753,  -2058],
                        [ -1551,  -1855],
                        [ -1359,  -1663],
                        [ -1177,  -1481],
                        [ -1002,  -1314],
                        [  -832,  -1159],
                        [  -670,  -1021],
                        [  -514,   -899],
                        [  -369,   -792],
                        [  -234,   -702],
                        [  -119,   -626],
                        [   -23,   -568],
                        [    53,   -523],
                        [   107,   -494],
                        [   144,   -478],
                        [   162,   -475],
                        [   163,   -483],
                        [   145,   -502],
                        [   115,   -531],
                        [    69,   -567],
                        [    11,   -609],
                        [   -59,   -658],
                        [  -140,   -709],
                        [  -231,   -765],
                        [  -329,   -822],
                        [  -436,   -881],
                        [  -544,   -940],
                        [  -657,   -999],
                        [  -769,  -1055],
                        [  -879,  -1110],
                        [  -986,  -1161],
                        [ -1089,  -1208],
                        [ -1185,  -1251],
                        [ -1275,  -1289],
                        [ -1354,  -1319],
                        [ -1436,  -1354],
                        [ -1541,  -1416],
                        [ -1682,  -1518],
                        [ -1857,  -1657],
                        [ -2067,  -1835],
                        [ -2308,  -2045],
                        [ -2550,  -2260],
                        [ -2761,  -2446],
                        [ -2932,  -2594],
                        [ -3066,  -2706],
                        [ -3161,  -2784],
                        [ -3218,  -2826],
                        [ -3237,  -2836],
                        [ -3219,  -2815],
                        [ -3166,  -2766],
                        [ -3083,  -2689],
                        [ -2971,  -2588],
                        [ -2838,  -2462],
                        [ -2685,  -2312],
                        [ -2516,  -2143],
                        [ -2334,  -1954],
                        [ -2139,  -1749],
                        [ -1933,  -1528],
                        [ -1721,  -1299],
                        [ -1502,  -1061],
                        [ -1281,   -820],
                        [ -1058,   -575],
                        [  -834,   -332],
                        [  -613,    -89],
                        [  -392,    153],
                        [  -177,    389],
                        [    34,    620],
                        [   240,    845],
                        [   439,   1062],
                        [   631,   1271],
                        [   813,   1470],
                        [   988,   1659],
                        [  1153,   1838],
                        [  1309,   2006],
                        [  1454,   2161],
                        [  1591,   2305],
                        [  1716,   2437],
                        [  1831,   2555],
                        [  1933,   2660],
                        [  2024,   2753],
                        [  2101,   2831],
                        [  2167,   2897],
                        [  2219,   2953],
                        [  2257,   3001],
                        [  2280,   3040],
                        [  2287,   3073],
                        [  2279,   3092],
                        [  2256,   3098],
                        [  2221,   3088],
                        [  2172,   3064],
                        [  2113,   3027],
                        [  2046,   2977],
                        [  1972,   2923],
                        [  1892,   2864],
                        [  1805,   2802],
                        [  1716,   2736],
                        [  1625,   2666],
                        [  1535,   2594],
                        [  1448,   2519],
                        [  1364,   2442],
                        [  1281,   2363],
                        [  1199,   2282],
                        [  1109,   2195],
                        [  1012,   2106],
                        [   909,   2016],
                        [   800,   1923],
                        [   686,   1830],
                        [   567,   1736],
                        [   443,   1638],
                        [   315,   1541],
                        [   180,   1437],
                        [    40,   1330],
                        [  -106,   1219],
                        [  -256,   1103],
                        [  -423,    969],
                        [  -608,    816],
                        [  -801,    652],
                        [ -1005,    475],
                        [ -1206,    300],
                        [ -1405,    124],
                        [ -1594,    -44],
                        [ -1775,   -206],
                        [ -1939,   -355],
                        [ -2087,   -492],
                        [ -2217,   -613],
                        [ -2329,   -717],
                        [ -2425,   -803],
                        [ -2504,   -870],
                        [ -2569,   -919],
                        [ -2621,   -947],
                        [ -2660,   -959],
                        [ -2686,   -951],
                        [ -2696,   -928],
                        [ -2691,   -888],
                        [ -2667,   -835],
                        [ -2623,   -769],
                        [ -2564,   -693],
                        [ -2492,   -606],
                        [ -2407,   -514],
                        [ -2309,   -414],
                        [ -2204,   -311],
                        [ -2091,   -206],
                        [ -1971,   -102],
                        [ -1848,      0],
                        [ -1722,     98],
                        [ -1593,    190],
                        [ -1467,    275],
                        [ -1340,    353],
                        [ -1217,    421],
                        [ -1099,    479],
                        [  -989,    527],
                        [  -886,    566],
                        [  -792,    593],
                        [  -710,    609],
                        [  -639,    613],
                        [  -578,    609],
                        [  -530,    592],
                        [  -494,    564],
                        [  -457,    540],
                        [  -395,    542],
                        [  -301,    580],
                        [  -173,    653],
                        [   -10,    765],
                        [   189,    913],
                        [   398,   1074],
                        [   588,   1217],
                        [   752,   1333],
                        [   890,   1424],
                        [  1003,   1493],
                        [  1089,   1539],
                        [  1148,   1564],
                        [  1181,   1571],
                        [  1191,   1562],
                        [  1178,   1536],
                        [  1149,   1496],
                        [  1106,   1441],
                        [  1053,   1372],
                        [   992,   1292],
                        [   925,   1199],
                        [   853,   1097],
                        [   778,    986],
                        [   700,    869],
                        [   622,    749],
                        [   544,    626],
                        [   466,    502],
                        [   390,    378],
                        [   314,    254],
                        [   240,    130],
                        [   166,      8],
                        [    93,   -113],
                        [    21,   -233],
                        [   -51,   -351],
                        [  -124,   -468],
                        [  -196,   -584],
                        [  -270,   -700],
                        [  -345,   -815],
                        [  -424,   -930],
                        [  -505,  -1046],
                        [  -591,  -1161],
                        [  -680,  -1277],
                        [  -774,  -1393],
                        [  -873,  -1508],
                        [  -975,  -1621],
                        [ -1082,  -1731],
                        [ -1192,  -1840],
                        [ -1307,  -1947],
                        [ -1422,  -2058],
                        [ -1540,  -2172],
                        [ -1656,  -2290],
                        [ -1772,  -2411],
                        [ -1887,  -2533],
                        [ -2002,  -2656],
                        [ -2117,  -2777],
                        [ -2233,  -2897],
                        [ -2351,  -3018],
                        [ -2471,  -3140],
                        [ -2593,  -3265],
                        [ -2715,  -3395],
                        [ -2841,  -3523],
                        [ -2969,  -3651],
                        [ -3105,  -3779],
                        [ -3247,  -3906],
                        [ -3393,  -4028],
                        [ -3543,  -4145],
                        [ -3686,  -4254],
                        [ -3822,  -4354],
                        [ -3940,  -4441],
                        [ -4039,  -4517],
                        [ -4119,  -4578],
                        [ -4177,  -4626],
                        [ -4216,  -4660],
                        [ -4233,  -4678],
                        [ -4232,  -4682],
                        [ -4210,  -4673],
                        [ -4175,  -4654],
                        [ -4128,  -4626],
                        [ -4063,  -4583],
                        [ -3980,  -4526],
                        [ -3868,  -4438],
                        [ -3726,  -4323],
                        [ -3560,  -4182],
                        [ -3371,  -4019],
                        [ -3164,  -3838],
                        [ -2940,  -3640],
                        [ -2706,  -3433],
                        [ -2464,  -3215],
                        [ -2218,  -2995],
                        [ -1970,  -2771],
                        [ -1723,  -2550],
                        [ -1479,  -2330],
                        [ -1237,  -2118],
                        [ -1000,  -1913],
                        [  -769,  -1718],
                        [  -544,  -1534],
                        [  -328,  -1363],
                        [  -121,  -1204],
                        [    70,  -1060],
                        [   245,   -930],
                        [   401,   -814],
                        [   540,   -713],
                        [   660,   -628],
                        [   761,   -557],
                        [   843,   -501],
                        [   908,   -457],
                        [   955,   -425],
                        [   984,   -404],
                        [   997,   -392],
                        [   995,   -389],
                        [   977,   -393],
                        [   945,   -404],
                        [   903,   -419],
                        [   848,   -438],
                        [   787,   -460],
                        [   717,   -483],
                        [   645,   -508],
                        [   568,   -533],
                        [   491,   -557],
                        [   413,   -580],
                        [   336,   -602],
                        [   263,   -620],
                        [   196,   -634],
                        [   119,   -657],
                        [    18,   -709],
                        [  -115,   -792],
                        [  -276,   -908],
                        [  -470,  -1059],
                        [  -695,  -1242],
                        [  -930,  -1437],
                        [ -1146,  -1614],
                        [ -1338,  -1769],
                        [ -1505,  -1899],
                        [ -1645,  -2006],
                        [ -1756,  -2089],
                        [ -1837,  -2148],
                        [ -1887,  -2186],
                        [ -1908,  -2202],
                        [ -1901,  -2197],
                        [ -1868,  -2172],
                        [ -1816,  -2126],
                        [ -1745,  -2060],
                        [ -1662,  -1974],
                        [ -1565,  -1870],
                        [ -1458,  -1749],
                        [ -1341,  -1612],
                        [ -1218,  -1464],
                        [ -1090,  -1306],
                        [  -959,  -1140],
                        [  -826,   -969],
                        [  -693,   -794],
                        [  -562,   -617],
                        [  -433,   -440],
                        [  -308,   -263],
                        [  -188,    -90],
                        [   -72,     78],
                        [    37,    241],
                        [   138,    397],
                        [   232,    546],
                        [   318,    687],
                        [   394,    817],
                        [   462,    939],
                        [   521,   1050],
                        [   570,   1150],
                        [   611,   1237],
                        [   641,   1311],
                        [   662,   1369],
                        [   674,   1411],
                        [   675,   1432],
                        [   667,   1434],
                        [   648,   1420],
                        [   619,   1390],
                        [   578,   1352],
                        [   526,   1306],
                        [   462,   1255],
                        [   387,   1199],
                        [   305,   1139],
                        [   215,   1074],
                        [   121,   1006],
                        [    26,    934],
                        [   -70,    866],
                        [  -166,    800],
                        [  -258,    738],
                        [  -346,    678],
                        [  -422,    625],
                        [  -483,    577],
                        [  -527,    535],
                        [  -553,    498],
                        [  -565,    466],
                        [  -564,    437],
                        [  -565,    410],
                        [  -565,    384],
                        [  -572,    358],
                        [  -585,    332],
                        [  -605,    307],
                        [  -629,    282],
                        [  -657,    259],
                        [  -689,    238],
                        [  -715,    228],
                        [  -735,    229],
                        [  -744,    243],
                        [  -744,    270],
                        [  -747,    294],
                        [  -750,    319],
                        [  -768,    328],
                        [  -800,    324],
                        [  -843,    309],
                        [  -898,    280],
                        [  -961,    244],
                        [ -1034,    197],
                        [ -1111,    146],
                        [ -1193,     90],
                        [ -1276,     32],
                        [ -1361,    -28],
                        [ -1445,    -89],
                        [ -1529,   -149],
                        [ -1611,   -207],
                        [ -1692,   -264],
                        [ -1774,   -318],
                        [ -1855,   -368],
                        [ -1935,   -414],
                        [ -2012,   -457],
                        [ -2083,   -497],
                        [ -2149,   -533],
                        [ -2209,   -565],
                        [ -2264,   -594],
                        [ -2312,   -619],
                        [ -2352,   -642],
                        [ -2386,   -662],
                        [ -2413,   -680],
                        [ -2433,   -696],
                        [ -2446,   -711],
                        [ -2451,   -726],
                        [ -2451,   -742],
                        [ -2444,   -758],
                        [ -2430,   -774],
                        [ -2412,   -792],
                        [ -2387,   -812],
                        [ -2360,   -832],
                        [ -2327,   -853],
                        [ -2293,   -875],
                        [ -2255,   -898],
                        [ -2215,   -921],
                        [ -2173,   -944],
                        [ -2130,   -969],
                        [ -2087,   -993],
                        [ -2028,  -1003],
                        [ -1943,   -986],
                        [ -1827,   -938],
                        [ -1681,   -860],
                        [ -1501,   -746],
                        [ -1286,   -597],
                        [ -1053,   -431],
                        [  -826,   -270],
                        [  -609,   -119],
                        [  -402,     22],
                        [  -210,    151],
                        [   -32,    268],
                        [   126,    375],
                        [   265,    470],
                        [   385,    553],
                        [   484,    626],
                        [   567,    687],
                        [   634,    735],
                        [   689,    769],
                        [   734,    789],
                        [   769,    794],
                        [   794,    784],
                        [   809,    760],
                        [   817,    722],
                        [   817,    672],
                        [   810,    610],
                        [   796,    538],
                        [   776,    455],
                        [   749,    363],
                        [   717,    263],
                        [   678,    156],
                        [   635,     41],
                        [   584,    -78],
                        [   528,   -203],
                        [   467,   -332],
                        [   402,   -466],
                        [   332,   -603],
                        [   258,   -743],
                        [   180,   -884],
                        [    98,  -1027],
                        [    14,  -1168],
                        [   -75,  -1311],
                        [  -165,  -1447],
                        [  -257,  -1579],
                        [  -349,  -1698],
                        [  -442,  -1805],
                        [  -533,  -1896],
                        [  -623,  -1972],
                        [  -709,  -2038],
                        [  -789,  -2093],
                        [  -862,  -2146],
                        [  -928,  -2197],
                        [  -986,  -2248],
                        [ -1036,  -2300],
                        [ -1081,  -2347],
                        [ -1120,  -2392],
                        [ -1156,  -2435],
                        [ -1187,  -2476],
                        [ -1214,  -2515],
                        [ -1238,  -2552],
                        [ -1265,  -2588],
                        [ -1294,  -2623],
                        [ -1336,  -2656],
                        [ -1389,  -2689],
                        [ -1450,  -2719],
                        [ -1520,  -2745],
                        [ -1587,  -2763],
                        [ -1650,  -2776],
                        [ -1696,  -2776],
                        [ -1725,  -2767],
                        [ -1735,  -2748],
                        [ -1726,  -2719],
                        [ -1699,  -2679],
                        [ -1654,  -2629],
                        [ -1601,  -2579],
                        [ -1538,  -2528],
                        [ -1478,  -2485],
                        [ -1420,  -2450],
                        [ -1363,  -2420],
                        [ -1308,  -2395],
                        [ -1240,  -2359],
                        [ -1157,  -2310],
                        [ -1055,  -2243],
                        [  -933,  -2158],
                        [  -795,  -2060],
                        [  -641,  -1946],
                        [  -475,  -1823],
                        [  -299,  -1690],
                        [  -117,  -1551],
                        [    72,  -1406],
                        [   261,  -1260],
                        [   450,  -1113],
                        [   635,   -967],
                        [   816,   -822],
                        [   992,   -682],
                        [  1164,   -546],
                        [  1332,   -417],
                        [  1496,   -294],
                        [  1653,   -180],
                        [  1805,    -72],
                        [  1946,     26],
                        [  2078,    115],
                        [  2199,    197],
                        [  2310,    269],
                        [  2409,    332],
                        [  2497,    388],
                        [  2572,    435],
                        [  2637,    475],
                        [  2689,    509],
                        [  2731,    538],
                        [  2763,    562],
                        [  2784,    583],
                        [  2796,    600],
                        [  2799,    616],
                        [  2796,    630],
                        [  2785,    643],
                        [  2770,    655],
                        [  2750,    668],
                        [  2727,    681],
                        [  2701,    696],
                        [  2674,    711],
                        [  2646,    728],
                        [  2619,    747],
                        [  2581,    757],
                        [  2524,    748],
                        [  2446,    721],
                        [  2349,    673],
                        [  2227,    600],
                        [  2082,    505],
                        [  1925,    397],
                        [  1773,    296],
                        [  1630,    205],
                        [  1497,    124],
                        [  1376,     54],
                        [  1271,     -7],
                        [  1181,    -55],
                        [  1108,    -95],
                        [  1055,   -124],
                        [  1016,   -145],
                        [   995,   -157],
                        [   985,   -158],
                        [   985,   -149],
                        [   991,   -129],
                        [  1003,    -99],
                        [  1019,    -59],
                        [  1039,     -8],
                        [  1062,     51],
                        [  1086,    118],
                        [  1109,    192],
                        [  1132,    271],
                        [  1153,    354],
                        [  1172,    441],
                        [  1187,    529],
                        [  1200,    618],
                        [  1210,    706],
                        [  1216,    793],
                        [  1216,    877],
                        [  1213,    958],
                        [  1205,   1035],
                        [  1192,   1109],
                        [  1173,   1178],
                        [  1150,   1242],
                        [  1121,   1300],
                        [  1088,   1352],
                        [  1050,   1395],
                        [  1007,   1431],
                        [   960,   1451],
                        [   908,   1457],
                        [   853,   1442],
                        [   794,   1406],
                        [   730,   1353],
                        [   661,   1280],
                        [   587,   1201],
                        [   505,   1114],
                        [   420,   1033],
                        [   329,    956],
                        [   236,    883],
                        [   142,    816],
                        [    50,    752],
                        [   -41,    691],
                        [  -128,    637],
                        [  -210,    589],
                        [  -283,    549],
                        [  -345,    516],
                        [  -388,    492],
                        [  -409,    479],
                        [  -404,    476],
                        [  -375,    482],
                        [  -328,    495],
                        [  -265,    514],
                        [  -201,    535],
                        [  -135,    557],
                        [   -76,    579],
                        [   -25,    603],
                        [    18,    625],
                        [    53,    647],
                        [    83,    670],
                        [   106,    696],
                        [   139,    737],
                        [   178,    791],
                        [   228,    859],
                        [   288,    943],
                        [   349,   1029],
                        [   413,   1120],
                        [   460,   1197],
                        [   492,   1259],
                        [   506,   1307],
                        [   502,   1337],
                        [   482,   1354],
                        [   444,   1357],
                        [   394,   1348],
                        [   330,   1325],
                        [   256,   1294],
                        [   173,   1250],
                        [    87,   1200],
                        [    -2,   1142],
                        [   -93,   1078],
                        [  -184,   1008],
                        [  -282,    934],
                        [  -384,    857],
                        [  -491,    778],
                        [  -603,    696],
                        [  -717,    615],
                        [  -833,    533],
                        [  -947,    453],
                        [ -1060,    373],
                        [ -1169,    296],
                        [ -1276,    220],
                        [ -1375,    149],
                        [ -1469,     80],
                        [ -1555,     15],
                        [ -1634,    -47],
                        [ -1705,   -105],
                        [ -1766,   -159],
                        [ -1818,   -210],
                        [ -1861,   -258],
                        [ -1894,   -302],
                        [ -1917,   -344],
                        [ -1930,   -381],
                        [ -1934,   -415],
                        [ -1929,   -445],
                        [ -1914,   -472],
                        [ -1893,   -495],
                        [ -1862,   -514],
                        [ -1827,   -531],
                        [ -1782,   -542],
                        [ -1723,   -541],
                        [ -1645,   -524],
                        [ -1546,   -488],
                        [ -1428,   -434],
                        [ -1289,   -359],
                        [ -1125,   -260],
                        [  -947,   -150],
                        [  -768,    -38],
                        [  -592,     69],
                        [  -418,    174],
                        [  -251,    274],
                        [   -92,    367],
                        [    54,    456],
                        [   188,    537],
                        [   305,    613],
                        [   407,    682],
                        [   495,    743],
                        [   567,    795],
                        [   630,    837],
                        [   683,    868],
                        [   725,    886],
                        [   757,    894],
                        [   781,    886],
                        [   795,    865],
                        [   802,    832],
                        [   801,    786],
                        [   793,    727],
                        [   778,    657],
                        [   757,    577],
                        [   730,    487],
                        [   697,    389],
                        [   659,    284],
                        [   617,    173],
                        [   570,     57],
                        [   520,    -63],
                        [   467,   -186],
                        [   414,   -311],
                        [   359,   -439],
                        [   304,   -566],
                        [   249,   -691],
                        [   195,   -813],
                        [   141,   -932],
                        [    89,  -1042],
                        [    40,  -1142],
                        [    -7,  -1224],
                        [   -50,  -1285],
                        [   -87,  -1323],
                        [  -119,  -1336],
                        [  -144,  -1330],
                        [  -160,  -1307],
                        [  -167,  -1280],
                        [  -164,  -1249],
                        [  -153,  -1220],
                        [  -132,  -1194],
                        [  -104,  -1166],
                        [   -70,  -1137],
                        [   -31,  -1104],
                        [    14,  -1069],
                        [    60,  -1034],
                        [   109,   -997],
                        [   150,   -961],
                        [   184,   -928],
                        [   201,   -897],
                        [   201,   -869],
                        [   187,   -843],
                        [   157,   -820],
                        [   126,   -794],
                        [    92,   -767],
                        [    69,   -735],
                        [    58,   -699],
                        [    58,   -659],
                        [    70,   -615],
                        [    93,   -569],
                        [   128,   -519],
                        [   164,   -478],
                        [   202,   -443],
                        [   230,   -423],
                        [   250,   -418],
                        [   262,   -426],
                        [   264,   -447],
                        [   271,   -465],
                        [   284,   -481],
                        [   310,   -487],
                        [   349,   -481],
                        [   403,   -466],
                        [   470,   -441],
                        [   548,   -409],
                        [   636,   -368],
                        [   732,   -321],
                        [   834,   -268],
                        [   937,   -211],
                        [  1039,   -149],
                        [  1137,    -85],
                        [  1229,    -19],
                        [  1319,     49],
                        [  1407,    118],
                        [  1499,    186],
                        [  1594,    254],
                        [  1692,    321],
                        [  1793,    386],
                        [  1894,    449],
                        [  1995,    510],
                        [  2094,    569],
                        [  2191,    624],
                        [  2286,    678],
                        [  2377,    728],
                        [  2463,    776],
                        [  2545,    821],
                        [  2622,    863],
                        [  2694,    904],
                        [  2761,    942],
                        [  2823,    979],
                        [  2878,   1015],
                        [  2927,   1050],
                        [  2970,   1085],
                        [  3006,   1118],
                        [  3038,   1152],
                        [  3063,   1186],
                        [  3083,   1220],
                        [  3099,   1252],
                        [  3109,   1285],
                        [  3115,   1318],
                        [  3116,   1349],
                        [  3106,   1373],
                        [  3085,   1389],
                        [  3051,   1395],
                        [  3004,   1391],
                        [  2942,   1374],
                        [  2862,   1341],
                        [  2771,   1298],
                        [  2678,   1255],
                        [  2581,   1211],
                        [  2484,   1168],
                        [  2387,   1125],
                        [  2293,   1083],
                        [  2204,   1042],
                        [  2121,   1003],
                        [  2043,    964],
                        [  1974,    925],
                        [  1913,    886],
                        [  1854,    849],
                        [  1800,    813],
                        [  1747,    780],
                        [  1695,    749],
                        [  1644,    723],
                        [  1593,    702],
                        [  1541,    687],
                        [  1489,    677],
                        [  1436,    673],
                        [  1381,    674],
                        [  1324,    679],
                        [  1267,    689],
                        [  1207,    701],
                        [  1146,    717],
                        [  1085,    735],
                        [  1021,    754],
                        [   957,    774],
                        [   891,    796],
                        [   824,    818],
                        [   755,    841],
                        [   685,    864],
                        [   613,    886],
                        [   540,    907],
                        [   468,    927],
                        [   395,    943],
                        [   321,    956],
                        [   248,    957],
                        [   175,    947],
                        [   102,    918],
                        [    31,    870],
                        [   -42,    804],
                        [  -115,    720],
                        [  -189,    631],
                        [  -263,    537],
                        [  -340,    453],
                        [  -417,    380],
                        [  -493,    316],
                        [  -568,    260],
                        [  -639,    210],
                        [  -709,    164],
                        [  -773,    124],
                        [  -832,     90],
                        [  -879,     63],
                        [  -917,     44],
                        [  -932,     36],
                        [  -926,     37],
                        [  -896,     47],
                        [  -843,     67],
                        [  -774,     93],
                        [  -687,    126],
                        [  -602,    159],
                        [  -516,    194],
                        [  -436,    229],
                        [  -363,    263],
                        [  -299,    297],
                        [  -243,    329],
                        [  -192,    364],
                        [  -146,    401],
                        [   -97,    449],
                        [   -44,    507],
                        [    16,    577],
                        [    82,    658],
                        [   150,    743],
                        [   220,    834],
                        [   275,    912],
                        [   318,    981],
                        [   344,   1037],
                        [   352,   1081],
                        [   344,   1112],
                        [   319,   1131],
                        [   281,   1139],
                        [   228,   1135],
                        [   169,   1121],
                        [   103,   1099],
                        [    37,   1067],
                        [   -28,   1027],
                        [   -92,    981],
                        [  -154,    927],
                        [  -222,    870],
                        [  -294,    808],
                        [  -375,    743],
                        [  -464,    676],
                        [  -558,    607],
                        [  -657,    537],
                        [  -756,    468],
                        [  -859,    398],
                        [  -960,    331],
                        [ -1060,    266],
                        [ -1156,    202],
                        [ -1250,    142],
                        [ -1339,     85],
                        [ -1423,     32],
                        [ -1502,    -18],
                        [ -1574,    -63],
                        [ -1639,   -105],
                        [ -1696,   -143],
                        [ -1744,   -177],
                        [ -1783,   -207],
                        [ -1814,   -235],
                        [ -1835,   -258],
                        [ -1848,   -280],
                        [ -1853,   -297],
                        [ -1850,   -311],
                        [ -1840,   -323],
                        [ -1822,   -332],
                        [ -1797,   -337],
                        [ -1763,   -339],
                        [ -1718,   -334],
                        [ -1666,   -323],
                        [ -1606,   -308],
                        [ -1535,   -284],
                        [ -1453,   -251],
                        [ -1363,   -212],
                        [ -1270,   -172],
                        [ -1177,   -133],
                        [ -1083,    -94],
                        [  -992,    -58],
                        [  -905,    -24],
                        [  -825,      7],
                        [  -752,     35],
                        [  -687,     60],
                        [  -634,     82],
                        [  -588,    102],
                        [  -555,    119],
                        [  -527,    131],
                        [  -507,    140],
                        [  -493,    141],
                        [  -485,    137],
                        [  -483,    126],
                        [  -485,    106],
                        [  -492,     78],
                        [  -503,     41],
                        [  -517,     -3],
                        [  -534,    -54],
                        [  -553,   -112],
                        [  -574,   -176],
                        [  -596,   -244],
                        [  -620,   -316],
                        [  -644,   -390],
                        [  -669,   -466],
                        [  -691,   -544],
                        [  -713,   -622],
                        [  -732,   -700],
                        [  -748,   -776],
                        [  -761,   -850],
                        [  -769,   -921],
                        [  -774,   -987],
                        [  -775,  -1048],
                        [  -772,  -1099],
                        [  -764,  -1138],
                        [  -751,  -1159],
                        [  -732,  -1159],
                        [  -708,  -1134],
                        [  -678,  -1086],
                        [  -642,  -1020],
                        [  -598,   -934],
                        [  -548,   -847],
                        [  -490,   -760],
                        [  -426,   -678],
                        [  -355,   -601],
                        [  -280,   -526],
                        [  -200,   -451],
                        [  -117,   -375],
                        [   -31,   -297],
                        [    53,   -220],
                        [   136,   -145],
                        [   206,    -76],
                        [   266,    -11],
                        [   308,     46],
                        [   332,     96],
                        [   338,    140],
                        [   326,    176],
                        [   307,    209],
                        [   281,    239],
                        [   259,    267],
                        [   239,    293],
                        [   223,    317],
                        [   212,    338],
                        [   206,    358],
                        [   203,    375],
                        [   197,    380],
                        [   189,    376],
                        [   174,    359],
                        [   150,    328],
                        [   116,    284],
                        [    74,    228],
                        [    33,    170],
                        [    -6,    110],
                        [   -35,     56],
                        [   -54,      7],
                        [   -63,    -36],
                        [   -60,    -73],
                        [   -47,   -103],
                        [   -23,   -128],
                        [     7,   -145],
                        [    45,   -158],
                        [    80,   -163],
                        [   112,   -163],
                        [   140,   -158],
                        [   163,   -148],
                        [   187,   -133],
                        [   210,   -114],
                        [   241,    -90],
                        [   283,    -63],
                        [   333,    -33],
                        [   392,      0],
                        [   459,     36],
                        [   532,     74],
                        [   609,    114],
                        [   692,    156],
                        [   778,    198],
                        [   867,    242],
                        [   957,    287],
                        [  1050,    331],
                        [  1142,    375],
                        [  1235,    418],
                        [  1327,    462],
                        [  1417,    504],
                        [  1504,    545],
                        [  1587,    587],
                        [  1664,    627],
                        [  1736,    667],
                        [  1802,    706],
                        [  1862,    743],
                        [  1916,    779],
                        [  1962,    814],
                        [  2002,    846],
                        [  2035,    876],
                        [  2060,    904],
                        [  2075,    928],
                        [  2083,    948],
                        [  2082,    965],
                        [  2074,    977],
                        [  2055,    984],
                        [  2025,    982],
                        [  1983,    973],
                        [  1935,    960],
                        [  1879,    942],
                        [  1817,    919],
                        [  1749,    894],
                        [  1679,    865],
                        [  1605,    833],
                        [  1529,    798],
                        [  1452,    761],
                        [  1376,    719],
                        [  1302,    675],
                        [  1228,    628],
                        [  1155,    577],
                        [  1082,    524],
                        [  1009,    470],
                        [   935,    418],
                        [   862,    366],
                        [   788,    320],
                        [   714,    277],
                        [   640,    239],
                        [   566,    206],
                        [   492,    178],
                        [   418,    154],
                        [   345,    136],
                        [   272,    121],
                        [   201,    111],
                        [   129,    104],
                        [    59,    102],
                        [    -9,    103],
                        [   -77,    107],
                        [  -144,    115],
                        [  -210,    126],
                        [  -275,    139],
                        [  -340,    154],
                        [  -403,    169],
                        [  -463,    184],
                        [  -522,    198],
                        [  -579,    204],
                        [  -635,    202],
                        [  -687,    185],
                        [  -739,    153],
                        [  -787,    106],
                        [  -835,     44],
                        [  -882,    -21],
                        [  -927,    -90],
                        [  -973,   -149],
                        [ -1017,   -197],
                        [ -1062,   -238],
                        [ -1106,   -271],
                        [ -1149,   -304],
                        [ -1190,   -334],
                        [ -1230,   -364],
                        [ -1268,   -392],
                        [ -1296,   -414],
                        [ -1317,   -432],
                        [ -1324,   -444],
                        [ -1318,   -449],
                        [ -1295,   -449],
                        [ -1257,   -440],
                        [ -1207,   -428],
                        [ -1146,   -412],
                        [ -1086,   -395],
                        [ -1024,   -376],
                        [  -966,   -357],
                        [  -912,   -338],
                        [  -862,   -319],
                        [  -817,   -301],
                        [  -776,   -280],
                        [  -738,   -256],
                        [  -697,   -226],
                        [  -655,   -188],
                        [  -607,   -142],
                        [  -556,    -89],
                        [  -502,    -32],
                        [  -446,     29],
                        [  -399,     86],
                        [  -358,    137],
                        [  -330,    183],
                        [  -312,    223],
                        [  -305,    255],
                        [  -309,    281],
                        [  -323,    301],
                        [  -345,    314],
                        [  -366,    322],
                        [  -389,    323],
                        [  -405,    320],
                        [  -417,    313],
                        [  -423,    301],
                        [  -423,    285],
                        [  -427,    267],
                        [  -435,    245],
                        [  -451,    222],
                        [  -476,    197],
                        [  -509,    171],
                        [  -546,    144],
                        [  -589,    116],
                        [  -636,     89],
                        [  -686,     62],
                        [  -739,     34],
                        [  -794,      9],
                        [  -850,    -15],
                        [  -908,    -39],
                        [  -965,    -60],
                        [ -1024,    -80],
                        [ -1081,    -99],
                        [ -1137,   -115],
                        [ -1190,   -131],
                        [ -1240,   -145],
                        [ -1285,   -158],
                        [ -1327,   -171],
                        [ -1364,   -184],
                        [ -1397,   -197],
                        [ -1425,   -210],
                        [ -1450,   -223],
                        [ -1469,   -236],
                        [ -1485,   -249],
                        [ -1497,   -262],
                        [ -1505,   -278],
                        [ -1510,   -294],
                        [ -1514,   -314],
                        [ -1515,   -334],
                        [ -1514,   -355],
                        [ -1509,   -375],
                        [ -1501,   -393],
                        [ -1490,   -410],
                        [ -1477,   -428],
                        [ -1463,   -445],
                        [ -1448,   -463],
                        [ -1433,   -482],
                        [ -1419,   -501],
                        [ -1407,   -520],
                        [ -1396,   -540],
                        [ -1388,   -560],
                        [ -1382,   -578],
                        [ -1380,   -594],
                        [ -1382,   -608],
                        [ -1387,   -619],
                        [ -1393,   -630],
                        [ -1402,   -639],
                        [ -1411,   -651],
                        [ -1421,   -662],
                        [ -1431,   -676],
                        [ -1441,   -692],
                        [ -1450,   -710],
                        [ -1458,   -730],
                        [ -1465,   -750],
                        [ -1470,   -771],
                        [ -1472,   -792],
                        [ -1472,   -814],
                        [ -1469,   -834],
                        [ -1463,   -855],
                        [ -1452,   -873],
                        [ -1439,   -891],
                        [ -1420,   -905],
                        [ -1397,   -918],
                        [ -1368,   -927],
                        [ -1336,   -934],
                        [ -1299,   -937],
                        [ -1259,   -934],
                        [ -1214,   -925],
                        [ -1167,   -908],
                        [ -1116,   -876],
                        [ -1061,   -830],
                        [ -1004,   -769],
                        [  -945,   -692],
                        [  -885,   -604],
                        [  -821,   -505],
                        [  -756,   -410],
                        [  -690,   -318],
                        [  -620,   -232],
                        [  -548,   -154],
                        [  -475,    -78],
                        [  -399,     -4],
                        [  -323,     72],
                        [  -248,    150],
                        [  -176,    224],
                        [  -106,    296],
                        [   -44,    362],
                        [    11,    423],
                        [    55,    478],
                        [    89,    524],
                        [   111,    563],
                        [   120,    594],
                        [   124,    620],
                        [   119,    640],
                        [   112,    656],
                        [   102,    666],
                        [    92,    674],
                        [    79,    675],
                        [    65,    674],
                        [    50,    667],
                        [    32,    652],
                        [     9,    631],
                        [   -20,    600],
                        [   -55,    560],
                        [   -98,    511],
                        [  -146,    454],
                        [  -195,    396],
                        [  -245,    335],
                        [  -289,    276],
                        [  -328,    219],
                        [  -359,    167],
                        [  -382,    117],
                        [  -397,     72],
                        [  -405,     31],
                        [  -409,     -4],
                        [  -410,    -36],
                        [  -415,    -62],
                        [  -425,    -82],
                        [  -440,    -97],
                        [  -459,   -106],
                        [  -479,   -112],
                        [  -501,   -112],
                        [  -509,   -108],
                        [  -509,   -100],
                        [  -499,    -88],
                        [  -479,    -72],
                        [  -450,    -52],
                        [  -412,    -29],
                        [  -366,     -3],
                        [  -314,     24],
                        [  -256,     54],
                        [  -192,     86],
                        [  -123,    119],
                        [   -49,    152],
                        [    28,    184],
                        [   109,    218],
                        [   191,    249],
                        [   274,    280],
                        [   355,    310],
                        [   435,    340],
                        [   509,    366],
                        [   582,    393],
                        [   648,    418],
                        [   710,    440],
                        [   766,    462],
                        [   817,    480],
                        [   860,    496],
                        [   898,    509],
                        [   928,    521],
                        [   951,    531],
                        [   970,    540],
                        [   983,    548],
                        [   992,    555],
                        [   995,    560],
                        [   992,    561],
                        [   982,    557],
                        [   966,    550],
                        [   945,    539],
                        [   919,    523],
                        [   887,    505],
                        [   852,    484],
                        [   813,    461],
                        [   770,    436],
                        [   724,    408],
                        [   677,    377],
                        [   628,    345],
                        [   581,    307],
                        [   536,    267],
                        [   492,    222],
                        [   451,    175],
                        [   410,    127],
                        [   372,     78],
                        [   336,     32],
                        [   301,    -13],
                        [   268,    -54],
                        [   237,    -93],
                        [   208,   -129],
                        [   180,   -162],
                        [   154,   -190],
                        [   128,   -215],
                        [   103,   -236],
                        [    80,   -254],
                        [    58,   -267],
                        [    36,   -278],
                        [    14,   -286],
                        [    -8,   -290],
                        [   -30,   -292],
                        [   -53,   -291],
                        [   -75,   -287],
                        [   -97,   -282],
                        [  -119,   -277],
                        [  -140,   -271],
                        [  -162,   -271],
                        [  -182,   -274],
                        [  -202,   -283],
                        [  -222,   -299],
                        [  -240,   -320],
                        [  -257,   -345],
                        [  -273,   -371],
                        [  -288,   -394],
                        [  -305,   -410],
                        [  -322,   -419],
                        [  -342,   -424],
                        [  -364,   -427],
                        [  -388,   -432],
                        [  -414,   -441],
                        [  -442,   -453],
                        [  -470,   -470],
                        [  -497,   -485],
                        [  -523,   -501],
                        [  -548,   -518],
                        [  -570,   -533],
                        [  -587,   -545],
                        [  -599,   -556],
                        [  -606,   -565],
                        [  -609,   -571],
                        [  -609,   -578],
                        [  -607,   -583],
                        [  -603,   -587],
                        [  -597,   -592],
                        [  -592,   -594],
                        [  -583,   -596],
                        [  -574,   -596],
                        [  -562,   -594],
                        [  -546,   -587],
                        [  -525,   -576],
                        [  -499,   -561],
                        [  -466,   -540],
                        [  -430,   -515],
                        [  -388,   -486],
                        [  -345,   -457],
                        [  -303,   -427],
                        [  -264,   -399],
                        [  -228,   -372],
                        [  -197,   -347],
                        [  -167,   -323],
                        [  -141,   -301],
                        [  -117,   -280],
                        [   -87,   -262],
                        [   -51,   -246],
                        [    -8,   -232],
                        [    43,   -219],
                        [   102,   -208],
                        [   167,   -199],
                        [   229,   -192],
                        [   288,   -185],
                        [   339,   -181],
                        [   382,   -178],
                        [   417,   -176],
                        [   444,   -175],
                        [   464,   -176],
                        [   476,   -176],
                        [   481,   -179],
                        [   479,   -182],
                        [   470,   -186],
                        [   453,   -192],
                        [   430,   -197],
                        [   400,   -203],
                        [   363,   -210],
                        [   322,   -217],
                        [   276,   -223],
                        [   227,   -231],
                        [   176,   -238],
                        [   124,   -247],
                        [    71,   -257],
                        [    17,   -267],
                        [   -37,   -280],
                        [   -90,   -293],
                        [  -143,   -306],
                        [  -195,   -322],
                        [  -245,   -338],
                        [  -294,   -355],
                        [  -341,   -375],
                        [  -388,   -397],
                        [  -434,   -423],
                        [  -479,   -450],
                        [  -524,   -479],
                        [  -567,   -509],
                        [  -608,   -538],
                        [  -647,   -566],
                        [  -683,   -592],
                        [  -717,   -618],
                        [  -750,   -643],
                        [  -779,   -666],
                        [  -804,   -688],
                        [  -826,   -710],
                        [  -843,   -730],
                        [  -856,   -749],
                        [  -867,   -765],
                        [  -878,   -776],
                        [  -887,   -782],
                        [  -898,   -783],
                        [  -908,   -779],
                        [  -918,   -770],
                        [  -927,   -757],
                        [  -935,   -741],
                        [  -942,   -723],
                        [  -947,   -703],
                        [  -951,   -680],
                        [  -952,   -656],
                        [  -951,   -630],
                        [  -948,   -602],
                        [  -941,   -574],
                        [  -931,   -544],
                        [  -918,   -514],
                        [  -902,   -483],
                        [  -882,   -449],
                        [  -858,   -415],
                        [  -831,   -381],
                        [  -800,   -345],
                        [  -765,   -309],
                        [  -728,   -273],
                        [  -689,   -236],
                        [  -648,   -197],
                        [  -605,   -156],
                        [  -561,   -113],
                        [  -516,    -66],
                        [  -471,    -15],
                        [  -427,     36],
                        [  -385,     89],
                        [  -345,    141],
                        [  -308,    190],
                        [  -271,    232],
                        [  -236,    267],
                        [  -199,    297],
                        [  -162,    318],
                        [  -124,    339],
                        [   -84,    360],
                        [   -44,    384],
                        [    -3,    412],
                        [    37,    440],
                        [    76,    466],
                        [   116,    494],
                        [   155,    521],
                        [   193,    546],
                        [   230,    568],
                        [   262,    587],
                        [   290,    601],
                        [   314,    613],
                        [   333,    622],
                        [   349,    626],
                        [   361,    629],
                        [   371,    629],
                        [   376,    626],
                        [   379,    620],
                        [   379,    613],
                        [   376,    601],
                        [   370,    587],
                        [   360,    569],
                        [   345,    547],
                        [   328,    522],
                        [   306,    493],
                        [   282,    463],
                        [   256,    431],
                        [   231,    400],
                        [   207,    368],
                        [   186,    338],
                        [   169,    310],
                        [   154,    284],
                        [   141,    259],
                        [   128,    238],
                        [   113,    219],
                        [    91,    202],
                        [    63,    189],
                        [    28,    179],
                        [   -12,    171],
                        [   -56,    166],
                        [  -103,    163],
                        [  -142,    163],
                        [  -176,    166],
                        [  -202,    171],
                        [  -223,    177],
                        [  -236,    186],
                        [  -243,    197],
                        [  -244,    208],
                        [  -239,    220],
                        [  -227,    234],
                        [  -209,    249],
                        [  -184,    263],
                        [  -154,    279],
                        [  -119,    293],
                        [   -78,    306],
                        [   -34,    319],
                        [    12,    329],
                        [    61,    339],
                        [   110,    347],
                        [   158,    353],
                        [   206,    358],
                        [   251,    360],
                        [   295,    362],
                        [   337,    362],
                        [   377,    359],
                        [   414,    356],
                        [   447,    350],
                        [   476,    342],
                        [   502,    334],
                        [   525,    325],
                        [   544,    315],
                        [   561,    305],
                        [   576,    294],
                        [   589,    282],
                        [   600,    267],
                        [   608,    251],
                        [   614,    232],
                        [   620,    212],
                        [   624,    191],
                        [   625,    170],
                        [   623,    147],
                        [   618,    125],
                        [   608,    104],
                        [   597,     82],
                        [   583,     61],
                        [   571,     37],
                        [   561,     12],
                        [   553,    -16],
                        [   550,    -47],
                        [   549,    -80],
                        [   552,   -115],
                        [   557,   -150],
                        [   565,   -185],
                        [   574,   -220],
                        [   586,   -255],
                        [   598,   -288],
                        [   613,   -319],
                        [   627,   -349],
                        [   641,   -376],
                        [   655,   -400],
                        [   668,   -422],
                        [   680,   -441],
                        [   690,   -459],
                        [   698,   -475],
                        [   704,   -488],
                        [   708,   -499],
                        [   709,   -506],
                        [   709,   -512],
                        [   707,   -516],
                        [   703,   -519],
                        [   696,   -522],
                        [   689,   -526],
                        [   680,   -530],
                        [   671,   -533],
                        [   663,   -535],
                        [   656,   -532],
                        [   650,   -526],
                        [   644,   -515],
                        [   639,   -499],
                        [   633,   -476],
                        [   624,   -449],
                        [   612,   -420],
                        [   596,   -391],
                        [   577,   -367],
                        [   554,   -349],
                        [   529,   -336],
                        [   501,   -327],
                        [   470,   -324],
                        [   436,   -326],
                        [   397,   -331],
                        [   356,   -340],
                        [   314,   -352],
                        [   271,   -364],
                        [   232,   -375],
                        [   194,   -388],
                        [   160,   -400],
                        [   131,   -411],
                        [   105,   -423],
                        [    83,   -433],
                        [    67,   -443],
                        [    54,   -453],
                        [    47,   -460],
                        [    45,   -466],
                        [    47,   -470],
                        [    54,   -474],
                        [    65,   -474],
                        [    82,   -471],
                        [   105,   -466],
                        [   134,   -457],
                        [   167,   -447],
                        [   203,   -434],
                        [   242,   -420],
                        [   283,   -404],
                        [   323,   -388],
                        [   366,   -370],
                        [   410,   -352],
                        [   457,   -333],
                        [   509,   -314],
                        [   566,   -297],
                        [   629,   -278],
                        [   699,   -260],
                        [   774,   -242],
                        [   855,   -225],
                        [   934,   -210],
                        [  1010,   -195],
                        [  1081,   -180],
                        [  1144,   -168],
                        [  1202,   -157],
                        [  1253,   -146],
                        [  1296,   -137],
                        [  1332,   -130],
                        [  1359,   -124],
                        [  1377,   -121],
                        [  1387,   -120],
                        [  1387,   -120],
                        [  1378,   -123],
                        [  1361,   -127],
                        [  1335,   -132],
                        [  1301,   -140],
                        [  1260,   -148],
                        [  1214,   -156],
                        [  1164,   -167],
                        [  1108,   -179],
                        [  1051,   -192],
                        [   989,   -206],
                        [   926,   -221],
                        [   860,   -238],
                        [   795,   -256],
                        [   728,   -274],
                        [   663,   -293],
                        [   598,   -312],
                        [   535,   -332],
                        [   475,   -352],
                        [   417,   -372],
                        [   362,   -392],
                        [   309,   -411],
                        [   258,   -430],
                        [   209,   -447],
                        [   162,   -462],
                        [   116,   -476],
                        [    72,   -488],
                        [    33,   -499],
                        [    -6,   -508],
                        [   -37,   -517],
                        [   -61,   -523],
                        [   -80,   -530],
                        [   -90,   -535],
                        [   -98,   -539],
                        [  -101,   -539],
                        [  -104,   -535],
                        [  -107,   -527],
                        [  -111,   -512],
                        [  -115,   -492],
                        [  -120,   -465],
                        [  -125,   -434],
                        [  -130,   -398],
                        [  -136,   -358],
                        [  -141,   -315],
                        [  -146,   -268],
                        [  -150,   -220],
                        [  -154,   -171],
                        [  -155,   -119],
                        [  -155,    -69],
                        [  -154,    -17],
                        [  -150,     35],
                        [  -145,     88],
                        [  -137,    140],
                        [  -127,    190],
                        [  -116,    240],
                        [  -104,    287],
                        [   -91,    332],
                        [   -77,    375],
                        [   -63,    416],
                        [   -48,    457],
                        [   -33,    496],
                        [   -20,    531],
                        [    -8,    563],
                        [     1,    588],
                        [     6,    606],
                        [     7,    615],
                        [     5,    615],
                        [     1,    607],
                        [    -5,    592],
                        [    -9,    570],
                        [   -11,    541],
                        [   -11,    514],
                        [    -9,    485],
                        [    -4,    462],
                        [     3,    440],
                        [    13,    421],
                        [    27,    405],
                        [    46,    394],
                        [    71,    387],
                        [    99,    383],
                        [   132,    380],
                        [   167,    377],
                        [   202,    375],
                        [   235,    372],
                        [   267,    368],
                        [   297,    365],
                        [   324,    360],
                        [   349,    356],
                        [   371,    351],
                        [   391,    345],
                        [   407,    341],
                        [   422,    337],
                        [   434,    333],
                        [   444,    329],
                        [   454,    327],
                        [   461,    324],
                        [   464,    321],
                        [   463,    318],
                        [   460,    314],
                        [   453,    309],
                        [   443,    305],
                        [   432,    301],
                        [   420,    298],
                        [   406,    296],
                        [   391,    293],
                        [   372,    293],
                        [   350,    293],
                        [   323,    293],
                        [   292,    294],
                        [   256,    297],
                        [   215,    300],
                        [   170,    303],
                        [   121,    307],
                        [    74,    312],
                        [    28,    318],
                        [   -16,    323],
                        [   -59,    329],
                        [   -99,    336],
                        [  -136,    341],
                        [  -169,    347],
                        [  -199,    353],
                        [  -223,    358],
                        [  -244,    364],
                        [  -259,    369],
                        [  -269,    374],
                        [  -274,    379],
                        [  -275,    382],
                        [  -270,    384],
                        [  -262,    384],
                        [  -250,    383],
                        [  -236,    380],
                        [  -220,    375],
                        [  -202,    370],
                        [  -182,    363],
                        [  -160,    354],
                        [  -137,    345],
                        [  -114,    333],
                        [   -90,    320],
                        [   -67,    306],
                        [   -44,    292],
                        [   -22,    275],
                        [    -2,    257],
                        [    16,    238],
                        [    33,    219],
                        [    50,    197],
                        [    66,    176],
                        [    82,    152],
                        [   100,    129],
                        [   119,    105],
                        [   137,     81],
                        [   158,     57],
                        [   176,     33],
                        [   192,     11],
                        [   203,    -10],
                        [   210,    -28],
                        [   213,    -43],
                        [   212,    -56],
                        [   211,    -68],
                        [   210,    -80],
                        [   214,    -93],
                        [   220,   -107],
                        [   230,   -124],
                        [   241,   -145],
                        [   257,   -166],
                        [   275,   -189],
                        [   294,   -215],
                        [   315,   -241],
                        [   338,   -268],
                        [   362,   -294],
                        [   384,   -319],
                        [   408,   -342],
                        [   429,   -365],
                        [   449,   -386],
                        [   468,   -406],
                        [   484,   -427],
                        [   499,   -444],
                        [   511,   -460],
                        [   522,   -474],
                        [   530,   -485],
                        [   536,   -494],
                        [   541,   -501],
                        [   545,   -507],
                        [   547,   -512],
                        [   548,   -515],
                        [   549,   -517],
                        [   552,   -513],
                        [   556,   -505],
                        [   563,   -489],
                        [   573,   -466],
                        [   584,   -437],
                        [   598,   -403],
                        [   610,   -365],
                        [   622,   -323],
                        [   630,   -280],
                        [   635,   -236],
                        [   637,   -197],
                        [   636,   -163],
                        [   632,   -132],
                        [   626,   -106],
                        [   613,    -88],
                        [   596,    -75],
                        [   574,    -68],
                        [   546,    -67],
                        [   514,    -69],
                        [   480,    -74],
                        [   447,    -79],
                        [   415,    -84],
                        [   385,    -89],
                        [   358,    -93],
                        [   335,    -98],
                        [   314,   -102],
                        [   297,   -104],
                        [   286,   -107],
                        [   277,   -109],
                        [   271,   -111],
                        [   268,   -112],
                        [   267,   -114],
                        [   267,   -115],
                        [   271,   -115],
                        [   278,   -113],
                        [   288,   -111],
                        [   303,   -106],
                        [   322,    -99],
                        [   344,    -92],
                        [   369,    -84],
                        [   396,    -74],
                        [   425,    -63],
                        [   455,    -52],
                        [   488,    -41],
                        [   521,    -29],
                        [   556,    -17],
                        [   592,     -7],
                        [   631,      5],
                        [   671,     16],
                        [   713,     27],
                        [   756,     36],
                        [   797,     45],
                        [   837,     52],
                        [   874,     59],
                        [   908,     64],
                        [   938,     68],
                        [   964,     72],
                        [   986,     73],
                        [  1003,     72],
                        [  1014,     71],
                        [  1019,     66],
                        [  1017,     60],
                        [  1010,     52],
                        [   996,     42],
                        [   977,     31],
                        [   951,     19],
                        [   921,      6],
                        [   887,     -9],
                        [   849,    -24],
                        [   808,    -39],
                        [   764,    -54],
                        [   717,    -70],
                        [   670,    -85],
                        [   620,   -102],
                        [   570,   -117],
                        [   518,   -132],
                        [   468,   -146],
                        [   419,   -159],
                        [   373,   -171],
                        [   328,   -181],
                        [   286,   -189],
                        [   247,   -196],
                        [   210,   -200],
                        [   176,   -202],
                        [   142,   -202],
                        [   110,   -198],
                        [    80,   -193],
                        [    50,   -184],
                        [    23,   -175],
                        [    -2,   -163],
                        [   -20,   -150],
                        [   -32,   -135],
                        [   -37,   -121],
                        [   -36,   -108],
                        [   -29,    -95],
                        [   -17,    -83],
                        [    -7,    -68],
                        [     5,    -51],
                        [    13,    -30],
                        [    20,     -5],
                        [    24,     26],
                        [    25,     61],
                        [    25,    100],
                        [    23,    144],
                        [    18,    190],
                        [    12,    239],
                        [     5,    288],
                        [    -4,    339],
                        [   -13,    388],
                        [   -22,    437],
                        [   -31,    485],
                        [   -39,    533],
                        [   -47,    579],
                        [   -55,    624],
                        [   -63,    666],
                        [   -72,    705],
                        [   -80,    740],
                        [   -88,    772],
                        [   -97,    800],
                        [  -106,    824],
                        [  -115,    845],
                        [  -125,    862],
                        [  -137,    874],
                        [  -152,    880],
                        [  -171,    877],
                        [  -193,    865],
                        [  -219,    846],
                        [  -249,    820],
                        [  -280,    789],
                        [  -313,    752],
                        [  -342,    713],
                        [  -371,    670],
                        [  -395,    626],
                        [  -416,    584],
                        [  -434,    544],
                        [  -448,    504],
                        [  -457,    470],
                        [  -462,    440],
                        [  -459,    416],
                        [  -449,    398],
                        [  -432,    385],
                        [  -410,    376],
                        [  -384,    369],
                        [  -355,    362],
                        [  -327,    356],
                        [  -297,    350],
                        [  -269,    345],
                        [  -241,    340],
                        [  -215,    336],
                        [  -189,    332],
                        [  -167,    329],
                        [  -146,    327],
                        [  -126,    326],
                        [  -106,    327],
                        [   -86,    329],
                        [   -67,    332],
                        [   -49,    337],
                        [   -33,    342],
                        [   -20,    348],
                        [   -11,    353],
                        [    -7,    358],
                        [    -7,    364],
                        [   -11,    369],
                        [   -18,    374],
                        [   -28,    378],
                        [   -42,    383],
                        [   -58,    387],
                        [   -76,    391],
                        [   -97,    394],
                        [  -119,    398],
                        [  -145,    401],
                        [  -172,    402],
                        [  -205,    404],
                        [  -241,    405],
                        [  -279,    405],
                        [  -319,    404],
                        [  -360,    402],
                        [  -401,    400],
                        [  -442,    397],
                        [  -483,    392],
                        [  -522,    387],
                        [  -559,    381],
                        [  -594,    375],
                        [  -626,    367],
                        [  -655,    361],
                        [  -680,    353],
                        [  -701,    345],
                        [  -718,    338],
                        [  -731,    330],
                        [  -741,    320],
                        [  -747,    310],
                        [  -749,    300],
                        [  -748,    289],
                        [  -745,    277],
                        [  -738,    266],
                        [  -729,    253],
                        [  -717,    241],
                        [  -703,    228],
                        [  -687,    214],
                        [  -670,    200],
                        [  -652,    186],
                        [  -633,    172],
                        [  -615,    158],
                        [  -597,    142],
                        [  -579,    128],
                        [  -561,    112],
                        [  -543,     97],
                        [  -524,     81],
                        [  -505,     66],
                        [  -483,     50],
                        [  -462,     34],
                        [  -439,     19],
                        [  -419,      5],
                        [  -401,     -9],
                        [  -388,    -19],
                        [  -381,    -26],
                        [  -379,    -30],
                        [  -382,    -29],
                        [  -387,    -26],
                        [  -394,    -20],
                        [  -398,    -14],
                        [  -400,     -8],
                        [  -400,     -5],
                        [  -397,     -5],
                        [  -392,     -8],
                        [  -385,    -15],
                        [  -375,    -24],
                        [  -364,    -37],
                        [  -351,    -50],
                        [  -337,    -66],
                        [  -323,    -80],
                        [  -308,    -96],
                        [  -293,   -112],
                        [  -280,   -128],
                        [  -267,   -145],
                        [  -254,   -163],
                        [  -242,   -180],
                        [  -231,   -196],
                        [  -220,   -210],
                        [  -210,   -223],
                        [  -199,   -235],
                        [  -189,   -245],
                        [  -180,   -253],
                        [  -170,   -260],
                        [  -159,   -265],
                        [  -148,   -267],
                        [  -132,   -264],
                        [  -115,   -256],
                        [   -93,   -243],
                        [   -66,   -223],
                        [   -37,   -202],
                        [    -7,   -179],
                        [    24,   -153],
                        [    55,   -125],
                        [    84,    -98],
                        [   111,    -68],
                        [   135,    -41],
                        [   158,    -13],
                        [   176,     11],
                        [   192,     33],
                        [   202,     49],
                        [   207,     59],
                        [   207,     65],
                        [   201,     66],
                        [   191,     64],
                        [   177,     61],
                        [   163,     60],
                        [   149,     61],
                        [   134,     63],
                        [   119,     65],
                        [   106,     68],
                        [    94,     73],
                        [    84,     80],
                        [    75,     88],
                        [    66,     96],
                        [    58,    104],
                        [    49,    113],
                        [    38,    121],
                        [    28,    130],
                        [    16,    139],
                        [     6,    148],
                        [    -3,    158],
                        [    -9,    167],
                        [   -12,    177],
                        [   -13,    187],
                        [   -11,    197],
                        [    -7,    206],
                        [    -2,    216],
                        [     4,    224],
                        [    11,    232],
                        [    17,    239],
                        [    21,    245],
                        [    26,    250],
                        [    30,    254],
                        [    36,    258],
                        [    43,    259],
                        [    52,    260],
                        [    63,    259],
                        [    73,    258],
                        [    85,    254],
                        [    96,    249],
                        [   106,    244],
                        [   115,    237],
                        [   124,    230],
                        [   130,    221],
                        [   134,    211],
                        [   136,    199],
                        [   136,    187],
                        [   132,    173],
                        [   127,    158],
                        [   118,    142],
                        [   106,    125],
                        [    92,    108],
                        [    76,     92],
                        [    57,     76],
                        [    37,     60],
                        [    15,     45],
                        [    -9,     31],
                        [   -33,     18],
                        [   -59,      6],
                        [   -85,     -4],
                        [  -111,    -12],
                        [  -136,    -19],
                        [  -160,    -24],
                        [  -184,    -26],
                        [  -205,    -26],
                        [  -224,    -24],
                        [  -242,    -20],
                        [  -258,    -12],
                        [  -271,     -2],
                        [  -285,     11],
                        [  -297,     25],
                        [  -310,     43],
                        [  -320,     63],
                        [  -329,     84],
                        [  -336,    107],
                        [  -338,    131],
                        [  -336,    154],
                        [  -327,    176],
                        [  -312,    196],
                        [  -293,    212],
                        [  -268,    226],
                        [  -244,    238],
                        [  -219,    248],
                        [  -197,    260],
                        [  -177,    273],
                        [  -160,    289],
                        [  -145,    309],
                        [  -134,    332],
                        [  -125,    357],
                        [  -120,    383],
                        [  -117,    411],
                        [  -117,    439],
                        [  -119,    466],
                        [  -122,    493],
                        [  -127,    518],
                        [  -132,    544],
                        [  -138,    568],
                        [  -146,    591],
                        [  -155,    611],
                        [  -166,    630],
                        [  -178,    645],
                        [  -190,    657],
                        [  -204,    665],
                        [  -219,    670],
                        [  -234,    673],
                        [  -250,    672],
                        [  -268,    668],
                        [  -288,    658],
                        [  -311,    644],
                        [  -337,    625],
                        [  -367,    599],
                        [  -400,    570],
                        [  -436,    539],
                        [  -474,    505],
                        [  -512,    471],
                        [  -548,    436],
                        [  -582,    400],
                        [  -614,    362],
                        [  -643,    326],
                        [  -669,    291],
                        [  -691,    258],
                        [  -709,    230],
                        [  -721,    208],
                        [  -727,    193],
                        [  -727,    183],
                        [  -722,    179],
                        [  -711,    179],
                        [  -697,    179],
                        [  -680,    181],
                        [  -662,    183],
                        [  -644,    184],
                        [  -624,    184],
                        [  -604,    186],
                        [  -584,    187],
                        [  -564,    189],
                        [  -544,    189],
                        [  -526,    190],
                        [  -505,    192],
                        [  -485,    193],
                        [  -462,    193],
                        [  -440,    195],
                        [  -417,    196],
                        [  -394,    197],
                        [  -375,    197],
                        [  -358,    196],
                        [  -346,    195],
                        [  -337,    193],
                        [  -332,    191],
                        [  -330,    188],
                        [  -331,    184],
                        [  -335,    180],
                        [  -340,    176],
                        [  -345,    170],
                        [  -350,    163],
                        [  -356,    157],
                        [  -364,    150],
                        [  -373,    141],
                        [  -387,    132],
                        [  -403,    122],
                        [  -422,    111],
                        [  -444,    100],
                        [  -467,     88],
                        [  -492,     76],
                        [  -517,     63],
                        [  -543,     49],
                        [  -568,     35],
                        [  -592,     21],
                        [  -617,      7],
                        [  -639,     -7],
                        [  -661,    -21],
                        [  -680,    -34],
                        [  -697,    -46],
                        [  -711,    -58],
                        [  -722,    -68],
                        [  -730,    -78],
                        [  -735,    -88],
                        [  -737,    -97],
                        [  -736,   -106],
                        [  -732,   -115],
                        [  -726,   -123],
                        [  -717,   -130],
                        [  -706,   -138],
                        [  -692,   -145],
                        [  -678,   -152],
                        [  -660,   -158],
                        [  -642,   -165],
                        [  -623,   -171],
                        [  -605,   -177],
                        [  -585,   -183],
                        [  -566,   -189],
                        [  -548,   -196],
                        [  -529,   -202],
                        [  -510,   -209],
                        [  -492,   -215],
                        [  -473,   -223],
                        [  -455,   -231],
                        [  -437,   -239],
                        [  -422,   -246],
                        [  -410,   -254],
                        [  -402,   -258],
                        [  -399,   -261],
                        [  -401,   -260],
                        [  -410,   -255],
                        [  -422,   -246],
                        [  -437,   -233],
                        [  -452,   -219],
                        [  -466,   -205],
                        [  -479,   -192],
                        [  -491,   -183],
                        [  -500,   -176],
                        [  -508,   -173],
                        [  -514,   -174],
                        [  -518,   -177],
                        [  -520,   -183],
                        [  -521,   -191],
                        [  -520,   -201],
                        [  -518,   -211],
                        [  -515,   -223],
                        [  -512,   -236],
                        [  -507,   -251],
                        [  -501,   -267],
                        [  -494,   -283],
                        [  -485,   -298],
                        [  -475,   -314],
                        [  -464,   -327],
                        [  -452,   -340],
                        [  -438,   -350],
                        [  -423,   -360],
                        [  -406,   -368],
                        [  -388,   -374],
                        [  -366,   -376],
                        [  -343,   -375],
                        [  -314,   -370],
                        [  -283,   -362],
                        [  -248,   -351],
                        [  -210,   -340],
                        [  -168,   -327],
                        [  -126,   -314],
                        [   -84,   -299],
                        [   -42,   -282],
                        [    -1,   -264],
                        [    39,   -245],
                        [    77,   -225],
                        [   113,   -208],
                        [   145,   -193],
                        [   175,   -183],
                        [   198,   -177],
                        [   219,   -175],
                        [   234,   -176],
                        [   246,   -180],
                        [   255,   -184],
                        [   262,   -186],
                        [   268,   -185],
                        [   273,   -184],
                        [   275,   -182],
                        [   277,   -178],
                        [   277,   -172],
                        [   275,   -167],
                        [   273,   -159],
                        [   269,   -150],
                        [   262,   -141],
                        [   251,   -132],
                        [   237,   -123],
                        [   221,   -112],
                        [   202,   -102],
                        [   181,    -93],
                        [   161,    -83],
                        [   141,    -73],
                        [   124,    -64],
                        [   108,    -56],
                        [    93,    -49],
                        [    80,    -42],
                        [    67,    -36],
                        [    54,    -31],
                        [    41,    -28],
                        [    28,    -24],
                        [    11,    -24],
                        [    -5,    -24],
                        [   -21,    -24],
                        [   -37,    -26],
                        [   -50,    -29],
                        [   -60,    -34],
                        [   -67,    -39],
                        [   -73,    -45],
                        [   -78,    -51],
                        [   -80,    -59],
                        [   -82,    -66],
                        [   -82,    -74],
                        [   -82,    -82],
                        [   -80,    -91],
                        [   -79,   -100],
                        [   -76,   -109],
                        [   -72,   -119],
                        [   -69,   -128],
                        [   -66,   -139],
                        [   -63,   -149],
                        [   -62,   -160],
                        [   -61,   -170],
                        [   -61,   -180],
                        [   -62,   -189],
                        [   -63,   -196],
                        [   -66,   -202],
                        [   -69,   -208],
                        [   -72,   -211],
                        [   -76,   -214],
                        [   -80,   -214],
                        [   -85,   -213],
                        [   -90,   -210],
                        [   -94,   -205],
                        [   -99,   -199],
                        [  -102,   -191],
                        [  -105,   -181],
                        [  -106,   -169],
                        [  -107,   -156],
                        [  -107,   -141],
                        [  -106,   -124],
                        [  -104,   -105],
                        [  -101,    -85],
                        [   -98,    -64],
                        [   -93,    -41],
                        [   -87,    -19],
                        [   -78,      2],
                        [   -67,     24],
                        [   -51,     42],
                        [   -33,     58],
                        [    -9,     68],
                        [    18,     74],
                        [    46,     75],
                        [    73,     72],
                        [   101,     69],
                        [   127,     63],
                        [   151,     60],
                        [   173,     58],
                        [   193,     57],
                        [   211,     58],
                        [   226,     59],
                        [   238,     61],
                        [   249,     63],
                        [   256,     67],
                        [   262,     69],
                        [   267,     72],
                        [   269,     75],
                        [   270,     77],
                        [   269,     80],
                        [   266,     82],
                        [   261,     84],
                        [   254,     84],
                        [   246,     83],
                        [   236,     80],
                        [   226,     75],
                        [   215,     68],
                        [   202,     61],
                        [   188,     51],
                        [   172,     39],
                        [   154,     24],
                        [   135,      8],
                        [   114,    -10],
                        [    89,    -28],
                        [    64,    -46],
                        [    37,    -63],
                        [    10,    -78],
                        [   -18,    -94],
                        [   -46,   -111],
                        [   -72,   -128],
                        [   -98,   -145],
                        [  -121,   -159],
                        [  -142,   -171],
                        [  -162,   -180],
                        [  -177,   -183],
                        [  -189,   -180],
                        [  -198,   -172],
                        [  -204,   -161],
                        [  -207,   -145],
                        [  -209,   -131],
                        [  -210,   -116],
                        [  -210,   -102],
                        [  -208,    -89],
                        [  -206,    -76],
                        [  -202,    -64],
                        [  -197,    -54],
                        [  -192,    -46],
                        [  -185,    -39],
                        [  -177,    -33],
                        [  -167,    -28],
                        [  -154,    -24],
                        [  -138,    -23],
                        [  -119,    -22],
                        [  -101,    -24],
                        [   -80,    -27],
                        [   -61,    -31],
                        [   -44,    -37],
                        [   -29,    -43],
                        [   -17,    -51],
                        [    -7,    -61],
                        [     0,    -72],
                        [     7,    -83],
                        [    11,    -96],
                        [    15,   -111],
                        [    20,   -124],
                        [    26,   -139],
                        [    32,   -155],
                        [    36,   -171],
                        [    40,   -188],
                        [    40,   -205],
                        [    38,   -222],
                        [    34,   -239],
                        [    28,   -257],
                        [    20,   -274],
                        [    11,   -291],
                        [     2,   -309],
                        [    -9,   -325],
                        [   -20,   -342],
                        [   -31,   -358],
                        [   -44,   -373],
                        [   -57,   -388],
                        [   -70,   -401],
                        [   -82,   -414],
                        [   -93,   -424],
                        [  -103,   -433],
                        [  -111,   -440],
                        [  -115,   -446],
                        [  -119,   -451],
                        [  -121,   -453],
                        [  -121,   -457],
                        [  -119,   -458],
                        [  -115,   -459],
                        [  -109,   -459],
                        [  -102,   -458],
                        [   -93,   -457],
                        [   -82,   -455],
                        [   -71,   -453],
                        [   -58,   -451],
                        [   -44,   -448],
                        [   -30,   -445],
                        [   -15,   -443],
                        [    -1,   -440],
                        [    13,   -437],
                        [    26,   -436],
                        [    38,   -434],
                        [    49,   -433],
                        [    59,   -433],
                        [    68,   -434],
                        [    76,   -436],
                        [    82,   -437],
                        [    86,   -439],
                        [    88,   -440],
                        [    87,   -440],
                        [    82,   -436],
                        [    75,   -431],
                        [    64,   -421],
                        [    50,   -407],
                        [    36,   -392],
                        [    20,   -374],
                        [     5,   -358],
                        [   -11,   -341],
                        [   -27,   -328],
                        [   -42,   -318],
                        [   -55,   -309],
                        [   -67,   -303],
                        [   -79,   -300],
                        [   -89,   -298],
                        [   -98,   -298],
                        [  -104,   -299],
                        [  -111,   -302],
                        [  -115,   -306],
                        [  -116,   -311],
                        [  -117,   -319],
                        [  -115,   -326],
                        [  -112,   -335],
                        [  -106,   -342],
                        [  -100,   -350],
                        [   -92,   -357],
                        [   -81,   -361],
                        [   -69,   -364],
                        [   -55,   -366],
                        [   -40,   -366],
                        [   -23,   -363],
                        [    -3,   -358],
                        [    18,   -352],
                        [    41,   -345],
                        [    67,   -336],
                        [    94,   -328],
                        [   124,   -319],
                        [   156,   -310],
                        [   189,   -301],
                        [   223,   -288],
                        [   257,   -275],
                        [   290,   -261],
                        [   323,   -246],
                        [   355,   -232],
                        [   384,   -222],
                        [   412,   -215],
                        [   437,   -210],
                        [   459,   -210],
                        [   480,   -212],
                        [   499,   -215],
                        [   515,   -220],
                        [   531,   -223],
                        [   546,   -225],
                        [   558,   -227],
                        [   568,   -228],
                        [   575,   -228],
                        [   580,   -227],
                        [   582,   -225],
                        [   581,   -223],
                        [   577,   -219],
                        [   569,   -215],
                        [   556,   -211],
                        [   538,   -207],
                        [   517,   -202],
                        [   492,   -197],
                        [   466,   -193],
                        [   438,   -187],
                        [   411,   -182],
                        [   384,   -177],
                        [   359,   -172],
                        [   334,   -167],
                        [   310,   -163],
                        [   288,   -159],
                        [   265,   -156],
                        [   242,   -153],
                        [   219,   -150],
                        [   194,   -148],
                        [   170,   -147],
                        [   146,   -145],
                        [   126,   -145],
                        [   107,   -145],
                        [    91,   -144],
                        [    79,   -144],
                        [    67,   -144],
                        [    59,   -144],
                        [    54,   -144],
                        [    50,   -143],
                        [    48,   -143],
                        [    50,   -141],
                        [    53,   -140],
                        [    59,   -138],
                        [    67,   -135],
                        [    77,   -132],
                        [    89,   -129],
                        [   102,   -127],
                        [   115,   -123],
                        [   128,   -119],
                        [   140,   -116],
                        [   152,   -112],
                        [   164,   -108],
                        [   176,   -102],
                        [   186,    -97],
                        [   196,    -89],
                        [   206,    -82],
                        [   215,    -73],
                        [   222,    -64],
                        [   229,    -54],
                        [   235,    -44],
                        [   240,    -33],
                        [   244,    -21],
                        [   247,     -9],
                        [   249,      3],
                        [   251,     16],
                        [   254,     29],
                        [   257,     43],
                        [   260,     56],
                        [   265,     71],
                        [   269,     84],
                        [   275,     98],
                        [   280,    112],
                        [   286,    125],
                        [   293,    138],
                        [   301,    149],
                        [   310,    158],
                        [   319,    163],
                        [   329,    165],
                        [   341,    163],
                        [   355,    155],
                        [   370,    143],
                        [   385,    128],
                        [   401,    111],
                        [   416,     93],
                        [   431,     76],
                        [   445,     59],
                        [   459,     42],
                        [   471,     26],
                        [   483,     11],
                        [   493,     -2],
                        [   502,    -16],
                        [   510,    -28],
                        [   518,    -40],
                        [   522,    -50],
                        [   527,    -60],
                        [   529,    -67],
                        [   531,    -74],
                        [   531,    -79],
                        [   531,    -84],
                        [   529,    -88],
                        [   527,    -92],
                        [   523,    -97],
                        [   519,   -102],
                        [   514,   -106],
                        [   509,   -111],
                        [   503,   -117],
                        [   496,   -123],
                        [   489,   -127],
                        [   480,   -131],
                        [   470,   -133],
                        [   458,   -133],
                        [   444,   -132],
                        [   429,   -131],
                        [   413,   -128],
                        [   395,   -126],
                        [   376,   -124],
                        [   357,   -122],
                        [   339,   -119],
                        [   320,   -114],
                        [   302,   -106],
                        [   286,    -96],
                        [   270,    -82],
                        [   254,    -67],
                        [   239,    -48],
                        [   223,    -28],
                        [   208,     -7],
                        [   192,     11],
                        [   176,     30],
                        [   161,     47],
                        [   147,     63],
                        [   135,     77],
                        [   124,     90],
                        [   115,    102],
                        [   108,    111],
                        [   103,    117],
                        [   102,    123],
                        [   104,    126],
                        [   110,    127],
                        [   119,    126],
                        [   129,    124],
                        [   143,    119],
                        [   155,    113],
                        [   168,    106],
                        [   180,     96],
                        [   192,     85],
                        [   203,     74],
                        [   213,     61],
                        [   223,     47],
                        [   232,     33],
                        [   242,     18],
                        [   253,      3],
                        [   264,    -13],
                        [   275,    -28],
                        [   286,    -44],
                        [   296,    -59],
                        [   305,    -74],
                        [   310,    -89],
                        [   315,   -102],
                        [   319,   -116],
                        [   322,   -129],
                        [   323,   -141],
                        [   323,   -154],
                        [   323,   -164],
                        [   319,   -175],
                        [   315,   -184],
                        [   309,   -192],
                        [   301,   -198],
                        [   292,   -205],
                        [   282,   -210],
                        [   272,   -213],
                        [   262,   -215],
                        [   254,   -215],
                        [   245,   -215],
                        [   239,   -213],
                        [   232,   -210],
                        [   227,   -206],
                        [   222,   -202],
                        [   218,   -197],
                        [   215,   -192],
                        [   213,   -186],
                        [   212,   -180],
                        [   211,   -174],
                        [   212,   -167],
                        [   214,   -162],
                        [   217,   -155],
                        [   221,   -149],
                        [   226,   -143],
                        [   231,   -137],
                        [   235,   -132],
                        [   237,   -127],
                        [   240,   -122],
                        [   240,   -119],
                        [   239,   -116],
                        [   237,   -115],
                        [   233,   -115],
                        [   229,   -114],
                        [   224,   -115],
                        [   219,   -115],
                        [   212,   -115],
                        [   205,   -114],
                        [   197,   -111],
                        [   187,   -106],
                        [   176,    -98],
                        [   163,    -87],
                        [   149,    -74],
                        [   133,    -60],
                        [   118,    -45],
                        [   102,    -31],
                        [    85,    -18],
                        [    71,     -6],
                        [    55,      5],
                        [    41,     15],
                        [    28,     23],
                        [    16,     30],
                        [     7,     36],
                        [    -2,     40],
                        [   -10,     44],
                        [   -15,     46],
                        [   -18,     48],
                        [   -20,     48],
                        [   -21,     47],
                        [   -21,     46],
                        [   -20,     45],
                        [   -16,     45],
                        [   -13,     46],
                        [    -8,     48],
                        [    -2,     51],
                        [     4,     55],
                        [    11,     61],
                        [    19,     67],
                        [    27,     73],
                        [    36,     79],
                        [    46,     84],
                        [    57,     88],
                        [    71,     92],
                        [    85,     96],
                        [   102,    100],
                        [   119,    106],
                        [   137,    112],
                        [   155,    119],
                        [   173,    126],
                        [   190,    132],
                        [   206,    137],
                        [   222,    141],
                        [   236,    143],
                        [   250,    142],
                        [   264,    140],
                        [   277,    137],
                        [   290,    132],
                        [   303,    127],
                        [   315,    122],
                        [   326,    116],
                        [   335,    111],
                        [   340,    104],
                        [   344,     99],
                        [   345,     93],
                        [   342,     88],
                        [   336,     82],
                        [   327,     77],
                        [   314,     72],
                        [   298,     68],
                        [   279,     64],
                        [   256,     61],
                        [   232,     57],
                        [   206,     54],
                        [   180,     51],
                        [   154,     50],
                        [   128,     48],
                        [   102,     46],
                        [    78,     46],
                        [    54,     45],
                        [    30,     45],
                        [     6,     44],
                        [   -17,     45],
                        [   -41,     46],
                        [   -63,     46],
                        [   -85,     48],
                        [  -104,     50],
                        [  -121,     52],
                        [  -136,     54],
                        [  -149,     58],
                        [  -159,     61],
                        [  -168,     65],
                        [  -175,     70],
                        [  -179,     75],
                        [  -181,     80],
                        [  -180,     87],
                        [  -176,     93],
                        [  -168,    101],
                        [  -158,    109],
                        [  -146,    117],
                        [  -132,    125],
                        [  -117,    134],
                        [  -102,    143],
                        [   -86,    152],
                        [   -72,    162],
                        [   -56,    170],
                        [   -41,    179],
                        [   -26,    189],
                        [   -12,    197],
                        [     2,    206],
                        [    14,    215],
                        [    25,    224],
                        [    36,    233],
                        [    45,    242],
                        [    52,    250],
                        [    58,    258],
                        [    62,    265],
                        [    63,    271],
                        [    64,    278],
                        [    64,    284],
                        [    63,    288],
                        [    63,    293],
                        [    63,    297],
                        [    63,    301],
                        [    64,    303],
                        [    66,    306],
                        [    69,    308],
                        [    72,    310],
                        [    75,    311],
                        [    77,    311],
                        [    80,    310],
                        [    82,    307],
                        [    85,    301],
                        [    87,    293],
                        [    92,    282],
                        [    97,    267],
                        [   104,    250],
                        [   113,    230],
                        [   121,    209],
                        [   132,    187],
                        [   141,    165],
                        [   153,    144],
                        [   163,    124],
                        [   175,    106],
                        [   184,     89],
                        [   195,     73],
                        [   203,     59],
                        [   211,     46],
                        [   218,     36],
                        [   223,     28],
                        [   229,     22],
                        [   234,     18],
                        [   238,     15],
                        [   242,     16],
                        [   245,     17],
                        [   249,     19],
                        [   252,     21],
                        [   254,     24],
                        [   257,     26],
                        [   258,     28],
                        [   261,     32],
                        [   263,     35],
                        [   266,     40],
                        [   267,     46],
                        [   267,     54],
                        [   266,     63],
                        [   262,     74],
                        [   258,     85],
                        [   250,     95],
                        [   241,    106],
                        [   232,    115],
                        [   219,    123],
                        [   208,    132],
                        [   196,    140],
                        [   183,    148],
                        [   170,    155],
                        [   157,    164],
                        [   143,    173],
                        [   127,    182],
                        [   110,    192],
                        [    92,    202],
                        [    72,    211],
                        [    52,    220],
                        [    32,    229],
                        [    14,    237],
                        [    -3,    244],
                        [   -19,    249],
                        [   -32,    255],
                        [   -43,    259],
                        [   -53,    262],
                        [   -59,    263],
                        [   -64,    263],
                        [   -66,    262],
                        [   -65,    261],
                        [   -62,    258],
                        [   -56,    254],
                        [   -50,    249],
                        [   -41,    243],
                        [   -33,    236],
                        [   -24,    228],
                        [   -14,    220],
                        [    -4,    212],
                        [     7,    203],
                        [    19,    194],
                        [    30,    185],
                        [    43,    176],
                        [    57,    167],
                        [    71,    158],
                        [    84,    150],
                        [    98,    142],
                        [   110,    134],
                        [   121,    128],
                        [   132,    121],
                        [   141,    115],
                        [   150,    110],
                        [   158,    105],
                        [   165,    100],
                        [   171,     96],
                        [   174,     93],
                        [   174,     90],
                        [   172,     88],
                        [   167,     86],
                        [   162,     85],
                        [   153,     84],
                        [   145,     83],
                        [   137,     83],
                        [   128,     83],
                        [   119,     84],
                        [   110,     85],
                        [   101,     85],
                        [    92,     87],
                        [    83,     88],
                        [    75,     89],
                        [    67,     91],
                        [    59,     93],
                        [    52,     94],
                        [    46,     96],
                        [    40,     98],
                        [    37,     99],
                        [    35,    100],
                        [    33,    102],
                        [    34,    103],
                        [    35,    104],
                        [    36,    106],
                        [    36,    106],
                        [    35,    107],
                        [    33,    108],
                        [    28,    107],
                        [    24,    107],
                        [    18,    106],
                        [    12,    104],
                        [     5,    102],
                        [    -1,    102],
                        [    -7,    100],
                        [   -14,     99],
                        [   -19,     99],
                        [   -25,    101],
                        [   -33,    105],
                        [   -41,    111],
                        [   -50,    121],
                        [   -60,    132],
                        [   -72,    145],
                        [   -84,    159],
                        [   -97,    174],
                        [  -110,    188],
                        [  -124,    202],
                        [  -136,    214],
                        [  -148,    225],
                        [  -158,    235],
                        [  -168,    245],
                        [  -176,    253],
                        [  -183,    260],
                        [  -189,    266],
                        [  -193,    270],
                        [  -197,    272],
                        [  -202,    274],
                        [  -206,    274],
                        [  -209,    273],
                        [  -212,    273],
                        [  -215,    273],
                        [  -219,    274],
                        [  -221,    275],
                        [  -225,    277],
                        [  -229,    279],
                        [  -233,    280],
                        [  -238,    280],
                        [  -242,    280],
                        [  -246,    280],
                        [  -249,    278],
                        [  -249,    275],
                        [  -249,    272],
                        [  -249,    268],
                        [  -246,    266],
                        [  -243,    264],
                        [  -240,    262],
                        [  -236,    261],
                        [  -232,    259],
                        [  -229,    258],
                        [  -226,    257],
                        [  -223,    255],
                        [  -218,    252],
                        [  -213,    248],
                        [  -206,    243],
                        [  -199,    236],
                        [  -191,    229],
                        [  -181,    221],
                        [  -174,    212],
                        [  -167,    203],
                        [  -161,    193],
                        [  -158,    183],
                        [  -155,    172],
                        [  -154,    162],
                        [  -156,    151],
                        [  -158,    141],
                        [  -163,    132],
                        [  -168,    122],
                        [  -176,    113],
                        [  -186,    104],
                        [  -197,     97],
                        [  -210,     89],
                        [  -223,     83],
                        [  -236,     77],
                        [  -251,     72],
                        [  -265,     67],
                        [  -280,     64],
                        [  -294,     61],
                        [  -309,     59],
                        [  -323,     57],
                        [  -337,     56],
                        [  -352,     56],
                        [  -365,     57],
                        [  -379,     58],
                        [  -390,     59],
                        [  -401,     62],
                        [  -411,     65],
                        [  -420,     68],
                        [  -427,     72],
                        [  -433,     77],
                        [  -438,     82],
                        [  -441,     88],
                        [  -442,     94],
                        [  -440,    101],
                        [  -437,    108],
                        [  -430,    115],
                        [  -421,    123],
                        [  -410,    131],
                        [  -397,    140],
                        [  -384,    149],
                        [  -371,    158],
                        [  -357,    167],
                        [  -343,    176],
                        [  -329,    185],
                        [  -315,    194],
                        [  -301,    202],
                        [  -288,    210],
                        [  -275,    218],
                        [  -264,    224],
                        [  -253,    231],
                        [  -243,    236],
                        [  -235,    241],
                        [  -228,    245],
                        [  -223,    247],
                        [  -221,    249],
                        [  -221,    249],
                        [  -222,    249],
                        [  -224,    246],
                        [  -228,    243],
                        [  -230,    240],
                        [  -232,    235],
                        [  -234,    229],
                        [  -235,    223],
                        [  -235,    216],
                        [  -234,    209],
                        [  -232,    202],
                        [  -231,    194],
                        [  -229,    185],
                        [  -228,    177],
                        [  -228,    167],
                        [  -227,    158],
                        [  -226,    146],
                        [  -224,    133],
                        [  -222,    119],
                        [  -217,    102],
                        [  -211,     82],
                        [  -204,     62],
                        [  -195,     41],
                        [  -185,     20],
                        [  -175,     -1],
                        [  -163,    -20],
                        [  -152,    -37],
                        [  -141,    -52],
                        [  -130,    -65],
                        [  -121,    -77],
                        [  -113,    -87],
                        [  -105,    -94],
                        [   -98,   -100],
                        [   -91,   -103],
                        [   -84,   -104],
                        [   -77,   -102],
                        [   -69,    -98],
                        [   -62,    -92],
                        [   -54,    -85],
                        [   -46,    -79],
                        [   -38,    -72],
                        [   -30,    -65],
                        [   -22,    -59],
                        [   -12,    -50],
                        [    -3,    -43],
                        [     7,    -34],
                        [    15,    -24],
                        [    24,    -15],
                        [    30,     -4],
                        [    36,      7],
                        [    39,     18],
                        [    41,     28],
                        [    41,     37],
                        [    41,     46],
                        [    39,     53],
                        [    36,     59],
                        [    33,     64],
                        [    28,     67],
                        [    24,     69],
                        [    20,     70],
                        [    13,     71],
                        [     4,     72],
                        [    -6,     73],
                        [   -18,     74],
                        [   -33,     76],
                        [   -47,     77],
                        [   -63,     78],
                        [   -76,     80],
                        [   -89,     80],
                        [  -101,     81],
                        [  -111,     82],
                        [  -121,     82],
                        [  -130,     82],
                        [  -137,     81],
                        [  -144,     80],
                        [  -149,     79],
                        [  -152,     77],
                        [  -153,     75],
                        [  -152,     72],
                        [  -150,     70],
                        [  -145,     67],
                        [  -140,     63],
                        [  -133,     60],
                        [  -125,     57],
                        [  -116,     53],
                        [  -106,     50],
                        [   -96,     46],
                        [   -85,     43],
                        [   -73,     40],
                        [   -61,     37],
                        [   -47,     35],
                        [   -34,     33],
                        [   -21,     31],
                        [    -9,     29],
                        [     4,     28],
                        [    15,     27],
                        [    28,     26],
                        [    38,     26],
                        [    49,     26],
                        [    58,     27],
                        [    64,     27],
                        [    70,     27],
                        [    72,     28],
                        [    73,     28],
                        [    72,     28],
                        [    68,     28],
                        [    63,     28],
                        [    57,     28],
                        [    50,     27],
                        [    43,     24],
                        [    35,     22],
                        [    27,     20],
                        [    18,     17],
                        [     9,     14],
                        [     0,     11],
                        [    -8,      7],
                        [   -17,      5],
                        [   -26,      2],
                        [   -34,     -1],
                        [   -41,     -4],
                        [   -47,     -7],
                        [   -51,     -9],
                        [   -54,    -11],
                        [   -54,    -13],
                        [   -54,    -15],
                        [   -53,    -15],
                        [   -51,    -15],
                        [   -50,    -15],
                        [   -49,    -14],
                        [   -48,    -12],
                        [   -49,    -11],
                        [   -50,    -10],
                        [   -53,     -8],
                        [   -55,     -7],
                        [   -59,     -4],
                        [   -61,     -2],
                        [   -63,     -1],
                        [   -65,      2],
                        [   -66,      4],
                        [   -67,      7],
                        [   -68,     11],
                        [   -71,     17],
                        [   -73,     25],
                        [   -78,     36],
                        [   -84,     49],
                        [   -89,     62],
                        [   -97,     76],
                        [  -104,     91],
                        [  -112,    105],
                        [  -119,    117],
                        [  -127,    128],
                        [  -133,    139],
                        [  -138,    150],
                        [  -142,    158],
                        [  -145,    166],
                        [  -147,    172],
                        [  -149,    177],
                        [  -152,    180],
                        [  -154,    180],
                        [  -158,    180],
                        [  -162,    178],
                        [  -167,    176],
                        [  -171,    173],
                        [  -177,    171],
                        [  -183,    168],
                        [  -191,    166],
                        [  -199,    163],
                        [  -207,    159],
                        [  -217,    155],
                        [  -228,    150],
                        [  -236,    145],
                        [  -245,    139],
                        [  -254,    133],
                        [  -261,    127],
                        [  -267,    119],
                        [  -272,    113],
                        [  -277,    106],
                        [  -282,    101],
                        [  -286,     95],
                        [  -290,     91],
                        [  -294,     88],
                        [  -297,     85],
                        [  -301,     82],
                        [  -302,     80],
                        [  -303,     76],
                        [  -301,     72],
                        [  -298,     66],
                        [  -293,     59],
                        [  -287,     53],
                        [  -280,     46],
                        [  -274,     37],
                        [  -267,     29],
                        [  -262,     21],
                        [  -258,     12],
                        [  -252,      3],
                        [  -248,     -6],
                        [  -243,    -15],
                        [  -239,    -23],
                        [  -235,    -30],
                        [  -232,    -37],
                        [  -229,    -45],
                        [  -228,    -51],
                        [  -228,    -57],
                        [  -229,    -62],
                        [  -231,    -67],
                        [  -233,    -71],
                        [  -236,    -75],
                        [  -240,    -77],
                        [  -243,    -80],
                        [  -247,    -81],
                        [  -251,    -83],
                        [  -255,    -84],
                        [  -259,    -84],
                        [  -263,    -84],
                        [  -267,    -84],
                        [  -271,    -83],
                        [  -275,    -81],
                        [  -278,    -80],
                        [  -281,    -78],
                        [  -284,    -76],
                        [  -286,    -75],
                        [  -287,    -72],
                        [  -288,    -70],
                        [  -287,    -67],
                        [  -284,    -65],
                        [  -280,    -63],
                        [  -275,    -60],
                        [  -268,    -57],
                        [  -259,    -54],
                        [  -250,    -51],
                        [  -241,    -47],
                        [  -231,    -43],
                        [  -220,    -38],
                        [  -210,    -33],
                        [  -199,    -28],
                        [  -189,    -23],
                        [  -179,    -18],
                        [  -169,    -14],
                        [  -159,    -11],
                        [  -150,     -7],
                        [  -142,     -6],
                        [  -135,     -4],
                        [  -129,     -3],
                        [  -124,     -3],
                        [  -121,     -5],
                        [  -120,     -7],
                        [  -121,    -10],
                        [  -123,    -14],
                        [  -127,    -20],
                        [  -131,    -26],
                        [  -135,    -33],
                        [  -139,    -41],
                        [  -142,    -51],
                        [  -145,    -61],
                        [  -146,    -71],
                        [  -147,    -81],
                        [  -148,    -92],
                        [  -147,   -102],
                        [  -147,   -113],
                        [  -147,   -123],
                        [  -147,   -132],
                        [  -147,   -141],
                        [  -147,   -150],
                        [  -147,   -158],
                        [  -145,   -168],
                        [  -142,   -180],
                        [  -138,   -192],
                        [  -132,   -205],
                        [  -126,   -219],
                        [  -119,   -234],
                        [  -110,   -248],
                        [  -101,   -260],
                        [   -91,   -270],
                        [   -82,   -279],
                        [   -74,   -285],
                        [   -66,   -292],
                        [   -60,   -296],
                        [   -54,   -300],
                        [   -50,   -301],
                        [   -44,   -301],
                        [   -38,   -299],
                        [   -32,   -295],
                        [   -25,   -288],
                        [   -18,   -280],
                        [   -11,   -271],
                        [    -2,   -262],
                        [     6,   -254],
                        [    15,   -245],
                        [    24,   -236],
                        [    35,   -228],
                        [    46,   -219],
                        [    57,   -210],
                        [    68,   -202],
                        [    78,   -193],
                        [    88,   -185],
                        [    97,   -177],
                        [   104,   -170],
                        [   111,   -163],
                        [   117,   -158],
                        [   122,   -153],
                        [   126,   -149],
                        [   130,   -145],
                        [   132,   -145],
                        [   135,   -146],
                        [   138,   -149],
                        [   141,   -151],
                        [   141,   -154],
                        [   141,   -158],
                        [   138,   -160],
                        [   133,   -163],
                        [   128,   -165],
                        [   120,   -167],
                        [   111,   -168],
                        [   103,   -169],
                        [    96,   -170],
                        [    89,   -170],
                        [    81,   -171],
                        [    75,   -171],
                        [    67,   -170],
                        [    60,   -170],
                        [    54,   -169],
                        [    48,   -168],
                        [    42,   -167],
                        [    38,   -167],
                        [    36,   -166],
                        [    34,   -165],
                        [    34,   -164],
                        [    35,   -163],
                        [    37,   -162],
                        [    40,   -160],
                        [    45,   -158],
                        [    50,   -157],
                        [    55,   -154],
                        [    61,   -153],
                        [    67,   -150],
                        [    74,   -148],
                        [    81,   -145],
                        [    89,   -142],
                        [    97,   -139],
                        [   105,   -137],
                        [   112,   -133],
                        [   120,   -130],
                        [   128,   -126],
                        [   133,   -123],
                        [   140,   -119],
                        [   145,   -115],
                        [   150,   -112],
                        [   154,   -108],
                        [   156,   -105],
                        [   156,   -102],
                        [   155,    -99],
                        [   154,    -98],
                        [   150,    -96],
                        [   146,    -96],
                        [   142,    -96],
                        [   137,    -98],
                        [   131,   -101],
                        [   124,   -104],
                        [   117,   -108],
                        [   110,   -112],
                        [   102,   -117],
                        [    95,   -121],
                        [    89,   -125],
                        [    81,   -129],
                        [    75,   -132],
                        [    69,   -136],
                        [    64,   -139],
                        [    60,   -141],
                        [    59,   -143],
                        [    58,   -145],
                        [    59,   -145],
                        [    60,   -144],
                        [    63,   -142],
                        [    65,   -140],
                        [    68,   -136],
                        [    71,   -131],
                        [    73,   -126],
                        [    75,   -120],
                        [    76,   -114],
                        [    76,   -107],
                        [    77,   -100],
                        [    78,    -93],
                        [    79,    -85],
                        [    80,    -79],
                        [    83,    -72],
                        [    85,    -66],
                        [    87,    -59],
                        [    88,    -52],
                        [    89,    -43],
                        [    89,    -33],
                        [    88,    -20],
                        [    85,     -7],
                        [    82,      7],
                        [    78,     20],
                        [    73,     33],
                        [    69,     43],
                        [    66,     53],
                        [    63,     62],
                        [    60,     70],
                        [    59,     77],
                        [    59,     84],
                        [    57,     89],
                        [    57,     93],
                        [    55,     96],
                        [    53,     95],
                        [    50,     93],
                        [    46,     89],
                        [    41,     85],
                        [    37,     79],
                        [    30,     73],
                        [    24,     67],
                        [    15,     61],
                        [     7,     54],
                        [    -3,     47],
                        [   -14,     41],
                        [   -24,     34],
                        [   -35,     28],
                        [   -46,     20],
                        [   -55,     13],
                        [   -65,      7],
                        [   -74,     -1],
                        [   -83,     -7],
                        [   -91,    -14],
                        [   -98,    -19],
                        [  -105,    -24],
                        [  -112,    -27],
                        [  -119,    -29],
                        [  -125,    -31],
                        [  -132,    -32],
                        [  -137,    -33],
                        [  -140,    -33],
                        [  -141,    -36],
                        [  -142,    -37],
                        [  -140,    -40],
                        [  -137,    -43],
                        [  -132,    -46],
                        [  -127,    -50],
                        [  -122,    -54],
                        [  -115,    -58],
                        [  -109,    -62],
                        [  -101,    -65],
                        [   -93,    -70],
                        [   -84,    -74],
                        [   -74,    -77],
                        [   -64,    -81],
                        [   -55,    -85],
                        [   -46,    -88],
                        [   -37,    -90],
                        [   -28,    -93],
                        [   -21,    -95],
                        [   -15,    -97],
                        [    -9,    -98],
                        [    -3,   -100],
                        [     1,   -102],
                        [     5,   -102],
                        [     9,   -102],
                        [    12,   -102],
                        [    15,   -103],
                        [    17,   -103],
                        [    20,   -103],
                        [    20,   -103],
                        [    22,   -103],
                        [    23,   -102],
                        [    24,   -102],
                        [    24,   -102],
                        [    24,   -102],
                        [    24,   -102],
                        [    24,   -102],
                        [    25,   -102],
                        [    25,   -103],
                        [    26,   -103],
                        [    27,   -104],
                        [    28,   -105],
                        [    31,   -105],
                        [    34,   -105],
                        [    37,   -105],
                        [    40,   -104],
                        [    44,   -102],
                        [    47,   -100],
                        [    51,    -97],
                        [    56,    -93],
                        [    59,    -89],
                        [    64,    -85],
                        [    68,    -82],
                        [    72,    -79],
                        [    76,    -76],
                        [    79,    -74],
                        [    82,    -72],
                        [    85,    -71],
                        [    86,    -71],
                        [    87,    -71],
                        [    86,    -72],
                        [    85,    -73],
                        [    82,    -76],
                        [    78,    -80],
                        [    74,    -84],
                        [    70,    -89],
                        [    66,    -96],
                        [    62,   -103],
                        [    59,   -111],
                        [    55,   -119],
                        [    53,   -128],
                        [    50,   -137],
                        [    49,   -145],
                        [    47,   -154],
                        [    46,   -161],
                        [    44,   -168],
                        [    41,   -174],
                        [    40,   -180],
                        [    38,   -184],
                        [    37,   -190],
                        [    37,   -197],
                        [    37,   -203],
                        [    39,   -211],
                        [    41,   -219],
                        [    45,   -228],
                        [    49,   -236],
                        [    54,   -241],
                        [    59,   -246],
                        [    62,   -250],
                        [    66,   -253],
                        [    68,   -254],
                        [    70,   -256],
                        [    72,   -256],
                        [    72,   -256],
                        [    74,   -255],
                        [    76,   -252],
                        [    77,   -247],
                        [    80,   -240],
                        [    83,   -232],
                        [    86,   -223],
                        [    91,   -213],
                        [    95,   -204],
                        [   100,   -194],
                        [   106,   -185],
                        [   112,   -176],
                        [   119,   -167],
                        [   127,   -159],
                        [   135,   -151],
                        [   142,   -145],
                        [   150,   -138],
                        [   157,   -132],
                        [   164,   -128],
                        [   171,   -123],
                        [   176,   -119],
                        [   181,   -116],
                        [   186,   -114],
                        [   191,   -113],
                        [   196,   -114],
                        [   201,   -116],
                        [   206,   -119],
                        [   210,   -123],
                        [   214,   -127],
                        [   218,   -130],
                        [   220,   -133],
                        [   221,   -137],
                        [   221,   -139],
                        [   220,   -141],
                        [   218,   -143],
                        [   215,   -145],
                        [   212,   -145],
                        [   208,   -145],
                        [   203,   -145],
                        [   197,   -145],
                        [   192,   -144],
                        [   185,   -143],
                        [   178,   -141],
                        [   171,   -139],
                        [   163,   -137],
                        [   157,   -134],
                        [   150,   -132],
                        [   144,   -129],
                        [   138,   -126],
                        [   133,   -122],
                        [   129,   -119],
                        [   126,   -115],
                        [   124,   -111],
                        [   121,   -106],
                        [   119,   -102],
                        [   118,    -98],
                        [   117,    -93],
                        [   116,    -89],
                        [   116,    -85],
                        [   116,    -80],
                        [   117,    -76],
                        [   117,    -72],
                        [   118,    -67],
                        [   118,    -63],
                        [   119,    -58],
                        [   119,    -53],
                        [   119,    -49],
                        [   119,    -45],
                        [   119,    -41],
                        [   119,    -37],
                        [   119,    -33],
                        [   119,    -28],
                        [   118,    -26],
                        [   116,    -23],
                        [   115,    -20],
                        [   111,    -20],
                        [   109,    -20],
                        [   106,    -22],
                        [   102,    -24],
                        [    98,    -28],
                        [    94,    -32],
                        [    90,    -36],
                        [    86,    -41],
                        [    83,    -45],
                        [    79,    -49],
                        [    75,    -52],
                        [    72,    -55],
                        [    68,    -59],
                        [    66,    -61],
                        [    64,    -63],
                        [    63,    -64],
                        [    63,    -64],
                        [    63,    -63],
                        [    63,    -62],
                        [    65,    -59],
                        [    67,    -55],
                        [    70,    -50],
                        [    73,    -44],
                        [    76,    -37],
                        [    79,    -28],
                        [    81,    -20],
                        [    84,    -12],
                        [    86,     -2],
                        [    89,      7],
                        [    93,     16],
                        [    96,     25],
                        [   100,     33],
                        [   104,     42],
                        [   108,     50],
                        [   112,     59],
                        [   115,     67],
                        [   119,     77],
                        [   120,     88],
                        [   121,     98],
                        [   121,    110],
                        [   122,    120],
                        [   121,    130],
                        [   120,    138],
                        [   119,    145],
                        [   119,    151],
                        [   119,    157],
                        [   120,    163],
                        [   122,    167],
                        [   124,    171],
                        [   124,    174],
                        [   125,    176],
                        [   125,    175],
                        [   124,    172],
                        [   123,    167],
                        [   120,    162],
                        [   117,    154],
                        [   114,    147],
                        [   110,    139],
                        [   104,    131],
                        [    98,    123],
                        [    92,    115],
                        [    85,    106],
                        [    76,     99],
                        [    69,     92],
                        [    60,     84],
                        [    52,     77],
                        [    44,     71],
                        [    35,     64],
                        [    28,     59],
                        [    20,     54],
                        [    13,     49],
                        [     7,     46],
                        [     0,     44],
                        [    -7,     43],
                        [   -13,     43],
                        [   -20,     43],
                        [   -26,     45],
                        [   -33,     46],
                        [   -37,     46],
                        [   -41,     47],
                        [   -45,     47],
                        [   -46,     48],
                        [   -46,     49],
                        [   -46,     50],
                        [   -44,     50],
                        [   -41,     50],
                        [   -37,     50],
                        [   -32,     50],
                        [   -26,     49],
                        [   -19,     49],
                        [   -11,     49],
                        [    -2,     48],
                        [     7,     48],
                        [    15,     48],
                        [    24,     48],
                        [    33,     48],
                        [    41,     48],
                        [    49,     47],
                        [    56,     47],
                        [    63,     47],
                        [    70,     47],
                        [    76,     46],
                        [    82,     46],
                        [    87,     46],
                        [    91,     46],
                        [    95,     46],
                        [    98,     46],
                        [   101,     45],
                        [   103,     45],
                        [   106,     44],
                        [   107,     43],
                        [   110,     41],
                        [   111,     41],
                        [   113,     39],
                        [   114,     37],
                        [   114,     35],
                        [   114,     33],
                        [   114,     30],
                        [   113,     28],
                        [   113,     25],
                        [   112,     23],
                        [   112,     20],
                        [   112,     19],
                        [   112,     17],
                        [   112,     17],
                        [   112,     18],
                        [   112,     20],
                        [   112,     21],
                        [   112,     24],
                        [   112,     26],
                        [   112,     28],
                        [   112,     31],
                        [   112,     33],
                        [   112,     35],
                        [   112,     37],
                        [   112,     38],
                        [   112,     39],
                        [   111,     40],
                        [   111,     40],
                        [   111,     40],
                        [   109,     38],
                        [   106,     37],
                        [   105,     33],
                        [   102,     30],
                        [   100,     25],
                        [    98,     20],
                        [    94,     14],
                        [    91,      8],
                        [    89,      2],
                        [    85,     -6],
                        [    83,    -12],
                        [    80,    -20],
                        [    76,    -25],
                        [    72,    -31],
                        [    68,    -37],
                        [    65,    -41],
                        [    60,    -46],
                        [    57,    -49],
                        [    53,    -53],
                        [    50,    -58],
                        [    46,    -63],
                        [    45,    -67],
                        [    42,    -72],
                        [    41,    -76],
                        [    40,    -80],
                        [    39,    -82],
                        [    37,    -84],
                        [    36,    -85],
                        [    33,    -85],
                        [    30,    -86],
                        [    27,    -87],
                        [    23,    -88],
                        [    19,    -88],
                        [    15,    -87],
                        [    11,    -85],
                        [     9,    -80],
                        [     6,    -76],
                        [     4,    -69],
                        [     2,    -63],
                        [     2,    -55],
                        [     1,    -49],
                        [     2,    -41],
                        [     2,    -34],
                        [     4,    -27],
                        [     7,    -20],
                        [    10,    -15],
                        [    13,     -9],
                        [    17,     -4],
                        [    22,      1],
                        [    27,      5],
                        [    31,      8],
                        [    35,     11],
                        [    39,     13],
                        [    43,     15],
                        [    47,     15],
                        [    51,     15],
                        [    55,     13],
                        [    60,     11],
                        [    65,      8],
                        [    71,      5],
                        [    76,      2],
                        [    80,     -1],
                        [    85,     -4],
                        [    89,     -7],
                        [    91,     -9],
                        [    93,    -11],
                        [    94,    -13],
                        [    94,    -14],
                        [    93,    -15],
                        [    91,    -16],
                        [    89,    -16],
                        [    85,    -16],
                        [    80,    -16],
                        [    74,    -15],
                        [    67,    -15],
                        [    62,    -14],
                        [    55,    -13],
                        [    49,    -11],
                        [    42,    -10],
                        [    35,     -7],
                        [    28,     -5],
                        [    22,     -2],
                        [    16,      0],
                        [    10,      2],
                        [     5,      6],
                        [     0,      8],
                        [    -4,     11],
                        [    -8,     15],
                        [   -12,     18],
                        [   -15,     21],
                        [   -19,     24],
                        [   -22,     27],
                        [   -25,     30],
                        [   -28,     33],
                        [   -32,     37],
                        [   -35,     40],
                        [   -37,     43],
                        [   -40,     46],
                        [   -43,     50],
                        [   -45,     53],
                        [   -47,     56],
                        [   -49,     59],
                        [   -50,     63],
                        [   -52,     66],
                        [   -54,     68],
                        [   -55,     70],
                        [   -57,     72],
                        [   -59,     72],
                        [   -61,     72],
                        [   -62,     71],
                        [   -64,     69],
                        [   -65,     67],
                        [   -67,     65],
                        [   -68,     63],
                        [   -69,     60],
                        [   -71,     58],
                        [   -72,     55],
                        [   -73,     54],
                        [   -75,     52],
                        [   -76,     51],
                        [   -76,     50],
                        [   -78,     50],
                        [   -79,     49],
                        [   -79,     50],
                        [   -79,     51],
                        [   -79,     54],
                        [   -78,     57],
                        [   -76,     61],
                        [   -75,     65],
                        [   -72,     71],
                        [   -70,     77],
                        [   -67,     84],
                        [   -64,     90],
                        [   -61,     98],
                        [   -58,    104],
                        [   -54,    111],
                        [   -50,    118],
                        [   -46,    124],
                        [   -41,    129],
                        [   -36,    135],
                        [   -32,    140],
                        [   -27,    144],
                        [   -23,    149],
                        [   -19,    154],
                        [   -15,    158],
                        [   -12,    163],
                        [   -10,    168],
                        [    -7,    171],
                        [    -5,    175],
                        [    -3,    176],
                        [     0,    179],
                        [     2,    180],
                        [     7,    182],
                        [    10,    184],
                        [    14,    184],
                        [    18,    185],
                        [    21,    185],
                        [    24,    184],
                        [    27,    181],
                        [    29,    178],
                        [    32,    173],
                        [    33,    167],
                        [    33,    161],
                        [    33,    155],
                        [    33,    148],
                        [    32,    140],
                        [    29,    132],
                        [    27,    124],
                        [    23,    117],
                        [    18,    110],
                        [    13,    103],
                        [     7,     97],
                        [     2,     90],
                        [    -4,     85],
                        [   -10,     79],
                        [   -15,     74],
                        [   -20,     71],
                        [   -24,     67],
                        [   -29,     66],
                        [   -34,     65],
                        [   -40,     64],
                        [   -46,     64],
                        [   -51,     65],
                        [   -58,     66],
                        [   -63,     67],
                        [   -68,     68],
                        [   -72,     70],
                        [   -76,     72],
                        [   -79,     73],
                        [   -80,     75],
                        [   -80,     76],
                        [   -80,     78],
                        [   -79,     80],
                        [   -76,     81],
                        [   -72,     83],
                        [   -67,     85],
                        [   -63,     86],
                        [   -57,     87],
                        [   -51,     89],
                        [   -46,     89],
                        [   -40,     90],
                        [   -33,     91],
                        [   -27,     92],
                        [   -20,     91],
                        [   -13,     92],
                        [    -7,     92],
                        [    -2,     91],
                        [     4,     92],
                        [     9,     91],
                        [    12,     90],
                        [    16,     89],
                        [    19,     89],
                        [    22,     88],
                        [    24,     86],
                        [    27,     85],
                        [    30,     83],
                        [    33,     81],
                        [    35,     80],
                        [    37,     77],
                        [    40,     75],
                        [    41,     72],
                        [    43,     70],
                        [    44,     67],
                        [    45,     64],
                        [    45,     61],
                        [    45,     58],
                        [    45,     55],
                        [    45,     52],
                        [    46,     50],
                        [    46,     48],
                        [    46,     47],
                        [    46,     46],
                        [    45,     46],
                        [    44,     46],
                        [    43,     46],
                        [    42,     48],
                        [    42,     49],
                        [    41,     50],
                        [    41,     51],
                        [    42,     54],
                        [    41,     54],
                        [    42,     56],
                        [    42,     58],
                        [    43,     59],
                        [    44,     60],
                        [    46,     60],
                        [    46,     61],
                        [    47,     61],
                        [    47,     61],
                        [    47,     60],
                        [    46,     59],
                        [    46,     57],
                        [    45,     55],
                        [    43,     53],
                        [    41,     50],
                        [    39,     46],
                        [    36,     43],
                        [    33,     39],
                        [    30,     37],
                        [    26,     33],
                        [    22,     30],
                        [    18,     28],
                        [    14,     26],
                        [     9,     24],
                        [     5,     23],
                        [     0,     21],
                        [    -4,     20],
                        [    -8,     17],
                        [   -12,     15],
                        [   -15,     13],
                        [   -20,     11],
                        [   -24,      8],
                        [   -27,      7],
                        [   -31,      4],
                        [   -36,      2],
                        [   -40,     -1],
                        [   -46,     -3],
                        [   -52,     -7],
                        [   -58,    -10],
                        [   -64,    -12],
                        [   -70,    -14],
                        [   -75,    -15],
                        [   -80,    -15],
                        [   -85,    -15],
                        [   -89,    -14],
                        [   -93,    -12],
                        [   -97,    -10],
                        [  -100,     -7],
                        [  -102,     -4],
                        [  -102,     -1],
                        [  -103,      2],
                        [  -102,      6],
                        [  -102,     10],
                        [   -98,     13],
                        [   -96,     16],
                        [   -93,     20],
                        [   -89,     23],
                        [   -86,     25],
                        [   -83,     28],
                        [   -80,     30],
                        [   -77,     31],
                        [   -74,     33],
                        [   -71,     33],
                        [   -67,     33],
                        [   -63,     33],
                        [   -59,     32],
                        [   -54,     31],
                        [   -49,     30],
                        [   -45,     29],
                        [   -40,     28],
                        [   -36,     28],
                        [   -33,     27],
                        [   -31,     25],
                        [   -30,     25],
                        [   -30,     24],
                        [   -30,     24],
                        [   -32,     24],
                        [   -34,     23],
                        [   -37,     23],
                        [   -40,     23],
                        [   -44,     23],
                        [   -47,     24],
                        [   -50,     24],
                        [   -54,     24],
                        [   -59,     25],
                        [   -63,     26],
                        [   -68,     27],
                        [   -74,     28],
                        [   -79,     29],
                        [   -84,     30],
                        [   -88,     32],
                        [   -91,     33],
                        [   -94,     33],
                        [   -98,     35],
                        [  -101,     36],
                        [  -103,     37],
                        [  -106,     38],
                        [  -108,     39],
                        [  -111,     39],
                        [  -115,     41],
                        [  -118,     41],
                        [  -121,     42],
                        [  -124,     44],
                        [  -128,     45],
                        [  -130,     46],
                        [  -132,     46],
                        [  -133,     48],
                        [  -134,     49],
                        [  -136,     50],
                        [  -137,     50],
                        [  -138,     51],
                        [  -140,     52],
                        [  -140,     52],
                        [  -141,     51],
                        [  -141,     51],
                        [  -141,     50],
                        [  -140,     49],
                        [  -140,     47],
                        [  -139,     46],
                        [  -138,     44],
                        [  -138,     42],
                        [  -138,     40],
                        [  -137,     38],
                        [  -137,     37],
                        [  -137,     35],
                        [  -137,     33],
                        [  -138,     32],
                        [  -138,     30],
                        [  -139,     29],
                        [  -140,     28],
                        [  -141,     28],
                        [  -140,     28],
                        [  -140,     28],
                        [  -139,     28],
                        [  -137,     28],
                        [  -137,     30],
                        [  -134,     31],
                        [  -132,     33],
                        [  -128,     35],
                        [  -125,     37],
                        [  -121,     40],
                        [  -118,     42],
                        [  -113,     44],
                        [  -109,     46],
                        [  -104,     47],
                        [  -100,     48],
                        [   -95,     49],
                        [   -90,     50],
                        [   -85,     50],
                        [   -80,     50],
                        [   -76,     50],
                        [   -72,     51],
                        [   -68,     52],
                        [   -64,     53],
                        [   -60,     54],
                        [   -57,     54],
                        [   -53,     55],
                        [   -49,     57],
                        [   -45,     59],
                        [   -41,     60],
                        [   -36,     62],
                        [   -31,     63],
                        [   -26,     64],
                        [   -21,     65],
                        [   -16,     65],
                        [   -11,     65],
                        [    -7,     64],
                        [    -3,     62],
                        [     1,     59],
                        [     4,     56],
                        [     7,     53],
                        [     9,     49],
                        [    11,     44],
                        [    11,     39],
                        [    11,     34],
                        [    10,     29],
                        [     7,     24],
                        [     6,     20],
                        [     3,     15],
                        [     1,     10],
                        [    -2,      6],
                        [    -4,      2],
                        [    -5,     -2],
                        [    -7,     -5],
                        [    -9,     -7],
                        [   -10,     -9],
                        [   -11,    -11],
                        [   -14,    -11],
                        [   -16,    -12],
                        [   -19,    -12],
                        [   -22,    -12],
                        [   -24,    -11],
                        [   -27,    -11],
                        [   -29,    -10],
                        [   -30,     -9],
                        [   -31,     -7],
                        [   -31,     -7],
                        [   -30,     -5],
                        [   -28,     -3],
                        [   -26,     -2],
                        [   -23,     -1],
                        [   -20,      1],
                        [   -17,      2],
                        [   -14,      3],
                        [   -11,      4],
                        [    -7,      5],
                        [    -4,      6],
                        [    -1,      7],
                        [     3,      7],
                        [     7,      7],
                        [    11,      7],
                        [    16,      7],
                        [    20,      6],
                        [    23,      6],
                        [    25,      5],
                        [    28,      4],
                        [    29,      4],
                        [    32,      3],
                        [    33,      2],
                        [    35,      2],
                        [    37,      1],
                        [    38,      0],
                        [    41,     -2],
                        [    43,     -2],
                        [    46,     -3],
                        [    47,     -5],
                        [    50,     -6],
                        [    51,     -7],
                        [    53,     -8],
                        [    54,    -10],
                        [    54,    -11],
                        [    55,    -13],
                        [    56,    -14],
                        [    58,    -15],
                        [    58,    -15],
                        [    59,    -16],
                        [    59,    -17],
                        [    59,    -16],
                        [    59,    -17],
                        [    57,    -16],
                        [    57,    -15],
                        [    56,    -15],
                        [    56,    -14],
                        [    56,    -12],
                        [    56,    -11],
                        [    56,    -10],
                        [    57,     -8],
                        [    58,     -7],
                        [    59,     -5],
                        [    59,     -3],
                        [    61,     -1],
                        [    63,      2],
                        [    64,      3],
                        [    67,      6],
                        [    67,      7],
                        [    69,      9],
                        [    70,     11],
                        [    70,     12],
                        [    70,     14],
                        [    69,     14],
                        [    67,     15],
                        [    67,     15],
                        [    64,     15],
                        [    62,     15],
                        [    59,     14],
                        [    55,     14],
                        [    52,     14],
                        [    49,     13],
                        [    46,     13],
                        [    41,     13],
                        [    37,     14],
                        [    33,     14],
                        [    29,     14],
                        [    25,     13],
                        [    21,     11],
                        [    17,     10],
                        [    13,      7],
                        [     9,      5],
                        [     5,      2],
                        [     2,     -2],
                        [    -2,     -6],
                        [    -7,    -10],
                        [   -11,    -15],
                        [   -15,    -20],
                        [   -20,    -24],
                        [   -25,    -28],
                        [   -30,    -33],
                        [   -35,    -37],
                        [   -41,    -41],
                        [   -46,    -45],
                        [   -50,    -47],
                        [   -54,    -49],
                        [   -59,    -50],
                        [   -62,    -51],
                        [   -65,    -51],
                        [   -67,    -50],
                        [   -68,    -50],
                        [   -68,    -48],
                        [   -68,    -46],
                        [   -67,    -44],
                        [   -65,    -41],
                        [   -63,    -39],
                        [   -62,    -36],
                        [   -60,    -33],
                        [   -59,    -31],
                        [   -58,    -28],
                        [   -56,    -25],
                        [   -55,    -22],
                        [   -54,    -20],
                        [   -53,    -17],
                        [   -51,    -15],
                        [   -49,    -14],
                        [   -47,    -12],
                        [   -44,    -11],
                        [   -41,    -10],
                        [   -39,     -9],
                        [   -37,     -8],
                        [   -36,     -7],
                        [   -35,     -7],
                        [   -34,     -6],
                        [   -34,     -6],
                        [   -35,     -5],
                        [   -36,     -5],
                        [   -37,     -4],
                        [   -39,     -4],
                        [   -41,     -4],
                        [   -42,     -4],
                        [   -43,     -3],
                        [   -44,     -3],
                        [   -46,     -2],
                        [   -47,     -2],
                        [   -50,     -2],
                        [   -52,     -1],
                        [   -54,     -1],
                        [   -57,      0],
                        [   -59,      0],
                        [   -62,      1],
                        [   -63,      1],
                        [   -64,      1],
                        [   -64,      2],
                        [   -65,      2],
                        [   -67,      2],
                        [   -67,      2],
                        [   -69,      2],
                        [   -70,      1],
                        [   -72,      1],
                        [   -74,      1],
                        [   -76,      0],
                        [   -77,      0],
                        [   -80,     -1],
                        [   -81,     -1],
                        [   -83,     -2],
                        [   -84,     -2],
                        [   -85,     -2],
                        [   -87,     -2],
                        [   -88,     -3],
                        [   -89,     -4],
                        [   -89,     -4],
                        [   -90,     -5],
                        [   -90,     -5],
                        [   -90,     -6],
                        [   -89,     -6],
                        [   -89,     -7],
                        [   -87,     -7],
                        [   -86,     -7],
                        [   -86,     -8],
                        [   -85,     -9],
                        [   -85,    -10],
                        [   -85,    -11],
                        [   -85,    -11],
                        [   -85,    -13],
                        [   -85,    -14],
                        [   -85,    -15],
                        [   -85,    -17],
                        [   -86,    -19],
                        [   -88,    -20],
                        [   -88,    -22],
                        [   -89,    -24],
                        [   -89,    -26],
                        [   -89,    -28],
                        [   -88,    -31],
                        [   -87,    -33],
                        [   -85,    -36],
                        [   -83,    -37],
                        [   -81,    -39],
                        [   -78,    -41],
                        [   -75,    -42],
                        [   -72,    -44],
                        [   -68,    -46],
                        [   -64,    -46],
                        [   -60,    -48],
                        [   -57,    -50],
                        [   -53,    -53],
                        [   -49,    -55],
                        [   -45,    -57],
                        [   -41,    -59],
                        [   -36,    -60],
                        [   -32,    -61],
                        [   -28,    -62],
                        [   -24,    -62],
                        [   -20,    -61],
                        [   -15,    -60],
                        [   -12,    -59],
                        [    -9,    -57],
                        [    -5,    -54],
                        [    -1,    -51],
                        [     3,    -49],
                        [     7,    -46],
                        [    12,    -43],
                        [    16,    -40],
                        [    21,    -37],
                        [    26,    -35],
                        [    31,    -33],
                        [    35,    -30],
                        [    39,    -28],
                        [    43,    -28],
                        [    47,    -27],
                        [    50,    -27],
                        [    52,    -27],
                        [    54,    -28],
                        [    54,    -29],
                        [    54,    -31],
                        [    54,    -33],
                        [    54,    -34],
                        [    53,    -36],
                        [    53,    -38],
                        [    52,    -41],
                        [    52,    -43],
                        [    51,    -46],
                        [    52,    -47],
                        [    52,    -50],
                        [    53,    -51],
                        [    54,    -52],
                        [    53,    -54],
                        [    53,    -54],
                        [    52,    -55],
                        [    51,    -56],
                        [    50,    -56],
                        [    50,    -56],
                        [    50,    -57],
                        [    50,    -56],
                        [    50,    -56],
                        [    50,    -56],
                        [    50,    -55],
                        [    52,    -54],
                        [    54,    -54],
                        [    55,    -53],
                        [    57,    -53],
                        [    59,    -52],
                        [    59,    -51],
                        [    59,    -51],
                        [    60,    -50],
                        [    61,    -50],
                        [    61,    -50],
                        [    63,    -50],
                        [    64,    -50],
                        [    66,    -50],
                        [    67,    -50],
                        [    67,    -50],
                        [    68,    -51],
                        [    69,    -51],
                        [    69,    -51],
                        [    69,    -51],
                        [    68,    -52],
                        [    68,    -52],
                        [    68,    -52],
                        [    68,    -52],
                        [    69,    -52],
                        [    70,    -51],
                        [    71,    -51],
                        [    72,    -50],
                        [    73,    -50],
                        [    75,    -50],
                        [    76,    -49],
                        [    76,    -48],
                        [    78,    -47],
                        [    79,    -46],
                        [    80,    -45],
                        [    81,    -44],
                        [    82,    -42],
                        [    84,    -41],
                        [    85,    -41],
                        [    85,    -40],
                        [    85,    -39],
                        [    85,    -38],
                        [    85,    -37],
                        [    85,    -37],
                        [    85,    -36],
                        [    85,    -35],
                        [    85,    -34],
                        [    87,    -33],
                        [    87,    -32],
                        [    88,    -30],
                        [    89,    -29],
                        [    90,    -28],
                        [    92,    -25],
                        [    93,    -24],
                        [    96,    -21],
                        [    98,    -18],
                        [    99,    -15],
                        [   101,    -12],
                        [   102,     -9],
                        [   103,     -6],
                        [   104,     -2],
                        [   105,      2],
                        [   105,      6],
                        [   103,      9],
                        [   102,     12],
                        [   101,     15],
                        [    98,     16],
                        [    97,     19],
                        [    94,     21],
                        [    92,     23],
                        [    89,     25],
                        [    87,     27],
                        [    84,     28],
                        [    80,     30],
                        [    77,     32],
                        [    74,     33],
                        [    70,     33],
                        [    67,     33],
                        [    63,     32],
                        [    59,     30],
                        [    55,     28],
                        [    52,     24],
                        [    49,     22],
                        [    46,     18],
                        [    41,     14],
                        [    38,     10],
                        [    35,      6],
                        [    30,      1],
                        [    26,     -4],
                        [    21,     -8],
                        [    17,    -13],
                        [    12,    -17],
                        [     7,    -22],
                        [     3,    -26],
                        [    -1,    -30],
                        [    -5,    -33],
                        [    -8,    -36],
                        [   -11,    -37],
                        [   -13,    -38],
                        [   -15,    -39],
                        [   -16,    -39],
                        [   -17,    -39],
                        [   -17,    -38],
                        [   -17,    -37],
                        [   -17,    -35],
                        [   -17,    -33],
                        [   -17,    -31],
                        [   -17,    -29],
                        [   -17,    -27],
                        [   -18,    -24],
                        [   -18,    -21],
                        [   -19,    -19],
                        [   -20,    -15],
                        [   -20,    -13],
                        [   -20,    -11],
                        [   -20,     -8],
                        [   -20,     -7],
                        [   -19,     -5],
                        [   -19,     -2],
                        [   -18,     -1],
                        [   -19,      0],
                        [   -19,      2],
                        [   -20,      2],
                        [   -20,      3],
                        [   -21,      4],
                        [   -22,      5],
                        [   -23,      5],
                        [   -24,      6],
                        [   -24,      6],
                        [   -24,      6],
                        [   -24,      7],
                        [   -24,      7],
                        [   -23,      7],
                        [   -23,      7],
                        [   -24,      7],
                        [   -24,      7],
                        [   -25,      8],
                        [   -25,      8],
                        [   -26,      8],
                        [   -26,      9],
                        [   -27,      9],
                        [   -27,      9],
                        [   -27,      9],
                        [   -26,      8],
                        [   -25,      9],
                        [   -26,      8],
                        [   -26,      8],
                        [   -27,      7],
                        [   -28,      7],
                        [   -28,      7],
                        [   -29,      6],
                        [   -31,      5],
                        [   -33,      4],
                        [   -34,      2],
                        [   -35,      2],
                        [   -37,      1],
                        [   -38,     -1],
                        [   -40,     -2],
                        [   -41,     -2],
                        [   -43,     -3],
                        [   -44,     -4],
                        [   -45,     -5],
                        [   -46,     -6],
                        [   -46,     -5],
                        [   -46,     -4],
                        [   -46,     -4],
                        [   -46,     -3],
                        [   -46,     -2],
                        [   -46,     -1],
                        [   -46,     -1],
                        [   -47,     -1],
                        [   -48,     -1],
                        [   -48,     -1],
                        [   -48,      0],
                        [   -49,     -1],
                        [   -50,     -2],
                        [   -50,     -2],
                        [   -51,     -4],
                        [   -52,     -6],
                        [   -54,     -8],
                        [   -54,    -11],
                        [   -54,    -15],
                        [   -54,    -19],
                        [   -54,    -24],
                        [   -54,    -28],
                        [   -53,    -33],
                        [   -51,    -37],
                        [   -50,    -41],
                        [   -48,    -46],
                        [   -46,    -50],
                        [   -44,    -53],
                        [   -41,    -57],
                        [   -39,    -60],
                        [   -37,    -64],
                        [   -34,    -68],
                        [   -31,    -72],
                        [   -28,    -75],
                        [   -25,    -78],
                        [   -22,    -81],
                        [   -19,    -83],
                        [   -15,    -85],
                        [   -12,    -85],
                        [    -9,    -85],
                        [    -7,    -85],
                        [    -3,    -84],
                        [    -1,    -82],
                        [     2,    -80],
                        [     5,    -79],
                        [     7,    -76],
                        [    10,    -73],
                        [    13,    -70],
                        [    16,    -67],
                        [    19,    -63],
                        [    23,    -59],
                        [    26,    -55],
                        [    29,    -51],
                        [    33,    -47],
                        [    36,    -43],
                        [    38,    -40],
                        [    41,    -37],
                        [    42,    -33],
                        [    44,    -30],
                        [    45,    -28],
                        [    46,    -27],
                        [    46,    -25],
                        [    46,    -24],
                        [    46,    -24],
                        [    46,    -24],
                        [    46,    -24],
                        [    46,    -24],
                        [    46,    -24],
                        [    47,    -24],
                        [    48,    -25],
                        [    48,    -26],
                        [    50,    -27],
                        [    50,    -28],
                        [    51,    -28],
                        [    51,    -29],
                        [    52,    -30],
                        [    52,    -30],
                        [    52,    -31],
                        [    52,    -31],
                        [    52,    -32],
                        [    52,    -32],
                        [    53,    -32],
                        [    54,    -32],
                        [    54,    -32],
                        [    55,    -31],
                        [    55,    -32],
                        [    56,    -31],
                        [    57,    -31],
                        [    57,    -31],
                        [    56,    -30],
                        [    54,    -29],
                        [    53,    -29],
                        [    52,    -29],
                        [    50,    -28],
                        [    50,    -28],
                        [    49,    -28],
                        [    49,    -28],
                        [    48,    -28],
                        [    47,    -28],
                        [    47,    -28],
                        [    46,    -28],
                        [    45,    -28],
                        [    44,    -27],
                        [    42,    -26],
                        [    41,    -26],
                        [    40,    -25],
                        [    39,    -24],
                        [    38,    -24],
                        [    37,    -22],
                        [    37,    -20],
                        [    37,    -20],
                        [    38,    -18],
                        [    39,    -16],
                        [    39,    -14],
                        [    40,    -12],
                        [    41,    -10],
                        [    42,     -7],
                        [    43,     -6],
                        [    44,     -3],
                        [    45,     -2],
                        [    46,      0],
                        [    47,      2],
                        [    48,      2],
                        [    49,      2],
                        [    49,      3],
                        [    50,      2],
                        [    50,      2],
                        [    51,      2],
                        [    52,      1],
                        [    53,      0],
                        [    54,      0],
                        [    56,     -1],
                        [    58,     -1],
                        [    59,     -1],
                        [    60,     -2],
                        [    62,     -1],
                        [    63,     -1],
                        [    65,      0],
                        [    66,      2],
                        [    67,      3],
                        [    69,      6],
                        [    71,      9],
                        [    72,     12],
                        [    72,     16],
                        [    72,     20],
                        [    72,     24],
                        [    72,     28],
                        [    72,     33],
                        [    72,     36],
                        [    71,     39],
                        [    69,     42],
                        [    67,     46],
                        [    67,     48],
                        [    65,     52],
                        [    63,     54],
                        [    62,     57],
                        [    60,     59],
                        [    58,     62],
                        [    55,     63],
                        [    53,     65],
                        [    50,     66],
                        [    47,     65],
                        [    44,     65],
                        [    41,     63],
                        [    38,     63],
                        [    36,     62],
                        [    33,     60],
                        [    30,     58],
                        [    28,     55],
                        [    25,     53],
                        [    22,     50],
                        [    19,     47],
                        [    15,     45],
                        [    11,     41],
                        [     8,     37],
                        [     4,     33],
                        [     1,     28],
                        [    -2,     25],
                        [    -5,     21],
                        [    -8,     18],
                        [   -11,     15],
                        [   -13,     12],
                        [   -15,     11],
                        [   -18,      9],
                        [   -20,      7],
                        [   -20,      7],
                        [   -21,      7],
                        [   -23,      7],
                        [   -24,      7],
                        [   -24,      7],
                        [   -26,      8],
                        [   -28,      9],
                        [   -29,     10],
                        [   -31,     11],
                        [   -32,     13],
                        [   -33,     15],
                        [   -35,     16],
                        [   -36,     18],
                        [   -37,     19],
                        [   -37,     20],
                        [   -38,     21],
                        [   -39,     23],
                        [   -40,     24],
                        [   -41,     25],
                        [   -41,     26],
                        [   -41,     27],
                        [   -42,     27],
                        [   -43,     28],
                        [   -43,     28],
                        [   -43,     29],
                        [   -43,     29],
                        [   -42,     29],
                        [   -41,     29],
                        [   -40,     30],
                        [   -38,     30],
                        [   -37,     30],
                        [   -36,     30],
                        [   -34,     31],
                        [   -33,     31],
                        [   -33,     32],
                        [   -32,     32],
                        [   -31,     33],
                        [   -30,     33],
                        [   -29,     33],
                        [   -28,     33],
                        [   -26,     33],
                        [   -24,     33],
                        [   -23,     33],
                        [   -22,     33],
                        [   -20,     33],
                        [   -20,     32],
                        [   -20,     31],
                        [   -19,     31],
                        [   -19,     29],
                        [   -18,     28],
                        [   -18,     28],
                        [   -19,     26],
                        [   -19,     24],
                        [   -20,     23],
                        [   -20,     21],
                        [   -21,     20],
                        [   -22,     18],
                        [   -23,     16],
                        [   -24,     15],
                        [   -24,     15],
                        [   -25,     14],
                        [   -26,     14],
                        [   -27,     14],
                        [   -27,     15],
                        [   -28,     16],
                        [   -28,     18],
                        [   -30,     19],
                        [   -31,     20],
                        [   -33,     20],
                        [   -33,     21],
                        [   -35,     22],
                        [   -36,     23],
                        [   -37,     23],
                        [   -38,     23],
                        [   -39,     22],
                        [   -40,     21],
                        [   -41,     20],
                        [   -42,     18],
                        [   -43,     15],
                        [   -44,     11],
                        [   -45,      8],
                        [   -46,      3],
                        [   -46,     -2],
                        [   -46,     -7],
                        [   -46,    -11],
                        [   -46,    -16],
                        [   -45,    -21],
                        [   -44,    -25],
                        [   -44,    -30],
                        [   -44,    -34],
                        [   -43,    -39],
                        [   -43,    -43],
                        [   -42,    -46],
                        [   -41,    -50],
                        [   -41,    -54],
                        [   -40,    -58],
                        [   -38,    -60],
                        [   -37,    -63],
                        [   -36,    -64],
                        [   -34,    -65],
                        [   -33,    -66],
                        [   -30,    -66],
                        [   -28,    -66],
                        [   -28,    -66],
                        [   -26,    -65],
                        [   -25,    -64],
                        [   -24,    -63],
                        [   -22,    -61],
                        [   -20,    -59],
                        [   -18,    -57],
                        [   -16,    -54],
                        [   -15,    -51],
                        [   -12,    -47],
                        [   -10,    -43],
                        [    -7,    -39],
                        [    -6,    -34],
                        [    -3,    -30],
                        [    -2,    -27],
                        [     0,    -23],
                        [     2,    -20],
                        [     4,    -16],
                        [     6,    -14],
                        [     7,    -11],
                        [     9,     -9],
                        [    10,     -7],
                        [    11,     -6],
                        [    12,     -5],
                        [    13,     -4],
                        [    15,     -3],
                        [    15,     -2],
                        [    17,     -2],
                        [    18,     -2],
                        [    20,     -2],
                        [    21,     -2],
                        [    22,     -2],
                        [    23,     -2],
                        [    24,     -3],
                        [    24,     -3],
                        [    24,     -4],
                        [    25,     -4],
                        [    25,     -5],
                        [    26,     -5],
                        [    26,     -5],
                        [    26,     -5],
                        [    27,     -5],
                        [    26,     -5],
                        [    25,     -5],
                        [    25,     -5],
                        [    24,     -4],
                        [    23,     -4],
                        [    20,     -4],
                        [    19,     -3],
                        [    16,     -3],
                        [    14,     -2],
                        [    12,     -2],
                        [    10,     -2],
                        [     8,     -2],
                        [     7,     -2],
                        [     5,     -2],
                        [     4,     -1],
                        [     2,     -1],
                        [     1,     -1],
                        [    -2,     -1],
                        [    -3,      0],
                        [    -5,      0],
                        [    -7,      1],
                        [    -9,      2],
                        [   -11,      2],
                        [   -12,      3],
                        [   -13,      4],
                        [   -15,      6],
                        [   -15,      7],
                        [   -16,      8],
                        [   -16,     10],
                        [   -16,     11],
                        [   -16,     13],
                        [   -16,     15],
                        [   -15,     17],
                        [   -15,     19],
                        [   -14,     20],
                        [   -13,     23],
                        [   -12,     24],
                        [   -11,     24],
                        [   -10,     24],
                        [    -9,     24],
                        [    -7,     24],
                        [    -6,     22],
                        [    -4,     21],
                        [    -2,     20],
                        [    -1,     18],
                        [     2,     16],
                        [     3,     15],
                        [     5,     13],
                        [     7,     11],
                        [     9,     10],
                        [    11,      8],
                        [    11,      7],
                        [    13,      7],
                        [    15,      6],
                        [    16,      6],
                        [    17,      7],
                        [    19,      7],
                        [    20,     10],
                        [    21,     12],
                        [    22,     15],
                        [    23,     18],
                        [    23,     22],
                        [    23,     26],
                        [    24,     29],
                        [    24,     33],
                        [    24,     37],
                        [    24,     40],
                        [    24,     43],
                        [    24,     46],
                        [    24,     50],
                        [    24,     53],
                        [    24,     56],
                        [    24,     59],
                        [    24,     62],
                        [    23,     64],
                        [    22,     66],
                        [    20,     67],
                        [    20,     68],
                        [    18,     69],
                        [    16,     70],
                        [    15,     70],
                        [    15,     71],
                        [    13,     71],
                        [    12,     71],
                        [    11,     70],
                        [    10,     69],
                        [     8,     68],
                        [     7,     67],
                        [     5,     65],
                        [     3,     63],
                        [     2,     60],
                        [    -1,     57],
                        [    -2,     54],
                        [    -4,     50],
                        [    -7,     47],
                        [    -8,     44],
                        [   -10,     41],
                        [   -12,     38],
                        [   -14,     36],
                        [   -16,     33],
                        [   -18,     31],
                        [   -20,     29],
                        [   -22,     28],
                        [   -23,     27],
                        [   -24,     26],
                        [   -26,     25],
                        [   -28,     24],
                        [   -29,     24],
                        [   -31,     24],
                        [   -33,     24],
                        [   -34,     24],
                        [   -36,     24],
                        [   -37,     24],
                        [   -38,     24],
                        [   -40,     24],
                        [   -41,     25],
                        [   -41,     25],
                        [   -42,     26],
                        [   -43,     26],
                        [   -43,     27],
                        [   -44,     27],
                        [   -45,     27],
                        [   -45,     28],
                        [   -44,     28],
                        [   -44,     28],
                        [   -43,     28],
                        [   -42,     28],
                        [   -41,     28],
                        [   -39,     28],
                        [   -37,     28],
                        [   -36,     28],
                        [   -34,     28],
                        [   -32,     28],
                        [   -30,     28],
                        [   -28,     28],
                        [   -27,     28],
                        [   -25,     28],
                        [   -24,     29],
                        [   -22,     29],
                        [   -20,     29],
                        [   -19,     30],
                        [   -17,     30],
                        [   -15,     30],
                        [   -12,     30],
                        [   -11,     29],
                        [    -9,     29],
                        [    -7,     29],
                        [    -5,     28],
                        [    -3,     28],
                        [    -2,     27],
                        [    -1,     26],
                        [     1,     24],
                        [     2,     24],
                        [     2,     22],
                        [     2,     20],
                        [     2,     19],
                        [     2,     17],
                        [     2,     15],
                        [     3,     14],
                        [     2,     12],
                        [     2,     11],
                        [     2,     11],
                        [     1,     11],
                        [     0,     11],
                        [    -2,     11],
                        [    -2,     12],
                        [    -3,     13],
                        [    -5,     14],
                        [    -6,     15],
                        [    -8,     16],
                        [    -9,     17],
                        [   -11,     18],
                        [   -11,     19],
                        [   -12,     20],
                        [   -13,     20],
                        [   -14,     20],
                        [   -15,     20],
                        [   -17,     19],
                        [   -18,     18],
                        [   -19,     15],
                        [   -20,     14],
                        [   -20,     11],
                        [   -21,      7],
                        [   -22,      3],
                        [   -23,      0],
                        [   -24,     -5],
                        [   -24,     -9],
                        [   -25,    -12],
                        [   -26,    -16],
                        [   -26,    -20],
                        [   -28,    -24],
                        [   -28,    -28],
                        [   -29,    -31],
                        [   -29,    -35],
                        [   -30,    -38],
                        [   -31,    -42],
                        [   -31,    -45],
                        [   -32,    -47],
                        [   -32,    -50],
                        [   -31,    -52],
                        [   -31,    -54],
                        [   -30,    -55],
                        [   -30,    -57],
                        [   -29,    -58],
                        [   -29,    -59],
                        [   -28,    -59],
                        [   -28,    -59],
                        [   -28,    -59],
                        [   -28,    -59],
                        [   -27,    -59],
                        [   -26,    -58],
                        [   -25,    -56],
                        [   -24,    -54],
                        [   -24,    -52],
                        [   -22,    -50],
                        [   -21,    -46],
                        [   -20,    -42],
                        [   -19,    -39],
                        [   -17,    -36],
                        [   -15,    -33],
                        [   -14,    -30],
                        [   -11,    -27],
                        [    -9,    -24],
                        [    -7,    -22],
                        [    -6,    -20],
                        [    -4,    -18],
                        [    -2,    -16],
                        [    -2,    -15],
                        [    -1,    -13],
                        [     1,    -11],
                        [     2,    -11],
                        [     3,    -10],
                        [     5,     -9],
                        [     5,     -9],
                        [     7,     -8],
                        [     8,     -8],
                        [     9,     -7],
                        [    10,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    12,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    10,     -8],
                        [     9,     -8],
                        [     7,     -7],
                        [     6,     -7],
                        [     4,     -7],
                        [     2,     -7],
                        [     0,     -7],
                        [    -2,     -7],
                        [    -3,     -7],
                        [    -5,     -6],
                        [    -7,     -6],
                        [    -7,     -5],
                        [    -9,     -5],
                        [   -10,     -5],
                        [   -11,     -4],
                        [   -12,     -5],
                        [   -14,     -4],
                        [   -15,     -4],
                        [   -16,     -4],
                        [   -17,     -3],
                        [   -19,     -3],
                        [   -20,     -2],
                        [   -21,     -2],
                        [   -22,     -1],
                        [   -24,     -1],
                        [   -24,      0],
                        [   -25,      1],
                        [   -26,      2],
                        [   -26,      3],
                        [   -27,      4],
                        [   -28,      6],
                        [   -28,      7],
                        [   -27,      8],
                        [   -27,      9],
                        [   -26,     11],
                        [   -26,     11],
                        [   -25,     11],
                        [   -24,     11],
                        [   -24,     11],
                        [   -22,     11],
                        [   -21,      9],
                        [   -20,      7],
                        [   -19,      7],
                        [   -17,      5],
                        [   -16,      3],
                        [   -15,      2],
                        [   -13,     -1],
                        [   -11,     -2],
                        [   -11,     -4],
                        [   -10,     -6],
                        [    -9,     -7],
                        [    -8,     -8],
                        [    -7,     -9],
                        [    -7,    -10],
                        [    -6,    -11],
                        [    -4,    -10],
                        [    -3,     -9],
                        [    -2,     -8],
                        [    -2,     -6],
                        [    -1,     -4],
                        [     0,     -2],
                        [     1,      0],
                        [     2,      2],
                        [     2,      5],
                        [     3,      7],
                        [     5,     10],
                        [     6,     12],
                        [     7,     15],
                        [     8,     17],
                        [     9,     20],
                        [    11,     23],
                        [    11,     25],
                        [    12,     28],
                        [    12,     30],
                        [    13,     32],
                        [    13,     34],
                        [    14,     37],
                        [    14,     38],
                        [    14,     40],
                        [    15,     41],
                        [    15,     42],
                        [    15,     44],
                        [    15,     46],
                        [    15,     46],
                        [    15,     46],
                        [    15,     46],
                        [    15,     46],
                        [    15,     46],
                        [    15,     45],
                        [    15,     44],
                        [    14,     42],
                        [    13,     40],
                        [    13,     38],
                        [    11,     36],
                        [    11,     33],
                        [     9,     31],
                        [     7,     29],
                        [     6,     27],
                        [     3,     24],
                        [     2,     23],
                        [     0,     21],
                        [    -2,     20],
                        [    -3,     18],
                        [    -5,     16],
                        [    -6,     15],
                        [    -7,     15],
                        [    -8,     14],
                        [    -9,     13],
                        [   -11,     12],
                        [   -11,     11],
                        [   -12,     11],
                        [   -14,     11],
                        [   -15,     11],
                        [   -15,     11],
                        [   -16,     11],
                        [   -16,     11],
                        [   -17,     11],
                        [   -18,     11],
                        [   -18,     11],
                        [   -17,     11],
                        [   -17,     11],
                        [   -16,     11],
                        [   -15,     11],
                        [   -15,     11],
                        [   -14,     11],
                        [   -12,     11],
                        [   -11,     10],
                        [    -9,     10],
                        [    -7,     10],
                        [    -6,     10],
                        [    -5,     10],
                        [    -3,      9],
                        [    -2,      9],
                        [     0,      9],
                        [     2,      8],
                        [     3,      8],
                        [     4,      8],
                        [     5,      8],
                        [     7,      8],
                        [     7,      8],
                        [     9,      7],
                        [    11,      7],
                        [    12,      7],
                        [    14,      7],
                        [    15,      7],
                        [    16,      6],
                        [    18,      5],
                        [    20,      5],
                        [    21,      4],
                        [    23,      3],
                        [    24,      2],
                        [    25,      2],
                        [    26,      1],
                        [    27,     -1],
                        [    28,     -2],
                        [    28,     -3],
                        [    28,     -5],
                        [    28,     -7],
                        [    28,     -7],
                        [    28,     -7],
                        [    28,     -8],
                        [    28,     -8],
                        [    28,     -8],
                        [    27,     -7],
                        [    26,     -7],
                        [    25,     -6],
                        [    24,     -5],
                        [    23,     -5],
                        [    22,     -4],
                        [    21,     -3],
                        [    20,     -2],
                        [    20,     -2],
                        [    19,     -1],
                        [    19,      0],
                        [    18,      1],
                        [    17,      1],
                        [    16,      1],
                        [    15,      0],
                        [    15,     -1],
                        [    14,     -2],
                        [    13,     -3],
                        [    12,     -5],
                        [    11,     -7],
                        [    10,     -8],
                        [     9,    -11],
                        [     7,    -13],
                        [     7,    -15],
                        [     6,    -17],
                        [     4,    -20],
                        [     2,    -22],
                        [     2,    -24],
                        [     0,    -26],
                        [    -1,    -28],
                        [    -2,    -31],
                        [    -3,    -33],
                        [    -4,    -35],
                        [    -5,    -37],
                        [    -6,    -40],
                        [    -7,    -41],
                        [    -7,    -43],
                        [    -8,    -45],
                        [    -8,    -46],
                        [    -9,    -48],
                        [   -10,    -50],
                        [   -11,    -50],
                        [   -11,    -52],
                        [   -12,    -53],
                        [   -13,    -54],
                        [   -14,    -54],
                        [   -15,    -54],
                        [   -15,    -53],
                        [   -15,    -52],
                        [   -15,    -51],
                        [   -15,    -50],
                        [   -15,    -48],
                        [   -15,    -46],
                        [   -14,    -44],
                        [   -13,    -41],
                        [   -12,    -40],
                        [   -11,    -37],
                        [   -10,    -35],
                        [    -8,    -33],
                        [    -7,    -31],
                        [    -6,    -29],
                        [    -5,    -28],
                        [    -4,    -26],
                        [    -3,    -24],
                        [    -2,    -23],
                        [    -2,    -21],
                        [    -1,    -20],
                        [     0,    -19],
                        [     1,    -18],
                        [     2,    -18],
                        [     2,    -17],
                        [     2,    -16],
                        [     3,    -15],
                        [     3,    -15],
                        [     3,    -15],
                        [     4,    -15],
                        [     4,    -15],
                        [     4,    -14],
                        [     4,    -15],
                        [     4,    -14],
                        [     3,    -14],
                        [     2,    -14],
                        [     2,    -14],
                        [     1,    -14],
                        [     0,    -13],
                        [    -1,    -13],
                        [    -2,    -13],
                        [    -2,    -13],
                        [    -4,    -13],
                        [    -5,    -12],
                        [    -5,    -11],
                        [    -6,    -11],
                        [    -7,    -11],
                        [    -7,    -11],
                        [    -8,    -11],
                        [    -9,    -11],
                        [    -9,    -10],
                        [   -10,    -10],
                        [   -10,    -10],
                        [   -11,    -10],
                        [   -11,     -9],
                        [   -11,     -9],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -12,     -7],
                        [   -13,     -7],
                        [   -14,     -7],
                        [   -15,     -6],
                        [   -15,     -6],
                        [   -16,     -5],
                        [   -17,     -4],
                        [   -17,     -3],
                        [   -18,     -3],
                        [   -19,     -2],
                        [   -19,     -2],
                        [   -20,     -1],
                        [   -20,      0],
                        [   -20,      1],
                        [   -20,      2],
                        [   -20,      2],
                        [   -20,      2],
                        [   -19,      2],
                        [   -19,      1],
                        [   -18,      0],
                        [   -17,     -1],
                        [   -16,     -2],
                        [   -16,     -3],
                        [   -15,     -4],
                        [   -15,     -6],
                        [   -14,     -7],
                        [   -14,     -8],
                        [   -13,    -10],
                        [   -13,    -11],
                        [   -13,    -12],
                        [   -13,    -13],
                        [   -13,    -15],
                        [   -12,    -15],
                        [   -12,    -15],
                        [   -11,    -15],
                        [   -11,    -15],
                        [   -11,    -15],
                        [   -10,    -15],
                        [    -8,    -14],
                        [    -8,    -13],
                        [    -7,    -12],
                        [    -6,    -11],
                        [    -5,    -10],
                        [    -3,     -9],
                        [    -2,     -8],
                        [    -2,     -7],
                        [     0,     -6],
                        [     1,     -4],
                        [     2,     -2],
                        [     3,      0],
                        [     5,      2],
                        [     6,      3],
                        [     7,      5],
                        [     8,      7],
                        [     9,      9],
                        [    10,     11],
                        [    11,     13],
                        [    12,     15],
                        [    13,     17],
                        [    14,     19],
                        [    15,     20],
                        [    16,     23],
                        [    18,     24],
                        [    19,     25],
                        [    20,     26],
                        [    20,     26],
                        [    22,     28],
                        [    22,     27],
                        [    23,     27],
                        [    23,     27],
                        [    23,     27],
                        [    24,     26],
                        [    23,     25],
                        [    22,     24],
                        [    21,     24],
                        [    20,     22],
                        [    20,     21],
                        [    18,     20],
                        [    16,     19],
                        [    15,     18],
                        [    14,     17],
                        [    13,     15],
                        [    12,     15],
                        [    11,     14],
                        [    11,     13],
                        [    11,     11],
                        [    10,     11],
                        [    10,     10],
                        [     9,      9],
                        [     8,      8],
                        [     7,      8],
                        [     7,      7],
                        [     7,      7],
                        [     7,      7],
                        [     7,      7],
                        [     6,      6],
                        [     7,      6],
                        [     7,      6],
                        [     7,      6],
                        [     8,      5],
                        [     8,      5],
                        [     9,      4],
                        [    10,      4],
                        [    11,      4],
                        [    12,      3],
                        [    13,      3],
                        [    15,      3],
                        [    15,      2],
                        [    15,      2],
                        [    16,      2],
                        [    17,      2],
                        [    18,      2],
                        [    20,      1],
                        [    20,      1],
                        [    20,      0],
                        [    21,      0],
                        [    22,      0],
                        [    22,     -1],
                        [    23,     -1],
                        [    24,     -2],
                        [    24,     -2],
                        [    24,     -2],
                        [    25,     -2],
                        [    25,     -2],
                        [    26,     -3],
                        [    27,     -3],
                        [    28,     -4],
                        [    29,     -4],
                        [    30,     -5],
                        [    31,     -5],
                        [    32,     -6],
                        [    33,     -6],
                        [    33,     -7],
                        [    34,     -7],
                        [    35,     -7],
                        [    35,     -8],
                        [    36,     -9],
                        [    36,    -10],
                        [    36,    -10],
                        [    36,    -10],
                        [    35,    -10],
                        [    35,    -10],
                        [    34,    -10],
                        [    34,     -9],
                        [    33,     -8],
                        [    33,     -8],
                        [    33,     -7],
                        [    33,     -7],
                        [    32,     -6],
                        [    31,     -4],
                        [    31,     -3],
                        [    31,     -2],
                        [    30,     -2],
                        [    30,     -1],
                        [    30,     -1],
                        [    30,      0],
                        [    29,      0],
                        [    28,      0],
                        [    28,      1],
                        [    28,      1],
                        [    27,      0],
                        [    26,      0],
                        [    25,     -1],
                        [    24,     -1],
                        [    23,     -2],
                        [    22,     -2],
                        [    20,     -2],
                        [    20,     -2],
                        [    19,     -3],
                        [    17,     -4],
                        [    16,     -5],
                        [    15,     -6],
                        [    14,     -7],
                        [    13,     -8],
                        [    12,     -9],
                        [    11,    -11],
                        [    10,    -11],
                        [     8,    -13],
                        [     7,    -15],
                        [     7,    -16],
                        [     5,    -18],
                        [     4,    -19],
                        [     2,    -20],
                        [     2,    -21],
                        [     0,    -23],
                        [    -2,    -24],
                        [    -2,    -24],
                        [    -4,    -25],
                        [    -5,    -26],
                        [    -6,    -26],
                        [    -7,    -27],
                        [    -8,    -27],
                        [    -9,    -26],
                        [   -10,    -26],
                        [   -10,    -26],
                        [   -10,    -25],
                        [   -10,    -24],
                        [   -10,    -24],
                        [    -9,    -23],
                        [    -8,    -22],
                        [    -7,    -21],
                        [    -7,    -20],
                        [    -6,    -19],
                        [    -5,    -18],
                        [    -5,    -17],
                        [    -4,    -16],
                        [    -3,    -15],
                        [    -3,    -14],
                        [    -3,    -13],
                        [    -3,    -12],
                        [    -3,    -11],
                        [    -2,    -11],
                        [    -2,    -11],
                        [    -2,    -10],
                        [    -2,     -9],
                        [    -2,     -9],
                        [    -2,     -8],
                        [    -2,     -8],
                        [    -2,     -7],
                        [    -1,     -7],
                        [    -1,     -7],
                        [    -2,     -7],
                        [    -2,     -7],
                        [    -2,     -7],
                        [    -2,     -7],
                        [    -3,     -7],
                        [    -3,     -7],
                        [    -3,     -6],
                        [    -3,     -6],
                        [    -4,     -6],
                        [    -4,     -5],
                        [    -4,     -5],
                        [    -4,     -5],
                        [    -4,     -4],
                        [    -4,     -4],
                        [    -4,     -4],
                        [    -4,     -3],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -1],
                        [    -4,     -1],
                        [    -3,     -1],
                        [    -3,      0],
                        [    -3,      0],
                        [    -4,      1],
                        [    -4,      1],
                        [    -4,      2],
                        [    -5,      2],
                        [    -6,      2],
                        [    -7,      2],
                        [    -7,      3],
                        [    -8,      3],
                        [    -9,      3],
                        [   -10,      3],
                        [   -11,      4],
                        [   -11,      4],
                        [   -12,      4],
                        [   -12,      5],
                        [   -13,      5],
                        [   -13,      5],
                        [   -14,      5],
                        [   -15,      5],
                        [   -15,      5],
                        [   -15,      4],
                        [   -15,      4],
                        [   -15,      3],
                        [   -15,      3],
                        [   -15,      2],
                        [   -15,      2],
                        [   -15,      1],
                        [   -16,      0],
                        [   -16,     -1],
                        [   -16,     -2],
                        [   -17,     -2],
                        [   -17,     -4],
                        [   -18,     -5],
                        [   -18,     -6],
                        [   -18,     -7],
                        [   -19,     -7],
                        [   -18,     -8],
                        [   -18,     -8],
                        [   -17,     -9],
                        [   -16,     -9],
                        [   -15,     -9],
                        [   -15,    -10],
                        [   -15,    -10],
                        [   -14,    -11],
                        [   -13,    -11],
                        [   -12,    -11],
                        [   -11,    -10],
                        [   -11,    -10],
                        [   -10,    -10],
                        [    -9,     -9],
                        [    -8,     -9],
                        [    -7,     -7],
                        [    -6,     -7],
                        [    -4,     -6],
                        [    -3,     -4],
                        [    -2,     -3],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [     4,      4],
                        [     6,      6],
                        [     7,      7],
                        [     8,      8],
                        [    10,     10],
                        [    11,     11],
                        [    12,     11],
                        [    13,     12],
                        [    14,     13],
                        [    15,     14],
                        [    16,     15],
                        [    16,     15],
                        [    17,     15],
                        [    17,     15],
                        [    17,     15],
                        [    16,     15],
                        [    16,     15],
                        [    15,     15],
                        [    15,     14],
                        [    15,     14],
                        [    15,     13],
                        [    14,     12],
                        [    14,     11],
                        [    13,     11],
                        [    13,     11],
                        [    13,     10],
                        [    13,      9],
                        [    13,      9],
                        [    13,      8],
                        [    12,      7],
                        [    12,      7],
                        [    12,      7],
                        [    13,      6],
                        [    13,      6],
                        [    13,      5],
                        [    13,      5],
                        [    13,      5],
                        [    13,      4],
                        [    14,      4],
                        [    14,      4],
                        [    15,      4],
                        [    15,      4],
                        [    15,      4],
                        [    15,      3],
                        [    15,      3],
                        [    16,      3],
                        [    16,      3],
                        [    16,      3],
                        [    16,      3],
                        [    16,      2],
                        [    17,      2],
                        [    17,      2],
                        [    17,      2],
                        [    17,      2],
                        [    17,      2],
                        [    17,      2],
                        [    16,      1],
                        [    16,      1],
                        [    16,      1],
                        [    16,      1],
                        [    17,      0],
                        [    16,      0],
                        [    16,     -1],
                        [    16,     -2],
                        [    15,     -2],
                        [    16,     -2],
                        [    16,     -2],
                        [    16,     -2],
                        [    16,     -3],
                        [    17,     -2],
                        [    18,     -3],
                        [    19,     -3],
                        [    19,     -3],
                        [    20,     -3],
                        [    20,     -3],
                        [    20,     -3],
                        [    20,     -3],
                        [    21,     -3],
                        [    21,     -4],
                        [    21,     -4],
                        [    22,     -5],
                        [    22,     -5],
                        [    22,     -5],
                        [    22,     -6],
                        [    22,     -5],
                        [    22,     -5],
                        [    22,     -5],
                        [    22,     -5],
                        [    23,     -5],
                        [    23,     -4],
                        [    23,     -4],
                        [    23,     -3],
                        [    24,     -2],
                        [    24,     -2],
                        [    24,     -1],
                        [    25,      0],
                        [    24,      1],
                        [    25,      2],
                        [    24,      2],
                        [    24,      3],
                        [    24,      3],
                        [    24,      4],
                        [    24,      5],
                        [    24,      6],
                        [    23,      7],
                        [    22,      7],
                        [    21,      7],
                        [    21,      8],
                        [    20,      9],
                        [    20,      9],
                        [    20,     10],
                        [    19,     10],
                        [    18,     10],
                        [    18,     10],
                        [    17,      9],
                        [    15,      9],
                        [    15,      8],
                        [    14,      7],
                        [    13,      7],
                        [    11,      6],
                        [    10,      5],
                        [     9,      4],
                        [     7,      2],
                        [     6,      2],
                        [     4,      1],
                        [     3,      0],
                        [     2,     -1],
                        [     0,     -2],
                        [    -2,     -3],
                        [    -3,     -4],
                        [    -5,     -5],
                        [    -6,     -5],
                        [    -7,     -7],
                        [    -8,     -7],
                        [    -8,     -7],
                        [    -9,     -7],
                        [   -10,     -7],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -11,     -6],
                        [   -11,     -5],
                        [   -11,     -5],
                        [   -11,     -4],
                        [   -11,     -4],
                        [   -11,     -3],
                        [   -11,     -2],
                        [   -11,     -2],
                        [   -11,     -2],
                        [   -11,     -2],
                        [   -11,     -2],
                        [   -11,     -1],
                        [   -11,     -1],
                        [   -11,      0],
                        [   -11,      0],
                        [   -11,      0],
                        [   -11,      0],
                        [   -10,      0],
                        [   -10,      0],
                        [   -10,      1],
                        [    -9,      0],
                        [    -9,      1],
                        [    -8,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      2],
                        [    -6,      2],
                        [    -6,      2],
                        [    -6,      2],
                        [    -5,      2],
                        [    -4,      2],
                        [    -4,      2],
                        [    -4,      3],
                        [    -4,      3],
                        [    -3,      4],
                        [    -3,      4],
                        [    -3,      5],
                        [    -3,      5],
                        [    -2,      5],
                        [    -2,      5],
                        [    -3,      5],
                        [    -3,      6],
                        [    -3,      6],
                        [    -4,      6],
                        [    -5,      6],
                        [    -6,      5],
                        [    -7,      5],
                        [    -8,      5],
                        [    -9,      4],
                        [   -10,      3],
                        [   -11,      3],
                        [   -11,      2],
                        [   -11,      2],
                        [   -12,      2],
                        [   -13,      2],
                        [   -15,      2],
                        [   -15,      2],
                        [   -16,      2],
                        [   -16,      2],
                        [   -18,      2],
                        [   -19,      2],
                        [   -19,      2],
                        [   -20,      2],
                        [   -20,      1],
                        [   -21,      1],
                        [   -22,      0],
                        [   -23,      0],
                        [   -24,      0],
                        [   -24,     -1],
                        [   -25,     -2],
                        [   -26,     -2],
                        [   -26,     -3],
                        [   -26,     -4],
                        [   -27,     -5],
                        [   -27,     -6],
                        [   -27,     -7],
                        [   -26,     -7],
                        [   -26,     -8],
                        [   -26,     -9],
                        [   -26,    -10],
                        [   -26,    -11],
                        [   -26,    -11],
                        [   -26,    -11],
                        [   -25,    -12],
                        [   -24,    -12],
                        [   -24,    -12],
                        [   -24,    -13],
                        [   -24,    -12],
                        [   -23,    -12],
                        [   -23,    -12],
                        [   -22,    -12],
                        [   -21,    -11],
                        [   -20,    -11],
                        [   -19,    -11],
                        [   -18,    -10],
                        [   -17,     -8],
                        [   -16,     -7],
                        [   -15,     -7],
                        [   -14,     -6],
                        [   -12,     -5],
                        [   -11,     -4],
                        [   -10,     -3],
                        [    -9,     -2],
                        [    -7,     -2],
                        [    -7,     -1],
                        [    -6,      0],
                        [    -4,      1],
                        [    -3,      1],
                        [    -2,      2],
                        [    -2,      2],
                        [    -1,      2],
                        [    -1,      3],
                        [     0,      3],
                        [     1,      4],
                        [     1,      4],
                        [     1,      4],
                        [     2,      4],
                        [     2,      4],
                        [     2,      4],
                        [     2,      4],
                        [     3,      4],
                        [     3,      4],
                        [     3,      3],
                        [     4,      3],
                        [     5,      2],
                        [     5,      2],
                        [     6,      2],
                        [     6,      2],
                        [     6,      2],
                        [     7,      2],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      0],
                        [     8,      1],
                        [     8,      1],
                        [     8,      1],
                        [     8,      1],
                        [     9,      1],
                        [     9,      1],
                        [     9,      1],
                        [     9,      1],
                        [     9,      1],
                        [     9,      2],
                        [     8,      2],
                        [     8,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     6,      2],
                        [     6,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      1],
                        [     4,      0],
                        [     4,      0],
                        [     3,      0],
                        [     2,     -1],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     1,     -2],
                        [     1,     -3],
                        [     1,     -3],
                        [     2,     -3],
                        [     2,     -4],
                        [     2,     -4],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     5,     -3],
                        [     5,     -3],
                        [     6,     -3],
                        [     6,     -3],
                        [     7,     -3],
                        [     7,     -3],
                        [     7,     -3],
                        [     8,     -3],
                        [     9,     -2],
                        [     9,     -2],
                        [    10,     -2],
                        [    11,     -2],
                        [    11,     -1],
                        [    11,      0],
                        [    12,      0],
                        [    12,      1],
                        [    13,      2],
                        [    13,      3],
                        [    13,      4],
                        [    14,      5],
                        [    14,      6],
                        [    14,      7],
                        [    14,      8],
                        [    14,      9],
                        [    14,     10],
                        [    13,     11],
                        [    13,     11],
                        [    13,     12],
                        [    14,     13],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    12,     15],
                        [    12,     15],
                        [    11,     14],
                        [    11,     14],
                        [    10,     13],
                        [     9,     13],
                        [     8,     12],
                        [     7,     11],
                        [     7,     11],
                        [     5,     11],
                        [     4,     10],
                        [     3,      9],
                        [     2,      8],
                        [     1,      7],
                        [     0,      7],
                        [    -2,      6],
                        [    -2,      5],
                        [    -3,      4],
                        [    -4,      3],
                        [    -5,      2],
                        [    -6,      2],
                        [    -7,      2],
                        [    -7,      1],
                        [    -8,      0],
                        [    -8,      0],
                        [    -9,     -1],
                        [    -9,     -1],
                        [   -10,     -1],
                        [   -10,     -1],
                        [   -11,     -1],
                        [   -11,     -1],
                        [   -11,     -1],
                        [   -11,     -1],
                        [   -11,     -1],
                        [   -11,      0],
                        [   -12,      1],
                        [   -12,      1],
                        [   -12,      1],
                        [   -12,      2],
                        [   -12,      2],
                        [   -12,      2],
                        [   -11,      3],
                        [   -11,      3],
                        [   -12,      4],
                        [   -12,      4],
                        [   -11,      5],
                        [   -11,      5],
                        [   -11,      5],
                        [   -11,      5],
                        [   -11,      6],
                        [   -11,      6],
                        [   -11,      6],
                        [   -11,      6],
                        [   -10,      6],
                        [    -9,      6],
                        [    -9,      6],
                        [    -8,      6],
                        [    -7,      5],
                        [    -7,      6],
                        [    -7,      6],
                        [    -7,      5],
                        [    -6,      5],
                        [    -6,      5],
                        [    -5,      5],
                        [    -5,      5],
                        [    -5,      5],
                        [    -4,      5],
                        [    -4,      6],
                        [    -5,      6],
                        [    -5,      6],
                        [    -4,      7],
                        [    -4,      7],
                        [    -4,      7],
                        [    -4,      7],
                        [    -4,      7],
                        [    -4,      7],
                        [    -5,      7],
                        [    -5,      7],
                        [    -6,      7],
                        [    -7,      7],
                        [    -7,      7],
                        [    -7,      6],
                        [    -8,      5],
                        [    -9,      5],
                        [    -9,      4],
                        [   -10,      3],
                        [   -11,      2],
                        [   -11,      2],
                        [   -11,      3],
                        [   -12,      3],
                        [   -13,      3],
                        [   -14,      3],
                        [   -15,      2],
                        [   -15,      2],
                        [   -16,      2],
                        [   -17,      3],
                        [   -18,      3],
                        [   -18,      3],
                        [   -19,      3],
                        [   -20,      3],
                        [   -20,      3],
                        [   -21,      2],
                        [   -22,      2],
                        [   -22,      2],
                        [   -23,      2],
                        [   -23,      1],
                        [   -23,      0],
                        [   -24,     -1],
                        [   -24,     -2],
                        [   -24,     -2],
                        [   -24,     -2],
                        [   -24,     -3],
                        [   -24,     -4],
                        [   -24,     -6],
                        [   -24,     -6],
                        [   -24,     -7],
                        [   -24,     -7],
                        [   -24,     -7],
                        [   -24,     -8],
                        [   -24,     -8],
                        [   -24,     -9],
                        [   -24,    -10],
                        [   -24,    -10],
                        [   -24,    -10],
                        [   -24,    -10],
                        [   -24,    -10],
                        [   -24,    -10],
                        [   -23,     -9],
                        [   -22,     -9],
                        [   -22,     -9],
                        [   -21,     -9],
                        [   -20,     -8],
                        [   -20,     -7],
                        [   -19,     -7],
                        [   -18,     -7],
                        [   -17,     -6],
                        [   -16,     -6],
                        [   -15,     -5],
                        [   -15,     -5],
                        [   -14,     -4],
                        [   -13,     -3],
                        [   -12,     -2],
                        [   -11,     -2],
                        [   -10,     -2],
                        [    -9,     -1],
                        [    -8,      0],
                        [    -8,      0],
                        [    -7,      1],
                        [    -6,      2],
                        [    -5,      2],
                        [    -5,      2],
                        [    -4,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -1,      2],
                        [     0,      3],
                        [     1,      3],
                        [     1,      3],
                        [     2,      3],
                        [     2,      2],
                        [     2,      3],
                        [     3,      2],
                        [     3,      2],
                        [     4,      2],
                        [     4,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     6,      2],
                        [     6,      2],
                        [     6,      2],
                        [     7,      3],
                        [     6,      2],
                        [     6,      2],
                        [     6,      3],
                        [     6,      3],
                        [     5,      3],
                        [     5,      3],
                        [     5,      4],
                        [     4,      4],
                        [     4,      4],
                        [     3,      4],
                        [     3,      5],
                        [     2,      4],
                        [     2,      4],
                        [     2,      4],
                        [     1,      4],
                        [     1,      4],
                        [     0,      3],
                        [     0,      3],
                        [     0,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -2,      1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -3,     -1],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -1],
                        [    -3,     -1],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     2,      0],
                        [     3,      0],
                        [     4,      1],
                        [     4,      1],
                        [     5,      1],
                        [     6,      1],
                        [     6,      2],
                        [     7,      2],
                        [     7,      2],
                        [     8,      3],
                        [     9,      4],
                        [     9,      5],
                        [     9,      5],
                        [    10,      7],
                        [    10,      7],
                        [    11,      9],
                        [    11,     10],
                        [    11,     10],
                        [    11,     11],
                        [    11,     11],
                        [    11,     11],
                        [    12,     12],
                        [    12,     13],
                        [    13,     13],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     13],
                        [    13,     13],
                        [    12,     12],
                        [    11,     12],
                        [    11,     11],
                        [    11,     11],
                        [    10,     11],
                        [    10,     11],
                        [     9,     10],
                        [     8,      9],
                        [     7,      8],
                        [     7,      8],
                        [     7,      7],
                        [     6,      7],
                        [     5,      6],
                        [     5,      6],
                        [     4,      5],
                        [     4,      5],
                        [     3,      4],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     0,      3],
                        [     0,      3],
                        [     0,      3],
                        [     0,      3],
                        [     0,      4],
                        [     0,      4],
                        [    -1,      5],
                        [    -1,      5],
                        [    -1,      6],
                        [    -1,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      8],
                        [     0,      9],
                        [     0,      9],
                        [     0,      9],
                        [     1,      9],
                        [     1,      9],
                        [     1,      8],
                        [     1,      9],
                        [     1,      8],
                        [     2,      8],
                        [     2,      8],
                        [     2,      7],
                        [     2,      7],
                        [     2,      7],
                        [     2,      7],
                        [     2,      6],
                        [     2,      6],
                        [     2,      5],
                        [     2,      5],
                        [     2,      5],
                        [     1,      5],
                        [     1,      5],
                        [     1,      5],
                        [     1,      5],
                        [     1,      5],
                        [     1,      5],
                        [     1,      6],
                        [     0,      6],
                        [     0,      6],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [    -1,      7],
                        [    -1,      6],
                        [    -1,      6],
                        [    -2,      6],
                        [    -2,      5],
                        [    -2,      5],
                        [    -2,      4],
                        [    -2,      4],
                        [    -2,      4],
                        [    -2,      4],
                        [    -2,      4],
                        [    -2,      4],
                        [    -3,      4],
                        [    -3,      4],
                        [    -4,      4],
                        [    -4,      5],
                        [    -5,      5],
                        [    -5,      5],
                        [    -6,      5],
                        [    -7,      5],
                        [    -7,      4],
                        [    -7,      4],
                        [    -7,      4],
                        [    -8,      4],
                        [    -8,      4],
                        [    -8,      3],
                        [    -8,      2],
                        [    -9,      2],
                        [    -9,      2],
                        [   -10,      1],
                        [   -10,      0],
                        [   -10,     -1],
                        [   -10,     -2],
                        [   -11,     -2],
                        [   -11,     -3],
                        [   -11,     -3],
                        [   -11,     -4],
                        [   -11,     -5],
                        [   -11,     -5],
                        [   -12,     -6],
                        [   -12,     -7],
                        [   -13,     -7],
                        [   -13,     -7],
                        [   -13,     -7],
                        [   -13,     -7],
                        [   -14,     -8],
                        [   -13,     -8],
                        [   -13,     -8],
                        [   -13,     -8],
                        [   -13,     -8],
                        [   -13,     -8],
                        [   -12,     -7],
                        [   -12,     -8],
                        [   -12,     -7],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -10,     -7],
                        [    -9,     -6],
                        [    -9,     -6],
                        [    -8,     -5],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -3],
                        [    -6,     -3],
                        [    -5,     -2],
                        [    -4,     -2],
                        [    -3,     -2],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [     0,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     3,      2],
                        [     3,      2],
                        [     4,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      1],
                        [     5,      1],
                        [     6,      1],
                        [     6,      1],
                        [     6,      1],
                        [     6,      1],
                        [     6,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      0],
                        [     6,      0],
                        [     7,      0],
                        [     7,      0],
                        [     6,      0],
                        [     6,      0],
                        [     6,      0],
                        [     6,      0],
                        [     5,      0],
                        [     5,      1],
                        [     5,      1],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     2,     -1],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     1,     -3],
                        [     1,     -3],
                        [     1,     -3],
                        [     0,     -4],
                        [     0,     -4],
                        [     0,     -4],
                        [     0,     -5],
                        [    -1,     -5],
                        [    -1,     -4],
                        [    -1,     -4],
                        [    -1,     -3],
                        [    -1,     -3],
                        [    -2,     -3],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     3,     -1],
                        [     3,     -1],
                        [     4,      0],
                        [     4,      0],
                        [     5,      1],
                        [     5,      1],
                        [     6,      2],
                        [     6,      2],
                        [     7,      2],
                        [     7,      3],
                        [     7,      4],
                        [     8,      4],
                        [     8,      4],
                        [     9,      4],
                        [     9,      5],
                        [    10,      5],
                        [    10,      6],
                        [    10,      6],
                        [    11,      6],
                        [    11,      6],
                        [    11,      6],
                        [    11,      6],
                        [    12,      6],
                        [    12,      6],
                        [    12,      6],
                        [    12,      6],
                        [    13,      6],
                        [    13,      6],
                        [    13,      5],
                        [    13,      5],
                        [    13,      5],
                        [    13,      5],
                        [    13,      5],
                        [    13,      5],
                        [    12,      4],
                        [    12,      4],
                        [    11,      3],
                        [    11,      3],
                        [    11,      3],
                        [    11,      3],
                        [    11,      2],
                        [    11,      2],
                        [    11,      2],
                        [    11,      2],
                        [    10,      2],
                        [    10,      2],
                        [    10,      2],
                        [    10,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      3],
                        [     8,      3],
                        [     8,      3],
                        [     8,      4],
                        [     8,      4],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     7,      5],
                        [     7,      4],
                        [     7,      4],
                        [     7,      4],
                        [     7,      3],
                        [     7,      2],
                        [     7,      2],
                        [     6,      2],
                        [     6,      1],
                        [     5,      1],
                        [     5,      0],
                        [     4,     -1],
                        [     4,     -1],
                        [     3,     -2],
                        [     3,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      0],
                        [     3,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,     -1],
                        [     1,     -2],
                        [     0,     -2],
                        [    -1,     -3],
                        [    -1,     -3],
                        [    -1,     -4],
                        [    -2,     -4],
                        [    -2,     -5],
                        [    -2,     -6],
                        [    -2,     -6],
                        [    -2,     -6],
                        [    -3,     -7],
                        [    -3,     -7],
                        [    -3,     -7],
                        [    -4,     -7],
                        [    -5,     -8],
                        [    -5,     -8],
                        [    -6,     -8],
                        [    -6,     -9],
                        [    -7,     -9],
                        [    -7,     -9],
                        [    -7,     -9],
                        [    -7,    -10],
                        [    -7,    -10],
                        [    -7,     -9],
                        [    -7,    -10],
                        [    -7,    -10],
                        [    -7,     -9],
                        [    -7,     -9],
                        [    -7,     -9],
                        [    -6,     -8],
                        [    -6,     -8],
                        [    -6,     -8],
                        [    -5,     -7],
                        [    -5,     -7],
                        [    -4,     -7],
                        [    -4,     -7],
                        [    -3,     -6],
                        [    -3,     -6],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -2,     -4],
                        [    -1,     -4],
                        [    -1,     -3],
                        [    -1,     -3],
                        [    -1,     -3],
                        [     0,     -3],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -4],
                        [     2,     -4],
                        [     2,     -4],
                        [     2,     -4],
                        [     2,     -4],
                        [     2,     -4],
                        [     1,     -5],
                        [     1,     -5],
                        [     1,     -6],
                        [     0,     -6],
                        [     0,     -6],
                        [     1,     -5],
                        [     0,     -5],
                        [     0,     -5],
                        [     0,     -5],
                        [     0,     -4],
                        [     0,     -4],
                        [     0,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     0,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     0,     -4],
                        [     0,     -5],
                        [     0,     -5],
                        [     0,     -5],
                        [     0,     -6],
                        [     0,     -6],
                        [    -1,     -6],
                        [    -1,     -6],
                        [    -1,     -6],
                        [    -1,     -6],
                        [    -1,     -6],
                        [    -1,     -5],
                        [    -2,     -5],
                        [    -2,     -6],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -3,     -5],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -3,     -3],
                        [    -4,     -4],
                        [    -4,     -4],
                        [    -3,     -3],
                        [    -3,     -4],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -2,     -4],
                        [    -2,     -4],
                        [    -2,     -3],
                        [    -2,     -3],
                        [    -2,     -3],
                        [    -2,     -3],
                        [    -2,     -3],
                        [    -1,     -3],
                        [    -1,     -3],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -3],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     3,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     5,     -2],
                        [     6,     -2],
                        [     6,     -2],
                        [     6,     -1],
                        [     6,     -1],
                        [     7,     -1],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      2],
                        [     7,      1],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     6,      2],
                        [     6,      2],
                        [     6,      2],
                        [     5,      1],
                        [     5,      1],
                        [     5,      1],
                        [     4,      0],
                        [     4,      0],
                        [     3,     -1],
                        [     3,     -1],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     1,     -2],
                        [     0,     -2],
                        [     0,     -3],
                        [    -1,     -3],
                        [    -2,     -4],
                        [    -2,     -4],
                        [    -2,     -4],
                        [    -2,     -4],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -4,     -4],
                        [    -4,     -4],
                        [    -5,     -4],
                        [    -5,     -4],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -5,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -3],
                        [     2,     -2],
                        [     2,     -2],
                        [     1,     -3],
                        [     1,     -3],
                        [     1,     -4],
                        [     1,     -4],
                        [     0,     -4],
                        [     0,     -4],
                        [     0,     -4],
                        [    -1,     -5],
                        [    -1,     -5],
                        [    -1,     -5],
                        [    -1,     -5],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -3,     -6],
                        [    -3,     -6],
                        [    -4,     -6],
                        [    -4,     -6],
                        [    -4,     -6],
                        [    -4,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -6,     -7],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -4,     -5],
                        [    -4,     -5],
                        [    -4,     -5],
                        [    -4,     -4],
                        [    -4,     -4],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -5,     -2],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -6,     -3],
                        [    -6,     -4],
                        [    -6,     -4],
                        [    -6,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -6,     -3],
                        [    -6,     -3],
                        [    -6,     -3],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -4,     -3],
                        [    -4,     -3],
                        [    -4,     -3],
                        [    -4,     -2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -4,      0],
                        [    -4,      0],
                        [    -4,      1],
                        [    -4,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -6,     -1],
                        [    -6,     -1],
                        [    -5,     -1],
                        [    -6,     -1],
                        [    -5,     -1],
                        [    -5,     -1],
                        [    -5,     -1],
                        [    -5,     -1],
                        [    -5,     -2],
                        [    -4,     -1],
                        [    -4,     -1],
                        [    -4,     -1],
                        [    -4,     -1],
                        [    -3,     -1],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     3,      3],
                        [     3,      3],
                        [     3,      3],
                        [     3,      4],
                        [     3,      4],
                        [     4,      4],
                        [     4,      5],
                        [     4,      5],
                        [     4,      5],
                        [     4,      5],
                        [     5,      5],
                        [     5,      5],
                        [     5,      5],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      3],
                        [     5,      3],
                        [     5,      3],
                        [     5,      3],
                        [     5,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     3,      2],
                        [     3,      2],
                        [     3,      2],
                        [     3,      2],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      1],
                        [    -1,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -3,      0],
                        [    -4,      0],
                        [    -4,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -6,      2],
                        [    -6,      2],
                        [    -6,      2],
                        [    -6,      2],
                        [    -5,      2],
                        [    -5,      2],
                        [    -5,      1],
                        [    -4,      1],
                        [    -4,      1],
                        [    -3,      1],
                        [    -2,      1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -2],
                        [     2,     -1],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -3,      1],
                        [    -3,      1],
                        [    -3,      1],
                        [    -4,      1],
                        [    -4,      2],
                        [    -4,      1],
                        [    -4,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -6,      1],
                        [    -6,      1],
                        [    -6,      1],
                        [    -6,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      1],
                        [    -6,      0],
                        [    -6,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -4,      1],
                        [    -4,      1],
                        [    -3,      1],
                        [    -3,      1],
                        [    -2,      2],
                        [    -2,      1],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [     0,      2],
                        [     0,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     1,      3],
                        [     1,      3],
                        [     1,      3],
                        [     1,      3],
                        [     0,      3],
                        [     0,      3],
                        [     0,      3],
                        [     0,      3],
                        [    -1,      3],
                        [    -1,      3],
                        [    -1,      3],
                        [    -1,      3],
                        [    -2,      2],
                        [    -2,      3],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      3],
                        [    -2,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [     0,      2],
                        [     1,      3],
                        [     1,      3],
                        [     1,      3],
                        [     2,      4],
                        [     1,      3],
                        [     2,      4],
                        [     2,      4],
                        [     2,      4],
                        [     2,      5],
                        [     2,      5],
                        [     2,      5],
                        [     2,      5],
                        [     2,      5],
                        [     3,      6],
                        [     3,      6],
                        [     3,      6],
                        [     3,      6],
                        [     3,      6],
                        [     3,      6],
                        [     4,      6],
                        [     4,      6],
                        [     5,      6],
                        [     5,      6],
                        [     5,      6],
                        [     5,      6],
                        [     5,      6],
                        [     5,      5],
                        [     5,      5],
                        [     5,      5],
                        [     5,      5],
                        [     5,      4],
                        [     4,      4],
                        [     4,      4],
                        [     4,      3],
                        [     4,      3],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      1],
                        [     5,      2],
                        [     4,      2],
                        [     4,      1],
                        [     4,      2],
                        [     4,      2],
                        [     4,      1],
                        [     3,      1],
                        [     3,      1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     3,     -1],
                        [     3,     -1],
                        [     3,     -1],
                        [     4,     -1],
                        [     4,     -1],
                        [     4,     -1],
                        [     4,     -1],
                        [     4,     -1],
                        [     5,     -1],
                        [     5,     -1],
                        [     5,      0],
                        [     6,      0],
                        [     6,      0],
                        [     6,      0],
                        [     6,      0],
                        [     5,      1],
                        [     5,      1],
                        [     5,      1],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     3,      2],
                        [     3,      2],
                        [     3,      2],
                        [     3,      2],
                        [     2,      1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -2,      0],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -3,      1],
                        [    -3,      1],
                        [    -3,      1],
                        [    -4,      1],
                        [    -4,      1],
                        [    -4,      1],
                        [    -4,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      0],
                        [    -4,      0],
                        [    -4,      0],
                        [    -4,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      2],
                        [    -1,      1],
                        [    -1,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     0,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     2,     -2],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -3],
                        [    -2,     -3],
                        [    -1,     -3],
                        [    -1,     -3],
                        [    -1,     -3],
                        [     0,     -3],
                        [     0,     -3],
                        [     0,     -3],
                        [     1,     -3],
                        [     1,     -3],
                        [     1,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     5,     -2],
                        [     5,     -2],
                        [     5,     -1],
                        [     5,     -1],
                        [     5,     -1],
                        [     5,     -1],
                        [     4,     -1],
                        [     4,      0],
                        [     4,      0],
                        [     4,      0],
                        [     4,      0],
                        [     4,      0],
                        [     4,      0],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -1],
                        [    -4,     -1],
                        [    -5,     -1],
                        [    -4,     -1],
                        [    -5,     -2],
                        [    -5,     -2],
                        [    -5,     -2],
                        [    -5,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [    -1,     -2],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     0,     -2],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,     -1],
                        [    -3,     -1],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      2],
                        [     1,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -2,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     2,      1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [    -1,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      2],
                        [     1,      2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -2],
                        [     1,     -1],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,     -1],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -2],
                        [     0,     -1],
                        [     0,     -2],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -2,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      2],
                        [     1,      2],
                        [     0,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0]],
                        dtype = numpy.int16)
))

sounds.append(Sound(
    name = "DynamicLoad_BSPNostromo_Ripley.023",
    rate = 41000,
    data = numpy.array([[  1.03759766e-03,   3.87573242e-03],
                        [ -4.45556641e-03,  -2.65502930e-03],
                        [ -1.17797852e-02,  -1.11694336e-02],
                        [ -2.07824707e-02,  -2.13928223e-02],
                        [ -2.81677246e-02,  -2.99072266e-02],
                        [ -3.20129395e-02,  -3.47595215e-02],
                        [ -3.56445312e-02,  -3.91540527e-02],
                        [ -4.17480469e-02,  -4.56848145e-02],
                        [ -4.60510254e-02,  -5.01708984e-02],
                        [ -4.28466797e-02,  -4.67834473e-02],
                        [ -3.34777832e-02,  -3.69262695e-02],
                        [ -2.31933594e-02,  -2.58789062e-02],
                        [ -1.35803223e-02,  -1.52893066e-02],
                        [ -5.67626953e-03,  -6.28662109e-03],
                        [ -3.60107422e-03,  -3.05175781e-03],
                        [ -6.59179688e-03,  -4.97436523e-03],
                        [ -6.50024414e-03,  -3.93676758e-03],
                        [ -9.15527344e-05,   3.20434570e-03],
                        [  5.15747070e-03,   8.91113281e-03],
                        [  2.89916992e-03,   6.77490234e-03],
                        [ -3.50952148e-03,   1.52587891e-04],
                        [ -7.96508789e-03,  -4.82177734e-03],
                        [ -8.94165039e-03,  -6.59179688e-03],
                        [ -7.35473633e-03,  -5.98144531e-03],
                        [ -3.57055664e-03,  -3.32641602e-03],
                        [  3.05175781e-05,  -9.15527344e-04],
                        [  7.32421875e-04,  -1.34277344e-03],
                        [  1.25122070e-03,  -1.80053711e-03],
                        [  7.29370117e-03,   3.47900391e-03],
                        [  1.84936523e-02,   1.41601562e-02],
                        [  2.78015137e-02,   2.32849121e-02],
                        [  3.07922363e-02,   2.64282227e-02],
                        [  2.97546387e-02,   2.58483887e-02],
                        [  2.86254883e-02,   2.54516602e-02],
                        [  2.97241211e-02,   2.75268555e-02],
                        [  3.42102051e-02,   3.30810547e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  5.07812500e-02,   5.19104004e-02],
                        [  6.39648438e-02,   6.60705566e-02],
                        [  8.36791992e-02,   8.65478516e-02],
                        [  1.07177734e-01,   1.10595703e-01],
                        [  1.27197266e-01,   1.30828857e-01],
                        [  1.33666992e-01,   1.37207031e-01],
                        [  1.10443115e-01,   1.13647461e-01],
                        [  4.14733887e-02,   4.40368652e-02],
                        [ -7.10144043e-02,  -6.93359375e-02],
                        [ -1.97753906e-01,  -1.97021484e-01],
                        [ -2.97363281e-01,  -2.97668457e-01],
                        [ -3.40850830e-01,  -3.42132568e-01],
                        [ -3.25317383e-01,  -3.27484131e-01],
                        [ -2.73895264e-01,  -2.76733398e-01],
                        [ -2.20245361e-01,  -2.23541260e-01],
                        [ -1.82617188e-01,  -1.86126709e-01],
                        [ -1.53472900e-01,  -1.56860352e-01],
                        [ -1.15692139e-01,  -1.18743896e-01],
                        [ -6.19812012e-02,  -6.43920898e-02],
                        [ -1.52587891e-04,  -1.83105469e-03],
                        [  5.31005859e-02,   5.23376465e-02],
                        [  8.41369629e-02,   8.43200684e-02],
                        [  9.06982422e-02,   9.17358398e-02],
                        [  8.30993652e-02,   8.49609375e-02],
                        [  7.65380859e-02,   7.90405273e-02],
                        [  7.71789551e-02,   8.00781250e-02],
                        [  7.95593262e-02,   8.26110840e-02],
                        [  7.82775879e-02,   8.12988281e-02],
                        [  7.56225586e-02,   7.83691406e-02],
                        [  7.48901367e-02,   7.71484375e-02],
                        [  7.27233887e-02,   7.43408203e-02],
                        [  6.51245117e-02,   6.60400391e-02],
                        [  5.55114746e-02,   5.56335449e-02],
                        [  4.92248535e-02,   4.86450195e-02],
                        [  4.60510254e-02,   4.48303223e-02],
                        [  4.21752930e-02,   4.04052734e-02],
                        [  3.65295410e-02,   3.44543457e-02],
                        [  3.16772461e-02,   2.94189453e-02],
                        [  2.88085938e-02,   2.65808105e-02],
                        [  2.76489258e-02,   2.56347656e-02],
                        [  2.85339355e-02,   2.68859863e-02],
                        [  3.08227539e-02,   2.96020508e-02],
                        [  3.46069336e-02,   3.39050293e-02],
                        [  4.19006348e-02,   4.17480469e-02],
                        [  5.04150391e-02,   5.07507324e-02],
                        [  5.11779785e-02,   5.19714355e-02],
                        [  3.68957520e-02,   3.80249023e-02],
                        [  1.07116699e-02,   1.20544434e-02],
                        [ -1.40380859e-02,  -1.25732422e-02],
                        [ -2.40478516e-02,  -2.26440430e-02],
                        [ -1.68151855e-02,  -1.55639648e-02],
                        [ -3.38745117e-03,  -2.38037109e-03],
                        [  3.35693359e-04,   1.03759766e-03],
                        [ -1.00708008e-02,  -9.70458984e-03],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.54821777e-02,  -2.57873535e-02],
                        [ -1.63879395e-02,  -1.69982910e-02],
                        [ -4.45556641e-03,  -5.24902344e-03],
                        [  3.14331055e-03,   2.19726562e-03],
                        [  4.08935547e-03,   3.08227539e-03],
                        [  1.25122070e-03,   3.05175781e-04],
                        [  2.92968750e-03,   2.07519531e-03],
                        [  1.31835938e-02,   1.24511719e-02],
                        [  2.47802734e-02,   2.42309570e-02],
                        [  2.92663574e-02,   2.89306641e-02],
                        [  2.80456543e-02,   2.79235840e-02],
                        [  2.86560059e-02,   2.86865234e-02],
                        [  3.38745117e-02,   3.40576172e-02],
                        [  3.91845703e-02,   3.94592285e-02],
                        [  3.96423340e-02,   3.99780273e-02],
                        [  3.42102051e-02,   3.45764160e-02],
                        [  2.55432129e-02,   2.58789062e-02],
                        [  1.82189941e-02,   1.85241699e-02],
                        [  1.48620605e-02,   1.51062012e-02],
                        [  1.38549805e-02,   1.40380859e-02],
                        [  1.14746094e-02,   1.15356445e-02],
                        [  6.43920898e-03,   6.46972656e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.89208984e-03,   1.80053711e-03],
                        [  3.87573242e-03,   3.78417969e-03],
                        [  5.37109375e-03,   5.27954102e-03],
                        [  3.47900391e-03,   3.38745117e-03],
                        [ -1.80053711e-03,  -1.86157227e-03],
                        [ -7.56835938e-03,  -7.59887695e-03],
                        [ -1.26953125e-02,  -1.27563477e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -1.51672363e-02,  -1.51367188e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -3.50646973e-02,  -3.50341797e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -4.23583984e-02,  -4.23278809e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  5.73730469e-03,   5.70678711e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  4.30297852e-03,   4.33349609e-03],
                        [  8.33129883e-03,   8.30078125e-03],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  2.29797363e-02,   2.30102539e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  7.96813965e-02,   7.96813965e-02],
                        [  1.02600098e-01,   1.02600098e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.41296387e-01,   1.41296387e-01],
                        [  1.31072998e-01,   1.31072998e-01],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [ -1.04278564e-01,  -1.04248047e-01],
                        [ -2.21374512e-01,  -2.21374512e-01],
                        [ -3.14880371e-01,  -3.14880371e-01],
                        [ -3.60565186e-01,  -3.60565186e-01],
                        [ -3.54003906e-01,  -3.54003906e-01],
                        [ -3.09997559e-01,  -3.09997559e-01],
                        [ -2.50946045e-01,  -2.50946045e-01],
                        [ -1.96014404e-01,  -1.96014404e-01],
                        [ -1.51123047e-01,  -1.51123047e-01],
                        [ -1.05255127e-01,  -1.05255127e-01],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  8.33129883e-02,   8.33129883e-02],
                        [  1.15570068e-01,   1.15570068e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  1.15692139e-01,   1.15692139e-01],
                        [  1.01959229e-01,   1.01959229e-01],
                        [  8.96301270e-02,   8.96606445e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  6.61926270e-02,   6.61926270e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  7.61718750e-02,   7.61718750e-02],
                        [  8.59985352e-02,   8.59985352e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  5.73730469e-03,   5.70678711e-03],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.42297363e-02,  -5.41992188e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  5.21545410e-02,   5.21545410e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  8.18481445e-02,   8.18481445e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [ -7.06787109e-02,  -7.06787109e-02],
                        [ -1.82159424e-01,  -1.82159424e-01],
                        [ -2.80853271e-01,  -2.80853271e-01],
                        [ -3.31787109e-01,  -3.31787109e-01],
                        [ -3.22570801e-01,  -3.22570801e-01],
                        [ -2.73498535e-01,  -2.73498535e-01],
                        [ -2.19238281e-01,  -2.19238281e-01],
                        [ -1.79962158e-01,  -1.79962158e-01],
                        [ -1.52526855e-01,  -1.52526855e-01],
                        [ -1.22711182e-01,  -1.22711182e-01],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  8.53881836e-02,   8.53881836e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [  7.93457031e-04,   7.93457031e-04],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.19311523e-02,   4.19311523e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  9.42687988e-02,   9.42687988e-02],
                        [  1.24145508e-01,   1.24145508e-01],
                        [  1.43554688e-01,   1.43554688e-01],
                        [  1.40380859e-01,   1.40380859e-01],
                        [  1.08276367e-01,   1.08276367e-01],
                        [  4.71191406e-02,   4.71191406e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -1.49353027e-01,  -1.49353027e-01],
                        [ -2.51647949e-01,  -2.51647949e-01],
                        [ -3.16040039e-01,  -3.16040039e-01],
                        [ -3.26110840e-01,  -3.26110840e-01],
                        [ -2.94403076e-01,  -2.94403076e-01],
                        [ -2.50305176e-01,  -2.50305176e-01],
                        [ -2.15454102e-01,  -2.15454102e-01],
                        [ -1.89514160e-01,  -1.89514160e-01],
                        [ -1.56463623e-01,  -1.56463623e-01],
                        [ -1.03118896e-01,  -1.03118896e-01],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.01379395e-01,   1.01379395e-01],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  1.14715576e-01,   1.14715576e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.21246338e-01,   1.21246338e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  6.45446777e-02,   6.45446777e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  5.24291992e-02,   5.24291992e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  6.83593750e-03,   6.83593750e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  6.71386719e-03,   6.71386719e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  9.68017578e-02,   9.68017578e-02],
                        [  1.14257812e-01,   1.14257812e-01],
                        [  1.25000000e-01,   1.25000000e-01],
                        [  1.22039795e-01,   1.22039795e-01],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -1.70928955e-01,  -1.70928955e-01],
                        [ -2.70568848e-01,  -2.70568848e-01],
                        [ -3.30474854e-01,  -3.30474854e-01],
                        [ -3.33892822e-01,  -3.33892822e-01],
                        [ -2.92236328e-01,  -2.92236328e-01],
                        [ -2.41027832e-01,  -2.41027832e-01],
                        [ -2.07672119e-01,  -2.07672119e-01],
                        [ -1.86157227e-01,  -1.86157227e-01],
                        [ -1.52221680e-01,  -1.52221680e-01],
                        [ -9.53674316e-02,  -9.53674316e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [  9.08203125e-02,   9.08203125e-02],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  5.27038574e-02,   5.27038574e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  1.14013672e-01,   1.14013672e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.19903564e-01,   1.19903564e-01],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -1.69433594e-01,  -1.69433594e-01],
                        [ -2.62359619e-01,  -2.62359619e-01],
                        [ -3.21411133e-01,  -3.21411133e-01],
                        [ -3.32916260e-01,  -3.32916260e-01],
                        [ -3.02001953e-01,  -3.02001953e-01],
                        [ -2.50976562e-01,  -2.50976562e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.75811768e-01,  -1.75811768e-01],
                        [ -1.46911621e-01,  -1.46911621e-01],
                        [ -1.01623535e-01,  -1.01623535e-01],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  1.37573242e-01,   1.37573242e-01],
                        [  1.37603760e-01,   1.37603760e-01],
                        [  1.24847412e-01,   1.24847412e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  8.67614746e-02,   8.67614746e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  3.73840332e-02,   3.73840332e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  4.03137207e-02,   4.03137207e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  7.67822266e-02,   7.67822266e-02],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  4.65698242e-02,   4.65698242e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  3.53393555e-02,   3.53393555e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  3.46679688e-02,   3.46679688e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [  1.70898438e-03,   1.67846680e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  5.30090332e-02,   5.29785156e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  1.26251221e-01,   1.26251221e-01],
                        [  1.28326416e-01,   1.28326416e-01],
                        [  1.11816406e-01,   1.11816406e-01],
                        [  6.55517578e-02,   6.55517578e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -1.31866455e-01,  -1.31866455e-01],
                        [ -2.40905762e-01,  -2.40905762e-01],
                        [ -3.11401367e-01,  -3.11370850e-01],
                        [ -3.24096680e-01,  -3.24096680e-01],
                        [ -2.86224365e-01,  -2.86224365e-01],
                        [ -2.29705811e-01,  -2.29705811e-01],
                        [ -1.90917969e-01,  -1.90917969e-01],
                        [ -1.80236816e-01,  -1.80236816e-01],
                        [ -1.74407959e-01,  -1.74407959e-01],
                        [ -1.45355225e-01,  -1.45324707e-01],
                        [ -9.04846191e-02,  -9.04846191e-02],
                        [ -2.71606445e-02,  -2.71911621e-02],
                        [  3.12194824e-02,   3.11889648e-02],
                        [  7.98950195e-02,   7.99255371e-02],
                        [  1.13372803e-01,   1.13403320e-01],
                        [  1.26190186e-01,   1.26220703e-01],
                        [  1.22100830e-01,   1.22100830e-01],
                        [  1.12548828e-01,   1.12548828e-01],
                        [  1.05865479e-01,   1.05865479e-01],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  8.34655762e-02,   8.34960938e-02],
                        [  7.34558105e-02,   7.34863281e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  6.02416992e-02,   6.02111816e-02],
                        [  4.72717285e-02,   4.72412109e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  6.15234375e-02,   6.14929199e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  1.92260742e-02,   1.92565918e-02],
                        [ -6.34765625e-03,  -6.31713867e-03],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -2.74658203e-02,  -2.74963379e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.22570801e-02,  -3.22875977e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  3.18298340e-02,   3.18603516e-02],
                        [  4.16564941e-02,   4.16870117e-02],
                        [  4.38232422e-02,   4.37927246e-02],
                        [  4.25415039e-02,   4.25109863e-02],
                        [  4.08020020e-02,   4.07714844e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  3.54003906e-02,   3.54309082e-02],
                        [  3.40881348e-02,   3.41186523e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  3.94592285e-02,   3.94287109e-02],
                        [  3.68347168e-02,   3.68041992e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.23999023e-02,   2.24304199e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.48718262e-02,   2.48413086e-02],
                        [  2.50854492e-02,   2.50549316e-02],
                        [  2.37731934e-02,   2.37426758e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  2.24609375e-02,   2.24914551e-02],
                        [  1.91650391e-02,   1.91955566e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  4.45556641e-03,   4.42504883e-03],
                        [ -2.62451172e-03,  -2.65502930e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.76086426e-02,  -1.75781250e-02],
                        [ -2.53906250e-02,  -2.53601074e-02],
                        [ -3.25622559e-02,  -3.25317383e-02],
                        [ -3.79333496e-02,  -3.79638672e-02],
                        [ -4.06494141e-02,  -4.07104492e-02],
                        [ -4.02526855e-02,  -4.02832031e-02],
                        [ -3.59497070e-02,  -3.59191895e-02],
                        [ -2.98156738e-02,  -2.97851562e-02],
                        [ -2.65808105e-02,  -2.65502930e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.38342285e-02,  -2.38647461e-02],
                        [ -1.95922852e-02,  -1.96228027e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -1.66625977e-02,  -1.66320801e-02],
                        [ -1.32751465e-02,  -1.32446289e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -6.59179688e-03,  -6.62231445e-03],
                        [ -7.96508789e-03,  -8.02612305e-03],
                        [ -9.67407227e-03,  -9.70458984e-03],
                        [ -1.18103027e-02,  -1.17797852e-02],
                        [ -1.67541504e-02,  -1.66931152e-02],
                        [ -2.29797363e-02,  -2.29492188e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.55639648e-02,  -1.56250000e-02],
                        [ -7.93457031e-04,  -8.23974609e-04],
                        [  1.37329102e-02,   1.37634277e-02],
                        [  2.34069824e-02,   2.34375000e-02],
                        [  2.52685547e-02,   2.52990723e-02],
                        [  1.85241699e-02,   1.85546875e-02],
                        [  7.84301758e-03,   7.78198242e-03],
                        [  8.23974609e-04,   7.62939453e-04],
                        [ -1.83105469e-04,  -2.13623047e-04],
                        [  2.74658203e-04,   3.35693359e-04],
                        [  5.79833984e-04,   6.40869141e-04],
                        [  4.88281250e-03,   4.91333008e-03],
                        [  1.42822266e-02,   1.42517090e-02],
                        [  2.39562988e-02,   2.38952637e-02],
                        [  3.02734375e-02,   3.02124023e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  4.29687500e-02,   4.30297852e-02],
                        [  5.64880371e-02,   5.65490723e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  9.52148438e-02,   9.51538086e-02],
                        [  1.12884521e-01,   1.12823486e-01],
                        [  1.18499756e-01,   1.18499756e-01],
                        [  1.01684570e-01,   1.01715088e-01],
                        [  5.60607910e-02,   5.61523438e-02],
                        [ -2.04467773e-02,  -2.04162598e-02],
                        [ -1.24298096e-01,  -1.24359131e-01],
                        [ -2.35778809e-01,  -2.35870361e-01],
                        [ -3.17291260e-01,  -3.17352295e-01],
                        [ -3.38500977e-01,  -3.38470459e-01],
                        [ -3.04046631e-01,  -3.03955078e-01],
                        [ -2.47558594e-01,  -2.47497559e-01],
                        [ -1.99829102e-01,  -1.99829102e-01],
                        [ -1.68884277e-01,  -1.68975830e-01],
                        [ -1.45996094e-01,  -1.46057129e-01],
                        [ -1.19415283e-01,  -1.19445801e-01],
                        [ -8.18481445e-02,  -8.17871094e-02],
                        [ -3.32031250e-02,  -3.31115723e-02],
                        [  1.97753906e-02,   1.98059082e-02],
                        [  6.83898926e-02,   6.83593750e-02],
                        [  1.06201172e-01,   1.06140137e-01],
                        [  1.29089355e-01,   1.29058838e-01],
                        [  1.36169434e-01,   1.36169434e-01],
                        [  1.31866455e-01,   1.31958008e-01],
                        [  1.23992920e-01,   1.24084473e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  1.03302002e-01,   1.03210449e-01],
                        [  8.41064453e-02,   8.40454102e-02],
                        [  6.39343262e-02,   6.39038086e-02],
                        [  5.05981445e-02,   5.06896973e-02],
                        [  4.68444824e-02,   4.69360352e-02],
                        [  5.05371094e-02,   5.05676270e-02],
                        [  5.79528809e-02,   5.78918457e-02],
                        [  6.41479492e-02,   6.40258789e-02],
                        [  6.38122559e-02,   6.37512207e-02],
                        [  5.53894043e-02,   5.54199219e-02],
                        [  4.22668457e-02,   4.23889160e-02],
                        [  2.81372070e-02,   2.81982422e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -2.50244141e-03,  -2.59399414e-03],
                        [ -1.66625977e-02,  -1.67541504e-02],
                        [ -2.37121582e-02,  -2.37426758e-02],
                        [ -2.16064453e-02,  -2.15148926e-02],
                        [ -1.53198242e-02,  -1.51977539e-02],
                        [ -1.15356445e-02,  -1.15051270e-02],
                        [ -1.18713379e-02,  -1.19323730e-02],
                        [ -1.35192871e-02,  -1.36413574e-02],
                        [ -1.40991211e-02,  -1.41601562e-02],
                        [ -1.33972168e-02,  -1.33666992e-02],
                        [ -1.11694336e-02,  -1.10778809e-02],
                        [ -5.95092773e-03,  -5.88989258e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  1.18713379e-02,   1.17797852e-02],
                        [  1.90124512e-02,   1.89208984e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  2.88085938e-02,   2.89001465e-02],
                        [  3.24096680e-02,   3.25012207e-02],
                        [  3.55224609e-02,   3.55529785e-02],
                        [  4.02526855e-02,   4.01916504e-02],
                        [  4.54711914e-02,   4.53491211e-02],
                        [  4.68139648e-02,   4.67529297e-02],
                        [  4.32434082e-02,   4.33044434e-02],
                        [  3.78112793e-02,   3.79333496e-02],
                        [  3.27148438e-02,   3.27758789e-02],
                        [  2.78625488e-02,   2.78320312e-02],
                        [  2.47192383e-02,   2.45971680e-02],
                        [  2.61535645e-02,   2.60620117e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  3.17993164e-02,   3.18908691e-02],
                        [  2.84118652e-02,   2.85339355e-02],
                        [  2.30712891e-02,   2.31018066e-02],
                        [  1.84936523e-02,   1.84020996e-02],
                        [  1.66320801e-02,   1.65100098e-02],
                        [  1.83105469e-02,   1.82495117e-02],
                        [  2.05993652e-02,   2.06604004e-02],
                        [  1.87072754e-02,   1.88293457e-02],
                        [  1.14746094e-02,   1.15661621e-02],
                        [  2.47192383e-03,   2.41088867e-03],
                        [ -5.40161133e-03,  -5.55419922e-03],
                        [ -1.26953125e-02,  -1.28173828e-02],
                        [ -1.98364258e-02,  -1.98059082e-02],
                        [ -2.50854492e-02,  -2.49328613e-02],
                        [ -2.75268555e-02,  -2.74047852e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -3.15551758e-02,  -3.16467285e-02],
                        [ -3.45764160e-02,  -3.47290039e-02],
                        [ -3.48510742e-02,  -3.49121094e-02],
                        [ -3.06091309e-02,  -3.05175781e-02],
                        [ -2.38647461e-02,  -2.37121582e-02],
                        [ -1.83410645e-02,  -1.82495117e-02],
                        [ -1.62048340e-02,  -1.62658691e-02],
                        [ -1.70288086e-02,  -1.71508789e-02],
                        [ -1.82800293e-02,  -1.84020996e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.58386230e-02,  -1.56860352e-02],
                        [ -1.44653320e-02,  -1.43127441e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.22680664e-02,  -1.24206543e-02],
                        [ -1.28479004e-02,  -1.30004883e-02],
                        [ -1.36108398e-02,  -1.36718750e-02],
                        [ -1.06811523e-02,  -1.05895996e-02],
                        [ -4.60815430e-03,  -4.42504883e-03],
                        [  4.57763672e-04,   5.49316406e-04],
                        [  3.50952148e-03,   3.41796875e-03],
                        [  5.88989258e-03,   5.73730469e-03],
                        [  7.44628906e-03,   7.32421875e-03],
                        [  7.81250000e-03,   7.87353516e-03],
                        [  8.63647461e-03,   8.78906250e-03],
                        [  1.06811523e-02,   1.08337402e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.19934082e-02,   1.18713379e-02],
                        [  9.94873047e-03,   9.79614258e-03],
                        [  6.56127930e-03,   6.50024414e-03],
                        [  4.15039062e-03,   4.27246094e-03],
                        [  7.53784180e-03,   7.72094727e-03],
                        [  1.87072754e-02,   1.87683105e-02],
                        [  3.37524414e-02,   3.36608887e-02],
                        [  4.78820801e-02,   4.76989746e-02],
                        [  6.21337891e-02,   6.20117188e-02],
                        [  8.18786621e-02,   8.19091797e-02],
                        [  1.06964111e-01,   1.07147217e-01],
                        [  1.28295898e-01,   1.28448486e-01],
                        [  1.34826660e-01,   1.34826660e-01],
                        [  1.19140625e-01,   1.18988037e-01],
                        [  7.42492676e-02,   7.40966797e-02],
                        [ -6.01196289e-03,  -6.07299805e-03],
                        [ -1.16760254e-01,  -1.16638184e-01],
                        [ -2.32940674e-01,  -2.32757568e-01],
                        [ -3.16528320e-01,  -3.16436768e-01],
                        [ -3.38958740e-01,  -3.39080811e-01],
                        [ -3.03222656e-01,  -3.03436279e-01],
                        [ -2.43041992e-01,  -2.43133545e-01],
                        [ -1.95770264e-01,  -1.95709229e-01],
                        [ -1.74133301e-01,  -1.73919678e-01],
                        [ -1.62689209e-01,  -1.62506104e-01],
                        [ -1.39434814e-01,  -1.39465332e-01],
                        [ -9.78698730e-02,  -9.80529785e-02],
                        [ -4.64782715e-02,  -4.66613770e-02],
                        [  6.50024414e-03,   6.46972656e-03],
                        [  5.80749512e-02,   5.82275391e-02],
                        [  1.03240967e-01,   1.03454590e-01],
                        [  1.33880615e-01,   1.33941650e-01],
                        [  1.45965576e-01,   1.45874023e-01],
                        [  1.43249512e-01,   1.43035889e-01],
                        [  1.32812500e-01,   1.32690430e-01],
                        [  1.20391846e-01,   1.20483398e-01],
                        [  1.08154297e-01,   1.08367920e-01],
                        [  9.44824219e-02,   9.46350098e-02],
                        [  7.83081055e-02,   7.82775879e-02],
                        [  6.39038086e-02,   6.36901855e-02],
                        [  5.69458008e-02,   5.67321777e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  6.24694824e-02,   6.26525879e-02],
                        [  6.24389648e-02,   6.26525879e-02],
                        [  5.27648926e-02,   5.28259277e-02],
                        [  3.54003906e-02,   3.52478027e-02],
                        [  1.52587891e-02,   1.50146484e-02],
                        [ -6.07299805e-03,  -6.19506836e-03],
                        [ -2.59399414e-02,  -2.58178711e-02],
                        [ -3.64685059e-02,  -3.62548828e-02],
                        [ -3.22265625e-02,  -3.20434570e-02],
                        [ -1.80358887e-02,  -1.80664062e-02],
                        [ -4.39453125e-03,  -4.63867188e-03],
                        [  2.10571289e-03,   1.89208984e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -4.02832031e-03,  -3.81469727e-03],
                        [ -1.10778809e-02,  -1.08337402e-02],
                        [ -1.68151855e-02,  -1.67541504e-02],
                        [ -1.71813965e-02,  -1.73339844e-02],
                        [ -9.70458984e-03,  -9.97924805e-03],
                        [  3.20434570e-03,   3.08227539e-03],
                        [  1.66931152e-02,   1.68151855e-02],
                        [  2.68859863e-02,   2.71301270e-02],
                        [  3.15246582e-02,   3.16772461e-02],
                        [  3.04565430e-02,   3.03955078e-02],
                        [  2.75878906e-02,   2.73742676e-02],
                        [  2.82287598e-02,   2.80456543e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  3.46679688e-02,   3.48815918e-02],
                        [  3.15551758e-02,   3.17993164e-02],
                        [  2.75268555e-02,   2.75573730e-02],
                        [  2.71911621e-02,   2.70080566e-02],
                        [  2.97851562e-02,   2.95104980e-02],
                        [  3.12805176e-02,   3.11889648e-02],
                        [  2.93273926e-02,   2.94799805e-02],
                        [  2.57568359e-02,   2.60314941e-02],
                        [  2.44445801e-02,   2.46276855e-02],
                        [  2.67333984e-02,   2.66418457e-02],
                        [  2.94494629e-02,   2.91748047e-02],
                        [  2.79846191e-02,   2.77709961e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  1.53198242e-02,   1.55639648e-02],
                        [  1.19628906e-02,   1.22070312e-02],
                        [  8.48388672e-03,   8.54492188e-03],
                        [  2.62451172e-03,   2.41088867e-03],
                        [ -2.41088867e-03,  -2.68554688e-03],
                        [ -4.18090820e-03,  -4.30297852e-03],
                        [ -6.22558594e-03,  -6.07299805e-03],
                        [ -1.22985840e-02,  -1.19934082e-02],
                        [ -2.08435059e-02,  -2.06909180e-02],
                        [ -2.83813477e-02,  -2.84729004e-02],
                        [ -3.35388184e-02,  -3.38134766e-02],
                        [ -3.58581543e-02,  -3.60717773e-02],
                        [ -3.45153809e-02,  -3.44543457e-02],
                        [ -3.03649902e-02,  -3.00903320e-02],
                        [ -2.59399414e-02,  -2.56958008e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -2.13317871e-02,  -2.15454102e-02],
                        [ -2.13928223e-02,  -2.16674805e-02],
                        [ -2.31628418e-02,  -2.32543945e-02],
                        [ -2.54821777e-02,  -2.52990723e-02],
                        [ -2.64892578e-02,  -2.61840820e-02],
                        [ -2.59704590e-02,  -2.58178711e-02],
                        [ -2.55126953e-02,  -2.56652832e-02],
                        [ -2.57263184e-02,  -2.60314941e-02],
                        [ -2.48718262e-02,  -2.50854492e-02],
                        [ -2.21862793e-02,  -2.21252441e-02],
                        [ -1.88293457e-02,  -1.85546875e-02],
                        [ -1.47094727e-02,  -1.44653320e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.03759766e-03,  -1.28173828e-03],
                        [  4.33349609e-03,   4.05883789e-03],
                        [  4.15039062e-03,   4.08935547e-03],
                        [ -1.37329102e-03,  -1.19018555e-03],
                        [ -6.50024414e-03,  -6.19506836e-03],
                        [ -5.88989258e-03,  -5.73730469e-03],
                        [ -1.77001953e-03,  -1.92260742e-03],
                        [  0.00000000e+00,  -3.35693359e-04],
                        [  9.15527344e-05,  -1.22070312e-04],
                        [  3.50952148e-03,   3.60107422e-03],
                        [  8.81958008e-03,   9.12475586e-03],
                        [  9.85717773e-03,   1.01013184e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  9.42993164e-03,   9.15527344e-03],
                        [  1.59301758e-02,   1.56250000e-02],
                        [  2.23693848e-02,   2.23083496e-02],
                        [  2.74047852e-02,   2.76489258e-02],
                        [  3.48205566e-02,   3.51562500e-02],
                        [  4.98352051e-02,   4.99572754e-02],
                        [  7.61413574e-02,   7.59887695e-02],
                        [  1.10168457e-01,   1.09832764e-01],
                        [  1.38122559e-01,   1.37908936e-01],
                        [  1.44531250e-01,   1.44622803e-01],
                        [  1.21307373e-01,   1.21643066e-01],
                        [  6.50939941e-02,   6.53686523e-02],
                        [ -2.51464844e-02,  -2.52075195e-02],
                        [ -1.39465332e-01,  -1.39770508e-01],
                        [ -2.49847412e-01,  -2.50152588e-01],
                        [ -3.20678711e-01,  -3.20739746e-01],
                        [ -3.31817627e-01,  -3.31542969e-01],
                        [ -2.92510986e-01,  -2.92175293e-01],
                        [ -2.34436035e-01,  -2.34313965e-01],
                        [ -1.90216064e-01,  -1.90399170e-01],
                        [ -1.71051025e-01,  -1.71386719e-01],
                        [ -1.60583496e-01,  -1.60797119e-01],
                        [ -1.36505127e-01,  -1.36383057e-01],
                        [ -9.49707031e-02,  -9.46044922e-02],
                        [ -4.61730957e-02,  -4.58984375e-02],
                        [  4.24194336e-03,   4.18090820e-03],
                        [  5.52978516e-02,   5.49926758e-02],
                        [  9.93957520e-02,   9.90905762e-02],
                        [  1.25244141e-01,   1.25213623e-01],
                        [  1.31195068e-01,   1.31469727e-01],
                        [  1.25762939e-01,   1.26129150e-01],
                        [  1.18286133e-01,   1.18377686e-01],
                        [  1.13159180e-01,   1.12945557e-01],
                        [  1.07299805e-01,   1.06933594e-01],
                        [  9.44824219e-02,   9.42993164e-02],
                        [  7.86743164e-02,   7.87963867e-02],
                        [  7.29370117e-02,   7.33032227e-02],
                        [  7.97729492e-02,   8.00170898e-02],
                        [  8.58154297e-02,   8.57238770e-02],
                        [  7.93457031e-02,   7.89794922e-02],
                        [  6.12182617e-02,   6.09130859e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  1.14135742e-02,   1.17187500e-02],
                        [ -1.30615234e-02,  -1.26953125e-02],
                        [ -2.99377441e-02,  -2.98461914e-02],
                        [ -3.45458984e-02,  -3.47900391e-02],
                        [ -2.78625488e-02,  -2.82592773e-02],
                        [ -1.69982910e-02,  -1.71508789e-02],
                        [ -1.02539062e-02,  -1.00708008e-02],
                        [ -9.88769531e-03,  -9.52148438e-03],
                        [ -9.88769531e-03,  -9.64355469e-03],
                        [ -3.72314453e-03,  -3.81469727e-03],
                        [  5.82885742e-03,   5.46264648e-03],
                        [  8.27026367e-03,   7.93457031e-03],
                        [  1.22070312e-04,   1.52587891e-04],
                        [ -7.47680664e-03,  -7.14111328e-03],
                        [ -3.38745117e-03,  -3.05175781e-03],
                        [  8.54492188e-03,   8.60595703e-03],
                        [  1.73950195e-02,   1.71203613e-02],
                        [  2.05993652e-02,   2.02026367e-02],
                        [  2.29492188e-02,   2.27661133e-02],
                        [  2.65808105e-02,   2.67944336e-02],
                        [  3.01208496e-02,   3.05175781e-02],
                        [  3.20434570e-02,   3.22875977e-02],
                        [  3.09143066e-02,   3.07922363e-02],
                        [  2.71301270e-02,   2.67333984e-02],
                        [  2.38647461e-02,   2.35595703e-02],
                        [  2.39257812e-02,   2.39562988e-02],
                        [  2.80151367e-02,   2.83813477e-02],
                        [  3.56750488e-02,   3.60412598e-02],
                        [  4.37622070e-02,   4.38232422e-02],
                        [  4.75158691e-02,   4.72106934e-02],
                        [  4.55932617e-02,   4.51965332e-02],
                        [  4.04968262e-02,   4.03442383e-02],
                        [  3.39660645e-02,   3.41796875e-02],
                        [  2.47802734e-02,   2.51770020e-02],
                        [  1.33972168e-02,   1.36413574e-02],
                        [  4.88281250e-03,   4.73022461e-03],
                        [  2.59399414e-03,   2.16674805e-03],
                        [  2.47192383e-03,   2.13623047e-03],
                        [ -3.66210938e-04,  -2.74658203e-04],
                        [ -4.05883789e-03,  -3.69262695e-03],
                        [ -5.46264648e-03,  -5.09643555e-03],
                        [ -6.31713867e-03,  -6.25610352e-03],
                        [ -8.45336914e-03,  -8.78906250e-03],
                        [ -1.06811523e-02,  -1.11083984e-02],
                        [ -1.40380859e-02,  -1.41906738e-02],
                        [ -2.14233398e-02,  -2.11486816e-02],
                        [ -2.96630859e-02,  -2.92358398e-02],
                        [ -3.22875977e-02,  -3.20739746e-02],
                        [ -2.92053223e-02,  -2.93579102e-02],
                        [ -2.46276855e-02,  -2.50549316e-02],
                        [ -2.06298828e-02,  -2.09350586e-02],
                        [ -2.01416016e-02,  -2.00500488e-02],
                        [ -2.73437500e-02,  -2.69165039e-02],
                        [ -3.83605957e-02,  -3.79943848e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.05578613e-02,  -4.08935547e-02],
                        [ -3.39355469e-02,  -3.43322754e-02],
                        [ -2.56042480e-02,  -2.57263184e-02],
                        [ -1.66015625e-02,  -1.63269043e-02],
                        [ -1.00402832e-02,  -9.58251953e-03],
                        [ -6.22558594e-03,  -6.01196289e-03],
                        [ -1.86157227e-03,  -2.07519531e-03],
                        [  2.53295898e-03,   2.07519531e-03],
                        [  2.41088867e-03,   2.13623047e-03],
                        [ -2.01416016e-03,  -1.89208984e-03],
                        [ -5.24902344e-03,  -4.82177734e-03],
                        [ -6.04248047e-03,  -5.67626953e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -1.17797852e-02,  -1.21765137e-02],
                        [ -1.55029297e-02,  -1.59301758e-02],
                        [ -1.65405273e-02,  -1.66320801e-02],
                        [ -1.27563477e-02,  -1.24206543e-02],
                        [ -4.94384766e-03,  -4.51660156e-03],
                        [  2.28881836e-03,   2.47192383e-03],
                        [  7.44628906e-03,   7.20214844e-03],
                        [  1.43127441e-02,   1.38549805e-02],
                        [  2.29492188e-02,   2.26440430e-02],
                        [  2.65808105e-02,   2.67333984e-02],
                        [  2.25830078e-02,   2.30407715e-02],
                        [  1.67541504e-02,   1.70898438e-02],
                        [  1.51977539e-02,   1.51367188e-02],
                        [  2.04162598e-02,   2.00195312e-02],
                        [  3.53393555e-02,   3.49121094e-02],
                        [  6.15234375e-02,   6.14318848e-02],
                        [  9.42382812e-02,   9.46044922e-02],
                        [  1.23138428e-01,   1.23596191e-01],
                        [  1.37725830e-01,   1.37908936e-01],
                        [  1.31622314e-01,   1.31347656e-01],
                        [  1.00891113e-01,   1.00433350e-01],
                        [  4.11682129e-02,   4.08935547e-02],
                        [ -4.93774414e-02,  -4.92248535e-02],
                        [ -1.60095215e-01,  -1.59637451e-01],
                        [ -2.62847900e-01,  -2.62481689e-01],
                        [ -3.23760986e-01,  -3.23852539e-01],
                        [ -3.25988770e-01,  -3.26446533e-01],
                        [ -2.82440186e-01,  -2.82867432e-01],
                        [ -2.27172852e-01,  -2.27203369e-01],
                        [ -1.89941406e-01,  -1.89575195e-01],
                        [ -1.74804688e-01,  -1.74346924e-01],
                        [ -1.64733887e-01,  -1.64581299e-01],
                        [ -1.42913818e-01,  -1.43218994e-01],
                        [ -1.04522705e-01,  -1.05010986e-01],
                        [ -5.40466309e-02,  -5.43212891e-02],
                        [  1.64794922e-03,   1.83105469e-03],
                        [  5.78613281e-02,   5.83496094e-02],
                        [  1.08703613e-01,   1.09039307e-01],
                        [  1.42700195e-01,   1.42608643e-01],
                        [  1.52038574e-01,   1.51580811e-01],
                        [  1.44348145e-01,   1.43951416e-01],
                        [  1.34674072e-01,   1.34643555e-01],
                        [  1.26373291e-01,   1.26800537e-01],
                        [  1.13037109e-01,   1.13494873e-01],
                        [  9.55200195e-02,   9.56115723e-02],
                        [  8.27636719e-02,   8.24279785e-02],
                        [  7.90100098e-02,   7.85217285e-02],
                        [  8.07800293e-02,   8.05358887e-02],
                        [  8.14514160e-02,   8.16650391e-02],
                        [  7.27539062e-02,   7.32421875e-02],
                        [  4.90112305e-02,   4.93469238e-02],
                        [  1.35498047e-02,   1.33972168e-02],
                        [ -2.23388672e-02,  -2.28271484e-02],
                        [ -4.56542969e-02,  -4.60510254e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -3.07617188e-02,  -3.03344727e-02],
                        [ -7.47680664e-03,  -6.98852539e-03],
                        [  6.77490234e-03,   6.86645508e-03],
                        [  9.09423828e-03,   8.72802734e-03],
                        [  8.17871094e-03,   7.65991211e-03],
                        [  9.36889648e-03,   9.18579102e-03],
                        [  8.81958008e-03,   9.09423828e-03],
                        [  3.72314453e-03,   4.24194336e-03],
                        [ -1.80053711e-03,  -1.46484375e-03],
                        [ -2.50244141e-03,  -2.65502930e-03],
                        [  3.47900391e-03,   2.96020508e-03],
                        [  1.43432617e-02,   1.39465332e-02],
                        [  2.41699219e-02,   2.42309570e-02],
                        [  2.73437500e-02,   2.77709961e-02],
                        [  2.46887207e-02,   2.51464844e-02],
                        [  2.16979980e-02,   2.17895508e-02],
                        [  2.11791992e-02,   2.07824707e-02],
                        [  2.16369629e-02,   2.11181641e-02],
                        [  2.13928223e-02,   2.12097168e-02],
                        [  2.17895508e-02,   2.20642090e-02],
                        [  2.57873535e-02,   2.63061523e-02],
                        [  3.42712402e-02,   3.45764160e-02],
                        [  4.37011719e-02,   4.35180664e-02],
                        [  4.86755371e-02,   4.81567383e-02],
                        [  4.67834473e-02,   4.63867188e-02],
                        [  4.04968262e-02,   4.05883789e-02],
                        [  3.48205566e-02,   3.53088379e-02],
                        [  3.30200195e-02,   3.34777832e-02],
                        [  3.40576172e-02,   3.41186523e-02],
                        [  3.36914062e-02,   3.32946777e-02],
                        [  2.88085938e-02,   2.82897949e-02],
                        [  2.04467773e-02,   2.02941895e-02],
                        [  1.25122070e-02,   1.28173828e-02],
                        [  8.17871094e-03,   8.72802734e-03],
                        [  7.72094727e-03,   7.99560547e-03],
                        [  7.78198242e-03,   7.56835938e-03],
                        [  3.84521484e-03,   3.32641602e-03],
                        [ -4.94384766e-03,  -5.34057617e-03],
                        [ -1.49230957e-02,  -1.48315430e-02],
                        [ -2.33154297e-02,  -2.28271484e-02],
                        [ -3.00598145e-02,  -2.96020508e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.32336426e-02,  -3.36914062e-02],
                        [ -3.03039551e-02,  -3.08227539e-02],
                        [ -2.80151367e-02,  -2.81677246e-02],
                        [ -2.73742676e-02,  -2.70385742e-02],
                        [ -2.82897949e-02,  -2.77404785e-02],
                        [ -2.96630859e-02,  -2.93884277e-02],
                        [ -2.95715332e-02,  -2.98156738e-02],
                        [ -2.83508301e-02,  -2.89001465e-02],
                        [ -2.87475586e-02,  -2.90832520e-02],
                        [ -3.03955078e-02,  -3.02734375e-02],
                        [ -2.86865234e-02,  -2.81677246e-02],
                        [ -2.20031738e-02,  -2.15454102e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -1.23291016e-02,  -1.27868652e-02],
                        [ -1.33972168e-02,  -1.39160156e-02],
                        [ -1.66015625e-02,  -1.67236328e-02],
                        [ -1.85241699e-02,  -1.81579590e-02],
                        [ -1.58691406e-02,  -1.53503418e-02],
                        [ -1.03759766e-02,  -1.01318359e-02],
                        [ -6.37817383e-03,  -6.65283203e-03],
                        [ -4.82177734e-03,  -5.40161133e-03],
                        [ -4.85229492e-03,  -5.21850586e-03],
                        [ -7.23266602e-03,  -7.04956055e-03],
                        [ -1.08642578e-02,  -1.03454590e-02],
                        [ -1.11083984e-02,  -1.06811523e-02],
                        [ -6.83593750e-03,  -6.86645508e-03],
                        [ -2.68554688e-03,  -3.17382812e-03],
                        [ -1.25122070e-03,  -1.77001953e-03],
                        [ -9.15527344e-05,  -1.83105469e-04],
                        [  2.22778320e-03,   2.65502930e-03],
                        [  4.85229492e-03,   5.40161133e-03],
                        [  6.50024414e-03,   6.71386719e-03],
                        [  6.07299805e-03,   5.76782227e-03],
                        [  4.27246094e-03,   3.72314453e-03],
                        [  5.76782227e-03,   5.43212891e-03],
                        [  1.56860352e-02,   1.58691406e-02],
                        [  3.42712402e-02,   3.48510742e-02],
                        [  5.72814941e-02,   5.76782227e-02],
                        [  8.02001953e-02,   8.01086426e-02],
                        [  1.00402832e-01,   9.98840332e-02],
                        [  1.16027832e-01,   1.15539551e-01],
                        [  1.24938965e-01,   1.24877930e-01],
                        [  1.21887207e-01,   1.22344971e-01],
                        [  9.61303711e-02,   9.66796875e-02],
                        [  3.73229980e-02,   3.75061035e-02],
                        [ -5.32226562e-02,  -5.35583496e-02],
                        [ -1.59240723e-01,  -1.59820557e-01],
                        [ -2.55249023e-01,  -2.55554199e-01],
                        [ -3.14117432e-01,  -3.13873291e-01],
                        [ -3.19061279e-01,  -3.18511963e-01],
                        [ -2.79144287e-01,  -2.78747559e-01],
                        [ -2.27081299e-01,  -2.27172852e-01],
                        [ -1.90795898e-01,  -1.91345215e-01],
                        [ -1.71325684e-01,  -1.71813965e-01],
                        [ -1.53442383e-01,  -1.53442383e-01],
                        [ -1.27868652e-01,  -1.27380371e-01],
                        [ -9.52453613e-02,  -9.47265625e-02],
                        [ -5.71594238e-02,  -5.70068359e-02],
                        [ -1.17187500e-02,  -1.20849609e-02],
                        [  4.15954590e-02,   4.09851074e-02],
                        [  9.54589844e-02,   9.51538086e-02],
                        [  1.36566162e-01,   1.36871338e-01],
                        [  1.56341553e-01,   1.56921387e-01],
                        [  1.57684326e-01,   1.58050537e-01],
                        [  1.49871826e-01,   1.49749756e-01],
                        [  1.39923096e-01,   1.39373779e-01],
                        [  1.29943848e-01,   1.29455566e-01],
                        [  1.19140625e-01,   1.19171143e-01],
                        [  1.07025146e-01,   1.07513428e-01],
                        [  9.53369141e-02,   9.58862305e-02],
                        [  8.51745605e-02,   8.52966309e-02],
                        [  7.28454590e-02,   7.24487305e-02],
                        [  5.31005859e-02,   5.25207520e-02],
                        [  2.45971680e-02,   2.43225098e-02],
                        [ -9.46044922e-03,  -9.15527344e-03],
                        [ -4.15649414e-02,  -4.09851074e-02],
                        [ -6.17675781e-02,  -6.14013672e-02],
                        [ -6.38732910e-02,  -6.40563965e-02],
                        [ -4.94079590e-02,  -4.99572754e-02],
                        [ -2.50854492e-02,  -2.55737305e-02],
                        [ -1.67846680e-03,  -1.64794922e-03],
                        [  1.05895996e-02,   1.11083984e-02],
                        [  1.09863281e-02,   1.15051270e-02],
                        [  7.44628906e-03,   7.50732422e-03],
                        [  5.27954102e-03,   4.85229492e-03],
                        [  3.93676758e-03,   3.35693359e-03],
                        [  3.84521484e-03,   3.63159180e-03],
                        [  8.54492188e-03,   8.88061523e-03],
                        [  1.90734863e-02,   1.96838379e-02],
                        [  3.22265625e-02,   3.25622559e-02],
                        [  4.31518555e-02,   4.29382324e-02],
                        [  4.66613770e-02,   4.60815430e-02],
                        [  4.04357910e-02,   3.99780273e-02],
                        [  2.95410156e-02,   2.96020508e-02],
                        [  2.20336914e-02,   2.25830078e-02],
                        [  1.98669434e-02,   2.03857422e-02],
                        [  1.98669434e-02,   1.99279785e-02],
                        [  2.03857422e-02,   1.99279785e-02],
                        [  2.13012695e-02,   2.07214355e-02],
                        [  2.21557617e-02,   2.19726562e-02],
                        [  2.39868164e-02,   2.43225098e-02],
                        [  2.87475586e-02,   2.93579102e-02],
                        [  3.56140137e-02,   3.59497070e-02],
                        [  4.13513184e-02,   4.11071777e-02],
                        [  4.40368652e-02,   4.34570312e-02],
                        [  4.27551270e-02,   4.23278809e-02],
                        [  3.72314453e-02,   3.73535156e-02],
                        [  3.09448242e-02,   3.14941406e-02],
                        [  2.89001465e-02,   2.94189453e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  3.20739746e-02,   3.15856934e-02],
                        [  2.91748047e-02,   2.86254883e-02],
                        [  2.48107910e-02,   2.46582031e-02],
                        [  2.03247070e-02,   2.07214355e-02],
                        [  1.20239258e-02,   1.26342773e-02],
                        [ -2.71606445e-03,  -2.44140625e-03],
                        [ -1.93176270e-02,  -1.95922852e-02],
                        [ -3.07922363e-02,  -3.14025879e-02],
                        [ -3.46069336e-02,  -3.50036621e-02],
                        [ -3.30200195e-02,  -3.28674316e-02],
                        [ -2.95104980e-02,  -2.89306641e-02],
                        [ -2.57873535e-02,  -2.52990723e-02],
                        [ -2.16979980e-02,  -2.17285156e-02],
                        [ -1.76086426e-02,  -1.80969238e-02],
                        [ -1.49536133e-02,  -1.55029297e-02],
                        [ -1.53503418e-02,  -1.54724121e-02],
                        [ -1.92565918e-02,  -1.88598633e-02],
                        [ -2.49633789e-02,  -2.43530273e-02],
                        [ -2.85339355e-02,  -2.82592773e-02],
                        [ -2.61840820e-02,  -2.65197754e-02],
                        [ -1.86462402e-02,  -1.92565918e-02],
                        [ -1.19323730e-02,  -1.22680664e-02],
                        [ -1.11694336e-02,  -1.09863281e-02],
                        [ -1.52893066e-02,  -1.47399902e-02],
                        [ -1.97753906e-02,  -1.92871094e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -1.62048340e-02,  -1.67541504e-02],
                        [ -9.03320312e-03,  -9.58251953e-03],
                        [ -4.24194336e-03,  -4.30297852e-03],
                        [ -1.77001953e-03,  -1.34277344e-03],
                        [  2.59399414e-03,   3.17382812e-03],
                        [  7.17163086e-03,   7.41577148e-03],
                        [  5.15747070e-03,   4.82177734e-03],
                        [ -3.23486328e-03,  -3.87573242e-03],
                        [ -1.11389160e-02,  -1.15051270e-02],
                        [ -1.55029297e-02,  -1.52587891e-02],
                        [ -1.63879395e-02,  -1.57775879e-02],
                        [ -1.22985840e-02,  -1.18713379e-02],
                        [ -5.31005859e-03,  -5.37109375e-03],
                        [  3.35693359e-04,  -2.13623047e-04],
                        [  5.92041016e-03,   5.37109375e-03],
                        [  1.34277344e-02,   1.33972168e-02],
                        [  1.77917480e-02,   1.83105469e-02],
                        [  1.65405273e-02,   1.71203613e-02],
                        [  1.69677734e-02,   1.71508789e-02],
                        [  2.45056152e-02,   2.41394043e-02],
                        [  3.50036621e-02,   3.43933105e-02],
                        [  4.54711914e-02,   4.51354980e-02],
                        [  6.02722168e-02,   6.05163574e-02],
                        [  8.26721191e-02,   8.32824707e-02],
                        [  1.08306885e-01,   1.08703613e-01],
                        [  1.28173828e-01,   1.28051758e-01],
                        [  1.30645752e-01,   1.30096436e-01],
                        [  1.03210449e-01,   1.02691650e-01],
                        [  3.98254395e-02,   3.97949219e-02],
                        [ -5.37109375e-02,  -5.32226562e-02],
                        [ -1.61254883e-01,  -1.60644531e-01],
                        [ -2.58666992e-01,  -2.58514404e-01],
                        [ -3.17535400e-01,  -3.17932129e-01],
                        [ -3.18725586e-01,  -3.19366455e-01],
                        [ -2.71118164e-01,  -2.71423340e-01],
                        [ -2.09899902e-01,  -2.09594727e-01],
                        [ -1.68212891e-01,  -1.67572021e-01],
                        [ -1.51947021e-01,  -1.51519775e-01],
                        [ -1.45935059e-01,  -1.46087646e-01],
                        [ -1.36199951e-01,  -1.36779785e-01],
                        [ -1.18804932e-01,  -1.19323730e-01],
                        [ -9.26818848e-02,  -9.26818848e-02],
                        [ -5.34362793e-02,  -5.29174805e-02],
                        [  2.86865234e-03,   3.44848633e-03],
                        [  7.08923340e-02,   7.10144043e-02],
                        [  1.33941650e-01,   1.33544922e-01],
                        [  1.74011230e-01,   1.73400879e-01],
                        [  1.84295654e-01,   1.84020996e-01],
                        [  1.72027588e-01,   1.72332764e-01],
                        [  1.51306152e-01,   1.51947021e-01],
                        [  1.34765625e-01,   1.35162354e-01],
                        [  1.26586914e-01,   1.26403809e-01],
                        [  1.20513916e-01,   1.19934082e-01],
                        [  1.07910156e-01,   1.07421875e-01],
                        [  8.68835449e-02,   8.69445801e-02],
                        [  5.99670410e-02,   6.05163574e-02],
                        [  2.73437500e-02,   2.78930664e-02],
                        [ -1.08032227e-02,  -1.07421875e-02],
                        [ -4.72106934e-02,  -4.76684570e-02],
                        [ -6.92443848e-02,  -6.98547363e-02],
                        [ -7.00683594e-02,  -7.03125000e-02],
                        [ -5.42907715e-02,  -5.39245605e-02],
                        [ -3.14025879e-02,  -3.07922363e-02],
                        [ -9.15527344e-03,  -8.81958008e-03],
                        [  6.46972656e-03,   6.25610352e-03],
                        [  1.19934082e-02,   1.13830566e-02],
                        [  9.58251953e-03,   9.12475586e-03],
                        [  5.24902344e-03,   5.31005859e-03],
                        [  1.95312500e-03,   2.50244141e-03],
                        [ -3.05175781e-05,   5.18798828e-04],
                        [  2.89916992e-03,   2.96020508e-03],
                        [  1.52282715e-02,   1.47399902e-02],
                        [  3.33557129e-02,   3.27453613e-02],
                        [  4.81872559e-02,   4.79736328e-02],
                        [  5.44433594e-02,   5.48095703e-02],
                        [  5.09033203e-02,   5.15441895e-02],
                        [  3.94287109e-02,   3.97644043e-02],
                        [  2.76184082e-02,   2.73437500e-02],
                        [  2.27355957e-02,   2.21252441e-02],
                        [  2.22778320e-02,   2.18505859e-02],
                        [  1.99279785e-02,   2.00500488e-02],
                        [  1.65710449e-02,   1.71203613e-02],
                        [  1.53808594e-02,   1.59301758e-02],
                        [  1.53503418e-02,   1.54113770e-02],
                        [  1.77307129e-02,   1.72119141e-02],
                        [  2.76184082e-02,   2.70080566e-02],
                        [  4.20227051e-02,   4.19006348e-02],
                        [  5.02319336e-02,   5.06286621e-02],
                        [  4.85534668e-02,   4.91638184e-02],
                        [  4.24499512e-02,   4.27856445e-02],
                        [  3.59191895e-02,   3.56445312e-02],
                        [  3.03039551e-02,   2.96630859e-02],
                        [  2.79846191e-02,   2.75573730e-02],
                        [  2.84118652e-02,   2.85949707e-02],
                        [  2.72827148e-02,   2.78625488e-02],
                        [  2.40173340e-02,   2.45056152e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.77917480e-02,   1.72729492e-02],
                        [  7.69042969e-03,   7.11059570e-03],
                        [ -6.40869141e-03,  -6.53076172e-03],
                        [ -1.86767578e-02,  -1.82189941e-02],
                        [ -2.79235840e-02,  -2.73132324e-02],
                        [ -3.39355469e-02,  -3.36914062e-02],
                        [ -3.38745117e-02,  -3.41796875e-02],
                        [ -2.85644531e-02,  -2.91748047e-02],
                        [ -2.43835449e-02,  -2.47802734e-02],
                        [ -2.44750977e-02,  -2.42919922e-02],
                        [ -2.46276855e-02,  -2.40173340e-02],
                        [ -2.20336914e-02,  -2.15454102e-02],
                        [ -2.06604004e-02,  -2.06909180e-02],
                        [ -2.31628418e-02,  -2.37121582e-02],
                        [ -2.67944336e-02,  -2.73437500e-02],
                        [ -3.04870605e-02,  -3.05786133e-02],
                        [ -3.53698730e-02,  -3.49121094e-02],
                        [ -3.69567871e-02,  -3.63464355e-02],
                        [ -3.02429199e-02,  -2.99987793e-02],
                        [ -2.01416016e-02,  -2.04772949e-02],
                        [ -1.46484375e-02,  -1.52893066e-02],
                        [ -1.28784180e-02,  -1.32446289e-02],
                        [ -1.01013184e-02,  -9.88769531e-03],
                        [ -7.41577148e-03,  -6.80541992e-03],
                        [ -7.53784180e-03,  -7.08007812e-03],
                        [ -9.30786133e-03,  -9.36889648e-03],
                        [ -1.06201172e-02,  -1.11694336e-02],
                        [ -9.82666016e-03,  -1.03759766e-02],
                        [ -6.16455078e-03,  -6.22558594e-03],
                        [ -4.05883789e-03,  -3.57055664e-03],
                        [ -8.69750977e-03,  -8.11767578e-03],
                        [ -1.49536133e-02,  -1.47705078e-02],
                        [ -1.28173828e-02,  -1.31835938e-02],
                        [ -3.78417969e-03,  -4.39453125e-03],
                        [  1.06811523e-03,   7.32421875e-04],
                        [ -1.43432617e-03,  -1.19018555e-03],
                        [ -2.89916992e-03,  -2.25830078e-03],
                        [  2.74658203e-03,   3.17382812e-03],
                        [  1.09863281e-02,   1.08642578e-02],
                        [  1.34887695e-02,   1.29089355e-02],
                        [  8.45336914e-03,   7.93457031e-03],
                        [  3.57055664e-03,   3.50952148e-03],
                        [  7.62939453e-03,   8.11767578e-03],
                        [  2.05993652e-02,   2.12097168e-02],
                        [  3.66821289e-02,   3.68347168e-02],
                        [  5.55114746e-02,   5.50842285e-02],
                        [  8.09326172e-02,   8.03222656e-02],
                        [  1.10748291e-01,   1.10473633e-01],
                        [  1.33880615e-01,   1.34124756e-01],
                        [  1.36688232e-01,   1.37329102e-01],
                        [  1.09283447e-01,   1.09741211e-01],
                        [  4.78515625e-02,   4.76989746e-02],
                        [ -4.44946289e-02,  -4.51049805e-02],
                        [ -1.54418945e-01,  -1.54907227e-01],
                        [ -2.55584717e-01,  -2.55584717e-01],
                        [ -3.16497803e-01,  -3.15979004e-01],
                        [ -3.19824219e-01,  -3.19244385e-01],
                        [ -2.76245117e-01,  -2.76092529e-01],
                        [ -2.17468262e-01,  -2.17926025e-01],
                        [ -1.73889160e-01,  -1.74499512e-01],
                        [ -1.55517578e-01,  -1.55792236e-01],
                        [ -1.51092529e-01,  -1.50756836e-01],
                        [ -1.42883301e-01,  -1.42272949e-01],
                        [ -1.22711182e-01,  -1.22314453e-01],
                        [ -9.16442871e-02,  -9.17968750e-02],
                        [ -4.94995117e-02,  -5.01098633e-02],
                        [  6.43920898e-03,   5.95092773e-03],
                        [  7.25708008e-02,   7.26013184e-02],
                        [  1.34216309e-01,   1.34765625e-01],
                        [  1.74591064e-01,   1.75140381e-01],
                        [  1.87774658e-01,   1.87866211e-01],
                        [  1.82067871e-01,   1.81610107e-01],
                        [  1.69555664e-01,   1.68945312e-01],
                        [  1.55914307e-01,   1.55670166e-01],
                        [  1.39831543e-01,   1.40197754e-01],
                        [  1.19201660e-01,   1.19842529e-01],
                        [  9.41162109e-02,   9.44824219e-02],
                        [  6.50634766e-02,   6.48498535e-02],
                        [  3.17993164e-02,   3.11889648e-02],
                        [ -4.54711914e-03,  -5.03540039e-03],
                        [ -3.88793945e-02,  -3.87878418e-02],
                        [ -6.20117188e-02,  -6.14624023e-02],
                        [ -6.51550293e-02,  -6.46057129e-02],
                        [ -4.87976074e-02,  -4.87365723e-02],
                        [ -2.59704590e-02,  -2.64587402e-02],
                        [ -1.07727051e-02,  -1.13830566e-02],
                        [ -4.48608398e-03,  -4.69970703e-03],
                        [  1.00708008e-03,   1.37329102e-03],
                        [  8.05664062e-03,   8.69750977e-03],
                        [  1.11083984e-02,   1.14440918e-02],
                        [  9.18579102e-03,   8.91113281e-03],
                        [  8.57543945e-03,   7.93457031e-03],
                        [  1.25732422e-02,   1.21459961e-02],
                        [  1.92260742e-02,   1.93481445e-02],
                        [  2.71911621e-02,   2.77404785e-02],
                        [  3.63464355e-02,   3.68957520e-02],
                        [  4.44641113e-02,   4.44946289e-02],
                        [  4.74243164e-02,   4.69055176e-02],
                        [  4.25415039e-02,   4.19616699e-02],
                        [  3.21655273e-02,   3.20129395e-02],
                        [  2.22778320e-02,   2.26745605e-02],
                        [  1.60522461e-02,   1.66931152e-02],
                        [  1.17187500e-02,   1.20239258e-02],
                        [  8.20922852e-03,   7.90405273e-03],
                        [  8.81958008e-03,   8.17871094e-03],
                        [  1.53808594e-02,   1.49536133e-02],
                        [  2.44140625e-02,   2.45666504e-02],
                        [  3.25927734e-02,   3.31726074e-02],
                        [  3.94897461e-02,   4.00085449e-02],
                        [  4.39758301e-02,   4.40063477e-02],
                        [  4.40368652e-02,   4.35180664e-02],
                        [  4.07714844e-02,   4.01916504e-02],
                        [  3.77807617e-02,   3.76892090e-02],
                        [  3.72009277e-02,   3.76281738e-02],
                        [  3.84216309e-02,   3.90014648e-02],
                        [  3.91845703e-02,   3.94592285e-02],
                        [  3.69873047e-02,   3.67126465e-02],
                        [  3.03039551e-02,   2.96630859e-02],
                        [  1.99890137e-02,   1.95617676e-02],
                        [  8.94165039e-03,   9.15527344e-03],
                        [  1.83105469e-04,   7.93457031e-04],
                        [ -4.79125977e-03,  -4.30297852e-03],
                        [ -7.23266602e-03,  -7.29370117e-03],
                        [ -1.03759766e-02,  -1.09252930e-02],
                        [ -1.48620605e-02,  -1.54418945e-02],
                        [ -1.79138184e-02,  -1.80358887e-02],
                        [ -1.93786621e-02,  -1.89208984e-02],
                        [ -2.27355957e-02,  -2.21252441e-02],
                        [ -2.89001465e-02,  -2.86865234e-02],
                        [ -3.45153809e-02,  -3.48510742e-02],
                        [ -3.73840332e-02,  -3.80249023e-02],
                        [ -3.79333496e-02,  -3.82995605e-02],
                        [ -3.44543457e-02,  -3.42712402e-02],
                        [ -2.56652832e-02,  -2.50549316e-02],
                        [ -1.81884766e-02,  -1.77001953e-02],
                        [ -2.10876465e-02,  -2.11791992e-02],
                        [ -3.16467285e-02,  -3.22265625e-02],
                        [ -3.80859375e-02,  -3.86352539e-02],
                        [ -3.58886719e-02,  -3.59497070e-02],
                        [ -3.00598145e-02,  -2.96020508e-02],
                        [ -2.41699219e-02,  -2.35595703e-02],
                        [ -1.76391602e-02,  -1.74255371e-02],
                        [ -1.17492676e-02,  -1.21154785e-02],
                        [ -1.02844238e-02,  -1.09252930e-02],
                        [ -1.38549805e-02,  -1.41601562e-02],
                        [ -1.74255371e-02,  -1.71508789e-02],
                        [ -1.53503418e-02,  -1.47399902e-02],
                        [ -7.47680664e-03,  -7.01904297e-03],
                        [  3.35693359e-04,   2.44140625e-04],
                        [  2.22778320e-03,   1.64794922e-03],
                        [ -1.25122070e-03,  -1.77001953e-03],
                        [ -4.82177734e-03,  -4.85229492e-03],
                        [ -6.19506836e-03,  -5.67626953e-03],
                        [ -8.05664062e-03,  -7.44628906e-03],
                        [ -1.19018555e-02,  -1.17187500e-02],
                        [ -1.37023926e-02,  -1.41296387e-02],
                        [ -1.00097656e-02,  -1.06506348e-02],
                        [ -3.57055664e-03,  -3.84521484e-03],
                        [  1.34277344e-03,   1.64794922e-03],
                        [  4.15039062e-03,   4.76074219e-03],
                        [  6.10351562e-03,   6.53076172e-03],
                        [  9.09423828e-03,   8.94165039e-03],
                        [  1.57775879e-02,   1.51672363e-02],
                        [  2.65197754e-02,   2.60009766e-02],
                        [  3.99475098e-02,   3.99780273e-02],
                        [  5.80139160e-02,   5.85327148e-02],
                        [  8.45642090e-02,   8.51440430e-02],
                        [  1.16760254e-01,   1.16912842e-01],
                        [  1.42089844e-01,   1.41662598e-01],
                        [  1.45050049e-01,   1.44439697e-01],
                        [  1.15814209e-01,   1.15570068e-01],
                        [  5.21850586e-02,   5.24902344e-02],
                        [ -4.20837402e-02,  -4.14428711e-02],
                        [ -1.54296875e-01,  -1.53900146e-01],
                        [ -2.58636475e-01,  -2.58819580e-01],
                        [ -3.22570801e-01,  -3.23181152e-01],
                        [ -3.26812744e-01,  -3.27301025e-01],
                        [ -2.81280518e-01,  -2.81219482e-01],
                        [ -2.18231201e-01,  -2.17681885e-01],
                        [ -1.68640137e-01,  -1.68090820e-01],
                        [ -1.43981934e-01,  -1.43890381e-01],
                        [ -1.35467529e-01,  -1.35925293e-01],
                        [ -1.27716064e-01,  -1.28326416e-01],
                        [ -1.12579346e-01,  -1.12823486e-01],
                        [ -8.89282227e-02,  -8.85620117e-02],
                        [ -5.43518066e-02,  -5.37109375e-02],
                        [ -4.91333008e-03,  -4.54711914e-03],
                        [  5.74035645e-02,   5.71899414e-02],
                        [  1.21337891e-01,   1.20697021e-01],
                        [  1.71295166e-01,   1.70837402e-01],
                        [  1.95983887e-01,   1.96044922e-01],
                        [  1.95129395e-01,   1.95678711e-01],
                        [  1.79870605e-01,   1.80419922e-01],
                        [  1.62261963e-01,   1.62322998e-01],
                        [  1.43859863e-01,   1.43341064e-01],
                        [  1.17553711e-01,   1.16943359e-01],
                        [  7.95288086e-02,   7.93457031e-02],
                        [  3.37219238e-02,   3.41186523e-02],
                        [ -1.19018555e-02,  -1.12915039e-02],
                        [ -4.69665527e-02,  -4.66308594e-02],
                        [ -6.10046387e-02,  -6.12182617e-02],
                        [ -5.24291992e-02,  -5.30700684e-02],
                        [ -3.41796875e-02,  -3.46374512e-02],
                        [ -2.15148926e-02,  -2.13928223e-02],
                        [ -1.61437988e-02,  -1.55639648e-02],
                        [ -1.04064941e-02,  -9.88769531e-03],
                        [ -2.04467773e-03,  -2.01416016e-03],
                        [  5.61523438e-03,   5.12695312e-03],
                        [  1.16882324e-02,   1.10778809e-02],
                        [  1.70593262e-02,   1.68762207e-02],
                        [  2.10876465e-02,   2.14843750e-02],
                        [  2.38647461e-02,   2.45056152e-02],
                        [  2.76489258e-02,   2.79541016e-02],
                        [  3.31726074e-02,   3.28674316e-02],
                        [  3.86047363e-02,   3.79943848e-02],
                        [  4.32739258e-02,   4.28466797e-02],
                        [  4.68750000e-02,   4.70275879e-02],
                        [  4.58984375e-02,   4.65087891e-02],
                        [  3.72619629e-02,   3.77807617e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  1.69677734e-02,   1.64184570e-02],
                        [  1.42517090e-02,   1.36718750e-02],
                        [  1.30615234e-02,   1.29394531e-02],
                        [  1.23291016e-02,   1.27563477e-02],
                        [  1.45874023e-02,   1.51977539e-02],
                        [  1.97448730e-02,   2.00500488e-02],
                        [  2.51464844e-02,   2.48413086e-02],
                        [  3.09143066e-02,   3.02734375e-02],
                        [  3.87573242e-02,   3.83605957e-02],
                        [  4.65393066e-02,   4.67224121e-02],
                        [  4.98046875e-02,   5.03845215e-02],
                        [  4.72412109e-02,   4.77294922e-02],
                        [  4.23278809e-02,   4.22973633e-02],
                        [  3.98559570e-02,   3.93066406e-02],
                        [  4.03747559e-02,   3.97949219e-02],
                        [  3.81469727e-02,   3.80554199e-02],
                        [  2.78015137e-02,   2.82897949e-02],
                        [  1.33056641e-02,   1.39160156e-02],
                        [  4.66918945e-03,   4.88281250e-03],
                        [  5.03540039e-03,   4.69970703e-03],
                        [  7.75146484e-03,   7.14111328e-03],
                        [  6.62231445e-03,   6.22558594e-03],
                        [  2.07519531e-03,   2.28881836e-03],
                        [ -2.59399414e-03,  -1.95312500e-03],
                        [ -5.31005859e-03,  -4.82177734e-03],
                        [ -6.83593750e-03,  -6.92749023e-03],
                        [ -1.16882324e-02,  -1.22375488e-02],
                        [ -2.38342285e-02,  -2.43835449e-02],
                        [ -3.92761230e-02,  -3.93676758e-02],
                        [ -4.69360352e-02,  -4.64477539e-02],
                        [ -4.05883789e-02,  -3.99475098e-02],
                        [ -2.65502930e-02,  -2.63366699e-02],
                        [ -1.61743164e-02,  -1.65710449e-02],
                        [ -1.52587891e-02,  -1.58996582e-02],
                        [ -2.20336914e-02,  -2.23388672e-02],
                        [ -2.98767090e-02,  -2.96325684e-02],
                        [ -3.20129395e-02,  -3.14025879e-02],
                        [ -2.69470215e-02,  -2.64587402e-02],
                        [ -1.95312500e-02,  -1.96533203e-02],
                        [ -1.66931152e-02,  -1.73034668e-02],
                        [ -2.19421387e-02,  -2.24609375e-02],
                        [ -2.99682617e-02,  -2.99987793e-02],
                        [ -2.93884277e-02,  -2.89001465e-02],
                        [ -1.66015625e-02,  -1.60217285e-02],
                        [ -1.92260742e-03,  -1.73950195e-03],
                        [  4.42504883e-03,   3.99780273e-03],
                        [  3.60107422e-03,   2.96020508e-03],
                        [  5.79833984e-04,   3.05175781e-04],
                        [ -4.05883789e-03,  -3.75366211e-03],
                        [ -9.33837891e-03,  -8.72802734e-03],
                        [ -1.17797852e-02,  -1.13525391e-02],
                        [ -1.16271973e-02,  -1.17797852e-02],
                        [ -1.27868652e-02,  -1.33972168e-02],
                        [ -1.51367188e-02,  -1.56555176e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -5.58471680e-03,  -5.06591797e-03],
                        [  6.53076172e-03,   7.11059570e-03],
                        [  1.51062012e-02,   1.52282715e-02],
                        [  1.39160156e-02,   1.34582520e-02],
                        [  4.24194336e-03,   3.60107422e-03],
                        [ -4.97436523e-03,  -5.21850586e-03],
                        [ -4.60815430e-03,  -4.30297852e-03],
                        [  6.65283203e-03,   7.26318359e-03],
                        [  2.40783691e-02,   2.44750977e-02],
                        [  4.49218750e-02,   4.47387695e-02],
                        [  7.01904297e-02,   6.95800781e-02],
                        [  9.92126465e-02,   9.87243652e-02],
                        [  1.25854492e-01,   1.25915527e-01],
                        [  1.40808105e-01,   1.41357422e-01],
                        [  1.35711670e-01,   1.36291504e-01],
                        [  1.04949951e-01,   1.05072021e-01],
                        [  4.52575684e-02,   4.47998047e-02],
                        [ -4.21752930e-02,  -4.27856445e-02],
                        [ -1.46911621e-01,  -1.47155762e-01],
                        [ -2.45941162e-01,  -2.45574951e-01],
                        [ -3.08380127e-01,  -3.07769775e-01],
                        [ -3.13537598e-01,  -3.13201904e-01],
                        [ -2.69348145e-01,  -2.69561768e-01],
                        [ -2.08862305e-01,  -2.09472656e-01],
                        [ -1.65252686e-01,  -1.65740967e-01],
                        [ -1.49291992e-01,  -1.49200439e-01],
                        [ -1.47766113e-01,  -1.47186279e-01],
                        [ -1.41235352e-01,  -1.40686035e-01],
                        [ -1.21856689e-01,  -1.21795654e-01],
                        [ -9.28649902e-02,  -9.33532715e-02],
                        [ -5.60607910e-02,  -5.66711426e-02],
                        [ -7.35473633e-03,  -7.56835938e-03],
                        [  5.42602539e-02,   5.46264648e-02],
                        [  1.19812012e-01,   1.20422363e-01],
                        [  1.73675537e-01,   1.74011230e-01],
                        [  2.02850342e-01,   2.02606201e-01],
                        [  2.04986572e-01,   2.04376221e-01],
                        [  1.89483643e-01,   1.89025879e-01],
                        [  1.66656494e-01,   1.66778564e-01],
                        [  1.37298584e-01,   1.37878418e-01],
                        [  9.65576172e-02,   9.70764160e-02],
                        [  4.50744629e-02,   4.51049805e-02],
                        [ -7.23266602e-03,  -7.72094727e-03],
                        [ -4.62036133e-02,  -4.68139648e-02],
                        [ -6.17675781e-02,  -6.19506836e-02],
                        [ -5.40466309e-02,  -5.36499023e-02],
                        [ -3.33251953e-02,  -3.27148438e-02],
                        [ -1.36108398e-02,  -1.33056641e-02],
                        [ -3.05175781e-03,  -3.32641602e-03],
                        [ -1.22070312e-04,  -7.32421875e-04],
                        [  6.71386719e-04,   2.44140625e-04],
                        [  2.31933594e-03,   2.47192383e-03],
                        [  5.70678711e-03,   6.31713867e-03],
                        [  1.08032227e-02,   1.12915039e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.77001953e-02,   1.71813965e-02],
                        [  2.14843750e-02,   2.08740234e-02],
                        [  3.16467285e-02,   3.14941406e-02],
                        [  4.66003418e-02,   4.70581055e-02],
                        [  5.93872070e-02,   6.00280762e-02],
                        [  6.53076172e-02,   6.55517578e-02],
                        [  6.25610352e-02,   6.22558594e-02],
                        [  5.09338379e-02,   5.03234863e-02],
                        [  3.51562500e-02,   3.47290039e-02],
                        [  2.26745605e-02,   2.28271484e-02],
                        [  1.46484375e-02,   1.52587891e-02],
                        [  7.04956055e-03,   7.53784180e-03],
                        [  1.19018555e-03,   1.12915039e-03],
                        [  3.93676758e-03,   3.38745117e-03],
                        [  1.61743164e-02,   1.55944824e-02],
                        [  2.92968750e-02,   2.91748047e-02],
                        [  3.57666016e-02,   3.62243652e-02],
                        [  3.75976562e-02,   3.82080078e-02],
                        [  4.05578613e-02,   4.08020020e-02],
                        [  4.40368652e-02,   4.37011719e-02],
                        [  4.25720215e-02,   4.19311523e-02],
                        [  3.66210938e-02,   3.62548828e-02],
                        [  3.44543457e-02,   3.46679688e-02],
                        [  3.98864746e-02,   4.05273438e-02],
                        [  4.57763672e-02,   4.62646484e-02],
                        [  4.35485840e-02,   4.34570312e-02],
                        [  3.28063965e-02,   3.22570801e-02],
                        [  1.91650391e-02,   1.86157227e-02],
                        [  7.53784180e-03,   7.44628906e-03],
                        [ -2.74658203e-04,   1.83105469e-04],
                        [ -4.51660156e-03,  -3.90625000e-03],
                        [ -6.31713867e-03,  -6.10351562e-03],
                        [ -8.08715820e-03,  -8.45336914e-03],
                        [ -1.20544434e-02,  -1.26647949e-02],
                        [ -1.71508789e-02,  -1.74560547e-02],
                        [ -2.07519531e-02,  -2.05383301e-02],
                        [ -2.33154297e-02,  -2.27050781e-02],
                        [ -2.74353027e-02,  -2.69775391e-02],
                        [ -3.25622559e-02,  -3.26843262e-02],
                        [ -3.48815918e-02,  -3.54919434e-02],
                        [ -3.26232910e-02,  -3.31420898e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -1.82495117e-02,  -1.77612305e-02],
                        [ -9.03320312e-03,  -8.45336914e-03],
                        [ -5.58471680e-03,  -5.40161133e-03],
                        [ -1.09863281e-02,  -1.13830566e-02],
                        [ -1.95312500e-02,  -2.01416016e-02],
                        [ -2.34985352e-02,  -2.38037109e-02],
                        [ -2.23388672e-02,  -2.20642090e-02],
                        [ -2.10876465e-02,  -2.04467773e-02],
                        [ -2.12707520e-02,  -2.08740234e-02],
                        [ -1.87072754e-02,  -1.88293457e-02],
                        [ -1.14135742e-02,  -1.19934082e-02],
                        [ -4.73022461e-03,  -5.24902344e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.26953125e-02,  -1.21765137e-02],
                        [ -2.10876465e-02,  -2.05078125e-02],
                        [ -2.34069824e-02,  -2.32849121e-02],
                        [ -1.82189941e-02,  -1.86157227e-02],
                        [ -9.15527344e-03,  -9.76562500e-03],
                        [ -9.76562500e-04,  -1.25122070e-03],
                        [  3.66210938e-03,   3.96728516e-03],
                        [  5.21850586e-03,   5.85937500e-03],
                        [  5.52368164e-03,   5.88989258e-03],
                        [  4.33349609e-03,   4.11987305e-03],
                        [ -7.32421875e-04,  -1.31225586e-03],
                        [ -8.85009766e-03,  -9.33837891e-03],
                        [ -1.42517090e-02,  -1.42211914e-02],
                        [ -1.33972168e-02,  -1.28784180e-02],
                        [ -8.42285156e-03,  -7.84301758e-03],
                        [  3.35693359e-04,   4.27246094e-04],
                        [  1.45874023e-02,   1.41296387e-02],
                        [  2.99987793e-02,   2.94189453e-02],
                        [  4.04968262e-02,   4.02526855e-02],
                        [  4.87060547e-02,   4.90417480e-02],
                        [  6.17675781e-02,   6.24084473e-02],
                        [  8.12377930e-02,   8.16040039e-02],
                        [  1.03637695e-01,   1.03424072e-01],
                        [  1.24359131e-01,   1.23748779e-01],
                        [  1.34338379e-01,   1.33880615e-01],
                        [  1.17919922e-01,   1.18011475e-01],
                        [  6.18286133e-02,   6.23779297e-02],
                        [ -3.24401855e-02,  -3.19213867e-02],
                        [ -1.45050049e-01,  -1.44989014e-01],
                        [ -2.44476318e-01,  -2.44934082e-01],
                        [ -3.00903320e-01,  -3.01513672e-01],
                        [ -3.01635742e-01,  -3.01818848e-01],
                        [ -2.58575439e-01,  -2.58209229e-01],
                        [ -2.02178955e-01,  -2.01538086e-01],
                        [ -1.62322998e-01,  -1.61987305e-01],
                        [ -1.48223877e-01,  -1.48468018e-01],
                        [ -1.46118164e-01,  -1.46728516e-01],
                        [ -1.38763428e-01,  -1.39190674e-01],
                        [ -1.21978760e-01,  -1.21856689e-01],
                        [ -9.96704102e-02,  -9.91210938e-02],
                        [ -7.06787109e-02,  -7.01293945e-02],
                        [ -2.71301270e-02,  -2.70996094e-02],
                        [  3.57360840e-02,   3.52172852e-02],
                        [  1.10839844e-01,   1.10260010e-01],
                        [  1.79290771e-01,   1.79138184e-01],
                        [  2.20092773e-01,   2.20489502e-01],
                        [  2.24304199e-01,   2.24884033e-01],
                        [  2.00500488e-01,   2.00805664e-01],
                        [  1.64306641e-01,   1.64031982e-01],
                        [  1.23107910e-01,   1.22497559e-01],
                        [  7.47070312e-02,   7.42797852e-02],
                        [  2.05688477e-02,   2.07519531e-02],
                        [ -2.58483887e-02,  -2.52990723e-02],
                        [ -4.94689941e-02,  -4.89807129e-02],
                        [ -4.81567383e-02,  -4.81262207e-02],
                        [ -3.29895020e-02,  -3.34777832e-02],
                        [ -1.72119141e-02,  -1.77917480e-02],
                        [ -8.14819336e-03,  -8.27026367e-03],
                        [ -4.85229492e-03,  -4.42504883e-03],
                        [ -2.25830078e-03,  -1.67846680e-03],
                        [  1.22070312e-03,   1.46484375e-03],
                        [  3.17382812e-03,   2.86865234e-03],
                        [  3.20434570e-03,   2.59399414e-03],
                        [  4.82177734e-03,   4.42504883e-03],
                        [  1.13525391e-02,   1.15356445e-02],
                        [  2.30407715e-02,   2.36206055e-02],
                        [  3.86047363e-02,   3.90930176e-02],
                        [  5.63354492e-02,   5.62744141e-02],
                        [  7.22656250e-02,   7.17468262e-02],
                        [  8.15429688e-02,   8.09936523e-02],
                        [  8.14819336e-02,   8.13598633e-02],
                        [  7.18383789e-02,   7.22656250e-02],
                        [  5.50231934e-02,   5.56335449e-02],
                        [  3.61633301e-02,   3.64074707e-02],
                        [  1.91040039e-02,   1.87683105e-02],
                        [  4.97436523e-03,   4.36401367e-03],
                        [ -3.17382812e-03,  -3.50952148e-03],
                        [ -2.74658203e-04,  -6.10351562e-05],
                        [  1.22375488e-02,   1.28173828e-02],
                        [  2.54211426e-02,   2.58789062e-02],
                        [  3.31115723e-02,   3.30200195e-02],
                        [  3.64379883e-02,   3.59191895e-02],
                        [  3.74450684e-02,   3.69262695e-02],
                        [  3.71704102e-02,   3.71093750e-02],
                        [  3.83300781e-02,   3.87878418e-02],
                        [  4.16259766e-02,   4.22058105e-02],
                        [  4.34265137e-02,   4.36096191e-02],
                        [  4.22058105e-02,   4.18701172e-02],
                        [  4.11071777e-02,   4.05273438e-02],
                        [  4.16870117e-02,   4.13513184e-02],
                        [  4.02832031e-02,   4.05273438e-02],
                        [  3.31420898e-02,   3.37219238e-02],
                        [  2.16674805e-02,   2.20947266e-02],
                        [  9.97924805e-03,   9.88769531e-03],
                        [ -2.44140625e-04,  -7.93457031e-04],
                        [ -9.12475586e-03,  -9.61303711e-03],
                        [ -1.59301758e-02,  -1.59606934e-02],
                        [ -2.09655762e-02,  -2.04772949e-02],
                        [ -2.57873535e-02,  -2.52075195e-02],
                        [ -3.01208496e-02,  -2.99377441e-02],
                        [ -3.12500000e-02,  -3.16162109e-02],
                        [ -2.87780762e-02,  -2.93884277e-02],
                        [ -2.56958008e-02,  -2.59704590e-02],
                        [ -2.34985352e-02,  -2.32543945e-02],
                        [ -2.14538574e-02,  -2.08740234e-02],
                        [ -1.96838379e-02,  -1.92565918e-02],
                        [ -1.88293457e-02,  -1.89819336e-02],
                        [ -1.87683105e-02,  -1.93481445e-02],
                        [ -1.92565918e-02,  -1.97448730e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.81274414e-02,  -1.76391602e-02],
                        [ -1.55029297e-02,  -1.49536133e-02],
                        [ -1.35803223e-02,  -1.34582520e-02],
                        [ -1.32751465e-02,  -1.37023926e-02],
                        [ -1.44958496e-02,  -1.50756836e-02],
                        [ -1.66931152e-02,  -1.69677734e-02],
                        [ -1.93481445e-02,  -1.90734863e-02],
                        [ -2.29187012e-02,  -2.23388672e-02],
                        [ -2.77709961e-02,  -2.74047852e-02],
                        [ -3.16772461e-02,  -3.18603516e-02],
                        [ -3.10668945e-02,  -3.16162109e-02],
                        [ -2.50854492e-02,  -2.55737305e-02],
                        [ -1.69982910e-02,  -1.69677734e-02],
                        [ -1.11999512e-02,  -1.06811523e-02],
                        [ -9.39941406e-03,  -8.85009766e-03],
                        [ -1.00402832e-02,  -9.94873047e-03],
                        [ -1.12915039e-02,  -1.17187500e-02],
                        [ -1.30004883e-02,  -1.35498047e-02],
                        [ -1.40991211e-02,  -1.43432617e-02],
                        [ -1.26647949e-02,  -1.23596191e-02],
                        [ -9.70458984e-03,  -9.12475586e-03],
                        [ -7.75146484e-03,  -7.41577148e-03],
                        [ -5.31005859e-03,  -5.52368164e-03],
                        [ -1.22070312e-04,  -7.01904297e-04],
                        [  5.00488281e-03,   4.57763672e-03],
                        [  6.86645508e-03,   6.95800781e-03],
                        [  8.14819336e-03,   8.66699219e-03],
                        [  1.36413574e-02,   1.41601562e-02],
                        [  2.52075195e-02,   2.52685547e-02],
                        [  4.29077148e-02,   4.24804688e-02],
                        [  6.69860840e-02,   6.64367676e-02],
                        [  9.46655273e-02,   9.44824219e-02],
                        [  1.19323730e-01,   1.19659424e-01],
                        [  1.34063721e-01,   1.34643555e-01],
                        [  1.32202148e-01,   1.32507324e-01],
                        [  1.05834961e-01,   1.05621338e-01],
                        [  5.03845215e-02,   4.98352051e-02],
                        [ -3.04870605e-02,  -3.08837891e-02],
                        [ -1.26068115e-01,  -1.25976562e-01],
                        [ -2.18231201e-01,  -2.17712402e-01],
                        [ -2.80059814e-01,  -2.79571533e-01],
                        [ -2.88909912e-01,  -2.88879395e-01],
                        [ -2.48931885e-01,  -2.49389648e-01],
                        [ -1.93084717e-01,  -1.93603516e-01],
                        [ -1.54998779e-01,  -1.55151367e-01],
                        [ -1.43218994e-01,  -1.42883301e-01],
                        [ -1.44775391e-01,  -1.44226074e-01],
                        [ -1.43920898e-01,  -1.43615723e-01],
                        [ -1.32873535e-01,  -1.33148193e-01],
                        [ -1.11480713e-01,  -1.12060547e-01],
                        [ -8.10241699e-02,  -8.13903809e-02],
                        [ -3.86047363e-02,  -3.84826660e-02],
                        [  2.05078125e-02,   2.09960938e-02],
                        [  9.34753418e-02,   9.39331055e-02],
                        [  1.66046143e-01,   1.66046143e-01],
                        [  2.20031738e-01,   2.19543457e-01],
                        [  2.42462158e-01,   2.41943359e-01],
                        [  2.27905273e-01,   2.27813721e-01],
                        [  1.78314209e-01,   1.78710938e-01],
                        [  1.05316162e-01,   1.05865479e-01],
                        [  2.93579102e-02,   2.96325684e-02],
                        [ -2.77404785e-02,  -2.80151367e-02],
                        [ -5.37414551e-02,  -5.43212891e-02],
                        [ -5.21545410e-02,  -5.25207520e-02],
                        [ -3.61633301e-02,  -3.60107422e-02],
                        [ -1.72424316e-02,  -1.66931152e-02],
                        [ -1.52587891e-03,  -1.09863281e-03],
                        [  7.26318359e-03,   7.23266602e-03],
                        [  8.60595703e-03,   8.14819336e-03],
                        [  5.82885742e-03,   5.31005859e-03],
                        [  2.83813477e-03,   2.71606445e-03],
                        [  1.89208984e-03,   2.28881836e-03],
                        [  4.24194336e-03,   4.79125977e-03],
                        [  1.10778809e-02,   1.12609863e-02],
                        [  2.27050781e-02,   2.23999023e-02],
                        [  3.79638672e-02,   3.74145508e-02],
                        [  5.57556152e-02,   5.54504395e-02],
                        [  7.47680664e-02,   7.49511719e-02],
                        [  8.99658203e-02,   9.04846191e-02],
                        [  9.45434570e-02,   9.49707031e-02],
                        [  8.75549316e-02,   8.74938965e-02],
                        [  7.37915039e-02,   7.33032227e-02],
                        [  5.77392578e-02,   5.72509766e-02],
                        [  4.19006348e-02,   4.18395996e-02],
                        [  2.85034180e-02,   2.89001465e-02],
                        [  1.83715820e-02,   1.89208984e-02],
                        [  1.13220215e-02,   1.15356445e-02],
                        [  8.60595703e-03,   8.30078125e-03],
                        [  1.10473633e-02,   1.04980469e-02],
                        [  1.47705078e-02,   1.44653320e-02],
                        [  1.62963867e-02,   1.65100098e-02],
                        [  1.95617676e-02,   2.00805664e-02],
                        [  2.79846191e-02,   2.83508301e-02],
                        [  3.59497070e-02,   3.58581543e-02],
                        [  3.79028320e-02,   3.74145508e-02],
                        [  3.78417969e-02,   3.73535156e-02],
                        [  4.05578613e-02,   4.05273438e-02],
                        [  4.29077148e-02,   4.33349609e-02],
                        [  4.08325195e-02,   4.13513184e-02],
                        [  3.67126465e-02,   3.68652344e-02],
                        [  3.31420898e-02,   3.28063965e-02],
                        [  2.82287598e-02,   2.77099609e-02],
                        [  2.17285156e-02,   2.14538574e-02],
                        [  1.70593262e-02,   1.72729492e-02],
                        [  1.48010254e-02,   1.53198242e-02],
                        [  1.08947754e-02,   1.12609863e-02],
                        [  2.83813477e-03,   2.71606445e-03],
                        [ -7.59887695e-03,  -8.08715820e-03],
                        [ -1.75170898e-02,  -1.79443359e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.84118652e-02,  -2.79846191e-02],
                        [ -2.69775391e-02,  -2.64892578e-02],
                        [ -2.16979980e-02,  -2.15759277e-02],
                        [ -1.50756836e-02,  -1.54418945e-02],
                        [ -1.20544434e-02,  -1.25732422e-02],
                        [ -1.63574219e-02,  -1.65710449e-02],
                        [ -2.55432129e-02,  -2.52990723e-02],
                        [ -3.22875977e-02,  -3.17687988e-02],
                        [ -3.17687988e-02,  -3.14331055e-02],
                        [ -2.56347656e-02,  -2.57568359e-02],
                        [ -1.94091797e-02,  -1.98974609e-02],
                        [ -1.73645020e-02,  -1.77612305e-02],
                        [ -1.97143555e-02,  -1.96533203e-02],
                        [ -2.31628418e-02,  -2.27355957e-02],
                        [ -2.43530273e-02,  -2.38952637e-02],
                        [ -2.32543945e-02,  -2.31628418e-02],
                        [ -2.20031738e-02,  -2.23693848e-02],
                        [ -2.09045410e-02,  -2.13928223e-02],
                        [ -1.87988281e-02,  -1.90124512e-02],
                        [ -1.62048340e-02,  -1.59301758e-02],
                        [ -1.53503418e-02,  -1.48620605e-02],
                        [ -1.73645020e-02,  -1.70593262e-02],
                        [ -2.08435059e-02,  -2.09960938e-02],
                        [ -2.40478516e-02,  -2.45361328e-02],
                        [ -2.59704590e-02,  -2.63366699e-02],
                        [ -2.53601074e-02,  -2.53295898e-02],
                        [ -2.08129883e-02,  -2.03857422e-02],
                        [ -1.17797852e-02,  -1.13220215e-02],
                        [ -6.40869141e-04,  -5.79833984e-04],
                        [  5.52368164e-03,   5.12695312e-03],
                        [  1.06811523e-03,   6.10351562e-04],
                        [ -9.12475586e-03,  -9.30786133e-03],
                        [ -1.33972168e-02,  -1.30920410e-02],
                        [ -7.47680664e-03,  -6.98852539e-03],
                        [  2.28881836e-03,   2.56347656e-03],
                        [  1.08032227e-02,   1.06201172e-02],
                        [  1.96228027e-02,   1.91345215e-02],
                        [  2.98461914e-02,   2.95104980e-02],
                        [  4.03137207e-02,   4.04052734e-02],
                        [  5.26733398e-02,   5.31005859e-02],
                        [  7.08618164e-02,   7.12890625e-02],
                        [  9.37805176e-02,   9.38110352e-02],
                        [  1.13830566e-01,   1.13433838e-01],
                        [  1.25213623e-01,   1.24755859e-01],
                        [  1.25793457e-01,   1.25640869e-01],
                        [  1.08764648e-01,   1.09069824e-01],
                        [  6.27441406e-02,   6.32324219e-02],
                        [ -1.66931152e-02,  -1.64794922e-02],
                        [ -1.19537354e-01,  -1.19720459e-01],
                        [ -2.20947266e-01,  -2.21405029e-01],
                        [ -2.87597656e-01,  -2.87933350e-01],
                        [ -2.95654297e-01,  -2.95562744e-01],
                        [ -2.52166748e-01,  -2.51708984e-01],
                        [ -1.93145752e-01,  -1.92749023e-01],
                        [ -1.52099609e-01,  -1.52099609e-01],
                        [ -1.34948730e-01,  -1.35345459e-01],
                        [ -1.29302979e-01,  -1.29730225e-01],
                        [ -1.24938965e-01,  -1.25061035e-01],
                        [ -1.19049072e-01,  -1.18743896e-01],
                        [ -1.10504150e-01,  -1.10046387e-01],
                        [ -9.31396484e-02,  -9.29260254e-02],
                        [ -5.51452637e-02,  -5.53588867e-02],
                        [  9.46044922e-03,   9.00268555e-03],
                        [  9.07592773e-02,   9.04846191e-02],
                        [  1.68518066e-01,   1.68640137e-01],
                        [  2.22808838e-01,   2.23236084e-01],
                        [  2.38830566e-01,   2.39196777e-01],
                        [  2.10235596e-01,   2.10205078e-01],
                        [  1.45202637e-01,   1.44805908e-01],
                        [  6.59790039e-02,   6.55822754e-02],
                        [ -2.25830078e-03,  -2.31933594e-03],
                        [ -4.21142578e-02,  -4.17785645e-02],
                        [ -4.92858887e-02,  -4.88586426e-02],
                        [ -3.36303711e-02,  -3.34472656e-02],
                        [ -1.13830566e-02,  -1.16271973e-02],
                        [  6.80541992e-03,   6.34765625e-03],
                        [  1.93481445e-02,   1.91040039e-02],
                        [  2.71606445e-02,   2.73132324e-02],
                        [  2.78930664e-02,   2.83508301e-02],
                        [  1.98059082e-02,   2.01416016e-02],
                        [  8.30078125e-03,   8.23974609e-03],
                        [  1.15966797e-03,   7.62939453e-04],
                        [ -2.44140625e-04,  -6.40869141e-04],
                        [  2.22778320e-03,   2.19726562e-03],
                        [  1.10778809e-02,   1.14135742e-02],
                        [  2.96630859e-02,   3.01208496e-02],
                        [  5.52062988e-02,   5.53588867e-02],
                        [  7.97119141e-02,   7.94372559e-02],
                        [  9.57641602e-02,   9.53369141e-02],
                        [  9.95178223e-02,   9.92736816e-02],
                        [  9.15527344e-02,   9.17358398e-02],
                        [  7.63244629e-02,   7.67517090e-02],
                        [  5.90515137e-02,   5.93566895e-02],
                        [  4.24499512e-02,   4.23583984e-02],
                        [  2.71606445e-02,   2.67639160e-02],
                        [  1.46789551e-02,   1.42822266e-02],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  1.07421875e-02,   1.11083984e-02],
                        [  1.81884766e-02,   1.86157227e-02],
                        [  2.57568359e-02,   2.58789062e-02],
                        [  3.04870605e-02,   3.02429199e-02],
                        [  3.23486328e-02,   3.19213867e-02],
                        [  3.25927734e-02,   3.23791504e-02],
                        [  3.32031250e-02,   3.34167480e-02],
                        [  3.56140137e-02,   3.60412598e-02],
                        [  3.83300781e-02,   3.86047363e-02],
                        [  3.90319824e-02,   3.89404297e-02],
                        [  3.83605957e-02,   3.79943848e-02],
                        [  3.82385254e-02,   3.78723145e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  3.77807617e-02,   3.81164551e-02],
                        [  3.45458984e-02,   3.49426270e-02],
                        [  2.70690918e-02,   2.71606445e-02],
                        [  1.64489746e-02,   1.61743164e-02],
                        [  6.16455078e-03,   5.73730469e-03],
                        [ -2.71606445e-03,  -2.89916992e-03],
                        [ -1.18103027e-02,  -1.16271973e-02],
                        [ -2.04772949e-02,  -2.00805664e-02],
                        [ -2.42919922e-02,  -2.40478516e-02],
                        [ -2.16064453e-02,  -2.17285156e-02],
                        [ -1.65100098e-02,  -1.69067383e-02],
                        [ -1.26342773e-02,  -1.29699707e-02],
                        [ -1.01623535e-02,  -1.01318359e-02],
                        [ -9.73510742e-03,  -9.39941406e-03],
                        [ -1.39465332e-02,  -1.35803223e-02],
                        [ -2.23693848e-02,  -2.23083496e-02],
                        [ -2.99072266e-02,  -3.01818848e-02],
                        [ -3.27453613e-02,  -3.31420898e-02],
                        [ -3.21044922e-02,  -3.22570801e-02],
                        [ -2.94494629e-02,  -2.92358398e-02],
                        [ -2.54516602e-02,  -2.50549316e-02],
                        [ -2.26135254e-02,  -2.23999023e-02],
                        [ -2.18505859e-02,  -2.19726562e-02],
                        [ -1.99279785e-02,  -2.02941895e-02],
                        [ -1.62048340e-02,  -1.64794922e-02],
                        [ -1.51367188e-02,  -1.50756836e-02],
                        [ -1.70898438e-02,  -1.67541504e-02],
                        [ -1.57470703e-02,  -1.54113770e-02],
                        [ -9.70458984e-03,  -9.64355469e-03],
                        [ -7.08007812e-03,  -7.35473633e-03],
                        [ -1.31835938e-02,  -1.35498047e-02],
                        [ -2.40783691e-02,  -2.42004395e-02],
                        [ -3.29589844e-02,  -3.27453613e-02],
                        [ -3.55834961e-02,  -3.51867676e-02],
                        [ -3.04565430e-02,  -3.02429199e-02],
                        [ -1.97448730e-02,  -1.98974609e-02],
                        [ -9.39941406e-03,  -9.76562500e-03],
                        [ -5.79833984e-03,  -6.07299805e-03],
                        [ -9.67407227e-03,  -9.61303711e-03],
                        [ -1.51672363e-02,  -1.48620605e-02],
                        [ -1.65710449e-02,  -1.62658691e-02],
                        [ -1.24206543e-02,  -1.23901367e-02],
                        [ -4.82177734e-03,  -5.09643555e-03],
                        [  2.71606445e-03,   2.38037109e-03],
                        [  9.00268555e-03,   8.91113281e-03],
                        [  1.60827637e-02,   1.63269043e-02],
                        [  2.63061523e-02,   2.66723633e-02],
                        [  3.87573242e-02,   3.89404297e-02],
                        [  4.93164062e-02,   4.91638184e-02],
                        [  5.64880371e-02,   5.61218262e-02],
                        [  6.52465820e-02,   6.50024414e-02],
                        [  8.03222656e-02,   8.03833008e-02],
                        [  9.93041992e-02,   9.96398926e-02],
                        [  1.14105225e-01,   1.14379883e-01],
                        [  1.14440918e-01,   1.14410400e-01],
                        [  9.03320312e-02,   9.00268555e-02],
                        [  3.43322754e-02,   3.40270996e-02],
                        [ -5.32531738e-02,  -5.33447266e-02],
                        [ -1.57836914e-01,  -1.57592773e-01],
                        [ -2.50976562e-01,  -2.50640869e-01],
                        [ -3.01666260e-01,  -3.01513672e-01],
                        [ -2.93182373e-01,  -2.93365479e-01],
                        [ -2.38708496e-01,  -2.39044189e-01],
                        [ -1.76086426e-01,  -1.76300049e-01],
                        [ -1.36962891e-01,  -1.36871338e-01],
                        [ -1.23809814e-01,  -1.23504639e-01],
                        [ -1.20697021e-01,  -1.20422363e-01],
                        [ -1.15844727e-01,  -1.15844727e-01],
                        [ -1.07574463e-01,  -1.07849121e-01],
                        [ -9.66186523e-02,  -9.69238281e-02],
                        [ -8.00781250e-02,  -8.01391602e-02],
                        [ -5.04760742e-02,  -5.02319336e-02],
                        [  5.18798828e-04,   8.54492188e-04],
                        [  7.36999512e-02,   7.38220215e-02],
                        [  1.54022217e-01,   1.53869629e-01],
                        [  2.13775635e-01,   2.13439941e-01],
                        [  2.27722168e-01,   2.27508545e-01],
                        [  1.88385010e-01,   1.88507080e-01],
                        [  1.11511230e-01,   1.11816406e-01],
                        [  2.99682617e-02,   3.02124023e-02],
                        [ -2.41699219e-02,  -2.42004395e-02],
                        [ -3.96423340e-02,  -3.99169922e-02],
                        [ -2.90527344e-02,  -2.93273926e-02],
                        [ -1.33056641e-02,  -1.33361816e-02],
                        [ -4.39453125e-03,  -4.15039062e-03],
                        [  1.83105469e-04,   4.88281250e-04],
                        [  8.17871094e-03,   8.30078125e-03],
                        [  1.85852051e-02,   1.84020996e-02],
                        [  2.05078125e-02,   2.02026367e-02],
                        [  8.63647461e-03,   8.45336914e-03],
                        [ -7.23266602e-03,  -7.14111328e-03],
                        [ -1.31225586e-02,  -1.28173828e-02],
                        [ -4.15039062e-03,  -3.93676758e-03],
                        [  1.66015625e-02,   1.65710449e-02],
                        [  4.32434082e-02,   4.29687500e-02],
                        [  6.77185059e-02,   6.74743652e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  9.06372070e-02,   9.08813477e-02],
                        [  8.80126953e-02,   8.83178711e-02],
                        [  7.73010254e-02,   7.73620605e-02],
                        [  6.42395020e-02,   6.40563965e-02],
                        [  5.56335449e-02,   5.53283691e-02],
                        [  5.07507324e-02,   5.05981445e-02],
                        [  4.37011719e-02,   4.38232422e-02],
                        [  3.36608887e-02,   3.39355469e-02],
                        [  2.57568359e-02,   2.59399414e-02],
                        [  2.24609375e-02,   2.23999023e-02],
                        [  2.09960938e-02,   2.07519531e-02],
                        [  1.90124512e-02,   1.87683105e-02],
                        [  1.79748535e-02,   1.80053711e-02],
                        [  2.13012695e-02,   2.15148926e-02],
                        [  2.96020508e-02,   2.98461914e-02],
                        [  3.82995605e-02,   3.83605957e-02],
                        [  4.04968262e-02,   4.03137207e-02],
                        [  3.45764160e-02,   3.43017578e-02],
                        [  2.61535645e-02,   2.60314941e-02],
                        [  2.15759277e-02,   2.16979980e-02],
                        [  2.30407715e-02,   2.33154297e-02],
                        [  2.87780762e-02,   2.89611816e-02],
                        [  3.28063965e-02,   3.27453613e-02],
                        [  2.98461914e-02,   2.96020508e-02],
                        [  2.20947266e-02,   2.18811035e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.10168457e-02,   1.12304688e-02],
                        [  6.34765625e-03,   6.59179688e-03],
                        [  6.10351562e-05,   9.15527344e-05],
                        [ -7.11059570e-03,  -7.29370117e-03],
                        [ -1.36718750e-02,  -1.39465332e-02],
                        [ -1.80358887e-02,  -1.81274414e-02],
                        [ -1.95312500e-02,  -1.94091797e-02],
                        [ -2.04772949e-02,  -2.02331543e-02],
                        [ -2.33154297e-02,  -2.31628418e-02],
                        [ -2.70385742e-02,  -2.70996094e-02],
                        [ -3.03039551e-02,  -3.05480957e-02],
                        [ -3.45764160e-02,  -3.47900391e-02],
                        [ -3.87878418e-02,  -3.87573242e-02],
                        [ -3.74755859e-02,  -3.72619629e-02],
                        [ -2.95104980e-02,  -2.92968750e-02],
                        [ -2.13012695e-02,  -2.12707520e-02],
                        [ -1.84936523e-02,  -1.86767578e-02],
                        [ -2.02636719e-02,  -2.05078125e-02],
                        [ -2.45361328e-02,  -2.46276855e-02],
                        [ -3.10668945e-02,  -3.09143066e-02],
                        [ -3.71093750e-02,  -3.68652344e-02],
                        [ -3.77502441e-02,  -3.76281738e-02],
                        [ -3.24707031e-02,  -3.25622559e-02],
                        [ -2.49938965e-02,  -2.52075195e-02],
                        [ -1.81884766e-02,  -1.83715820e-02],
                        [ -1.27868652e-02,  -1.27563477e-02],
                        [ -8.75854492e-03,  -8.54492188e-03],
                        [ -6.89697266e-03,  -6.68334961e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.33361816e-02,  -1.35192871e-02],
                        [ -1.88293457e-02,  -1.90429688e-02],
                        [ -2.39562988e-02,  -2.40173340e-02],
                        [ -2.87170410e-02,  -2.85644531e-02],
                        [ -3.18908691e-02,  -3.16772461e-02],
                        [ -3.16467285e-02,  -3.15551758e-02],
                        [ -2.70996094e-02,  -2.71911621e-02],
                        [ -1.89208984e-02,  -1.91345215e-02],
                        [ -9.91821289e-03,  -1.00708008e-02],
                        [ -3.32641602e-03,  -3.26538086e-03],
                        [ -2.74658203e-04,  -6.10351562e-05],
                        [  6.10351562e-05,   2.44140625e-04],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -6.40869141e-04,  -8.23974609e-04],
                        [  6.34765625e-03,   6.16455078e-03],
                        [  2.08129883e-02,   2.07519531e-02],
                        [  3.76586914e-02,   3.78112793e-02],
                        [  5.23071289e-02,   5.25207520e-02],
                        [  6.58569336e-02,   6.59484863e-02],
                        [  8.30688477e-02,   8.29772949e-02],
                        [  1.05438232e-01,   1.05255127e-01],
                        [  1.25946045e-01,   1.25823975e-01],
                        [  1.31896973e-01,   1.31958008e-01],
                        [  1.11816406e-01,   1.11999512e-01],
                        [  5.82275391e-02,   5.83801270e-02],
                        [ -2.87475586e-02,  -2.87780762e-02],
                        [ -1.35833740e-01,  -1.36016846e-01],
                        [ -2.36175537e-01,  -2.36358643e-01],
                        [ -2.96783447e-01,  -2.96844482e-01],
                        [ -2.95928955e-01,  -2.95776367e-01],
                        [ -2.42614746e-01,  -2.42431641e-01],
                        [ -1.75262451e-01,  -1.75201416e-01],
                        [ -1.30615234e-01,  -1.30737305e-01],
                        [ -1.15356445e-01,  -1.15539551e-01],
                        [ -1.12121582e-01,  -1.12243652e-01],
                        [ -1.06170654e-01,  -1.06109619e-01],
                        [ -9.62219238e-02,  -9.60388184e-02],
                        [ -8.59680176e-02,  -8.58459473e-02],
                        [ -7.47985840e-02,  -7.48291016e-02],
                        [ -5.52368164e-02,  -5.53894043e-02],
                        [ -1.73339844e-02,  -1.74865723e-02],
                        [  4.16870117e-02,   4.16564941e-02],
                        [  1.10290527e-01,   1.10412598e-01],
                        [  1.64794922e-01,   1.64978027e-01],
                        [  1.81793213e-01,   1.81854248e-01],
                        [  1.53137207e-01,   1.53045654e-01],
                        [  9.23156738e-02,   9.21325684e-02],
                        [  2.85034180e-02,   2.84118652e-02],
                        [ -9.73510742e-03,  -9.67407227e-03],
                        [ -1.52587891e-02,  -1.51062012e-02],
                        [ -5.49316406e-03,  -5.37109375e-03],
                        [  7.93457031e-04,   7.62939453e-04],
                        [  4.08935547e-03,   3.93676758e-03],
                        [  1.48620605e-02,   1.47399902e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  4.51660156e-02,   4.53186035e-02],
                        [  4.28466797e-02,   4.30297852e-02],
                        [  2.76489258e-02,   2.76794434e-02],
                        [  9.24682617e-03,   9.12475586e-03],
                        [ -4.88281250e-04,  -6.71386719e-04],
                        [  5.58471680e-03,   5.49316406e-03],
                        [  2.55126953e-02,   2.55737305e-02],
                        [  5.18493652e-02,   5.20019531e-02],
                        [  7.77893066e-02,   7.78808594e-02],
                        [  9.70458984e-02,   9.70153809e-02],
                        [  1.01562500e-01,   1.01409912e-01],
                        [  8.82263184e-02,   8.81042480e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  5.48095703e-02,   5.49316406e-02],
                        [  5.34057617e-02,   5.35278320e-02],
                        [  5.24902344e-02,   5.25207520e-02],
                        [  4.46777344e-02,   4.45861816e-02],
                        [  3.43322754e-02,   3.41796875e-02],
                        [  2.72216797e-02,   2.71606445e-02],
                        [  2.25830078e-02,   2.26440430e-02],
                        [  1.87072754e-02,   1.88598633e-02],
                        [  1.69067383e-02,   1.69982910e-02],
                        [  1.62963867e-02,   1.62658691e-02],
                        [  1.42211914e-02,   1.40991211e-02],
                        [  1.27563477e-02,   1.26342773e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  2.38952637e-02,   2.40173340e-02],
                        [  2.94494629e-02,   2.95715332e-02],
                        [  3.15551758e-02,   3.15856934e-02],
                        [  3.32031250e-02,   3.30810547e-02],
                        [  3.61633301e-02,   3.60412598e-02],
                        [  3.92456055e-02,   3.91845703e-02],
                        [  3.91540527e-02,   3.92150879e-02],
                        [  3.28369141e-02,   3.29895020e-02],
                        [  2.13012695e-02,   2.13928223e-02],
                        [  1.00402832e-02,   1.00097656e-02],
                        [  2.86865234e-03,   2.74658203e-03],
                        [ -1.64794922e-03,  -1.73950195e-03],
                        [ -4.24194336e-03,  -4.21142578e-03],
                        [ -2.62451172e-03,  -2.50244141e-03],
                        [  1.03759766e-03,   1.15966797e-03],
                        [ -3.05175781e-05,   0.00000000e+00],
                        [ -7.14111328e-03,  -7.23266602e-03],
                        [ -1.42517090e-02,  -1.43737793e-02],
                        [ -1.74865723e-02,  -1.75476074e-02],
                        [ -1.99279785e-02,  -1.98669434e-02],
                        [ -2.46276855e-02,  -2.45056152e-02],
                        [ -2.81372070e-02,  -2.80761719e-02],
                        [ -2.69165039e-02,  -2.69470215e-02],
                        [ -2.45971680e-02,  -2.46887207e-02],
                        [ -2.59399414e-02,  -2.60314941e-02],
                        [ -2.90527344e-02,  -2.90222168e-02],
                        [ -3.03039551e-02,  -3.01818848e-02],
                        [ -3.21350098e-02,  -3.20434570e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.82177734e-02,  -4.83093262e-02],
                        [ -4.92553711e-02,  -4.93469238e-02],
                        [ -4.22058105e-02,  -4.22668457e-02],
                        [ -3.55224609e-02,  -3.54614258e-02],
                        [ -3.20129395e-02,  -3.18908691e-02],
                        [ -2.67639160e-02,  -2.67028809e-02],
                        [ -1.79443359e-02,  -1.80053711e-02],
                        [ -1.04980469e-02,  -1.06201172e-02],
                        [ -8.14819336e-03,  -8.20922852e-03],
                        [ -8.30078125e-03,  -8.27026367e-03],
                        [ -9.24682617e-03,  -9.15527344e-03],
                        [ -1.37023926e-02,  -1.36108398e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -2.53601074e-02,  -2.54211426e-02],
                        [ -2.18200684e-02,  -2.19116211e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.11083984e-02,  -1.10473633e-02],
                        [ -1.08032227e-02,  -1.07116699e-02],
                        [ -1.02233887e-02,  -1.01928711e-02],
                        [ -8.39233398e-03,  -8.42285156e-03],
                        [ -5.31005859e-03,  -5.40161133e-03],
                        [ -1.83105469e-04,  -2.44140625e-04],
                        [  6.71386719e-03,   6.74438477e-03],
                        [  1.36718750e-02,   1.37634277e-02],
                        [  1.85241699e-02,   1.85852051e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.64892578e-02,   2.63977051e-02],
                        [  4.00390625e-02,   3.99475098e-02],
                        [  6.17065430e-02,   6.16760254e-02],
                        [  8.67919922e-02,   8.68530273e-02],
                        [  1.11389160e-01,   1.11480713e-01],
                        [  1.30798340e-01,   1.30828857e-01],
                        [  1.34521484e-01,   1.34490967e-01],
                        [  1.11022949e-01,   1.10961914e-01],
                        [  5.62133789e-02,   5.61523438e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -1.28845215e-01,  -1.28753662e-01],
                        [ -2.27020264e-01,  -2.26959229e-01],
                        [ -2.88909912e-01,  -2.88909912e-01],
                        [ -2.92449951e-01,  -2.92510986e-01],
                        [ -2.46704102e-01,  -2.46765137e-01],
                        [ -1.87530518e-01,  -1.87561035e-01],
                        [ -1.46636963e-01,  -1.46606445e-01],
                        [ -1.28387451e-01,  -1.28295898e-01],
                        [ -1.18865967e-01,  -1.18835449e-01],
                        [ -1.07849121e-01,  -1.07879639e-01],
                        [ -9.43603516e-02,  -9.44519043e-02],
                        [ -7.90405273e-02,  -7.90710449e-02],
                        [ -6.11572266e-02,  -6.11267090e-02],
                        [ -4.00695801e-02,  -4.00085449e-02],
                        [ -1.29394531e-02,  -1.29089355e-02],
                        [  2.36816406e-02,   2.36511230e-02],
                        [  6.60705566e-02,   6.60095215e-02],
                        [  1.00738525e-01,   1.00708008e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.01196289e-01,   1.01257324e-01],
                        [  7.20520020e-02,   7.21130371e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  1.66015625e-02,   1.65710449e-02],
                        [  1.16882324e-02,   1.16271973e-02],
                        [  2.11486816e-02,   2.11181641e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  3.24096680e-02,   3.24707031e-02],
                        [  3.01513672e-02,   3.02124023e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  3.76892090e-02,   3.76281738e-02],
                        [  3.16467285e-02,   3.15856934e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  5.21850586e-03,   5.24902344e-03],
                        [  1.01013184e-02,   1.01623535e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  4.82482910e-02,   4.81872559e-02],
                        [  6.83593750e-02,   6.83288574e-02],
                        [  8.70056152e-02,   8.69750977e-02],
                        [  1.00006104e-01,   1.00036621e-01],
                        [  1.01684570e-01,   1.01745605e-01],
                        [  9.12780762e-02,   9.13085938e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  6.50024414e-02,   6.49719238e-02],
                        [  6.10656738e-02,   6.10351562e-02],
                        [  5.69458008e-02,   5.69763184e-02],
                        [  4.63867188e-02,   4.64172363e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  1.73950195e-02,   1.74255371e-02],
                        [  1.04064941e-02,   1.03759766e-02],
                        [  1.07116699e-02,   1.06811523e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.88293457e-02,   1.88598633e-02],
                        [  1.86157227e-02,   1.86462402e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  2.30407715e-02,   2.30102539e-02],
                        [  2.91442871e-02,   2.91137695e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  3.52478027e-02,   3.52783203e-02],
                        [  3.35083008e-02,   3.35388184e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  2.49023438e-02,   2.48718262e-02],
                        [  2.14233398e-02,   2.13928223e-02],
                        [  1.69982910e-02,   1.69677734e-02],
                        [  1.14135742e-02,   1.14440918e-02],
                        [  6.25610352e-03,   6.28662109e-03],
                        [  2.19726562e-03,   2.22778320e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -6.40869141e-03,  -6.43920898e-03],
                        [ -9.12475586e-03,  -9.15527344e-03],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -4.30297852e-03,  -4.27246094e-03],
                        [ -4.05883789e-03,  -4.02832031e-03],
                        [ -1.03149414e-02,  -1.02844238e-02],
                        [ -2.00195312e-02,  -2.00500488e-02],
                        [ -2.59704590e-02,  -2.60009766e-02],
                        [ -2.56958008e-02,  -2.57263184e-02],
                        [ -2.38647461e-02,  -2.38342285e-02],
                        [ -2.46887207e-02,  -2.46582031e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -4.01611328e-02,  -4.01916504e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.29687500e-02,  -4.29382324e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.07824707e-02,  -2.08129883e-02],
                        [ -1.26647949e-02,  -1.26953125e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.66625977e-02,  -1.66320801e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -2.96020508e-03,  -2.99072266e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [ -1.15966797e-03,  -1.12915039e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  4.97436523e-03,   4.94384766e-03],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  6.75048828e-02,   6.75048828e-02],
                        [  8.28552246e-02,   8.28247070e-02],
                        [  1.03118896e-01,   1.03118896e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.13555908e-01,   1.13555908e-01],
                        [  8.69750977e-02,   8.70056152e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -1.39404297e-01,  -1.39404297e-01],
                        [ -2.31811523e-01,  -2.31811523e-01],
                        [ -2.83721924e-01,  -2.83691406e-01],
                        [ -2.79052734e-01,  -2.79052734e-01],
                        [ -2.30987549e-01,  -2.30987549e-01],
                        [ -1.71905518e-01,  -1.71905518e-01],
                        [ -1.30767822e-01,  -1.30798340e-01],
                        [ -1.12915039e-01,  -1.12915039e-01],
                        [ -1.02752686e-01,  -1.02752686e-01],
                        [ -8.78906250e-02,  -8.78906250e-02],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -5.34973145e-02,  -5.35278320e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  5.37414551e-02,   5.37414551e-02],
                        [  6.62231445e-02,   6.62231445e-02],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  7.06481934e-02,   7.06481934e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  4.29077148e-02,   4.29382324e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  6.22863770e-02,   6.22863770e-02],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  1.06018066e-01,   1.06018066e-01],
                        [  1.18438721e-01,   1.18438721e-01],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.95410156e-02,   2.95410156e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  1.19171143e-01,   1.19171143e-01],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  9.57031250e-02,   9.57031250e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -1.38366699e-01,  -1.38366699e-01],
                        [ -2.26348877e-01,  -2.26348877e-01],
                        [ -2.78289795e-01,  -2.78289795e-01],
                        [ -2.79357910e-01,  -2.79357910e-01],
                        [ -2.35321045e-01,  -2.35321045e-01],
                        [ -1.75415039e-01,  -1.75415039e-01],
                        [ -1.32537842e-01,  -1.32537842e-01],
                        [ -1.12854004e-01,  -1.12854004e-01],
                        [ -9.70153809e-02,  -9.70153809e-02],
                        [ -7.27233887e-02,  -7.27233887e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.06140137e-01,   1.06140137e-01],
                        [  9.97924805e-02,   9.97924805e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  9.95788574e-02,   9.95788574e-02],
                        [  1.01287842e-01,   1.01287842e-01],
                        [  9.71984863e-02,   9.71984863e-02],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  3.05175781e-03,   3.05175781e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  5.08117676e-02,   5.08117676e-02],
                        [  7.06787109e-02,   7.06787109e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.20697021e-01,   1.20697021e-01],
                        [  1.32568359e-01,   1.32568359e-01],
                        [  1.25671387e-01,   1.25671387e-01],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -2.15026855e-01,  -2.15026855e-01],
                        [ -2.74902344e-01,  -2.74902344e-01],
                        [ -2.78228760e-01,  -2.78228760e-01],
                        [ -2.28942871e-01,  -2.28942871e-01],
                        [ -1.61834717e-01,  -1.61834717e-01],
                        [ -1.11083984e-01,  -1.11083984e-01],
                        [ -8.55712891e-02,  -8.55712891e-02],
                        [ -7.31201172e-02,  -7.31201172e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -8.19702148e-02,  -8.19702148e-02],
                        [ -1.02172852e-01,  -1.02172852e-01],
                        [ -1.09497070e-01,  -1.09497070e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  1.04553223e-01,   1.04553223e-01],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.06286621e-02,   5.06286621e-02],
                        [  5.08117676e-02,   5.08117676e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  1.23870850e-01,   1.23870850e-01],
                        [  1.20361328e-01,   1.20361328e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  4.68444824e-02,   4.68444824e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -1.28875732e-01,  -1.28875732e-01],
                        [ -2.07489014e-01,  -2.07489014e-01],
                        [ -2.53997803e-01,  -2.53997803e-01],
                        [ -2.56011963e-01,  -2.56011963e-01],
                        [ -2.15972900e-01,  -2.15972900e-01],
                        [ -1.57379150e-01,  -1.57379150e-01],
                        [ -1.10443115e-01,  -1.10443115e-01],
                        [ -8.63037109e-02,  -8.63037109e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -1.14044189e-01,  -1.14044189e-01],
                        [ -1.44256592e-01,  -1.44256592e-01],
                        [ -1.52038574e-01,  -1.52038574e-01],
                        [ -1.27136230e-01,  -1.27136230e-01],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  1.14959717e-01,   1.14959717e-01],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  8.38623047e-02,   8.38623047e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  6.75048828e-02,   6.75048828e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  5.77392578e-02,   5.77392578e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  1.07269287e-01,   1.07269287e-01],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  6.86950684e-02,   6.86950684e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  3.69567871e-02,   3.69567871e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  6.79321289e-02,   6.79321289e-02],
                        [  7.34863281e-02,   7.34863281e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  1.07879639e-01,   1.07879639e-01],
                        [  1.28387451e-01,   1.28387451e-01],
                        [  1.32934570e-01,   1.32934570e-01],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  6.04858398e-02,   6.04858398e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.08520508e-01,  -1.08520508e-01],
                        [ -1.95190430e-01,  -1.95190430e-01],
                        [ -2.54699707e-01,  -2.54699707e-01],
                        [ -2.70172119e-01,  -2.70172119e-01],
                        [ -2.40936279e-01,  -2.40936279e-01],
                        [ -1.86676025e-01,  -1.86676025e-01],
                        [ -1.33270264e-01,  -1.33270264e-01],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -1.40380859e-01,  -1.40380859e-01],
                        [ -1.62292480e-01,  -1.62292480e-01],
                        [ -1.58203125e-01,  -1.58203125e-01],
                        [ -1.23077393e-01,  -1.23077393e-01],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.40686035e-01,   1.40686035e-01],
                        [  1.25427246e-01,   1.25427246e-01],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  5.35583496e-02,   5.35583496e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  8.80737305e-02,   8.80737305e-02],
                        [  1.07421875e-01,   1.07421875e-01],
                        [  1.25488281e-01,   1.25488281e-01],
                        [  1.33819580e-01,   1.33819580e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  5.19104004e-02,   5.19104004e-02],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  5.80139160e-02,   5.80139160e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  1.14593506e-01,   1.14593506e-01],
                        [  1.35070801e-01,   1.35070801e-01],
                        [  1.40563965e-01,   1.40563965e-01],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  6.63452148e-02,   6.63452148e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.11663818e-01,  -1.11663818e-01],
                        [ -2.06176758e-01,  -2.06176758e-01],
                        [ -2.69622803e-01,  -2.69622803e-01],
                        [ -2.81066895e-01,  -2.81066895e-01],
                        [ -2.40814209e-01,  -2.40814209e-01],
                        [ -1.73126221e-01,  -1.73126221e-01],
                        [ -1.10717773e-01,  -1.10717773e-01],
                        [ -7.19299316e-02,  -7.19299316e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -1.07849121e-01,  -1.07849121e-01],
                        [ -1.60583496e-01,  -1.60583496e-01],
                        [ -1.95983887e-01,  -1.95983887e-01],
                        [ -1.99310303e-01,  -1.99310303e-01],
                        [ -1.71844482e-01,  -1.71844482e-01],
                        [ -1.23504639e-01,  -1.23504639e-01],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  7.41271973e-02,   7.41271973e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  1.05651855e-01,   1.05651855e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  1.26403809e-01,   1.26403809e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.23321533e-01,   1.23321533e-01],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  1.11999512e-01,   1.11999512e-01],
                        [  1.37695312e-01,   1.37695312e-01],
                        [  1.48803711e-01,   1.48803711e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  8.82568359e-02,   8.82568359e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -8.48388672e-02,  -8.48388672e-02],
                        [ -1.87408447e-01,  -1.87408447e-01],
                        [ -2.63214111e-01,  -2.63214111e-01],
                        [ -2.84454346e-01,  -2.84454346e-01],
                        [ -2.46582031e-01,  -2.46582031e-01],
                        [ -1.73034668e-01,  -1.73034668e-01],
                        [ -9.97009277e-02,  -9.97009277e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -8.57238770e-02,  -8.57238770e-02],
                        [ -1.34277344e-01,  -1.34277344e-01],
                        [ -1.82678223e-01,  -1.82678223e-01],
                        [ -2.12463379e-01,  -2.12463379e-01],
                        [ -2.09503174e-01,  -2.09503174e-01],
                        [ -1.74743652e-01,  -1.74743652e-01],
                        [ -1.25305176e-01,  -1.25305176e-01],
                        [ -7.82775879e-02,  -7.82775879e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  1.14776611e-01,   1.14776611e-01],
                        [  1.42150879e-01,   1.42150879e-01],
                        [  1.39343262e-01,   1.39343262e-01],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  8.63342285e-02,   8.63342285e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  7.25708008e-02,   7.25708008e-02],
                        [  7.58361816e-02,   7.58361816e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.46209717e-01,   1.46209717e-01],
                        [  1.42730713e-01,   1.42730713e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  7.27233887e-02,   7.27233887e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  9.76562500e-04,   9.76562500e-04],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.51397705e-01,   1.51397705e-01],
                        [  1.60156250e-01,   1.60156250e-01],
                        [  1.41998291e-01,   1.41998291e-01],
                        [  9.38415527e-02,   9.38415527e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [ -8.72802734e-02,  -8.72802734e-02],
                        [ -1.91711426e-01,  -1.91711426e-01],
                        [ -2.64556885e-01,  -2.64556885e-01],
                        [ -2.79083252e-01,  -2.79083252e-01],
                        [ -2.34710693e-01,  -2.34710693e-01],
                        [ -1.59576416e-01,  -1.59576416e-01],
                        [ -9.14916992e-02,  -9.14916992e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -7.22656250e-02,  -7.22656250e-02],
                        [ -1.13494873e-01,  -1.13494873e-01],
                        [ -1.63146973e-01,  -1.63146973e-01],
                        [ -2.04223633e-01,  -2.04223633e-01],
                        [ -2.21008301e-01,  -2.21008301e-01],
                        [ -2.08038330e-01,  -2.08038330e-01],
                        [ -1.72119141e-01,  -1.72119141e-01],
                        [ -1.26281738e-01,  -1.26281738e-01],
                        [ -8.09020996e-02,  -8.09020996e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  1.06140137e-01,   1.06140137e-01],
                        [  1.41052246e-01,   1.41052246e-01],
                        [  1.53533936e-01,   1.53533936e-01],
                        [  1.42517090e-01,   1.42517090e-01],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  9.73205566e-02,   9.73205566e-02],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  9.56115723e-02,   9.56115723e-02],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  1.35589600e-01,   1.35589600e-01],
                        [  1.49536133e-01,   1.49536133e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  7.70568848e-02,   7.70568848e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  8.14819336e-03,   8.14819336e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  7.86437988e-02,   7.86437988e-02],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  1.42333984e-01,   1.42333984e-01],
                        [  1.46209717e-01,   1.46209717e-01],
                        [  1.24755859e-01,   1.24755859e-01],
                        [  7.49816895e-02,   7.49816895e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -9.26208496e-02,  -9.26208496e-02],
                        [ -1.84539795e-01,  -1.84539795e-01],
                        [ -2.49481201e-01,  -2.49481201e-01],
                        [ -2.62176514e-01,  -2.62176514e-01],
                        [ -2.19696045e-01,  -2.19696045e-01],
                        [ -1.51000977e-01,  -1.51000977e-01],
                        [ -9.61608887e-02,  -9.61608887e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -7.76367188e-02,  -7.76367188e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -1.09283447e-01,  -1.09283447e-01],
                        [ -1.38336182e-01,  -1.38336182e-01],
                        [ -1.71783447e-01,  -1.71783447e-01],
                        [ -1.92718506e-01,  -1.92718506e-01],
                        [ -1.89636230e-01,  -1.89636230e-01],
                        [ -1.68243408e-01,  -1.68243408e-01],
                        [ -1.42059326e-01,  -1.42059326e-01],
                        [ -1.17156982e-01,  -1.17156982e-01],
                        [ -9.03625488e-02,  -9.03625488e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  1.22558594e-01,   1.22558594e-01],
                        [  1.45660400e-01,   1.45660400e-01],
                        [  1.45904541e-01,   1.45904541e-01],
                        [  1.29852295e-01,   1.29852295e-01],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  1.13220215e-01,   1.13220215e-01],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.40167236e-01,   1.40167236e-01],
                        [  1.44500732e-01,   1.44500732e-01],
                        [  1.36444092e-01,   1.36444092e-01],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -4.10766602e-02,  -4.10766602e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  7.06787109e-02,   7.06787109e-02],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  1.58386230e-01,   1.58386230e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  7.20520020e-02,   7.20520020e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -9.93652344e-02,  -9.93652344e-02],
                        [ -1.88323975e-01,  -1.88323975e-01],
                        [ -2.44506836e-01,  -2.44506836e-01],
                        [ -2.47100830e-01,  -2.47100830e-01],
                        [ -2.00164795e-01,  -2.00164795e-01],
                        [ -1.33483887e-01,  -1.33483887e-01],
                        [ -8.29467773e-02,  -8.29467773e-02],
                        [ -6.85729980e-02,  -6.85729980e-02],
                        [ -8.74938965e-02,  -8.74938965e-02],
                        [ -1.23992920e-01,  -1.23992920e-01],
                        [ -1.62048340e-01,  -1.62048340e-01],
                        [ -1.89056396e-01,  -1.89056396e-01],
                        [ -1.94976807e-01,  -1.94976807e-01],
                        [ -1.77429199e-01,  -1.77429199e-01],
                        [ -1.46881104e-01,  -1.46881104e-01],
                        [ -1.19812012e-01,  -1.19812012e-01],
                        [ -1.04614258e-01,  -1.04614258e-01],
                        [ -9.61303711e-02,  -9.61303711e-02],
                        [ -8.37402344e-02,  -8.37402344e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  1.50238037e-01,   1.50238037e-01],
                        [  1.60552979e-01,   1.60552979e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.20666504e-01,   1.20666504e-01],
                        [  1.03302002e-01,   1.03302002e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  1.15905762e-01,   1.15905762e-01],
                        [  1.39495850e-01,   1.39495850e-01],
                        [  1.57867432e-01,   1.57867432e-01],
                        [  1.61254883e-01,   1.61254883e-01],
                        [  1.48590088e-01,   1.48590088e-01],
                        [  1.24145508e-01,   1.24145508e-01],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  5.44738770e-02,   5.44738770e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [ -3.05175781e-05,   0.00000000e+00],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -6.32324219e-02,  -6.32324219e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.19714355e-02,  -5.19714355e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.02526855e-02,  -4.02832031e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.43432617e-01,   1.43432617e-01],
                        [  1.48773193e-01,   1.48742676e-01],
                        [  1.28967285e-01,   1.28967285e-01],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  3.20434570e-03,   3.20434570e-03],
                        [ -8.85925293e-02,  -8.85925293e-02],
                        [ -1.76513672e-01,  -1.76513672e-01],
                        [ -2.34893799e-01,  -2.34893799e-01],
                        [ -2.42858887e-01,  -2.42858887e-01],
                        [ -2.01812744e-01,  -2.01812744e-01],
                        [ -1.40686035e-01,  -1.40686035e-01],
                        [ -9.76257324e-02,  -9.76257324e-02],
                        [ -9.30175781e-02,  -9.30175781e-02],
                        [ -1.19567871e-01,  -1.19567871e-01],
                        [ -1.55181885e-01,  -1.55181885e-01],
                        [ -1.81732178e-01,  -1.81732178e-01],
                        [ -1.91223145e-01,  -1.91223145e-01],
                        [ -1.82250977e-01,  -1.82250977e-01],
                        [ -1.58660889e-01,  -1.58660889e-01],
                        [ -1.29608154e-01,  -1.29608154e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -9.08508301e-02,  -9.08508301e-02],
                        [ -8.53576660e-02,  -8.53576660e-02],
                        [ -8.16345215e-02,  -8.16345215e-02],
                        [ -7.14416504e-02,  -7.14416504e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  9.54895020e-02,   9.54895020e-02],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  1.68029785e-01,   1.68029785e-01],
                        [  1.58325195e-01,   1.58325195e-01],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  1.16912842e-01,   1.16912842e-01],
                        [  1.08093262e-01,   1.08093262e-01],
                        [  1.06292725e-01,   1.06292725e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  1.21368408e-01,   1.21368408e-01],
                        [  1.37512207e-01,   1.37512207e-01],
                        [  1.53717041e-01,   1.53717041e-01],
                        [  1.64001465e-01,   1.64001465e-01],
                        [  1.64855957e-01,   1.64855957e-01],
                        [  1.55456543e-01,   1.55456543e-01],
                        [  1.36444092e-01,   1.36444092e-01],
                        [  1.11511230e-01,   1.11480713e-01],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  2.68554688e-02,   2.68249512e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.95410156e-02,  -2.95715332e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -7.23571777e-02,  -7.23571777e-02],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -5.41076660e-02,  -5.41076660e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -3.08227539e-02,  -3.07922363e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  1.10717773e-01,   1.10717773e-01],
                        [  1.34185791e-01,   1.34185791e-01],
                        [  1.49383545e-01,   1.49383545e-01],
                        [  1.49047852e-01,   1.49047852e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  7.52868652e-02,   7.52868652e-02],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -1.69342041e-01,  -1.69342041e-01],
                        [ -2.18109131e-01,  -2.18109131e-01],
                        [ -2.19512939e-01,  -2.19512939e-01],
                        [ -1.79840088e-01,  -1.79840088e-01],
                        [ -1.30737305e-01,  -1.30737305e-01],
                        [ -1.07727051e-01,  -1.07727051e-01],
                        [ -1.22558594e-01,  -1.22558594e-01],
                        [ -1.59484863e-01,  -1.59484863e-01],
                        [ -1.92779541e-01,  -1.92779541e-01],
                        [ -2.04559326e-01,  -2.04589844e-01],
                        [ -1.92108154e-01,  -1.92108154e-01],
                        [ -1.64916992e-01,  -1.64916992e-01],
                        [ -1.36077881e-01,  -1.36077881e-01],
                        [ -1.14471436e-01,  -1.14471436e-01],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -9.46044922e-02,  -9.46044922e-02],
                        [ -8.76159668e-02,  -8.76159668e-02],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [  9.27429199e-02,   9.27429199e-02],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.66320801e-01,   1.66320801e-01],
                        [  1.64550781e-01,   1.64550781e-01],
                        [  1.47247314e-01,   1.47247314e-01],
                        [  1.27471924e-01,   1.27471924e-01],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  1.14959717e-01,   1.14990234e-01],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  1.42639160e-01,   1.42639160e-01],
                        [  1.57196045e-01,   1.57196045e-01],
                        [  1.68731689e-01,   1.68731689e-01],
                        [  1.73004150e-01,   1.73004150e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.44561768e-01,   1.44561768e-01],
                        [  1.24847412e-01,   1.24847412e-01],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [ -9.15527344e-04,  -8.85009766e-04],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -5.41381836e-02,  -5.41076660e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -4.36706543e-02,  -4.37011719e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -2.04162598e-02,  -2.03857422e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.89208984e-03,  -1.92260742e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  7.37915039e-02,   7.37915039e-02],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  1.09191895e-01,   1.09191895e-01],
                        [  1.34460449e-01,   1.34429932e-01],
                        [  1.51702881e-01,   1.51702881e-01],
                        [  1.50054932e-01,   1.50085449e-01],
                        [  1.24206543e-01,   1.24206543e-01],
                        [  7.03735352e-02,   7.03735352e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.00891113e-01,  -1.00891113e-01],
                        [ -1.77581787e-01,  -1.77581787e-01],
                        [ -2.18536377e-01,  -2.18536377e-01],
                        [ -2.15484619e-01,  -2.15484619e-01],
                        [ -1.79962158e-01,  -1.79962158e-01],
                        [ -1.43493652e-01,  -1.43493652e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -1.71600342e-01,  -1.71600342e-01],
                        [ -2.17132568e-01,  -2.17132568e-01],
                        [ -2.42370605e-01,  -2.42370605e-01],
                        [ -2.33276367e-01,  -2.33276367e-01],
                        [ -1.99798584e-01,  -1.99798584e-01],
                        [ -1.60522461e-01,  -1.60522461e-01],
                        [ -1.27593994e-01,  -1.27593994e-01],
                        [ -1.02935791e-01,  -1.02905273e-01],
                        [ -8.20617676e-02,  -8.20617676e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  6.14013672e-02,   6.14013672e-02],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.49169922e-01,   1.49169922e-01],
                        [  1.64672852e-01,   1.64672852e-01],
                        [  1.57073975e-01,   1.57073975e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.18988037e-01,   1.18988037e-01],
                        [  1.15814209e-01,   1.15814209e-01],
                        [  1.31195068e-01,   1.31195068e-01],
                        [  1.57196045e-01,   1.57196045e-01],
                        [  1.79473877e-01,   1.79473877e-01],
                        [  1.89056396e-01,   1.89056396e-01],
                        [  1.86981201e-01,   1.86981201e-01],
                        [  1.76269531e-01,   1.76269531e-01],
                        [  1.56005859e-01,   1.56005859e-01],
                        [  1.26770020e-01,   1.26770020e-01],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  6.89086914e-02,   6.88781738e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  5.30090332e-02,   5.30090332e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  7.78198242e-03,   7.75146484e-03],
                        [  4.08935547e-03,   4.05883789e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.25427246e-02,   1.25732422e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  1.76696777e-02,   1.77001953e-02],
                        [  5.82885742e-03,   5.82885742e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -5.89294434e-02,  -5.89294434e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -6.69250488e-02,  -6.69555664e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  3.27148438e-02,   3.27453613e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  7.70568848e-02,   7.70568848e-02],
                        [  1.01959229e-01,   1.01959229e-01],
                        [  1.30798340e-01,   1.30798340e-01],
                        [  1.53442383e-01,   1.53442383e-01],
                        [  1.57745361e-01,   1.57745361e-01],
                        [  1.37481689e-01,   1.37481689e-01],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -1.34246826e-01,  -1.34246826e-01],
                        [ -2.01080322e-01,  -2.01080322e-01],
                        [ -2.30682373e-01,  -2.30712891e-01],
                        [ -2.24670410e-01,  -2.24670410e-01],
                        [ -2.08770752e-01,  -2.08770752e-01],
                        [ -2.07031250e-01,  -2.07061768e-01],
                        [ -2.18750000e-01,  -2.18750000e-01],
                        [ -2.25494385e-01,  -2.25463867e-01],
                        [ -2.13623047e-01,  -2.13623047e-01],
                        [ -1.84478760e-01,  -1.84478760e-01],
                        [ -1.50238037e-01,  -1.50238037e-01],
                        [ -1.24633789e-01,  -1.24633789e-01],
                        [ -1.12365723e-01,  -1.12365723e-01],
                        [ -1.04370117e-01,  -1.04370117e-01],
                        [ -8.86840820e-02,  -8.86535645e-02],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -1.83410645e-02,  -1.83105469e-02],
                        [  4.48608398e-03,   4.51660156e-03],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  1.21917725e-01,   1.21917725e-01],
                        [  1.49505615e-01,   1.49505615e-01],
                        [  1.56341553e-01,   1.56341553e-01],
                        [  1.51000977e-01,   1.51031494e-01],
                        [  1.46789551e-01,   1.46820068e-01],
                        [  1.53900146e-01,   1.53869629e-01],
                        [  1.74377441e-01,   1.74346924e-01],
                        [  1.98883057e-01,   1.98883057e-01],
                        [  2.12615967e-01,   2.12615967e-01],
                        [  2.08038330e-01,   2.08038330e-01],
                        [  1.89300537e-01,   1.89300537e-01],
                        [  1.64642334e-01,   1.64672852e-01],
                        [  1.39709473e-01,   1.39709473e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  5.08117676e-02,   5.07812500e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.71301270e-02,   2.70996094e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.19421387e-02,   2.19726562e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  5.18798828e-03,   5.18798828e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  3.03649902e-02,   3.03955078e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -2.30712891e-02,  -2.30407715e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.82482910e-02,  -4.82788086e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -6.39648438e-02,  -6.39648438e-02],
                        [ -6.79626465e-02,  -6.79931641e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -5.76782227e-02,  -5.76477051e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.39343262e-02,  -6.39343262e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -5.15747070e-02,  -5.15441895e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  1.27258301e-02,   1.26953125e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.65405273e-02,   1.65710449e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  1.03546143e-01,   1.03546143e-01],
                        [  1.35986328e-01,   1.35986328e-01],
                        [  1.61437988e-01,   1.61437988e-01],
                        [  1.71051025e-01,   1.71051025e-01],
                        [  1.58843994e-01,   1.58843994e-01],
                        [  1.19140625e-01,   1.19140625e-01],
                        [  4.87976074e-02,   4.87976074e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -1.40625000e-01,  -1.40594482e-01],
                        [ -2.17315674e-01,  -2.17315674e-01],
                        [ -2.61322021e-01,  -2.61322021e-01],
                        [ -2.73468018e-01,  -2.73437500e-01],
                        [ -2.65472412e-01,  -2.65472412e-01],
                        [ -2.51312256e-01,  -2.51312256e-01],
                        [ -2.37548828e-01,  -2.37548828e-01],
                        [ -2.19940186e-01,  -2.19940186e-01],
                        [ -1.91528320e-01,  -1.91528320e-01],
                        [ -1.55731201e-01,  -1.55731201e-01],
                        [ -1.26129150e-01,  -1.26129150e-01],
                        [ -1.09985352e-01,  -1.09985352e-01],
                        [ -9.86022949e-02,  -9.86022949e-02],
                        [ -8.13293457e-02,  -8.12988281e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  9.41772461e-02,   9.41772461e-02],
                        [  1.26831055e-01,   1.26800537e-01],
                        [  1.52587891e-01,   1.52618408e-01],
                        [  1.67053223e-01,   1.67053223e-01],
                        [  1.70898438e-01,   1.70867920e-01],
                        [  1.72363281e-01,   1.72393799e-01],
                        [  1.78985596e-01,   1.78985596e-01],
                        [  1.89483643e-01,   1.89483643e-01],
                        [  1.96166992e-01,   1.96166992e-01],
                        [  1.93908691e-01,   1.93939209e-01],
                        [  1.84387207e-01,   1.84356689e-01],
                        [  1.70104980e-01,   1.70104980e-01],
                        [  1.50482178e-01,   1.50512695e-01],
                        [  1.26464844e-01,   1.26464844e-01],
                        [  1.02111816e-01,   1.02111816e-01],
                        [  7.94067383e-02,   7.94372559e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  1.35192871e-02,   1.34887695e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.23083496e-02,   2.22778320e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  1.30310059e-02,   1.30615234e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -2.00500488e-02,  -2.00805664e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -7.27844238e-02,  -7.27844238e-02],
                        [ -7.62634277e-02,  -7.62634277e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.81457520e-02,  -6.81152344e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -6.37512207e-02,  -6.37207031e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -4.82177734e-03,  -4.85229492e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  1.06811523e-03,   1.03759766e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.52893066e-02,  -1.52587891e-02],
                        [ -1.93176270e-02,  -1.93481445e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.47192383e-03,  -2.44140625e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  5.13305664e-02,   5.13000488e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  7.69348145e-02,   7.69653320e-02],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  1.32751465e-01,   1.32751465e-01],
                        [  1.64642334e-01,   1.64642334e-01],
                        [  1.88629150e-01,   1.88629150e-01],
                        [  1.93267822e-01,   1.93267822e-01],
                        [  1.63909912e-01,   1.63909912e-01],
                        [  9.28344727e-02,   9.28344727e-02],
                        [ -1.17797852e-02,  -1.18103027e-02],
                        [ -1.29516602e-01,  -1.29516602e-01],
                        [ -2.36022949e-01,  -2.36022949e-01],
                        [ -3.08288574e-01,  -3.08288574e-01],
                        [ -3.32244873e-01,  -3.32244873e-01],
                        [ -3.13598633e-01,  -3.13598633e-01],
                        [ -2.74658203e-01,  -2.74658203e-01],
                        [ -2.35595703e-01,  -2.35595703e-01],
                        [ -2.01599121e-01,  -2.01599121e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -1.41815186e-01,  -1.41815186e-01],
                        [ -1.22558594e-01,  -1.22558594e-01],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -1.00982666e-01,  -1.00982666e-01],
                        [ -8.42590332e-02,  -8.42590332e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  2.34069824e-02,   2.34375000e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  1.41662598e-01,   1.41662598e-01],
                        [  1.74652100e-01,   1.74652100e-01],
                        [  1.92352295e-01,   1.92321777e-01],
                        [  2.00836182e-01,   2.00836182e-01],
                        [  2.08099365e-01,   2.08099365e-01],
                        [  2.15332031e-01,   2.15301514e-01],
                        [  2.15423584e-01,   2.15423584e-01],
                        [  2.02453613e-01,   2.02453613e-01],
                        [  1.81091309e-01,   1.81091309e-01],
                        [  1.61743164e-01,   1.61743164e-01],
                        [  1.47888184e-01,   1.47888184e-01],
                        [  1.34948730e-01,   1.34948730e-01],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.00677490e-01,   1.00677490e-01],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  6.21032715e-02,   6.21337891e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.92260742e-03,   1.95312500e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  7.56835938e-03,   7.53784180e-03],
                        [  1.22375488e-02,   1.22680664e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  2.46887207e-02,   2.46582031e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.09252930e-02,  -1.09558105e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.64282227e-02,  -2.64587402e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -7.45849609e-02,  -7.45849609e-02],
                        [ -8.19396973e-02,  -8.19396973e-02],
                        [ -8.68835449e-02,  -8.68835449e-02],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -7.36083984e-02,  -7.36083984e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.77307129e-02,  -1.77612305e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  9.26513672e-02,   9.26513672e-02],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.70135498e-01,   1.70135498e-01],
                        [  2.01599121e-01,   2.01599121e-01],
                        [  2.04711914e-01,   2.04711914e-01],
                        [  1.71447754e-01,   1.71478271e-01],
                        [  1.00250244e-01,   1.00250244e-01],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -1.39739990e-01,  -1.39739990e-01],
                        [ -2.71087646e-01,  -2.71087646e-01],
                        [ -3.63952637e-01,  -3.63952637e-01],
                        [ -3.90106201e-01,  -3.90106201e-01],
                        [ -3.52691650e-01,  -3.52691650e-01],
                        [ -2.84820557e-01,  -2.84790039e-01],
                        [ -2.21527100e-01,  -2.21527100e-01],
                        [ -1.78039551e-01,  -1.78039551e-01],
                        [ -1.51977539e-01,  -1.51977539e-01],
                        [ -1.34887695e-01,  -1.34887695e-01],
                        [ -1.19110107e-01,  -1.19110107e-01],
                        [ -1.02172852e-01,  -1.02172852e-01],
                        [ -8.82263184e-02,  -8.82568359e-02],
                        [ -8.11767578e-02,  -8.11767578e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [  1.56555176e-02,   1.56250000e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  1.20300293e-01,   1.20330811e-01],
                        [  1.74468994e-01,   1.74468994e-01],
                        [  2.17834473e-01,   2.17834473e-01],
                        [  2.45758057e-01,   2.45788574e-01],
                        [  2.55218506e-01,   2.55218506e-01],
                        [  2.48870850e-01,   2.48840332e-01],
                        [  2.33978271e-01,   2.34008789e-01],
                        [  2.14874268e-01,   2.14874268e-01],
                        [  1.91467285e-01,   1.91467285e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.45507812e-01,   1.45507812e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  1.16271973e-01,   1.16271973e-01],
                        [  9.75036621e-02,   9.75341797e-02],
                        [  7.80944824e-02,   7.80944824e-02],
                        [  6.18286133e-02,   6.17980957e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  3.17687988e-02,   3.17993164e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  1.23291016e-02,   1.23596191e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.84936523e-02,   1.85241699e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  2.07519531e-03,   2.07519531e-03],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.43432617e-02,  -1.43737793e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -5.84716797e-02,  -5.84411621e-02],
                        [ -5.68237305e-02,  -5.68237305e-02],
                        [ -5.32531738e-02,  -5.32836914e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -6.32324219e-02,  -6.32629395e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -7.89489746e-02,  -7.89489746e-02],
                        [ -7.57141113e-02,  -7.57446289e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -3.63769531e-02,  -3.63464355e-02],
                        [ -2.49328613e-02,  -2.49023438e-02],
                        [ -1.82495117e-02,  -1.82800293e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.40991211e-02,  -1.40686035e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.72119141e-02,  -1.72424316e-02],
                        [ -2.24914551e-02,  -2.24609375e-02],
                        [ -2.55737305e-02,  -2.55432129e-02],
                        [ -2.19116211e-02,  -2.19421387e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -9.18579102e-03,  -9.15527344e-03],
                        [ -4.36401367e-03,  -4.39453125e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  1.25823975e-01,   1.25854492e-01],
                        [  1.60705566e-01,   1.60675049e-01],
                        [  1.90979004e-01,   1.90979004e-01],
                        [  1.99188232e-01,   1.99188232e-01],
                        [  1.70166016e-01,   1.70166016e-01],
                        [  9.65576172e-02,   9.65270996e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.65985107e-01,  -1.65954590e-01],
                        [ -3.05633545e-01,  -3.05664062e-01],
                        [ -3.95324707e-01,  -3.95355225e-01],
                        [ -4.09362793e-01,  -4.09332275e-01],
                        [ -3.57788086e-01,  -3.57788086e-01],
                        [ -2.76397705e-01,  -2.76397705e-01],
                        [ -2.03094482e-01,  -2.03094482e-01],
                        [ -1.58294678e-01,  -1.58294678e-01],
                        [ -1.37268066e-01,  -1.37298584e-01],
                        [ -1.21124268e-01,  -1.21124268e-01],
                        [ -9.87854004e-02,  -9.87854004e-02],
                        [ -7.56835938e-02,  -7.57141113e-02],
                        [ -6.19506836e-02,  -6.19812012e-02],
                        [ -5.79223633e-02,  -5.78918457e-02],
                        [ -5.29174805e-02,  -5.29174805e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [  8.45336914e-03,   8.48388672e-03],
                        [  9.24682617e-03,   9.21630859e-03],
                        [ -7.93457031e-03,  -7.96508789e-03],
                        [ -3.16467285e-02,  -3.16162109e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  1.06872559e-01,   1.06903076e-01],
                        [  1.81457520e-01,   1.81457520e-01],
                        [  2.43591309e-01,   2.43560791e-01],
                        [  2.74078369e-01,   2.74078369e-01],
                        [  2.71148682e-01,   2.71148682e-01],
                        [  2.52136230e-01,   2.52136230e-01],
                        [  2.34527588e-01,   2.34527588e-01],
                        [  2.20275879e-01,   2.20275879e-01],
                        [  2.03155518e-01,   2.03155518e-01],
                        [  1.81640625e-01,   1.81640625e-01],
                        [  1.58111572e-01,   1.58111572e-01],
                        [  1.33483887e-01,   1.33483887e-01],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  8.94775391e-02,   8.94775391e-02],
                        [  7.35473633e-02,   7.35473633e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -1.41601562e-02,  -1.41296387e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -8.34655762e-02,  -8.34655762e-02],
                        [ -8.68225098e-02,  -8.68225098e-02],
                        [ -8.64562988e-02,  -8.64257812e-02],
                        [ -8.14819336e-02,  -8.14819336e-02],
                        [ -7.37609863e-02,  -7.37915039e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.68859863e-02,  -2.69165039e-02],
                        [ -2.17590332e-02,  -2.17285156e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  3.87878418e-02,   3.87573242e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.50787354e-01,   1.50787354e-01],
                        [  1.80267334e-01,   1.80267334e-01],
                        [  1.93420410e-01,   1.93420410e-01],
                        [  1.78771973e-01,   1.78802490e-01],
                        [  1.23626709e-01,   1.23626709e-01],
                        [  2.44750977e-02,   2.44445801e-02],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -2.50976562e-01,  -2.50976562e-01],
                        [ -3.66302490e-01,  -3.66302490e-01],
                        [ -4.14215088e-01,  -4.14245605e-01],
                        [ -3.82781982e-01,  -3.82781982e-01],
                        [ -3.04229736e-01,  -3.04229736e-01],
                        [ -2.28637695e-01,  -2.28668213e-01],
                        [ -1.83135986e-01,  -1.83135986e-01],
                        [ -1.60644531e-01,  -1.60644531e-01],
                        [ -1.40808105e-01,  -1.40808105e-01],
                        [ -1.13800049e-01,  -1.13800049e-01],
                        [ -8.68835449e-02,  -8.68835449e-02],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.92260742e-03,  -1.95312500e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  1.72515869e-01,   1.72515869e-01],
                        [  2.34893799e-01,   2.34893799e-01],
                        [  2.73132324e-01,   2.73162842e-01],
                        [  2.78259277e-01,   2.78259277e-01],
                        [  2.57751465e-01,   2.57751465e-01],
                        [  2.29248047e-01,   2.29248047e-01],
                        [  2.06298828e-01,   2.06298828e-01],
                        [  1.90155029e-01,   1.90124512e-01],
                        [  1.73980713e-01,   1.73980713e-01],
                        [  1.54388428e-01,   1.54388428e-01],
                        [  1.35314941e-01,   1.35314941e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.03729248e-01,   1.03729248e-01],
                        [  8.34655762e-02,   8.34350586e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  8.72802734e-03,   8.69750977e-03],
                        [  6.40869141e-03,   6.43920898e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  3.50952148e-03,   3.54003906e-03],
                        [  1.77001953e-03,   1.73950195e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -1.64794922e-03,  -1.61743164e-03],
                        [ -2.13623047e-03,  -2.10571289e-03],
                        [ -3.41796875e-03,  -3.44848633e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -2.59094238e-02,  -2.59399414e-02],
                        [ -3.89709473e-02,  -3.89404297e-02],
                        [ -4.73937988e-02,  -4.74243164e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -4.27856445e-02,  -4.27551270e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -3.41186523e-02,  -3.41491699e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.58374023e-02,  -4.58068848e-02],
                        [ -5.48095703e-02,  -5.48400879e-02],
                        [ -5.89294434e-02,  -5.89599609e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -6.19812012e-02,  -6.20117188e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -6.64062500e-02,  -6.64367676e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -5.98144531e-02,  -5.97839355e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -4.54406738e-02,  -4.54406738e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -8.75854492e-03,  -8.72802734e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  1.65710449e-02,   1.66015625e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  5.92346191e-02,   5.92346191e-02],
                        [  7.15026855e-02,   7.15332031e-02],
                        [  8.62731934e-02,   8.62426758e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  1.54022217e-01,   1.53991699e-01],
                        [  1.77215576e-01,   1.77185059e-01],
                        [  1.78863525e-01,   1.78863525e-01],
                        [  1.46881104e-01,   1.46881104e-01],
                        [  7.77282715e-02,   7.77282715e-02],
                        [ -2.75268555e-02,  -2.74963379e-02],
                        [ -1.58477783e-01,  -1.58477783e-01],
                        [ -2.85736084e-01,  -2.85766602e-01],
                        [ -3.69903564e-01,  -3.69873047e-01],
                        [ -3.86749268e-01,  -3.86749268e-01],
                        [ -3.43811035e-01,  -3.43841553e-01],
                        [ -2.73681641e-01,  -2.73681641e-01],
                        [ -2.11334229e-01,  -2.11334229e-01],
                        [ -1.72210693e-01,  -1.72241211e-01],
                        [ -1.49139404e-01,  -1.49139404e-01],
                        [ -1.27990723e-01,  -1.27990723e-01],
                        [ -1.04675293e-01,  -1.04705811e-01],
                        [ -8.62426758e-02,  -8.62426758e-02],
                        [ -7.66296387e-02,  -7.66296387e-02],
                        [ -6.69250488e-02,  -6.69555664e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -2.09960938e-02,  -2.09655762e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  9.88769531e-03,   9.91821289e-03],
                        [  1.00708008e-03,   1.03759766e-03],
                        [ -1.27868652e-02,  -1.28173828e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -3.93371582e-02,  -3.93066406e-02],
                        [ -4.84924316e-02,  -4.85229492e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  4.10766602e-02,   4.10461426e-02],
                        [  1.17736816e-01,   1.17736816e-01],
                        [  1.98455811e-01,   1.98455811e-01],
                        [  2.65563965e-01,   2.65563965e-01],
                        [  3.03833008e-01,   3.03833008e-01],
                        [  3.04473877e-01,   3.04473877e-01],
                        [  2.73040771e-01,   2.73040771e-01],
                        [  2.30957031e-01,   2.30926514e-01],
                        [  1.99035645e-01,   1.99035645e-01],
                        [  1.80267334e-01,   1.80267334e-01],
                        [  1.65313721e-01,   1.65313721e-01],
                        [  1.49108887e-01,   1.49078369e-01],
                        [  1.32995605e-01,   1.32995605e-01],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  9.88769531e-02,   9.88464355e-02],
                        [  7.73620605e-02,   7.73925781e-02],
                        [  5.31005859e-02,   5.31311035e-02],
                        [  2.90222168e-02,   2.89916992e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  3.96728516e-03,   3.99780273e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.80053711e-02,   1.80358887e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  3.58276367e-02,   3.58581543e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  9.33837891e-03,   9.30786133e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [ -2.74658203e-03,  -2.77709961e-03],
                        [ -1.38854980e-02,  -1.38549805e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -1.29089355e-02,  -1.29394531e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.62048340e-02,  -1.61743164e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -4.15954590e-02,  -4.15649414e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -6.59179688e-02,  -6.58874512e-02],
                        [ -7.22656250e-02,  -7.22656250e-02],
                        [ -7.54089355e-02,  -7.54089355e-02],
                        [ -7.40966797e-02,  -7.41271973e-02],
                        [ -6.84814453e-02,  -6.84509277e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.16455078e-02,  -6.16760254e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.43823242e-02,  -5.44128418e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.25000000e-02,  -6.24694824e-02],
                        [ -6.83898926e-02,  -6.84204102e-02],
                        [ -6.79626465e-02,  -6.79931641e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -3.77502441e-02,  -3.77807617e-02],
                        [ -2.63366699e-02,  -2.63061523e-02],
                        [ -1.96228027e-02,  -1.95922852e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -9.30786133e-03,  -9.27734375e-03],
                        [ -4.24194336e-03,  -4.27246094e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  2.87780762e-02,   2.87475586e-02],
                        [  3.85742188e-02,   3.85437012e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  4.94995117e-02,   4.94689941e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.35314941e-01,   1.35314941e-01],
                        [  1.62963867e-01,   1.62963867e-01],
                        [  1.83441162e-01,   1.83441162e-01],
                        [  1.81213379e-01,   1.81213379e-01],
                        [  1.43371582e-01,   1.43371582e-01],
                        [  6.46057129e-02,   6.46057129e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -1.86065674e-01,  -1.86065674e-01],
                        [ -3.07983398e-01,  -3.07983398e-01],
                        [ -3.81317139e-01,  -3.81317139e-01],
                        [ -3.87512207e-01,  -3.87512207e-01],
                        [ -3.37768555e-01,  -3.37768555e-01],
                        [ -2.66143799e-01,  -2.66143799e-01],
                        [ -2.05291748e-01,  -2.05291748e-01],
                        [ -1.67083740e-01,  -1.67083740e-01],
                        [ -1.44348145e-01,  -1.44317627e-01],
                        [ -1.24908447e-01,  -1.24908447e-01],
                        [ -1.02691650e-01,  -1.02722168e-01],
                        [ -8.05969238e-02,  -8.05969238e-02],
                        [ -6.34460449e-02,  -6.34155273e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -2.67944336e-02,  -2.68249512e-02],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -7.10144043e-02,  -7.09838867e-02],
                        [ -8.02001953e-02,  -8.02001953e-02],
                        [ -6.70471191e-02,  -6.70471191e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  1.03485107e-01,   1.03485107e-01],
                        [  1.92443848e-01,   1.92443848e-01],
                        [  2.73590088e-01,   2.73620605e-01],
                        [  3.24493408e-01,   3.24493408e-01],
                        [  3.32794189e-01,   3.32794189e-01],
                        [  3.04443359e-01,   3.04473877e-01],
                        [  2.58514404e-01,   2.58514404e-01],
                        [  2.13043213e-01,   2.13043213e-01],
                        [  1.75506592e-01,   1.75506592e-01],
                        [  1.45843506e-01,   1.45843506e-01],
                        [  1.24267578e-01,   1.24237061e-01],
                        [  1.11328125e-01,   1.11358643e-01],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  7.65991211e-02,   7.66296387e-02],
                        [  5.32226562e-02,   5.31921387e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.62048340e-02,  -1.61743164e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -7.73010254e-02,  -7.73010254e-02],
                        [ -7.78198242e-02,  -7.77893066e-02],
                        [ -7.65991211e-02,  -7.65991211e-02],
                        [ -7.46459961e-02,  -7.46459961e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -7.28759766e-02,  -7.28759766e-02],
                        [ -6.82373047e-02,  -6.82067871e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -3.58276367e-02,  -3.57971191e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -2.74658203e-02,  -2.74963379e-02],
                        [ -2.33459473e-02,  -2.33154297e-02],
                        [ -1.28784180e-02,  -1.28479004e-02],
                        [ -6.40869141e-04,  -6.71386719e-04],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  4.84313965e-02,   4.84619141e-02],
                        [  6.10046387e-02,   6.09741211e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  1.17736816e-01,   1.17706299e-01],
                        [  1.47399902e-01,   1.47399902e-01],
                        [  1.72637939e-01,   1.72637939e-01],
                        [  1.76513672e-01,   1.76483154e-01],
                        [  1.48498535e-01,   1.48498535e-01],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -9.89685059e-02,  -9.89685059e-02],
                        [ -2.04376221e-01,  -2.04376221e-01],
                        [ -2.97943115e-01,  -2.97943115e-01],
                        [ -3.59405518e-01,  -3.59405518e-01],
                        [ -3.72436523e-01,  -3.72436523e-01],
                        [ -3.37066650e-01,  -3.37066650e-01],
                        [ -2.72460938e-01,  -2.72460938e-01],
                        [ -2.05383301e-01,  -2.05383301e-01],
                        [ -1.53717041e-01,  -1.53686523e-01],
                        [ -1.17828369e-01,  -1.17797852e-01],
                        [ -8.84704590e-02,  -8.85009766e-02],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -4.84008789e-02,  -4.83703613e-02],
                        [ -4.47387695e-02,  -4.47692871e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -3.08837891e-02,  -3.08532715e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [  7.01904297e-04,   6.71386719e-04],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -5.95092773e-02,  -5.95397949e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -6.60095215e-02,  -6.59790039e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  1.84234619e-01,   1.84234619e-01],
                        [  2.58789062e-01,   2.58789062e-01],
                        [  3.03192139e-01,   3.03192139e-01],
                        [  3.08441162e-01,   3.08441162e-01],
                        [  2.82623291e-01,   2.82623291e-01],
                        [  2.44079590e-01,   2.44079590e-01],
                        [  2.07244873e-01,   2.07244873e-01],
                        [  1.76635742e-01,   1.76605225e-01],
                        [  1.50970459e-01,   1.50970459e-01],
                        [  1.29028320e-01,   1.29028320e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  8.87145996e-02,   8.87451172e-02],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  6.19506836e-03,   6.22558594e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  8.30078125e-03,   8.33129883e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.32238770e-02,  -2.32543945e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.23999023e-02,  -2.23693848e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -2.37121582e-02,  -2.37426758e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -6.09130859e-02,  -6.09436035e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -7.10754395e-02,  -7.10754395e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -7.25097656e-02,  -7.25402832e-02],
                        [ -6.36596680e-02,  -6.36291504e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.59497070e-02,  -3.59191895e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.10778809e-02,  -1.10473633e-02],
                        [ -2.25830078e-03,  -2.28881836e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  1.89819336e-02,   1.90124512e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  1.03515625e-01,   1.03546143e-01],
                        [  1.25213623e-01,   1.25244141e-01],
                        [  1.44561768e-01,   1.44531250e-01],
                        [  1.57562256e-01,   1.57531738e-01],
                        [  1.56097412e-01,   1.56127930e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  2.12402344e-02,   2.12707520e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -1.46118164e-01,  -1.46118164e-01],
                        [ -2.34069824e-01,  -2.34069824e-01],
                        [ -3.08898926e-01,  -3.08898926e-01],
                        [ -3.52630615e-01,  -3.52661133e-01],
                        [ -3.51226807e-01,  -3.51226807e-01],
                        [ -3.07067871e-01,  -3.07067871e-01],
                        [ -2.41577148e-01,  -2.41577148e-01],
                        [ -1.81945801e-01,  -1.81945801e-01],
                        [ -1.43035889e-01,  -1.43035889e-01],
                        [ -1.19812012e-01,  -1.19812012e-01],
                        [ -9.86328125e-02,  -9.86328125e-02],
                        [ -7.53479004e-02,  -7.53479004e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -4.75463867e-02,  -4.75769043e-02],
                        [ -3.67431641e-02,  -3.67736816e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -5.47790527e-02,  -5.47485352e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -8.14819336e-03,  -8.11767578e-03],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  1.12304688e-01,   1.12274170e-01],
                        [  1.92504883e-01,   1.92535400e-01],
                        [  2.62023926e-01,   2.62054443e-01],
                        [  3.01696777e-01,   3.01696777e-01],
                        [  3.07281494e-01,   3.07281494e-01],
                        [  2.85705566e-01,   2.85736084e-01],
                        [  2.47680664e-01,   2.47680664e-01],
                        [  2.05352783e-01,   2.05322266e-01],
                        [  1.69189453e-01,   1.69189453e-01],
                        [  1.43402100e-01,   1.43402100e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  9.89379883e-02,   9.89685059e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  4.88586426e-02,   4.88891602e-02],
                        [  5.74035645e-02,   5.73730469e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -2.53295898e-03,  -2.50244141e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -2.07519531e-03,  -2.10571289e-03],
                        [ -5.06591797e-03,  -5.03540039e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.55639648e-03,  -1.58691406e-03],
                        [  1.12915039e-03,   1.15966797e-03],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -6.63146973e-02,  -6.63146973e-02],
                        [ -6.85729980e-02,  -6.85729980e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.65893555e-02,  -6.65893555e-02],
                        [ -6.43615723e-02,  -6.43615723e-02],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -6.72607422e-02,  -6.72912598e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  2.68249512e-02,   2.68249512e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  8.90808105e-02,   8.90502930e-02],
                        [  1.12792969e-01,   1.12792969e-01],
                        [  1.33209229e-01,   1.33239746e-01],
                        [  1.46331787e-01,   1.46301270e-01],
                        [  1.48162842e-01,   1.48162842e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  9.84802246e-02,   9.84802246e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [ -1.87072754e-02,  -1.86767578e-02],
                        [ -8.75549316e-02,  -8.75549316e-02],
                        [ -1.57562256e-01,  -1.57562256e-01],
                        [ -2.28118896e-01,  -2.28118896e-01],
                        [ -2.93853760e-01,  -2.93853760e-01],
                        [ -3.37463379e-01,  -3.37463379e-01],
                        [ -3.38195801e-01,  -3.38195801e-01],
                        [ -2.93548584e-01,  -2.93548584e-01],
                        [ -2.27935791e-01,  -2.27935791e-01],
                        [ -1.73339844e-01,  -1.73339844e-01],
                        [ -1.41357422e-01,  -1.41357422e-01],
                        [ -1.19537354e-01,  -1.19537354e-01],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -2.51464844e-02,  -2.51159668e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  7.98339844e-02,   7.98034668e-02],
                        [  1.43859863e-01,   1.43829346e-01],
                        [  2.09747314e-01,   2.09747314e-01],
                        [  2.61566162e-01,   2.61596680e-01],
                        [  2.88543701e-01,   2.88543701e-01],
                        [  2.87200928e-01,   2.87200928e-01],
                        [  2.62298584e-01,   2.62298584e-01],
                        [  2.26898193e-01,   2.26898193e-01],
                        [  1.94793701e-01,   1.94793701e-01],
                        [  1.70318604e-01,   1.70318604e-01],
                        [  1.48986816e-01,   1.48986816e-01],
                        [  1.26586914e-01,   1.26556396e-01],
                        [  1.04156494e-01,   1.04187012e-01],
                        [  8.52661133e-02,   8.52966309e-02],
                        [  6.95800781e-02,   6.95800781e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  3.64685059e-02,   3.64990234e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.02941895e-02,   2.02636719e-02],
                        [  1.66015625e-02,   1.66320801e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  2.33154297e-02,   2.33459473e-02],
                        [  3.53698730e-02,   3.53393555e-02],
                        [  4.34570312e-02,   4.34265137e-02],
                        [  4.44946289e-02,   4.45251465e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  2.88085938e-02,   2.87780762e-02],
                        [  2.14843750e-02,   2.15148926e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [ -4.97436523e-03,  -5.00488281e-03],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  7.29370117e-03,   7.32421875e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -4.92858887e-02,  -4.92553711e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -5.14831543e-02,  -5.14526367e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -5.87463379e-02,  -5.87768555e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -6.55212402e-02,  -6.55212402e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  7.11059570e-03,   7.14111328e-03],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  1.18835449e-01,   1.18865967e-01],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.14959717e-01,   1.14929199e-01],
                        [  9.59777832e-02,   9.59777832e-02],
                        [  6.31408691e-02,   6.31713867e-02],
                        [  1.90124512e-02,   1.89819336e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -9.42687988e-02,  -9.42687988e-02],
                        [ -1.28631592e-01,  -1.28662109e-01],
                        [ -1.86523438e-01,  -1.86492920e-01],
                        [ -2.60467529e-01,  -2.60467529e-01],
                        [ -3.13995361e-01,  -3.14025879e-01],
                        [ -3.14453125e-01,  -3.14453125e-01],
                        [ -2.63885498e-01,  -2.63885498e-01],
                        [ -1.94488525e-01,  -1.94488525e-01],
                        [ -1.40747070e-01,  -1.40747070e-01],
                        [ -1.15570068e-01,  -1.15570068e-01],
                        [ -1.05377197e-01,  -1.05377197e-01],
                        [ -8.87145996e-02,  -8.87451172e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -3.22570801e-02,  -3.22265625e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [ -6.10351562e-05,  -3.05175781e-05],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -2.35290527e-02,  -2.35595703e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.88085938e-02,  -2.87780762e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -6.40869141e-04,  -6.71386719e-04],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  1.55792236e-01,   1.55792236e-01],
                        [  1.99737549e-01,   1.99768066e-01],
                        [  2.37579346e-01,   2.37579346e-01],
                        [  2.64495850e-01,   2.64495850e-01],
                        [  2.71759033e-01,   2.71789551e-01],
                        [  2.56011963e-01,   2.56011963e-01],
                        [  2.27294922e-01,   2.27264404e-01],
                        [  1.98059082e-01,   1.98059082e-01],
                        [  1.69830322e-01,   1.69860840e-01],
                        [  1.40197754e-01,   1.40167236e-01],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  9.14916992e-02,   9.15222168e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  6.11572266e-02,   6.11267090e-02],
                        [  4.94995117e-02,   4.95300293e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  3.55529785e-02,   3.55224609e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  7.47680664e-03,   7.44628906e-03],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  2.50854492e-02,   2.51159668e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  2.18811035e-02,   2.18505859e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  7.62939453e-04,   7.93457031e-04],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -3.23791504e-02,  -3.24096680e-02],
                        [ -3.43933105e-02,  -3.43627930e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.84619141e-02,  -4.84924316e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.99975586e-02,  -6.00280762e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -6.41174316e-02,  -6.40869141e-02],
                        [ -6.31408691e-02,  -6.31713867e-02],
                        [ -6.06994629e-02,  -6.07299805e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -5.76782227e-02,  -5.76477051e-02],
                        [ -5.64880371e-02,  -5.65185547e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -6.00891113e-02,  -6.00585938e-02],
                        [ -5.92041016e-02,  -5.92041016e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.02929688e-02,  -5.02624512e-02],
                        [ -4.24499512e-02,  -4.24194336e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.44348145e-02,  -1.44653320e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [  4.30297852e-03,   4.33349609e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  1.05407715e-01,   1.05438232e-01],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -1.01562500e-01,  -1.01562500e-01],
                        [ -1.79779053e-01,  -1.79779053e-01],
                        [ -2.64099121e-01,  -2.64099121e-01],
                        [ -3.16223145e-01,  -3.16223145e-01],
                        [ -3.09967041e-01,  -3.09967041e-01],
                        [ -2.54364014e-01,  -2.54333496e-01],
                        [ -1.86096191e-01,  -1.86126709e-01],
                        [ -1.37054443e-01,  -1.37054443e-01],
                        [ -1.11694336e-01,  -1.11694336e-01],
                        [ -9.49707031e-02,  -9.49707031e-02],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  7.59887695e-03,   7.62939453e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  7.34863281e-02,   7.35168457e-02],
                        [  1.06536865e-01,   1.06536865e-01],
                        [  1.43218994e-01,   1.43218994e-01],
                        [  1.80999756e-01,   1.81030273e-01],
                        [  2.17559814e-01,   2.17559814e-01],
                        [  2.51342773e-01,   2.51342773e-01],
                        [  2.73651123e-01,   2.73681641e-01],
                        [  2.70751953e-01,   2.70751953e-01],
                        [  2.40966797e-01,   2.40936279e-01],
                        [  1.99523926e-01,   1.99554443e-01],
                        [  1.62292480e-01,   1.62322998e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.09680176e-01,   1.09680176e-01],
                        [  8.86840820e-02,   8.87145996e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  5.70983887e-02,   5.70678711e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  3.45764160e-02,   3.46069336e-02],
                        [  2.64282227e-02,   2.63977051e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  1.99279785e-02,   1.99584961e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  3.88793945e-02,   3.89099121e-02],
                        [  4.42810059e-02,   4.43115234e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  4.37011719e-02,   4.37316895e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -3.93676758e-03,  -3.96728516e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -1.86157227e-02,  -1.86157227e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -7.30590820e-02,  -7.30590820e-02],
                        [ -7.43103027e-02,  -7.43103027e-02],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -7.28759766e-02,  -7.28759766e-02],
                        [ -7.74841309e-02,  -7.74841309e-02],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -5.69763184e-02,  -5.70068359e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -2.34985352e-03,  -2.31933594e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  3.23486328e-03,   3.20434570e-03],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  8.58154297e-02,   8.58154297e-02],
                        [  9.90295410e-02,   9.89990234e-02],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  1.00677490e-01,   1.00708008e-01],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -1.75811768e-01,  -1.75781250e-01],
                        [ -2.61047363e-01,  -2.61047363e-01],
                        [ -3.05816650e-01,  -3.05816650e-01],
                        [ -2.94097900e-01,  -2.94067383e-01],
                        [ -2.40509033e-01,  -2.40509033e-01],
                        [ -1.77764893e-01,  -1.77795410e-01],
                        [ -1.33728027e-01,  -1.33728027e-01],
                        [ -1.13006592e-01,  -1.13006592e-01],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -2.06298828e-02,  -2.06604004e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  1.26037598e-02,   1.25732422e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  1.52587891e-02,   1.52282715e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  3.99780273e-03,   4.02832031e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  7.29370117e-03,   7.26318359e-03],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  3.81164551e-02,   3.81469727e-02],
                        [  6.21337891e-02,   6.21032715e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  1.01287842e-01,   1.01318359e-01],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  1.45538330e-01,   1.45538330e-01],
                        [  1.81365967e-01,   1.81365967e-01],
                        [  2.20336914e-01,   2.20336914e-01],
                        [  2.49023438e-01,   2.48992920e-01],
                        [  2.55432129e-01,   2.55432129e-01],
                        [  2.39471436e-01,   2.39471436e-01],
                        [  2.11517334e-01,   2.11517334e-01],
                        [  1.80603027e-01,   1.80603027e-01],
                        [  1.50238037e-01,   1.50238037e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  8.70666504e-02,   8.70666504e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.09753418e-02,   3.10058594e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  2.34069824e-02,   2.33764648e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  3.28979492e-02,   3.29284668e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.40380859e-02,   1.40075684e-02],
                        [  5.31005859e-03,   5.27954102e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -1.08642578e-02,  -1.08947754e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -3.52783203e-02,  -3.53088379e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -4.32434082e-02,  -4.32128906e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.29174805e-02,  -5.29479980e-02],
                        [ -5.35583496e-02,  -5.35278320e-02],
                        [ -5.23681641e-02,  -5.23376465e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -7.46154785e-02,  -7.46154785e-02],
                        [ -7.73010254e-02,  -7.72705078e-02],
                        [ -7.72399902e-02,  -7.72399902e-02],
                        [ -7.37304688e-02,  -7.37609863e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -2.27050781e-02,  -2.27355957e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.81164551e-02,   3.80859375e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -7.86743164e-02,  -7.86743164e-02],
                        [ -8.00476074e-02,  -8.00170898e-02],
                        [ -4.82177734e-02,  -4.82482910e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [  1.84020996e-02,   1.84020996e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -1.61712646e-01,  -1.61712646e-01],
                        [ -2.48413086e-01,  -2.48413086e-01],
                        [ -2.99255371e-01,  -2.99255371e-01],
                        [ -2.94464111e-01,  -2.94464111e-01],
                        [ -2.42340088e-01,  -2.42340088e-01],
                        [ -1.73583984e-01,  -1.73614502e-01],
                        [ -1.16607666e-01,  -1.16638184e-01],
                        [ -8.16955566e-02,  -8.16650391e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -5.08728027e-02,  -5.09033203e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.52783203e-02,  -3.53088379e-02],
                        [ -3.95812988e-02,  -3.96118164e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  1.54418945e-02,   1.54113770e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  7.23266602e-02,   7.22961426e-02],
                        [  8.77685547e-02,   8.77990723e-02],
                        [  9.24682617e-02,   9.24987793e-02],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  1.00799561e-01,   1.00830078e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.68365479e-01,   1.68365479e-01],
                        [  2.09899902e-01,   2.09930420e-01],
                        [  2.34130859e-01,   2.34130859e-01],
                        [  2.31719971e-01,   2.31689453e-01],
                        [  2.08374023e-01,   2.08374023e-01],
                        [  1.77398682e-01,   1.77429199e-01],
                        [  1.51000977e-01,   1.50970459e-01],
                        [  1.34368896e-01,   1.34368896e-01],
                        [  1.22192383e-01,   1.22222900e-01],
                        [  1.05255127e-01,   1.05255127e-01],
                        [  8.37402344e-02,   8.37097168e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  5.52673340e-02,   5.52673340e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  3.90930176e-02,   3.91235352e-02],
                        [  3.11584473e-02,   3.11279297e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  1.46484375e-02,   1.46179199e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  1.52282715e-02,   1.51977539e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.73034668e-02,   1.72729492e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  7.72094727e-03,   7.75146484e-03],
                        [  1.52587891e-04,   1.52587891e-04],
                        [ -6.53076172e-03,  -6.56127930e-03],
                        [ -1.10778809e-02,  -1.10473633e-02],
                        [ -1.29699707e-02,  -1.29394531e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.15051270e-02,  -1.14746094e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -5.42602539e-02,  -5.42297363e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -5.74035645e-02,  -5.74340820e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -5.95703125e-02,  -5.96008301e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -6.19201660e-02,  -6.18896484e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  7.61413574e-02,   7.61413574e-02],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  1.04034424e-01,   1.04034424e-01],
                        [  9.30480957e-02,   9.30480957e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -9.28955078e-02,  -9.28955078e-02],
                        [ -9.91516113e-02,  -9.91516113e-02],
                        [ -6.76879883e-02,  -6.77185059e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  3.10974121e-02,   3.10668945e-02],
                        [  1.15966797e-03,   1.15966797e-03],
                        [ -5.92956543e-02,  -5.92651367e-02],
                        [ -1.38000488e-01,  -1.38000488e-01],
                        [ -2.16247559e-01,  -2.16247559e-01],
                        [ -2.68157959e-01,  -2.68157959e-01],
                        [ -2.73712158e-01,  -2.73712158e-01],
                        [ -2.36206055e-01,  -2.36206055e-01],
                        [ -1.81304932e-01,  -1.81304932e-01],
                        [ -1.34674072e-01,  -1.34643555e-01],
                        [ -1.03820801e-01,  -1.03820801e-01],
                        [ -8.20312500e-02,  -8.20312500e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -2.62451172e-03,  -2.59399414e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.93786621e-02,   1.93481445e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.86560059e-02,   2.86865234e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  7.17773438e-02,   7.17773438e-02],
                        [  9.39025879e-02,   9.39331055e-02],
                        [  1.04125977e-01,   1.04125977e-01],
                        [  1.04095459e-01,   1.04064941e-01],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  1.15936279e-01,   1.15936279e-01],
                        [  1.49627686e-01,   1.49627686e-01],
                        [  1.93664551e-01,   1.93695068e-01],
                        [  2.27844238e-01,   2.27844238e-01],
                        [  2.38403320e-01,   2.38403320e-01],
                        [  2.25677490e-01,   2.25677490e-01],
                        [  1.98242188e-01,   1.98242188e-01],
                        [  1.66778564e-01,   1.66778564e-01],
                        [  1.39190674e-01,   1.39190674e-01],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  7.49511719e-02,   7.49511719e-02],
                        [  6.40258789e-02,   6.40563965e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  6.79016113e-02,   6.78710938e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  4.92248535e-02,   4.91943359e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  7.62939453e-04,   7.32421875e-04],
                        [  1.89208984e-03,   1.92260742e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.64794922e-02,   1.65100098e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -9.67407227e-03,  -9.64355469e-03],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -4.40368652e-02,  -4.40673828e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.75769043e-02,  -4.76074219e-02],
                        [ -5.16052246e-02,  -5.15747070e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -6.21948242e-02,  -6.22253418e-02],
                        [ -6.51855469e-02,  -6.51550293e-02],
                        [ -6.57043457e-02,  -6.56738281e-02],
                        [ -6.49414062e-02,  -6.49719238e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -6.39343262e-02,  -6.39343262e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -6.83288574e-02,  -6.82983398e-02],
                        [ -6.66809082e-02,  -6.66809082e-02],
                        [ -6.09436035e-02,  -6.09436035e-02],
                        [ -5.53894043e-02,  -5.53588867e-02],
                        [ -5.12695312e-02,  -5.13000488e-02],
                        [ -4.52575684e-02,  -4.52880859e-02],
                        [ -3.67431641e-02,  -3.67126465e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -7.38525391e-03,  -7.35473633e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  6.68334961e-03,   6.71386719e-03],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  7.67517090e-02,   7.67822266e-02],
                        [  9.54284668e-02,   9.54284668e-02],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  8.38317871e-02,   8.38623047e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  6.13403320e-03,   6.10351562e-03],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -8.36181641e-02,  -8.36181641e-02],
                        [ -9.09423828e-02,  -9.09423828e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  2.31018066e-02,   2.31323242e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.11999512e-01,  -1.11999512e-01],
                        [ -1.99707031e-01,  -1.99676514e-01],
                        [ -2.71820068e-01,  -2.71850586e-01],
                        [ -2.99407959e-01,  -2.99407959e-01],
                        [ -2.71240234e-01,  -2.71240234e-01],
                        [ -2.06451416e-01,  -2.06451416e-01],
                        [ -1.39434814e-01,  -1.39434814e-01],
                        [ -9.53979492e-02,  -9.53979492e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -6.97937012e-02,  -6.97937012e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -4.08935547e-02,  -4.08630371e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -2.99072266e-02,  -2.99377441e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  2.16674805e-03,   2.19726562e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  1.35192871e-02,   1.34887695e-02],
                        [  1.91040039e-02,   1.91345215e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  6.74743652e-02,   6.74743652e-02],
                        [  8.53881836e-02,   8.54187012e-02],
                        [  9.60083008e-02,   9.60083008e-02],
                        [  9.72900391e-02,   9.72900391e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  8.77685547e-02,   8.77380371e-02],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  1.51428223e-01,   1.51428223e-01],
                        [  1.99279785e-01,   1.99279785e-01],
                        [  2.35290527e-01,   2.35290527e-01],
                        [  2.44049072e-01,   2.44049072e-01],
                        [  2.26074219e-01,   2.26074219e-01],
                        [  1.94793701e-01,   1.94793701e-01],
                        [  1.63543701e-01,   1.63574219e-01],
                        [  1.39099121e-01,   1.39099121e-01],
                        [  1.20971680e-01,   1.20941162e-01],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  8.19702148e-02,   8.19702148e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  3.59802246e-02,   3.60107422e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  2.10571289e-02,   2.10266113e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.43432617e-02,   1.43737793e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  2.84729004e-02,   2.85034180e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -3.31115723e-02,  -3.31420898e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -3.84826660e-02,  -3.84521484e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.31115723e-02,  -3.31420898e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -4.49829102e-02,  -4.49523926e-02],
                        [ -5.18798828e-02,  -5.19104004e-02],
                        [ -5.67016602e-02,  -5.67321777e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -5.07812500e-02,  -5.08117676e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -4.61730957e-02,  -4.62036133e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -6.79626465e-02,  -6.79321289e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -1.87377930e-02,  -1.87683105e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  3.02429199e-02,   3.02124023e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  6.81152344e-02,   6.81152344e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -1.14685059e-01,  -1.14685059e-01],
                        [ -1.12731934e-01,  -1.12731934e-01],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  4.02526855e-02,   4.02526855e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -1.65740967e-01,  -1.65740967e-01],
                        [ -2.29156494e-01,  -2.29156494e-01],
                        [ -2.54180908e-01,  -2.54180908e-01],
                        [ -2.33337402e-01,  -2.33337402e-01],
                        [ -1.84356689e-01,  -1.84356689e-01],
                        [ -1.36138916e-01,  -1.36138916e-01],
                        [ -1.05438232e-01,  -1.05407715e-01],
                        [ -8.86230469e-02,  -8.86230469e-02],
                        [ -7.36083984e-02,  -7.36083984e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  3.28979492e-02,   3.28674316e-02],
                        [  5.63659668e-02,   5.63659668e-02],
                        [  8.41674805e-02,   8.41979980e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  9.12780762e-02,   9.13085938e-02],
                        [  8.08715820e-02,   8.08715820e-02],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  1.02325439e-01,   1.02355957e-01],
                        [  1.37390137e-01,   1.37390137e-01],
                        [  1.77551270e-01,   1.77551270e-01],
                        [  2.08770752e-01,   2.08770752e-01],
                        [  2.20520020e-01,   2.20520020e-01],
                        [  2.11242676e-01,   2.11242676e-01],
                        [  1.87377930e-01,   1.87377930e-01],
                        [  1.58630371e-01,   1.58630371e-01],
                        [  1.33758545e-01,   1.33758545e-01],
                        [  1.15875244e-01,   1.15844727e-01],
                        [  9.95483398e-02,   9.95788574e-02],
                        [  7.89489746e-02,   7.89794922e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  2.44750977e-02,   2.44445801e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  6.56127930e-03,   6.59179688e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -4.02832031e-02,  -4.03137207e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -3.97949219e-02,  -3.97644043e-02],
                        [ -3.95812988e-02,  -3.96118164e-02],
                        [ -3.84216309e-02,  -3.84521484e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -5.20019531e-02,  -5.20324707e-02],
                        [ -5.42602539e-02,  -5.42297363e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.86547852e-02,  -5.86853027e-02],
                        [ -5.95703125e-02,  -5.95397949e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -6.14318848e-02,  -6.14624023e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.15844727e-02,  -6.16149902e-02],
                        [ -6.39953613e-02,  -6.40258789e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  1.66625977e-02,   1.66931152e-02],
                        [  3.24401855e-02,   3.24096680e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  6.53076172e-02,   6.53076172e-02],
                        [  8.05053711e-02,   8.05053711e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -9.79003906e-02,  -9.78698730e-02],
                        [ -1.20208740e-01,  -1.20208740e-01],
                        [ -1.05010986e-01,  -1.05010986e-01],
                        [ -5.93261719e-02,  -5.92956543e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  3.79943848e-02,   3.80249023e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -1.35955811e-01,  -1.35925293e-01],
                        [ -2.16064453e-01,  -2.16064453e-01],
                        [ -2.64099121e-01,  -2.64099121e-01],
                        [ -2.59552002e-01,  -2.59521484e-01],
                        [ -2.10571289e-01,  -2.10540771e-01],
                        [ -1.45843506e-01,  -1.45874023e-01],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [  7.01904297e-03,   7.04956055e-03],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  1.02081299e-01,   1.02081299e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.41510010e-01,   1.41510010e-01],
                        [  1.29913330e-01,   1.29913330e-01],
                        [  1.04095459e-01,   1.04064941e-01],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  5.78002930e-02,   5.78308105e-02],
                        [  6.51245117e-02,   6.50939941e-02],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  1.45782471e-01,   1.45812988e-01],
                        [  1.89422607e-01,   1.89422607e-01],
                        [  2.17651367e-01,   2.17620850e-01],
                        [  2.22595215e-01,   2.22595215e-01],
                        [  2.02819824e-01,   2.02850342e-01],
                        [  1.69342041e-01,   1.69311523e-01],
                        [  1.38519287e-01,   1.38488770e-01],
                        [  1.15539551e-01,   1.15570068e-01],
                        [  9.55200195e-02,   9.55200195e-02],
                        [  7.95593262e-02,   7.95288086e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  8.05358887e-02,   8.05664062e-02],
                        [  8.55712891e-02,   8.55407715e-02],
                        [  8.06884766e-02,   8.06579590e-02],
                        [  6.44836426e-02,   6.45141602e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  2.22778320e-02,   2.22473145e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  4.05883789e-03,   4.08935547e-03],
                        [  5.49316406e-03,   5.46264648e-03],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.08032227e-02,   1.08337402e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  1.91955566e-02,   1.91650391e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  1.15966797e-02,   1.15661621e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -2.89916992e-03,  -2.86865234e-03],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -2.16369629e-02,  -2.16674805e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -4.02832031e-02,  -4.03137207e-02],
                        [ -4.13818359e-02,  -4.13513184e-02],
                        [ -4.09851074e-02,  -4.09545898e-02],
                        [ -4.41284180e-02,  -4.41589355e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -5.83190918e-02,  -5.82885742e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -4.92553711e-02,  -4.92248535e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.65087891e-02,  -4.65393066e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.44030762e-02,  -4.43725586e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [  2.19116211e-02,   2.18811035e-02],
                        [  4.84313965e-02,   4.84008789e-02],
                        [  7.40661621e-02,   7.40966797e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  1.04339600e-01,   1.04339600e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  7.91015625e-02,   7.91015625e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [ -4.22973633e-02,  -4.23278809e-02],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -1.43890381e-01,  -1.43890381e-01],
                        [ -1.36199951e-01,  -1.36199951e-01],
                        [ -8.85925293e-02,  -8.85925293e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [  3.14331055e-02,   3.14025879e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [ -3.93676758e-03,  -3.96728516e-03],
                        [ -8.70056152e-02,  -8.70056152e-02],
                        [ -1.83166504e-01,  -1.83166504e-01],
                        [ -2.61871338e-01,  -2.61871338e-01],
                        [ -2.92053223e-01,  -2.92053223e-01],
                        [ -2.63183594e-01,  -2.63183594e-01],
                        [ -1.95739746e-01,  -1.95739746e-01],
                        [ -1.27655029e-01,  -1.27685547e-01],
                        [ -8.63342285e-02,  -8.63342285e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -6.57043457e-02,  -6.57043457e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -2.99987793e-02,  -3.00292969e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  1.17187500e-01,   1.17187500e-01],
                        [  1.26098633e-01,   1.26068115e-01],
                        [  1.17095947e-01,   1.17095947e-01],
                        [  9.79919434e-02,   9.79919434e-02],
                        [  7.95593262e-02,   7.95593262e-02],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  7.72705078e-02,   7.72705078e-02],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  1.45660400e-01,   1.45660400e-01],
                        [  1.90856934e-01,   1.90856934e-01],
                        [  2.23571777e-01,   2.23571777e-01],
                        [  2.34344482e-01,   2.34313965e-01],
                        [  2.20672607e-01,   2.20672607e-01],
                        [  1.88415527e-01,   1.88446045e-01],
                        [  1.52648926e-01,   1.52648926e-01],
                        [  1.27319336e-01,   1.27319336e-01],
                        [  1.12396240e-01,   1.12426758e-01],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  5.11779785e-02,   5.12084961e-02],
                        [  5.04455566e-02,   5.04150391e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  4.76684570e-02,   4.76989746e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.07421875e-02,   1.07116699e-02],
                        [  4.76074219e-03,   4.79125977e-03],
                        [  3.81469727e-03,   3.84521484e-03],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.62353516e-02,   1.62658691e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [ -4.45556641e-03,  -4.42504883e-03],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -6.26525879e-02,  -6.26220703e-02],
                        [ -6.32019043e-02,  -6.31713867e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -5.56030273e-02,  -5.56335449e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  6.29577637e-02,   6.29882812e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  7.56530762e-02,   7.56530762e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [ -2.38342285e-02,  -2.38647461e-02],
                        [ -8.58764648e-02,  -8.58764648e-02],
                        [ -1.32476807e-01,  -1.32476807e-01],
                        [ -1.43035889e-01,  -1.43035889e-01],
                        [ -1.09985352e-01,  -1.09985352e-01],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  6.97937012e-02,   6.97937012e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -1.35162354e-01,  -1.35162354e-01],
                        [ -2.25189209e-01,  -2.25189209e-01],
                        [ -2.77954102e-01,  -2.77954102e-01],
                        [ -2.73376465e-01,  -2.73376465e-01],
                        [ -2.20764160e-01,  -2.20764160e-01],
                        [ -1.51947021e-01,  -1.51947021e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  3.77197266e-02,   3.76892090e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  3.32336426e-02,   3.32641602e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  1.03729248e-01,   1.03729248e-01],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.26556396e-01,   1.26556396e-01],
                        [  1.14685059e-01,   1.14685059e-01],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  6.90002441e-02,   6.89697266e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  1.33026123e-01,   1.32995605e-01],
                        [  1.72180176e-01,   1.72180176e-01],
                        [  2.06878662e-01,   2.06878662e-01],
                        [  2.25067139e-01,   2.25067139e-01],
                        [  2.19451904e-01,   2.19451904e-01],
                        [  1.92047119e-01,   1.92077637e-01],
                        [  1.54602051e-01,   1.54602051e-01],
                        [  1.21673584e-01,   1.21643066e-01],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  7.34558105e-02,   7.34558105e-02],
                        [  7.35473633e-02,   7.35473633e-02],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  2.92968750e-03,   2.92968750e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.97448730e-02,   1.97143555e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.89501953e-02,  -4.89196777e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -4.85229492e-02,  -4.84924316e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.24804688e-02,  -4.24499512e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -4.14733887e-02,  -4.15039062e-02],
                        [ -4.51354980e-02,  -4.51049805e-02],
                        [ -5.60302734e-02,  -5.60302734e-02],
                        [ -6.80541992e-02,  -6.80847168e-02],
                        [ -7.36083984e-02,  -7.36083984e-02],
                        [ -7.44628906e-02,  -7.44323730e-02],
                        [ -7.53479004e-02,  -7.53479004e-02],
                        [ -7.36389160e-02,  -7.36694336e-02],
                        [ -6.59484863e-02,  -6.59179688e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -4.82177734e-02,  -4.82482910e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -6.09436035e-02,  -6.09741211e-02],
                        [ -6.91528320e-02,  -6.91833496e-02],
                        [ -7.05566406e-02,  -7.05261230e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -6.08520508e-02,  -6.08825684e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -4.69055176e-02,  -4.69055176e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [  5.21850586e-03,   5.21850586e-03],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  3.64685059e-02,   3.64379883e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  5.28259277e-02,   5.27954102e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -1.30981445e-01,  -1.30981445e-01],
                        [ -1.62963867e-01,  -1.62963867e-01],
                        [ -1.48651123e-01,  -1.48651123e-01],
                        [ -9.63439941e-02,  -9.63439941e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -1.32171631e-01,  -1.32171631e-01],
                        [ -2.17315674e-01,  -2.17315674e-01],
                        [ -2.65472412e-01,  -2.65472412e-01],
                        [ -2.57232666e-01,  -2.57232666e-01],
                        [ -2.02056885e-01,  -2.02087402e-01],
                        [ -1.34826660e-01,  -1.34826660e-01],
                        [ -8.80126953e-02,  -8.80126953e-02],
                        [ -6.83288574e-02,  -6.83288574e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -3.86657715e-02,  -3.86352539e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [  7.32421875e-04,   7.01904297e-04],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  3.96728516e-02,   3.97033691e-02],
                        [  4.88586426e-02,   4.88281250e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  3.87573242e-02,   3.87878418e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  3.17993164e-02,   3.17687988e-02],
                        [  5.06286621e-02,   5.06286621e-02],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  1.18621826e-01,   1.18591309e-01],
                        [  1.39617920e-01,   1.39617920e-01],
                        [  1.35345459e-01,   1.35375977e-01],
                        [  1.11053467e-01,   1.11022949e-01],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  6.04858398e-02,   6.04553223e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  1.15905762e-01,   1.15905762e-01],
                        [  1.62872314e-01,   1.62872314e-01],
                        [  2.05932617e-01,   2.05932617e-01],
                        [  2.28240967e-01,   2.28240967e-01],
                        [  2.21984863e-01,   2.21984863e-01],
                        [  1.92901611e-01,   1.92901611e-01],
                        [  1.54663086e-01,   1.54693604e-01],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  9.63745117e-02,   9.63439941e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  6.54296875e-02,   6.53991699e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  5.31005859e-02,   5.30700684e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [ -2.74658203e-03,  -2.71606445e-03],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  8.75854492e-03,   8.78906250e-03],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.78320312e-02,  -2.78015137e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.73327637e-02,  -4.73022461e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -5.43212891e-02,  -5.43518066e-02],
                        [ -6.18286133e-02,  -6.17980957e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -6.16455078e-02,  -6.16760254e-02],
                        [ -6.59790039e-02,  -6.59484863e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -6.70166016e-02,  -6.70471191e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -2.45361328e-02,  -2.45056152e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.89001465e-02,   2.88696289e-02],
                        [  4.86450195e-02,   4.86145020e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  7.15332031e-02,   7.15026855e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -1.22528076e-01,  -1.22528076e-01],
                        [ -1.53442383e-01,  -1.53411865e-01],
                        [ -1.43341064e-01,  -1.43341064e-01],
                        [ -1.03240967e-01,  -1.03271484e-01],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -1.05895996e-02,  -1.05590820e-02],
                        [  2.05078125e-02,   2.04772949e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  5.63964844e-02,   5.63964844e-02],
                        [  5.00183105e-02,   4.99877930e-02],
                        [  1.23291016e-02,   1.22985840e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -1.47430420e-01,  -1.47399902e-01],
                        [ -2.20916748e-01,  -2.20947266e-01],
                        [ -2.50457764e-01,  -2.50488281e-01],
                        [ -2.31445312e-01,  -2.31414795e-01],
                        [ -1.82464600e-01,  -1.82464600e-01],
                        [ -1.27990723e-01,  -1.27990723e-01],
                        [ -8.60290527e-02,  -8.59985352e-02],
                        [ -6.38427734e-02,  -6.38122559e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.74548340e-02,  -4.74243164e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  2.42919922e-02,   2.42614746e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  3.06091309e-02,   3.06396484e-02],
                        [  2.54516602e-02,   2.54211426e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  1.75476074e-02,   1.75781250e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  9.78088379e-02,   9.78088379e-02],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.47399902e-01,   1.47369385e-01],
                        [  1.47583008e-01,   1.47552490e-01],
                        [  1.27960205e-01,   1.27929688e-01],
                        [  9.70764160e-02,   9.70458984e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  6.26831055e-02,   6.27136230e-02],
                        [  9.53063965e-02,   9.53674316e-02],
                        [  1.39984131e-01,   1.40045166e-01],
                        [  1.81854248e-01,   1.81884766e-01],
                        [  2.06787109e-01,   2.06817627e-01],
                        [  2.08801270e-01,   2.08862305e-01],
                        [  1.91558838e-01,   1.91619873e-01],
                        [  1.65191650e-01,   1.65222168e-01],
                        [  1.41662598e-01,   1.41632080e-01],
                        [  1.25976562e-01,   1.25915527e-01],
                        [  1.11602783e-01,   1.11541748e-01],
                        [  9.21936035e-02,   9.21020508e-02],
                        [  7.28454590e-02,   7.27539062e-02],
                        [  6.13708496e-02,   6.12792969e-02],
                        [  5.61828613e-02,   5.60913086e-02],
                        [  5.09948730e-02,   5.09033203e-02],
                        [  4.43420410e-02,   4.42810059e-02],
                        [  3.82995605e-02,   3.83300781e-02],
                        [  3.29895020e-02,   3.30505371e-02],
                        [  2.63977051e-02,   2.64587402e-02],
                        [  1.83410645e-02,   1.84936523e-02],
                        [  1.34582520e-02,   1.36108398e-02],
                        [  1.63269043e-02,   1.64489746e-02],
                        [  2.23693848e-02,   2.25524902e-02],
                        [  2.18811035e-02,   2.20336914e-02],
                        [  1.43127441e-02,   1.43432617e-02],
                        [  6.16455078e-03,   6.13403320e-03],
                        [ -2.47192383e-03,  -2.53295898e-03],
                        [ -1.53503418e-02,  -1.54724121e-02],
                        [ -2.87170410e-02,  -2.88696289e-02],
                        [ -3.49426270e-02,  -3.50952148e-02],
                        [ -3.34167480e-02,  -3.36303711e-02],
                        [ -3.03039551e-02,  -3.05175781e-02],
                        [ -2.96325684e-02,  -2.97546387e-02],
                        [ -3.07312012e-02,  -3.07922363e-02],
                        [ -3.28063965e-02,  -3.27758789e-02],
                        [ -3.62548828e-02,  -3.61633301e-02],
                        [ -4.03747559e-02,  -4.02221680e-02],
                        [ -4.47082520e-02,  -4.45251465e-02],
                        [ -5.16967773e-02,  -5.14831543e-02],
                        [ -6.23168945e-02,  -6.20117188e-02],
                        [ -6.97326660e-02,  -6.94580078e-02],
                        [ -6.73828125e-02,  -6.71997070e-02],
                        [ -6.08520508e-02,  -6.07604980e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -6.51245117e-02,  -6.52160645e-02],
                        [ -6.81762695e-02,  -6.83288574e-02],
                        [ -6.62231445e-02,  -6.64672852e-02],
                        [ -6.10046387e-02,  -6.13098145e-02],
                        [ -5.47790527e-02,  -5.51147461e-02],
                        [ -5.00183105e-02,  -5.03234863e-02],
                        [ -4.90722656e-02,  -4.93164062e-02],
                        [ -5.24597168e-02,  -5.26123047e-02],
                        [ -5.91430664e-02,  -5.91735840e-02],
                        [ -6.76879883e-02,  -6.76574707e-02],
                        [ -7.44628906e-02,  -7.43103027e-02],
                        [ -7.38525391e-02,  -7.35778809e-02],
                        [ -6.31713867e-02,  -6.27746582e-02],
                        [ -4.55017090e-02,  -4.51049805e-02],
                        [ -2.83508301e-02,  -2.79541016e-02],
                        [ -1.84631348e-02,  -1.81579590e-02],
                        [ -1.65405273e-02,  -1.63574219e-02],
                        [ -1.80664062e-02,  -1.79443359e-02],
                        [ -1.83715820e-02,  -1.83410645e-02],
                        [ -1.45568848e-02,  -1.47094727e-02],
                        [ -5.15747070e-03,  -5.43212891e-03],
                        [  1.11083984e-02,   1.07116699e-02],
                        [  3.45764160e-02,   3.41491699e-02],
                        [  6.07299805e-02,   6.03332520e-02],
                        [  7.97424316e-02,   7.94067383e-02],
                        [  8.33740234e-02,   8.30993652e-02],
                        [  6.77795410e-02,   6.75354004e-02],
                        [  2.88696289e-02,   2.87475586e-02],
                        [ -3.45153809e-02,  -3.44543457e-02],
                        [ -1.07513428e-01,  -1.07299805e-01],
                        [ -1.60400391e-01,  -1.60064697e-01],
                        [ -1.70806885e-01,  -1.70410156e-01],
                        [ -1.39556885e-01,  -1.39190674e-01],
                        [ -8.41064453e-02,  -8.37402344e-02],
                        [ -2.44445801e-02,  -2.40783691e-02],
                        [  2.52685547e-02,   2.55737305e-02],
                        [  5.88378906e-02,   5.90515137e-02],
                        [  7.49206543e-02,   7.49816895e-02],
                        [  7.08312988e-02,   7.07092285e-02],
                        [  3.90319824e-02,   3.88488770e-02],
                        [ -2.62756348e-02,  -2.65197754e-02],
                        [ -1.15905762e-01,  -1.16180420e-01],
                        [ -2.03277588e-01,  -2.03582764e-01],
                        [ -2.58605957e-01,  -2.58941650e-01],
                        [ -2.64678955e-01,  -2.65014648e-01],
                        [ -2.24578857e-01,  -2.24822998e-01],
                        [ -1.60858154e-01,  -1.60949707e-01],
                        [ -1.03607178e-01,  -1.03637695e-01],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -6.06994629e-02,  -6.06689453e-02],
                        [ -5.70068359e-02,  -5.69458008e-02],
                        [ -5.18188477e-02,  -5.16967773e-02],
                        [ -4.73327637e-02,  -4.70886230e-02],
                        [ -4.53186035e-02,  -4.51049805e-02],
                        [ -3.80249023e-02,  -3.78723145e-02],
                        [ -1.60522461e-02,  -1.59606934e-02],
                        [  1.61437988e-02,   1.62963867e-02],
                        [  4.30908203e-02,   4.32128906e-02],
                        [  5.45349121e-02,   5.46875000e-02],
                        [  5.20324707e-02,   5.21850586e-02],
                        [  4.29687500e-02,   4.30297852e-02],
                        [  3.35388184e-02,   3.35083008e-02],
                        [  2.60314941e-02,   2.60620117e-02],
                        [  2.35290527e-02,   2.35900879e-02],
                        [  3.37524414e-02,   3.37524414e-02],
                        [  6.17675781e-02,   6.16455078e-02],
                        [  1.00219727e-01,   1.00006104e-01],
                        [  1.32751465e-01,   1.32476807e-01],
                        [  1.45660400e-01,   1.45385742e-01],
                        [  1.34399414e-01,   1.34185791e-01],
                        [  1.05804443e-01,   1.05560303e-01],
                        [  7.61108398e-02,   7.57751465e-02],
                        [  5.92041016e-02,   5.88989258e-02],
                        [  5.70068359e-02,   5.68237305e-02],
                        [  6.63146973e-02,   6.62841797e-02],
                        [  8.85314941e-02,   8.86535645e-02],
                        [  1.25549316e-01,   1.25762939e-01],
                        [  1.70715332e-01,   1.70989990e-01],
                        [  2.09014893e-01,   2.09350586e-01],
                        [  2.26104736e-01,   2.26593018e-01],
                        [  2.17010498e-01,   2.17590332e-01],
                        [  1.87591553e-01,   1.88201904e-01],
                        [  1.50421143e-01,   1.50878906e-01],
                        [  1.17187500e-01,   1.17462158e-01],
                        [  9.32006836e-02,   9.32922363e-02],
                        [  7.80944824e-02,   7.80944824e-02],
                        [  6.94274902e-02,   6.93054199e-02],
                        [  6.38427734e-02,   6.35681152e-02],
                        [  5.96008301e-02,   5.90820312e-02],
                        [  5.74340820e-02,   5.67321777e-02],
                        [  5.67932129e-02,   5.60607910e-02],
                        [  5.33752441e-02,   5.27343750e-02],
                        [  4.42504883e-02,   4.37316895e-02],
                        [  3.34777832e-02,   3.30505371e-02],
                        [  2.61535645e-02,   2.58178711e-02],
                        [  2.04467773e-02,   2.02636719e-02],
                        [  1.30004883e-02,   1.30615234e-02],
                        [  7.14111328e-03,   7.50732422e-03],
                        [  6.43920898e-03,   7.01904297e-03],
                        [  6.13403320e-03,   6.77490234e-03],
                        [ -1.22070312e-04,   5.18798828e-04],
                        [ -9.55200195e-03,  -8.91113281e-03],
                        [ -1.48620605e-02,  -1.41906738e-02],
                        [ -1.58996582e-02,  -1.52282715e-02],
                        [ -1.82495117e-02,  -1.77307129e-02],
                        [ -2.45971680e-02,  -2.43530273e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -4.31213379e-02,  -4.33044434e-02],
                        [ -4.86450195e-02,  -4.88891602e-02],
                        [ -4.73327637e-02,  -4.76989746e-02],
                        [ -4.17175293e-02,  -4.22363281e-02],
                        [ -3.90014648e-02,  -3.97033691e-02],
                        [ -4.30297852e-02,  -4.37927246e-02],
                        [ -4.88891602e-02,  -4.95910645e-02],
                        [ -5.08117676e-02,  -5.13305664e-02],
                        [ -5.04760742e-02,  -5.08422852e-02],
                        [ -5.21240234e-02,  -5.24291992e-02],
                        [ -5.47790527e-02,  -5.50537109e-02],
                        [ -5.58471680e-02,  -5.59692383e-02],
                        [ -5.70678711e-02,  -5.69458008e-02],
                        [ -6.18896484e-02,  -6.15234375e-02],
                        [ -6.98547363e-02,  -6.93054199e-02],
                        [ -7.65991211e-02,  -7.60192871e-02],
                        [ -7.68432617e-02,  -7.62939453e-02],
                        [ -6.89392090e-02,  -6.83593750e-02],
                        [ -5.91735840e-02,  -5.84411621e-02],
                        [ -5.56640625e-02,  -5.49316406e-02],
                        [ -5.87158203e-02,  -5.81359863e-02],
                        [ -6.29882812e-02,  -6.26525879e-02],
                        [ -6.45446777e-02,  -6.44531250e-02],
                        [ -6.15539551e-02,  -6.16455078e-02],
                        [ -5.50537109e-02,  -5.52062988e-02],
                        [ -4.95910645e-02,  -4.98657227e-02],
                        [ -4.73632812e-02,  -4.79431152e-02],
                        [ -4.41894531e-02,  -4.50439453e-02],
                        [ -3.51257324e-02,  -3.60412598e-02],
                        [ -2.11791992e-02,  -2.20642090e-02],
                        [ -7.23266602e-03,  -7.93457031e-03],
                        [  3.99780273e-03,   3.44848633e-03],
                        [  1.34887695e-02,   1.30004883e-02],
                        [  2.46887207e-02,   2.42919922e-02],
                        [  3.98254395e-02,   3.97033691e-02],
                        [  5.66406250e-02,   5.68847656e-02],
                        [  6.96105957e-02,   7.02209473e-02],
                        [  7.30895996e-02,   7.38525391e-02],
                        [  6.18286133e-02,   6.26220703e-02],
                        [  3.15551758e-02,   3.23486328e-02],
                        [ -1.92260742e-02,  -1.83715820e-02],
                        [ -8.41064453e-02,  -8.31909180e-02],
                        [ -1.44226074e-01,  -1.43402100e-01],
                        [ -1.74621582e-01,  -1.74072266e-01],
                        [ -1.60034180e-01,  -1.59881592e-01],
                        [ -1.07391357e-01,  -1.07543945e-01],
                        [ -4.26025391e-02,  -4.28466797e-02],
                        [  9.30786133e-03,   8.94165039e-03],
                        [  4.15649414e-02,   4.10156250e-02],
                        [  6.19201660e-02,   6.11572266e-02],
                        [  7.52868652e-02,   7.43713379e-02],
                        [  7.28759766e-02,   7.18994141e-02],
                        [  3.74755859e-02,   3.67431641e-02],
                        [ -3.85742188e-02,  -3.90625000e-02],
                        [ -1.38610840e-01,  -1.38977051e-01],
                        [ -2.26470947e-01,  -2.26837158e-01],
                        [ -2.70812988e-01,  -2.71057129e-01],
                        [ -2.62969971e-01,  -2.63000488e-01],
                        [ -2.15454102e-01,  -2.15148926e-01],
                        [ -1.52709961e-01,  -1.52160645e-01],
                        [ -1.01165771e-01,  -1.00555420e-01],
                        [ -7.35168457e-02,  -7.29980469e-02],
                        [ -6.25000000e-02,  -6.19812012e-02],
                        [ -5.48095703e-02,  -5.41076660e-02],
                        [ -4.53186035e-02,  -4.44641113e-02],
                        [ -3.61328125e-02,  -3.52783203e-02],
                        [ -2.88696289e-02,  -2.81982422e-02],
                        [ -2.16979980e-02,  -2.13012695e-02],
                        [ -1.03454590e-02,  -1.01013184e-02],
                        [  7.96508789e-03,   8.14819336e-03],
                        [  2.98156738e-02,   2.99377441e-02],
                        [  4.74853516e-02,   4.73022461e-02],
                        [  5.51147461e-02,   5.45349121e-02],
                        [  5.11779785e-02,   5.02319336e-02],
                        [  3.86047363e-02,   3.74450684e-02],
                        [  2.63671875e-02,   2.52380371e-02],
                        [  2.54516602e-02,   2.43530273e-02],
                        [  4.13513184e-02,   4.01611328e-02],
                        [  7.18078613e-02,   7.05871582e-02],
                        [  1.07055664e-01,   1.06048584e-01],
                        [  1.32324219e-01,   1.31774902e-01],
                        [  1.37268066e-01,   1.37329102e-01],
                        [  1.23779297e-01,   1.24359131e-01],
                        [  1.02111816e-01,   1.03057861e-01],
                        [  8.13293457e-02,   8.25195312e-02],
                        [  6.46057129e-02,   6.61621094e-02],
                        [  5.30090332e-02,   5.49316406e-02],
                        [  5.02929688e-02,   5.24291992e-02],
                        [  6.39343262e-02,   6.58874512e-02],
                        [  9.82971191e-02,   9.97619629e-02],
                        [  1.47430420e-01,   1.48254395e-01],
                        [  1.96472168e-01,   1.96685791e-01],
                        [  2.29064941e-01,   2.28790283e-01],
                        [  2.34375000e-01,   2.33551025e-01],
                        [  2.13531494e-01,   2.11975098e-01],
                        [  1.79290771e-01,   1.77093506e-01],
                        [  1.45568848e-01,   1.42974854e-01],
                        [  1.18408203e-01,   1.15875244e-01],
                        [  9.65881348e-02,   9.44213867e-02],
                        [  7.65075684e-02,   7.48291016e-02],
                        [  5.75561523e-02,   5.63354492e-02],
                        [  4.34570312e-02,   4.28466797e-02],
                        [  3.94287109e-02,   3.96118164e-02],
                        [  4.64782715e-02,   4.76074219e-02],
                        [  5.69458008e-02,   5.89599609e-02],
                        [  5.86853027e-02,   6.11877441e-02],
                        [  4.62951660e-02,   4.88586426e-02],
                        [  2.56042480e-02,   2.80456543e-02],
                        [  6.86645508e-03,   9.12475586e-03],
                        [ -3.32641602e-03,  -1.40380859e-03],
                        [ -4.18090820e-03,  -2.80761719e-03],
                        [  7.62939453e-04,   1.28173828e-03],
                        [  6.56127930e-03,   6.01196289e-03],
                        [  1.11999512e-02,   9.73510742e-03],
                        [  1.56555176e-02,   1.37023926e-02],
                        [  1.86767578e-02,   1.65405273e-02],
                        [  1.67236328e-02,   1.44653320e-02],
                        [  7.32421875e-03,   4.97436523e-03],
                        [ -9.61303711e-03,  -1.18103027e-02],
                        [ -2.90222168e-02,  -3.07312012e-02],
                        [ -4.26330566e-02,  -4.35180664e-02],
                        [ -4.92553711e-02,  -4.91638184e-02],
                        [ -5.42907715e-02,  -5.34362793e-02],
                        [ -5.85632324e-02,  -5.73425293e-02],
                        [ -5.94482422e-02,  -5.78918457e-02],
                        [ -5.87463379e-02,  -5.69152832e-02],
                        [ -5.91735840e-02,  -5.70983887e-02],
                        [ -5.84411621e-02,  -5.64270020e-02],
                        [ -5.52978516e-02,  -5.37109375e-02],
                        [ -5.25512695e-02,  -5.17883301e-02],
                        [ -5.19104004e-02,  -5.18798828e-02],
                        [ -5.27648926e-02,  -5.31616211e-02],
                        [ -5.49011230e-02,  -5.56335449e-02],
                        [ -5.69458008e-02,  -5.79833984e-02],
                        [ -5.60913086e-02,  -5.74951172e-02],
                        [ -5.20019531e-02,  -5.37109375e-02],
                        [ -4.78820801e-02,  -4.94689941e-02],
                        [ -4.81262207e-02,  -4.92248535e-02],
                        [ -5.35888672e-02,  -5.40466309e-02],
                        [ -5.94177246e-02,  -5.93872070e-02],
                        [ -6.10656738e-02,  -6.07604980e-02],
                        [ -5.99975586e-02,  -5.94787598e-02],
                        [ -5.96313477e-02,  -5.88073730e-02],
                        [ -5.96923828e-02,  -5.84411621e-02],
                        [ -5.76782227e-02,  -5.62438965e-02],
                        [ -5.34362793e-02,  -5.22766113e-02],
                        [ -4.83093262e-02,  -4.76684570e-02],
                        [ -4.18090820e-02,  -4.16870117e-02],
                        [ -3.18908691e-02,  -3.20739746e-02],
                        [ -1.79748535e-02,  -1.82800293e-02],
                        [ -3.50952148e-03,  -4.05883789e-03],
                        [  6.98852539e-03,   6.07299805e-03],
                        [  1.58996582e-02,   1.46179199e-02],
                        [  3.07006836e-02,   2.93884277e-02],
                        [  5.21545410e-02,   5.12084961e-02],
                        [  7.13806152e-02,   7.09228516e-02],
                        [  7.95288086e-02,   7.94677734e-02],
                        [  7.32116699e-02,   7.33032227e-02],
                        [  4.87365723e-02,   4.89807129e-02],
                        [  9.76562500e-04,   1.55639648e-03],
                        [ -6.62536621e-02,  -6.52160645e-02],
                        [ -1.33605957e-01,  -1.32263184e-01],
                        [ -1.76208496e-01,  -1.74926758e-01],
                        [ -1.77490234e-01,  -1.76605225e-01],
                        [ -1.37817383e-01,  -1.37298584e-01],
                        [ -7.55310059e-02,  -7.51953125e-02],
                        [ -1.51672363e-02,  -1.48925781e-02],
                        [  2.85644531e-02,   2.86560059e-02],
                        [  5.47485352e-02,   5.43518066e-02],
                        [  6.79016113e-02,   6.70166016e-02],
                        [  6.86035156e-02,   6.74133301e-02],
                        [  5.09643555e-02,   4.98962402e-02],
                        [  8.36181641e-03,   7.56835938e-03],
                        [ -5.96313477e-02,  -6.03027344e-02],
                        [ -1.41296387e-01,  -1.42089844e-01],
                        [ -2.12036133e-01,  -2.12860107e-01],
                        [ -2.44842529e-01,  -2.45422363e-01],
                        [ -2.27386475e-01,  -2.27447510e-01],
                        [ -1.73400879e-01,  -1.72973633e-01],
                        [ -1.15661621e-01,  -1.15081787e-01],
                        [ -8.09020996e-02,  -8.04138184e-02],
                        [ -7.08312988e-02,  -7.03735352e-02],
                        [ -7.01599121e-02,  -6.94580078e-02],
                        [ -6.59179688e-02,  -6.48803711e-02],
                        [ -5.58471680e-02,  -5.46264648e-02],
                        [ -4.32128906e-02,  -4.21752930e-02],
                        [ -3.08837891e-02,  -3.02124023e-02],
                        [ -1.97448730e-02,  -1.93481445e-02],
                        [ -8.42285156e-03,  -8.02612305e-03],
                        [  5.79833984e-03,   6.25610352e-03],
                        [  2.27966309e-02,   2.30407715e-02],
                        [  3.86657715e-02,   3.83911133e-02],
                        [  4.89807129e-02,   4.81262207e-02],
                        [  5.16052246e-02,   5.04760742e-02],
                        [  4.82788086e-02,   4.71496582e-02],
                        [  4.41589355e-02,   4.30603027e-02],
                        [  4.58068848e-02,   4.45861816e-02],
                        [  5.87768555e-02,   5.72204590e-02],
                        [  8.27636719e-02,   8.11157227e-02],
                        [  1.08123779e-01,   1.06842041e-01],
                        [  1.22253418e-01,   1.21643066e-01],
                        [  1.21765137e-01,   1.21734619e-01],
                        [  1.12731934e-01,   1.13098145e-01],
                        [  1.00952148e-01,   1.01531982e-01],
                        [  8.87145996e-02,   8.96911621e-02],
                        [  7.80944824e-02,   7.97424316e-02],
                        [  6.97326660e-02,   7.20214844e-02],
                        [  6.32019043e-02,   6.57653809e-02],
                        [  6.34460449e-02,   6.57348633e-02],
                        [  7.86743164e-02,   8.04748535e-02],
                        [  1.10534668e-01,   1.11938477e-01],
                        [  1.51641846e-01,   1.52740479e-01],
                        [  1.91406250e-01,   1.92077637e-01],
                        [  2.18414307e-01,   2.18261719e-01],
                        [  2.22137451e-01,   2.20886230e-01],
                        [  2.00317383e-01,   1.98059082e-01],
                        [  1.61956787e-01,   1.59210205e-01],
                        [  1.20880127e-01,   1.18072510e-01],
                        [  8.89282227e-02,   8.61206055e-02],
                        [  7.14721680e-02,   6.86035156e-02],
                        [  6.51245117e-02,   6.23168945e-02],
                        [  6.28356934e-02,   6.05163574e-02],
                        [  6.16149902e-02,   6.03027344e-02],
                        [  6.14013672e-02,   6.14013672e-02],
                        [  5.88989258e-02,   6.00280762e-02],
                        [  4.84008789e-02,   5.02624512e-02],
                        [  3.03649902e-02,   3.27453613e-02],
                        [  1.30004883e-02,   1.60522461e-02],
                        [  2.80761719e-03,   6.53076172e-03],
                        [ -8.85009766e-04,   3.20434570e-03],
                        [ -7.93457031e-04,   3.02124023e-03],
                        [  6.40869141e-04,   3.57055664e-03],
                        [  1.03759766e-03,   2.83813477e-03],
                        [  5.49316406e-04,   1.34277344e-03],
                        [  1.37329102e-03,   1.34277344e-03],
                        [  3.23486328e-03,   2.22778320e-03],
                        [  1.67846680e-03,  -5.79833984e-04],
                        [ -6.37817383e-03,  -9.91821289e-03],
                        [ -1.75170898e-02,  -2.18505859e-02],
                        [ -2.63671875e-02,  -3.07922363e-02],
                        [ -3.16162109e-02,  -3.55834961e-02],
                        [ -3.45153809e-02,  -3.79028320e-02],
                        [ -3.68652344e-02,  -3.97338867e-02],
                        [ -4.06188965e-02,  -4.27551270e-02],
                        [ -4.57763672e-02,  -4.66918945e-02],
                        [ -5.09643555e-02,  -5.02624512e-02],
                        [ -5.54199219e-02,  -5.31311035e-02],
                        [ -5.82275391e-02,  -5.49011230e-02],
                        [ -5.92346191e-02,  -5.53894043e-02],
                        [ -5.93872070e-02,  -5.53588867e-02],
                        [ -5.96313477e-02,  -5.54504395e-02],
                        [ -6.03637695e-02,  -5.61523438e-02],
                        [ -6.03332520e-02,  -5.65795898e-02],
                        [ -5.71594238e-02,  -5.45043945e-02],
                        [ -5.12695312e-02,  -5.02014160e-02],
                        [ -4.67834473e-02,  -4.71801758e-02],
                        [ -4.71496582e-02,  -4.86145020e-02],
                        [ -5.16967773e-02,  -5.38940430e-02],
                        [ -5.64880371e-02,  -5.94482422e-02],
                        [ -5.71594238e-02,  -6.09436035e-02],
                        [ -5.17883301e-02,  -5.61218262e-02],
                        [ -4.28771973e-02,  -4.71191406e-02],
                        [ -3.58581543e-02,  -3.92761230e-02],
                        [ -3.34472656e-02,  -3.56750488e-02],
                        [ -3.48815918e-02,  -3.61022949e-02],
                        [ -3.93066406e-02,  -3.97644043e-02],
                        [ -4.40368652e-02,  -4.37316895e-02],
                        [ -4.36096191e-02,  -4.22668457e-02],
                        [ -3.64685059e-02,  -3.39660645e-02],
                        [ -2.69165039e-02,  -2.36206055e-02],
                        [ -1.77612305e-02,  -1.43737793e-02],
                        [ -6.68334961e-03,  -3.75366211e-03],
                        [  9.46044922e-03,   1.18103027e-02],
                        [  2.99377441e-02,   3.19213867e-02],
                        [  4.99877930e-02,   5.16662598e-02],
                        [  6.41784668e-02,   6.52465820e-02],
                        [  6.83898926e-02,   6.84204102e-02],
                        [  5.64575195e-02,   5.54504395e-02],
                        [  1.98669434e-02,   1.82800293e-02],
                        [ -4.16870117e-02,  -4.33349609e-02],
                        [ -1.10137939e-01,  -1.11572266e-01],
                        [ -1.56036377e-01,  -1.57409668e-01],
                        [ -1.60736084e-01,  -1.62292480e-01],
                        [ -1.30401611e-01,  -1.32049561e-01],
                        [ -8.66394043e-02,  -8.78906250e-02],
                        [ -4.67224121e-02,  -4.73022461e-02],
                        [ -1.49841309e-02,  -1.50146484e-02],
                        [  1.28784180e-02,   1.29394531e-02],
                        [  4.19616699e-02,   4.17785645e-02],
                        [  7.11669922e-02,   7.07702637e-02],
                        [  8.96606445e-02,   8.94775391e-02],
                        [  8.05969238e-02,   8.08105469e-02],
                        [  3.29895020e-02,   3.33862305e-02],
                        [ -4.78515625e-02,  -4.76379395e-02],
                        [ -1.40197754e-01,  -1.40258789e-01],
                        [ -2.13256836e-01,  -2.13226318e-01],
                        [ -2.40509033e-01,  -2.39929199e-01],
                        [ -2.16705322e-01,  -2.15393066e-01],
                        [ -1.62109375e-01,  -1.60430908e-01],
                        [ -1.08123779e-01,  -1.06506348e-01],
                        [ -7.74230957e-02,  -7.59582520e-02],
                        [ -7.04040527e-02,  -6.89086914e-02],
                        [ -6.93359375e-02,  -6.75964355e-02],
                        [ -5.99060059e-02,  -5.81970215e-02],
                        [ -4.32434082e-02,  -4.22058105e-02],
                        [ -2.63366699e-02,  -2.64282227e-02],
                        [ -1.17492676e-02,  -1.28784180e-02],
                        [  1.98364258e-03,   1.83105469e-04],
                        [  1.60827637e-02,   1.39160156e-02],
                        [  3.02124023e-02,   2.76184082e-02],
                        [  4.22668457e-02,   3.90930176e-02],
                        [  4.73632812e-02,   4.36096191e-02],
                        [  4.10156250e-02,   3.73535156e-02],
                        [  2.59704590e-02,   2.31628418e-02],
                        [  1.06811523e-02,   9.15527344e-03],
                        [  3.84521484e-03,   3.47900391e-03],
                        [  1.31835938e-02,   1.37329102e-02],
                        [  4.17175293e-02,   4.31213379e-02],
                        [  8.15734863e-02,   8.41369629e-02],
                        [  1.17492676e-01,   1.21429443e-01],
                        [  1.38000488e-01,   1.42883301e-01],
                        [  1.40808105e-01,   1.45843506e-01],
                        [  1.28753662e-01,   1.33148193e-01],
                        [  1.06262207e-01,   1.09710693e-01],
                        [  8.14514160e-02,   8.40759277e-02],
                        [  6.27136230e-02,   6.44531250e-02],
                        [  5.11779785e-02,   5.16662598e-02],
                        [  4.39758301e-02,   4.26940918e-02],
                        [  4.39758301e-02,   4.08325195e-02],
                        [  6.11572266e-02,   5.66101074e-02],
                        [  1.00585938e-01,   9.54895020e-02],
                        [  1.51397705e-01,   1.46331787e-01],
                        [  1.93023682e-01,   1.88140869e-01],
                        [  2.10510254e-01,   2.05810547e-01],
                        [  2.00531006e-01,   1.96411133e-01],
                        [  1.71691895e-01,   1.68884277e-01],
                        [  1.40869141e-01,   1.40045166e-01],
                        [  1.19720459e-01,   1.20880127e-01],
                        [  1.05224609e-01,   1.07910156e-01],
                        [  9.04541016e-02,   9.40551758e-02],
                        [  7.62634277e-02,   8.05969238e-02],
                        [  6.68640137e-02,   7.19299316e-02],
                        [  6.08825684e-02,   6.65893555e-02],
                        [  5.37109375e-02,   5.93261719e-02],
                        [  4.37316895e-02,   4.83398438e-02],
                        [  3.21655273e-02,   3.51257324e-02],
                        [  2.01721191e-02,   2.15148926e-02],
                        [  1.06506348e-02,   1.06811523e-02],
                        [  7.62939453e-03,   6.53076172e-03],
                        [  9.91821289e-03,   7.53784180e-03],
                        [  1.06506348e-02,   6.77490234e-03],
                        [  5.79833984e-03,   6.40869141e-04],
                        [ -1.92260742e-03,  -7.44628906e-03],
                        [ -8.02612305e-03,  -1.30615234e-02],
                        [ -1.08947754e-02,  -1.50451660e-02],
                        [ -1.10168457e-02,  -1.43127441e-02],
                        [ -9.42993164e-03,  -1.19628906e-02],
                        [ -8.85009766e-03,  -1.04064941e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -2.42004395e-02,  -2.23693848e-02],
                        [ -3.75671387e-02,  -3.43017578e-02],
                        [ -4.80957031e-02,  -4.41284180e-02],
                        [ -5.32531738e-02,  -4.92248535e-02],
                        [ -5.52978516e-02,  -5.13305664e-02],
                        [ -5.70983887e-02,  -5.30395508e-02],
                        [ -5.85021973e-02,  -5.45349121e-02],
                        [ -5.98754883e-02,  -5.66711426e-02],
                        [ -6.29272461e-02,  -6.10961914e-02],
                        [ -6.55822754e-02,  -6.53381348e-02],
                        [ -6.39038086e-02,  -6.48803711e-02],
                        [ -5.78918457e-02,  -5.95397949e-02],
                        [ -5.07507324e-02,  -5.27954102e-02],
                        [ -4.50744629e-02,  -4.77600098e-02],
                        [ -4.16564941e-02,  -4.51354980e-02],
                        [ -4.04663086e-02,  -4.43420410e-02],
                        [ -4.20227051e-02,  -4.55017090e-02],
                        [ -4.59594727e-02,  -4.84619141e-02],
                        [ -5.11474609e-02,  -5.26733398e-02],
                        [ -5.80444336e-02,  -5.89294434e-02],
                        [ -6.69555664e-02,  -6.75048828e-02],
                        [ -7.45849609e-02,  -7.45849609e-02],
                        [ -7.54394531e-02,  -7.44628906e-02],
                        [ -6.65588379e-02,  -6.45446777e-02],
                        [ -5.13610840e-02,  -4.87976074e-02],
                        [ -3.82080078e-02,  -3.57666016e-02],
                        [ -3.40270996e-02,  -3.20739746e-02],
                        [ -3.88488770e-02,  -3.71398926e-02],
                        [ -4.46777344e-02,  -4.28771973e-02],
                        [ -4.17175293e-02,  -3.98559570e-02],
                        [ -2.75268555e-02,  -2.61535645e-02],
                        [ -6.62231445e-03,  -6.16455078e-03],
                        [  1.69372559e-02,   1.65100098e-02],
                        [  4.12902832e-02,   4.04968262e-02],
                        [  6.40563965e-02,   6.33544922e-02],
                        [  8.05969238e-02,   7.99255371e-02],
                        [  8.26416016e-02,   8.15734863e-02],
                        [  6.04858398e-02,   5.87768555e-02],
                        [  9.67407227e-03,   7.59887695e-03],
                        [ -6.27441406e-02,  -6.45141602e-02],
                        [ -1.37603760e-01,  -1.38763428e-01],
                        [ -1.90368652e-01,  -1.91162109e-01],
                        [ -2.01232910e-01,  -2.02087402e-01],
                        [ -1.67327881e-01,  -1.68334961e-01],
                        [ -1.08764648e-01,  -1.09497070e-01],
                        [ -5.50537109e-02,  -5.49621582e-02],
                        [ -2.14233398e-02,  -2.04162598e-02],
                        [ -1.70898438e-03,  -2.44140625e-04],
                        [  1.84326172e-02,   1.98059082e-02],
                        [  4.49218750e-02,   4.61425781e-02],
                        [  6.94274902e-02,   7.08923340e-02],
                        [  7.77587891e-02,   7.97119141e-02],
                        [  6.06689453e-02,   6.28051758e-02],
                        [  1.50451660e-02,   1.67236328e-02],
                        [ -5.60913086e-02,  -5.53588867e-02],
                        [ -1.38458252e-01,  -1.38610840e-01],
                        [ -2.05902100e-01,  -2.06420898e-01],
                        [ -2.32879639e-01,  -2.33489990e-01],
                        [ -2.13134766e-01,  -2.14080811e-01],
                        [ -1.66290283e-01,  -1.67999268e-01],
                        [ -1.21337891e-01,  -1.23779297e-01],
                        [ -9.30480957e-02,  -9.56420898e-02],
                        [ -7.69348145e-02,  -7.89489746e-02],
                        [ -6.25610352e-02,  -6.36596680e-02],
                        [ -4.56848145e-02,  -4.61425781e-02],
                        [ -2.88391113e-02,  -2.90222168e-02],
                        [ -1.45874023e-02,  -1.44348145e-02],
                        [ -2.65502930e-03,  -1.77001953e-03],
                        [  7.29370117e-03,   9.18579102e-03],
                        [  1.58996582e-02,   1.85546875e-02],
                        [  2.49633789e-02,   2.75573730e-02],
                        [  3.33557129e-02,   3.52478027e-02],
                        [  3.66821289e-02,   3.77502441e-02],
                        [  3.32641602e-02,   3.38745117e-02],
                        [  2.63671875e-02,   2.67028809e-02],
                        [  2.01416016e-02,   1.98669434e-02],
                        [  1.91345215e-02,   1.77917480e-02],
                        [  3.03039551e-02,   2.78320312e-02],
                        [  5.73730469e-02,   5.44128418e-02],
                        [  9.38110352e-02,   9.11865234e-02],
                        [  1.27014160e-01,   1.25213623e-01],
                        [  1.47216797e-01,   1.46118164e-01],
                        [  1.49444580e-01,   1.48803711e-01],
                        [  1.33697510e-01,   1.33605957e-01],
                        [  1.05407715e-01,   1.06384277e-01],
                        [  7.32116699e-02,   7.55920410e-02],
                        [  4.68750000e-02,   5.03845215e-02],
                        [  3.34167480e-02,   3.71704102e-02],
                        [  3.14941406e-02,   3.46374512e-02],
                        [  3.67736816e-02,   3.90625000e-02],
                        [  5.30700684e-02,   5.46875000e-02],
                        [  8.78295898e-02,   8.88061523e-02],
                        [  1.37084961e-01,   1.36932373e-01],
                        [  1.84265137e-01,   1.82434082e-01],
                        [  2.13195801e-01,   2.09625244e-01],
                        [  2.15942383e-01,   2.11242676e-01],
                        [  1.92871094e-01,   1.88049316e-01],
                        [  1.54357910e-01,   1.50054932e-01],
                        [  1.17279053e-01,   1.13677979e-01],
                        [  9.33532715e-02,   9.03625488e-02],
                        [  8.28247070e-02,   8.08715820e-02],
                        [  7.86743164e-02,   7.84606934e-02],
                        [  7.28759766e-02,   7.49206543e-02],
                        [  6.27136230e-02,   6.68945312e-02],
                        [  5.07812500e-02,   5.61828613e-02],
                        [  3.91845703e-02,   4.49218750e-02],
                        [  2.92053223e-02,   3.47900391e-02],
                        [  2.24609375e-02,   2.78625488e-02],
                        [  1.78527832e-02,   2.27355957e-02],
                        [  1.25732422e-02,   1.61437988e-02],
                        [  7.23266602e-03,   8.60595703e-03],
                        [  3.84521484e-03,   2.59399414e-03],
                        [  1.06811523e-03,  -2.47192383e-03],
                        [ -3.05175781e-03,  -8.05664062e-03],
                        [ -6.86645508e-03,  -1.26342773e-02],
                        [ -8.36181641e-03,  -1.47399902e-02],
                        [ -9.52148438e-03,  -1.63269043e-02],
                        [ -1.18103027e-02,  -1.84326172e-02],
                        [ -1.23291016e-02,  -1.76391602e-02],
                        [ -9.79614258e-03,  -1.28173828e-02],
                        [ -9.64355469e-03,  -1.01013184e-02],
                        [ -1.69982910e-02,  -1.52893066e-02],
                        [ -2.93884277e-02,  -2.61230469e-02],
                        [ -4.12597656e-02,  -3.66821289e-02],
                        [ -5.13916016e-02,  -4.54406738e-02],
                        [ -6.08825684e-02,  -5.38635254e-02],
                        [ -6.84509277e-02,  -6.11877441e-02],
                        [ -7.17468262e-02,  -6.55212402e-02],
                        [ -7.10144043e-02,  -6.66503906e-02],
                        [ -6.77185059e-02,  -6.53381348e-02],
                        [ -6.29272461e-02,  -6.21643066e-02],
                        [ -5.74951172e-02,  -5.81665039e-02],
                        [ -5.20324707e-02,  -5.43823242e-02],
                        [ -4.78820801e-02,  -5.20935059e-02],
                        [ -4.73022461e-02,  -5.30395508e-02],
                        [ -5.03234863e-02,  -5.65795898e-02],
                        [ -5.33752441e-02,  -5.90515137e-02],
                        [ -5.41992188e-02,  -5.88378906e-02],
                        [ -5.37719727e-02,  -5.74035645e-02],
                        [ -5.29785156e-02,  -5.57861328e-02],
                        [ -5.29785156e-02,  -5.47485352e-02],
                        [ -5.59997559e-02,  -5.61523438e-02],
                        [ -5.99975586e-02,  -5.82580566e-02],
                        [ -5.79528809e-02,  -5.47180176e-02],
                        [ -4.67529297e-02,  -4.29687500e-02],
                        [ -3.28369141e-02,  -2.91442871e-02],
                        [ -2.50244141e-02,  -2.15148926e-02],
                        [ -2.49328613e-02,  -2.13623047e-02],
                        [ -2.65502930e-02,  -2.28881836e-02],
                        [ -2.32543945e-02,  -2.01110840e-02],
                        [ -1.25427246e-02,  -1.05895996e-02],
                        [  4.51660156e-03,   5.06591797e-03],
                        [  2.50549316e-02,   2.46887207e-02],
                        [  4.49829102e-02,   4.43115234e-02],
                        [  5.91430664e-02,   5.83496094e-02],
                        [  6.24084473e-02,   6.10656738e-02],
                        [  4.95910645e-02,   4.73632812e-02],
                        [  1.67846680e-02,   1.38549805e-02],
                        [ -3.50646973e-02,  -3.79943848e-02],
                        [ -9.79919434e-02,  -1.00372314e-01],
                        [ -1.55792236e-01,  -1.57684326e-01],
                        [ -1.85913086e-01,  -1.87774658e-01],
                        [ -1.74163818e-01,  -1.76239014e-01],
                        [ -1.31072998e-01,  -1.33026123e-01],
                        [ -8.32214355e-02,  -8.43200684e-02],
                        [ -4.73937988e-02,  -4.73022461e-02],
                        [ -2.17590332e-02,  -2.08129883e-02],
                        [  1.64794922e-03,   2.89916992e-03],
                        [  2.72827148e-02,   2.86865234e-02],
                        [  5.52978516e-02,   5.71594238e-02],
                        [  7.91320801e-02,   8.19091797e-02],
                        [  8.53576660e-02,   8.89282227e-02],
                        [  6.28967285e-02,   6.65283203e-02],
                        [  1.16577148e-02,   1.45874023e-02],
                        [ -5.94787598e-02,  -5.74340820e-02],
                        [ -1.36199951e-01,  -1.34765625e-01],
                        [ -1.98577881e-01,  -1.97479248e-01],
                        [ -2.25433350e-01,  -2.24914551e-01],
                        [ -2.08862305e-01,  -2.09533691e-01],
                        [ -1.64398193e-01,  -1.66595459e-01],
                        [ -1.19232178e-01,  -1.22589111e-01],
                        [ -8.78906250e-02,  -9.16137695e-02],
                        [ -6.56433105e-02,  -6.91223145e-02],
                        [ -4.36096191e-02,  -4.68750000e-02],
                        [ -2.13928223e-02,  -2.46887207e-02],
                        [ -4.24194336e-03,  -7.50732422e-03],
                        [  4.94384766e-03,   2.38037109e-03],
                        [  8.75854492e-03,   7.65991211e-03],
                        [  1.17187500e-02,   1.22680664e-02],
                        [  1.54113770e-02,   1.70898438e-02],
                        [  1.87988281e-02,   2.09655762e-02],
                        [  2.06909180e-02,   2.31933594e-02],
                        [  2.02941895e-02,   2.34069824e-02],
                        [  1.90734863e-02,   2.29492188e-02],
                        [  2.12707520e-02,   2.55126953e-02],
                        [  2.86865234e-02,   3.24096680e-02],
                        [  3.86352539e-02,   4.11987305e-02],
                        [  5.13610840e-02,   5.27648926e-02],
                        [  7.27844238e-02,   7.35168457e-02],
                        [  1.04858398e-01,   1.05163574e-01],
                        [  1.37145996e-01,   1.36779785e-01],
                        [  1.53533936e-01,   1.51947021e-01],
                        [  1.47460938e-01,   1.44622803e-01],
                        [  1.27563477e-01,   1.24023438e-01],
                        [  1.06842041e-01,   1.03424072e-01],
                        [  9.03015137e-02,   8.73413086e-02],
                        [  7.47985840e-02,   7.20825195e-02],
                        [  5.77087402e-02,   5.48706055e-02],
                        [  4.26940918e-02,   3.99169922e-02],
                        [  3.68347168e-02,   3.47900391e-02],
                        [  4.36401367e-02,   4.29382324e-02],
                        [  6.21948242e-02,   6.27746582e-02],
                        [  9.15832520e-02,   9.29260254e-02],
                        [  1.30523682e-01,   1.32141113e-01],
                        [  1.70104980e-01,   1.72088623e-01],
                        [  1.94030762e-01,   1.96777344e-01],
                        [  1.90795898e-01,   1.94519043e-01],
                        [  1.64672852e-01,   1.68792725e-01],
                        [  1.32171631e-01,   1.35894775e-01],
                        [  1.08886719e-01,   1.11663818e-01],
                        [  9.72595215e-02,   9.92126465e-02],
                        [  8.73413086e-02,   8.88366699e-02],
                        [  7.11975098e-02,   7.22656250e-02],
                        [  5.32531738e-02,   5.33142090e-02],
                        [  4.21142578e-02,   4.06188965e-02],
                        [  3.79028320e-02,   3.48815918e-02],
                        [  3.45458984e-02,   3.06701660e-02],
                        [  2.95410156e-02,   2.55737305e-02],
                        [  2.52380371e-02,   2.14843750e-02],
                        [  2.26745605e-02,   1.88903809e-02],
                        [  1.91955566e-02,   1.53198242e-02],
                        [  1.23901367e-02,   8.88061523e-03],
                        [  3.23486328e-03,   1.00708008e-03],
                        [ -4.82177734e-03,  -5.21850586e-03],
                        [ -9.82666016e-03,  -8.60595703e-03],
                        [ -1.23596191e-02,  -1.01623535e-02],
                        [ -1.36108398e-02,  -1.08642578e-02],
                        [ -1.52587891e-02,  -1.19018555e-02],
                        [ -1.93786621e-02,  -1.51367188e-02],
                        [ -2.52380371e-02,  -2.03552246e-02],
                        [ -3.08532715e-02,  -2.61535645e-02],
                        [ -3.59191895e-02,  -3.23486328e-02],
                        [ -4.01611328e-02,  -3.81164551e-02],
                        [ -4.22668457e-02,  -4.14733887e-02],
                        [ -4.32739258e-02,  -4.32434082e-02],
                        [ -4.44946289e-02,  -4.52575684e-02],
                        [ -4.40673828e-02,  -4.59899902e-02],
                        [ -4.18090820e-02,  -4.51354980e-02],
                        [ -4.21447754e-02,  -4.64172363e-02],
                        [ -4.76074219e-02,  -5.18493652e-02],
                        [ -5.59387207e-02,  -5.94177246e-02],
                        [ -6.42089844e-02,  -6.68334961e-02],
                        [ -7.07702637e-02,  -7.28759766e-02],
                        [ -7.47985840e-02,  -7.65686035e-02],
                        [ -7.65686035e-02,  -7.75756836e-02],
                        [ -7.57751465e-02,  -7.55004883e-02],
                        [ -7.05566406e-02,  -6.88781738e-02],
                        [ -6.02416992e-02,  -5.77697754e-02],
                        [ -4.89196777e-02,  -4.64782715e-02],
                        [ -4.20532227e-02,  -3.99780273e-02],
                        [ -4.07104492e-02,  -3.87268066e-02],
                        [ -4.17480469e-02,  -3.95202637e-02],
                        [ -4.25109863e-02,  -4.01611328e-02],
                        [ -4.16564941e-02,  -3.97949219e-02],
                        [ -3.84216309e-02,  -3.75671387e-02],
                        [ -3.37829590e-02,  -3.38134766e-02],
                        [ -2.99682617e-02,  -3.02124023e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -2.04162598e-02,  -2.03247070e-02],
                        [ -9.18579102e-03,  -9.55200195e-03],
                        [  5.09643555e-03,   3.96728516e-03],
                        [  2.01110840e-02,   1.85241699e-02],
                        [  3.55224609e-02,   3.41186523e-02],
                        [  4.99572754e-02,   4.89501953e-02],
                        [  5.75866699e-02,   5.65795898e-02],
                        [  4.79736328e-02,   4.63867188e-02],
                        [  1.08947754e-02,   8.66699219e-03],
                        [ -5.30090332e-02,  -5.52673340e-02],
                        [ -1.26373291e-01,  -1.27990723e-01],
                        [ -1.83227539e-01,  -1.83990479e-01],
                        [ -2.04101562e-01,  -2.04376221e-01],
                        [ -1.86828613e-01,  -1.86950684e-01],
                        [ -1.44714355e-01,  -1.44500732e-01],
                        [ -9.56420898e-02,  -9.44519043e-02],
                        [ -5.41687012e-02,  -5.16052246e-02],
                        [ -2.76489258e-02,  -2.40173340e-02],
                        [ -1.13220215e-02,  -7.47680664e-03],
                        [  8.23974609e-03,   1.16577148e-02],
                        [  3.82690430e-02,   4.11682129e-02],
                        [  7.17468262e-02,   7.43713379e-02],
                        [  9.55200195e-02,   9.77783203e-02],
                        [  1.00097656e-01,   1.01348877e-01],
                        [  8.08715820e-02,   8.02917480e-02],
                        [  3.54309082e-02,   3.28979492e-02],
                        [ -3.54309082e-02,  -3.93981934e-02],
                        [ -1.21307373e-01,  -1.25823975e-01],
                        [ -1.96441650e-01,  -2.01049805e-01],
                        [ -2.31811523e-01,  -2.36572266e-01],
                        [ -2.18963623e-01,  -2.23785400e-01],
                        [ -1.75323486e-01,  -1.79687500e-01],
                        [ -1.26159668e-01,  -1.29028320e-01],
                        [ -8.88671875e-02,  -8.94775391e-02],
                        [ -6.89086914e-02,  -6.72302246e-02],
                        [ -5.89599609e-02,  -5.56640625e-02],
                        [ -4.68750000e-02,  -4.26025391e-02],
                        [ -2.94494629e-02,  -2.43835449e-02],
                        [ -1.26953125e-02,  -6.80541992e-03],
                        [ -4.57763672e-04,   5.95092773e-03],
                        [  9.39941406e-03,   1.52587891e-02],
                        [  1.88903809e-02,   2.30712891e-02],
                        [  2.69775391e-02,   2.87780762e-02],
                        [  3.28063965e-02,   3.24401855e-02],
                        [  3.82690430e-02,   3.62548828e-02],
                        [  4.41284180e-02,   4.07409668e-02],
                        [  4.79125977e-02,   4.30297852e-02],
                        [  4.80041504e-02,   4.16870117e-02],
                        [  4.80651855e-02,   4.10461426e-02],
                        [  5.54504395e-02,   4.89501953e-02],
                        [  7.35168457e-02,   6.86950684e-02],
                        [  9.64660645e-02,   9.37194824e-02],
                        [  1.14135742e-01,   1.13220215e-01],
                        [  1.20849609e-01,   1.21551514e-01],
                        [  1.17462158e-01,   1.19842529e-01],
                        [  1.08856201e-01,   1.13220215e-01],
                        [  1.01318359e-01,   1.07421875e-01],
                        [  9.77783203e-02,   1.04644775e-01],
                        [  9.41162109e-02,   1.00433350e-01],
                        [  8.31909180e-02,   8.80126953e-02],
                        [  6.37512207e-02,   6.69555664e-02],
                        [  4.39147949e-02,   4.56848145e-02],
                        [  3.43933105e-02,   3.46374512e-02],
                        [  4.08630371e-02,   3.91540527e-02],
                        [  6.31103516e-02,   5.92041016e-02],
                        [  9.75036621e-02,   9.18273926e-02],
                        [  1.38427734e-01,   1.32202148e-01],
                        [  1.76147461e-01,   1.70532227e-01],
                        [  1.95159912e-01,   1.90704346e-01],
                        [  1.85211182e-01,   1.81884766e-01],
                        [  1.55090332e-01,   1.52893066e-01],
                        [  1.24420166e-01,   1.23748779e-01],
                        [  1.02081299e-01,   1.03546143e-01],
                        [  8.50219727e-02,   8.87145996e-02],
                        [  7.18383789e-02,   7.70263672e-02],
                        [  6.49719238e-02,   7.04650879e-02],
                        [  6.28662109e-02,   6.77795410e-02],
                        [  5.95092773e-02,   6.35986328e-02],
                        [  5.05981445e-02,   5.39550781e-02],
                        [  3.68347168e-02,   3.92150879e-02],
                        [  2.21862793e-02,   2.29187012e-02],
                        [  1.02844238e-02,   8.81958008e-03],
                        [  2.28881836e-03,  -1.22070312e-03],
                        [ -1.31225586e-03,  -5.92041016e-03],
                        [  9.15527344e-05,  -4.60815430e-03],
                        [  3.81469727e-03,  -4.57763672e-04],
                        [  5.09643555e-03,   1.22070312e-03],
                        [  3.11279297e-03,  -3.35693359e-04],
                        [  3.05175781e-05,  -2.41088867e-03],
                        [ -4.05883789e-03,  -4.76074219e-03],
                        [ -9.88769531e-03,  -8.48388672e-03],
                        [ -1.47399902e-02,  -1.16577148e-02],
                        [ -1.58081055e-02,  -1.20544434e-02],
                        [ -1.70288086e-02,  -1.32751465e-02],
                        [ -2.55432129e-02,  -2.19421387e-02],
                        [ -4.01306152e-02,  -3.65295410e-02],
                        [ -5.13000488e-02,  -4.79431152e-02],
                        [ -5.45959473e-02,  -5.22460938e-02],
                        [ -5.49011230e-02,  -5.42602539e-02],
                        [ -5.71899414e-02,  -5.83496094e-02],
                        [ -6.13403320e-02,  -6.35986328e-02],
                        [ -6.43920898e-02,  -6.69555664e-02],
                        [ -6.38122559e-02,  -6.63452148e-02],
                        [ -5.92346191e-02,  -6.19201660e-02],
                        [ -5.27343750e-02,  -5.56640625e-02],
                        [ -4.83093262e-02,  -5.10253906e-02],
                        [ -4.87060547e-02,  -5.04150391e-02],
                        [ -5.18493652e-02,  -5.21240234e-02],
                        [ -5.24597168e-02,  -5.15747070e-02],
                        [ -4.81262207e-02,  -4.68444824e-02],
                        [ -4.22973633e-02,  -4.11071777e-02],
                        [ -4.08630371e-02,  -3.97338867e-02],
                        [ -4.52270508e-02,  -4.37622070e-02],
                        [ -4.92553711e-02,  -4.75463867e-02],
                        [ -4.72717285e-02,  -4.58374023e-02],
                        [ -4.17175293e-02,  -4.12292480e-02],
                        [ -3.76892090e-02,  -3.82080078e-02],
                        [ -3.47900391e-02,  -3.57360840e-02],
                        [ -3.00292969e-02,  -3.06091309e-02],
                        [ -2.31628418e-02,  -2.32238770e-02],
                        [ -1.44958496e-02,  -1.44042969e-02],
                        [ -1.83105469e-03,  -1.92260742e-03],
                        [  1.53503418e-02,   1.52587891e-02],
                        [  3.38745117e-02,   3.43933105e-02],
                        [  5.07202148e-02,   5.20935059e-02],
                        [  6.15844727e-02,   6.34460449e-02],
                        [  5.58166504e-02,   5.72814941e-02],
                        [  2.10571289e-02,   2.15454102e-02],
                        [ -4.35180664e-02,  -4.38842773e-02],
                        [ -1.20941162e-01,  -1.21734619e-01],
                        [ -1.82922363e-01,  -1.83990479e-01],
                        [ -2.05902100e-01,  -2.07550049e-01],
                        [ -1.86798096e-01,  -1.89453125e-01],
                        [ -1.44744873e-01,  -1.48254395e-01],
                        [ -1.04766846e-01,  -1.08245850e-01],
                        [ -7.76672363e-02,  -8.01391602e-02],
                        [ -5.56030273e-02,  -5.67321777e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [  7.26318359e-03,   8.08715820e-03],
                        [  3.72619629e-02,   3.89709473e-02],
                        [  5.71594238e-02,   6.02416992e-02],
                        [  7.34863281e-02,   7.80334473e-02],
                        [  9.32617188e-02,   9.86328125e-02],
                        [  1.07910156e-01,   1.12976074e-01],
                        [  9.61914062e-02,   1.00006104e-01],
                        [  4.39453125e-02,   4.62951660e-02],
                        [ -4.17480469e-02,  -4.06494141e-02],
                        [ -1.34979248e-01,  -1.35101318e-01],
                        [ -2.03826904e-01,  -2.05627441e-01],
                        [ -2.26165771e-01,  -2.30072021e-01],
                        [ -2.01110840e-01,  -2.06878662e-01],
                        [ -1.50238037e-01,  -1.56860352e-01],
                        [ -1.04614258e-01,  -1.10839844e-01],
                        [ -8.27941895e-02,  -8.79211426e-02],
                        [ -7.81555176e-02,  -8.20312500e-02],
                        [ -7.01293945e-02,  -7.27844238e-02],
                        [ -5.01403809e-02,  -5.11474609e-02],
                        [ -3.00292969e-02,  -2.86865234e-02],
                        [ -2.22167969e-02,  -1.82189941e-02],
                        [ -2.23999023e-02,  -1.63269043e-02],
                        [ -1.86462402e-02,  -1.16577148e-02],
                        [ -6.25610352e-03,   5.49316406e-04],
                        [  1.21765137e-02,   1.83105469e-02],
                        [  3.17993164e-02,   3.71398926e-02],
                        [  4.66918945e-02,   5.09033203e-02],
                        [  5.27038574e-02,   5.49926758e-02],
                        [  5.16357422e-02,   5.11779785e-02],
                        [  5.09948730e-02,   4.76989746e-02],
                        [  5.80444336e-02,   5.26733398e-02],
                        [  7.47375488e-02,   6.83898926e-02],
                        [  9.79919434e-02,   9.14306641e-02],
                        [  1.20391846e-01,   1.13861084e-01],
                        [  1.32263184e-01,   1.26007080e-01],
                        [  1.29211426e-01,   1.23901367e-01],
                        [  1.16516113e-01,   1.13189697e-01],
                        [  1.02661133e-01,   1.02081299e-01],
                        [  9.12780762e-02,   9.33227539e-02],
                        [  8.14819336e-02,   8.53576660e-02],
                        [  7.20825195e-02,   7.69348145e-02],
                        [  6.24084473e-02,   6.79016113e-02],
                        [  5.20324707e-02,   5.81359863e-02],
                        [  4.20532227e-02,   4.83703613e-02],
                        [  3.61633301e-02,   4.17480469e-02],
                        [  3.94287109e-02,   4.31823730e-02],
                        [  5.54809570e-02,   5.68847656e-02],
                        [  8.34655762e-02,   8.28552246e-02],
                        [  1.17889404e-01,   1.15966797e-01],
                        [  1.52557373e-01,   1.49688721e-01],
                        [  1.80236816e-01,   1.76361084e-01],
                        [  1.89056396e-01,   1.84143066e-01],
                        [  1.71173096e-01,   1.65802002e-01],
                        [  1.36199951e-01,   1.31408691e-01],
                        [  1.03942871e-01,   1.00616455e-01],
                        [  8.42895508e-02,   8.25805664e-02],
                        [  7.40966797e-02,   7.35473633e-02],
                        [  6.92443848e-02,   6.93969727e-02],
                        [  6.80847168e-02,   6.90307617e-02],
                        [  6.60400391e-02,   6.81152344e-02],
                        [  5.65185547e-02,   5.97229004e-02],
                        [  3.85742188e-02,   4.22363281e-02],
                        [  1.89819336e-02,   2.21557617e-02],
                        [  5.24902344e-03,   7.44628906e-03],
                        [ -2.53295898e-03,  -1.09863281e-03],
                        [ -9.85717773e-03,  -8.69750977e-03],
                        [ -1.87988281e-02,  -1.77612305e-02],
                        [ -2.52990723e-02,  -2.48413086e-02],
                        [ -2.55737305e-02,  -2.60925293e-02],
                        [ -1.96228027e-02,  -2.10266113e-02],
                        [ -1.00402832e-02,  -1.15966797e-02],
                        [ -6.10351562e-05,  -1.19018555e-03],
                        [  6.95800781e-03,   6.31713867e-03],
                        [  7.87353516e-03,   7.14111328e-03],
                        [  1.22070312e-03,   3.05175781e-05],
                        [ -1.03759766e-02,  -1.18408203e-02],
                        [ -2.26135254e-02,  -2.38037109e-02],
                        [ -3.37829590e-02,  -3.43322754e-02],
                        [ -4.35485840e-02,  -4.37011719e-02],
                        [ -5.11779785e-02,  -5.16052246e-02],
                        [ -5.76477051e-02,  -5.85021973e-02],
                        [ -6.45751953e-02,  -6.54296875e-02],
                        [ -7.04345703e-02,  -7.05871582e-02],
                        [ -7.11059570e-02,  -7.03430176e-02],
                        [ -6.61315918e-02,  -6.48498535e-02],
                        [ -6.05163574e-02,  -5.92956543e-02],
                        [ -5.81970215e-02,  -5.71289062e-02],
                        [ -5.68542480e-02,  -5.55114746e-02],
                        [ -5.27954102e-02,  -5.08117676e-02],
                        [ -4.70581055e-02,  -4.46777344e-02],
                        [ -4.34570312e-02,  -4.14733887e-02],
                        [ -4.37927246e-02,  -4.28466797e-02],
                        [ -4.63256836e-02,  -4.64172363e-02],
                        [ -4.76684570e-02,  -4.83093262e-02],
                        [ -4.60205078e-02,  -4.68139648e-02],
                        [ -4.29077148e-02,  -4.40979004e-02],
                        [ -4.07409668e-02,  -4.27551270e-02],
                        [ -3.89404297e-02,  -4.18701172e-02],
                        [ -3.40881348e-02,  -3.72924805e-02],
                        [ -2.41394043e-02,  -2.67028809e-02],
                        [ -1.10778809e-02,  -1.26037598e-02],
                        [  1.89208984e-03,   1.22070312e-03],
                        [  1.37329102e-02,   1.34887695e-02],
                        [  2.44750977e-02,   2.46276855e-02],
                        [  3.29589844e-02,   3.39050293e-02],
                        [  3.84826660e-02,   4.06188965e-02],
                        [  4.10766602e-02,   4.41284180e-02],
                        [  3.61633301e-02,   3.93066406e-02],
                        [  1.25732422e-02,   1.50146484e-02],
                        [ -3.69262695e-02,  -3.52783203e-02],
                        [ -1.02355957e-01,  -1.01196289e-01],
                        [ -1.59790039e-01,  -1.58813477e-01],
                        [ -1.88568115e-01,  -1.88049316e-01],
                        [ -1.84234619e-01,  -1.84722900e-01],
                        [ -1.56158447e-01,  -1.57836914e-01],
                        [ -1.18957520e-01,  -1.21276855e-01],
                        [ -8.59985352e-02,  -8.81347656e-02],
                        [ -6.26220703e-02,  -6.41174316e-02],
                        [ -4.40368652e-02,  -4.50744629e-02],
                        [ -2.41699219e-02,  -2.52380371e-02],
                        [ -2.25830078e-03,  -3.41796875e-03],
                        [  2.20336914e-02,   2.13012695e-02],
                        [  5.05371094e-02,   5.06896973e-02],
                        [  7.99560547e-02,   8.08715820e-02],
                        [  1.01745605e-01,   1.02691650e-01],
                        [  1.08489990e-01,   1.08856201e-01],
                        [  9.39025879e-02,   9.36889648e-02],
                        [  4.94995117e-02,   4.91943359e-02],
                        [ -2.74963379e-02,  -2.74353027e-02],
                        [ -1.20513916e-01,  -1.20208740e-01],
                        [ -1.96807861e-01,  -1.96746826e-01],
                        [ -2.28790283e-01,  -2.29125977e-01],
                        [ -2.11425781e-01,  -2.11730957e-01],
                        [ -1.62963867e-01,  -1.62475586e-01],
                        [ -1.12396240e-01,  -1.10809326e-01],
                        [ -8.01391602e-02,  -7.78503418e-02],
                        [ -6.57348633e-02,  -6.35070801e-02],
                        [ -5.68542480e-02,  -5.49926758e-02],
                        [ -4.79125977e-02,  -4.62646484e-02],
                        [ -4.25720215e-02,  -4.08935547e-02],
                        [ -3.94592285e-02,  -3.80249023e-02],
                        [ -2.83203125e-02,  -2.78930664e-02],
                        [ -5.34057617e-03,  -6.65283203e-03],
                        [  2.00195312e-02,   1.70593262e-02],
                        [  3.77807617e-02,   3.38745117e-02],
                        [  4.63562012e-02,   4.22058105e-02],
                        [  4.75769043e-02,   4.34265137e-02],
                        [  4.25109863e-02,   3.82690430e-02],
                        [  3.49121094e-02,   3.07312012e-02],
                        [  3.27148438e-02,   2.93579102e-02],
                        [  4.24499512e-02,   4.10156250e-02],
                        [  6.39343262e-02,   6.49108887e-02],
                        [  9.18884277e-02,   9.49707031e-02],
                        [  1.19628906e-01,   1.24084473e-01],
                        [  1.38580322e-01,   1.43859863e-01],
                        [  1.40563965e-01,   1.46606445e-01],
                        [  1.25122070e-01,   1.31805420e-01],
                        [  1.02325439e-01,   1.08978271e-01],
                        [  8.49304199e-02,   9.03930664e-02],
                        [  7.82470703e-02,   8.13903809e-02],
                        [  7.78808594e-02,   7.83386230e-02],
                        [  7.55920410e-02,   7.37304688e-02],
                        [  6.56433105e-02,   6.20422363e-02],
                        [  4.85229492e-02,   4.33959961e-02],
                        [  3.17687988e-02,   2.50244141e-02],
                        [  2.49633789e-02,   1.69677734e-02],
                        [  3.29589844e-02,   2.47802734e-02],
                        [  5.52978516e-02,   4.83398438e-02],
                        [  9.03015137e-02,   8.55712891e-02],
                        [  1.34033203e-01,   1.31713867e-01],
                        [  1.73431396e-01,   1.73187256e-01],
                        [  1.89178467e-01,   1.90826416e-01],
                        [  1.73370361e-01,   1.77154541e-01],
                        [  1.38397217e-01,   1.44378662e-01],
                        [  1.03607178e-01,   1.11236572e-01],
                        [  7.94372559e-02,   8.74633789e-02],
                        [  6.57348633e-02,   7.28149414e-02],
                        [  5.88684082e-02,   6.43310547e-02],
                        [  5.62438965e-02,   6.00585938e-02],
                        [  5.52978516e-02,   5.75866699e-02],
                        [  5.23071289e-02,   5.28564453e-02],
                        [  4.45861816e-02,   4.28466797e-02],
                        [  3.27453613e-02,   2.86865234e-02],
                        [  2.01721191e-02,   1.45263672e-02],
                        [  9.42993164e-03,   3.35693359e-03],
                        [  1.22070312e-04,  -5.43212891e-03],
                        [ -7.78198242e-03,  -1.25427246e-02],
                        [ -1.17187500e-02,  -1.58386230e-02],
                        [ -1.17187500e-02,  -1.51062012e-02],
                        [ -1.26953125e-02,  -1.47399902e-02],
                        [ -1.80358887e-02,  -1.82189941e-02],
                        [ -2.51770020e-02,  -2.35290527e-02],
                        [ -2.95410156e-02,  -2.68249512e-02],
                        [ -2.97546387e-02,  -2.69165039e-02],
                        [ -2.75268555e-02,  -2.49023438e-02],
                        [ -2.35290527e-02,  -2.09045410e-02],
                        [ -1.84631348e-02,  -1.55944824e-02],
                        [ -1.62658691e-02,  -1.34277344e-02],
                        [ -2.10876465e-02,  -1.89208984e-02],
                        [ -3.27453613e-02,  -3.16467285e-02],
                        [ -4.81262207e-02,  -4.77905273e-02],
                        [ -6.23779297e-02,  -6.20727539e-02],
                        [ -7.02514648e-02,  -6.95190430e-02],
                        [ -7.09533691e-02,  -7.00378418e-02],
                        [ -6.86645508e-02,  -6.81457520e-02],
                        [ -6.68945312e-02,  -6.70776367e-02],
                        [ -6.62231445e-02,  -6.68334961e-02],
                        [ -6.60705566e-02,  -6.66809082e-02],
                        [ -6.53381348e-02,  -6.59179688e-02],
                        [ -6.21337891e-02,  -6.32934570e-02],
                        [ -5.57556152e-02,  -5.81054688e-02],
                        [ -4.83703613e-02,  -5.19104004e-02],
                        [ -4.22058105e-02,  -4.62036133e-02],
                        [ -3.67736816e-02,  -4.04968262e-02],
                        [ -3.11279297e-02,  -3.42407227e-02],
                        [ -2.62756348e-02,  -2.89306641e-02],
                        [ -2.45056152e-02,  -2.67333984e-02],
                        [ -2.67639160e-02,  -2.80456543e-02],
                        [ -3.00598145e-02,  -2.95104980e-02],
                        [ -2.92053223e-02,  -2.63977051e-02],
                        [ -2.24304199e-02,  -1.76696777e-02],
                        [ -1.25122070e-02,  -6.77490234e-03],
                        [ -2.19726562e-03,   3.81469727e-03],
                        [  9.64355469e-03,   1.56555176e-02],
                        [  2.58789062e-02,   3.18298340e-02],
                        [  4.57153320e-02,   5.10864258e-02],
                        [  6.04248047e-02,   6.41479492e-02],
                        [  5.50842285e-02,   5.61828613e-02],
                        [  1.83715820e-02,   1.65710449e-02],
                        [ -4.56237793e-02,  -4.98046875e-02],
                        [ -1.17462158e-01,  -1.23199463e-01],
                        [ -1.74987793e-01,  -1.81793213e-01],
                        [ -2.02301025e-01,  -2.09960938e-01],
                        [ -1.93389893e-01,  -2.01538086e-01],
                        [ -1.57775879e-01,  -1.65405273e-01],
                        [ -1.16607666e-01,  -1.22375488e-01],
                        [ -8.55102539e-02,  -8.83789062e-02],
                        [ -6.50634766e-02,  -6.49414062e-02],
                        [ -4.94079590e-02,  -4.68444824e-02],
                        [ -3.54309082e-02,  -3.10058594e-02],
                        [ -1.95312500e-02,  -1.33361816e-02],
                        [  6.83593750e-03,   1.46179199e-02],
                        [  4.64172363e-02,   5.51452637e-02],
                        [  8.74938965e-02,   9.58251953e-02],
                        [  1.16882324e-01,   1.23382568e-01],
                        [  1.31988525e-01,   1.35894775e-01],
                        [  1.29638672e-01,   1.30981445e-01],
                        [  9.66491699e-02,   9.57946777e-02],
                        [  2.33459473e-02,   2.04772949e-02],
                        [ -7.89489746e-02,  -8.39538574e-02],
                        [ -1.78833008e-01,  -1.85760498e-01],
                        [ -2.40814209e-01,  -2.48779297e-01],
                        [ -2.44537354e-01,  -2.52075195e-01],
                        [ -1.98486328e-01,  -2.04345703e-01],
                        [ -1.36718750e-01,  -1.40502930e-01],
                        [ -9.19189453e-02,  -9.37194824e-02],
                        [ -6.96411133e-02,  -6.96716309e-02],
                        [ -5.48400879e-02,  -5.28869629e-02],
                        [ -3.75061035e-02,  -3.33251953e-02],
                        [ -2.21862793e-02,  -1.61743164e-02],
                        [ -1.58691406e-02,  -9.15527344e-03],
                        [ -1.56860352e-02,  -9.64355469e-03],
                        [ -1.29394531e-02,  -8.39233398e-03],
                        [ -3.72314453e-03,  -7.93457031e-04],
                        [  1.04370117e-02,   1.19018555e-02],
                        [  2.68554688e-02,   2.67333984e-02],
                        [  4.10156250e-02,   3.89404297e-02],
                        [  4.77905273e-02,   4.36096191e-02],
                        [  4.71801758e-02,   4.15649414e-02],
                        [  4.61730957e-02,   4.03442383e-02],
                        [  5.19714355e-02,   4.70581055e-02],
                        [  6.55212402e-02,   6.20117188e-02],
                        [  8.36181641e-02,   8.14208984e-02],
                        [  1.03179932e-01,   1.02233887e-01],
                        [  1.19628906e-01,   1.20361328e-01],
                        [  1.27502441e-01,   1.30310059e-01],
                        [  1.26007080e-01,   1.30767822e-01],
                        [  1.19628906e-01,   1.25427246e-01],
                        [  1.12762451e-01,   1.18347168e-01],
                        [  1.06964111e-01,   1.11541748e-01],
                        [  9.99450684e-02,   1.03302002e-01],
                        [  8.68225098e-02,   8.91113281e-02],
                        [  6.70166016e-02,   6.79626465e-02],
                        [  4.76074219e-02,   4.66003418e-02],
                        [  3.68041992e-02,   3.35388184e-02],
                        [  3.53088379e-02,   3.01818848e-02],
                        [  3.82995605e-02,   3.24096680e-02],
                        [  4.48608398e-02,   3.92761230e-02],
                        [  5.95703125e-02,   5.47485352e-02],
                        [  8.53576660e-02,   8.12988281e-02],
                        [  1.18835449e-01,   1.15661621e-01],
                        [  1.50299072e-01,   1.48559570e-01],
                        [  1.67877197e-01,   1.68304443e-01],
                        [  1.65832520e-01,   1.68609619e-01],
                        [  1.48559570e-01,   1.53015137e-01],
                        [  1.26373291e-01,   1.31500244e-01],
                        [  1.07543945e-01,   1.12640381e-01],
                        [  9.26818848e-02,   9.76257324e-02],
                        [  7.80029297e-02,   8.27941895e-02],
                        [  6.19812012e-02,   6.62231445e-02],
                        [  4.51049805e-02,   4.79736328e-02],
                        [  2.81982422e-02,   2.90222168e-02],
                        [  1.46179199e-02,   1.33666992e-02],
                        [  7.53784180e-03,   4.91333008e-03],
                        [  5.06591797e-03,   1.83105469e-03],
                        [  2.80761719e-03,  -8.54492188e-04],
                        [ -1.52587891e-04,  -4.36401367e-03],
                        [ -1.15966797e-03,  -5.85937500e-03],
                        [  9.15527344e-05,  -4.51660156e-03],
                        [ -4.27246094e-04,  -3.99780273e-03],
                        [ -4.42504883e-03,  -6.46972656e-03],
                        [ -9.36889648e-03,  -1.00402832e-02],
                        [ -1.41296387e-02,  -1.40380859e-02],
                        [ -1.96228027e-02,  -1.90429688e-02],
                        [ -2.38952637e-02,  -2.26135254e-02],
                        [ -2.45971680e-02,  -2.22473145e-02],
                        [ -2.45971680e-02,  -2.12707520e-02],
                        [ -2.94799805e-02,  -2.59094238e-02],
                        [ -3.94592285e-02,  -3.64074707e-02],
                        [ -4.91943359e-02,  -4.68139648e-02],
                        [ -5.71594238e-02,  -5.50842285e-02],
                        [ -6.61621094e-02,  -6.40258789e-02],
                        [ -7.37915039e-02,  -7.17773438e-02],
                        [ -7.35778809e-02,  -7.22961426e-02],
                        [ -6.54296875e-02,  -6.52770996e-02],
                        [ -5.58471680e-02,  -5.66711426e-02],
                        [ -5.04760742e-02,  -5.16357422e-02],
                        [ -4.95910645e-02,  -5.07202148e-02],
                        [ -4.90112305e-02,  -5.03845215e-02],
                        [ -4.54406738e-02,  -4.76074219e-02],
                        [ -4.15039062e-02,  -4.45556641e-02],
                        [ -4.35485840e-02,  -4.69665527e-02],
                        [ -5.33142090e-02,  -5.63964844e-02],
                        [ -6.36596680e-02,  -6.60705566e-02],
                        [ -6.50634766e-02,  -6.70776367e-02],
                        [ -5.58166504e-02,  -5.77392578e-02],
                        [ -4.19921875e-02,  -4.36706543e-02],
                        [ -2.98461914e-02,  -3.06091309e-02],
                        [ -2.09350586e-02,  -2.02026367e-02],
                        [ -1.35192871e-02,  -1.13525391e-02],
                        [ -6.71386719e-03,  -3.72314453e-03],
                        [ -1.15966797e-03,   2.10571289e-03],
                        [  5.06591797e-03,   8.54492188e-03],
                        [  1.66320801e-02,   2.05993652e-02],
                        [  3.47290039e-02,   3.92150879e-02],
                        [  5.21545410e-02,   5.64880371e-02],
                        [  5.49621582e-02,   5.81970215e-02],
                        [  3.10058594e-02,   3.26232910e-02],
                        [ -2.21862793e-02,  -2.20336914e-02],
                        [ -9.48181152e-02,  -9.56726074e-02],
                        [ -1.66320801e-01,  -1.67999268e-01],
                        [ -2.11975098e-01,  -2.14813232e-01],
                        [ -2.15637207e-01,  -2.19879150e-01],
                        [ -1.80603027e-01,  -1.85974121e-01],
                        [ -1.30371094e-01,  -1.35986328e-01],
                        [ -9.19799805e-02,  -9.68627930e-02],
                        [ -7.31201172e-02,  -7.69348145e-02],
                        [ -6.17980957e-02,  -6.46972656e-02],
                        [ -4.67224121e-02,  -4.88586426e-02],
                        [ -2.73132324e-02,  -2.83203125e-02],
                        [ -6.40869141e-03,  -5.73730469e-03],
                        [  1.46789551e-02,   1.73034668e-02],
                        [  3.71093750e-02,   4.12597656e-02],
                        [  6.48803711e-02,   6.96716309e-02],
                        [  9.97924805e-02,   1.04583740e-01],
                        [  1.32904053e-01,   1.37542725e-01],
                        [  1.43890381e-01,   1.48590088e-01],
                        [  1.14715576e-01,   1.19232178e-01],
                        [  4.31823730e-02,   4.67834473e-02],
                        [ -5.62744141e-02,  -5.43518066e-02],
                        [ -1.57196045e-01,  -1.57165527e-01],
                        [ -2.27539062e-01,  -2.28912354e-01],
                        [ -2.45971680e-01,  -2.48107910e-01],
                        [ -2.16491699e-01,  -2.19268799e-01],
                        [ -1.63360596e-01,  -1.66992188e-01],
                        [ -1.13067627e-01,  -1.17675781e-01],
                        [ -7.99865723e-02,  -8.51135254e-02],
                        [ -6.13098145e-02,  -6.60400391e-02],
                        [ -4.58679199e-02,  -4.95300293e-02],
                        [ -2.93579102e-02,  -3.18908691e-02],
                        [ -1.72729492e-02,  -1.90429688e-02],
                        [ -1.24511719e-02,  -1.36718750e-02],
                        [ -8.97216797e-03,  -9.27734375e-03],
                        [ -1.03759766e-03,   9.15527344e-05],
                        [  1.04675293e-02,   1.30920410e-02],
                        [  2.23388672e-02,   2.59094238e-02],
                        [  3.03344727e-02,   3.40881348e-02],
                        [  2.89001465e-02,   3.24707031e-02],
                        [  1.88293457e-02,   2.23693848e-02],
                        [  1.18408203e-02,   1.56250000e-02],
                        [  2.18505859e-02,   2.56042480e-02],
                        [  5.27038574e-02,   5.57250977e-02],
                        [  9.49401855e-02,   9.66186523e-02],
                        [  1.32995605e-01,   1.33300781e-01],
                        [  1.54388428e-01,   1.53778076e-01],
                        [  1.54510498e-01,   1.53411865e-01],
                        [  1.38366699e-01,   1.36688232e-01],
                        [  1.18377686e-01,   1.15661621e-01],
                        [  1.05377197e-01,   1.01562500e-01],
                        [  1.01165771e-01,   9.67407227e-02],
                        [  9.92431641e-02,   9.50622559e-02],
                        [  9.25598145e-02,   8.91113281e-02],
                        [  8.04748535e-02,   7.76672363e-02],
                        [  6.70776367e-02,   6.46667480e-02],
                        [  5.38330078e-02,   5.18798828e-02],
                        [  3.82080078e-02,   3.72314453e-02],
                        [  2.02026367e-02,   2.07824707e-02],
                        [  7.17163086e-03,   9.30786133e-03],
                        [  1.06811523e-02,   1.37634277e-02],
                        [  3.73229980e-02,   4.07409668e-02],
                        [  8.28247070e-02,   8.63342285e-02],
                        [  1.33636475e-01,   1.37451172e-01],
                        [  1.72058105e-01,   1.76239014e-01],
                        [  1.83715820e-01,   1.87805176e-01],
                        [  1.67755127e-01,   1.70928955e-01],
                        [  1.38397217e-01,   1.40075684e-01],
                        [  1.12701416e-01,   1.12976074e-01],
                        [  9.68627930e-02,   9.62829590e-02],
                        [  8.59375000e-02,   8.47473145e-02],
                        [  7.49511719e-02,   7.29370117e-02],
                        [  6.33850098e-02,   6.02722168e-02],
                        [  4.96520996e-02,   4.55322266e-02],
                        [  3.21960449e-02,   2.77709961e-02],
                        [  1.47094727e-02,   1.08032227e-02],
                        [  1.95312500e-03,  -1.06811523e-03],
                        [ -5.43212891e-03,  -7.75146484e-03],
                        [ -8.78906250e-03,  -1.06811523e-02],
                        [ -8.78906250e-03,  -1.01013184e-02],
                        [ -5.82885742e-03,  -6.04248047e-03],
                        [ -2.01416016e-03,  -7.62939453e-04],
                        [ -2.19726562e-03,   2.74658203e-04],
                        [ -8.57543945e-03,  -5.58471680e-03],
                        [ -1.61132812e-02,  -1.31835938e-02],
                        [ -1.84020996e-02,  -1.55639648e-02],
                        [ -1.64184570e-02,  -1.33666992e-02],
                        [ -1.71813965e-02,  -1.38854980e-02],
                        [ -2.52990723e-02,  -2.22778320e-02],
                        [ -3.76586914e-02,  -3.55834961e-02],
                        [ -4.66003418e-02,  -4.57153320e-02],
                        [ -4.77905273e-02,  -4.78210449e-02],
                        [ -4.51965332e-02,  -4.56237793e-02],
                        [ -4.63562012e-02,  -4.70581055e-02],
                        [ -5.16357422e-02,  -5.29785156e-02],
                        [ -5.39245605e-02,  -5.62438965e-02],
                        [ -5.07507324e-02,  -5.38635254e-02],
                        [ -4.72717285e-02,  -5.05676270e-02],
                        [ -4.70886230e-02,  -4.99877930e-02],
                        [ -4.89196777e-02,  -5.13305664e-02],
                        [ -5.13610840e-02,  -5.35888672e-02],
                        [ -5.52673340e-02,  -5.74951172e-02],
                        [ -6.19506836e-02,  -6.38427734e-02],
                        [ -6.97021484e-02,  -7.06176758e-02],
                        [ -7.37609863e-02,  -7.33337402e-02],
                        [ -7.10754395e-02,  -6.95190430e-02],
                        [ -6.30493164e-02,  -6.09436035e-02],
                        [ -5.27954102e-02,  -5.04150391e-02],
                        [ -4.22058105e-02,  -3.93676758e-02],
                        [ -3.10974121e-02,  -2.75268555e-02],
                        [ -1.89514160e-02,  -1.48010254e-02],
                        [ -7.08007812e-03,  -3.05175781e-03],
                        [  2.92968750e-03,   6.01196289e-03],
                        [  1.22375488e-02,   1.40991211e-02],
                        [  2.34069824e-02,   2.42614746e-02],
                        [  3.69262695e-02,   3.70483398e-02],
                        [  4.99267578e-02,   4.91333008e-02],
                        [  5.52368164e-02,   5.30700684e-02],
                        [  4.20532227e-02,   3.83605957e-02],
                        [  2.89916992e-03,  -1.89208984e-03],
                        [ -5.87158203e-02,  -6.37817383e-02],
                        [ -1.29760742e-01,  -1.34338379e-01],
                        [ -1.91284180e-01,  -1.95159912e-01],
                        [ -2.21099854e-01,  -2.24365234e-01],
                        [ -2.07916260e-01,  -2.10418701e-01],
                        [ -1.66381836e-01,  -1.67510986e-01],
                        [ -1.24786377e-01,  -1.23992920e-01],
                        [ -9.79919434e-02,  -9.51843262e-02],
                        [ -8.16650391e-02,  -7.74230957e-02],
                        [ -6.62231445e-02,  -6.13403320e-02],
                        [ -4.60815430e-02,  -4.10766602e-02],
                        [ -2.11486816e-02,  -1.61437988e-02],
                        [  3.99780273e-03,   8.94165039e-03],
                        [  2.56958008e-02,   2.99987793e-02],
                        [  4.79431152e-02,   5.07202148e-02],
                        [  7.76062012e-02,   7.82470703e-02],
                        [  1.11175537e-01,   1.09741211e-01],
                        [  1.34674072e-01,   1.31744385e-01],
                        [  1.35986328e-01,   1.32141113e-01],
                        [  1.08306885e-01,   1.03729248e-01],
                        [  4.66003418e-02,   4.13513184e-02],
                        [ -4.49218750e-02,  -5.05371094e-02],
                        [ -1.44042969e-01,  -1.49139404e-01],
                        [ -2.18017578e-01,  -2.21649170e-01],
                        [ -2.42431641e-01,  -2.44110107e-01],
                        [ -2.16339111e-01,  -2.16186523e-01],
                        [ -1.62902832e-01,  -1.61407471e-01],
                        [ -1.12335205e-01,  -1.09741211e-01],
                        [ -8.02612305e-02,  -7.65380859e-02],
                        [ -6.25305176e-02,  -5.77087402e-02],
                        [ -4.81872559e-02,  -4.27856445e-02],
                        [ -3.19213867e-02,  -2.70080566e-02],
                        [ -1.59606934e-02,  -1.23596191e-02],
                        [ -5.12695312e-03,  -3.11279297e-03],
                        [ -1.22070312e-03,  -5.49316406e-04],
                        [  3.66210938e-04,  -6.10351562e-05],
                        [  6.28662109e-03,   4.69970703e-03],
                        [  1.71508789e-02,   1.42211914e-02],
                        [  2.73132324e-02,   2.31628418e-02],
                        [  3.28063965e-02,   2.81982422e-02],
                        [  3.49426270e-02,   3.08532715e-02],
                        [  3.79333496e-02,   3.49731445e-02],
                        [  4.66918945e-02,   4.48608398e-02],
                        [  6.44531250e-02,   6.34765625e-02],
                        [  8.87756348e-02,   8.87145996e-02],
                        [  1.12518311e-01,   1.13616943e-01],
                        [  1.29364014e-01,   1.31805420e-01],
                        [  1.36047363e-01,   1.39495850e-01],
                        [  1.31500244e-01,   1.35162354e-01],
                        [  1.20300293e-01,   1.23382568e-01],
                        [  1.13098145e-01,   1.15295410e-01],
                        [  1.14318848e-01,   1.15783691e-01],
                        [  1.14501953e-01,   1.15386963e-01],
                        [  1.03576660e-01,   1.03668213e-01],
                        [  8.47778320e-02,   8.37097168e-02],
                        [  6.64367676e-02,   6.42089844e-02],
                        [  4.86755371e-02,   4.58068848e-02],
                        [  2.87170410e-02,   2.59704590e-02],
                        [  1.07727051e-02,   8.66699219e-03],
                        [  2.10571289e-03,   7.01904297e-04],
                        [  6.25610352e-03,   5.21850586e-03],
                        [  2.44445801e-02,   2.38342285e-02],
                        [  5.67321777e-02,   5.69152832e-02],
                        [  9.86328125e-02,   9.98535156e-02],
                        [  1.40258789e-01,   1.42364502e-01],
                        [  1.68762207e-01,   1.71051025e-01],
                        [  1.73675537e-01,   1.75537109e-01],
                        [  1.55761719e-01,   1.57012939e-01],
                        [  1.27746582e-01,   1.28540039e-01],
                        [  1.02539062e-01,   1.03118896e-01],
                        [  8.37402344e-02,   8.39538574e-02],
                        [  6.92749023e-02,   6.86950684e-02],
                        [  5.76171875e-02,   5.61523438e-02],
                        [  4.74243164e-02,   4.55017090e-02],
                        [  3.61938477e-02,   3.45153809e-02],
                        [  2.47497559e-02,   2.36816406e-02],
                        [  1.74255371e-02,   1.69067383e-02],
                        [  1.48620605e-02,   1.45874023e-02],
                        [  1.17187500e-02,   1.16271973e-02],
                        [  4.05883789e-03,   4.39453125e-03],
                        [ -6.22558594e-03,  -5.12695312e-03],
                        [ -1.47399902e-02,  -1.30615234e-02],
                        [ -2.02331543e-02,  -1.85852051e-02],
                        [ -2.45971680e-02,  -2.35290527e-02],
                        [ -2.82592773e-02,  -2.78930664e-02],
                        [ -2.76794434e-02,  -2.77709961e-02],
                        [ -1.98974609e-02,  -2.01721191e-02],
                        [ -9.09423828e-03,  -9.58251953e-03],
                        [ -4.57763672e-03,  -5.61523438e-03],
                        [ -1.06811523e-02,  -1.23291016e-02],
                        [ -2.18505859e-02,  -2.36816406e-02],
                        [ -3.03649902e-02,  -3.17382812e-02],
                        [ -3.42712402e-02,  -3.48205566e-02],
                        [ -3.63159180e-02,  -3.61328125e-02],
                        [ -4.09240723e-02,  -4.03747559e-02],
                        [ -5.19714355e-02,  -5.12084961e-02],
                        [ -6.75048828e-02,  -6.63757324e-02],
                        [ -7.86437988e-02,  -7.69348145e-02],
                        [ -7.90100098e-02,  -7.68737793e-02],
                        [ -7.17468262e-02,  -6.98242188e-02],
                        [ -6.44226074e-02,  -6.33239746e-02],
                        [ -6.02416992e-02,  -6.00891113e-02],
                        [ -5.80139160e-02,  -5.85632324e-02],
                        [ -5.55419922e-02,  -5.64575195e-02],
                        [ -4.99877930e-02,  -5.12695312e-02],
                        [ -4.03442383e-02,  -4.22058105e-02],
                        [ -3.20434570e-02,  -3.44848633e-02],
                        [ -3.20739746e-02,  -3.46374512e-02],
                        [ -3.85742188e-02,  -4.05273438e-02],
                        [ -4.19616699e-02,  -4.28466797e-02],
                        [ -3.57971191e-02,  -3.57055664e-02],
                        [ -2.11486816e-02,  -2.03857422e-02],
                        [ -2.19726562e-03,  -9.46044922e-04],
                        [  1.72729492e-02,   1.91345215e-02],
                        [  3.44543457e-02,   3.70483398e-02],
                        [  4.82177734e-02,   5.13305664e-02],
                        [  5.95397949e-02,   6.24694824e-02],
                        [  6.57348633e-02,   6.78100586e-02],
                        [  5.43212891e-02,   5.52368164e-02],
                        [  1.04064941e-02,   1.03454590e-02],
                        [ -6.55517578e-02,  -6.63452148e-02],
                        [ -1.51397705e-01,  -1.52954102e-01],
                        [ -2.16705322e-01,  -2.19146729e-01],
                        [ -2.41333008e-01,  -2.44689941e-01],
                        [ -2.23693848e-01,  -2.27416992e-01],
                        [ -1.77612305e-01,  -1.80969238e-01],
                        [ -1.25366211e-01,  -1.27746582e-01],
                        [ -8.65783691e-02,  -8.78601074e-02],
                        [ -6.67724609e-02,  -6.71081543e-02],
                        [ -5.67321777e-02,  -5.62133789e-02],
                        [ -4.58068848e-02,  -4.41894531e-02],
                        [ -3.23791504e-02,  -2.95410156e-02],
                        [ -1.80969238e-02,  -1.42517090e-02],
                        [  2.92968750e-03,   7.11059570e-03],
                        [  3.80554199e-02,   4.18090820e-02],
                        [  8.27331543e-02,   8.56323242e-02],
                        [  1.24572754e-01,   1.26525879e-01],
                        [  1.54235840e-01,   1.55364990e-01],
                        [  1.62170410e-01,   1.62292480e-01],
                        [  1.33880615e-01,   1.32629395e-01],
                        [  6.21948242e-02,   5.94787598e-02],
                        [ -4.04968262e-02,  -4.43115234e-02],
                        [ -1.45843506e-01,  -1.50024414e-01],
                        [ -2.22076416e-01,  -2.25982666e-01],
                        [ -2.47009277e-01,  -2.50366211e-01],
                        [ -2.19543457e-01,  -2.22351074e-01],
                        [ -1.62567139e-01,  -1.64703369e-01],
                        [ -1.07879639e-01,  -1.08947754e-01],
                        [ -7.31811523e-02,  -7.26928711e-02],
                        [ -5.42297363e-02,  -5.22155762e-02],
                        [ -3.88183594e-02,  -3.57360840e-02],
                        [ -2.35900879e-02,  -2.00805664e-02],
                        [ -1.53198242e-02,  -1.17492676e-02],
                        [ -1.68151855e-02,  -1.32751465e-02],
                        [ -1.90429688e-02,  -1.56250000e-02],
                        [ -1.09558105e-02,  -7.96508789e-03],
                        [  8.75854492e-03,   1.07421875e-02],
                        [  3.20129395e-02,   3.25317383e-02],
                        [  4.79125977e-02,   4.71191406e-02],
                        [  5.06896973e-02,   4.90112305e-02],
                        [  4.52575684e-02,   4.30297852e-02],
                        [  4.04663086e-02,   3.78112793e-02],
                        [  3.93066406e-02,   3.62548828e-02],
                        [  4.30603027e-02,   3.96728516e-02],
                        [  5.80749512e-02,   5.48400879e-02],
                        [  8.79211426e-02,   8.54492188e-02],
                        [  1.23474121e-01,   1.22070312e-01],
                        [  1.49139404e-01,   1.48620605e-01],
                        [  1.56311035e-01,   1.56372070e-01],
                        [  1.46820068e-01,   1.47399902e-01],
                        [  1.28112793e-01,   1.29333496e-01],
                        [  1.08734131e-01,   1.10717773e-01],
                        [  9.40551758e-02,   9.66186523e-02],
                        [  8.36486816e-02,   8.63037109e-02],
                        [  7.56835938e-02,   7.79418945e-02],
                        [  7.09838867e-02,   7.27539062e-02],
                        [  6.86035156e-02,   7.00988770e-02],
                        [  6.27746582e-02,   6.40869141e-02],
                        [  4.97436523e-02,   5.06896973e-02],
                        [  3.28369141e-02,   3.31115723e-02],
                        [  1.80664062e-02,   1.75170898e-02],
                        [  1.12304688e-02,   1.00708008e-02],
                        [  2.00195312e-02,   1.86767578e-02],
                        [  4.98962402e-02,   4.85534668e-02],
                        [  9.46350098e-02,   9.32006836e-02],
                        [  1.37298584e-01,   1.35559082e-01],
                        [  1.61590576e-01,   1.59637451e-01],
                        [  1.61010742e-01,   1.59179688e-01],
                        [  1.41693115e-01,   1.40319824e-01],
                        [  1.18560791e-01,   1.17767334e-01],
                        [  1.02630615e-01,   1.02203369e-01],
                        [  9.18579102e-02,   9.16137695e-02],
                        [  7.86437988e-02,   7.86132812e-02],
                        [  6.09741211e-02,   6.14624023e-02],
                        [  4.13818359e-02,   4.25720215e-02],
                        [  2.20642090e-02,   2.38037109e-02],
                        [  6.86645508e-03,   8.72802734e-03],
                        [  9.76562500e-04,   2.71606445e-03],
                        [  3.90625000e-03,   5.52368164e-03],
                        [  8.14819336e-03,   9.79614258e-03],
                        [  7.56835938e-03,   9.21630859e-03],
                        [  1.64794922e-03,   3.02124023e-03],
                        [ -7.41577148e-03,  -6.71386719e-03],
                        [ -1.66320801e-02,  -1.67541504e-02],
                        [ -2.19726562e-02,  -2.27050781e-02],
                        [ -2.06604004e-02,  -2.16674805e-02],
                        [ -1.42211914e-02,  -1.54724121e-02],
                        [ -8.60595703e-03,  -1.02233887e-02],
                        [ -9.55200195e-03,  -1.16271973e-02],
                        [ -1.67846680e-02,  -1.91040039e-02],
                        [ -2.56042480e-02,  -2.77709961e-02],
                        [ -3.43322754e-02,  -3.59802246e-02],
                        [ -4.52270508e-02,  -4.62341309e-02],
                        [ -5.72204590e-02,  -5.78308105e-02],
                        [ -6.57958984e-02,  -6.61010742e-02],
                        [ -6.97021484e-02,  -6.95495605e-02],
                        [ -7.04040527e-02,  -6.95495605e-02],
                        [ -6.61926270e-02,  -6.46057129e-02],
                        [ -5.67016602e-02,  -5.46264648e-02],
                        [ -4.90417480e-02,  -4.69360352e-02],
                        [ -4.98352051e-02,  -4.79431152e-02],
                        [ -5.59997559e-02,  -5.42907715e-02],
                        [ -6.03027344e-02,  -5.86242676e-02],
                        [ -5.95703125e-02,  -5.80444336e-02],
                        [ -5.45959473e-02,  -5.35583496e-02],
                        [ -4.80957031e-02,  -4.77905273e-02],
                        [ -4.37316895e-02,  -4.41894531e-02],
                        [ -4.23278809e-02,  -4.32739258e-02],
                        [ -3.93371582e-02,  -4.04968262e-02],
                        [ -3.05175781e-02,  -3.18298340e-02],
                        [ -1.73034668e-02,  -1.89208984e-02],
                        [ -3.57055664e-03,  -5.52368164e-03],
                        [  9.00268555e-03,   6.92749023e-03],
                        [  2.00195312e-02,   1.82495117e-02],
                        [  2.98156738e-02,   2.85644531e-02],
                        [  4.01611328e-02,   3.93981934e-02],
                        [  5.04455566e-02,   4.99572754e-02],
                        [  5.22460938e-02,   5.19714355e-02],
                        [  3.21655273e-02,   3.22875977e-02],
                        [ -1.69677734e-02,  -1.62048340e-02],
                        [ -8.82568359e-02,  -8.69140625e-02],
                        [ -1.64306641e-01,  -1.62658691e-01],
                        [ -2.23754883e-01,  -2.22106934e-01],
                        [ -2.46490479e-01,  -2.44934082e-01],
                        [ -2.25097656e-01,  -2.23541260e-01],
                        [ -1.75903320e-01,  -1.74285889e-01],
                        [ -1.28234863e-01,  -1.26678467e-01],
                        [ -9.76562500e-02,  -9.65576172e-02],
                        [ -7.67211914e-02,  -7.62634277e-02],
                        [ -5.38635254e-02,  -5.39855957e-02],
                        [ -3.08837891e-02,  -3.14025879e-02],
                        [ -1.48010254e-02,  -1.55334473e-02],
                        [ -3.05175781e-03,  -4.08935547e-03],
                        [  1.31530762e-02,   1.16577148e-02],
                        [  3.76281738e-02,   3.57055664e-02],
                        [  6.88171387e-02,   6.67419434e-02],
                        [  1.02996826e-01,   1.01135254e-01],
                        [  1.32476807e-01,   1.31011963e-01],
                        [  1.44866943e-01,   1.43768311e-01],
                        [  1.29302979e-01,   1.28448486e-01],
                        [  8.20617676e-02,   8.15429688e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [ -9.08203125e-02,  -9.00573730e-02],
                        [ -1.81762695e-01,  -1.80389404e-01],
                        [ -2.34924316e-01,  -2.33154297e-01],
                        [ -2.33398438e-01,  -2.31597900e-01],
                        [ -1.90521240e-01,  -1.88751221e-01],
                        [ -1.38000488e-01,  -1.36169434e-01],
                        [ -9.94262695e-02,  -9.76257324e-02],
                        [ -7.54699707e-02,  -7.39135742e-02],
                        [ -5.39855957e-02,  -5.29785156e-02],
                        [ -3.02429199e-02,  -2.99987793e-02],
                        [ -1.13220215e-02,  -1.16882324e-02],
                        [ -3.69262695e-03,  -4.45556641e-03],
                        [ -3.84521484e-03,  -4.91333008e-03],
                        [ -1.70898438e-03,  -3.08227539e-03],
                        [  8.57543945e-03,   6.83593750e-03],
                        [  2.31628418e-02,   2.11791992e-02],
                        [  3.39660645e-02,   3.20739746e-02],
                        [  3.65600586e-02,   3.50646973e-02],
                        [  3.32946777e-02,   3.23181152e-02],
                        [  3.08837891e-02,   3.03039551e-02],
                        [  3.57360840e-02,   3.54614258e-02],
                        [  5.01098633e-02,   5.01403809e-02],
                        [  7.04956055e-02,   7.10754395e-02],
                        [  9.20410156e-02,   9.31396484e-02],
                        [  1.13067627e-01,   1.14501953e-01],
                        [  1.30676270e-01,   1.32171631e-01],
                        [  1.36566162e-01,   1.37878418e-01],
                        [  1.28204346e-01,   1.29333496e-01],
                        [  1.17034912e-01,   1.18103027e-01],
                        [  1.13311768e-01,   1.14318848e-01],
                        [  1.13128662e-01,   1.13861084e-01],
                        [  1.09619141e-01,   1.09863281e-01],
                        [  1.03942871e-01,   1.03698730e-01],
                        [  9.81140137e-02,   9.75952148e-02],
                        [  8.88366699e-02,   8.82263184e-02],
                        [  7.38220215e-02,   7.31811523e-02],
                        [  5.56030273e-02,   5.48706055e-02],
                        [  3.63769531e-02,   3.54309082e-02],
                        [  1.72729492e-02,   1.62048340e-02],
                        [  3.50952148e-03,   2.59399414e-03],
                        [  4.33349609e-03,   3.69262695e-03],
                        [  2.62756348e-02,   2.58483887e-02],
                        [  6.71997070e-02,   6.68640137e-02],
                        [  1.14349365e-01,   1.14044189e-01],
                        [  1.50146484e-01,   1.49932861e-01],
                        [  1.62994385e-01,   1.63024902e-01],
                        [  1.52923584e-01,   1.53289795e-01],
                        [  1.29364014e-01,   1.29943848e-01],
                        [  1.05468750e-01,   1.06079102e-01],
                        [  9.03015137e-02,   9.08813477e-02],
                        [  8.19702148e-02,   8.26721191e-02],
                        [  7.16247559e-02,   7.24792480e-02],
                        [  5.56030273e-02,   5.66101074e-02],
                        [  4.01306152e-02,   4.10461426e-02],
                        [  3.10668945e-02,   3.17077637e-02],
                        [  2.52990723e-02,   2.56347656e-02],
                        [  1.62658691e-02,   1.64184570e-02],
                        [  2.96020508e-03,   2.99072266e-03],
                        [ -9.76562500e-03,  -9.94873047e-03],
                        [ -1.71813965e-02,  -1.77307129e-02],
                        [ -1.74865723e-02,  -1.84020996e-02],
                        [ -1.14135742e-02,  -1.26037598e-02],
                        [ -2.59399414e-03,  -3.81469727e-03],
                        [  2.28881836e-03,   1.19018555e-03],
                        [ -2.25830078e-03,  -3.17382812e-03],
                        [ -1.42517090e-02,  -1.50756836e-02],
                        [ -2.65502930e-02,  -2.72216797e-02],
                        [ -3.50341797e-02,  -3.53393555e-02],
                        [ -3.97033691e-02,  -3.95202637e-02],
                        [ -4.07104492e-02,  -4.00085449e-02],
                        [ -3.99169922e-02,  -3.88793945e-02],
                        [ -4.33044434e-02,  -4.21447754e-02],
                        [ -5.35278320e-02,  -5.23376465e-02],
                        [ -6.30493164e-02,  -6.18286133e-02],
                        [ -6.34460449e-02,  -6.22253418e-02],
                        [ -5.80444336e-02,  -5.69763184e-02],
                        [ -5.64880371e-02,  -5.58471680e-02],
                        [ -5.99060059e-02,  -5.97839355e-02],
                        [ -6.08825684e-02,  -6.12792969e-02],
                        [ -5.65185547e-02,  -5.72509766e-02],
                        [ -5.10864258e-02,  -5.20019531e-02],
                        [ -4.77905273e-02,  -4.88586426e-02],
                        [ -4.61730957e-02,  -4.74243164e-02],
                        [ -4.60510254e-02,  -4.73632812e-02],
                        [ -4.67224121e-02,  -4.78515625e-02],
                        [ -4.50134277e-02,  -4.57153320e-02],
                        [ -3.93981934e-02,  -3.96118164e-02],
                        [ -3.22265625e-02,  -3.20129395e-02],
                        [ -2.48718262e-02,  -2.43835449e-02],
                        [ -1.59912109e-02,  -1.52587891e-02],
                        [ -4.66918945e-03,  -3.69262695e-03],
                        [  9.49096680e-03,   1.06506348e-02],
                        [  2.72216797e-02,   2.84118652e-02],
                        [  4.47692871e-02,   4.57458496e-02],
                        [  5.19104004e-02,   5.24597168e-02],
                        [  3.96728516e-02,   3.97949219e-02],
                        [  4.88281250e-03,   4.69970703e-03],
                        [ -5.31616211e-02,  -5.35888672e-02],
                        [ -1.28936768e-01,  -1.29638672e-01],
                        [ -2.01385498e-01,  -2.02331543e-01],
                        [ -2.40661621e-01,  -2.41760254e-01],
                        [ -2.31781006e-01,  -2.32879639e-01],
                        [ -1.87530518e-01,  -1.88323975e-01],
                        [ -1.35681152e-01,  -1.36077881e-01],
                        [ -9.69238281e-02,  -9.69543457e-02],
                        [ -7.51953125e-02,  -7.49206543e-02],
                        [ -6.39953613e-02,  -6.34765625e-02],
                        [ -5.62438965e-02,  -5.54504395e-02],
                        [ -4.84924316e-02,  -4.73937988e-02],
                        [ -3.91540527e-02,  -3.79638672e-02],
                        [ -2.55737305e-02,  -2.45056152e-02],
                        [ -3.66210938e-03,  -2.92968750e-03],
                        [  2.91748047e-02,   2.95104980e-02],
                        [  7.07702637e-02,   7.07702637e-02],
                        [  1.12792969e-01,   1.12487793e-01],
                        [  1.44134521e-01,   1.43493652e-01],
                        [  1.56707764e-01,   1.55731201e-01],
                        [  1.44226074e-01,   1.42974854e-01],
                        [  9.79919434e-02,   9.67102051e-02],
                        [  1.45568848e-02,   1.34277344e-02],
                        [ -9.09118652e-02,  -9.17053223e-02],
                        [ -1.85272217e-01,  -1.85729980e-01],
                        [ -2.36785889e-01,  -2.36907959e-01],
                        [ -2.33581543e-01,  -2.33367920e-01],
                        [ -1.87622070e-01,  -1.87011719e-01],
                        [ -1.26617432e-01,  -1.25610352e-01],
                        [ -7.91320801e-02,  -7.78503418e-02],
                        [ -5.72814941e-02,  -5.59692383e-02],
                        [ -5.09948730e-02,  -4.98352051e-02],
                        [ -4.34265137e-02,  -4.25109863e-02],
                        [ -2.92053223e-02,  -2.85339355e-02],
                        [ -1.39160156e-02,  -1.35498047e-02],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  5.24902344e-03,   4.85229492e-03],
                        [  1.33361816e-02,   1.25427246e-02],
                        [  2.34985352e-02,   2.24304199e-02],
                        [  3.33862305e-02,   3.22570801e-02],
                        [  3.68347168e-02,   3.57666016e-02],
                        [  3.07922363e-02,   2.98767090e-02],
                        [  2.18200684e-02,   2.10571289e-02],
                        [  1.99890137e-02,   1.94396973e-02],
                        [  2.90527344e-02,   2.88391113e-02],
                        [  4.84924316e-02,   4.86145020e-02],
                        [  7.73315430e-02,   7.78198242e-02],
                        [  1.08764648e-01,   1.09466553e-01],
                        [  1.28753662e-01,   1.29516602e-01],
                        [  1.29547119e-01,   1.30279541e-01],
                        [  1.19628906e-01,   1.20391846e-01],
                        [  1.14379883e-01,   1.15081787e-01],
                        [  1.18865967e-01,   1.19445801e-01],
                        [  1.25274658e-01,   1.25610352e-01],
                        [  1.24877930e-01,   1.24938965e-01],
                        [  1.16821289e-01,   1.16668701e-01],
                        [  1.04919434e-01,   1.04644775e-01],
                        [  9.17663574e-02,   9.14611816e-02],
                        [  7.68432617e-02,   7.64770508e-02],
                        [  5.75561523e-02,   5.71289062e-02],
                        [  3.28063965e-02,   3.23791504e-02],
                        [  6.80541992e-03,   6.43920898e-03],
                        [ -1.15051270e-02,  -1.17797852e-02],
                        [ -1.40075684e-02,  -1.41296387e-02],
                        [  2.92968750e-03,   2.86865234e-03],
                        [  3.94897461e-02,   3.94287109e-02],
                        [  9.12170410e-02,   9.11560059e-02],
                        [  1.43188477e-01,   1.43188477e-01],
                        [  1.73492432e-01,   1.73553467e-01],
                        [  1.70288086e-01,   1.70379639e-01],
                        [  1.42913818e-01,   1.42974854e-01],
                        [  1.11328125e-01,   1.11358643e-01],
                        [  8.77990723e-02,   8.78295898e-02],
                        [  7.27539062e-02,   7.28759766e-02],
                        [  6.27136230e-02,   6.28967285e-02],
                        [  5.43823242e-02,   5.46569824e-02],
                        [  4.47387695e-02,   4.49829102e-02],
                        [  3.36303711e-02,   3.38745117e-02],
                        [  2.46582031e-02,   2.49023438e-02],
                        [  1.89819336e-02,   1.92260742e-02],
                        [  1.30615234e-02,   1.32751465e-02],
                        [  5.09643555e-03,   5.21850586e-03],
                        [ -2.01416016e-03,  -2.04467773e-03],
                        [ -5.58471680e-03,  -5.76782227e-03],
                        [ -6.43920898e-03,  -6.71386719e-03],
                        [ -6.89697266e-03,  -7.23266602e-03],
                        [ -9.33837891e-03,  -9.73510742e-03],
                        [ -1.55944824e-02,  -1.60522461e-02],
                        [ -2.46582031e-02,  -2.51159668e-02],
                        [ -3.17993164e-02,  -3.22265625e-02],
                        [ -3.31115723e-02,  -3.34167480e-02],
                        [ -2.89611816e-02,  -2.90832520e-02],
                        [ -2.21862793e-02,  -2.21252441e-02],
                        [ -1.69372559e-02,  -1.67846680e-02],
                        [ -1.86157227e-02,  -1.83410645e-02],
                        [ -2.87780762e-02,  -2.83813477e-02],
                        [ -4.29382324e-02,  -4.24499512e-02],
                        [ -5.64270020e-02,  -5.58776855e-02],
                        [ -6.82067871e-02,  -6.76879883e-02],
                        [ -7.60803223e-02,  -7.56835938e-02],
                        [ -7.54089355e-02,  -7.51342773e-02],
                        [ -6.62536621e-02,  -6.61621094e-02],
                        [ -5.57556152e-02,  -5.57861328e-02],
                        [ -4.87365723e-02,  -4.88891602e-02],
                        [ -4.19921875e-02,  -4.22973633e-02],
                        [ -3.17687988e-02,  -3.21960449e-02],
                        [ -2.20031738e-02,  -2.24914551e-02],
                        [ -1.91345215e-02,  -1.95922852e-02],
                        [ -2.25219727e-02,  -2.29187012e-02],
                        [ -2.67639160e-02,  -2.70690918e-02],
                        [ -2.99072266e-02,  -3.01208496e-02],
                        [ -3.21960449e-02,  -3.23181152e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -1.39465332e-02,  -1.37939453e-02],
                        [  1.07116699e-02,   1.10168457e-02],
                        [  3.66210938e-02,   3.69567871e-02],
                        [  5.68542480e-02,   5.72204590e-02],
                        [  6.49719238e-02,   6.52770996e-02],
                        [  5.13305664e-02,   5.15747070e-02],
                        [  1.04064941e-02,   1.06201172e-02],
                        [ -5.19714355e-02,  -5.18188477e-02],
                        [ -1.22467041e-01,  -1.22406006e-01],
                        [ -1.85638428e-01,  -1.85699463e-01],
                        [ -2.23999023e-01,  -2.24151611e-01],
                        [ -2.22534180e-01,  -2.22717285e-01],
                        [ -1.82250977e-01,  -1.82464600e-01],
                        [ -1.25885010e-01,  -1.26068115e-01],
                        [ -8.10546875e-02,  -8.12377930e-02],
                        [ -5.87768555e-02,  -5.89294434e-02],
                        [ -5.17272949e-02,  -5.18493652e-02],
                        [ -4.92553711e-02,  -4.93164062e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -4.48303223e-02,  -4.47998047e-02],
                        [ -3.76892090e-02,  -3.76281738e-02],
                        [ -1.77917480e-02,  -1.77612305e-02],
                        [  1.77917480e-02,   1.78527832e-02],
                        [  6.19812012e-02,   6.20727539e-02],
                        [  1.02996826e-01,   1.03088379e-01],
                        [  1.31896973e-01,   1.31958008e-01],
                        [  1.43280029e-01,   1.43310547e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  9.62524414e-02,   9.62219238e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [ -5.27038574e-02,  -5.26733398e-02],
                        [ -1.42547607e-01,  -1.42547607e-01],
                        [ -2.07916260e-01,  -2.07946777e-01],
                        [ -2.24487305e-01,  -2.24487305e-01],
                        [ -1.91406250e-01,  -1.91406250e-01],
                        [ -1.33361816e-01,  -1.33331299e-01],
                        [ -8.25805664e-02,  -8.25500488e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -4.55017090e-02,  -4.55322266e-02],
                        [ -3.60412598e-02,  -3.60717773e-02],
                        [ -2.28576660e-02,  -2.28881836e-02],
                        [ -1.15966797e-02,  -1.16271973e-02],
                        [ -4.60815430e-03,  -4.63867188e-03],
                        [  1.61743164e-03,   1.55639648e-03],
                        [  9.79614258e-03,   9.73510742e-03],
                        [  1.99890137e-02,   1.99279785e-02],
                        [  3.04260254e-02,   3.03955078e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.66210938e-02,   3.66516113e-02],
                        [  3.11584473e-02,   3.11889648e-02],
                        [  2.49023438e-02,   2.49328613e-02],
                        [  2.02331543e-02,   2.02941895e-02],
                        [  2.24914551e-02,   2.25219727e-02],
                        [  4.12902832e-02,   4.13513184e-02],
                        [  7.83386230e-02,   7.83996582e-02],
                        [  1.18988037e-01,   1.19018555e-01],
                        [  1.43646240e-01,   1.43646240e-01],
                        [  1.45812988e-01,   1.45812988e-01],
                        [  1.36718750e-01,   1.36718750e-01],
                        [  1.31744385e-01,   1.31713867e-01],
                        [  1.31988525e-01,   1.31958008e-01],
                        [  1.26037598e-01,   1.26007080e-01],
                        [  1.10168457e-01,   1.10107422e-01],
                        [  9.46655273e-02,   9.46350098e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  5.49011230e-02,   5.48706055e-02],
                        [  3.14331055e-02,   3.14025879e-02],
                        [  1.26953125e-02,   1.27258301e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  4.63867188e-03,   4.66918945e-03],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  5.84411621e-02,   5.84411621e-02],
                        [  9.77478027e-02,   9.77783203e-02],
                        [  1.34460449e-01,   1.34460449e-01],
                        [  1.55548096e-01,   1.55548096e-01],
                        [  1.52374268e-01,   1.52374268e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  4.62646484e-02,   4.62646484e-02],
                        [  3.04565430e-02,   3.04260254e-02],
                        [  2.44140625e-02,   2.43835449e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  3.59191895e-02,   3.59497070e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  1.69982910e-02,   1.69677734e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -2.32543945e-02,  -2.32238770e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.36206055e-02,  -2.35900879e-02],
                        [ -1.90124512e-02,  -1.90429688e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.42211914e-02,  -1.41906738e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -6.83288574e-02,  -6.83288574e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -6.34765625e-02,  -6.35070801e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -5.57250977e-02,  -5.57556152e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -3.28063965e-02,  -3.27758789e-02],
                        [ -2.29187012e-02,  -2.29492188e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  3.07617188e-02,   3.07922363e-02],
                        [  3.80554199e-02,   3.80859375e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -1.04217529e-01,  -1.04248047e-01],
                        [ -1.69281006e-01,  -1.69281006e-01],
                        [ -2.13562012e-01,  -2.13531494e-01],
                        [ -2.20153809e-01,  -2.20153809e-01],
                        [ -1.87866211e-01,  -1.87866211e-01],
                        [ -1.35223389e-01,  -1.35223389e-01],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -6.93359375e-02,  -6.93664551e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -6.80847168e-02,  -6.80541992e-02],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -5.63659668e-02,  -5.63964844e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  8.41369629e-02,   8.41674805e-02],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  1.34155273e-01,   1.34124756e-01],
                        [  1.31835938e-01,   1.31835938e-01],
                        [  1.02844238e-01,   1.02874756e-01],
                        [  4.74853516e-02,   4.74548340e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -1.18133545e-01,  -1.18103027e-01],
                        [ -1.92077637e-01,  -1.92108154e-01],
                        [ -2.22930908e-01,  -2.22961426e-01],
                        [ -2.00347900e-01,  -2.00317383e-01],
                        [ -1.44500732e-01,  -1.44470215e-01],
                        [ -9.03015137e-02,  -9.03015137e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -9.36889648e-03,  -9.39941406e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  4.28771973e-02,   4.28466797e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  2.88391113e-02,   2.88696289e-02],
                        [  1.41906738e-02,   1.41601562e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  3.28369141e-02,   3.28369141e-02],
                        [  6.51245117e-02,   6.50939941e-02],
                        [  1.06018066e-01,   1.06018066e-01],
                        [  1.42883301e-01,   1.42913818e-01],
                        [  1.60766602e-01,   1.60766602e-01],
                        [  1.56585693e-01,   1.56585693e-01],
                        [  1.41632080e-01,   1.41662598e-01],
                        [  1.27838135e-01,   1.27868652e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.09222412e-01,   1.09252930e-01],
                        [  1.00952148e-01,   1.00982666e-01],
                        [  9.17358398e-02,   9.17053223e-02],
                        [  7.99865723e-02,   7.99865723e-02],
                        [  6.65588379e-02,   6.65893555e-02],
                        [  5.34362793e-02,   5.34362793e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  4.05883789e-03,   4.02832031e-03],
                        [  1.72424316e-02,   1.72729492e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.42578125e-01,   1.42578125e-01],
                        [  1.41113281e-01,   1.41113281e-01],
                        [  1.19659424e-01,   1.19659424e-01],
                        [  8.90808105e-02,   8.90808105e-02],
                        [  6.38122559e-02,   6.38427734e-02],
                        [  5.17578125e-02,   5.17272949e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  3.92761230e-02,   3.93066406e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  5.58471680e-03,   5.58471680e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -8.08715820e-03,  -8.05664062e-03],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.32238770e-02,  -2.31933594e-02],
                        [ -2.46582031e-02,  -2.46887207e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -6.03027344e-02,  -6.03332520e-02],
                        [ -6.78710938e-02,  -6.78710938e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -6.05468750e-02,  -6.05773926e-02],
                        [ -5.02929688e-02,  -5.02624512e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.35998535e-02,  -3.35693359e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  5.68847656e-02,   5.69152832e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -1.15295410e-01,  -1.15295410e-01],
                        [ -1.82220459e-01,  -1.82220459e-01],
                        [ -2.23236084e-01,  -2.23236084e-01],
                        [ -2.22900391e-01,  -2.22869873e-01],
                        [ -1.86248779e-01,  -1.86248779e-01],
                        [ -1.36779785e-01,  -1.36810303e-01],
                        [ -9.94873047e-02,  -9.94567871e-02],
                        [ -8.34045410e-02,  -8.33740234e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -7.45544434e-02,  -7.45849609e-02],
                        [ -6.18591309e-02,  -6.18286133e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -2.47497559e-02,  -2.47802734e-02],
                        [ -5.46264648e-03,  -5.43212891e-03],
                        [  1.67236328e-02,   1.67541504e-02],
                        [  4.51660156e-02,   4.51354980e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  1.13677979e-01,   1.13708496e-01],
                        [  1.37481689e-01,   1.37481689e-01],
                        [  1.40441895e-01,   1.40411377e-01],
                        [  1.15356445e-01,   1.15386963e-01],
                        [  6.11267090e-02,   6.11267090e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -1.83410645e-01,  -1.83380127e-01],
                        [ -2.25616455e-01,  -2.25616455e-01],
                        [ -2.18292236e-01,  -2.18292236e-01],
                        [ -1.73553467e-01,  -1.73553467e-01],
                        [ -1.19506836e-01,  -1.19506836e-01],
                        [ -7.76977539e-02,  -7.76977539e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [ -1.40380859e-03,  -1.43432617e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  9.46044922e-03,   9.42993164e-03],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  1.45202637e-01,   1.45202637e-01],
                        [  1.54632568e-01,   1.54632568e-01],
                        [  1.52404785e-01,   1.52404785e-01],
                        [  1.41357422e-01,   1.41357422e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.15386963e-01,   1.15356445e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  9.32312012e-02,   9.32312012e-02],
                        [  8.26721191e-02,   8.26721191e-02],
                        [  7.36389160e-02,   7.36389160e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  1.19934082e-02,   1.19628906e-02],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  8.00476074e-02,   8.00476074e-02],
                        [  1.15570068e-01,   1.15570068e-01],
                        [  1.39465332e-01,   1.39465332e-01],
                        [  1.45233154e-01,   1.45233154e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  5.36499023e-02,   5.36193848e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  6.83593750e-03,   6.83593750e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.04980469e-02,  -1.05285645e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.25219727e-02,  -2.25524902e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -3.26538086e-02,  -3.26232910e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -5.52368164e-03,  -5.55419922e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -5.61218262e-02,  -5.61218262e-02],
                        [ -1.25152588e-01,  -1.25122070e-01],
                        [ -1.90887451e-01,  -1.90887451e-01],
                        [ -2.31964111e-01,  -2.31964111e-01],
                        [ -2.33551025e-01,  -2.33551025e-01],
                        [ -1.98364258e-01,  -1.98364258e-01],
                        [ -1.47369385e-01,  -1.47369385e-01],
                        [ -1.05804443e-01,  -1.05804443e-01],
                        [ -8.39233398e-02,  -8.39233398e-02],
                        [ -7.26318359e-02,  -7.26318359e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -2.83813477e-02,  -2.84118652e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.15966797e-03,  -1.12915039e-03],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  8.83789062e-02,   8.84094238e-02],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  1.29425049e-01,   1.29394531e-01],
                        [  1.34979248e-01,   1.35009766e-01],
                        [  1.19903564e-01,   1.19903564e-01],
                        [  7.19909668e-02,   7.19909668e-02],
                        [ -9.36889648e-03,  -9.39941406e-03],
                        [ -1.06872559e-01,  -1.06872559e-01],
                        [ -1.90490723e-01,  -1.90490723e-01],
                        [ -2.30255127e-01,  -2.30255127e-01],
                        [ -2.13531494e-01,  -2.13531494e-01],
                        [ -1.57531738e-01,  -1.57531738e-01],
                        [ -9.93041992e-02,  -9.93041992e-02],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  8.59069824e-02,   8.59069824e-02],
                        [  1.34613037e-01,   1.34613037e-01],
                        [  1.68548584e-01,   1.68548584e-01],
                        [  1.81701660e-01,   1.81701660e-01],
                        [  1.76391602e-01,   1.76391602e-01],
                        [  1.60156250e-01,   1.60156250e-01],
                        [  1.41021729e-01,   1.41021729e-01],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  1.08032227e-01,   1.08032227e-01],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  4.38232422e-02,   4.38537598e-02],
                        [  2.63671875e-02,   2.63366699e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -8.85009766e-03,  -8.85009766e-03],
                        [  7.84301758e-03,   7.84301758e-03],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  8.66394043e-02,   8.66088867e-02],
                        [  1.31256104e-01,   1.31256104e-01],
                        [  1.60430908e-01,   1.60461426e-01],
                        [  1.61621094e-01,   1.61621094e-01],
                        [  1.36901855e-01,   1.36871338e-01],
                        [  1.03485107e-01,   1.03485107e-01],
                        [  7.88879395e-02,   7.88879395e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  4.30908203e-02,   4.30908203e-02],
                        [  2.69775391e-02,   2.69470215e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -4.37622070e-02,  -4.37927246e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.84411621e-02,  -5.84411621e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -7.09838867e-02,  -7.09838867e-02],
                        [ -7.30285645e-02,  -7.30285645e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [ -4.29687500e-02,  -4.29992676e-02],
                        [ -1.20941162e-01,  -1.20941162e-01],
                        [ -1.96746826e-01,  -1.96746826e-01],
                        [ -2.45361328e-01,  -2.45391846e-01],
                        [ -2.49206543e-01,  -2.49206543e-01],
                        [ -2.13562012e-01,  -2.13531494e-01],
                        [ -1.62506104e-01,  -1.62536621e-01],
                        [ -1.18652344e-01,  -1.18652344e-01],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -7.10754395e-02,  -7.10449219e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  7.65686035e-02,   7.65686035e-02],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.31561279e-01,   1.31561279e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  7.88574219e-02,   7.88574219e-02],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -1.02966309e-01,  -1.02996826e-01],
                        [ -1.92047119e-01,  -1.92047119e-01],
                        [ -2.35748291e-01,  -2.35717773e-01],
                        [ -2.24761963e-01,  -2.24761963e-01],
                        [ -1.73370361e-01,  -1.73400879e-01],
                        [ -1.09619141e-01,  -1.09619141e-01],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [  6.65283203e-03,   6.68334961e-03],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  7.11059570e-03,   7.08007812e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  2.77709961e-03,   2.74658203e-03],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.21862793e-02,   2.21557617e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  7.20214844e-03,   7.17163086e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  1.10931396e-01,   1.10931396e-01],
                        [  1.46179199e-01,   1.46179199e-01],
                        [  1.67144775e-01,   1.67144775e-01],
                        [  1.68273926e-01,   1.68273926e-01],
                        [  1.55059814e-01,   1.55059814e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.24206543e-01,   1.24206543e-01],
                        [  1.16516113e-01,   1.16516113e-01],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.11572266e-01,   1.11602783e-01],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  8.07800293e-02,   8.07495117e-02],
                        [  5.82885742e-02,   5.83190918e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  1.46148682e-01,   1.46148682e-01],
                        [  1.74621582e-01,   1.74621582e-01],
                        [  1.70928955e-01,   1.70928955e-01],
                        [  1.43798828e-01,   1.43798828e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -4.60205078e-02,  -4.60510254e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -3.10668945e-02,  -3.10363770e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -5.66101074e-02,  -5.66101074e-02],
                        [ -6.67724609e-02,  -6.68029785e-02],
                        [ -7.14416504e-02,  -7.14416504e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.77709961e-03,  -2.74658203e-03],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -1.19201660e-01,  -1.19201660e-01],
                        [ -1.83685303e-01,  -1.83685303e-01],
                        [ -2.18627930e-01,  -2.18627930e-01],
                        [ -2.12127686e-01,  -2.12127686e-01],
                        [ -1.75140381e-01,  -1.75140381e-01],
                        [ -1.33697510e-01,  -1.33697510e-01],
                        [ -1.06811523e-01,  -1.06811523e-01],
                        [ -9.53369141e-02,  -9.53369141e-02],
                        [ -9.08508301e-02,  -9.08508301e-02],
                        [ -8.65173340e-02,  -8.65173340e-02],
                        [ -7.76672363e-02,  -7.76672363e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  4.87365723e-02,   4.87060547e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  1.37542725e-01,   1.37542725e-01],
                        [  1.44653320e-01,   1.44653320e-01],
                        [  1.30920410e-01,   1.30920410e-01],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [ -9.09118652e-02,  -9.09118652e-02],
                        [ -1.73217773e-01,  -1.73217773e-01],
                        [ -2.15850830e-01,  -2.15850830e-01],
                        [ -2.10876465e-01,  -2.10876465e-01],
                        [ -1.68609619e-01,  -1.68609619e-01],
                        [ -1.12701416e-01,  -1.12701416e-01],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -4.15344238e-02,  -4.15039062e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -1.13830566e-02,  -1.13525391e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  8.64562988e-02,   8.64562988e-02],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.52130127e-01,   1.52130127e-01],
                        [  1.61834717e-01,   1.61834717e-01],
                        [  1.53533936e-01,   1.53533936e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.28265381e-01,   1.28265381e-01],
                        [  1.25427246e-01,   1.25427246e-01],
                        [  1.24755859e-01,   1.24755859e-01],
                        [  1.24053955e-01,   1.24053955e-01],
                        [  1.23199463e-01,   1.23199463e-01],
                        [  1.17431641e-01,   1.17431641e-01],
                        [  1.01043701e-01,   1.01043701e-01],
                        [  7.44628906e-02,   7.44628906e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  1.02233887e-01,   1.02203369e-01],
                        [  1.39373779e-01,   1.39343262e-01],
                        [  1.47155762e-01,   1.47155762e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  7.01293945e-02,   7.01293945e-02],
                        [  6.04858398e-02,   6.04553223e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  3.27758789e-02,   3.28063965e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -5.85327148e-02,  -5.85021973e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -4.62646484e-02,  -4.62341309e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  5.21545410e-02,   5.21545410e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -1.33026123e-01,  -1.33026123e-01],
                        [ -2.07519531e-01,  -2.07489014e-01],
                        [ -2.48809814e-01,  -2.48809814e-01],
                        [ -2.44750977e-01,  -2.44750977e-01],
                        [ -2.06268311e-01,  -2.06268311e-01],
                        [ -1.57684326e-01,  -1.57684326e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -9.97314453e-02,  -9.97619629e-02],
                        [ -8.73107910e-02,  -8.73107910e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.03454590e-02,  -1.03149414e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  1.65100098e-02,   1.64794922e-02],
                        [  3.96728516e-02,   3.97033691e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  9.92126465e-02,   9.92126465e-02],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.32934570e-01,   1.32965088e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -1.53076172e-01,  -1.53076172e-01],
                        [ -2.10906982e-01,  -2.10906982e-01],
                        [ -2.17071533e-01,  -2.17041016e-01],
                        [ -1.78955078e-01,  -1.78955078e-01],
                        [ -1.21734619e-01,  -1.21765137e-01],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.62658691e-01,   1.62658691e-01],
                        [  1.80664062e-01,   1.80664062e-01],
                        [  1.81701660e-01,   1.81701660e-01],
                        [  1.68762207e-01,   1.68762207e-01],
                        [  1.51458740e-01,   1.51458740e-01],
                        [  1.38153076e-01,   1.38153076e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  8.45947266e-02,   8.45947266e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  1.12579346e-01,   1.12579346e-01],
                        [  1.42517090e-01,   1.42517090e-01],
                        [  1.46118164e-01,   1.46118164e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -6.73522949e-02,  -6.73522949e-02],
                        [ -6.90307617e-02,  -6.90307617e-02],
                        [ -6.40869141e-02,  -6.40869141e-02],
                        [ -5.48706055e-02,  -5.48400879e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -4.07104492e-02,  -4.07409668e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  5.06896973e-02,   5.06896973e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -1.56097412e-01,  -1.56097412e-01],
                        [ -2.16705322e-01,  -2.16705322e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -2.19024658e-01,  -2.19024658e-01],
                        [ -1.72973633e-01,  -1.72973633e-01],
                        [ -1.28143311e-01,  -1.28143311e-01],
                        [ -1.01287842e-01,  -1.01287842e-01],
                        [ -9.11560059e-02,  -9.11560059e-02],
                        [ -8.69140625e-02,  -8.69140625e-02],
                        [ -7.90100098e-02,  -7.90100098e-02],
                        [ -6.41479492e-02,  -6.41479492e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  1.05072021e-01,   1.05072021e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.39129639e-01,   1.39129639e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [ -1.04827881e-01,  -1.04827881e-01],
                        [ -1.99462891e-01,  -1.99462891e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -2.17437744e-01,  -2.17437744e-01],
                        [ -1.58172607e-01,  -1.58172607e-01],
                        [ -9.48486328e-02,  -9.48486328e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  8.80737305e-02,   8.80737305e-02],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  1.50360107e-01,   1.50360107e-01],
                        [  1.62506104e-01,   1.62506104e-01],
                        [  1.61621094e-01,   1.61621094e-01],
                        [  1.57012939e-01,   1.57012939e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  1.36444092e-01,   1.36444092e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  8.98742676e-02,   8.98742676e-02],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  6.37817383e-03,   6.40869141e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -4.53796387e-02,  -4.53796387e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -5.85632324e-02,  -5.85632324e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  5.75256348e-02,   5.75561523e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -7.86132812e-02,  -7.86132812e-02],
                        [ -1.49261475e-01,  -1.49261475e-01],
                        [ -2.04467773e-01,  -2.04467773e-01],
                        [ -2.27081299e-01,  -2.27081299e-01],
                        [ -2.12158203e-01,  -2.12158203e-01],
                        [ -1.74926758e-01,  -1.74926758e-01],
                        [ -1.40136719e-01,  -1.40136719e-01],
                        [ -1.20635986e-01,  -1.20635986e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -7.36694336e-02,  -7.36694336e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  1.42456055e-01,   1.42456055e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  9.88159180e-02,   9.88159180e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -1.77337646e-01,  -1.77337646e-01],
                        [ -2.28729248e-01,  -2.28729248e-01],
                        [ -2.17376709e-01,  -2.17376709e-01],
                        [ -1.63635254e-01,  -1.63635254e-01],
                        [ -1.06506348e-01,  -1.06506348e-01],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  3.96118164e-02,   3.96423340e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  6.99462891e-02,   6.99462891e-02],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  1.54113770e-01,   1.54113770e-01],
                        [  1.72637939e-01,   1.72637939e-01],
                        [  1.69891357e-01,   1.69891357e-01],
                        [  1.55822754e-01,   1.55822754e-01],
                        [  1.43646240e-01,   1.43646240e-01],
                        [  1.39282227e-01,   1.39282227e-01],
                        [  1.38305664e-01,   1.38305664e-01],
                        [  1.32415771e-01,   1.32415771e-01],
                        [  1.17889404e-01,   1.17889404e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  7.91931152e-02,   7.91931152e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  5.57250977e-02,   5.57250977e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  1.30737305e-01,   1.30737305e-01],
                        [  1.31927490e-01,   1.31927490e-01],
                        [  1.14624023e-01,   1.14624023e-01],
                        [  9.11254883e-02,   9.11254883e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -1.10717773e-01,  -1.10717773e-01],
                        [ -1.87347412e-01,  -1.87347412e-01],
                        [ -2.32727051e-01,  -2.32727051e-01],
                        [ -2.33123779e-01,  -2.33123779e-01],
                        [ -1.98669434e-01,  -1.98669434e-01],
                        [ -1.55303955e-01,  -1.55303955e-01],
                        [ -1.24359131e-01,  -1.24359131e-01],
                        [ -1.08337402e-01,  -1.08337402e-01],
                        [ -9.68017578e-02,  -9.68017578e-02],
                        [ -8.15734863e-02,  -8.15734863e-02],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  5.48400879e-02,   5.48400879e-02],
                        [  8.89587402e-02,   8.89587402e-02],
                        [  1.16424561e-01,   1.16424561e-01],
                        [  1.34124756e-01,   1.34124756e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  1.30859375e-01,   1.30859375e-01],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [ -9.24987793e-02,  -9.24987793e-02],
                        [ -1.84509277e-01,  -1.84509277e-01],
                        [ -2.29888916e-01,  -2.29888916e-01],
                        [ -2.17498779e-01,  -2.17498779e-01],
                        [ -1.64855957e-01,  -1.64855957e-01],
                        [ -1.04736328e-01,  -1.04736328e-01],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  1.34948730e-01,   1.34948730e-01],
                        [  1.73675537e-01,   1.73675537e-01],
                        [  1.91040039e-01,   1.91040039e-01],
                        [  1.86218262e-01,   1.86218262e-01],
                        [  1.68670654e-01,   1.68670654e-01],
                        [  1.50939941e-01,   1.50939941e-01],
                        [  1.38427734e-01,   1.38427734e-01],
                        [  1.26953125e-01,   1.26953125e-01],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  9.03015137e-02,   9.03015137e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  5.11474609e-02,   5.11474609e-02],
                        [  9.27429199e-02,   9.27429199e-02],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.13739014e-01,   1.13739014e-01],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -9.54589844e-02,  -9.54589844e-02],
                        [ -1.76818848e-01,  -1.76818848e-01],
                        [ -2.35443115e-01,  -2.35443115e-01],
                        [ -2.50885010e-01,  -2.50885010e-01],
                        [ -2.24090576e-01,  -2.24090576e-01],
                        [ -1.75842285e-01,  -1.75842285e-01],
                        [ -1.32385254e-01,  -1.32385254e-01],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -9.52148438e-02,  -9.52148438e-02],
                        [ -8.20922852e-02,  -8.20922852e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  6.52160645e-02,   6.52160645e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  6.64672852e-02,   6.64672852e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -1.98822021e-01,  -1.98822021e-01],
                        [ -2.28576660e-01,  -2.28576660e-01],
                        [ -1.99829102e-01,  -1.99829102e-01],
                        [ -1.39068604e-01,  -1.39068604e-01],
                        [ -7.96203613e-02,  -7.96203613e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.78558350e-01,   1.78558350e-01],
                        [  1.90826416e-01,   1.90826416e-01],
                        [  1.79626465e-01,   1.79626465e-01],
                        [  1.56372070e-01,   1.56372070e-01],
                        [  1.35711670e-01,   1.35711670e-01],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  8.93554688e-02,   8.93554688e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  1.23474121e-01,   1.23474121e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  1.12304688e-02,   1.12304688e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -1.30798340e-01,  -1.30798340e-01],
                        [ -2.04986572e-01,  -2.04986572e-01],
                        [ -2.49359131e-01,  -2.49359131e-01],
                        [ -2.47070312e-01,  -2.47070312e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.55364990e-01,  -1.55364990e-01],
                        [ -1.21459961e-01,  -1.21459961e-01],
                        [ -1.05285645e-01,  -1.05285645e-01],
                        [ -9.17968750e-02,  -9.17968750e-02],
                        [ -7.44018555e-02,  -7.44018555e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  1.31317139e-01,   1.31317139e-01],
                        [  1.38824463e-01,   1.38824463e-01],
                        [  1.33941650e-01,   1.33941650e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  3.82080078e-02,   3.82080078e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -1.56829834e-01,  -1.56829834e-01],
                        [ -2.20184326e-01,  -2.20184326e-01],
                        [ -2.28363037e-01,  -2.28363037e-01],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -1.26373291e-01,  -1.26373291e-01],
                        [ -7.60192871e-02,  -7.60192871e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  1.31225586e-01,   1.31225586e-01],
                        [  1.67846680e-01,   1.67846680e-01],
                        [  1.89849854e-01,   1.89849854e-01],
                        [  1.90338135e-01,   1.90338135e-01],
                        [  1.73614502e-01,   1.73614502e-01],
                        [  1.52709961e-01,   1.52709961e-01],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  1.21002197e-01,   1.21002197e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.28906250e-01,   1.28906250e-01],
                        [  1.10198975e-01,   1.10198975e-01],
                        [  8.72802734e-02,   8.72802734e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  6.90917969e-02,   6.90917969e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -7.80944824e-02,  -7.80944824e-02],
                        [ -1.63970947e-01,  -1.63970947e-01],
                        [ -2.31445312e-01,  -2.31445312e-01],
                        [ -2.54943848e-01,  -2.54943848e-01],
                        [ -2.31262207e-01,  -2.31262207e-01],
                        [ -1.82312012e-01,  -1.82312012e-01],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -1.13311768e-01,  -1.13311768e-01],
                        [ -1.01226807e-01,  -1.01226807e-01],
                        [ -8.69445801e-02,  -8.69445801e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  1.23077393e-01,   1.23077393e-01],
                        [  1.35711670e-01,   1.35711670e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  1.02020264e-01,   1.02020264e-01],
                        [  4.40979004e-02,   4.40979004e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -1.33422852e-01,  -1.33422852e-01],
                        [ -2.01538086e-01,  -2.01538086e-01],
                        [ -2.17102051e-01,  -2.17102051e-01],
                        [ -1.81213379e-01,  -1.81213379e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  5.31921387e-02,   5.31921387e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  1.27929688e-01,   1.27929688e-01],
                        [  1.72882080e-01,   1.72882080e-01],
                        [  1.97540283e-01,   1.97540283e-01],
                        [  1.94885254e-01,   1.94885254e-01],
                        [  1.74804688e-01,   1.74804688e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.34552002e-01,   1.34552002e-01],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  1.03302002e-01,   1.03302002e-01],
                        [  8.77380371e-02,   8.77380371e-02],
                        [  7.40661621e-02,   7.40661621e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.38366699e-01,   1.38366699e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  3.05175781e-03,   3.05175781e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -1.33178711e-01,  -1.33178711e-01],
                        [ -2.08038330e-01,  -2.08038330e-01],
                        [ -2.54425049e-01,  -2.54425049e-01],
                        [ -2.56500244e-01,  -2.56500244e-01],
                        [ -2.18200684e-01,  -2.18200684e-01],
                        [ -1.66931152e-01,  -1.66931152e-01],
                        [ -1.32507324e-01,  -1.32507324e-01],
                        [ -1.20849609e-01,  -1.20849609e-01],
                        [ -1.15081787e-01,  -1.15081787e-01],
                        [ -1.00555420e-01,  -1.00555420e-01],
                        [ -7.90100098e-02,  -7.90100098e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  8.62731934e-02,   8.62731934e-02],
                        [  1.02996826e-01,   1.02996826e-01],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  8.88671875e-02,   8.88671875e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -1.31683350e-01,  -1.31683350e-01],
                        [ -1.90979004e-01,  -1.90979004e-01],
                        [ -2.00775146e-01,  -2.00775146e-01],
                        [ -1.64947510e-01,  -1.64947510e-01],
                        [ -1.12670898e-01,  -1.12670898e-01],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  1.41174316e-01,   1.41174316e-01],
                        [  1.78405762e-01,   1.78405762e-01],
                        [  1.92749023e-01,   1.92749023e-01],
                        [  1.81793213e-01,   1.81793213e-01],
                        [  1.59027100e-01,   1.59027100e-01],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.17248535e-01,   1.17248535e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  1.01806641e-01,   1.01806641e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  1.31164551e-01,   1.31164551e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  8.64868164e-02,   8.64868164e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -6.63146973e-02,  -6.63146973e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -1.16210938e-01,  -1.16210938e-01],
                        [ -1.89300537e-01,  -1.89300537e-01],
                        [ -2.43255615e-01,  -2.43255615e-01],
                        [ -2.56561279e-01,  -2.56561279e-01],
                        [ -2.24884033e-01,  -2.24884033e-01],
                        [ -1.68914795e-01,  -1.68914795e-01],
                        [ -1.19384766e-01,  -1.19384766e-01],
                        [ -9.34143066e-02,  -9.34143066e-02],
                        [ -8.56628418e-02,  -8.56628418e-02],
                        [ -8.12377930e-02,  -8.12377930e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -6.87866211e-02,  -6.87866211e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  1.35803223e-01,   1.35803223e-01],
                        [  1.45965576e-01,   1.45965576e-01],
                        [  1.37390137e-01,   1.37390137e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  3.96118164e-02,   3.96118164e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -1.37847900e-01,  -1.37847900e-01],
                        [ -2.01965332e-01,  -2.01965332e-01],
                        [ -2.16003418e-01,  -2.16003418e-01],
                        [ -1.80694580e-01,  -1.80694580e-01],
                        [ -1.21826172e-01,  -1.21826172e-01],
                        [ -7.03430176e-02,  -7.03430176e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.72943115e-01,   1.72943115e-01],
                        [  1.86462402e-01,   1.86462402e-01],
                        [  1.79077148e-01,   1.79077148e-01],
                        [  1.60949707e-01,   1.60949707e-01],
                        [  1.44592285e-01,   1.44592285e-01],
                        [  1.36108398e-01,   1.36108398e-01],
                        [  1.32141113e-01,   1.32141113e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  7.80944824e-02,   7.80944824e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  8.37402344e-02,   8.37402344e-02],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  1.27166748e-01,   1.27166748e-01],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -7.54089355e-02,  -7.54089355e-02],
                        [ -1.57165527e-01,  -1.57165527e-01],
                        [ -2.27905273e-01,  -2.27905273e-01],
                        [ -2.64556885e-01,  -2.64556885e-01],
                        [ -2.56469727e-01,  -2.56469727e-01],
                        [ -2.11914062e-01,  -2.11914062e-01],
                        [ -1.55639648e-01,  -1.55639648e-01],
                        [ -1.15081787e-01,  -1.15081787e-01],
                        [ -1.00067139e-01,  -1.00067139e-01],
                        [ -9.70764160e-02,  -9.70764160e-02],
                        [ -8.79821777e-02,  -8.79821777e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  9.00573730e-02,   9.00573730e-02],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  9.42077637e-02,   9.42077637e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -1.40991211e-01,  -1.40991211e-01],
                        [ -2.04284668e-01,  -2.04284668e-01],
                        [ -2.13439941e-01,  -2.13439941e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.36401367e-02,   4.36401367e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  4.19311523e-02,   4.19311523e-02],
                        [  8.23364258e-02,   8.23364258e-02],
                        [  1.28234863e-01,   1.28234863e-01],
                        [  1.66412354e-01,   1.66412354e-01],
                        [  1.83441162e-01,   1.83441162e-01],
                        [  1.78680420e-01,   1.78680420e-01],
                        [  1.64123535e-01,   1.64123535e-01],
                        [  1.50848389e-01,   1.50848389e-01],
                        [  1.41143799e-01,   1.41143799e-01],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.18316650e-01,   1.18316650e-01],
                        [  1.03118896e-01,   1.03118896e-01],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  1.06536865e-01,   1.06536865e-01],
                        [  1.28326416e-01,   1.28326416e-01],
                        [  1.25305176e-01,   1.25305176e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  5.70373535e-02,   5.70373535e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -1.39038086e-01,  -1.39038086e-01],
                        [ -2.16766357e-01,  -2.16766357e-01],
                        [ -2.55950928e-01,  -2.55950928e-01],
                        [ -2.48596191e-01,  -2.48596191e-01],
                        [ -2.08404541e-01,  -2.08404541e-01],
                        [ -1.59362793e-01,  -1.59362793e-01],
                        [ -1.22528076e-01,  -1.22528076e-01],
                        [ -1.03637695e-01,  -1.03637695e-01],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -8.24890137e-02,  -8.24890137e-02],
                        [ -6.96411133e-02,  -6.96411133e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  7.09228516e-02,   7.09228516e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  1.06018066e-01,   1.06018066e-01],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -9.32006836e-02,  -9.32006836e-02],
                        [ -1.68823242e-01,  -1.68823242e-01],
                        [ -2.06176758e-01,  -2.06176758e-01],
                        [ -1.95922852e-01,  -1.95922852e-01],
                        [ -1.50726318e-01,  -1.50726318e-01],
                        [ -9.55200195e-02,  -9.55200195e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.69006348e-01,   1.69006348e-01],
                        [  1.84326172e-01,   1.84326172e-01],
                        [  1.81762695e-01,   1.81762695e-01],
                        [  1.70349121e-01,   1.70349121e-01],
                        [  1.56890869e-01,   1.56890869e-01],
                        [  1.42578125e-01,   1.42578125e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  8.96301270e-02,   8.96301270e-02],
                        [  7.68737793e-02,   7.68737793e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  7.89184570e-02,   7.89184570e-02],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  4.29992676e-02,   4.29992676e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -1.18072510e-01,  -1.18072510e-01],
                        [ -2.02819824e-01,  -2.02819824e-01],
                        [ -2.64770508e-01,  -2.64770508e-01],
                        [ -2.79205322e-01,  -2.79205322e-01],
                        [ -2.42492676e-01,  -2.42492676e-01],
                        [ -1.80419922e-01,  -1.80419922e-01],
                        [ -1.28479004e-01,  -1.28479004e-01],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -8.43811035e-02,  -8.43811035e-02],
                        [ -7.52868652e-02,  -7.52868652e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [  2.19726562e-03,   2.19726562e-03],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  5.00183105e-02,   5.00183105e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  8.57238770e-02,   8.57238770e-02],
                        [  9.35363770e-02,   9.35363770e-02],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -8.34350586e-02,  -8.34350586e-02],
                        [ -1.62841797e-01,  -1.62841797e-01],
                        [ -2.01965332e-01,  -2.01965332e-01],
                        [ -1.86676025e-01,  -1.86676025e-01],
                        [ -1.33331299e-01,  -1.33331299e-01],
                        [ -7.80029297e-02,  -7.80029297e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  5.24291992e-02,   5.24291992e-02],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  1.40289307e-01,   1.40289307e-01],
                        [  1.66564941e-01,   1.66564941e-01],
                        [  1.72790527e-01,   1.72790527e-01],
                        [  1.63940430e-01,   1.63940430e-01],
                        [  1.49536133e-01,   1.49536133e-01],
                        [  1.38854980e-01,   1.38854980e-01],
                        [  1.35375977e-01,   1.35375977e-01],
                        [  1.33911133e-01,   1.33911133e-01],
                        [  1.28021240e-01,   1.28021240e-01],
                        [  1.19903564e-01,   1.19903564e-01],
                        [  1.15692139e-01,   1.15692139e-01],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  9.35363770e-02,   9.35363770e-02],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  6.73522949e-02,   6.73522949e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [  5.10864258e-02,   5.10864258e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -1.57623291e-01,  -1.57623291e-01],
                        [ -2.34619141e-01,  -2.34619141e-01],
                        [ -2.74932861e-01,  -2.74932861e-01],
                        [ -2.68768311e-01,  -2.68768311e-01],
                        [ -2.26165771e-01,  -2.26165771e-01],
                        [ -1.71508789e-01,  -1.71508789e-01],
                        [ -1.30065918e-01,  -1.30065918e-01],
                        [ -1.09741211e-01,  -1.09741211e-01],
                        [ -9.79309082e-02,  -9.79309082e-02],
                        [ -8.07495117e-02,  -8.07495117e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  1.14044189e-01,   1.14044189e-01],
                        [  1.10229492e-01,   1.10229492e-01],
                        [  7.94372559e-02,   7.94372559e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -1.49139404e-01,  -1.49139404e-01],
                        [ -1.98120117e-01,  -1.98120117e-01],
                        [ -1.95465088e-01,  -1.95465088e-01],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  1.57470703e-01,   1.57470703e-01],
                        [  1.80267334e-01,   1.80267334e-01],
                        [  1.81488037e-01,   1.81488037e-01],
                        [  1.66259766e-01,   1.66259766e-01],
                        [  1.48193359e-01,   1.48193359e-01],
                        [  1.36352539e-01,   1.36352539e-01],
                        [  1.29638672e-01,   1.29638672e-01],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  1.14898682e-01,   1.14898682e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  9.03930664e-02,   9.03930664e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -1.49353027e-01,  -1.49353027e-01],
                        [ -2.24090576e-01,  -2.24090576e-01],
                        [ -2.64068604e-01,  -2.64068604e-01],
                        [ -2.52349854e-01,  -2.52349854e-01],
                        [ -2.02178955e-01,  -2.02178955e-01],
                        [ -1.47857666e-01,  -1.47857666e-01],
                        [ -1.15203857e-01,  -1.15203857e-01],
                        [ -1.04187012e-01,  -1.04187012e-01],
                        [ -9.95483398e-02,  -9.95483398e-02],
                        [ -8.97827148e-02,  -8.97827148e-02],
                        [ -7.46154785e-02,  -7.46154785e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  8.41979980e-02,   8.41979980e-02],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  1.09130859e-01,   1.09130859e-01],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  6.74743652e-02,   6.74743652e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -1.01074219e-01,  -1.01074219e-01],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -1.99432373e-01,  -1.99432373e-01],
                        [ -1.76879883e-01,  -1.76879883e-01],
                        [ -1.26312256e-01,  -1.26312256e-01],
                        [ -7.81860352e-02,  -7.81860352e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.48712158e-01,   1.48712158e-01],
                        [  1.78619385e-01,   1.78619385e-01],
                        [  1.84326172e-01,   1.84326172e-01],
                        [  1.71783447e-01,   1.71783447e-01],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  1.48162842e-01,   1.48162842e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  9.03930664e-02,   9.03930664e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  6.06994629e-02,   6.06994629e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -1.49810791e-01,  -1.49810791e-01],
                        [ -2.18872070e-01,  -2.18872070e-01],
                        [ -2.59246826e-01,  -2.59246826e-01],
                        [ -2.55645752e-01,  -2.55645752e-01],
                        [ -2.14508057e-01,  -2.14508057e-01],
                        [ -1.64794922e-01,  -1.64794922e-01],
                        [ -1.32659912e-01,  -1.32659912e-01],
                        [ -1.19262695e-01,  -1.19262695e-01],
                        [ -1.09741211e-01,  -1.09741211e-01],
                        [ -9.63439941e-02,  -9.63439941e-02],
                        [ -8.17565918e-02,  -8.17565918e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  1.06414795e-01,   1.06414795e-01],
                        [  1.25122070e-01,   1.25122070e-01],
                        [  1.33850098e-01,   1.33850098e-01],
                        [  1.21429443e-01,   1.21429443e-01],
                        [  7.62023926e-02,   7.62023926e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -1.06292725e-01,  -1.06292725e-01],
                        [ -1.88690186e-01,  -1.88690186e-01],
                        [ -2.17071533e-01,  -2.17071533e-01],
                        [ -1.87072754e-01,  -1.87072754e-01],
                        [ -1.28540039e-01,  -1.28540039e-01],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  1.43188477e-01,   1.43188477e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.66748047e-01,   1.66748047e-01],
                        [  1.53015137e-01,   1.53015137e-01],
                        [  1.40319824e-01,   1.40319824e-01],
                        [  1.36444092e-01,   1.36444092e-01],
                        [  1.37512207e-01,   1.37512207e-01],
                        [  1.35955811e-01,   1.35955811e-01],
                        [  1.29272461e-01,   1.29272461e-01],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  9.96093750e-02,   9.96093750e-02],
                        [  1.34613037e-01,   1.34613037e-01],
                        [  1.32049561e-01,   1.32049561e-01],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  7.08312988e-02,   7.08312988e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  2.07519531e-03,   2.07519531e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  4.94384766e-03,   4.94384766e-03],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -8.35571289e-02,  -8.35571289e-02],
                        [ -1.59088135e-01,  -1.59088135e-01],
                        [ -2.23022461e-01,  -2.23022461e-01],
                        [ -2.52746582e-01,  -2.52746582e-01],
                        [ -2.37060547e-01,  -2.37060547e-01],
                        [ -1.88354492e-01,  -1.88354492e-01],
                        [ -1.37207031e-01,  -1.37207031e-01],
                        [ -1.09008789e-01,  -1.09008789e-01],
                        [ -1.05468750e-01,  -1.05468750e-01],
                        [ -1.09893799e-01,  -1.09893799e-01],
                        [ -1.07879639e-01,  -1.07879639e-01],
                        [ -9.69543457e-02,  -9.69543457e-02],
                        [ -8.00781250e-02,  -8.00781250e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  9.98229980e-02,   9.98229980e-02],
                        [  1.11358643e-01,   1.11358643e-01],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -1.00769043e-01,  -1.00769043e-01],
                        [ -1.58935547e-01,  -1.58935547e-01],
                        [ -1.75201416e-01,  -1.75201416e-01],
                        [ -1.50085449e-01,  -1.50085449e-01],
                        [ -1.06414795e-01,  -1.06414795e-01],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  7.90710449e-02,   7.90710449e-02],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.51702881e-01,   1.51702881e-01],
                        [  1.67083740e-01,   1.67083740e-01],
                        [  1.63513184e-01,   1.63513184e-01],
                        [  1.48468018e-01,   1.48468018e-01],
                        [  1.33331299e-01,   1.33331299e-01],
                        [  1.25640869e-01,   1.25640869e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.20361328e-01,   1.20361328e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  1.13281250e-01,   1.13281250e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.05865479e-01,   1.05865479e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  1.13800049e-01,   1.13800049e-01],
                        [  9.69238281e-02,   9.69238281e-02],
                        [  7.40661621e-02,   7.40661621e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -1.38244629e-01,  -1.38244629e-01],
                        [ -2.23236084e-01,  -2.23236084e-01],
                        [ -2.77648926e-01,  -2.77648926e-01],
                        [ -2.82379150e-01,  -2.82379150e-01],
                        [ -2.43957520e-01,  -2.43957520e-01],
                        [ -1.89788818e-01,  -1.89788818e-01],
                        [ -1.44836426e-01,  -1.44836426e-01],
                        [ -1.14440918e-01,  -1.14440918e-01],
                        [ -9.09729004e-02,  -9.09729004e-02],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  1.03240967e-01,   1.03240967e-01],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -1.25732422e-01,  -1.25732422e-01],
                        [ -1.77062988e-01,  -1.77062988e-01],
                        [ -1.77398682e-01,  -1.77398682e-01],
                        [ -1.37542725e-01,  -1.37542725e-01],
                        [ -8.91723633e-02,  -8.91723633e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  1.61468506e-01,   1.61468506e-01],
                        [  1.86462402e-01,   1.86462402e-01],
                        [  1.92291260e-01,   1.92291260e-01],
                        [  1.78253174e-01,   1.78253174e-01],
                        [  1.51947021e-01,   1.51947021e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.10900879e-01,   1.10900879e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  9.58557129e-02,   9.58557129e-02],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  5.06286621e-02,   5.06286621e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -1.86523438e-01,  -1.86523438e-01],
                        [ -2.51007080e-01,  -2.51007080e-01],
                        [ -2.71728516e-01,  -2.71728516e-01],
                        [ -2.46643066e-01,  -2.46643066e-01],
                        [ -1.97631836e-01,  -1.97631836e-01],
                        [ -1.52160645e-01,  -1.52160645e-01],
                        [ -1.23565674e-01,  -1.23565674e-01],
                        [ -1.07238770e-01,  -1.07238770e-01],
                        [ -9.30480957e-02,  -9.30480957e-02],
                        [ -7.82775879e-02,  -7.82775879e-02],
                        [ -6.63146973e-02,  -6.63146973e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  8.43505859e-02,   8.43505859e-02],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -9.68627930e-02,  -9.68627930e-02],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.73095703e-01,  -1.73095703e-01],
                        [ -1.53717041e-01,  -1.53717041e-01],
                        [ -1.12426758e-01,  -1.12426758e-01],
                        [ -7.06787109e-02,  -7.06787109e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  5.30090332e-02,   5.30090332e-02],
                        [  9.73510742e-02,   9.73510742e-02],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  1.67480469e-01,   1.67480469e-01],
                        [  1.67846680e-01,   1.67846680e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  1.17828369e-01,   1.17828369e-01],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  1.34704590e-01,   1.34704590e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  9.39025879e-02,   9.39025879e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -1.35559082e-01,  -1.35559082e-01],
                        [ -2.13562012e-01,  -2.13562012e-01],
                        [ -2.64617920e-01,  -2.64617920e-01],
                        [ -2.71697998e-01,  -2.71697998e-01],
                        [ -2.37945557e-01,  -2.37945557e-01],
                        [ -1.83959961e-01,  -1.83959961e-01],
                        [ -1.33605957e-01,  -1.33605957e-01],
                        [ -1.01806641e-01,  -1.01806641e-01],
                        [ -8.94470215e-02,  -8.94470215e-02],
                        [ -8.63952637e-02,  -8.63952637e-02],
                        [ -8.16040039e-02,  -8.16040039e-02],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  6.80541992e-02,   6.80541992e-02],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.46972656e-01,   1.46972656e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.20941162e-01,   1.20941162e-01],
                        [  4.97741699e-02,   4.97741699e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -1.41540527e-01,  -1.41540527e-01],
                        [ -1.91375732e-01,  -1.91375732e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -1.43615723e-01,  -1.43615723e-01],
                        [ -9.12170410e-02,  -9.12170410e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  7.50732422e-02,   7.50732422e-02],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.75872803e-01,   1.75872803e-01],
                        [  2.04040527e-01,   2.04040527e-01],
                        [  2.01293945e-01,   2.01293945e-01],
                        [  1.70410156e-01,   1.70410156e-01],
                        [  1.29577637e-01,   1.29577637e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  8.19396973e-02,   8.19396973e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  9.22241211e-02,   9.22241211e-02],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.10961914e-01,   1.10961914e-01],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  5.19104004e-02,   5.19104004e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  6.83593750e-03,   6.83593750e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  5.31005859e-03,   5.31005859e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  3.37829590e-02,   3.37829590e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -1.36871338e-01,  -1.36871338e-01],
                        [ -2.14599609e-01,  -2.14599609e-01],
                        [ -2.64038086e-01,  -2.64038086e-01],
                        [ -2.67059326e-01,  -2.67059326e-01],
                        [ -2.31353760e-01,  -2.31353760e-01],
                        [ -1.84570312e-01,  -1.84570312e-01],
                        [ -1.48834229e-01,  -1.48834229e-01],
                        [ -1.26129150e-01,  -1.26129150e-01],
                        [ -1.08520508e-01,  -1.08520508e-01],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -7.93762207e-02,  -7.93762207e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  6.63452148e-02,   6.63452148e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  8.71276855e-02,   8.71276855e-02],
                        [  1.05926514e-01,   1.05926514e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  1.29821777e-01,   1.29821777e-01],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -1.51916504e-01,  -1.51916504e-01],
                        [ -1.79168701e-01,  -1.79168701e-01],
                        [ -1.60949707e-01,  -1.60949707e-01],
                        [ -1.17462158e-01,  -1.17462158e-01],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -4.69055176e-02,  -4.69055176e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.68365479e-01,   1.68365479e-01],
                        [  1.97814941e-01,   1.97814941e-01],
                        [  2.00469971e-01,   2.00469971e-01],
                        [  1.80725098e-01,   1.80725098e-01],
                        [  1.49963379e-01,   1.49963379e-01],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  6.13098145e-02,   6.13098145e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  1.05865479e-01,   1.05865479e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  6.30493164e-02,   6.30493164e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -8.83789062e-02,  -8.83789062e-02],
                        [ -1.58447266e-01,  -1.58447266e-01],
                        [ -2.16735840e-01,  -2.16735840e-01],
                        [ -2.42034912e-01,  -2.42034912e-01],
                        [ -2.31781006e-01,  -2.31781006e-01],
                        [ -2.01110840e-01,  -2.01110840e-01],
                        [ -1.68029785e-01,  -1.68029785e-01],
                        [ -1.41418457e-01,  -1.41418457e-01],
                        [ -1.19964600e-01,  -1.19964600e-01],
                        [ -9.93041992e-02,  -9.93041992e-02],
                        [ -7.90710449e-02,  -7.90710449e-02],
                        [ -6.32324219e-02,  -6.32324219e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  8.80432129e-02,   8.80432129e-02],
                        [  1.01684570e-01,   1.01684570e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [ -7.19299316e-02,  -7.19299316e-02],
                        [ -1.52465820e-01,  -1.52465820e-01],
                        [ -1.93695068e-01,  -1.93695068e-01],
                        [ -1.85363770e-01,  -1.85363770e-01],
                        [ -1.43310547e-01,  -1.43310547e-01],
                        [ -9.51843262e-02,  -9.51843262e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.52496338e-01,   1.52496338e-01],
                        [  1.77825928e-01,   1.77825928e-01],
                        [  1.74468994e-01,   1.74468994e-01],
                        [  1.50482178e-01,   1.50482178e-01],
                        [  1.20910645e-01,   1.20910645e-01],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  1.09497070e-01,   1.09497070e-01],
                        [  1.18225098e-01,   1.18225098e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  1.03851318e-01,   1.03851318e-01],
                        [  8.77990723e-02,   8.77990723e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  6.13708496e-02,   6.13708496e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -7.28454590e-02,  -7.28454590e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  7.34863281e-02,   7.34863281e-02],
                        [  1.08734131e-01,   1.08734131e-01],
                        [  1.17401123e-01,   1.17401123e-01],
                        [  1.02966309e-01,   1.02966309e-01],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  5.32531738e-02,   5.32531738e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -1.16058350e-01,  -1.16058350e-01],
                        [ -1.95678711e-01,  -1.95678711e-01],
                        [ -2.52014160e-01,  -2.52014160e-01],
                        [ -2.68341064e-01,  -2.68341064e-01],
                        [ -2.47711182e-01,  -2.47711182e-01],
                        [ -2.07275391e-01,  -2.07275391e-01],
                        [ -1.64306641e-01,  -1.64306641e-01],
                        [ -1.28417969e-01,  -1.28417969e-01],
                        [ -1.02752686e-01,  -1.02783203e-01],
                        [ -8.80432129e-02,  -8.80432129e-02],
                        [ -8.24890137e-02,  -8.24890137e-02],
                        [ -7.99865723e-02,  -7.99865723e-02],
                        [ -7.26623535e-02,  -7.26623535e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  5.20019531e-02,   5.19714355e-02],
                        [  6.67114258e-02,   6.67114258e-02],
                        [  8.55407715e-02,   8.55407715e-02],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.27471924e-01,   1.27471924e-01],
                        [  1.34674072e-01,   1.34674072e-01],
                        [  1.21032715e-01,   1.21032715e-01],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -1.57012939e-01,  -1.57043457e-01],
                        [ -1.94824219e-01,  -1.94824219e-01],
                        [ -1.83624268e-01,  -1.83654785e-01],
                        [ -1.38702393e-01,  -1.38702393e-01],
                        [ -8.94775391e-02,  -8.94775391e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -5.32836914e-02,  -5.33142090e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -2.74353027e-02,  -2.74658203e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  1.34460449e-01,   1.34460449e-01],
                        [  1.71386719e-01,   1.71356201e-01],
                        [  1.81365967e-01,   1.81335449e-01],
                        [  1.68975830e-01,   1.68975830e-01],
                        [  1.46545410e-01,   1.46545410e-01],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  1.10351562e-01,   1.10351562e-01],
                        [  9.88159180e-02,   9.88159180e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  9.85107422e-02,   9.85107422e-02],
                        [  1.06414795e-01,   1.06414795e-01],
                        [  1.08856201e-01,   1.08825684e-01],
                        [  1.03607178e-01,   1.03576660e-01],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  7.64770508e-02,   7.64770508e-02],
                        [  5.87463379e-02,   5.87158203e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  3.57360840e-02,   3.57055664e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.05895996e-02,   1.05590820e-02],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.69677734e-02,  -1.69982910e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -5.29785156e-02,  -5.30090332e-02],
                        [ -5.05676270e-02,  -5.05981445e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  1.01318359e-01,   1.01318359e-01],
                        [  1.24450684e-01,   1.24450684e-01],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  4.77905273e-02,   4.77905273e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.17187500e-02,   1.16882324e-02],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  9.97924805e-03,   9.94873047e-03],
                        [  7.50732422e-03,   7.47680664e-03],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -1.25122070e-03,  -1.28173828e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -1.38244629e-02,  -1.38549805e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -4.52880859e-02,  -4.53186035e-02],
                        [ -4.57458496e-02,  -4.57763672e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  5.96618652e-02,   5.96923828e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -1.55914307e-01,  -1.55914307e-01],
                        [ -2.27996826e-01,  -2.27996826e-01],
                        [ -2.65991211e-01,  -2.65991211e-01],
                        [ -2.61840820e-01,  -2.61840820e-01],
                        [ -2.25799561e-01,  -2.25799561e-01],
                        [ -1.79931641e-01,  -1.79931641e-01],
                        [ -1.43432617e-01,  -1.43432617e-01],
                        [ -1.21704102e-01,  -1.21704102e-01],
                        [ -1.08367920e-01,  -1.08337402e-01],
                        [ -9.45434570e-02,  -9.45129395e-02],
                        [ -7.57141113e-02,  -7.57141113e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  1.53503418e-02,   1.53808594e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  4.17175293e-02,   4.17480469e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  9.10339355e-02,   9.10644531e-02],
                        [  1.07910156e-01,   1.07940674e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.27807617e-01,   1.27807617e-01],
                        [  1.03912354e-01,   1.03942871e-01],
                        [  4.19006348e-02,   4.19311523e-02],
                        [ -4.73022461e-02,  -4.72717285e-02],
                        [ -1.29791260e-01,  -1.29760742e-01],
                        [ -1.73156738e-01,  -1.73156738e-01],
                        [ -1.70898438e-01,  -1.70867920e-01],
                        [ -1.41815186e-01,  -1.41815186e-01],
                        [ -1.11480713e-01,  -1.11450195e-01],
                        [ -9.33837891e-02,  -9.33532715e-02],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -7.96203613e-02,  -7.95898438e-02],
                        [ -7.27539062e-02,  -7.27233887e-02],
                        [ -6.37512207e-02,  -6.37207031e-02],
                        [ -4.80041504e-02,  -4.79736328e-02],
                        [ -1.77612305e-02,  -1.77307129e-02],
                        [  2.98156738e-02,   2.98461914e-02],
                        [  8.73413086e-02,   8.73718262e-02],
                        [  1.41235352e-01,   1.41265869e-01],
                        [  1.77886963e-01,   1.77886963e-01],
                        [  1.89208984e-01,   1.89239502e-01],
                        [  1.77429199e-01,   1.77459717e-01],
                        [  1.54083252e-01,   1.54113770e-01],
                        [  1.31683350e-01,   1.31713867e-01],
                        [  1.15814209e-01,   1.15814209e-01],
                        [  1.04217529e-01,   1.04248047e-01],
                        [  9.36584473e-02,   9.36889648e-02],
                        [  8.46862793e-02,   8.47167969e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  7.34252930e-02,   7.34558105e-02],
                        [  6.93054199e-02,   6.93359375e-02],
                        [  6.59484863e-02,   6.59790039e-02],
                        [  6.27441406e-02,   6.27746582e-02],
                        [  6.02416992e-02,   6.02722168e-02],
                        [  5.85327148e-02,   5.85632324e-02],
                        [  5.44128418e-02,   5.44433594e-02],
                        [  4.53796387e-02,   4.54101562e-02],
                        [  3.52783203e-02,   3.53088379e-02],
                        [  3.08837891e-02,   3.09143066e-02],
                        [  3.26538086e-02,   3.26843262e-02],
                        [  3.23791504e-02,   3.24096680e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [ -5.18798828e-04,  -4.88281250e-04],
                        [ -2.72521973e-02,  -2.72216797e-02],
                        [ -4.79736328e-02,  -4.79431152e-02],
                        [ -5.21240234e-02,  -5.20935059e-02],
                        [ -3.64379883e-02,  -3.64074707e-02],
                        [ -6.28662109e-03,  -6.25610352e-03],
                        [  3.17382812e-02,   3.17687988e-02],
                        [  7.20825195e-02,   7.21130371e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.11267090e-01,   1.11297607e-01],
                        [  8.95080566e-02,   8.95385742e-02],
                        [  5.20629883e-02,   5.20935059e-02],
                        [  2.14233398e-02,   2.14538574e-02],
                        [  1.04980469e-02,   1.05285645e-02],
                        [  1.53198242e-02,   1.53503418e-02],
                        [  2.31933594e-02,   2.32238770e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.55029297e-02,   1.55334473e-02],
                        [  1.06506348e-02,   1.06811523e-02],
                        [  1.83105469e-04,   2.13623047e-04],
                        [ -1.57775879e-02,  -1.57470703e-02],
                        [ -3.27148438e-02,  -3.26843262e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -4.35485840e-02,  -4.35180664e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -3.00903320e-02,  -3.00598145e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.26843262e-02,  -3.26538086e-02],
                        [ -3.83911133e-02,  -3.83605957e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  6.37817383e-02,   6.37817383e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -1.17187500e-01,  -1.17187500e-01],
                        [ -1.94763184e-01,  -1.94763184e-01],
                        [ -2.51464844e-01,  -2.51464844e-01],
                        [ -2.67913818e-01,  -2.67913818e-01],
                        [ -2.44689941e-01,  -2.44720459e-01],
                        [ -2.02117920e-01,  -2.02117920e-01],
                        [ -1.63635254e-01,  -1.63665771e-01],
                        [ -1.39282227e-01,  -1.39312744e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -1.07421875e-01,  -1.07452393e-01],
                        [ -8.79821777e-02,  -8.80126953e-02],
                        [ -6.76574707e-02,  -6.76879883e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -3.37219238e-02,  -3.37524414e-02],
                        [ -1.87377930e-02,  -1.87683105e-02],
                        [ -4.82177734e-03,  -4.85229492e-03],
                        [  7.29370117e-03,   7.26318359e-03],
                        [  1.74865723e-02,   1.74560547e-02],
                        [  2.53601074e-02,   2.53295898e-02],
                        [  3.12194824e-02,   3.11889648e-02],
                        [  3.72314453e-02,   3.72009277e-02],
                        [  4.53796387e-02,   4.53491211e-02],
                        [  5.47790527e-02,   5.47180176e-02],
                        [  6.26831055e-02,   6.26220703e-02],
                        [  7.00988770e-02,   7.00683594e-02],
                        [  8.38012695e-02,   8.37707520e-02],
                        [  1.06536865e-01,   1.06506348e-01],
                        [  1.26464844e-01,   1.26434326e-01],
                        [  1.22955322e-01,   1.22894287e-01],
                        [  8.36181641e-02,   8.35571289e-02],
                        [  1.19628906e-02,   1.19018555e-02],
                        [ -7.53784180e-02,  -7.54089355e-02],
                        [ -1.50756836e-01,  -1.50817871e-01],
                        [ -1.85577393e-01,  -1.85638428e-01],
                        [ -1.71875000e-01,  -1.71905518e-01],
                        [ -1.31134033e-01,  -1.31195068e-01],
                        [ -9.50317383e-02,  -9.50622559e-02],
                        [ -7.84606934e-02,  -7.85217285e-02],
                        [ -7.46459961e-02,  -7.47070312e-02],
                        [ -6.95495605e-02,  -6.95800781e-02],
                        [ -5.53894043e-02,  -5.54504395e-02],
                        [ -3.19213867e-02,  -3.19519043e-02],
                        [ -6.40869141e-04,  -7.01904297e-04],
                        [  3.75061035e-02,   3.74450684e-02],
                        [  8.00781250e-02,   8.00476074e-02],
                        [  1.21246338e-01,   1.21185303e-01],
                        [  1.52526855e-01,   1.52465820e-01],
                        [  1.64794922e-01,   1.64733887e-01],
                        [  1.54937744e-01,   1.54876709e-01],
                        [  1.32568359e-01,   1.32507324e-01],
                        [  1.15081787e-01,   1.15020752e-01],
                        [  1.11816406e-01,   1.11785889e-01],
                        [  1.16149902e-01,   1.16088867e-01],
                        [  1.14959717e-01,   1.14868164e-01],
                        [  1.02600098e-01,   1.02539062e-01],
                        [  8.47778320e-02,   8.47167969e-02],
                        [  7.03125000e-02,   7.02209473e-02],
                        [  6.20422363e-02,   6.19812012e-02],
                        [  5.77697754e-02,   5.77087402e-02],
                        [  5.46875000e-02,   5.46264648e-02],
                        [  5.01403809e-02,   5.00793457e-02],
                        [  4.43115234e-02,   4.42504883e-02],
                        [  4.23583984e-02,   4.22973633e-02],
                        [  4.73937988e-02,   4.73327637e-02],
                        [  5.48095703e-02,   5.47180176e-02],
                        [  5.67626953e-02,   5.67016602e-02],
                        [  5.00488281e-02,   4.99877930e-02],
                        [  3.82690430e-02,   3.82080078e-02],
                        [  2.54516602e-02,   2.53906250e-02],
                        [  9.76562500e-03,   9.70458984e-03],
                        [ -1.09558105e-02,  -1.10168457e-02],
                        [ -3.07312012e-02,  -3.07922363e-02],
                        [ -3.92456055e-02,  -3.93066406e-02],
                        [ -3.19519043e-02,  -3.20129395e-02],
                        [ -1.26647949e-02,  -1.27258301e-02],
                        [  1.35498047e-02,   1.34887695e-02],
                        [  4.39147949e-02,   4.38537598e-02],
                        [  7.29980469e-02,   7.29370117e-02],
                        [  9.08203125e-02,   9.07592773e-02],
                        [  9.08203125e-02,   9.07592773e-02],
                        [  7.55004883e-02,   7.54699707e-02],
                        [  5.36804199e-02,   5.36193848e-02],
                        [  3.59191895e-02,   3.58886719e-02],
                        [  2.85339355e-02,   2.85034180e-02],
                        [  2.71911621e-02,   2.71301270e-02],
                        [  2.18505859e-02,   2.18200684e-02],
                        [  1.00097656e-02,   9.94873047e-03],
                        [  5.49316406e-04,   5.18798828e-04],
                        [  3.05175781e-03,   2.99072266e-03],
                        [  1.45874023e-02,   1.45568848e-02],
                        [  2.17285156e-02,   2.16979980e-02],
                        [  1.60217285e-02,   1.59912109e-02],
                        [  1.89208984e-03,   1.86157227e-03],
                        [ -1.17187500e-02,  -1.17492676e-02],
                        [ -2.02026367e-02,  -2.02331543e-02],
                        [ -2.33459473e-02,  -2.33764648e-02],
                        [ -2.42919922e-02,  -2.43225098e-02],
                        [ -2.91137695e-02,  -2.91442871e-02],
                        [ -4.02832031e-02,  -4.03137207e-02],
                        [ -5.03234863e-02,  -5.03540039e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -3.58886719e-02,  -3.59191895e-02],
                        [ -2.31933594e-02,  -2.32238770e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.84936523e-02,  -1.85241699e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -2.84118652e-02,  -2.84423828e-02],
                        [ -3.33251953e-02,  -3.33557129e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -2.31933594e-02,  -2.32238770e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [  8.05664062e-03,   8.02612305e-03],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  7.39440918e-02,   7.39440918e-02],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -9.44824219e-02,  -9.44519043e-02],
                        [ -1.85394287e-01,  -1.85394287e-01],
                        [ -2.56927490e-01,  -2.56896973e-01],
                        [ -2.86834717e-01,  -2.86834717e-01],
                        [ -2.67456055e-01,  -2.67425537e-01],
                        [ -2.14508057e-01,  -2.14477539e-01],
                        [ -1.60827637e-01,  -1.60797119e-01],
                        [ -1.29760742e-01,  -1.29730225e-01],
                        [ -1.16699219e-01,  -1.16668701e-01],
                        [ -1.03271484e-01,  -1.03240967e-01],
                        [ -8.36486816e-02,  -8.36181641e-02],
                        [ -6.69555664e-02,  -6.69250488e-02],
                        [ -5.86242676e-02,  -5.85937500e-02],
                        [ -5.28259277e-02,  -5.27648926e-02],
                        [ -4.18395996e-02,  -4.17785645e-02],
                        [ -2.28271484e-02,  -2.27661133e-02],
                        [  9.76562500e-04,   1.03759766e-03],
                        [  2.10571289e-02,   2.11181641e-02],
                        [  3.14941406e-02,   3.15246582e-02],
                        [  3.51867676e-02,   3.52478027e-02],
                        [  3.82385254e-02,   3.82995605e-02],
                        [  4.16259766e-02,   4.16870117e-02],
                        [  4.42199707e-02,   4.42810059e-02],
                        [  4.99877930e-02,   5.00488281e-02],
                        [  6.46362305e-02,   6.46972656e-02],
                        [  8.66699219e-02,   8.67309570e-02],
                        [  1.08245850e-01,   1.08337402e-01],
                        [  1.22406006e-01,   1.22467041e-01],
                        [  1.22589111e-01,   1.22680664e-01],
                        [  1.00189209e-01,   1.00250244e-01],
                        [  4.93164062e-02,   4.93774414e-02],
                        [ -2.46887207e-02,  -2.45971680e-02],
                        [ -1.03332520e-01,  -1.03240967e-01],
                        [ -1.61651611e-01,  -1.61560059e-01],
                        [ -1.81915283e-01,  -1.81823730e-01],
                        [ -1.65802002e-01,  -1.65740967e-01],
                        [ -1.32629395e-01,  -1.32568359e-01],
                        [ -1.04492188e-01,  -1.04400635e-01],
                        [ -9.10339355e-02,  -9.09729004e-02],
                        [ -8.46862793e-02,  -8.45947266e-02],
                        [ -7.14111328e-02,  -7.13195801e-02],
                        [ -4.44335938e-02,  -4.43420410e-02],
                        [ -4.24194336e-03,  -4.15039062e-03],
                        [  4.65087891e-02,   4.66003418e-02],
                        [  1.00646973e-01,   1.00738525e-01],
                        [  1.43188477e-01,   1.43280029e-01],
                        [  1.60308838e-01,   1.60400391e-01],
                        [  1.53930664e-01,   1.54022217e-01],
                        [  1.39434814e-01,   1.39526367e-01],
                        [  1.27502441e-01,   1.27593994e-01],
                        [  1.18225098e-01,   1.18316650e-01],
                        [  1.09893799e-01,   1.09985352e-01],
                        [  1.02416992e-01,   1.02508545e-01],
                        [  9.42077637e-02,   9.43298340e-02],
                        [  8.36181641e-02,   8.37402344e-02],
                        [  7.33032227e-02,   7.33947754e-02],
                        [  6.83288574e-02,   6.84204102e-02],
                        [  6.92443848e-02,   6.93359375e-02],
                        [  7.18078613e-02,   7.19299316e-02],
                        [  7.22045898e-02,   7.23266602e-02],
                        [  6.79016113e-02,   6.80236816e-02],
                        [  5.68237305e-02,   5.69152832e-02],
                        [  4.19616699e-02,   4.20837402e-02],
                        [  3.31115723e-02,   3.32336426e-02],
                        [  3.51257324e-02,   3.52172852e-02],
                        [  3.98864746e-02,   3.99780273e-02],
                        [  3.74450684e-02,   3.75671387e-02],
                        [  2.73132324e-02,   2.74353027e-02],
                        [  1.38549805e-02,   1.39465332e-02],
                        [ -6.10351562e-04,  -5.18798828e-04],
                        [ -1.50451660e-02,  -1.49230957e-02],
                        [ -2.73132324e-02,  -2.72216797e-02],
                        [ -3.43017578e-02,  -3.42102051e-02],
                        [ -3.16772461e-02,  -3.15856934e-02],
                        [ -1.44042969e-02,  -1.43127441e-02],
                        [  1.74560547e-02,   1.75476074e-02],
                        [  5.42907715e-02,   5.43823242e-02],
                        [  8.22143555e-02,   8.23059082e-02],
                        [  9.17358398e-02,   9.18273926e-02],
                        [  8.09936523e-02,   8.10546875e-02],
                        [  5.66406250e-02,   5.67321777e-02],
                        [  3.28369141e-02,   3.28979492e-02],
                        [  2.19726562e-02,   2.20642090e-02],
                        [  2.51770020e-02,   2.52685547e-02],
                        [  3.39050293e-02,   3.39660645e-02],
                        [  3.91235352e-02,   3.91845703e-02],
                        [  3.66210938e-02,   3.66821289e-02],
                        [  2.78015137e-02,   2.78625488e-02],
                        [  1.76391602e-02,   1.77307129e-02],
                        [  9.76562500e-03,   9.82666016e-03],
                        [  3.72314453e-03,   3.78417969e-03],
                        [ -3.05175781e-03,  -2.99072266e-03],
                        [ -1.19934082e-02,  -1.19323730e-02],
                        [ -2.15454102e-02,  -2.14843750e-02],
                        [ -2.91137695e-02,  -2.90527344e-02],
                        [ -3.32946777e-02,  -3.32336426e-02],
                        [ -3.41186523e-02,  -3.40881348e-02],
                        [ -3.22265625e-02,  -3.21655273e-02],
                        [ -2.84729004e-02,  -2.84118652e-02],
                        [ -2.52075195e-02,  -2.51464844e-02],
                        [ -2.57873535e-02,  -2.57263184e-02],
                        [ -3.06396484e-02,  -3.05786133e-02],
                        [ -3.71093750e-02,  -3.70483398e-02],
                        [ -4.39453125e-02,  -4.39147949e-02],
                        [ -4.97131348e-02,  -4.96826172e-02],
                        [ -4.88586426e-02,  -4.88281250e-02],
                        [ -3.66516113e-02,  -3.66210938e-02],
                        [ -1.69067383e-02,  -1.68762207e-02],
                        [  1.83105469e-04,   2.13623047e-04],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  1.32751465e-02,   1.33056641e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  6.47583008e-02,   6.47583008e-02],
                        [  5.85632324e-02,   5.85632324e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -1.19384766e-01,  -1.19384766e-01],
                        [ -2.13104248e-01,  -2.13104248e-01],
                        [ -2.81311035e-01,  -2.81341553e-01],
                        [ -2.97912598e-01,  -2.97943115e-01],
                        [ -2.61413574e-01,  -2.61444092e-01],
                        [ -1.97845459e-01,  -1.97875977e-01],
                        [ -1.42517090e-01,  -1.42547607e-01],
                        [ -1.15173340e-01,  -1.15203857e-01],
                        [ -1.10260010e-01,  -1.10290527e-01],
                        [ -1.07543945e-01,  -1.07604980e-01],
                        [ -9.32922363e-02,  -9.33227539e-02],
                        [ -7.14111328e-02,  -7.14721680e-02],
                        [ -5.30700684e-02,  -5.31311035e-02],
                        [ -4.11376953e-02,  -4.11987305e-02],
                        [ -3.03039551e-02,  -3.03649902e-02],
                        [ -1.69982910e-02,  -1.70593262e-02],
                        [ -2.38037109e-03,  -2.44140625e-03],
                        [  1.08642578e-02,   1.07727051e-02],
                        [  2.15454102e-02,   2.14538574e-02],
                        [  2.99682617e-02,   2.99072266e-02],
                        [  3.60412598e-02,   3.59802246e-02],
                        [  3.84826660e-02,   3.84216309e-02],
                        [  3.86047363e-02,   3.85131836e-02],
                        [  4.25415039e-02,   4.24499512e-02],
                        [  5.63964844e-02,   5.63049316e-02],
                        [  8.02001953e-02,   8.01086426e-02],
                        [  1.07910156e-01,   1.07849121e-01],
                        [  1.31439209e-01,   1.31347656e-01],
                        [  1.40960693e-01,   1.40869141e-01],
                        [  1.23016357e-01,   1.22924805e-01],
                        [  6.72912598e-02,   6.71997070e-02],
                        [ -1.95007324e-02,  -1.95922852e-02],
                        [ -1.11328125e-01,  -1.11450195e-01],
                        [ -1.76818848e-01,  -1.76940918e-01],
                        [ -1.97113037e-01,  -1.97204590e-01],
                        [ -1.75598145e-01,  -1.75720215e-01],
                        [ -1.35375977e-01,  -1.35498047e-01],
                        [ -1.04034424e-01,  -1.04125977e-01],
                        [ -9.25292969e-02,  -9.26513672e-02],
                        [ -8.82873535e-02,  -8.84094238e-02],
                        [ -7.10449219e-02,  -7.11364746e-02],
                        [ -3.12500000e-02,  -3.13720703e-02],
                        [  2.55737305e-02,   2.54516602e-02],
                        [  8.45336914e-02,   8.44116211e-02],
                        [  1.30126953e-01,   1.30004883e-01],
                        [  1.53717041e-01,   1.53564453e-01],
                        [  1.56372070e-01,   1.56219482e-01],
                        [  1.46575928e-01,   1.46453857e-01],
                        [  1.34338379e-01,   1.34216309e-01],
                        [  1.25549316e-01,   1.25396729e-01],
                        [  1.19598389e-01,   1.19476318e-01],
                        [  1.12426758e-01,   1.12274170e-01],
                        [  1.02233887e-01,   1.02081299e-01],
                        [  9.07897949e-02,   9.06677246e-02],
                        [  8.01391602e-02,   7.99865723e-02],
                        [  7.00683594e-02,   6.99157715e-02],
                        [  5.80444336e-02,   5.79223633e-02],
                        [  4.33349609e-02,   4.32128906e-02],
                        [  2.96020508e-02,   2.94494629e-02],
                        [  2.15148926e-02,   2.13623047e-02],
                        [  2.17895508e-02,   2.16369629e-02],
                        [  3.04260254e-02,   3.03039551e-02],
                        [  4.35180664e-02,   4.33654785e-02],
                        [  5.49011230e-02,   5.47485352e-02],
                        [  6.09741211e-02,   6.08215332e-02],
                        [  6.26220703e-02,   6.24694824e-02],
                        [  6.11877441e-02,   6.10656738e-02],
                        [  5.38635254e-02,   5.37414551e-02],
                        [  3.55529785e-02,   3.54003906e-02],
                        [  5.43212891e-03,   5.31005859e-03],
                        [ -2.80151367e-02,  -2.81372070e-02],
                        [ -5.12084961e-02,  -5.13305664e-02],
                        [ -5.69152832e-02,  -5.70373535e-02],
                        [ -4.73937988e-02,  -4.75158691e-02],
                        [ -2.52685547e-02,  -2.54211426e-02],
                        [  9.82666016e-03,   9.70458984e-03],
                        [  5.27954102e-02,   5.26733398e-02],
                        [  8.86230469e-02,   8.85009766e-02],
                        [  1.02386475e-01,   1.02264404e-01],
                        [  9.15527344e-02,   9.14306641e-02],
                        [  6.62841797e-02,   6.61621094e-02],
                        [  4.19616699e-02,   4.18395996e-02],
                        [  2.93579102e-02,   2.92358398e-02],
                        [  2.74353027e-02,   2.73437500e-02],
                        [  2.85949707e-02,   2.84729004e-02],
                        [  2.78625488e-02,   2.77404785e-02],
                        [  2.46887207e-02,   2.45666504e-02],
                        [  2.09350586e-02,   2.08435059e-02],
                        [  1.82800293e-02,   1.81884766e-02],
                        [  1.55334473e-02,   1.54418945e-02],
                        [  1.00402832e-02,   9.94873047e-03],
                        [  9.46044922e-04,   8.54492188e-04],
                        [ -9.27734375e-03,  -9.36889648e-03],
                        [ -1.84631348e-02,  -1.85546875e-02],
                        [ -2.71606445e-02,  -2.72216797e-02],
                        [ -3.38134766e-02,  -3.38745117e-02],
                        [ -3.43627930e-02,  -3.44543457e-02],
                        [ -3.03039551e-02,  -3.03955078e-02],
                        [ -2.87780762e-02,  -2.88391113e-02],
                        [ -3.21655273e-02,  -3.22265625e-02],
                        [ -3.47290039e-02,  -3.47900391e-02],
                        [ -3.16772461e-02,  -3.17382812e-02],
                        [ -2.60009766e-02,  -2.60620117e-02],
                        [ -2.30102539e-02,  -2.30712891e-02],
                        [ -2.26440430e-02,  -2.27050781e-02],
                        [ -2.11791992e-02,  -2.12097168e-02],
                        [ -1.71508789e-02,  -1.71813965e-02],
                        [ -1.06506348e-02,  -1.07116699e-02],
                        [  1.52587891e-04,   1.22070312e-04],
                        [  1.72729492e-02,   1.72424316e-02],
                        [  3.78417969e-02,   3.78112793e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  6.52465820e-02,   6.52465820e-02],
                        [  6.71081543e-02,   6.70776367e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -1.23870850e-01,  -1.23901367e-01],
                        [ -2.10052490e-01,  -2.10052490e-01],
                        [ -2.69287109e-01,  -2.69287109e-01],
                        [ -2.82867432e-01,  -2.82836914e-01],
                        [ -2.52532959e-01,  -2.52502441e-01],
                        [ -2.00439453e-01,  -2.00439453e-01],
                        [ -1.54357910e-01,  -1.54327393e-01],
                        [ -1.27716064e-01,  -1.27685547e-01],
                        [ -1.14624023e-01,  -1.14593506e-01],
                        [ -1.04125977e-01,  -1.04095459e-01],
                        [ -9.17663574e-02,  -9.17358398e-02],
                        [ -7.67211914e-02,  -7.66906738e-02],
                        [ -5.82580566e-02,  -5.81970215e-02],
                        [ -3.81469727e-02,  -3.80859375e-02],
                        [ -1.94396973e-02,  -1.93786621e-02],
                        [ -9.76562500e-04,  -9.15527344e-04],
                        [  2.01110840e-02,   2.01721191e-02],
                        [  4.06188965e-02,   4.06799316e-02],
                        [  5.12390137e-02,   5.13000488e-02],
                        [  4.62036133e-02,   4.62646484e-02],
                        [  3.08837891e-02,   3.09448242e-02],
                        [  1.81274414e-02,   1.81884766e-02],
                        [  1.63574219e-02,   1.64489746e-02],
                        [  2.37731934e-02,   2.38342285e-02],
                        [  3.44238281e-02,   3.45153809e-02],
                        [  4.73937988e-02,   4.74853516e-02],
                        [  6.69250488e-02,   6.70166016e-02],
                        [  9.45434570e-02,   9.46350098e-02],
                        [  1.24237061e-01,   1.24328613e-01],
                        [  1.44714355e-01,   1.44836426e-01],
                        [  1.43310547e-01,   1.43432617e-01],
                        [  1.09008789e-01,   1.09130859e-01],
                        [  3.80859375e-02,   3.82080078e-02],
                        [ -5.83496094e-02,  -5.82275391e-02],
                        [ -1.52160645e-01,  -1.52038574e-01],
                        [ -2.09716797e-01,  -2.09594727e-01],
                        [ -2.13684082e-01,  -2.13562012e-01],
                        [ -1.75750732e-01,  -1.75628662e-01],
                        [ -1.24694824e-01,  -1.24572754e-01],
                        [ -8.06274414e-02,  -8.05053711e-02],
                        [ -4.19006348e-02,  -4.17785645e-02],
                        [  4.82177734e-03,   4.94384766e-03],
                        [  6.16455078e-02,   6.17980957e-02],
                        [  1.10870361e-01,   1.10992432e-01],
                        [  1.33483887e-01,   1.33636475e-01],
                        [  1.28326416e-01,   1.28479004e-01],
                        [  1.09344482e-01,   1.09497070e-01],
                        [  9.30480957e-02,   9.32006836e-02],
                        [  8.80432129e-02,   8.81958008e-02],
                        [  9.19494629e-02,   9.21020508e-02],
                        [  9.68627930e-02,   9.70153809e-02],
                        [  9.68933105e-02,   9.70458984e-02],
                        [  9.21020508e-02,   9.22241211e-02],
                        [  8.55407715e-02,   8.56933594e-02],
                        [  7.76672363e-02,   7.78198242e-02],
                        [  6.69860840e-02,   6.71386719e-02],
                        [  5.39245605e-02,   5.40771484e-02],
                        [  4.13208008e-02,   4.14733887e-02],
                        [  3.27453613e-02,   3.28674316e-02],
                        [  2.96630859e-02,   2.98156738e-02],
                        [  3.14331055e-02,   3.15856934e-02],
                        [  3.73229980e-02,   3.74755859e-02],
                        [  4.53796387e-02,   4.55322266e-02],
                        [  5.13610840e-02,   5.15136719e-02],
                        [  5.32836914e-02,   5.34362793e-02],
                        [  5.34667969e-02,   5.36499023e-02],
                        [  5.37109375e-02,   5.38635254e-02],
                        [  5.15136719e-02,   5.16662598e-02],
                        [  4.22668457e-02,   4.24194336e-02],
                        [  2.24914551e-02,   2.26745605e-02],
                        [ -6.22558594e-03,  -6.07299805e-03],
                        [ -3.56750488e-02,  -3.55224609e-02],
                        [ -5.72204590e-02,  -5.70373535e-02],
                        [ -6.70166016e-02,  -6.68945312e-02],
                        [ -6.26831055e-02,  -6.25305176e-02],
                        [ -4.01000977e-02,  -3.99475098e-02],
                        [  2.19726562e-03,   2.34985352e-03],
                        [  5.56945801e-02,   5.58166504e-02],
                        [  1.00402832e-01,   1.00524902e-01],
                        [  1.16485596e-01,   1.16607666e-01],
                        [  1.00311279e-01,   1.00463867e-01],
                        [  6.89086914e-02,   6.90307617e-02],
                        [  4.47082520e-02,   4.48303223e-02],
                        [  3.44543457e-02,   3.46069336e-02],
                        [  2.81982422e-02,   2.83203125e-02],
                        [  1.77307129e-02,   1.78527832e-02],
                        [  6.56127930e-03,   6.68334961e-03],
                        [  2.44140625e-03,   2.56347656e-03],
                        [  6.50024414e-03,   6.62231445e-03],
                        [  1.13220215e-02,   1.14440918e-02],
                        [  9.09423828e-03,   9.18579102e-03],
                        [ -4.27246094e-04,  -3.35693359e-04],
                        [ -1.09863281e-02,  -1.08947754e-02],
                        [ -1.76086426e-02,  -1.75170898e-02],
                        [ -2.12402344e-02,  -2.11486816e-02],
                        [ -2.59399414e-02,  -2.58483887e-02],
                        [ -3.43017578e-02,  -3.42102051e-02],
                        [ -4.33959961e-02,  -4.33044434e-02],
                        [ -4.51660156e-02,  -4.50744629e-02],
                        [ -3.54309082e-02,  -3.53393555e-02],
                        [ -1.94396973e-02,  -1.93481445e-02],
                        [ -6.65283203e-03,  -6.59179688e-03],
                        [ -3.66210938e-03,  -3.57055664e-03],
                        [ -9.00268555e-03,  -8.94165039e-03],
                        [ -1.49536133e-02,  -1.48925781e-02],
                        [ -1.58386230e-02,  -1.57775879e-02],
                        [ -1.13220215e-02,  -1.12915039e-02],
                        [ -3.63159180e-03,  -3.57055664e-03],
                        [  5.95092773e-03,   6.01196289e-03],
                        [  1.78833008e-02,   1.79443359e-02],
                        [  3.05175781e-02,   3.05480957e-02],
                        [  3.84826660e-02,   3.85131836e-02],
                        [  3.82385254e-02,   3.82690430e-02],
                        [  2.99682617e-02,   2.99987793e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -1.58386230e-02,  -1.58081055e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -1.19232178e-01,  -1.19232178e-01],
                        [ -1.77368164e-01,  -1.77368164e-01],
                        [ -2.20977783e-01,  -2.20977783e-01],
                        [ -2.37060547e-01,  -2.37060547e-01],
                        [ -2.21923828e-01,  -2.21923828e-01],
                        [ -1.89666748e-01,  -1.89666748e-01],
                        [ -1.63208008e-01,  -1.63238525e-01],
                        [ -1.51214600e-01,  -1.51245117e-01],
                        [ -1.43432617e-01,  -1.43432617e-01],
                        [ -1.28784180e-01,  -1.28784180e-01],
                        [ -1.06567383e-01,  -1.06597900e-01],
                        [ -8.09020996e-02,  -8.09326172e-02],
                        [ -5.45043945e-02,  -5.45349121e-02],
                        [ -2.93273926e-02,  -2.93884277e-02],
                        [ -9.18579102e-03,  -9.21630859e-03],
                        [  2.25830078e-03,   2.22778320e-03],
                        [  5.49316406e-03,   5.46264648e-03],
                        [  4.51660156e-03,   4.48608398e-03],
                        [  2.53295898e-03,   2.47192383e-03],
                        [  7.32421875e-04,   6.71386719e-04],
                        [  1.28173828e-03,   1.22070312e-03],
                        [  8.20922852e-03,   8.14819336e-03],
                        [  2.23083496e-02,   2.22167969e-02],
                        [  3.81469727e-02,   3.80859375e-02],
                        [  5.03845215e-02,   5.02929688e-02],
                        [  5.85937500e-02,   5.85021973e-02],
                        [  6.62231445e-02,   6.61315918e-02],
                        [  7.80334473e-02,   7.79418945e-02],
                        [  9.69238281e-02,   9.68322754e-02],
                        [  1.19720459e-01,   1.19598389e-01],
                        [  1.35742188e-01,   1.35650635e-01],
                        [  1.30737305e-01,   1.30645752e-01],
                        [  9.26818848e-02,   9.25598145e-02],
                        [  1.81579590e-02,   1.80358887e-02],
                        [ -7.93457031e-02,  -7.94677734e-02],
                        [ -1.67846680e-01,  -1.67968750e-01],
                        [ -2.11486816e-01,  -2.11639404e-01],
                        [ -1.94519043e-01,  -1.94641113e-01],
                        [ -1.33331299e-01,  -1.33453369e-01],
                        [ -6.27441406e-02,  -6.28967285e-02],
                        [ -8.94165039e-03,  -9.06372070e-03],
                        [  2.37121582e-02,   2.35900879e-02],
                        [  4.44946289e-02,   4.43725586e-02],
                        [  6.13098145e-02,   6.11877441e-02],
                        [  7.27844238e-02,   7.26623535e-02],
                        [  7.52563477e-02,   7.51342773e-02],
                        [  7.29675293e-02,   7.28149414e-02],
                        [  7.44628906e-02,   7.43103027e-02],
                        [  8.12072754e-02,   8.10546875e-02],
                        [  8.77075195e-02,   8.75549316e-02],
                        [  9.10949707e-02,   9.09423828e-02],
                        [  9.34448242e-02,   9.32922363e-02],
                        [  9.59777832e-02,   9.58251953e-02],
                        [  9.64355469e-02,   9.62829590e-02],
                        [  9.21020508e-02,   9.19189453e-02],
                        [  8.07495117e-02,   8.05969238e-02],
                        [  6.22863770e-02,   6.21337891e-02],
                        [  4.31518555e-02,   4.29992676e-02],
                        [  3.28674316e-02,   3.26843262e-02],
                        [  3.23181152e-02,   3.21350098e-02],
                        [  3.47900391e-02,   3.46069336e-02],
                        [  3.66821289e-02,   3.65295410e-02],
                        [  3.84216309e-02,   3.82690430e-02],
                        [  3.98559570e-02,   3.96728516e-02],
                        [  4.07104492e-02,   4.05578613e-02],
                        [  4.22973633e-02,   4.21447754e-02],
                        [  4.51660156e-02,   4.49829102e-02],
                        [  4.58374023e-02,   4.56848145e-02],
                        [  4.05273438e-02,   4.03442383e-02],
                        [  3.00292969e-02,   2.98767090e-02],
                        [  1.55334473e-02,   1.53808594e-02],
                        [ -5.67626953e-03,  -5.85937500e-03],
                        [ -3.40576172e-02,  -3.42102051e-02],
                        [ -6.09436035e-02,  -6.10961914e-02],
                        [ -7.00683594e-02,  -7.02514648e-02],
                        [ -4.90722656e-02,  -4.92248535e-02],
                        [ -6.71386719e-04,  -8.23974609e-04],
                        [  5.86853027e-02,   5.85021973e-02],
                        [  1.08642578e-01,   1.08489990e-01],
                        [  1.33483887e-01,   1.33331299e-01],
                        [  1.28204346e-01,   1.28082275e-01],
                        [  1.00006104e-01,   9.98535156e-02],
                        [  6.41479492e-02,   6.39953613e-02],
                        [  3.55834961e-02,   3.54309082e-02],
                        [  2.00195312e-02,   1.98669434e-02],
                        [  1.29699707e-02,   1.28479004e-02],
                        [  8.48388672e-03,   8.36181641e-03],
                        [  7.01904297e-03,   6.86645508e-03],
                        [  1.17492676e-02,   1.16271973e-02],
                        [  1.92260742e-02,   1.90734863e-02],
                        [  2.07519531e-02,   2.06298828e-02],
                        [  1.26342773e-02,   1.25122070e-02],
                        [ -1.15966797e-03,  -1.28173828e-03],
                        [ -1.53198242e-02,  -1.54418945e-02],
                        [ -2.72216797e-02,  -2.73437500e-02],
                        [ -3.40576172e-02,  -3.41796875e-02],
                        [ -3.18603516e-02,  -3.19824219e-02],
                        [ -2.13623047e-02,  -2.14538574e-02],
                        [ -1.05285645e-02,  -1.06506348e-02],
                        [ -7.84301758e-03,  -7.93457031e-03],
                        [ -1.26342773e-02,  -1.27258301e-02],
                        [ -1.66320801e-02,  -1.67541504e-02],
                        [ -1.56250000e-02,  -1.57165527e-02],
                        [ -1.34582520e-02,  -1.35498047e-02],
                        [ -1.40380859e-02,  -1.41296387e-02],
                        [ -1.54113770e-02,  -1.54724121e-02],
                        [ -1.19628906e-02,  -1.20544434e-02],
                        [ -6.71386719e-04,  -7.32421875e-04],
                        [  1.44042969e-02,   1.43127441e-02],
                        [  2.45056152e-02,   2.44750977e-02],
                        [  2.46582031e-02,   2.45971680e-02],
                        [  1.83715820e-02,   1.83105469e-02],
                        [  1.23596191e-02,   1.23291016e-02],
                        [  6.37817383e-03,   6.31713867e-03],
                        [ -6.74438477e-03,  -6.77490234e-03],
                        [ -3.33557129e-02,  -3.33862305e-02],
                        [ -7.30895996e-02,  -7.31201172e-02],
                        [ -1.16851807e-01,  -1.16882324e-01],
                        [ -1.53442383e-01,  -1.53442383e-01],
                        [ -1.76940918e-01,  -1.76940918e-01],
                        [ -1.86187744e-01,  -1.86218262e-01],
                        [ -1.82983398e-01,  -1.82983398e-01],
                        [ -1.70989990e-01,  -1.71020508e-01],
                        [ -1.54632568e-01,  -1.54632568e-01],
                        [ -1.38031006e-01,  -1.38061523e-01],
                        [ -1.22772217e-01,  -1.22772217e-01],
                        [ -1.08154297e-01,  -1.08123779e-01],
                        [ -9.45434570e-02,  -9.45434570e-02],
                        [ -8.26416016e-02,  -8.26416016e-02],
                        [ -7.16247559e-02,  -7.15942383e-02],
                        [ -5.95397949e-02,  -5.95092773e-02],
                        [ -4.55932617e-02,  -4.55627441e-02],
                        [ -3.19824219e-02,  -3.19213867e-02],
                        [ -1.93176270e-02,  -1.92565918e-02],
                        [ -4.60815430e-03,  -4.57763672e-03],
                        [  1.12609863e-02,   1.12915039e-02],
                        [  2.23999023e-02,   2.24609375e-02],
                        [  2.62145996e-02,   2.62756348e-02],
                        [  2.56347656e-02,   2.56958008e-02],
                        [  2.50854492e-02,   2.51464844e-02],
                        [  2.88085938e-02,   2.88696289e-02],
                        [  3.92761230e-02,   3.93371582e-02],
                        [  5.38024902e-02,   5.38635254e-02],
                        [  6.69555664e-02,   6.70166016e-02],
                        [  7.79418945e-02,   7.80334473e-02],
                        [  9.17358398e-02,   9.18273926e-02],
                        [  1.10595703e-01,   1.10687256e-01],
                        [  1.27380371e-01,   1.27471924e-01],
                        [  1.29119873e-01,   1.29211426e-01],
                        [  1.04339600e-01,   1.04431152e-01],
                        [  4.76989746e-02,   4.77905273e-02],
                        [ -3.49426270e-02,  -3.48205566e-02],
                        [ -1.22406006e-01,  -1.22283936e-01],
                        [ -1.84234619e-01,  -1.84112549e-01],
                        [ -1.95861816e-01,  -1.95739746e-01],
                        [ -1.55426025e-01,  -1.55303955e-01],
                        [ -8.79821777e-02,  -8.78601074e-02],
                        [ -2.67639160e-02,  -2.66418457e-02],
                        [  1.17492676e-02,   1.18713379e-02],
                        [  3.44238281e-02,   3.45458984e-02],
                        [  5.44433594e-02,   5.45654297e-02],
                        [  7.10144043e-02,   7.11364746e-02],
                        [  7.29980469e-02,   7.31506348e-02],
                        [  5.92041016e-02,   5.93566895e-02],
                        [  4.26635742e-02,   4.28161621e-02],
                        [  3.68652344e-02,   3.70178223e-02],
                        [  4.53491211e-02,   4.55017090e-02],
                        [  6.25000000e-02,   6.26525879e-02],
                        [  7.87048340e-02,   7.88574219e-02],
                        [  8.67004395e-02,   8.68835449e-02],
                        [  8.58154297e-02,   8.59680176e-02],
                        [  7.93151855e-02,   7.94677734e-02],
                        [  6.96105957e-02,   6.97937012e-02],
                        [  5.88989258e-02,   5.90820312e-02],
                        [  5.00183105e-02,   5.02014160e-02],
                        [  4.29992676e-02,   4.31518555e-02],
                        [  3.46984863e-02,   3.48510742e-02],
                        [  2.47497559e-02,   2.49328613e-02],
                        [  1.79748535e-02,   1.81579590e-02],
                        [  1.90734863e-02,   1.92565918e-02],
                        [  2.71606445e-02,   2.73437500e-02],
                        [  3.79028320e-02,   3.80554199e-02],
                        [  4.74853516e-02,   4.76379395e-02],
                        [  5.22766113e-02,   5.24291992e-02],
                        [  4.83093262e-02,   4.84924316e-02],
                        [  3.37219238e-02,   3.38745117e-02],
                        [  1.13830566e-02,   1.15661621e-02],
                        [ -1.08337402e-02,  -1.06506348e-02],
                        [ -2.56347656e-02,  -2.54516602e-02],
                        [ -3.29284668e-02,  -3.27758789e-02],
                        [ -3.73229980e-02,  -3.71704102e-02],
                        [ -3.85131836e-02,  -3.83300781e-02],
                        [ -2.83203125e-02,  -2.81677246e-02],
                        [  1.40380859e-03,   1.55639648e-03],
                        [  4.79125977e-02,   4.80957031e-02],
                        [  9.35974121e-02,   9.37805176e-02],
                        [  1.17126465e-01,   1.17279053e-01],
                        [  1.10534668e-01,   1.10717773e-01],
                        [  8.56018066e-02,   8.57543945e-02],
                        [  6.25305176e-02,   6.26831055e-02],
                        [  5.00183105e-02,   5.01708984e-02],
                        [  4.08935547e-02,   4.10766602e-02],
                        [  2.98461914e-02,   2.99682617e-02],
                        [  2.12707520e-02,   2.14233398e-02],
                        [  1.91345215e-02,   1.92871094e-02],
                        [  2.10571289e-02,   2.11791992e-02],
                        [  2.14843750e-02,   2.16369629e-02],
                        [  1.68151855e-02,   1.69677734e-02],
                        [  6.59179688e-03,   6.74438477e-03],
                        [ -8.81958008e-03,  -8.66699219e-03],
                        [ -2.74353027e-02,  -2.72827148e-02],
                        [ -4.26940918e-02,  -4.25720215e-02],
                        [ -4.63867188e-02,  -4.62646484e-02],
                        [ -3.52172852e-02,  -3.51257324e-02],
                        [ -1.67846680e-02,  -1.66625977e-02],
                        [ -5.70678711e-03,  -5.58471680e-03],
                        [ -8.33129883e-03,  -8.20922852e-03],
                        [ -1.63574219e-02,  -1.62658691e-02],
                        [ -1.91040039e-02,  -1.89819336e-02],
                        [ -1.54724121e-02,  -1.53808594e-02],
                        [ -1.14746094e-02,  -1.13525391e-02],
                        [ -9.85717773e-03,  -9.76562500e-03],
                        [ -7.99560547e-03,  -7.90405273e-03],
                        [ -3.63159180e-03,  -3.54003906e-03],
                        [  1.77001953e-03,   1.86157227e-03],
                        [  6.65283203e-03,   6.74438477e-03],
                        [  1.26953125e-02,   1.27868652e-02],
                        [  2.18505859e-02,   2.19116211e-02],
                        [  3.16467285e-02,   3.17077637e-02],
                        [  3.50036621e-02,   3.50646973e-02],
                        [  2.36206055e-02,   2.37121582e-02],
                        [ -5.37109375e-03,  -5.34057617e-03],
                        [ -4.81872559e-02,  -4.81262207e-02],
                        [ -1.00494385e-01,  -1.00433350e-01],
                        [ -1.57043457e-01,  -1.56982422e-01],
                        [ -2.04132080e-01,  -2.04101562e-01],
                        [ -2.24639893e-01,  -2.24578857e-01],
                        [ -2.13897705e-01,  -2.13867188e-01],
                        [ -1.85333252e-01,  -1.85302734e-01],
                        [ -1.56585693e-01,  -1.56585693e-01],
                        [ -1.34857178e-01,  -1.34826660e-01],
                        [ -1.17401123e-01,  -1.17370605e-01],
                        [ -1.00952148e-01,  -1.00952148e-01],
                        [ -8.62426758e-02,  -8.62426758e-02],
                        [ -7.61718750e-02,  -7.61718750e-02],
                        [ -7.08923340e-02,  -7.08923340e-02],
                        [ -6.64978027e-02,  -6.65283203e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -4.34875488e-02,  -4.35180664e-02],
                        [ -2.70080566e-02,  -2.70385742e-02],
                        [ -1.36718750e-02,  -1.37023926e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  1.06811523e-03,   1.03759766e-03],
                        [  9.15527344e-03,   9.12475586e-03],
                        [  1.85546875e-02,   1.85241699e-02],
                        [  2.49023438e-02,   2.48413086e-02],
                        [  2.74963379e-02,   2.74353027e-02],
                        [  2.89306641e-02,   2.89001465e-02],
                        [  3.17993164e-02,   3.17382812e-02],
                        [  3.88183594e-02,   3.87573242e-02],
                        [  5.10253906e-02,   5.09643555e-02],
                        [  6.74438477e-02,   6.73522949e-02],
                        [  8.75854492e-02,   8.75244141e-02],
                        [  1.10931396e-01,   1.10839844e-01],
                        [  1.33209229e-01,   1.33117676e-01],
                        [  1.42944336e-01,   1.42852783e-01],
                        [  1.26190186e-01,   1.26098633e-01],
                        [  7.90100098e-02,   7.89184570e-02],
                        [  8.78906250e-03,   8.69750977e-03],
                        [ -7.11059570e-02,  -7.11975098e-02],
                        [ -1.38305664e-01,  -1.38427734e-01],
                        [ -1.64154053e-01,  -1.64276123e-01],
                        [ -1.33605957e-01,  -1.33697510e-01],
                        [ -6.32934570e-02,  -6.34155273e-02],
                        [  6.95800781e-03,   6.80541992e-03],
                        [  4.54711914e-02,   4.53796387e-02],
                        [  5.04455566e-02,   5.03234863e-02],
                        [  4.08630371e-02,   4.07104492e-02],
                        [  3.35998535e-02,   3.34777832e-02],
                        [  3.25622559e-02,   3.24401855e-02],
                        [  3.38134766e-02,   3.36914062e-02],
                        [  3.46374512e-02,   3.45153809e-02],
                        [  3.70178223e-02,   3.68957520e-02],
                        [  4.31518555e-02,   4.30297852e-02],
                        [  5.20629883e-02,   5.19104004e-02],
                        [  6.23168945e-02,   6.21643066e-02],
                        [  7.26928711e-02,   7.25402832e-02],
                        [  7.79724121e-02,   7.78198242e-02],
                        [  7.16247559e-02,   7.14416504e-02],
                        [  5.53283691e-02,   5.52062988e-02],
                        [  4.14733887e-02,   4.13208008e-02],
                        [  4.02832031e-02,   4.01306152e-02],
                        [  4.82788086e-02,   4.80957031e-02],
                        [  5.41992188e-02,   5.40466309e-02],
                        [  5.20019531e-02,   5.18493652e-02],
                        [  4.41284180e-02,   4.39453125e-02],
                        [  3.69567871e-02,   3.68041992e-02],
                        [  3.48815918e-02,   3.47290039e-02],
                        [  3.66210938e-02,   3.64685059e-02],
                        [  3.78112793e-02,   3.76586914e-02],
                        [  3.56445312e-02,   3.54614258e-02],
                        [  2.91137695e-02,   2.89611816e-02],
                        [  1.69677734e-02,   1.67846680e-02],
                        [ -4.88281250e-04,  -6.71386719e-04],
                        [ -1.90124512e-02,  -1.91650391e-02],
                        [ -3.43017578e-02,  -3.44543457e-02],
                        [ -4.45861816e-02,  -4.47692871e-02],
                        [ -4.75463867e-02,  -4.76989746e-02],
                        [ -4.04052734e-02,  -4.05578613e-02],
                        [ -2.20947266e-02,  -2.22778320e-02],
                        [  6.31713867e-03,   6.16455078e-03],
                        [  4.06799316e-02,   4.05273438e-02],
                        [  7.24792480e-02,   7.22961426e-02],
                        [  9.15527344e-02,   9.14001465e-02],
                        [  9.29870605e-02,   9.28344727e-02],
                        [  8.18176270e-02,   8.16650391e-02],
                        [  6.78710938e-02,   6.77185059e-02],
                        [  5.68542480e-02,   5.66711426e-02],
                        [  4.83398438e-02,   4.81872559e-02],
                        [  3.99169922e-02,   3.97644043e-02],
                        [  3.07617188e-02,   3.06091309e-02],
                        [  2.23999023e-02,   2.22167969e-02],
                        [  1.49536133e-02,   1.48010254e-02],
                        [  5.85937500e-03,   5.73730469e-03],
                        [ -4.97436523e-03,  -5.12695312e-03],
                        [ -1.42517090e-02,  -1.44042969e-02],
                        [ -2.07519531e-02,  -2.09045410e-02],
                        [ -2.62451172e-02,  -2.63977051e-02],
                        [ -2.99377441e-02,  -3.00598145e-02],
                        [ -2.69470215e-02,  -2.70690918e-02],
                        [ -1.55639648e-02,  -1.56860352e-02],
                        [ -2.68554688e-03,  -2.80761719e-03],
                        [  3.41796875e-03,   3.26538086e-03],
                        [  2.25830078e-03,   2.13623047e-03],
                        [ -1.86157227e-03,  -1.98364258e-03],
                        [ -5.49316406e-03,  -5.61523438e-03],
                        [ -6.31713867e-03,  -6.43920898e-03],
                        [ -4.11987305e-03,  -4.21142578e-03],
                        [ -3.96728516e-04,  -5.18798828e-04],
                        [  3.23486328e-03,   3.11279297e-03],
                        [  6.83593750e-03,   6.74438477e-03],
                        [  1.37023926e-02,   1.35803223e-02],
                        [  2.66723633e-02,   2.65502930e-02],
                        [  4.42810059e-02,   4.42199707e-02],
                        [  6.22863770e-02,   6.21948242e-02],
                        [  7.37609863e-02,   7.36694336e-02],
                        [  6.76269531e-02,   6.75354004e-02],
                        [  3.17382812e-02,   3.16772461e-02],
                        [ -3.69262695e-02,  -3.69873047e-02],
                        [ -1.24481201e-01,  -1.24572754e-01],
                        [ -2.06604004e-01,  -2.06665039e-01],
                        [ -2.60772705e-01,  -2.60833740e-01],
                        [ -2.72796631e-01,  -2.72857666e-01],
                        [ -2.43469238e-01,  -2.43530273e-01],
                        [ -1.91864014e-01,  -1.91925049e-01],
                        [ -1.44744873e-01,  -1.44805908e-01],
                        [ -1.18377686e-01,  -1.18438721e-01],
                        [ -1.10168457e-01,  -1.10198975e-01],
                        [ -1.07574463e-01,  -1.07574463e-01],
                        [ -1.02691650e-01,  -1.02722168e-01],
                        [ -9.51843262e-02,  -9.52148438e-02],
                        [ -8.52661133e-02,  -8.52661133e-02],
                        [ -7.12585449e-02,  -7.12890625e-02],
                        [ -5.43518066e-02,  -5.43823242e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  5.98144531e-03,   6.01196289e-03],
                        [  1.69677734e-02,   1.69982910e-02],
                        [  1.94702148e-02,   1.95007324e-02],
                        [  1.50756836e-02,   1.51062012e-02],
                        [  8.05664062e-03,   8.08715820e-03],
                        [  2.16674805e-03,   2.19726562e-03],
                        [ -5.18798828e-04,  -4.88281250e-04],
                        [  1.25122070e-03,   1.31225586e-03],
                        [  9.52148438e-03,   9.55200195e-03],
                        [  2.40783691e-02,   2.41394043e-02],
                        [  4.07409668e-02,   4.08020020e-02],
                        [  5.92956543e-02,   5.93566895e-02],
                        [  8.46862793e-02,   8.47473145e-02],
                        [  1.13922119e-01,   1.13983154e-01],
                        [  1.34216309e-01,   1.34277344e-01],
                        [  1.36962891e-01,   1.37054443e-01],
                        [  1.23565674e-01,   1.23626709e-01],
                        [  9.53369141e-02,   9.54284668e-02],
                        [  4.82177734e-02,   4.83093262e-02],
                        [ -1.58386230e-02,  -1.57470703e-02],
                        [ -7.86743164e-02,  -7.85522461e-02],
                        [ -1.13708496e-01,  -1.13616943e-01],
                        [ -1.03179932e-01,  -1.03088379e-01],
                        [ -5.34667969e-02,  -5.33752441e-02],
                        [  4.97436523e-03,   5.09643555e-03],
                        [  3.96118164e-02,   3.97033691e-02],
                        [  3.96118164e-02,   3.97338867e-02],
                        [  2.13623047e-02,   2.14843750e-02],
                        [  1.10473633e-02,   1.11694336e-02],
                        [  1.78527832e-02,   1.79748535e-02],
                        [  2.81066895e-02,   2.82592773e-02],
                        [  2.78930664e-02,   2.80456543e-02],
                        [  2.10571289e-02,   2.11791992e-02],
                        [  2.07214355e-02,   2.08435059e-02],
                        [  3.06396484e-02,   3.07922363e-02],
                        [  4.35180664e-02,   4.36401367e-02],
                        [  5.26428223e-02,   5.27954102e-02],
                        [  5.53283691e-02,   5.54809570e-02],
                        [  5.06896973e-02,   5.08422852e-02],
                        [  4.16870117e-02,   4.18090820e-02],
                        [  3.47290039e-02,   3.48815918e-02],
                        [  3.54003906e-02,   3.55529785e-02],
                        [  4.27551270e-02,   4.29077148e-02],
                        [  4.79736328e-02,   4.81262207e-02],
                        [  4.36096191e-02,   4.37622070e-02],
                        [  3.33557129e-02,   3.35083008e-02],
                        [  2.76184082e-02,   2.77709961e-02],
                        [  3.02429199e-02,   3.04260254e-02],
                        [  3.48510742e-02,   3.50036621e-02],
                        [  3.36914062e-02,   3.38439941e-02],
                        [  2.55432129e-02,   2.57263184e-02],
                        [  1.34277344e-02,   1.36108398e-02],
                        [ -7.32421875e-04,  -5.79833984e-04],
                        [ -1.61132812e-02,  -1.59606934e-02],
                        [ -3.07312012e-02,  -3.05480957e-02],
                        [ -4.22363281e-02,  -4.20837402e-02],
                        [ -4.97131348e-02,  -4.95605469e-02],
                        [ -5.21545410e-02,  -5.20019531e-02],
                        [ -4.53491211e-02,  -4.51660156e-02],
                        [ -2.19116211e-02,  -2.17590332e-02],
                        [  2.02636719e-02,   2.04162598e-02],
                        [  7.09533691e-02,   7.11059570e-02],
                        [  1.12274170e-01,   1.12426758e-01],
                        [  1.28814697e-01,   1.28997803e-01],
                        [  1.15722656e-01,   1.15875244e-01],
                        [  8.29772949e-02,   8.31604004e-02],
                        [  4.91943359e-02,   4.93774414e-02],
                        [  2.68859863e-02,   2.70385742e-02],
                        [  1.50146484e-02,   1.51977539e-02],
                        [  6.19506836e-03,   6.34765625e-03],
                        [ -8.23974609e-04,  -6.71386719e-04],
                        [ -2.44140625e-04,  -9.15527344e-05],
                        [  9.55200195e-03,   9.70458984e-03],
                        [  2.13012695e-02,   2.14538574e-02],
                        [  2.52075195e-02,   2.53906250e-02],
                        [  1.65405273e-02,   1.66931152e-02],
                        [ -1.09863281e-03,  -9.46044922e-04],
                        [ -1.87988281e-02,  -1.86767578e-02],
                        [ -2.85644531e-02,  -2.84118652e-02],
                        [ -2.79846191e-02,  -2.78320312e-02],
                        [ -2.12097168e-02,  -2.10571289e-02],
                        [ -1.38549805e-02,  -1.37329102e-02],
                        [ -6.89697266e-03,  -6.77490234e-03],
                        [  2.47192383e-03,   2.62451172e-03],
                        [  1.40686035e-02,   1.41906738e-02],
                        [  2.26135254e-02,   2.27355957e-02],
                        [  2.36511230e-02,   2.37731934e-02],
                        [  1.88598633e-02,   1.89819336e-02],
                        [  1.40380859e-02,   1.41601562e-02],
                        [  1.43127441e-02,   1.44348145e-02],
                        [  2.07519531e-02,   2.08740234e-02],
                        [  3.04260254e-02,   3.05175781e-02],
                        [  4.06494141e-02,   4.07714844e-02],
                        [  5.19714355e-02,   5.20629883e-02],
                        [  6.20422363e-02,   6.21643066e-02],
                        [  5.92956543e-02,   5.94177246e-02],
                        [  2.90527344e-02,   2.91442871e-02],
                        [ -3.22265625e-02,  -3.21350098e-02],
                        [ -1.11114502e-01,  -1.11022949e-01],
                        [ -1.84753418e-01,  -1.84692383e-01],
                        [ -2.33398438e-01,  -2.33306885e-01],
                        [ -2.47741699e-01,  -2.47680664e-01],
                        [ -2.30560303e-01,  -2.30499268e-01],
                        [ -1.94824219e-01,  -1.94732666e-01],
                        [ -1.56768799e-01,  -1.56707764e-01],
                        [ -1.27746582e-01,  -1.27685547e-01],
                        [ -1.10565186e-01,  -1.10504150e-01],
                        [ -1.00585938e-01,  -1.00555420e-01],
                        [ -9.27124023e-02,  -9.26513672e-02],
                        [ -8.58459473e-02,  -8.58154297e-02],
                        [ -7.98034668e-02,  -7.97729492e-02],
                        [ -7.24487305e-02,  -7.23876953e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -2.47192383e-02,  -2.46887207e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  3.06091309e-02,   3.06396484e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  1.38549805e-02,   1.38244629e-02],
                        [  5.27954102e-03,   5.24902344e-03],
                        [ -3.96728516e-04,  -4.27246094e-04],
                        [ -1.52587891e-04,  -1.83105469e-04],
                        [  8.27026367e-03,   8.23974609e-03],
                        [  2.31018066e-02,   2.30712891e-02],
                        [  4.15039062e-02,   4.14733887e-02],
                        [  6.24694824e-02,   6.24389648e-02],
                        [  8.33740234e-02,   8.33129883e-02],
                        [  9.94567871e-02,   9.93957520e-02],
                        [  1.10321045e-01,   1.10260010e-01],
                        [  1.19476318e-01,   1.19415283e-01],
                        [  1.23931885e-01,   1.23901367e-01],
                        [  1.13220215e-01,   1.13159180e-01],
                        [  7.98034668e-02,   7.97119141e-02],
                        [  2.60314941e-02,   2.59399414e-02],
                        [ -3.47595215e-02,  -3.48205566e-02],
                        [ -7.93762207e-02,  -7.94677734e-02],
                        [ -8.56933594e-02,  -8.57849121e-02],
                        [ -5.30395508e-02,  -5.31005859e-02],
                        [ -7.87353516e-03,  -7.96508789e-03],
                        [  1.97753906e-02,   1.96838379e-02],
                        [  2.35900879e-02,   2.34985352e-02],
                        [  2.02026367e-02,   2.01110840e-02],
                        [  2.46887207e-02,   2.45666504e-02],
                        [  3.32946777e-02,   3.32031250e-02],
                        [  3.44543457e-02,   3.43322754e-02],
                        [  2.70690918e-02,   2.69470215e-02],
                        [  1.89208984e-02,   1.87988281e-02],
                        [  1.49536133e-02,   1.48315430e-02],
                        [  1.52587891e-02,   1.51367188e-02],
                        [  1.97448730e-02,   1.96228027e-02],
                        [  2.89611816e-02,   2.88391113e-02],
                        [  4.15039062e-02,   4.13818359e-02],
                        [  5.47790527e-02,   5.46264648e-02],
                        [  6.47583008e-02,   6.46057129e-02],
                        [  6.51855469e-02,   6.50634766e-02],
                        [  5.35278320e-02,   5.33752441e-02],
                        [  3.44543457e-02,   3.43017578e-02],
                        [  1.58691406e-02,   1.57470703e-02],
                        [  6.10351562e-03,   5.92041016e-03],
                        [  9.67407227e-03,   9.52148438e-03],
                        [  2.19726562e-02,   2.18200684e-02],
                        [  3.23181152e-02,   3.21655273e-02],
                        [  3.33251953e-02,   3.31726074e-02],
                        [  2.57263184e-02,   2.55737305e-02],
                        [  1.49230957e-02,   1.47705078e-02],
                        [  5.21850586e-03,   5.06591797e-03],
                        [ -2.47192383e-03,  -2.62451172e-03],
                        [ -1.02233887e-02,  -1.03759766e-02],
                        [ -2.05078125e-02,  -2.06604004e-02],
                        [ -3.14331055e-02,  -3.15856934e-02],
                        [ -3.81469727e-02,  -3.82995605e-02],
                        [ -3.56140137e-02,  -3.57666016e-02],
                        [ -1.79443359e-02,  -1.80969238e-02],
                        [  1.74865723e-02,   1.73339844e-02],
                        [  6.28051758e-02,   6.26220703e-02],
                        [  1.00830078e-01,   1.00646973e-01],
                        [  1.16485596e-01,   1.16333008e-01],
                        [  1.07269287e-01,   1.07116699e-01],
                        [  8.23974609e-02,   8.22448730e-02],
                        [  5.48400879e-02,   5.46569824e-02],
                        [  3.35083008e-02,   3.33557129e-02],
                        [  2.06604004e-02,   2.05078125e-02],
                        [  1.44348145e-02,   1.42517090e-02],
                        [  1.33666992e-02,   1.32141113e-02],
                        [  1.75170898e-02,   1.73645020e-02],
                        [  2.51464844e-02,   2.49938965e-02],
                        [  2.92663574e-02,   2.91137695e-02],
                        [  2.15454102e-02,   2.13928223e-02],
                        [  2.53295898e-03,   2.38037109e-03],
                        [ -1.71203613e-02,  -1.72729492e-02],
                        [ -2.79235840e-02,  -2.80456543e-02],
                        [ -3.07006836e-02,  -3.08227539e-02],
                        [ -3.11279297e-02,  -3.12805176e-02],
                        [ -3.05480957e-02,  -3.06701660e-02],
                        [ -2.64587402e-02,  -2.65808105e-02],
                        [ -1.81884766e-02,  -1.83410645e-02],
                        [ -7.87353516e-03,  -8.02612305e-03],
                        [  3.08227539e-03,   2.92968750e-03],
                        [  1.44348145e-02,   1.43127441e-02],
                        [  2.37426758e-02,   2.35900879e-02],
                        [  2.73437500e-02,   2.72216797e-02],
                        [  2.61840820e-02,   2.60620117e-02],
                        [  2.46582031e-02,   2.45361328e-02],
                        [  2.50244141e-02,   2.49023438e-02],
                        [  2.61840820e-02,   2.60620117e-02],
                        [  2.87780762e-02,   2.86560059e-02],
                        [  3.56445312e-02,   3.55224609e-02],
                        [  4.25720215e-02,   4.24499512e-02],
                        [  3.67126465e-02,   3.66210938e-02],
                        [  9.61303711e-03,   9.49096680e-03],
                        [ -3.70483398e-02,  -3.71704102e-02],
                        [ -9.85107422e-02,  -9.86022949e-02],
                        [ -1.66839600e-01,  -1.66931152e-01],
                        [ -2.24639893e-01,  -2.24731445e-01],
                        [ -2.51037598e-01,  -2.51129150e-01],
                        [ -2.38739014e-01,  -2.38830566e-01],
                        [ -2.00958252e-01,  -2.01049805e-01],
                        [ -1.59545898e-01,  -1.59637451e-01],
                        [ -1.29974365e-01,  -1.30065918e-01],
                        [ -1.15692139e-01,  -1.15753174e-01],
                        [ -1.09985352e-01,  -1.10076904e-01],
                        [ -1.03302002e-01,  -1.03363037e-01],
                        [ -9.14001465e-02,  -9.14306641e-02],
                        [ -7.67517090e-02,  -7.68127441e-02],
                        [ -6.34765625e-02,  -6.35375977e-02],
                        [ -5.41687012e-02,  -5.41992188e-02],
                        [ -4.76989746e-02,  -4.77294922e-02],
                        [ -3.85437012e-02,  -3.86047363e-02],
                        [ -2.34069824e-02,  -2.34375000e-02],
                        [ -5.46264648e-03,  -5.49316406e-03],
                        [  1.04370117e-02,   1.04064941e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  1.93786621e-02,   1.93481445e-02],
                        [  9.67407227e-03,   9.64355469e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  4.08935547e-03,   4.11987305e-03],
                        [  2.22778320e-02,   2.23083496e-02],
                        [  4.13818359e-02,   4.14123535e-02],
                        [  5.75866699e-02,   5.76171875e-02],
                        [  7.36083984e-02,   7.36083984e-02],
                        [  9.32617188e-02,   9.32922363e-02],
                        [  1.15783691e-01,   1.15844727e-01],
                        [  1.35498047e-01,   1.35528564e-01],
                        [  1.44744873e-01,   1.44775391e-01],
                        [  1.36474609e-01,   1.36535645e-01],
                        [  1.05133057e-01,   1.05194092e-01],
                        [  5.15136719e-02,   5.15747070e-02],
                        [ -9.79614258e-03,  -9.73510742e-03],
                        [ -5.52368164e-02,  -5.51452637e-02],
                        [ -6.85729980e-02,  -6.85424805e-02],
                        [ -5.16662598e-02,  -5.16052246e-02],
                        [ -2.24609375e-02,  -2.23693848e-02],
                        [ -1.15966797e-03,  -1.06811523e-03],
                        [  5.76782227e-03,   5.82885742e-03],
                        [  6.25610352e-03,   6.37817383e-03],
                        [  9.06372070e-03,   9.15527344e-03],
                        [  1.21765137e-02,   1.22375488e-02],
                        [  7.44628906e-03,   7.53784180e-03],
                        [ -4.51660156e-03,  -4.39453125e-03],
                        [ -1.16577148e-02,  -1.15661621e-02],
                        [ -3.78417969e-03,  -3.69262695e-03],
                        [  1.84020996e-02,   1.84936523e-02],
                        [  4.53796387e-02,   4.54711914e-02],
                        [  6.51245117e-02,   6.52160645e-02],
                        [  7.07397461e-02,   7.08312988e-02],
                        [  6.55212402e-02,   6.56433105e-02],
                        [  5.81665039e-02,   5.82885742e-02],
                        [  5.20324707e-02,   5.21545410e-02],
                        [  4.42504883e-02,   4.44030762e-02],
                        [  3.37524414e-02,   3.39050293e-02],
                        [  2.32543945e-02,   2.33459473e-02],
                        [  1.36413574e-02,   1.37634277e-02],
                        [  3.14331055e-03,   3.26538086e-03],
                        [ -6.07299805e-03,  -5.95092773e-03],
                        [ -6.68334961e-03,  -6.56127930e-03],
                        [  2.83813477e-03,   2.96020508e-03],
                        [  1.39465332e-02,   1.40686035e-02],
                        [  1.73645020e-02,   1.75170898e-02],
                        [  1.08337402e-02,   1.09863281e-02],
                        [ -2.28881836e-03,  -2.16674805e-03],
                        [ -1.94396973e-02,  -1.92871094e-02],
                        [ -3.92761230e-02,  -3.91235352e-02],
                        [ -5.55419922e-02,  -5.54199219e-02],
                        [ -5.80444336e-02,  -5.78918457e-02],
                        [ -4.08630371e-02,  -4.07104492e-02],
                        [ -4.33349609e-03,  -4.18090820e-03],
                        [  4.54101562e-02,   4.55627441e-02],
                        [  9.39636230e-02,   9.41162109e-02],
                        [  1.20941162e-01,   1.21093750e-01],
                        [  1.13342285e-01,   1.13494873e-01],
                        [  7.99865723e-02,   8.01391602e-02],
                        [  4.60510254e-02,   4.61730957e-02],
                        [  2.96325684e-02,   2.97851562e-02],
                        [  2.94189453e-02,   2.95715332e-02],
                        [  3.39660645e-02,   3.41186523e-02],
                        [  3.45764160e-02,   3.47290039e-02],
                        [  2.83203125e-02,   2.84729004e-02],
                        [  1.80053711e-02,   1.81274414e-02],
                        [  1.10473633e-02,   1.11694336e-02],
                        [  1.01623535e-02,   1.03149414e-02],
                        [  7.20214844e-03,   7.35473633e-03],
                        [ -5.09643555e-03,  -4.94384766e-03],
                        [ -2.06604004e-02,  -2.05078125e-02],
                        [ -2.78015137e-02,  -2.76489258e-02],
                        [ -2.50854492e-02,  -2.49328613e-02],
                        [ -2.08129883e-02,  -2.06909180e-02],
                        [ -1.82495117e-02,  -1.80969238e-02],
                        [ -1.34582520e-02,  -1.33056641e-02],
                        [ -5.52368164e-03,  -5.37109375e-03],
                        [  3.11279297e-03,   3.23486328e-03],
                        [  1.16577148e-02,   1.18103027e-02],
                        [  1.96533203e-02,   1.97753906e-02],
                        [  2.45361328e-02,   2.46582031e-02],
                        [  2.52990723e-02,   2.54516602e-02],
                        [  2.79235840e-02,   2.80456543e-02],
                        [  4.15344238e-02,   4.16259766e-02],
                        [  6.55517578e-02,   6.56738281e-02],
                        [  8.62426758e-02,   8.63647461e-02],
                        [  8.95690918e-02,   8.96911621e-02],
                        [  7.25402832e-02,   7.26318359e-02],
                        [  3.87573242e-02,   3.88793945e-02],
                        [ -9.73510742e-03,  -9.64355469e-03],
                        [ -7.12585449e-02,  -7.11364746e-02],
                        [ -1.37969971e-01,  -1.37847900e-01],
                        [ -1.96685791e-01,  -1.96594238e-01],
                        [ -2.35137939e-01,  -2.35046387e-01],
                        [ -2.46612549e-01,  -2.46520996e-01],
                        [ -2.31597900e-01,  -2.31536865e-01],
                        [ -1.99127197e-01,  -1.99035645e-01],
                        [ -1.63299561e-01,  -1.63208008e-01],
                        [ -1.33850098e-01,  -1.33758545e-01],
                        [ -1.12396240e-01,  -1.12335205e-01],
                        [ -9.60388184e-02,  -9.59472656e-02],
                        [ -8.09631348e-02,  -8.08715820e-02],
                        [ -6.64672852e-02,  -6.63757324e-02],
                        [ -5.56030273e-02,  -5.55419922e-02],
                        [ -4.91943359e-02,  -4.91333008e-02],
                        [ -4.29077148e-02,  -4.28771973e-02],
                        [ -3.33251953e-02,  -3.32946777e-02],
                        [ -2.26745605e-02,  -2.26135254e-02],
                        [ -1.48925781e-02,  -1.48620605e-02],
                        [ -9.55200195e-03,  -9.52148438e-03],
                        [ -3.81469727e-03,  -3.78417969e-03],
                        [  2.10571289e-03,   2.16674805e-03],
                        [  7.01904297e-03,   7.04956055e-03],
                        [  1.21154785e-02,   1.21459961e-02],
                        [  1.71508789e-02,   1.71813965e-02],
                        [  1.75170898e-02,   1.75476074e-02],
                        [  1.09863281e-02,   1.10168457e-02],
                        [  2.59399414e-03,   2.62451172e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  2.49328613e-02,   2.49023438e-02],
                        [  4.06799316e-02,   4.06494141e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  9.34143066e-02,   9.33837891e-02],
                        [  1.36871338e-01,   1.36840820e-01],
                        [  1.83685303e-01,   1.83654785e-01],
                        [  2.19848633e-01,   2.19818115e-01],
                        [  2.30590820e-01,   2.30560303e-01],
                        [  2.02331543e-01,   2.02301025e-01],
                        [  1.29608154e-01,   1.29577637e-01],
                        [  2.79235840e-02,   2.78930664e-02],
                        [ -6.43920898e-02,  -6.44531250e-02],
                        [ -1.09436035e-01,  -1.09466553e-01],
                        [ -9.92736816e-02,  -9.93347168e-02],
                        [ -6.12182617e-02,  -6.12487793e-02],
                        [ -3.19213867e-02,  -3.19824219e-02],
                        [ -2.72216797e-02,  -2.72827148e-02],
                        [ -3.53698730e-02,  -3.54309082e-02],
                        [ -3.61938477e-02,  -3.62548828e-02],
                        [ -2.36206055e-02,  -2.36816406e-02],
                        [ -8.20922852e-03,  -8.27026367e-03],
                        [ -2.74658203e-04,  -3.35693359e-04],
                        [  2.01416016e-03,   1.92260742e-03],
                        [  6.13403320e-03,   6.04248047e-03],
                        [  1.43432617e-02,   1.42517090e-02],
                        [  2.39562988e-02,   2.38647461e-02],
                        [  3.46679688e-02,   3.45764160e-02],
                        [  4.74548340e-02,   4.73632812e-02],
                        [  5.87463379e-02,   5.86547852e-02],
                        [  6.34460449e-02,   6.33544922e-02],
                        [  6.02416992e-02,   6.01501465e-02],
                        [  5.04150391e-02,   5.03234863e-02],
                        [  3.72924805e-02,   3.71704102e-02],
                        [  2.56042480e-02,   2.55126953e-02],
                        [  1.79138184e-02,   1.77917480e-02],
                        [  1.22070312e-02,   1.20849609e-02],
                        [  6.28662109e-03,   6.19506836e-03],
                        [  1.98364258e-03,   1.86157227e-03],
                        [  8.54492188e-04,   7.32421875e-04],
                        [ -1.22070312e-03,  -1.31225586e-03],
                        [ -8.54492188e-03,  -8.63647461e-03],
                        [ -1.91650391e-02,  -1.92871094e-02],
                        [ -2.89306641e-02,  -2.90527344e-02],
                        [ -3.73840332e-02,  -3.75061035e-02],
                        [ -4.47692871e-02,  -4.48913574e-02],
                        [ -4.66003418e-02,  -4.67224121e-02],
                        [ -3.63769531e-02,  -3.64990234e-02],
                        [ -1.16271973e-02,  -1.17187500e-02],
                        [  2.55737305e-02,   2.54516602e-02],
                        [  6.86340332e-02,   6.85119629e-02],
                        [  1.04125977e-01,   1.04003906e-01],
                        [  1.16424561e-01,   1.16302490e-01],
                        [  1.02233887e-01,   1.02111816e-01],
                        [  7.75756836e-02,   7.74841309e-02],
                        [  6.20727539e-02,   6.19506836e-02],
                        [  5.84106445e-02,   5.82885742e-02],
                        [  5.46875000e-02,   5.45349121e-02],
                        [  4.22363281e-02,   4.21142578e-02],
                        [  2.55737305e-02,   2.54516602e-02],
                        [  1.42211914e-02,   1.40991211e-02],
                        [  9.39941406e-03,   9.30786133e-03],
                        [  4.30297852e-03,   4.18090820e-03],
                        [ -5.49316406e-03,  -5.61523438e-03],
                        [ -1.79748535e-02,  -1.80969238e-02],
                        [ -2.79541016e-02,  -2.80761719e-02],
                        [ -3.10974121e-02,  -3.11889648e-02],
                        [ -2.67944336e-02,  -2.69165039e-02],
                        [ -1.74865723e-02,  -1.75781250e-02],
                        [ -4.73022461e-03,  -4.85229492e-03],
                        [  1.05285645e-02,   1.04064941e-02],
                        [  2.35290527e-02,   2.34375000e-02],
                        [  2.75573730e-02,   2.74353027e-02],
                        [  2.33764648e-02,   2.32543945e-02],
                        [  2.01721191e-02,   2.00805664e-02],
                        [  2.43530273e-02,   2.42309570e-02],
                        [  3.46984863e-02,   3.46069336e-02],
                        [  4.81567383e-02,   4.80651855e-02],
                        [  6.35070801e-02,   6.34155273e-02],
                        [  7.92846680e-02,   7.91625977e-02],
                        [  9.16442871e-02,   9.15527344e-02],
                        [  9.51232910e-02,   9.50317383e-02],
                        [  8.25500488e-02,   8.24584961e-02],
                        [  4.58068848e-02,   4.57153320e-02],
                        [ -1.88293457e-02,  -1.89208984e-02],
                        [ -1.04858398e-01,  -1.04949951e-01],
                        [ -1.94763184e-01,  -1.94854736e-01],
                        [ -2.64587402e-01,  -2.64678955e-01],
                        [ -2.92022705e-01,  -2.92114258e-01],
                        [ -2.68890381e-01,  -2.68981934e-01],
                        [ -2.12951660e-01,  -2.13012695e-01],
                        [ -1.59820557e-01,  -1.59881592e-01],
                        [ -1.32598877e-01,  -1.32659912e-01],
                        [ -1.25610352e-01,  -1.25671387e-01],
                        [ -1.20941162e-01,  -1.21002197e-01],
                        [ -1.09802246e-01,  -1.09863281e-01],
                        [ -9.39941406e-02,  -9.40551758e-02],
                        [ -7.70874023e-02,  -7.71484375e-02],
                        [ -6.15234375e-02,  -6.15844727e-02],
                        [ -4.92248535e-02,  -4.92858887e-02],
                        [ -3.86962891e-02,  -3.87268066e-02],
                        [ -2.58483887e-02,  -2.59094238e-02],
                        [ -1.07421875e-02,  -1.08032227e-02],
                        [  1.15966797e-03,   1.12915039e-03],
                        [  5.06591797e-03,   5.00488281e-03],
                        [  1.86157227e-03,   1.83105469e-03],
                        [ -3.66210938e-03,  -3.69262695e-03],
                        [ -7.81250000e-03,  -7.87353516e-03],
                        [ -8.42285156e-03,  -8.45336914e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [  2.31933594e-03,   2.28881836e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -2.34985352e-03,  -2.38037109e-03],
                        [ -1.03149414e-02,  -1.03454590e-02],
                        [ -1.56555176e-02,  -1.56860352e-02],
                        [ -1.79138184e-02,  -1.79443359e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [  7.29370117e-03,   7.26318359e-03],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  1.08917236e-01,   1.08917236e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  2.12829590e-01,   2.12829590e-01],
                        [  2.66784668e-01,   2.66815186e-01],
                        [  2.91534424e-01,   2.91534424e-01],
                        [  2.65380859e-01,   2.65380859e-01],
                        [  1.81274414e-01,   1.81304932e-01],
                        [  5.82275391e-02,   5.82275391e-02],
                        [ -6.12182617e-02,  -6.11877441e-02],
                        [ -1.36199951e-01,  -1.36169434e-01],
                        [ -1.53076172e-01,  -1.53045654e-01],
                        [ -1.26617432e-01,  -1.26586914e-01],
                        [ -8.37097168e-02,  -8.36791992e-02],
                        [ -4.58984375e-02,  -4.58679199e-02],
                        [ -2.07824707e-02,  -2.07519531e-02],
                        [ -6.34765625e-03,  -6.28662109e-03],
                        [ -1.52587891e-03,  -1.46484375e-03],
                        [ -9.12475586e-03,  -9.06372070e-03],
                        [ -2.73437500e-02,  -2.73132324e-02],
                        [ -4.35791016e-02,  -4.35485840e-02],
                        [ -4.35791016e-02,  -4.35485840e-02],
                        [ -2.68249512e-02,  -2.67639160e-02],
                        [ -4.76074219e-03,  -4.69970703e-03],
                        [  1.54113770e-02,   1.54724121e-02],
                        [  3.53393555e-02,   3.54003906e-02],
                        [  5.49621582e-02,   5.50231934e-02],
                        [  6.78710938e-02,   6.79321289e-02],
                        [  6.98852539e-02,   6.99462891e-02],
                        [  6.38732910e-02,   6.39343262e-02],
                        [  5.45043945e-02,   5.45654297e-02],
                        [  4.38842773e-02,   4.39758301e-02],
                        [  3.22570801e-02,   3.23181152e-02],
                        [  1.72424316e-02,   1.73034668e-02],
                        [ -2.59399414e-03,  -2.53295898e-03],
                        [ -2.15454102e-02,  -2.14843750e-02],
                        [ -3.05480957e-02,  -3.04870605e-02],
                        [ -2.75878906e-02,  -2.75268555e-02],
                        [ -1.94396973e-02,  -1.93786621e-02],
                        [ -1.46179199e-02,  -1.45263672e-02],
                        [ -1.75781250e-02,  -1.75170898e-02],
                        [ -2.69165039e-02,  -2.68554688e-02],
                        [ -3.71093750e-02,  -3.70483398e-02],
                        [ -4.24194336e-02,  -4.23278809e-02],
                        [ -3.61938477e-02,  -3.61328125e-02],
                        [ -1.09863281e-02,  -1.09252930e-02],
                        [  3.30810547e-02,   3.31726074e-02],
                        [  8.12683105e-02,   8.13293457e-02],
                        [  1.12213135e-01,   1.12304688e-01],
                        [  1.14410400e-01,   1.14471436e-01],
                        [  9.42382812e-02,   9.43298340e-02],
                        [  6.90307617e-02,   6.91223145e-02],
                        [  5.22766113e-02,   5.23681641e-02],
                        [  4.40368652e-02,   4.41284180e-02],
                        [  3.55224609e-02,   3.56140137e-02],
                        [  2.31323242e-02,   2.32238770e-02],
                        [  1.27258301e-02,   1.28173828e-02],
                        [  1.06506348e-02,   1.07116699e-02],
                        [  1.58691406e-02,   1.59606934e-02],
                        [  1.98364258e-02,   1.99279785e-02],
                        [  1.21154785e-02,   1.22070312e-02],
                        [ -8.97216797e-03,  -8.88061523e-03],
                        [ -3.25622559e-02,  -3.24707031e-02],
                        [ -4.49829102e-02,  -4.48913574e-02],
                        [ -4.08935547e-02,  -4.08325195e-02],
                        [ -2.37121582e-02,  -2.36206055e-02],
                        [ -1.15966797e-03,  -1.06811523e-03],
                        [  1.72729492e-02,   1.73339844e-02],
                        [  2.55126953e-02,   2.55737305e-02],
                        [  2.59399414e-02,   2.60314941e-02],
                        [  2.58483887e-02,   2.59399414e-02],
                        [  3.09448242e-02,   3.10058594e-02],
                        [  4.33654785e-02,   4.34265137e-02],
                        [  6.20422363e-02,   6.21032715e-02],
                        [  8.38012695e-02,   8.38623047e-02],
                        [  1.05041504e-01,   1.05102539e-01],
                        [  1.20513916e-01,   1.20574951e-01],
                        [  1.21154785e-01,   1.21215820e-01],
                        [  9.81140137e-02,   9.81750488e-02],
                        [  5.10253906e-02,   5.11169434e-02],
                        [ -1.43432617e-02,  -1.42517090e-02],
                        [ -9.52148438e-02,  -9.51538086e-02],
                        [ -1.84692383e-01,  -1.84600830e-01],
                        [ -2.59521484e-01,  -2.59460449e-01],
                        [ -2.92083740e-01,  -2.92022705e-01],
                        [ -2.74505615e-01,  -2.74444580e-01],
                        [ -2.25158691e-01,  -2.25097656e-01],
                        [ -1.73461914e-01,  -1.73400879e-01],
                        [ -1.40258789e-01,  -1.40197754e-01],
                        [ -1.26983643e-01,  -1.26922607e-01],
                        [ -1.21582031e-01,  -1.21551514e-01],
                        [ -1.14044189e-01,  -1.14013672e-01],
                        [ -1.03363037e-01,  -1.03332520e-01],
                        [ -9.06677246e-02,  -9.06372070e-02],
                        [ -7.47680664e-02,  -7.47375488e-02],
                        [ -5.60913086e-02,  -5.60302734e-02],
                        [ -3.72924805e-02,  -3.72314453e-02],
                        [ -1.95617676e-02,  -1.95312500e-02],
                        [ -4.30297852e-03,  -4.27246094e-03],
                        [  4.82177734e-03,   4.85229492e-03],
                        [  7.23266602e-03,   7.26318359e-03],
                        [  7.35473633e-03,   7.38525391e-03],
                        [  7.17163086e-03,   7.23266602e-03],
                        [  5.21850586e-03,   5.24902344e-03],
                        [  2.53295898e-03,   2.56347656e-03],
                        [  1.83105469e-04,   2.13623047e-04],
                        [ -3.44848633e-03,  -3.41796875e-03],
                        [ -6.74438477e-03,  -6.71386719e-03],
                        [ -4.18090820e-03,  -4.15039062e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  1.22070312e-04,   1.52587891e-04],
                        [ -1.07727051e-02,  -1.07421875e-02],
                        [ -1.49230957e-02,  -1.48925781e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  7.07702637e-02,   7.08007812e-02],
                        [  1.37756348e-01,   1.37756348e-01],
                        [  2.11395264e-01,   2.11395264e-01],
                        [  2.73925781e-01,   2.73925781e-01],
                        [  3.09875488e-01,   3.09875488e-01],
                        [  3.08532715e-01,   3.08532715e-01],
                        [  2.62756348e-01,   2.62756348e-01],
                        [  1.72607422e-01,   1.72607422e-01],
                        [  5.19409180e-02,   5.19104004e-02],
                        [ -6.98242188e-02,  -6.98242188e-02],
                        [ -1.55181885e-01,  -1.55181885e-01],
                        [ -1.78344727e-01,  -1.78344727e-01],
                        [ -1.45751953e-01,  -1.45782471e-01],
                        [ -9.33227539e-02,  -9.33227539e-02],
                        [ -5.34973145e-02,  -5.35278320e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -1.45263672e-02,  -1.45568848e-02],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [  9.46044922e-04,   9.15527344e-04],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -2.60314941e-02,  -2.60620117e-02],
                        [ -3.34472656e-02,  -3.34777832e-02],
                        [ -2.06604004e-02,  -2.06909180e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  3.00598145e-02,   3.00292969e-02],
                        [  4.03137207e-02,   4.02832031e-02],
                        [  4.37927246e-02,   4.37622070e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  4.74548340e-02,   4.74243164e-02],
                        [  3.89404297e-02,   3.89099121e-02],
                        [  2.49633789e-02,   2.49328613e-02],
                        [  1.26953125e-02,   1.26647949e-02],
                        [  5.00488281e-03,   4.97436523e-03],
                        [ -1.83105469e-04,  -2.13623047e-04],
                        [ -4.85229492e-03,  -4.88281250e-03],
                        [ -8.60595703e-03,  -8.66699219e-03],
                        [ -1.19018555e-02,  -1.19323730e-02],
                        [ -1.71508789e-02,  -1.71813965e-02],
                        [ -2.38342285e-02,  -2.38647461e-02],
                        [ -2.76184082e-02,  -2.76794434e-02],
                        [ -2.79235840e-02,  -2.79541016e-02],
                        [ -2.99072266e-02,  -2.99682617e-02],
                        [ -3.52783203e-02,  -3.53088379e-02],
                        [ -3.55834961e-02,  -3.56140137e-02],
                        [ -1.97753906e-02,  -1.98364258e-02],
                        [  1.45874023e-02,   1.45263672e-02],
                        [  5.84106445e-02,   5.83801270e-02],
                        [  9.62829590e-02,   9.62219238e-02],
                        [  1.16027832e-01,   1.15966797e-01],
                        [  1.16210938e-01,   1.16149902e-01],
                        [  1.03393555e-01,   1.03363037e-01],
                        [  8.44116211e-02,   8.43505859e-02],
                        [  6.39038086e-02,   6.38732910e-02],
                        [  4.50439453e-02,   4.50134277e-02],
                        [  2.91748047e-02,   2.91442871e-02],
                        [  1.75476074e-02,   1.75170898e-02],
                        [  1.19934082e-02,   1.19628906e-02],
                        [  1.15051270e-02,   1.14746094e-02],
                        [  1.09863281e-02,   1.09252930e-02],
                        [  4.66918945e-03,   4.60815430e-03],
                        [ -9.85717773e-03,  -9.91821289e-03],
                        [ -2.81066895e-02,  -2.81372070e-02],
                        [ -3.86962891e-02,  -3.87268066e-02],
                        [ -3.37524414e-02,  -3.37829590e-02],
                        [ -1.78833008e-02,  -1.79138184e-02],
                        [ -1.22070312e-03,  -1.25122070e-03],
                        [  1.16882324e-02,   1.16271973e-02],
                        [  2.15454102e-02,   2.15148926e-02],
                        [  2.98461914e-02,   2.98156738e-02],
                        [  3.78112793e-02,   3.77807617e-02],
                        [  4.50439453e-02,   4.49829102e-02],
                        [  5.00793457e-02,   5.00488281e-02],
                        [  5.64575195e-02,   5.63964844e-02],
                        [  7.13500977e-02,   7.13195801e-02],
                        [  9.43298340e-02,   9.42993164e-02],
                        [  1.14196777e-01,   1.14166260e-01],
                        [  1.18499756e-01,   1.18469238e-01],
                        [  1.00128174e-01,   1.00067139e-01],
                        [  5.72204590e-02,   5.71899414e-02],
                        [ -6.04248047e-03,  -6.07299805e-03],
                        [ -8.19396973e-02,  -8.20007324e-02],
                        [ -1.63391113e-01,  -1.63421631e-01],
                        [ -2.38647461e-01,  -2.38677979e-01],
                        [ -2.84393311e-01,  -2.84423828e-01],
                        [ -2.79754639e-01,  -2.79785156e-01],
                        [ -2.31140137e-01,  -2.31170654e-01],
                        [ -1.71234131e-01,  -1.71264648e-01],
                        [ -1.30920410e-01,  -1.30950928e-01],
                        [ -1.18041992e-01,  -1.18072510e-01],
                        [ -1.21215820e-01,  -1.21246338e-01],
                        [ -1.24114990e-01,  -1.24145508e-01],
                        [ -1.15936279e-01,  -1.15966797e-01],
                        [ -9.69543457e-02,  -9.69848633e-02],
                        [ -7.70874023e-02,  -7.71179199e-02],
                        [ -6.32019043e-02,  -6.32324219e-02],
                        [ -4.96520996e-02,  -4.96826172e-02],
                        [ -2.85339355e-02,  -2.85644531e-02],
                        [ -3.81469727e-03,  -3.84521484e-03],
                        [  1.38244629e-02,   1.37939453e-02],
                        [  2.10876465e-02,   2.10571289e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [ -9.30786133e-03,  -9.33837891e-03],
                        [ -2.80761719e-02,  -2.81066895e-02],
                        [ -3.31115723e-02,  -3.31420898e-02],
                        [ -2.60620117e-02,  -2.60925293e-02],
                        [ -1.87988281e-02,  -1.88293457e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -9.82666016e-03,  -9.85717773e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  1.51977539e-01,   1.51947021e-01],
                        [  2.26104736e-01,   2.26104736e-01],
                        [  2.81555176e-01,   2.81524658e-01],
                        [  3.04107666e-01,   3.04107666e-01],
                        [  2.93090820e-01,   2.93090820e-01],
                        [  2.54791260e-01,   2.54760742e-01],
                        [  1.93450928e-01,   1.93450928e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  7.81250000e-03,   7.81250000e-03],
                        [ -8.99047852e-02,  -8.99047852e-02],
                        [ -1.50421143e-01,  -1.50421143e-01],
                        [ -1.52130127e-01,  -1.52130127e-01],
                        [ -1.07238770e-01,  -1.07238770e-01],
                        [ -5.50537109e-02,  -5.50537109e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -6.24694824e-02,  -6.24389648e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -1.16882324e-02,  -1.16577148e-02],
                        [  2.24304199e-02,   2.24609375e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  5.31311035e-02,   5.31616211e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -2.37731934e-02,  -2.37426758e-02],
                        [ -2.37426758e-02,  -2.37121582e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -7.84301758e-03,  -7.81250000e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -2.70385742e-02,  -2.70080566e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -6.13403320e-02,  -6.13098145e-02],
                        [ -4.49829102e-02,  -4.49523926e-02],
                        [ -9.49096680e-03,  -9.46044922e-03],
                        [  4.14428711e-02,   4.14733887e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.36932373e-01,   1.36932373e-01],
                        [  1.17095947e-01,   1.17095947e-01],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  3.08837891e-02,   3.09143066e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  1.46789551e-02,   1.47094727e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -4.91333008e-03,  -4.88281250e-03],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -2.20336914e-02,  -2.20031738e-02],
                        [ -1.98059082e-02,  -1.97753906e-02],
                        [ -1.37939453e-02,  -1.37634277e-02],
                        [ -4.88281250e-03,  -4.85229492e-03],
                        [  4.02832031e-03,   4.05883789e-03],
                        [  1.15661621e-02,   1.15966797e-02],
                        [  2.10876465e-02,   2.11181641e-02],
                        [  3.53698730e-02,   3.54003906e-02],
                        [  5.14831543e-02,   5.15136719e-02],
                        [  6.65893555e-02,   6.66198730e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  9.84802246e-02,   9.85107422e-02],
                        [  1.11450195e-01,   1.11480713e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -1.66290283e-01,  -1.66259766e-01],
                        [ -2.49755859e-01,  -2.49755859e-01],
                        [ -3.04962158e-01,  -3.04931641e-01],
                        [ -3.14422607e-01,  -3.14422607e-01],
                        [ -2.75115967e-01,  -2.75115967e-01],
                        [ -2.11181641e-01,  -2.11181641e-01],
                        [ -1.57012939e-01,  -1.57012939e-01],
                        [ -1.25122070e-01,  -1.25122070e-01],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -7.16247559e-02,  -7.16247559e-02],
                        [ -7.48291016e-02,  -7.47985840e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -1.45874023e-02,  -1.45568848e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.50036621e-02,  -3.49731445e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  7.76062012e-02,   7.76062012e-02],
                        [  1.35620117e-01,   1.35620117e-01],
                        [  1.91223145e-01,   1.91223145e-01],
                        [  2.34924316e-01,   2.34954834e-01],
                        [  2.61291504e-01,   2.61291504e-01],
                        [  2.68188477e-01,   2.68188477e-01],
                        [  2.57995605e-01,   2.57995605e-01],
                        [  2.37823486e-01,   2.37823486e-01],
                        [  2.11547852e-01,   2.11547852e-01],
                        [  1.71722412e-01,   1.71722412e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  2.05078125e-02,   2.05078125e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -1.36291504e-01,  -1.36291504e-01],
                        [ -1.58691406e-01,  -1.58691406e-01],
                        [ -1.44744873e-01,  -1.44744873e-01],
                        [ -1.20239258e-01,  -1.20239258e-01],
                        [ -1.03149414e-01,  -1.03149414e-01],
                        [ -9.23156738e-02,  -9.23156738e-02],
                        [ -8.04138184e-02,  -8.04138184e-02],
                        [ -6.57043457e-02,  -6.57043457e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -5.34057617e-03,  -5.37109375e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -3.89404297e-02,  -3.89709473e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  4.69665527e-02,   4.69665527e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [ -4.11987305e-03,  -4.15039062e-03],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [  8.54492188e-04,   8.23974609e-04],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  1.12152100e-01,   1.12152100e-01],
                        [  1.33666992e-01,   1.33666992e-01],
                        [  1.43951416e-01,   1.43951416e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [ -9.06982422e-02,  -9.06982422e-02],
                        [ -2.00286865e-01,  -2.00286865e-01],
                        [ -2.81280518e-01,  -2.81280518e-01],
                        [ -3.08898926e-01,  -3.08898926e-01],
                        [ -2.83935547e-01,  -2.83935547e-01],
                        [ -2.31170654e-01,  -2.31170654e-01],
                        [ -1.80755615e-01,  -1.80755615e-01],
                        [ -1.49139404e-01,  -1.49139404e-01],
                        [ -1.32324219e-01,  -1.32324219e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -9.16137695e-02,  -9.16137695e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.93359375e-01,   1.93359375e-01],
                        [  2.35015869e-01,   2.35015869e-01],
                        [  2.44476318e-01,   2.44476318e-01],
                        [  2.33123779e-01,   2.33123779e-01],
                        [  2.20794678e-01,   2.20794678e-01],
                        [  2.19116211e-01,   2.19116211e-01],
                        [  2.24395752e-01,   2.24395752e-01],
                        [  2.21984863e-01,   2.21984863e-01],
                        [  1.97418213e-01,   1.97418213e-01],
                        [  1.43707275e-01,   1.43707275e-01],
                        [  6.35681152e-02,   6.35681152e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -1.14715576e-01,  -1.14715576e-01],
                        [ -1.69464111e-01,  -1.69464111e-01],
                        [ -1.81365967e-01,  -1.81365967e-01],
                        [ -1.55181885e-01,  -1.55181885e-01],
                        [ -1.14776611e-01,  -1.14776611e-01],
                        [ -8.69140625e-02,  -8.69140625e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -6.91528320e-02,  -6.91528320e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -2.88696289e-02,  -2.89001465e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.75573730e-02,   2.75268555e-02],
                        [  3.08532715e-02,   3.08227539e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  4.11071777e-02,   4.10766602e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.17187500e-02,  -1.16882324e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [  4.63867188e-03,   4.66918945e-03],
                        [  2.16674805e-02,   2.16979980e-02],
                        [  4.75463867e-02,   4.75769043e-02],
                        [  7.80029297e-02,   7.80334473e-02],
                        [  1.02447510e-01,   1.02478027e-01],
                        [  1.08032227e-01,   1.08062744e-01],
                        [  9.14916992e-02,   9.15222168e-02],
                        [  6.49414062e-02,   6.49719238e-02],
                        [  4.42504883e-02,   4.42810059e-02],
                        [  3.31726074e-02,   3.32031250e-02],
                        [  2.41699219e-02,   2.42004395e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  7.96508789e-03,   7.93457031e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.23901367e-02,   1.23596191e-02],
                        [  3.81469727e-03,   3.78417969e-03],
                        [ -7.50732422e-03,  -7.53784180e-03],
                        [ -1.52282715e-02,  -1.52893066e-02],
                        [ -1.44958496e-02,  -1.45263672e-02],
                        [ -3.96728516e-03,  -3.99780273e-03],
                        [  1.05590820e-02,   1.04980469e-02],
                        [  1.91955566e-02,   1.91345215e-02],
                        [  1.90734863e-02,   1.90124512e-02],
                        [  1.85852051e-02,   1.85241699e-02],
                        [  2.63977051e-02,   2.63671875e-02],
                        [  4.25720215e-02,   4.25415039e-02],
                        [  6.52465820e-02,   6.52160645e-02],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.56738281e-01,   1.56738281e-01],
                        [  1.51092529e-01,   1.51092529e-01],
                        [  1.14807129e-01,   1.14837646e-01],
                        [  5.41381836e-02,   5.41992188e-02],
                        [ -2.73742676e-02,  -2.72827148e-02],
                        [ -1.22802734e-01,  -1.22711182e-01],
                        [ -2.13714600e-01,  -2.13623047e-01],
                        [ -2.76702881e-01,  -2.76611328e-01],
                        [ -2.95135498e-01,  -2.95043945e-01],
                        [ -2.67272949e-01,  -2.67181396e-01],
                        [ -2.11425781e-01,  -2.11364746e-01],
                        [ -1.59820557e-01,  -1.59759521e-01],
                        [ -1.34765625e-01,  -1.34674072e-01],
                        [ -1.31622314e-01,  -1.31561279e-01],
                        [ -1.30187988e-01,  -1.30157471e-01],
                        [ -1.17187500e-01,  -1.17156982e-01],
                        [ -9.37805176e-02,  -9.37805176e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -5.07507324e-02,  -5.07812500e-02],
                        [ -3.95202637e-02,  -3.95507812e-02],
                        [ -2.86560059e-02,  -2.87170410e-02],
                        [ -1.44958496e-02,  -1.45874023e-02],
                        [ -1.77001953e-03,  -1.86157227e-03],
                        [  4.08935547e-03,   3.99780273e-03],
                        [  4.54711914e-03,   4.42504883e-03],
                        [  2.62451172e-03,   2.50244141e-03],
                        [ -3.44848633e-03,  -3.57055664e-03],
                        [ -1.47705078e-02,  -1.48620605e-02],
                        [ -2.57873535e-02,  -2.59094238e-02],
                        [ -3.14941406e-02,  -3.15856934e-02],
                        [ -3.56750488e-02,  -3.57666016e-02],
                        [ -4.43115234e-02,  -4.44030762e-02],
                        [ -5.35583496e-02,  -5.36193848e-02],
                        [ -5.19104004e-02,  -5.19409180e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  2.63671875e-02,   2.63977051e-02],
                        [  5.99060059e-02,   5.99670410e-02],
                        [  9.86633301e-02,   9.87243652e-02],
                        [  1.43402100e-01,   1.43493652e-01],
                        [  1.88873291e-01,   1.88964844e-01],
                        [  2.23815918e-01,   2.23937988e-01],
                        [  2.37701416e-01,   2.37823486e-01],
                        [  2.31597900e-01,   2.31719971e-01],
                        [  2.19238281e-01,   2.19360352e-01],
                        [  2.12646484e-01,   2.12768555e-01],
                        [  2.10754395e-01,   2.10906982e-01],
                        [  2.03918457e-01,   2.04071045e-01],
                        [  1.83135986e-01,   1.83258057e-01],
                        [  1.42242432e-01,   1.42333984e-01],
                        [  7.65075684e-02,   7.65991211e-02],
                        [ -1.28479004e-02,  -1.27563477e-02],
                        [ -1.09619141e-01,  -1.09558105e-01],
                        [ -1.83929443e-01,  -1.83898926e-01],
                        [ -2.10968018e-01,  -2.10968018e-01],
                        [ -1.90948486e-01,  -1.90979004e-01],
                        [ -1.48681641e-01,  -1.48712158e-01],
                        [ -1.12121582e-01,  -1.12182617e-01],
                        [ -9.04846191e-02,  -9.06066895e-02],
                        [ -7.22351074e-02,  -7.23571777e-02],
                        [ -4.49218750e-02,  -4.50439453e-02],
                        [ -1.23901367e-02,  -1.25122070e-02],
                        [  1.22070312e-02,   1.20544434e-02],
                        [  2.35290527e-02,   2.33459473e-02],
                        [  2.68859863e-02,   2.67028809e-02],
                        [  2.74047852e-02,   2.72521973e-02],
                        [  2.48413086e-02,   2.46887207e-02],
                        [  1.81579590e-02,   1.80053711e-02],
                        [  8.85009766e-03,   8.66699219e-03],
                        [ -9.76562500e-04,  -1.09863281e-03],
                        [ -9.30786133e-03,  -9.39941406e-03],
                        [ -1.35803223e-02,  -1.36413574e-02],
                        [ -1.34887695e-02,  -1.35498047e-02],
                        [ -1.40075684e-02,  -1.40380859e-02],
                        [ -1.95007324e-02,  -1.94702148e-02],
                        [ -2.61230469e-02,  -2.60620117e-02],
                        [ -2.58483887e-02,  -2.57873535e-02],
                        [ -1.77307129e-02,  -1.76086426e-02],
                        [ -9.61303711e-03,  -9.46044922e-03],
                        [ -9.27734375e-03,  -9.09423828e-03],
                        [ -1.80053711e-02,  -1.78222656e-02],
                        [ -3.24707031e-02,  -3.22570801e-02],
                        [ -4.76379395e-02,  -4.73937988e-02],
                        [ -5.69458008e-02,  -5.67016602e-02],
                        [ -5.16052246e-02,  -5.13916016e-02],
                        [ -2.34375000e-02,  -2.31933594e-02],
                        [  2.73132324e-02,   2.75268555e-02],
                        [  8.57849121e-02,   8.59680176e-02],
                        [  1.28265381e-01,   1.28387451e-01],
                        [  1.38732910e-01,   1.38885498e-01],
                        [  1.20391846e-01,   1.20483398e-01],
                        [  9.06066895e-02,   9.06372070e-02],
                        [  6.59484863e-02,   6.59179688e-02],
                        [  5.06286621e-02,   5.05676270e-02],
                        [  3.75976562e-02,   3.75061035e-02],
                        [  1.97143555e-02,   1.95617676e-02],
                        [ -1.09863281e-03,  -1.31225586e-03],
                        [ -1.68151855e-02,  -1.70898438e-02],
                        [ -2.21252441e-02,  -2.24304199e-02],
                        [ -1.82800293e-02,  -1.85852051e-02],
                        [ -1.00097656e-02,  -1.03149414e-02],
                        [ -3.11279297e-03,  -3.44848633e-03],
                        [ -3.11279297e-03,  -3.47900391e-03],
                        [ -9.49096680e-03,  -9.79614258e-03],
                        [ -1.30004883e-02,  -1.32446289e-02],
                        [ -6.59179688e-03,  -6.80541992e-03],
                        [  3.96728516e-03,   3.75366211e-03],
                        [  1.11694336e-02,   1.09863281e-02],
                        [  2.01110840e-02,   2.00500488e-02],
                        [  3.92456055e-02,   3.92761230e-02],
                        [  6.44836426e-02,   6.45141602e-02],
                        [  8.55102539e-02,   8.56018066e-02],
                        [  1.00433350e-01,   1.00646973e-01],
                        [  1.13891602e-01,   1.14166260e-01],
                        [  1.26037598e-01,   1.26312256e-01],
                        [  1.29425049e-01,   1.29730225e-01],
                        [  1.14196777e-01,   1.14562988e-01],
                        [  7.54394531e-02,   7.58666992e-02],
                        [  1.63574219e-02,   1.67541504e-02],
                        [ -5.70373535e-02,  -5.66711426e-02],
                        [ -1.40625000e-01,  -1.40289307e-01],
                        [ -2.24609375e-01,  -2.24273682e-01],
                        [ -2.84759521e-01,  -2.84454346e-01],
                        [ -2.95837402e-01,  -2.95593262e-01],
                        [ -2.59063721e-01,  -2.58911133e-01],
                        [ -2.06176758e-01,  -2.06115723e-01],
                        [ -1.67816162e-01,  -1.67816162e-01],
                        [ -1.46575928e-01,  -1.46636963e-01],
                        [ -1.27777100e-01,  -1.27899170e-01],
                        [ -1.04705811e-01,  -1.04919434e-01],
                        [ -8.20312500e-02,  -8.23364258e-02],
                        [ -6.34460449e-02,  -6.37817383e-02],
                        [ -4.91943359e-02,  -4.95300293e-02],
                        [ -4.06188965e-02,  -4.09851074e-02],
                        [ -3.72924805e-02,  -3.77197266e-02],
                        [ -3.25622559e-02,  -3.29589844e-02],
                        [ -2.08129883e-02,  -2.11791992e-02],
                        [ -7.50732422e-03,  -7.87353516e-03],
                        [ -3.93676758e-03,  -4.27246094e-03],
                        [ -1.24511719e-02,  -1.26953125e-02],
                        [ -2.48107910e-02,  -2.49938965e-02],
                        [ -3.34472656e-02,  -3.36303711e-02],
                        [ -3.66821289e-02,  -3.67736816e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -2.81372070e-02,  -2.80456543e-02],
                        [ -2.66113281e-02,  -2.64892578e-02],
                        [ -3.62548828e-02,  -3.60412598e-02],
                        [ -4.93774414e-02,  -4.91027832e-02],
                        [ -4.88586426e-02,  -4.85534668e-02],
                        [ -2.62756348e-02,  -2.59399414e-02],
                        [  1.13830566e-02,   1.17492676e-02],
                        [  5.34057617e-02,   5.37719727e-02],
                        [  9.81140137e-02,   9.84802246e-02],
                        [  1.49322510e-01,   1.49658203e-01],
                        [  2.00103760e-01,   2.00408936e-01],
                        [  2.29217529e-01,   2.29492188e-01],
                        [  2.22991943e-01,   2.23236084e-01],
                        [  1.95373535e-01,   1.95556641e-01],
                        [  1.74743652e-01,   1.74865723e-01],
                        [  1.75170898e-01,   1.75201416e-01],
                        [  1.88690186e-01,   1.88690186e-01],
                        [  1.99798584e-01,   1.99768066e-01],
                        [  1.97753906e-01,   1.97631836e-01],
                        [  1.78100586e-01,   1.77917480e-01],
                        [  1.37908936e-01,   1.37725830e-01],
                        [  7.24487305e-02,   7.22656250e-02],
                        [ -1.76696777e-02,  -1.79138184e-02],
                        [ -1.14715576e-01,  -1.15020752e-01],
                        [ -1.87927246e-01,  -1.88232422e-01],
                        [ -2.14935303e-01,  -2.15179443e-01],
                        [ -1.96716309e-01,  -1.96929932e-01],
                        [ -1.52954102e-01,  -1.53198242e-01],
                        [ -1.06842041e-01,  -1.07086182e-01],
                        [ -7.24792480e-02,  -7.27233887e-02],
                        [ -5.08422852e-02,  -5.09948730e-02],
                        [ -3.50036621e-02,  -3.50952148e-02],
                        [ -2.02331543e-02,  -2.02941895e-02],
                        [ -8.45336914e-03,  -8.54492188e-03],
                        [ -4.02832031e-03,  -4.05883789e-03],
                        [ -7.04956055e-03,  -6.98852539e-03],
                        [ -1.18713379e-02,  -1.17797852e-02],
                        [ -1.05285645e-02,  -1.04675293e-02],
                        [  1.70898438e-03,   1.80053711e-03],
                        [  2.24304199e-02,   2.26440430e-02],
                        [  4.06188965e-02,   4.08325195e-02],
                        [  4.06799316e-02,   4.08325195e-02],
                        [  1.65405273e-02,   1.67236328e-02],
                        [ -1.63879395e-02,  -1.61437988e-02],
                        [ -3.38134766e-02,  -3.35693359e-02],
                        [ -3.00292969e-02,  -2.98461914e-02],
                        [ -2.03247070e-02,  -2.01416016e-02],
                        [ -1.58081055e-02,  -1.55944824e-02],
                        [ -1.24816895e-02,  -1.22680664e-02],
                        [ -7.32421875e-03,  -7.17163086e-03],
                        [ -6.77490234e-03,  -6.68334961e-03],
                        [ -1.53503418e-02,  -1.52587891e-02],
                        [ -2.95410156e-02,  -2.94494629e-02],
                        [ -4.54101562e-02,  -4.53796387e-02],
                        [ -5.92651367e-02,  -5.92956543e-02],
                        [ -6.05468750e-02,  -6.05773926e-02],
                        [ -3.65295410e-02,  -3.66210938e-02],
                        [  1.25732422e-02,   1.24511719e-02],
                        [  7.09533691e-02,   7.08007812e-02],
                        [  1.18713379e-01,   1.18530273e-01],
                        [  1.41204834e-01,   1.40960693e-01],
                        [  1.33300781e-01,   1.33056641e-01],
                        [  1.03942871e-01,   1.03668213e-01],
                        [  7.08312988e-02,   7.05261230e-02],
                        [  4.42199707e-02,   4.39147949e-02],
                        [  2.13623047e-02,   2.10876465e-02],
                        [ -1.83105469e-04,  -4.27246094e-04],
                        [ -1.38854980e-02,  -1.41601562e-02],
                        [ -1.34277344e-02,  -1.36718750e-02],
                        [ -1.34277344e-03,  -1.49536133e-03],
                        [  1.34582520e-02,   1.33666992e-02],
                        [  2.09960938e-02,   2.09045410e-02],
                        [  1.58386230e-02,   1.58081055e-02],
                        [  3.60107422e-03,   3.66210938e-03],
                        [ -3.96728516e-03,  -3.75366211e-03],
                        [ -3.69262695e-03,  -3.47900391e-03],
                        [ -2.01416016e-03,  -1.80053711e-03],
                        [  1.31225586e-03,   1.61743164e-03],
                        [  1.51367188e-02,   1.55944824e-02],
                        [  3.94897461e-02,   3.99169922e-02],
                        [  6.13708496e-02,   6.17370605e-02],
                        [  7.46154785e-02,   7.50122070e-02],
                        [  8.86230469e-02,   8.91418457e-02],
                        [  1.11419678e-01,   1.11877441e-01],
                        [  1.35650635e-01,   1.35955811e-01],
                        [  1.46728516e-01,   1.46972656e-01],
                        [  1.34399414e-01,   1.34674072e-01],
                        [  9.28955078e-02,   9.31396484e-02],
                        [  2.10876465e-02,   2.11486816e-02],
                        [ -7.34252930e-02,  -7.35168457e-02],
                        [ -1.75445557e-01,  -1.75598145e-01],
                        [ -2.63916016e-01,  -2.64099121e-01],
                        [ -3.10913086e-01,  -3.11218262e-01],
                        [ -2.96386719e-01,  -2.96813965e-01],
                        [ -2.36236572e-01,  -2.36785889e-01],
                        [ -1.77581787e-01,  -1.78131104e-01],
                        [ -1.50817871e-01,  -1.51397705e-01],
                        [ -1.41662598e-01,  -1.42242432e-01],
                        [ -1.22070312e-01,  -1.22680664e-01],
                        [ -9.09423828e-02,  -9.15527344e-02],
                        [ -6.78100586e-02,  -6.83593750e-02],
                        [ -6.07604980e-02,  -6.12182617e-02],
                        [ -5.86242676e-02,  -5.89599609e-02],
                        [ -4.91027832e-02,  -4.93469238e-02],
                        [ -3.08837891e-02,  -3.10668945e-02],
                        [ -1.11999512e-02,  -1.12304688e-02],
                        [ -6.10351562e-05,   9.15527344e-05],
                        [ -3.96728516e-03,  -3.66210938e-03],
                        [ -1.95617676e-02,  -1.91345215e-02],
                        [ -3.60717773e-02,  -3.56140137e-02],
                        [ -4.44946289e-02,  -4.39147949e-02],
                        [ -4.26025391e-02,  -4.18701172e-02],
                        [ -3.54614258e-02,  -3.46679688e-02],
                        [ -3.17077637e-02,  -3.09448242e-02],
                        [ -3.45764160e-02,  -3.38745117e-02],
                        [ -3.85742188e-02,  -3.78112793e-02],
                        [ -3.86352539e-02,  -3.79028320e-02],
                        [ -3.50952148e-02,  -3.44848633e-02],
                        [ -2.61230469e-02,  -2.56652832e-02],
                        [ -5.58471680e-03,  -5.21850586e-03],
                        [  2.88085938e-02,   2.90832520e-02],
                        [  7.41271973e-02,   7.42187500e-02],
                        [  1.26129150e-01,   1.26007080e-01],
                        [  1.75079346e-01,   1.74835205e-01],
                        [  2.04223633e-01,   2.03857422e-01],
                        [  2.03887939e-01,   2.03399658e-01],
                        [  1.83349609e-01,   1.82708740e-01],
                        [  1.60583496e-01,   1.59820557e-01],
                        [  1.45751953e-01,   1.44927979e-01],
                        [  1.39160156e-01,   1.38336182e-01],
                        [  1.38275146e-01,   1.37420654e-01],
                        [  1.40991211e-01,   1.40075684e-01],
                        [  1.45660400e-01,   1.44775391e-01],
                        [  1.50451660e-01,   1.49719238e-01],
                        [  1.49963379e-01,   1.49353027e-01],
                        [  1.32720947e-01,   1.32202148e-01],
                        [  8.72497559e-02,   8.68225098e-02],
                        [  1.27258301e-02,   1.25122070e-02],
                        [ -7.58972168e-02,  -7.59582520e-02],
                        [ -1.52404785e-01,  -1.52282715e-01],
                        [ -1.89880371e-01,  -1.89605713e-01],
                        [ -1.77093506e-01,  -1.76635742e-01],
                        [ -1.31378174e-01,  -1.30828857e-01],
                        [ -8.85925293e-02,  -8.79516602e-02],
                        [ -7.04345703e-02,  -6.96716309e-02],
                        [ -6.66503906e-02,  -6.57348633e-02],
                        [ -5.70373535e-02,  -5.61218262e-02],
                        [ -4.17480469e-02,  -4.08935547e-02],
                        [ -3.56750488e-02,  -3.48205566e-02],
                        [ -4.15039062e-02,  -4.05883789e-02],
                        [ -4.52575684e-02,  -4.44335938e-02],
                        [ -3.61328125e-02,  -3.54919434e-02],
                        [ -1.67236328e-02,  -1.62048340e-02],
                        [  4.82177734e-03,   5.27954102e-03],
                        [  2.20336914e-02,   2.23693848e-02],
                        [  2.95715332e-02,   2.96936035e-02],
                        [  2.38037109e-02,   2.37426758e-02],
                        [  7.65991211e-03,   7.47680664e-03],
                        [ -9.49096680e-03,  -9.76562500e-03],
                        [ -1.97753906e-02,  -2.01721191e-02],
                        [ -2.30407715e-02,  -2.36206055e-02],
                        [ -2.28271484e-02,  -2.35900879e-02],
                        [ -1.97448730e-02,  -2.05078125e-02],
                        [ -1.29394531e-02,  -1.36718750e-02],
                        [ -6.89697266e-03,  -7.78198242e-03],
                        [ -9.97924805e-03,  -1.09863281e-02],
                        [ -2.37121582e-02,  -2.46276855e-02],
                        [ -3.91540527e-02,  -3.98864746e-02],
                        [ -4.72412109e-02,  -4.80041504e-02],
                        [ -4.69360352e-02,  -4.77294922e-02],
                        [ -3.68652344e-02,  -3.75061035e-02],
                        [ -8.78906250e-03,  -9.18579102e-03],
                        [  3.95507812e-02,   3.92150879e-02],
                        [  8.97521973e-02,   8.94470215e-02],
                        [  1.15631104e-01,   1.15539551e-01],
                        [  1.09771729e-01,   1.09893799e-01],
                        [  8.66394043e-02,   8.68225098e-02],
                        [  6.12182617e-02,   6.14929199e-02],
                        [  3.78417969e-02,   3.83300781e-02],
                        [  2.01416016e-02,   2.08435059e-02],
                        [  1.63574219e-02,   1.70898438e-02],
                        [  2.68554688e-02,   2.75573730e-02],
                        [  3.86962891e-02,   3.95507812e-02],
                        [  4.05273438e-02,   4.15954590e-02],
                        [  3.41491699e-02,   3.51867676e-02],
                        [  2.46582031e-02,   2.55126953e-02],
                        [  1.16882324e-02,   1.25427246e-02],
                        [ -3.26538086e-03,  -2.31933594e-03],
                        [ -1.30004883e-02,  -1.21154785e-02],
                        [ -1.37329102e-02,  -1.30310059e-02],
                        [ -8.02612305e-03,  -7.44628906e-03],
                        [  4.51660156e-03,   5.00488281e-03],
                        [  2.77709961e-02,   2.80761719e-02],
                        [  5.88989258e-02,   5.89599609e-02],
                        [  8.78295898e-02,   8.77990723e-02],
                        [  1.09069824e-01,   1.08917236e-01],
                        [  1.23596191e-01,   1.23138428e-01],
                        [  1.31011963e-01,   1.30279541e-01],
                        [  1.29272461e-01,   1.28479004e-01],
                        [  1.19018555e-01,   1.18225098e-01],
                        [  9.77783203e-02,   9.67712402e-02],
                        [  5.47180176e-02,   5.34667969e-02],
                        [ -1.81579590e-02,  -1.94091797e-02],
                        [ -1.13159180e-01,  -1.14318848e-01],
                        [ -2.10357666e-01,  -2.11547852e-01],
                        [ -2.84545898e-01,  -2.85797119e-01],
                        [ -3.10363770e-01,  -3.11523438e-01],
                        [ -2.79022217e-01,  -2.80029297e-01],
                        [ -2.13958740e-01,  -2.14813232e-01],
                        [ -1.54327393e-01,  -1.55029297e-01],
                        [ -1.20025635e-01,  -1.20452881e-01],
                        [ -1.02996826e-01,  -1.03179932e-01],
                        [ -8.92944336e-02,  -8.93249512e-02],
                        [ -7.56835938e-02,  -7.55004883e-02],
                        [ -6.53991699e-02,  -6.48803711e-02],
                        [ -5.93872070e-02,  -5.85937500e-02],
                        [ -5.40771484e-02,  -5.31921387e-02],
                        [ -4.47082520e-02,  -4.36706543e-02],
                        [ -3.03649902e-02,  -2.90527344e-02],
                        [ -1.56250000e-02,  -1.40991211e-02],
                        [ -5.55419922e-03,  -4.05883789e-03],
                        [ -9.46044922e-04,   4.88281250e-04],
                        [ -6.10351562e-04,   9.46044922e-04],
                        [ -4.82177734e-03,  -3.23486328e-03],
                        [ -1.44348145e-02,  -1.30920410e-02],
                        [ -2.85949707e-02,  -2.75573730e-02],
                        [ -4.44946289e-02,  -4.34265137e-02],
                        [ -5.82580566e-02,  -5.73120117e-02],
                        [ -6.79931641e-02,  -6.74743652e-02],
                        [ -7.36999512e-02,  -7.36389160e-02],
                        [ -7.23266602e-02,  -7.23876953e-02],
                        [ -5.57861328e-02,  -5.59692383e-02],
                        [ -1.81274414e-02,  -1.87072754e-02],
                        [  3.75671387e-02,   3.65600586e-02],
                        [  1.02447510e-01,   1.01257324e-01],
                        [  1.66412354e-01,   1.65161133e-01],
                        [  2.16247559e-01,   2.14752197e-01],
                        [  2.36328125e-01,   2.34588623e-01],
                        [  2.21679688e-01,   2.19940186e-01],
                        [  1.86614990e-01,   1.84967041e-01],
                        [  1.52160645e-01,   1.50451660e-01],
                        [  1.27716064e-01,   1.26007080e-01],
                        [  1.11968994e-01,   1.10534668e-01],
                        [  1.04339600e-01,   1.03179932e-01],
                        [  1.05438232e-01,   1.04339600e-01],
                        [  1.12243652e-01,   1.11328125e-01],
                        [  1.21856689e-01,   1.21368408e-01],
                        [  1.35101318e-01,   1.35009766e-01],
                        [  1.50268555e-01,   1.50360107e-01],
                        [  1.55120850e-01,   1.55395508e-01],
                        [  1.30706787e-01,   1.31408691e-01],
                        [  6.52465820e-02,   6.63146973e-02],
                        [ -3.33862305e-02,  -3.21350098e-02],
                        [ -1.35070801e-01,  -1.33758545e-01],
                        [ -2.00531006e-01,  -1.98974609e-01],
                        [ -2.06848145e-01,  -2.05047607e-01],
                        [ -1.65740967e-01,  -1.63909912e-01],
                        [ -1.12854004e-01,  -1.11175537e-01],
                        [ -7.78808594e-02,  -7.62329102e-02],
                        [ -6.62841797e-02,  -6.46057129e-02],
                        [ -6.42089844e-02,  -6.26220703e-02],
                        [ -5.54199219e-02,  -5.41381836e-02],
                        [ -3.76586914e-02,  -3.67126465e-02],
                        [ -2.46887207e-02,  -2.39257812e-02],
                        [ -2.77099609e-02,  -2.70690918e-02],
                        [ -3.96728516e-02,  -3.93066406e-02],
                        [ -4.49218750e-02,  -4.50439453e-02],
                        [ -3.72009277e-02,  -3.76586914e-02],
                        [ -2.06604004e-02,  -2.12707520e-02],
                        [ -1.64794922e-03,  -2.47192383e-03],
                        [  1.27563477e-02,   1.15966797e-02],
                        [  1.65405273e-02,   1.51367188e-02],
                        [  1.07116699e-02,   9.21630859e-03],
                        [  1.92260742e-03,   3.05175781e-04],
                        [ -5.82885742e-03,  -7.59887695e-03],
                        [ -1.23291016e-02,  -1.40686035e-02],
                        [ -1.62048340e-02,  -1.78527832e-02],
                        [ -1.69982910e-02,  -1.86767578e-02],
                        [ -1.91955566e-02,  -2.08740234e-02],
                        [ -2.67333984e-02,  -2.81372070e-02],
                        [ -3.62243652e-02,  -3.72924805e-02],
                        [ -4.25109863e-02,  -4.34570312e-02],
                        [ -4.56848145e-02,  -4.64782715e-02],
                        [ -4.51660156e-02,  -4.56237793e-02],
                        [ -3.20739746e-02,  -3.21960449e-02],
                        [  1.77001953e-03,   1.89208984e-03],
                        [  4.98962402e-02,   5.03540039e-02],
                        [  9.38110352e-02,   9.46044922e-02],
                        [  1.16729736e-01,   1.17675781e-01],
                        [  1.11389160e-01,   1.12487793e-01],
                        [  8.39538574e-02,   8.53881836e-02],
                        [  5.31616211e-02,   5.48706055e-02],
                        [  3.56140137e-02,   3.73535156e-02],
                        [  3.03649902e-02,   3.20434570e-02],
                        [  2.61535645e-02,   2.79541016e-02],
                        [  1.83410645e-02,   2.02331543e-02],
                        [  1.00708008e-02,   1.17797852e-02],
                        [  4.73022461e-03,   6.28662109e-03],
                        [  5.58471680e-03,   7.08007812e-03],
                        [  1.31530762e-02,   1.43737793e-02],
                        [  1.95312500e-02,   2.03857422e-02],
                        [  1.48925781e-02,   1.55334473e-02],
                        [  2.22778320e-03,   2.71606445e-03],
                        [ -2.56347656e-03,  -2.44140625e-03],
                        [  1.12609863e-02,   1.08947754e-02],
                        [  3.73535156e-02,   3.66516113e-02],
                        [  6.28662109e-02,   6.20422363e-02],
                        [  8.41674805e-02,   8.30993652e-02],
                        [  1.03881836e-01,   1.02416992e-01],
                        [  1.20056152e-01,   1.18255615e-01],
                        [  1.29486084e-01,   1.27593994e-01],
                        [  1.35681152e-01,   1.33819580e-01],
                        [  1.39923096e-01,   1.38000488e-01],
                        [  1.29730225e-01,   1.27655029e-01],
                        [  8.79516602e-02,   8.58459473e-02],
                        [  1.08337402e-02,   9.03320312e-03],
                        [ -8.85009766e-02,  -8.99963379e-02],
                        [ -1.89514160e-01,  -1.90948486e-01],
                        [ -2.69073486e-01,  -2.70355225e-01],
                        [ -3.03527832e-01,  -3.04351807e-01],
                        [ -2.81707764e-01,  -2.82043457e-01],
                        [ -2.21160889e-01,  -2.21282959e-01],
                        [ -1.60705566e-01,  -1.60614014e-01],
                        [ -1.28540039e-01,  -1.27960205e-01],
                        [ -1.20788574e-01,  -1.19689941e-01],
                        [ -1.15081787e-01,  -1.13739014e-01],
                        [ -9.77172852e-02,  -9.62829590e-02],
                        [ -7.17468262e-02,  -7.00073242e-02],
                        [ -4.68139648e-02,  -4.47082520e-02],
                        [ -3.14941406e-02,  -2.93579102e-02],
                        [ -3.07922363e-02,  -2.87475586e-02],
                        [ -4.03747559e-02,  -3.82385254e-02],
                        [ -4.68750000e-02,  -4.47082520e-02],
                        [ -4.11376953e-02,  -3.92761230e-02],
                        [ -2.71606445e-02,  -2.55737305e-02],
                        [ -1.33666992e-02,  -1.18713379e-02],
                        [ -3.05175781e-03,  -1.73950195e-03],
                        [  1.73950195e-03,   2.47192383e-03],
                        [ -4.66918945e-03,  -4.45556641e-03],
                        [ -2.34680176e-02,  -2.33764648e-02],
                        [ -4.52575684e-02,  -4.53796387e-02],
                        [ -6.03942871e-02,  -6.10961914e-02],
                        [ -6.86340332e-02,  -6.98852539e-02],
                        [ -6.99157715e-02,  -7.12890625e-02],
                        [ -5.51757812e-02,  -5.66101074e-02],
                        [ -1.79748535e-02,  -1.97448730e-02],
                        [  3.39355469e-02,   3.17993164e-02],
                        [  8.97827148e-02,   8.76464844e-02],
                        [  1.46301270e-01,   1.44348145e-01],
                        [  1.96960449e-01,   1.94915771e-01],
                        [  2.24182129e-01,   2.22106934e-01],
                        [  2.17041016e-01,   2.15209961e-01],
                        [  1.87316895e-01,   1.85882568e-01],
                        [  1.57989502e-01,   1.56707764e-01],
                        [  1.40563965e-01,   1.39434814e-01],
                        [  1.31378174e-01,   1.30645752e-01],
                        [  1.23962402e-01,   1.23718262e-01],
                        [  1.17279053e-01,   1.17370605e-01],
                        [  1.15142822e-01,   1.15447998e-01],
                        [  1.21124268e-01,   1.21734619e-01],
                        [  1.32843018e-01,   1.33850098e-01],
                        [  1.41510010e-01,   1.42791748e-01],
                        [  1.39221191e-01,   1.40655518e-01],
                        [  1.23291016e-01,   1.24938965e-01],
                        [  9.12475586e-02,   9.30786133e-02],
                        [  3.69262695e-02,   3.86962891e-02],
                        [ -4.13818359e-02,  -3.96423340e-02],
                        [ -1.27410889e-01,  -1.25518799e-01],
                        [ -1.89605713e-01,  -1.87683105e-01],
                        [ -2.04345703e-01,  -2.02819824e-01],
                        [ -1.76147461e-01,  -1.74957275e-01],
                        [ -1.31408691e-01,  -1.30218506e-01],
                        [ -9.56420898e-02,  -9.45129395e-02],
                        [ -7.81250000e-02,  -7.74230957e-02],
                        [ -7.13195801e-02,  -7.10754395e-02],
                        [ -6.15844727e-02,  -6.14929199e-02],
                        [ -4.32739258e-02,  -4.33654785e-02],
                        [ -2.35900879e-02,  -2.40478516e-02],
                        [ -1.28173828e-02,  -1.36108398e-02],
                        [ -1.33361816e-02,  -1.42211914e-02],
                        [ -1.80358887e-02,  -1.91345215e-02],
                        [ -1.84020996e-02,  -1.98364258e-02],
                        [ -1.28173828e-02,  -1.43737793e-02],
                        [ -5.46264648e-03,  -6.86645508e-03],
                        [  9.15527344e-04,  -5.18798828e-04],
                        [  4.94384766e-03,   3.26538086e-03],
                        [  3.23486328e-03,   1.49536133e-03],
                        [ -4.30297852e-03,  -5.73730469e-03],
                        [ -1.05590820e-02,  -1.17187500e-02],
                        [ -1.08032227e-02,  -1.20239258e-02],
                        [ -1.15051270e-02,  -1.26953125e-02],
                        [ -2.08435059e-02,  -2.16979980e-02],
                        [ -3.57666016e-02,  -3.62548828e-02],
                        [ -4.61425781e-02,  -4.64782715e-02],
                        [ -4.97131348e-02,  -4.99267578e-02],
                        [ -5.40466309e-02,  -5.38940430e-02],
                        [ -6.12792969e-02,  -6.07910156e-02],
                        [ -6.02416992e-02,  -5.96313477e-02],
                        [ -3.72924805e-02,  -3.65295410e-02],
                        [  1.01928711e-02,   1.13525391e-02],
                        [  6.94885254e-02,   7.08923340e-02],
                        [  1.16241455e-01,   1.17584229e-01],
                        [  1.29302979e-01,   1.30615234e-01],
                        [  1.09558105e-01,   1.11175537e-01],
                        [  7.94982910e-02,   8.13293457e-02],
                        [  5.95092773e-02,   6.10961914e-02],
                        [  5.07507324e-02,   5.20935059e-02],
                        [  4.40063477e-02,   4.54101562e-02],
                        [  3.46069336e-02,   3.60412598e-02],
                        [  2.38647461e-02,   2.49938965e-02],
                        [  1.36718750e-02,   1.44042969e-02],
                        [  6.16455078e-03,   6.71386719e-03],
                        [  4.36401367e-03,   4.73022461e-03],
                        [  7.90405273e-03,   7.99560547e-03],
                        [  1.20544434e-02,   1.17797852e-02],
                        [  1.24511719e-02,   1.17797852e-02],
                        [  9.73510742e-03,   8.85009766e-03],
                        [  1.03454590e-02,   9.33837891e-03],
                        [  2.16674805e-02,   2.03857422e-02],
                        [  4.47387695e-02,   4.30908203e-02],
                        [  7.41577148e-02,   7.23571777e-02],
                        [  1.05163574e-01,   1.03485107e-01],
                        [  1.34246826e-01,   1.32568359e-01],
                        [  1.54815674e-01,   1.52954102e-01],
                        [  1.60888672e-01,   1.59057617e-01],
                        [  1.51824951e-01,   1.50238037e-01],
                        [  1.26861572e-01,   1.25579834e-01],
                        [  8.07495117e-02,   7.95898438e-02],
                        [  8.94165039e-03,   8.02612305e-03],
                        [ -8.59069824e-02,  -8.64562988e-02],
                        [ -1.91619873e-01,  -1.91864014e-01],
                        [ -2.83447266e-01,  -2.83355713e-01],
                        [ -3.27880859e-01,  -3.27423096e-01],
                        [ -3.05053711e-01,  -3.04168701e-01],
                        [ -2.31567383e-01,  -2.30468750e-01],
                        [ -1.52801514e-01,  -1.51519775e-01],
                        [ -1.05224609e-01,  -1.03637695e-01],
                        [ -9.04541016e-02,  -8.85925293e-02],
                        [ -8.81958008e-02,  -8.62426758e-02],
                        [ -8.48693848e-02,  -8.29772949e-02],
                        [ -8.18176270e-02,  -7.99865723e-02],
                        [ -8.27026367e-02,  -8.08715820e-02],
                        [ -8.33129883e-02,  -8.15734863e-02],
                        [ -7.59887695e-02,  -7.44934082e-02],
                        [ -5.93261719e-02,  -5.81665039e-02],
                        [ -3.87268066e-02,  -3.79028320e-02],
                        [ -1.95922852e-02,  -1.90124512e-02],
                        [ -4.45556641e-03,  -4.21142578e-03],
                        [  3.66210938e-03,   3.47900391e-03],
                        [  2.10571289e-03,   1.52587891e-03],
                        [ -6.77490234e-03,  -7.62939453e-03],
                        [ -1.80664062e-02,  -1.91650391e-02],
                        [ -3.22570801e-02,  -3.36914062e-02],
                        [ -5.31311035e-02,  -5.48706055e-02],
                        [ -7.57446289e-02,  -7.75146484e-02],
                        [ -8.49609375e-02,  -8.67004395e-02],
                        [ -7.07397461e-02,  -7.25708008e-02],
                        [ -3.73229980e-02,  -3.92761230e-02],
                        [  6.74438477e-03,   4.97436523e-03],
                        [  5.85327148e-02,   5.71594238e-02],
                        [  1.15631104e-01,   1.14471436e-01],
                        [  1.67663574e-01,   1.66625977e-01],
                        [  2.00103760e-01,   1.99279785e-01],
                        [  2.05261230e-01,   2.04895020e-01],
                        [  1.88171387e-01,   1.88262939e-01],
                        [  1.61621094e-01,   1.62048340e-01],
                        [  1.36260986e-01,   1.36901855e-01],
                        [  1.16302490e-01,   1.17126465e-01],
                        [  1.02416992e-01,   1.03546143e-01],
                        [  9.51538086e-02,   9.66186523e-02],
                        [  9.54895020e-02,   9.71679688e-02],
                        [  1.03851318e-01,   1.05468750e-01],
                        [  1.17553711e-01,   1.19110107e-01],
                        [  1.29119873e-01,   1.30676270e-01],
                        [  1.30645752e-01,   1.32202148e-01],
                        [  1.22100830e-01,   1.23535156e-01],
                        [  1.12060547e-01,   1.13281250e-01],
                        [  1.05377197e-01,   1.06262207e-01],
                        [  9.10949707e-02,   9.16137695e-02],
                        [  5.07812500e-02,   5.11779785e-02],
                        [ -1.94702148e-02,  -1.91650391e-02],
                        [ -1.01745605e-01,  -1.01867676e-01],
                        [ -1.69555664e-01,  -1.70227051e-01],
                        [ -2.01507568e-01,  -2.02362061e-01],
                        [ -1.89575195e-01,  -1.90307617e-01],
                        [ -1.47308350e-01,  -1.48223877e-01],
                        [ -1.04980469e-01,  -1.06353760e-01],
                        [ -8.33435059e-02,  -8.48388672e-02],
                        [ -7.65686035e-02,  -7.77893066e-02],
                        [ -6.81762695e-02,  -6.93054199e-02],
                        [ -5.42297363e-02,  -5.55725098e-02],
                        [ -4.16870117e-02,  -4.30297852e-02],
                        [ -3.38439941e-02,  -3.48205566e-02],
                        [ -2.78930664e-02,  -2.85644531e-02],
                        [ -2.22778320e-02,  -2.29187012e-02],
                        [ -1.80664062e-02,  -1.86767578e-02],
                        [ -1.35803223e-02,  -1.37939453e-02],
                        [ -4.36401367e-03,  -4.21142578e-03],
                        [  8.39233398e-03,   8.63647461e-03],
                        [  1.56555176e-02,   1.59301758e-02],
                        [  1.12304688e-02,   1.17187500e-02],
                        [ -1.52587891e-04,   6.40869141e-04],
                        [ -9.70458984e-03,  -8.81958008e-03],
                        [ -1.54724121e-02,  -1.46179199e-02],
                        [ -2.21862793e-02,  -2.12707520e-02],
                        [ -3.29589844e-02,  -3.19824219e-02],
                        [ -4.42810059e-02,  -4.32739258e-02],
                        [ -5.13305664e-02,  -5.03845215e-02],
                        [ -5.58776855e-02,  -5.49926758e-02],
                        [ -6.16455078e-02,  -6.08520508e-02],
                        [ -6.33850098e-02,  -6.27136230e-02],
                        [ -4.88891602e-02,  -4.83703613e-02],
                        [ -1.19323730e-02,  -1.15356445e-02],
                        [  4.11376953e-02,   4.14428711e-02],
                        [  9.35668945e-02,   9.37500000e-02],
                        [  1.25457764e-01,   1.25518799e-01],
                        [  1.26312256e-01,   1.26159668e-01],
                        [  1.03332520e-01,   1.02996826e-01],
                        [  7.45239258e-02,   7.41577148e-02],
                        [  5.34362793e-02,   5.30700684e-02],
                        [  4.16564941e-02,   4.11071777e-02],
                        [  3.37524414e-02,   3.29589844e-02],
                        [  2.69165039e-02,   2.61230469e-02],
                        [  2.42614746e-02,   2.35900879e-02],
                        [  2.75878906e-02,   2.68859863e-02],
                        [  3.14331055e-02,   3.04870605e-02],
                        [  2.78625488e-02,   2.69165039e-02],
                        [  1.66320801e-02,   1.59301758e-02],
                        [  6.28662109e-03,   5.64575195e-03],
                        [  4.63867188e-03,   3.81469727e-03],
                        [  1.08642578e-02,   1.01013184e-02],
                        [  1.98059082e-02,   1.93481445e-02],
                        [  3.05480957e-02,   3.02734375e-02],
                        [  4.64477539e-02,   4.60510254e-02],
                        [  6.93054199e-02,   6.89697266e-02],
                        [  9.86633301e-02,   9.87243652e-02],
                        [  1.32080078e-01,   1.32476807e-01],
                        [  1.60919189e-01,   1.61254883e-01],
                        [  1.70837402e-01,   1.71142578e-01],
                        [  1.52404785e-01,   1.53015137e-01],
                        [  1.06750488e-01,   1.07727051e-01],
                        [  3.83605957e-02,   3.94592285e-02],
                        [ -5.16357422e-02,  -5.05676270e-02],
                        [ -1.57440186e-01,  -1.56402588e-01],
                        [ -2.55706787e-01,  -2.54547119e-01],
                        [ -3.09631348e-01,  -3.08288574e-01],
                        [ -2.95379639e-01,  -2.93945312e-01],
                        [ -2.28240967e-01,  -2.27081299e-01],
                        [ -1.55914307e-01,  -1.55090332e-01],
                        [ -1.16394043e-01,  -1.15539551e-01],
                        [ -1.06689453e-01,  -1.05712891e-01],
                        [ -1.00830078e-01,  -1.00189209e-01],
                        [ -8.79211426e-02,  -8.78295898e-02],
                        [ -7.68737793e-02,  -7.69958496e-02],
                        [ -7.37609863e-02,  -7.39440918e-02],
                        [ -7.24182129e-02,  -7.29064941e-02],
                        [ -6.40563965e-02,  -6.50024414e-02],
                        [ -4.53796387e-02,  -4.65393066e-02],
                        [ -1.98974609e-02,  -2.12097168e-02],
                        [  2.16674805e-03,   6.10351562e-04],
                        [  1.04370117e-02,   8.66699219e-03],
                        [  3.57055664e-03,   1.77001953e-03],
                        [ -1.16577148e-02,  -1.34582520e-02],
                        [ -2.89916992e-02,  -3.08227539e-02],
                        [ -4.51965332e-02,  -4.69360352e-02],
                        [ -5.74645996e-02,  -5.90820312e-02],
                        [ -6.45141602e-02,  -6.59179688e-02],
                        [ -6.72607422e-02,  -6.82983398e-02],
                        [ -6.46972656e-02,  -6.53686523e-02],
                        [ -5.27343750e-02,  -5.31921387e-02],
                        [ -2.73132324e-02,  -2.74353027e-02],
                        [  1.55334473e-02,   1.59606934e-02],
                        [  7.63244629e-02,   7.72094727e-02],
                        [  1.43249512e-01,   1.44409180e-01],
                        [  1.94091797e-01,   1.95556641e-01],
                        [  2.12829590e-01,   2.14721680e-01],
                        [  2.00408936e-01,   2.02484131e-01],
                        [  1.70074463e-01,   1.72241211e-01],
                        [  1.39404297e-01,   1.41754150e-01],
                        [  1.21368408e-01,   1.23870850e-01],
                        [  1.16149902e-01,   1.18499756e-01],
                        [  1.13616943e-01,   1.15600586e-01],
                        [  1.05529785e-01,   1.07421875e-01],
                        [  9.32617188e-02,   9.50622559e-02],
                        [  8.28247070e-02,   8.42285156e-02],
                        [  7.65686035e-02,   7.73010254e-02],
                        [  7.14416504e-02,   7.16857910e-02],
                        [  6.54602051e-02,   6.54296875e-02],
                        [  6.24084473e-02,   6.20117188e-02],
                        [  6.86035156e-02,   6.75964355e-02],
                        [  8.56628418e-02,   8.41369629e-02],
                        [  1.06658936e-01,   1.04736328e-01],
                        [  1.16790771e-01,   1.14624023e-01],
                        [  1.00616455e-01,   9.82971191e-02],
                        [  5.11779785e-02,   4.86755371e-02],
                        [ -2.57568359e-02,  -2.85034180e-02],
                        [ -1.11999512e-01,  -1.14837646e-01],
                        [ -1.79412842e-01,  -1.81976318e-01],
                        [ -2.01843262e-01,  -2.03979492e-01],
                        [ -1.77032471e-01,  -1.79046631e-01],
                        [ -1.33666992e-01,  -1.35681152e-01],
                        [ -1.04644775e-01,  -1.06109619e-01],
                        [ -9.43603516e-02,  -9.49401855e-02],
                        [ -8.38012695e-02,  -8.39843750e-02],
                        [ -6.38732910e-02,  -6.40563965e-02],
                        [ -4.53186035e-02,  -4.50134277e-02],
                        [ -3.72314453e-02,  -3.59497070e-02],
                        [ -3.45764160e-02,  -3.27453613e-02],
                        [ -3.09448242e-02,  -2.91748047e-02],
                        [ -2.74963379e-02,  -2.56652832e-02],
                        [ -2.50244141e-02,  -2.25830078e-02],
                        [ -2.00805664e-02,  -1.72119141e-02],
                        [ -1.28479004e-02,  -1.01318359e-02],
                        [ -7.87353516e-03,  -5.40161133e-03],
                        [ -5.58471680e-03,  -3.17382812e-03],
                        [ -3.60107422e-03,  -1.22070312e-03],
                        [ -5.18798828e-03,  -2.99072266e-03],
                        [ -1.49230957e-02,  -1.30310059e-02],
                        [ -2.83508301e-02,  -2.70080566e-02],
                        [ -3.73840332e-02,  -3.66210938e-02],
                        [ -4.15039062e-02,  -4.10156250e-02],
                        [ -4.56237793e-02,  -4.53186035e-02],
                        [ -5.30395508e-02,  -5.32836914e-02],
                        [ -6.37207031e-02,  -6.47277832e-02],
                        [ -7.06481934e-02,  -7.19909668e-02],
                        [ -5.90820312e-02,  -6.04858398e-02],
                        [ -2.12402344e-02,  -2.29187012e-02],
                        [  3.07617188e-02,   2.86254883e-02],
                        [  7.57446289e-02,   7.33947754e-02],
                        [  1.02691650e-01,   1.00402832e-01],
                        [  1.12609863e-01,   1.10290527e-01],
                        [  1.08612061e-01,   1.06231689e-01],
                        [  9.35363770e-02,   9.13391113e-02],
                        [  7.30285645e-02,   7.10754395e-02],
                        [  5.21850586e-02,   5.03540039e-02],
                        [  3.23486328e-02,   3.06701660e-02],
                        [  1.67846680e-02,   1.55944824e-02],
                        [  1.41906738e-02,   1.34887695e-02],
                        [  2.78015137e-02,   2.72521973e-02],
                        [  4.61730957e-02,   4.58374023e-02],
                        [  5.36499023e-02,   5.38330078e-02],
                        [  4.74243164e-02,   4.81567383e-02],
                        [  3.70483398e-02,   3.79028320e-02],
                        [  3.05480957e-02,   3.15246582e-02],
                        [  3.04565430e-02,   3.18603516e-02],
                        [  3.87573242e-02,   4.06188965e-02],
                        [  5.52978516e-02,   5.71289062e-02],
                        [  7.42492676e-02,   7.59887695e-02],
                        [  9.25598145e-02,   9.45129395e-02],
                        [  1.15417480e-01,   1.17645264e-01],
                        [  1.42913818e-01,   1.45050049e-01],
                        [  1.59637451e-01,   1.61499023e-01],
                        [  1.46728516e-01,   1.48437500e-01],
                        [  9.67407227e-02,   9.84191895e-02],
                        [  1.46179199e-02,   1.62048340e-02],
                        [ -8.51135254e-02,  -8.37402344e-02],
                        [ -1.81182861e-01,  -1.80297852e-01],
                        [ -2.52197266e-01,  -2.51800537e-01],
                        [ -2.81890869e-01,  -2.81585693e-01],
                        [ -2.63458252e-01,  -2.63153076e-01],
                        [ -2.08923340e-01,  -2.09075928e-01],
                        [ -1.49749756e-01,  -1.50634766e-01],
                        [ -1.14410400e-01,  -1.15600586e-01],
                        [ -1.04522705e-01,  -1.05621338e-01],
                        [ -1.01165771e-01,  -1.02416992e-01],
                        [ -9.22851562e-02,  -9.40856934e-02],
                        [ -8.41369629e-02,  -8.63342285e-02],
                        [ -8.43505859e-02,  -8.65173340e-02],
                        [ -8.60595703e-02,  -8.80737305e-02],
                        [ -7.60803223e-02,  -7.81555176e-02],
                        [ -5.08728027e-02,  -5.31921387e-02],
                        [ -1.87072754e-02,  -2.09960938e-02],
                        [  9.30786133e-03,   7.32421875e-03],
                        [  2.48107910e-02,   2.31628418e-02],
                        [  2.31628418e-02,   2.16674805e-02],
                        [  4.15039062e-03,   2.83813477e-03],
                        [ -2.46887207e-02,  -2.56347656e-02],
                        [ -4.95300293e-02,  -4.99267578e-02],
                        [ -6.08825684e-02,  -6.09130859e-02],
                        [ -6.18591309e-02,  -6.15844727e-02],
                        [ -5.98449707e-02,  -5.91125488e-02],
                        [ -5.40161133e-02,  -5.27954102e-02],
                        [ -3.64074707e-02,  -3.48510742e-02],
                        [ -8.54492188e-04,   1.00708008e-03],
                        [  5.25512695e-02,   5.47790527e-02],
                        [  1.15844727e-01,   1.18255615e-01],
                        [  1.72271729e-01,   1.74774170e-01],
                        [  2.04437256e-01,   2.07122803e-01],
                        [  2.07519531e-01,   2.10327148e-01],
                        [  1.91192627e-01,   1.93817139e-01],
                        [  1.66870117e-01,   1.69189453e-01],
                        [  1.39160156e-01,   1.41326904e-01],
                        [  1.11328125e-01,   1.13403320e-01],
                        [  8.90808105e-02,   9.07287598e-02],
                        [  7.51037598e-02,   7.60803223e-02],
                        [  6.75048828e-02,   6.80236816e-02],
                        [  6.47277832e-02,   6.49719238e-02],
                        [  6.52160645e-02,   6.50024414e-02],
                        [  6.49719238e-02,   6.40869141e-02],
                        [  6.18591309e-02,   6.04553223e-02],
                        [  5.88073730e-02,   5.70373535e-02],
                        [  5.85327148e-02,   5.63659668e-02],
                        [  6.02111816e-02,   5.76782227e-02],
                        [  6.47277832e-02,   6.20117188e-02],
                        [  7.60803223e-02,   7.32421875e-02],
                        [  9.29260254e-02,   8.98742676e-02],
                        [  1.03149414e-01,   1.00097656e-01],
                        [  9.21936035e-02,   8.93859863e-02],
                        [  5.39550781e-02,   5.14526367e-02],
                        [ -6.56127930e-03,  -8.88061523e-03],
                        [ -7.51953125e-02,  -7.72399902e-02],
                        [ -1.31561279e-01,  -1.33087158e-01],
                        [ -1.58569336e-01,  -1.59545898e-01],
                        [ -1.53503418e-01,  -1.54022217e-01],
                        [ -1.27746582e-01,  -1.27746582e-01],
                        [ -9.72595215e-02,  -9.67102051e-02],
                        [ -7.40051270e-02,  -7.29675293e-02],
                        [ -6.11572266e-02,  -5.96923828e-02],
                        [ -5.42297363e-02,  -5.23071289e-02],
                        [ -4.85839844e-02,  -4.62341309e-02],
                        [ -4.39453125e-02,  -4.13208008e-02],
                        [ -4.05578613e-02,  -3.77502441e-02],
                        [ -3.51867676e-02,  -3.23486328e-02],
                        [ -2.46276855e-02,  -2.17895508e-02],
                        [ -1.03454590e-02,  -7.44628906e-03],
                        [  2.04467773e-03,   4.79125977e-03],
                        [  7.47680664e-03,   9.85717773e-03],
                        [  5.52368164e-03,   7.47680664e-03],
                        [  0.00000000e+00,   1.64794922e-03],
                        [ -5.40161133e-03,  -4.05883789e-03],
                        [ -1.06201172e-02,  -9.76562500e-03],
                        [ -1.81579590e-02,  -1.78527832e-02],
                        [ -2.95104980e-02,  -2.96936035e-02],
                        [ -4.41894531e-02,  -4.48608398e-02],
                        [ -6.04858398e-02,  -6.15844727e-02],
                        [ -7.49816895e-02,  -7.63549805e-02],
                        [ -8.29772949e-02,  -8.46862793e-02],
                        [ -8.14514160e-02,  -8.36181641e-02],
                        [ -6.86035156e-02,  -7.11059570e-02],
                        [ -4.05883789e-02,  -4.30297852e-02],
                        [  4.91333008e-03,   2.62451172e-03],
                        [  5.85021973e-02,   5.60607910e-02],
                        [  9.94873047e-02,   9.68627930e-02],
                        [  1.12518311e-01,   1.10168457e-01],
                        [  1.01379395e-01,   9.94873047e-02],
                        [  8.09020996e-02,   7.92846680e-02],
                        [  6.05163574e-02,   5.90209961e-02],
                        [  4.18701172e-02,   4.06799316e-02],
                        [  2.70690918e-02,   2.63977051e-02],
                        [  1.97448730e-02,   1.95312500e-02],
                        [  2.04467773e-02,   2.05688477e-02],
                        [  2.67333984e-02,   2.71606445e-02],
                        [  3.48205566e-02,   3.56140137e-02],
                        [  4.06799316e-02,   4.18395996e-02],
                        [  4.30908203e-02,   4.45251465e-02],
                        [  4.40063477e-02,   4.55932617e-02],
                        [  4.45861816e-02,   4.63256836e-02],
                        [  4.58984375e-02,   4.78515625e-02],
                        [  5.22460938e-02,   5.42907715e-02],
                        [  6.75048828e-02,   6.94885254e-02],
                        [  8.91723633e-02,   9.10339355e-02],
                        [  1.10687256e-01,   1.12518311e-01],
                        [  1.27929688e-01,   1.29730225e-01],
                        [  1.39678955e-01,   1.41265869e-01],
                        [  1.41052246e-01,   1.42303467e-01],
                        [  1.19476318e-01,   1.20422363e-01],
                        [  6.30493164e-02,   6.38122559e-02],
                        [ -2.54211426e-02,  -2.48413086e-02],
                        [ -1.26983643e-01,  -1.26739502e-01],
                        [ -2.17620850e-01,  -2.17803955e-01],
                        [ -2.75848389e-01,  -2.76275635e-01],
                        [ -2.87170410e-01,  -2.87750244e-01],
                        [ -2.54180908e-01,  -2.54974365e-01],
                        [ -1.99127197e-01,  -2.00256348e-01],
                        [ -1.47796631e-01,  -1.49108887e-01],
                        [ -1.11206055e-01,  -1.12640381e-01],
                        [ -8.68225098e-02,  -8.83483887e-02],
                        [ -7.04956055e-02,  -7.21130371e-02],
                        [ -6.17980957e-02,  -6.34155273e-02],
                        [ -6.03027344e-02,  -6.18896484e-02],
                        [ -6.21948242e-02,  -6.37512207e-02],
                        [ -6.16760254e-02,  -6.31713867e-02],
                        [ -5.49316406e-02,  -5.63049316e-02],
                        [ -4.16564941e-02,  -4.28161621e-02],
                        [ -2.35900879e-02,  -2.45361328e-02],
                        [ -4.82177734e-03,  -5.61523438e-03],
                        [  7.17163086e-03,   6.59179688e-03],
                        [  6.16455078e-03,   5.88989258e-03],
                        [ -7.78198242e-03,  -7.72094727e-03],
                        [ -2.99682617e-02,  -2.97851562e-02],
                        [ -5.45349121e-02,  -5.41381836e-02],
                        [ -7.32727051e-02,  -7.25097656e-02],
                        [ -7.72705078e-02,  -7.62634277e-02],
                        [ -6.31713867e-02,  -6.21032715e-02],
                        [ -3.33251953e-02,  -3.21960449e-02],
                        [  1.02844238e-02,   1.17187500e-02],
                        [  6.62231445e-02,   6.78100586e-02],
                        [  1.25976562e-01,   1.27471924e-01],
                        [  1.73034668e-01,   1.74407959e-01],
                        [  1.93603516e-01,   1.95037842e-01],
                        [  1.86859131e-01,   1.88354492e-01],
                        [  1.63085938e-01,   1.64398193e-01],
                        [  1.34216309e-01,   1.35223389e-01],
                        [  1.09313965e-01,   1.10168457e-01],
                        [  9.36584473e-02,   9.43603516e-02],
                        [  8.62426758e-02,   8.67004395e-02],
                        [  8.16650391e-02,   8.18786621e-02],
                        [  7.87048340e-02,   7.87353516e-02],
                        [  8.00476074e-02,   7.97729492e-02],
                        [  8.14514160e-02,   8.07800293e-02],
                        [  7.18688965e-02,   7.10449219e-02],
                        [  4.93774414e-02,   4.86450195e-02],
                        [  2.76794434e-02,   2.67639160e-02],
                        [  2.05993652e-02,   1.92565918e-02],
                        [  2.81372070e-02,   2.65502930e-02],
                        [  4.22058105e-02,   4.08630371e-02],
                        [  6.00585938e-02,   5.89904785e-02],
                        [  8.35876465e-02,   8.23669434e-02],
                        [  1.09252930e-01,   1.07757568e-01],
                        [  1.26617432e-01,   1.25274658e-01],
                        [  1.25976562e-01,   1.25152588e-01],
                        [  1.01043701e-01,   1.00463867e-01],
                        [  4.66613770e-02,   4.59899902e-02],
                        [ -3.48205566e-02,  -3.54614258e-02],
                        [ -1.22985840e-01,  -1.23229980e-01],
                        [ -1.84997559e-01,  -1.84753418e-01],
                        [ -1.99798584e-01,  -1.99462891e-01],
                        [ -1.75720215e-01,  -1.75445557e-01],
                        [ -1.40258789e-01,  -1.39770508e-01],
                        [ -1.14135742e-01,  -1.13250732e-01],
                        [ -9.82055664e-02,  -9.72290039e-02],
                        [ -8.33129883e-02,  -8.24279785e-02],
                        [ -6.38122559e-02,  -6.28967285e-02],
                        [ -4.11987305e-02,  -4.00085449e-02],
                        [ -2.20336914e-02,  -2.08129883e-02],
                        [ -1.49230957e-02,  -1.40380859e-02],
                        [ -2.23083496e-02,  -2.15454102e-02],
                        [ -3.38134766e-02,  -3.28674316e-02],
                        [ -3.53698730e-02,  -3.44543457e-02],
                        [ -2.53906250e-02,  -2.48718262e-02],
                        [ -1.48925781e-02,  -1.46484375e-02],
                        [ -1.15051270e-02,  -1.12304688e-02],
                        [ -1.19323730e-02,  -1.16577148e-02],
                        [ -1.12609863e-02,  -1.12915039e-02],
                        [ -1.17187500e-02,  -1.20239258e-02],
                        [ -1.76086426e-02,  -1.79138184e-02],
                        [ -2.90527344e-02,  -2.93884277e-02],
                        [ -4.53186035e-02,  -4.58679199e-02],
                        [ -6.62536621e-02,  -6.69250488e-02],
                        [ -8.61816406e-02,  -8.67614746e-02],
                        [ -9.34448242e-02,  -9.40551758e-02],
                        [ -7.97729492e-02,  -8.05358887e-02],
                        [ -4.43725586e-02,  -4.50744629e-02],
                        [  7.50732422e-03,   6.95800781e-03],
                        [  6.35070801e-02,   6.29882812e-02],
                        [  1.06323242e-01,   1.05804443e-01],
                        [  1.25305176e-01,   1.24938965e-01],
                        [  1.22741699e-01,   1.22467041e-01],
                        [  1.07086182e-01,   1.06811523e-01],
                        [  8.64868164e-02,   8.63647461e-02],
                        [  6.90002441e-02,   6.91528320e-02],
                        [  5.83496094e-02,   5.84716797e-02],
                        [  4.90722656e-02,   4.90112305e-02],
                        [  3.60717773e-02,   3.61938477e-02],
                        [  2.65808105e-02,   2.70385742e-02],
                        [  3.00292969e-02,   3.04565430e-02],
                        [  4.09240723e-02,   4.10766602e-02],
                        [  4.62036133e-02,   4.63562012e-02],
                        [  4.48303223e-02,   4.52270508e-02],
                        [  4.64477539e-02,   4.68750000e-02],
                        [  5.55419922e-02,   5.56945801e-02],
                        [  6.93054199e-02,   6.93664551e-02],
                        [  8.68530273e-02,   8.70361328e-02],
                        [  1.09375000e-01,   1.09558105e-01],
                        [  1.33178711e-01,   1.33209229e-01],
                        [  1.49200439e-01,   1.49169922e-01],
                        [  1.48254395e-01,   1.48162842e-01],
                        [  1.23657227e-01,   1.23565674e-01],
                        [  7.26013184e-02,   7.25402832e-02],
                        [ -2.41088867e-03,  -2.47192383e-03],
                        [ -9.35974121e-02,  -9.38110352e-02],
                        [ -1.87103271e-01,  -1.87377930e-01],
                        [ -2.59552002e-01,  -2.59643555e-01],
                        [ -2.84942627e-01,  -2.84881592e-01],
                        [ -2.56866455e-01,  -2.56958008e-01],
                        [ -1.99920654e-01,  -2.00195312e-01],
                        [ -1.48590088e-01,  -1.48681641e-01],
                        [ -1.18225098e-01,  -1.17950439e-01],
                        [ -1.02355957e-01,  -1.02081299e-01],
                        [ -9.06066895e-02,  -9.05761719e-02],
                        [ -8.06579590e-02,  -8.06579590e-02],
                        [ -7.44628906e-02,  -7.41271973e-02],
                        [ -6.97937012e-02,  -6.92443848e-02],
                        [ -6.10046387e-02,  -6.06079102e-02],
                        [ -4.58984375e-02,  -4.57153320e-02],
                        [ -2.64587402e-02,  -2.61840820e-02],
                        [ -5.88989258e-03,  -5.43212891e-03],
                        [  9.39941406e-03,   9.82666016e-03],
                        [  1.22070312e-02,   1.25122070e-02],
                        [  3.99780273e-03,   4.21142578e-03],
                        [ -7.59887695e-03,  -7.44628906e-03],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -7.06787109e-02,  -7.06481934e-02],
                        [ -8.23059082e-02,  -8.25195312e-02],
                        [ -7.21435547e-02,  -7.26318359e-02],
                        [ -4.52270508e-02,  -4.57153320e-02],
                        [ -6.13403320e-03,  -6.56127930e-03],
                        [  4.73937988e-02,   4.68444824e-02],
                        [  1.14410400e-01,   1.13677979e-01],
                        [  1.81579590e-01,   1.80786133e-01],
                        [  2.26623535e-01,   2.25830078e-01],
                        [  2.31292725e-01,   2.30499268e-01],
                        [  1.96838379e-01,   1.96136475e-01],
                        [  1.46301270e-01,   1.45660400e-01],
                        [  1.05560303e-01,   1.04827881e-01],
                        [  8.39538574e-02,   8.32519531e-02],
                        [  7.66906738e-02,   7.63244629e-02],
                        [  7.64770508e-02,   7.63549805e-02],
                        [  7.66601562e-02,   7.65075684e-02],
                        [  7.18994141e-02,   7.18078613e-02],
                        [  6.17675781e-02,   6.20422363e-02],
                        [  4.89196777e-02,   4.94995117e-02],
                        [  3.40881348e-02,   3.46984863e-02],
                        [  1.80053711e-02,   1.86462402e-02],
                        [  6.28662109e-03,   7.26318359e-03],
                        [  6.92749023e-03,   8.14819336e-03],
                        [  2.16064453e-02,   2.27661133e-02],
                        [  4.33959961e-02,   4.44335938e-02],
                        [  6.52770996e-02,   6.65283203e-02],
                        [  8.73413086e-02,   8.88061523e-02],
                        [  1.11022949e-01,   1.12304688e-01],
                        [  1.30828857e-01,   1.31774902e-01],
                        [  1.37023926e-01,   1.37878418e-01],
                        [  1.21368408e-01,   1.22283936e-01],
                        [  7.67211914e-02,   7.75146484e-02],
                        [  3.66210938e-04,   7.32421875e-04],
                        [ -9.50927734e-02,  -9.50927734e-02],
                        [ -1.79199219e-01,  -1.79382324e-01],
                        [ -2.20367432e-01,  -2.20672607e-01],
                        [ -2.09106445e-01,  -2.09686279e-01],
                        [ -1.64550781e-01,  -1.65435791e-01],
                        [ -1.16821289e-01,  -1.18011475e-01],
                        [ -8.53881836e-02,  -8.67919922e-02],
                        [ -7.15942383e-02,  -7.30895996e-02],
                        [ -6.54296875e-02,  -6.69250488e-02],
                        [ -5.84716797e-02,  -6.00891113e-02],
                        [ -5.34973145e-02,  -5.52978516e-02],
                        [ -5.71899414e-02,  -5.89294434e-02],
                        [ -6.31408691e-02,  -6.46057129e-02],
                        [ -5.49011230e-02,  -5.62133789e-02],
                        [ -2.84118652e-02,  -2.97241211e-02],
                        [  2.16674805e-03,   1.00708008e-03],
                        [  2.21557617e-02,   2.14538574e-02],
                        [  2.69775391e-02,   2.66113281e-02],
                        [  1.77917480e-02,   1.76391602e-02],
                        [ -4.88281250e-04,  -4.27246094e-04],
                        [ -1.95617676e-02,  -1.91650391e-02],
                        [ -3.39660645e-02,  -3.30810547e-02],
                        [ -4.57763672e-02,  -4.45861816e-02],
                        [ -6.15234375e-02,  -6.03027344e-02],
                        [ -8.36486816e-02,  -8.22753906e-02],
                        [ -1.03057861e-01,  -1.01318359e-01],
                        [ -1.03027344e-01,  -1.01013184e-01],
                        [ -7.56835938e-02,  -7.37609863e-02],
                        [ -3.08837891e-02,  -2.90832520e-02],
                        [  1.61132812e-02,   1.79138184e-02],
                        [  5.77697754e-02,   5.96008301e-02],
                        [  9.10949707e-02,   9.28344727e-02],
                        [  1.10382080e-01,   1.11877441e-01],
                        [  1.09985352e-01,   1.11114502e-01],
                        [  9.16748047e-02,   9.24377441e-02],
                        [  6.68945312e-02,   6.75659180e-02],
                        [  5.03845215e-02,   5.09033203e-02],
                        [  4.74548340e-02,   4.74853516e-02],
                        [  5.05065918e-02,   4.98962402e-02],
                        [  5.14526367e-02,   5.06591797e-02],
                        [  5.27343750e-02,   5.19714355e-02],
                        [  5.93872070e-02,   5.82885742e-02],
                        [  6.74133301e-02,   6.57348633e-02],
                        [  6.90917969e-02,   6.72607422e-02],
                        [  6.61010742e-02,   6.44226074e-02],
                        [  6.66503906e-02,   6.48193359e-02],
                        [  7.21435547e-02,   6.99768066e-02],
                        [  7.74841309e-02,   7.53173828e-02],
                        [  8.37402344e-02,   8.19702148e-02],
                        [  9.83886719e-02,   9.66796875e-02],
                        [  1.20635986e-01,   1.18774414e-01],
                        [  1.37512207e-01,   1.35833740e-01],
                        [  1.34704590e-01,   1.33514404e-01],
                        [  1.02508545e-01,   1.01654053e-01],
                        [  3.53088379e-02,   3.45458984e-02],
                        [ -6.32019043e-02,  -6.37207031e-02],
                        [ -1.72790527e-01,  -1.72882080e-01],
                        [ -2.60742188e-01,  -2.60437012e-01],
                        [ -2.97149658e-01,  -2.96447754e-01],
                        [ -2.73223877e-01,  -2.72277832e-01],
                        [ -2.10479736e-01,  -2.09289551e-01],
                        [ -1.46118164e-01,  -1.44653320e-01],
                        [ -1.05834961e-01,  -1.04064941e-01],
                        [ -9.07592773e-02,  -8.87756348e-02],
                        [ -8.73718262e-02,  -8.51745605e-02],
                        [ -8.36181641e-02,  -8.13598633e-02],
                        [ -7.80944824e-02,  -7.59582520e-02],
                        [ -7.68127441e-02,  -7.46765137e-02],
                        [ -7.93457031e-02,  -7.70263672e-02],
                        [ -7.34558105e-02,  -7.11669922e-02],
                        [ -5.14221191e-02,  -4.95605469e-02],
                        [ -2.34680176e-02,  -2.20947266e-02],
                        [ -3.93676758e-03,  -2.62451172e-03],
                        [  6.56127930e-03,   7.87353516e-03],
                        [  1.32141113e-02,   1.40686035e-02],
                        [  1.14746094e-02,   1.15356445e-02],
                        [ -7.50732422e-03,  -7.87353516e-03],
                        [ -4.02526855e-02,  -4.07104492e-02],
                        [ -7.01904297e-02,  -7.09228516e-02],
                        [ -8.30078125e-02,  -8.43811035e-02],
                        [ -7.48291016e-02,  -7.67822266e-02],
                        [ -4.46472168e-02,  -4.67224121e-02],
                        [  1.00708008e-02,   7.87353516e-03],
                        [  8.26110840e-02,   8.00476074e-02],
                        [  1.51550293e-01,   1.48681641e-01],
                        [  1.94793701e-01,   1.91955566e-01],
                        [  2.05078125e-01,   2.02362061e-01],
                        [  1.89086914e-01,   1.86309814e-01],
                        [  1.59912109e-01,   1.57196045e-01],
                        [  1.31866455e-01,   1.29547119e-01],
                        [  1.13220215e-01,   1.11267090e-01],
                        [  1.01043701e-01,   9.92736816e-02],
                        [  8.86840820e-02,   8.73413086e-02],
                        [  7.69958496e-02,   7.63549805e-02],
                        [  7.03735352e-02,   7.02514648e-02],
                        [  6.49719238e-02,   6.51245117e-02],
                        [  5.21850586e-02,   5.29479980e-02],
                        [  3.34777832e-02,   3.50646973e-02],
                        [  1.79138184e-02,   1.99279785e-02],
                        [  6.46972656e-03,   8.57543945e-03],
                        [ -5.40161133e-03,  -2.83813477e-03],
                        [ -1.21154785e-02,  -8.85009766e-03],
                        [ -3.29589844e-03,   1.52587891e-04],
                        [  1.63574219e-02,   1.95617676e-02],
                        [  3.14025879e-02,   3.46374512e-02],
                        [  3.90014648e-02,   4.24499512e-02],
                        [  5.14831543e-02,   5.48095703e-02],
                        [  7.63549805e-02,   7.91625977e-02],
                        [  1.07452393e-01,   1.09832764e-01],
                        [  1.32995605e-01,   1.35101318e-01],
                        [  1.38092041e-01,   1.39709473e-01],
                        [  1.04858398e-01,   1.05804443e-01],
                        [  2.64282227e-02,   2.67639160e-02],
                        [ -7.77587891e-02,  -7.80029297e-02],
                        [ -1.69555664e-01,  -1.70440674e-01],
                        [ -2.16339111e-01,  -2.17864990e-01],
                        [ -2.10296631e-01,  -2.12341309e-01],
                        [ -1.69769287e-01,  -1.72302246e-01],
                        [ -1.24023438e-01,  -1.26983643e-01],
                        [ -9.21325684e-02,  -9.54589844e-02],
                        [ -7.56835938e-02,  -7.92236328e-02],
                        [ -6.85119629e-02,  -7.22045898e-02],
                        [ -6.70776367e-02,  -7.07702637e-02],
                        [ -7.00073242e-02,  -7.35778809e-02],
                        [ -7.38830566e-02,  -7.72094727e-02],
                        [ -7.35168457e-02,  -7.65686035e-02],
                        [ -6.67114258e-02,  -6.94274902e-02],
                        [ -5.43212891e-02,  -5.65490723e-02],
                        [ -3.52478027e-02,  -3.68041992e-02],
                        [ -8.66699219e-03,  -9.64355469e-03],
                        [  1.59912109e-02,   1.55334473e-02],
                        [  2.26745605e-02,   2.28271484e-02],
                        [  7.04956055e-03,   7.90405273e-03],
                        [ -1.81884766e-02,  -1.67236328e-02],
                        [ -3.85131836e-02,  -3.65600586e-02],
                        [ -5.00793457e-02,  -4.75769043e-02],
                        [ -5.80139160e-02,  -5.50842285e-02],
                        [ -6.98547363e-02,  -6.67419434e-02],
                        [ -8.70666504e-02,  -8.37707520e-02],
                        [ -9.89074707e-02,  -9.53063965e-02],
                        [ -8.88061523e-02,  -8.51135254e-02],
                        [ -5.15136719e-02,  -4.81567383e-02],
                        [  4.27246094e-04,   3.44848633e-03],
                        [  4.94689941e-02,   5.24597168e-02],
                        [  8.60595703e-02,   8.88977051e-02],
                        [  1.06201172e-01,   1.08398438e-01],
                        [  1.06567383e-01,   1.08062744e-01],
                        [  9.13696289e-02,   9.24682617e-02],
                        [  7.56225586e-02,   7.64465332e-02],
                        [  7.03430176e-02,   7.04650879e-02],
                        [  6.99462891e-02,   6.93054199e-02],
                        [  6.59484863e-02,   6.48803711e-02],
                        [  6.30187988e-02,   6.16760254e-02],
                        [  6.91528320e-02,   6.72302246e-02],
                        [  7.83996582e-02,   7.58666992e-02],
                        [  7.80639648e-02,   7.53479004e-02],
                        [  6.82678223e-02,   6.55822754e-02],
                        [  6.14929199e-02,   5.85632324e-02],
                        [  6.46667480e-02,   6.12792969e-02],
                        [  7.40661621e-02,   7.06787109e-02],
                        [  8.81347656e-02,   8.52661133e-02],
                        [  1.10534668e-01,   1.07940674e-01],
                        [  1.35711670e-01,   1.32934570e-01],
                        [  1.45690918e-01,   1.42974854e-01],
                        [  1.28417969e-01,   1.26403809e-01],
                        [  8.70666504e-02,   8.57543945e-02],
                        [  2.40478516e-02,   2.29492188e-02],
                        [ -6.64062500e-02,  -6.73217773e-02],
                        [ -1.76391602e-01,  -1.76757812e-01],
                        [ -2.70904541e-01,  -2.70568848e-01],
                        [ -3.10852051e-01,  -3.09997559e-01],
                        [ -2.85491943e-01,  -2.84271240e-01],
                        [ -2.19238281e-01,  -2.17742920e-01],
                        [ -1.51031494e-01,  -1.49139404e-01],
                        [ -1.06262207e-01,  -1.03912354e-01],
                        [ -8.57849121e-02,  -8.30688477e-02],
                        [ -7.81860352e-02,  -7.53784180e-02],
                        [ -7.53784180e-02,  -7.25097656e-02],
                        [ -7.38830566e-02,  -7.08618164e-02],
                        [ -7.11975098e-02,  -6.80847168e-02],
                        [ -6.62841797e-02,  -6.33239746e-02],
                        [ -5.88073730e-02,  -5.60607910e-02],
                        [ -4.64172363e-02,  -4.38232422e-02],
                        [ -2.79235840e-02,  -2.56042480e-02],
                        [ -8.14819336e-03,  -6.22558594e-03],
                        [  4.63867188e-03,   6.16455078e-03],
                        [  4.97436523e-03,   6.07299805e-03],
                        [ -7.84301758e-03,  -7.32421875e-03],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -5.38330078e-02,  -5.42297363e-02],
                        [ -6.53991699e-02,  -6.63146973e-02],
                        [ -5.74645996e-02,  -5.90209961e-02],
                        [ -3.24096680e-02,  -3.44848633e-02],
                        [  5.79833984e-03,   3.50952148e-03],
                        [  5.93872070e-02,   5.67932129e-02],
                        [  1.25793457e-01,   1.22711182e-01],
                        [  1.85424805e-01,   1.82006836e-01],
                        [  2.14202881e-01,   2.10784912e-01],
                        [  2.07550049e-01,   2.04254150e-01],
                        [  1.81182861e-01,   1.77886963e-01],
                        [  1.50115967e-01,   1.46850586e-01],
                        [  1.19659424e-01,   1.16607666e-01],
                        [  9.32006836e-02,   9.06372070e-02],
                        [  7.43713379e-02,   7.22961426e-02],
                        [  6.18286133e-02,   6.01501465e-02],
                        [  5.31616211e-02,   5.19714355e-02],
                        [  5.06591797e-02,   5.01098633e-02],
                        [  5.45043945e-02,   5.45959473e-02],
                        [  5.53588867e-02,   5.60302734e-02],
                        [  4.27246094e-02,   4.40063477e-02],
                        [  1.87683105e-02,   2.06604004e-02],
                        [ -3.02124023e-03,  -6.40869141e-04],
                        [ -1.16577148e-02,  -8.88061523e-03],
                        [ -6.43920898e-03,  -3.26538086e-03],
                        [  7.38525391e-03,   1.09252930e-02],
                        [  2.47192383e-02,   2.83813477e-02],
                        [  4.16564941e-02,   4.52880859e-02],
                        [  5.60913086e-02,   5.97229004e-02],
                        [  6.89086914e-02,   7.24487305e-02],
                        [  8.12988281e-02,   8.45031738e-02],
                        [  9.17053223e-02,   9.44824219e-02],
                        [  9.89074707e-02,   1.01287842e-01],
                        [  1.02935791e-01,   1.04858398e-01],
                        [  9.78393555e-02,   9.91210938e-02],
                        [  7.09838867e-02,   7.15332031e-02],
                        [  1.49230957e-02,   1.48925781e-02],
                        [ -6.26525879e-02,  -6.32629395e-02],
                        [ -1.40594482e-01,  -1.41784668e-01],
                        [ -1.93054199e-01,  -1.94915771e-01],
                        [ -2.03277588e-01,  -2.05718994e-01],
                        [ -1.75048828e-01,  -1.77886963e-01],
                        [ -1.30065918e-01,  -1.33087158e-01],
                        [ -9.15832520e-02,  -9.48181152e-02],
                        [ -7.10754395e-02,  -7.46154785e-02],
                        [ -6.66503906e-02,  -7.03430176e-02],
                        [ -6.89392090e-02,  -7.24487305e-02],
                        [ -6.86035156e-02,  -7.17163086e-02],
                        [ -6.30493164e-02,  -6.58874512e-02],
                        [ -5.83190918e-02,  -6.10351562e-02],
                        [ -6.06994629e-02,  -6.30798340e-02],
                        [ -6.41174316e-02,  -6.58264160e-02],
                        [ -5.36499023e-02,  -5.45959473e-02],
                        [ -2.62145996e-02,  -2.66723633e-02],
                        [  1.15966797e-03,   9.76562500e-04],
                        [  1.10168457e-02,   1.14135742e-02],
                        [  4.11987305e-03,   5.31005859e-03],
                        [ -8.05664062e-03,  -6.37817383e-03],
                        [ -2.12402344e-02,  -1.93176270e-02],
                        [ -4.02526855e-02,  -3.80249023e-02],
                        [ -6.61315918e-02,  -6.35070801e-02],
                        [ -8.88977051e-02,  -8.60900879e-02],
                        [ -9.68017578e-02,  -9.39636230e-02],
                        [ -8.58459473e-02,  -8.29772949e-02],
                        [ -5.79528809e-02,  -5.50842285e-02],
                        [ -1.60217285e-02,  -1.33361816e-02],
                        [  3.40576172e-02,   3.64379883e-02],
                        [  8.06884766e-02,   8.28552246e-02],
                        [  1.10565186e-01,   1.12457275e-01],
                        [  1.16821289e-01,   1.18316650e-01],
                        [  1.04339600e-01,   1.05407715e-01],
                        [  8.58764648e-02,   8.65478516e-02],
                        [  7.15637207e-02,   7.18383789e-02],
                        [  6.30187988e-02,   6.28356934e-02],
                        [  5.83801270e-02,   5.78918457e-02],
                        [  5.83496094e-02,   5.75561523e-02],
                        [  6.36596680e-02,   6.24694824e-02],
                        [  7.13500977e-02,   6.97937012e-02],
                        [  7.63549805e-02,   7.45849609e-02],
                        [  7.52258301e-02,   7.34558105e-02],
                        [  6.95495605e-02,   6.76574707e-02],
                        [  6.51550293e-02,   6.30493164e-02],
                        [  6.66809082e-02,   6.44836426e-02],
                        [  7.52563477e-02,   7.31811523e-02],
                        [  9.14611816e-02,   8.96301270e-02],
                        [  1.13861084e-01,   1.12060547e-01],
                        [  1.32843018e-01,   1.31011963e-01],
                        [  1.32476807e-01,   1.30859375e-01],
                        [  9.89074707e-02,   9.76562500e-02],
                        [  2.58483887e-02,   2.48413086e-02],
                        [ -8.01391602e-02,  -8.09936523e-02],
                        [ -1.93084717e-01,  -1.93695068e-01],
                        [ -2.75695801e-01,  -2.75970459e-01],
                        [ -3.03344727e-01,  -3.03283691e-01],
                        [ -2.78015137e-01,  -2.77770996e-01],
                        [ -2.21679688e-01,  -2.21221924e-01],
                        [ -1.61621094e-01,  -1.60858154e-01],
                        [ -1.17126465e-01,  -1.16088867e-01],
                        [ -9.17053223e-02,  -9.04541016e-02],
                        [ -7.92236328e-02,  -7.78198242e-02],
                        [ -7.51647949e-02,  -7.36083984e-02],
                        [ -7.57751465e-02,  -7.40966797e-02],
                        [ -7.20214844e-02,  -7.02209473e-02],
                        [ -5.49011230e-02,  -5.30090332e-02],
                        [ -2.61535645e-02,  -2.42919922e-02],
                        [  1.55639648e-03,   3.32641602e-03],
                        [  1.51367188e-02,   1.68151855e-02],
                        [  1.13220215e-02,   1.30004883e-02],
                        [ -2.22778320e-03,  -7.01904297e-04],
                        [ -1.89208984e-02,  -1.76696777e-02],
                        [ -4.06494141e-02,  -3.97644043e-02],
                        [ -6.73522949e-02,  -6.66198730e-02],
                        [ -8.66088867e-02,  -8.60595703e-02],
                        [ -8.38928223e-02,  -8.37097168e-02],
                        [ -5.67016602e-02,  -5.69152832e-02],
                        [ -1.23596191e-02,  -1.28784180e-02],
                        [  4.18701172e-02,   4.11071777e-02],
                        [  1.00860596e-01,   9.97619629e-02],
                        [  1.55456543e-01,   1.54083252e-01],
                        [  1.91864014e-01,   1.90307617e-01],
                        [  2.00958252e-01,   1.99188232e-01],
                        [  1.85760498e-01,   1.83746338e-01],
                        [  1.58874512e-01,   1.56768799e-01],
                        [  1.34155273e-01,   1.32202148e-01],
                        [  1.17279053e-01,   1.15417480e-01],
                        [  1.02569580e-01,   1.00555420e-01],
                        [  8.24584961e-02,   8.04748535e-02],
                        [  6.04248047e-02,   5.88378906e-02],
                        [  4.72412109e-02,   4.61120605e-02],
                        [  4.52575684e-02,   4.42504883e-02],
                        [  4.37316895e-02,   4.27856445e-02],
                        [  3.24401855e-02,   3.19824219e-02],
                        [  1.28479004e-02,   1.29699707e-02],
                        [ -5.98144531e-03,  -5.58471680e-03],
                        [ -1.64184570e-02,  -1.58691406e-02],
                        [ -1.64184570e-02,  -1.55334473e-02],
                        [ -8.75854492e-03,  -7.41577148e-03],
                        [  2.38037109e-03,   3.96728516e-03],
                        [  1.46789551e-02,   1.62658691e-02],
                        [  2.81677246e-02,   2.99072266e-02],
                        [  4.37316895e-02,   4.57458496e-02],
                        [  6.16149902e-02,   6.36596680e-02],
                        [  8.02001953e-02,   8.20007324e-02],
                        [  9.51843262e-02,   9.68322754e-02],
                        [  1.02539062e-01,   1.04248047e-01],
                        [  1.03393555e-01,   1.05010986e-01],
                        [  1.00891113e-01,   1.02111816e-01],
                        [  9.05456543e-02,   9.14001465e-02],
                        [  5.86547852e-02,   5.92956543e-02],
                        [ -5.82885742e-03,  -5.37109375e-03],
                        [ -9.49401855e-02,  -9.48486328e-02],
                        [ -1.78588867e-01,  -1.78863525e-01],
                        [ -2.22869873e-01,  -2.23358154e-01],
                        [ -2.15515137e-01,  -2.16247559e-01],
                        [ -1.74224854e-01,  -1.75201416e-01],
                        [ -1.30920410e-01,  -1.32049561e-01],
                        [ -1.06018066e-01,  -1.07208252e-01],
                        [ -9.53063965e-02,  -9.65881348e-02],
                        [ -8.26416016e-02,  -8.41064453e-02],
                        [ -6.36596680e-02,  -6.51245117e-02],
                        [ -4.96826172e-02,  -5.09643555e-02],
                        [ -4.87365723e-02,  -4.98657227e-02],
                        [ -5.35888672e-02,  -5.47790527e-02],
                        [ -5.30700684e-02,  -5.42297363e-02],
                        [ -4.52880859e-02,  -4.62036133e-02],
                        [ -3.40881348e-02,  -3.46984863e-02],
                        [ -2.25219727e-02,  -2.30102539e-02],
                        [ -1.41906738e-02,  -1.46484375e-02],
                        [ -1.32446289e-02,  -1.35192871e-02],
                        [ -2.09655762e-02,  -2.09960938e-02],
                        [ -3.63159180e-02,  -3.61938477e-02],
                        [ -5.71594238e-02,  -5.69152832e-02],
                        [ -7.78503418e-02,  -7.75451660e-02],
                        [ -8.98742676e-02,  -8.95080566e-02],
                        [ -8.88671875e-02,  -8.84094238e-02],
                        [ -7.65686035e-02,  -7.60192871e-02],
                        [ -5.36499023e-02,  -5.30700684e-02],
                        [ -1.82800293e-02,  -1.77001953e-02],
                        [  2.63671875e-02,   2.69775391e-02],
                        [  7.08618164e-02,   7.14721680e-02],
                        [  1.05834961e-01,   1.06506348e-01],
                        [  1.24359131e-01,   1.25030518e-01],
                        [  1.22039795e-01,   1.22680664e-01],
                        [  1.02111816e-01,   1.02722168e-01],
                        [  7.72705078e-02,   7.79113770e-02],
                        [  6.13708496e-02,   6.20422363e-02],
                        [  5.97229004e-02,   6.03332520e-02],
                        [  6.74133301e-02,   6.79626465e-02],
                        [  7.55310059e-02,   7.61413574e-02],
                        [  7.93151855e-02,   7.99255371e-02],
                        [  8.16040039e-02,   8.20922852e-02],
                        [  8.67309570e-02,   8.71582031e-02],
                        [  9.31701660e-02,   9.35363770e-02],
                        [  9.63745117e-02,   9.66796875e-02],
                        [  9.61914062e-02,   9.64050293e-02],
                        [  9.71069336e-02,   9.72290039e-02],
                        [  1.03607178e-01,   1.03546143e-01],
                        [  1.15509033e-01,   1.15264893e-01],
                        [  1.24328613e-01,   1.23931885e-01],
                        [  1.13494873e-01,   1.13067627e-01],
                        [  6.67419434e-02,   6.61621094e-02],
                        [ -1.99890137e-02,  -2.08129883e-02],
                        [ -1.30798340e-01,  -1.31866455e-01],
                        [ -2.32452393e-01,  -2.33520508e-01],
                        [ -2.88574219e-01,  -2.89611816e-01],
                        [ -2.83630371e-01,  -2.84790039e-01],
                        [ -2.36572266e-01,  -2.37854004e-01],
                        [ -1.84326172e-01,  -1.85607910e-01],
                        [ -1.49749756e-01,  -1.50909424e-01],
                        [ -1.29211426e-01,  -1.30249023e-01],
                        [ -1.08551025e-01,  -1.09527588e-01],
                        [ -8.38317871e-02,  -8.46862793e-02],
                        [ -6.24694824e-02,  -6.31103516e-02],
                        [ -5.04455566e-02,  -5.08728027e-02],
                        [ -4.60510254e-02,  -4.62646484e-02],
                        [ -4.37927246e-02,  -4.37316895e-02],
                        [ -3.87878418e-02,  -3.84216309e-02],
                        [ -2.99682617e-02,  -2.93884277e-02],
                        [ -2.10266113e-02,  -2.03247070e-02],
                        [ -1.64794922e-02,  -1.54724121e-02],
                        [ -1.75170898e-02,  -1.61743164e-02],
                        [ -2.36511230e-02,  -2.22167969e-02],
                        [ -3.50341797e-02,  -3.36914062e-02],
                        [ -4.79736328e-02,  -4.65087891e-02],
                        [ -5.13916016e-02,  -4.97131348e-02],
                        [ -3.62854004e-02,  -3.46374512e-02],
                        [ -5.24902344e-03,  -3.84521484e-03],
                        [  3.60717773e-02,   3.73535156e-02],
                        [  8.93249512e-02,   9.06066895e-02],
                        [  1.51306152e-01,   1.52374268e-01],
                        [  1.99798584e-01,   2.00500488e-01],
                        [  2.09503174e-01,   2.09930420e-01],
                        [  1.82373047e-01,   1.82678223e-01],
                        [  1.47888184e-01,   1.47979736e-01],
                        [  1.30554199e-01,   1.30187988e-01],
                        [  1.26464844e-01,   1.25762939e-01],
                        [  1.16912842e-01,   1.16119385e-01],
                        [  9.56420898e-02,   9.47875977e-02],
                        [  7.35168457e-02,   7.23266602e-02],
                        [  5.96923828e-02,   5.81665039e-02],
                        [  5.08117676e-02,   4.92858887e-02],
                        [  3.95812988e-02,   3.81774902e-02],
                        [  2.41699219e-02,   2.27355957e-02],
                        [  8.05664062e-03,   6.50024414e-03],
                        [ -3.60107422e-03,  -5.09643555e-03],
                        [ -8.02612305e-03,  -9.33837891e-03],
                        [ -6.86645508e-03,  -8.02612305e-03],
                        [ -3.17382812e-03,  -4.18090820e-03],
                        [  1.61743164e-03,   8.23974609e-04],
                        [  7.78198242e-03,   7.23266602e-03],
                        [  1.52893066e-02,   1.48925781e-02],
                        [  2.20031738e-02,   2.18200684e-02],
                        [  2.63366699e-02,   2.64892578e-02],
                        [  3.20434570e-02,   3.24401855e-02],
                        [  4.61730957e-02,   4.66613770e-02],
                        [  6.90307617e-02,   6.96716309e-02],
                        [  8.99047852e-02,   9.07897949e-02],
                        [  9.78698730e-02,   9.89379883e-02],
                        [  9.41162109e-02,   9.52148438e-02],
                        [  8.60900879e-02,   8.72497559e-02],
                        [  7.14416504e-02,   7.26623535e-02],
                        [  3.54309082e-02,   3.66821289e-02],
                        [ -3.29895020e-02,  -3.17382812e-02],
                        [ -1.22039795e-01,  -1.20819092e-01],
                        [ -1.96136475e-01,  -1.95007324e-01],
                        [ -2.21649170e-01,  -2.20611572e-01],
                        [ -1.95800781e-01,  -1.94885254e-01],
                        [ -1.46759033e-01,  -1.45935059e-01],
                        [ -1.05407715e-01,  -1.04736328e-01],
                        [ -8.19091797e-02,  -8.14208984e-02],
                        [ -6.87866211e-02,  -6.84509277e-02],
                        [ -5.77697754e-02,  -5.75866699e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -4.27551270e-02,  -4.29382324e-02],
                        [ -4.44946289e-02,  -4.48913574e-02],
                        [ -5.07202148e-02,  -5.13000488e-02],
                        [ -5.42907715e-02,  -5.49316406e-02],
                        [ -5.01403809e-02,  -5.09033203e-02],
                        [ -4.15039062e-02,  -4.25109863e-02],
                        [ -3.62548828e-02,  -3.74145508e-02],
                        [ -3.74450684e-02,  -3.85742188e-02],
                        [ -4.15039062e-02,  -4.26330566e-02],
                        [ -4.49829102e-02,  -4.62646484e-02],
                        [ -4.94384766e-02,  -5.07812500e-02],
                        [ -5.81359863e-02,  -5.93872070e-02],
                        [ -7.15332031e-02,  -7.26928711e-02],
                        [ -8.61206055e-02,  -8.71887207e-02],
                        [ -9.54589844e-02,  -9.64965820e-02],
                        [ -8.96606445e-02,  -9.05761719e-02],
                        [ -5.83190918e-02,  -5.90209961e-02],
                        [ -1.89208984e-03,  -2.34985352e-03],
                        [  6.22558594e-02,   6.19812012e-02],
                        [  1.11145020e-01,   1.11022949e-01],
                        [  1.31744385e-01,   1.31866455e-01],
                        [  1.25427246e-01,   1.25854492e-01],
                        [  1.02752686e-01,   1.03393555e-01],
                        [  7.80029297e-02,   7.88574219e-02],
                        [  6.45446777e-02,   6.56127930e-02],
                        [  6.65588379e-02,   6.78100586e-02],
                        [  7.46765137e-02,   7.60192871e-02],
                        [  7.74841309e-02,   7.89794922e-02],
                        [  7.69653320e-02,   7.85522461e-02],
                        [  8.27331543e-02,   8.43200684e-02],
                        [  9.40856934e-02,   9.56420898e-02],
                        [  1.00250244e-01,   1.01806641e-01],
                        [  9.86328125e-02,   1.00067139e-01],
                        [  9.96398926e-02,   1.00860596e-01],
                        [  1.11541748e-01,   1.12548828e-01],
                        [  1.29425049e-01,   1.30310059e-01],
                        [  1.39221191e-01,   1.39862061e-01],
                        [  1.26251221e-01,   1.26495361e-01],
                        [  8.34350586e-02,   8.33435059e-02],
                        [  1.35803223e-02,   1.33056641e-02],
                        [ -7.68127441e-02,  -7.72705078e-02],
                        [ -1.75689697e-01,  -1.76544189e-01],
                        [ -2.55920410e-01,  -2.57141113e-01],
                        [ -2.86071777e-01,  -2.87445068e-01],
                        [ -2.59796143e-01,  -2.61230469e-01],
                        [ -2.03704834e-01,  -2.05291748e-01],
                        [ -1.52618408e-01,  -1.54388428e-01],
                        [ -1.24023438e-01,  -1.25854492e-01],
                        [ -1.13983154e-01,  -1.15753174e-01],
                        [ -1.07330322e-01,  -1.08947754e-01],
                        [ -9.21936035e-02,  -9.36584473e-02],
                        [ -7.10144043e-02,  -7.23876953e-02],
                        [ -5.53283691e-02,  -5.65490723e-02],
                        [ -4.94384766e-02,  -5.03540039e-02],
                        [ -4.66613770e-02,  -4.72106934e-02],
                        [ -4.04052734e-02,  -4.06799316e-02],
                        [ -3.09753418e-02,  -3.10363770e-02],
                        [ -2.19726562e-02,  -2.16979980e-02],
                        [ -1.69677734e-02,  -1.63574219e-02],
                        [ -2.07214355e-02,  -1.98364258e-02],
                        [ -3.58886719e-02,  -3.47900391e-02],
                        [ -5.52673340e-02,  -5.39550781e-02],
                        [ -6.32629395e-02,  -6.17675781e-02],
                        [ -4.85839844e-02,  -4.69665527e-02],
                        [ -1.15051270e-02,  -9.85717773e-03],
                        [  4.11376953e-02,   4.28161621e-02],
                        [  1.01928711e-01,   1.03576660e-01],
                        [  1.59881592e-01,   1.61468506e-01],
                        [  1.97998047e-01,   1.99432373e-01],
                        [  2.02545166e-01,   2.03765869e-01],
                        [  1.76971436e-01,   1.78009033e-01],
                        [  1.42303467e-01,   1.43157959e-01],
                        [  1.20544434e-01,   1.21124268e-01],
                        [  1.16973877e-01,   1.17279053e-01],
                        [  1.19201660e-01,   1.19232178e-01],
                        [  1.12365723e-01,   1.12152100e-01],
                        [  9.32922363e-02,   9.28039551e-02],
                        [  7.07092285e-02,   6.99768066e-02],
                        [  5.35888672e-02,   5.27038574e-02],
                        [  4.17175293e-02,   4.06799316e-02],
                        [  3.02429199e-02,   2.89611816e-02],
                        [  1.79138184e-02,   1.65405273e-02],
                        [  3.87573242e-03,   2.56347656e-03],
                        [ -1.35192871e-02,  -1.48315430e-02],
                        [ -2.77709961e-02,  -2.91748047e-02],
                        [ -2.84118652e-02,  -2.97851562e-02],
                        [ -1.68457031e-02,  -1.80358887e-02],
                        [ -4.27246094e-03,  -5.31005859e-03],
                        [  5.34057617e-03,   4.39453125e-03],
                        [  1.55639648e-02,   1.47399902e-02],
                        [  2.42309570e-02,   2.36206055e-02],
                        [  2.51159668e-02,   2.47192383e-02],
                        [  2.16369629e-02,   2.14843750e-02],
                        [  2.58483887e-02,   2.58789062e-02],
                        [  4.25109863e-02,   4.26940918e-02],
                        [  6.37817383e-02,   6.41784668e-02],
                        [  7.99560547e-02,   8.05664062e-02],
                        [  8.93554688e-02,   9.00878906e-02],
                        [  9.49096680e-02,   9.57336426e-02],
                        [  9.15527344e-02,   9.24987793e-02],
                        [  6.23474121e-02,   6.33850098e-02],
                        [ -4.69970703e-03,  -3.60107422e-03],
                        [ -9.60388184e-02,  -9.49401855e-02],
                        [ -1.76025391e-01,  -1.74926758e-01],
                        [ -2.12799072e-01,  -2.11730957e-01],
                        [ -1.99249268e-01,  -1.98272705e-01],
                        [ -1.53808594e-01,  -1.52862549e-01],
                        [ -1.06445312e-01,  -1.05590820e-01],
                        [ -7.91625977e-02,  -7.84912109e-02],
                        [ -7.22351074e-02,  -7.17163086e-02],
                        [ -7.12280273e-02,  -7.08007812e-02],
                        [ -6.59484863e-02,  -6.56433105e-02],
                        [ -5.87158203e-02,  -5.86242676e-02],
                        [ -5.64880371e-02,  -5.66101074e-02],
                        [ -6.05773926e-02,  -6.08520508e-02],
                        [ -6.54296875e-02,  -6.57958984e-02],
                        [ -6.52465820e-02,  -6.57043457e-02],
                        [ -5.88989258e-02,  -5.95703125e-02],
                        [ -4.91943359e-02,  -5.00793457e-02],
                        [ -4.02221680e-02,  -4.11376953e-02],
                        [ -3.51562500e-02,  -3.59802246e-02],
                        [ -3.64379883e-02,  -3.73535156e-02],
                        [ -4.67224121e-02,  -4.77905273e-02],
                        [ -6.53991699e-02,  -6.64672852e-02],
                        [ -8.63647461e-02,  -8.72802734e-02],
                        [ -1.01654053e-01,  -1.02478027e-01],
                        [ -1.04675293e-01,  -1.05529785e-01],
                        [ -8.96301270e-02,  -9.04235840e-02],
                        [ -5.27954102e-02,  -5.33752441e-02],
                        [  2.41088867e-03,   2.01416016e-03],
                        [  6.14318848e-02,   6.10961914e-02],
                        [  1.04187012e-01,   1.03973389e-01],
                        [  1.18774414e-01,   1.18835449e-01],
                        [  1.11328125e-01,   1.11572266e-01],
                        [  1.00189209e-01,   1.00494385e-01],
                        [  9.89074707e-02,   9.93347168e-02],
                        [  1.06262207e-01,   1.06933594e-01],
                        [  1.12609863e-01,   1.13433838e-01],
                        [  1.10992432e-01,   1.11846924e-01],
                        [  1.02539062e-01,   1.03393555e-01],
                        [  9.57641602e-02,   9.67102051e-02],
                        [  9.85107422e-02,   9.95483398e-02],
                        [  1.08367920e-01,   1.09375000e-01],
                        [  1.15173340e-01,   1.16088867e-01],
                        [  1.14471436e-01,   1.15325928e-01],
                        [  1.15203857e-01,   1.15997314e-01],
                        [  1.27502441e-01,   1.28204346e-01],
                        [  1.42028809e-01,   1.42578125e-01],
                        [  1.31652832e-01,   1.32049561e-01],
                        [  8.05664062e-02,   8.08105469e-02],
                        [  2.13623047e-04,   2.44140625e-04],
                        [ -8.92333984e-02,  -8.93554688e-02],
                        [ -1.77642822e-01,  -1.77917480e-01],
                        [ -2.53662109e-01,  -2.54089355e-01],
                        [ -2.91564941e-01,  -2.92114258e-01],
                        [ -2.71606445e-01,  -2.72277832e-01],
                        [ -2.09625244e-01,  -2.10418701e-01],
                        [ -1.48284912e-01,  -1.49139404e-01],
                        [ -1.16394043e-01,  -1.17279053e-01],
                        [ -1.08581543e-01,  -1.09497070e-01],
                        [ -1.05834961e-01,  -1.06719971e-01],
                        [ -1.00585938e-01,  -1.01440430e-01],
                        [ -9.50927734e-02,  -9.58862305e-02],
                        [ -8.81042480e-02,  -8.88061523e-02],
                        [ -7.47680664e-02,  -7.53784180e-02],
                        [ -5.35888672e-02,  -5.40466309e-02],
                        [ -2.89001465e-02,  -2.92663574e-02],
                        [ -1.00402832e-02,  -1.02539062e-02],
                        [ -5.06591797e-03,  -5.12695312e-03],
                        [ -1.31225586e-02,  -1.30310059e-02],
                        [ -2.55432129e-02,  -2.53601074e-02],
                        [ -3.50646973e-02,  -3.46984863e-02],
                        [ -3.94897461e-02,  -3.90014648e-02],
                        [ -3.58581543e-02,  -3.53393555e-02],
                        [ -1.64794922e-02,  -1.58996582e-02],
                        [  2.34375000e-02,   2.41699219e-02],
                        [  7.89794922e-02,   7.97119141e-02],
                        [  1.37359619e-01,   1.38031006e-01],
                        [  1.82556152e-01,   1.83227539e-01],
                        [  2.01538086e-01,   2.02270508e-01],
                        [  1.92840576e-01,   1.93511963e-01],
                        [  1.67755127e-01,   1.68273926e-01],
                        [  1.41601562e-01,   1.42059326e-01],
                        [  1.24206543e-01,   1.24633789e-01],
                        [  1.15417480e-01,   1.15722656e-01],
                        [  1.07513428e-01,   1.07666016e-01],
                        [  9.43603516e-02,   9.44213867e-02],
                        [  7.94372559e-02,   7.94067383e-02],
                        [  7.08618164e-02,   7.07092285e-02],
                        [  6.68945312e-02,   6.66503906e-02],
                        [  5.59387207e-02,   5.56030273e-02],
                        [  3.26538086e-02,   3.22570801e-02],
                        [  4.91333008e-03,   4.48608398e-03],
                        [ -1.68151855e-02,  -1.73034668e-02],
                        [ -2.89001465e-02,  -2.94494629e-02],
                        [ -3.40576172e-02,  -3.45764160e-02],
                        [ -3.56445312e-02,  -3.61633301e-02],
                        [ -3.21960449e-02,  -3.27148438e-02],
                        [ -1.91650391e-02,  -1.96533203e-02],
                        [  2.19726562e-03,   1.83105469e-03],
                        [  2.21557617e-02,   2.18200684e-02],
                        [  3.14331055e-02,   3.10974121e-02],
                        [  3.04260254e-02,   3.01818848e-02],
                        [  2.73742676e-02,   2.72521973e-02],
                        [  2.98767090e-02,   2.98156738e-02],
                        [  3.89099121e-02,   3.88488770e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.85327148e-02,   5.86853027e-02],
                        [  7.00683594e-02,   7.03125000e-02],
                        [  8.79821777e-02,   8.81652832e-02],
                        [  1.05834961e-01,   1.06048584e-01],
                        [  1.06628418e-01,   1.06933594e-01],
                        [  7.32421875e-02,   7.36083984e-02],
                        [  1.80053711e-03,   2.13623047e-03],
                        [ -9.11560059e-02,  -9.07897949e-02],
                        [ -1.71417236e-01,  -1.71081543e-01],
                        [ -2.04193115e-01,  -2.03887939e-01],
                        [ -1.82373047e-01,  -1.82067871e-01],
                        [ -1.36718750e-01,  -1.36413574e-01],
                        [ -1.06140137e-01,  -1.05895996e-01],
                        [ -1.01287842e-01,  -1.01104736e-01],
                        [ -1.04003906e-01,  -1.03790283e-01],
                        [ -9.51843262e-02,  -9.50317383e-02],
                        [ -7.53173828e-02,  -7.52563477e-02],
                        [ -5.83190918e-02,  -5.82580566e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -5.38024902e-02,  -5.38940430e-02],
                        [ -5.53588867e-02,  -5.54809570e-02],
                        [ -5.33142090e-02,  -5.34057617e-02],
                        [ -4.73937988e-02,  -4.75463867e-02],
                        [ -4.16259766e-02,  -4.18395996e-02],
                        [ -4.22973633e-02,  -4.25415039e-02],
                        [ -4.98962402e-02,  -5.01098633e-02],
                        [ -5.86547852e-02,  -5.88989258e-02],
                        [ -6.81457520e-02,  -6.84204102e-02],
                        [ -8.34960938e-02,  -8.37707520e-02],
                        [ -1.00067139e-01,  -1.00280762e-01],
                        [ -1.02050781e-01,  -1.02233887e-01],
                        [ -8.05053711e-02,  -8.07189941e-02],
                        [ -4.07409668e-02,  -4.09240723e-02],
                        [  8.66699219e-03,   8.54492188e-03],
                        [  6.13403320e-02,   6.12487793e-02],
                        [  1.06628418e-01,   1.06536865e-01],
                        [  1.31011963e-01,   1.30950928e-01],
                        [  1.32843018e-01,   1.32873535e-01],
                        [  1.26342773e-01,   1.26403809e-01],
                        [  1.23565674e-01,   1.23657227e-01],
                        [  1.20971680e-01,   1.21063232e-01],
                        [  1.10107422e-01,   1.10229492e-01],
                        [  9.35668945e-02,   9.36889648e-02],
                        [  8.19091797e-02,   8.20922852e-02],
                        [  8.05358887e-02,   8.07495117e-02],
                        [  8.73107910e-02,   8.74633789e-02],
                        [  9.94262695e-02,   9.96093750e-02],
                        [  1.16241455e-01,   1.16455078e-01],
                        [  1.36047363e-01,   1.36230469e-01],
                        [  1.53839111e-01,   1.54022217e-01],
                        [  1.62414551e-01,   1.62536621e-01],
                        [  1.55639648e-01,   1.55761719e-01],
                        [  1.28601074e-01,   1.28692627e-01],
                        [  7.39440918e-02,   7.40356445e-02],
                        [ -1.25732422e-02,  -1.25122070e-02],
                        [ -1.20300293e-01,  -1.20300293e-01],
                        [ -2.23510742e-01,  -2.23541260e-01],
                        [ -2.93701172e-01,  -2.93731689e-01],
                        [ -3.10882568e-01,  -3.10943604e-01],
                        [ -2.72796631e-01,  -2.72918701e-01],
                        [ -2.03582764e-01,  -2.03674316e-01],
                        [ -1.43829346e-01,  -1.43920898e-01],
                        [ -1.16516113e-01,  -1.16638184e-01],
                        [ -1.09191895e-01,  -1.09344482e-01],
                        [ -1.00585938e-01,  -1.00738525e-01],
                        [ -8.88671875e-02,  -8.89892578e-02],
                        [ -8.16040039e-02,  -8.17260742e-02],
                        [ -7.62023926e-02,  -7.62939453e-02],
                        [ -6.50024414e-02,  -6.51245117e-02],
                        [ -4.91943359e-02,  -4.93164062e-02],
                        [ -3.52172852e-02,  -3.53088379e-02],
                        [ -2.46582031e-02,  -2.47192383e-02],
                        [ -1.72424316e-02,  -1.72729492e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -3.28674316e-02,  -3.28369141e-02],
                        [ -3.13720703e-02,  -3.13110352e-02],
                        [ -1.46789551e-02,  -1.46179199e-02],
                        [  1.86157227e-02,   1.86767578e-02],
                        [  6.58874512e-02,   6.59484863e-02],
                        [  1.18652344e-01,   1.18743896e-01],
                        [  1.65740967e-01,   1.65832520e-01],
                        [  1.96502686e-01,   1.96563721e-01],
                        [  2.01965332e-01,   2.02026367e-01],
                        [  1.82403564e-01,   1.82495117e-01],
                        [  1.54174805e-01,   1.54266357e-01],
                        [  1.34582520e-01,   1.34643555e-01],
                        [  1.21917725e-01,   1.21948242e-01],
                        [  1.05560303e-01,   1.05590820e-01],
                        [  8.70056152e-02,   8.70361328e-02],
                        [  7.37915039e-02,   7.38220215e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  5.48400879e-02,   5.48095703e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  3.24096680e-02,   3.23791504e-02],
                        [  1.68457031e-02,   1.68151855e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -1.19628906e-02,  -1.19934082e-02],
                        [ -1.71813965e-02,  -1.72424316e-02],
                        [ -1.77307129e-02,  -1.77612305e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.28173828e-02,  -1.28784180e-02],
                        [ -3.69262695e-03,  -3.72314453e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.14843750e-02,   2.14233398e-02],
                        [  3.16467285e-02,   3.16772461e-02],
                        [  3.65295410e-02,   3.65600586e-02],
                        [  3.20129395e-02,   3.19824219e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  3.28369141e-02,   3.28674316e-02],
                        [  4.69970703e-02,   4.70275879e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  7.92236328e-02,   7.92541504e-02],
                        [  9.08203125e-02,   9.08508301e-02],
                        [  8.69140625e-02,   8.68835449e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [ -1.14440918e-02,  -1.14135742e-02],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -1.73858643e-01,  -1.73858643e-01],
                        [ -2.06176758e-01,  -2.06176758e-01],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -1.40563965e-01,  -1.40563965e-01],
                        [ -9.80834961e-02,  -9.80834961e-02],
                        [ -7.89794922e-02,  -7.89794922e-02],
                        [ -7.82470703e-02,  -7.82470703e-02],
                        [ -7.87048340e-02,  -7.87353516e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -7.50427246e-02,  -7.50732422e-02],
                        [ -8.57849121e-02,  -8.57849121e-02],
                        [ -8.98437500e-02,  -8.98132324e-02],
                        [ -8.53271484e-02,  -8.53271484e-02],
                        [ -7.49511719e-02,  -7.49816895e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -4.62036133e-02,  -4.61730957e-02],
                        [ -4.39147949e-02,  -4.39453125e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -6.67724609e-02,  -6.67419434e-02],
                        [ -7.36999512e-02,  -7.36694336e-02],
                        [ -7.47375488e-02,  -7.47680664e-02],
                        [ -6.68334961e-02,  -6.68029785e-02],
                        [ -4.31518555e-02,  -4.31213379e-02],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  3.90319824e-02,   3.90014648e-02],
                        [  7.41271973e-02,   7.41577148e-02],
                        [  9.52453613e-02,   9.52453613e-02],
                        [  1.02111816e-01,   1.02111816e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  8.79211426e-02,   8.78906250e-02],
                        [  9.50317383e-02,   9.50317383e-02],
                        [  1.00982666e-01,   1.00982666e-01],
                        [  9.87243652e-02,   9.86938477e-02],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  9.59777832e-02,   9.59777832e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.37084961e-01,   1.37084961e-01],
                        [  1.66900635e-01,   1.66900635e-01],
                        [  1.90917969e-01,   1.90917969e-01],
                        [  1.96960449e-01,   1.96960449e-01],
                        [  1.76239014e-01,   1.76239014e-01],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  5.69152832e-02,   5.69152832e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -1.42333984e-01,  -1.42333984e-01],
                        [ -2.45819092e-01,  -2.45819092e-01],
                        [ -3.11492920e-01,  -3.11492920e-01],
                        [ -3.17016602e-01,  -3.17016602e-01],
                        [ -2.71545410e-01,  -2.71545410e-01],
                        [ -2.08618164e-01,  -2.08618164e-01],
                        [ -1.59301758e-01,  -1.59271240e-01],
                        [ -1.30554199e-01,  -1.30554199e-01],
                        [ -1.10137939e-01,  -1.10168457e-01],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -6.75048828e-02,  -6.74743652e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -3.60107422e-02,  -3.59802246e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.74658203e-02,  -2.74353027e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.74243164e-02,  -4.74548340e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [  1.71508789e-02,   1.71203613e-02],
                        [  7.76062012e-02,   7.76367188e-02],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.78924561e-01,   1.78894043e-01],
                        [  2.04223633e-01,   2.04193115e-01],
                        [  2.13745117e-01,   2.13775635e-01],
                        [  2.08251953e-01,   2.08251953e-01],
                        [  1.91467285e-01,   1.91436768e-01],
                        [  1.67877197e-01,   1.67877197e-01],
                        [  1.39678955e-01,   1.39709473e-01],
                        [  1.10778809e-01,   1.10748291e-01],
                        [  8.62426758e-02,   8.62426758e-02],
                        [  6.73522949e-02,   6.73828125e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  4.44946289e-02,   4.44641113e-02],
                        [  3.68041992e-02,   3.68347168e-02],
                        [  2.62756348e-02,   2.63061523e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.58386230e-02,   1.58691406e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [ -3.35693359e-04,  -3.66210938e-04],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -8.57543945e-03,  -8.54492188e-03],
                        [ -5.67626953e-03,  -5.70678711e-03],
                        [ -3.17382812e-03,  -3.20434570e-03],
                        [ -1.49536133e-03,  -1.46484375e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  9.61303711e-03,   9.64355469e-03],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  2.56042480e-02,   2.56347656e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  5.01708984e-02,   5.02014160e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.12091064e-01,  -1.12091064e-01],
                        [ -1.83319092e-01,  -1.83319092e-01],
                        [ -2.13592529e-01,  -2.13592529e-01],
                        [ -1.95678711e-01,  -1.95678711e-01],
                        [ -1.46972656e-01,  -1.46972656e-01],
                        [ -9.90295410e-02,  -9.90295410e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -6.88781738e-02,  -6.88781738e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -7.93457031e-02,  -7.93762207e-02],
                        [ -8.17871094e-02,  -8.17871094e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -5.85021973e-02,  -5.84716797e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -7.40356445e-02,  -7.40661621e-02],
                        [ -7.76672363e-02,  -7.76672363e-02],
                        [ -7.35168457e-02,  -7.34863281e-02],
                        [ -6.42700195e-02,  -6.43005371e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -3.82080078e-02,  -3.81774902e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  5.97534180e-02,   5.97839355e-02],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  1.17034912e-01,   1.17004395e-01],
                        [  1.17645264e-01,   1.17645264e-01],
                        [  1.06292725e-01,   1.06323242e-01],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  8.94775391e-02,   8.94775391e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.17370605e-01,   1.17340088e-01],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  1.36291504e-01,   1.36322021e-01],
                        [  1.50695801e-01,   1.50695801e-01],
                        [  1.75231934e-01,   1.75231934e-01],
                        [  1.96502686e-01,   1.96533203e-01],
                        [  1.93878174e-01,   1.93908691e-01],
                        [  1.57440186e-01,   1.57409668e-01],
                        [  8.98742676e-02,   8.98742676e-02],
                        [ -1.52587891e-03,  -1.49536133e-03],
                        [ -1.06140137e-01,  -1.06170654e-01],
                        [ -2.08282471e-01,  -2.08282471e-01],
                        [ -2.87292480e-01,  -2.87292480e-01],
                        [ -3.18328857e-01,  -3.18298340e-01],
                        [ -2.84973145e-01,  -2.85003662e-01],
                        [ -2.06237793e-01,  -2.06237793e-01],
                        [ -1.33636475e-01,  -1.33605957e-01],
                        [ -1.02844238e-01,  -1.02874756e-01],
                        [ -1.01806641e-01,  -1.01806641e-01],
                        [ -9.95178223e-02,  -9.95178223e-02],
                        [ -8.80737305e-02,  -8.80432129e-02],
                        [ -8.04138184e-02,  -8.04138184e-02],
                        [ -8.35266113e-02,  -8.35266113e-02],
                        [ -8.93249512e-02,  -8.93249512e-02],
                        [ -8.50524902e-02,  -8.50524902e-02],
                        [ -6.49719238e-02,  -6.50024414e-02],
                        [ -3.72314453e-02,  -3.72009277e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -1.99279785e-02,  -1.99584961e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.50952148e-02,  -3.50646973e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [  3.01513672e-02,   3.01208496e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  1.49169922e-01,   1.49169922e-01],
                        [  1.97479248e-01,   1.97479248e-01],
                        [  2.19177246e-01,   2.19177246e-01],
                        [  2.06604004e-01,   2.06604004e-01],
                        [  1.69769287e-01,   1.69769287e-01],
                        [  1.33148193e-01,   1.33117676e-01],
                        [  1.14715576e-01,   1.14715576e-01],
                        [  1.11572266e-01,   1.11602783e-01],
                        [  1.10778809e-01,   1.10748291e-01],
                        [  1.05255127e-01,   1.05255127e-01],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  8.09631348e-02,   8.09936523e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.33447266e-02,   5.33447266e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.43530273e-02,  -2.43835449e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.86462402e-02,  -1.86767578e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  1.05285645e-02,   1.05590820e-02],
                        [  1.68457031e-02,   1.68151855e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.66931152e-02,   1.67236328e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.34277344e-02,   1.33972168e-02],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  5.23681641e-02,   5.23681641e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  8.39538574e-02,   8.39233398e-02],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -7.03735352e-02,  -7.03735352e-02],
                        [ -1.40197754e-01,  -1.40167236e-01],
                        [ -1.82617188e-01,  -1.82617188e-01],
                        [ -1.82556152e-01,  -1.82556152e-01],
                        [ -1.50329590e-01,  -1.50299072e-01],
                        [ -1.14349365e-01,  -1.14349365e-01],
                        [ -9.39941406e-02,  -9.40246582e-02],
                        [ -8.92944336e-02,  -8.92944336e-02],
                        [ -9.26818848e-02,  -9.26818848e-02],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -9.85107422e-02,  -9.85107422e-02],
                        [ -9.54284668e-02,  -9.54284668e-02],
                        [ -9.20715332e-02,  -9.20715332e-02],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -7.65686035e-02,  -7.65380859e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -4.49218750e-02,  -4.49523926e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -5.09643555e-02,  -5.09338379e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -2.62451172e-03,  -2.59399414e-03],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  1.25061035e-01,   1.25061035e-01],
                        [  1.34124756e-01,   1.34124756e-01],
                        [  1.35742188e-01,   1.35742188e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  1.12304688e-01,   1.12274170e-01],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  1.22100830e-01,   1.22131348e-01],
                        [  1.47033691e-01,   1.47033691e-01],
                        [  1.66931152e-01,   1.66931152e-01],
                        [  1.77032471e-01,   1.77032471e-01],
                        [  1.71936035e-01,   1.71936035e-01],
                        [  1.40380859e-01,   1.40380859e-01],
                        [  7.25708008e-02,   7.25708008e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -1.42730713e-01,  -1.42730713e-01],
                        [ -2.42858887e-01,  -2.42858887e-01],
                        [ -2.99560547e-01,  -2.99560547e-01],
                        [ -2.95166016e-01,  -2.95166016e-01],
                        [ -2.40631104e-01,  -2.40631104e-01],
                        [ -1.75872803e-01,  -1.75872803e-01],
                        [ -1.38336182e-01,  -1.38336182e-01],
                        [ -1.31225586e-01,  -1.31256104e-01],
                        [ -1.30249023e-01,  -1.30249023e-01],
                        [ -1.16851807e-01,  -1.16851807e-01],
                        [ -9.52148438e-02,  -9.52148438e-02],
                        [ -7.71789551e-02,  -7.71789551e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.80969238e-02,  -1.81274414e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  1.13220215e-01,   1.13220215e-01],
                        [  1.68457031e-01,   1.68457031e-01],
                        [  2.05535889e-01,   2.05505371e-01],
                        [  2.13775635e-01,   2.13775635e-01],
                        [  1.99096680e-01,   1.99096680e-01],
                        [  1.76574707e-01,   1.76574707e-01],
                        [  1.56433105e-01,   1.56402588e-01],
                        [  1.38641357e-01,   1.38641357e-01],
                        [  1.21765137e-01,   1.21765137e-01],
                        [  1.07299805e-01,   1.07269287e-01],
                        [  9.37805176e-02,   9.38110352e-02],
                        [  7.80029297e-02,   7.80334473e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  3.18603516e-02,   3.18908691e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [ -3.69262695e-03,  -3.72314453e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [  6.25610352e-03,   6.22558594e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  5.52368164e-03,   5.55419922e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -5.82885742e-03,  -5.85937500e-03],
                        [ -4.11987305e-03,  -4.15039062e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  2.38037109e-03,   2.34985352e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -6.56127930e-03,  -6.53076172e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  5.58471680e-03,   5.55419922e-03],
                        [  2.47497559e-02,   2.47802734e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  8.26721191e-02,   8.26416016e-02],
                        [  1.00524902e-01,   1.00555420e-01],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.01470947e-01,   1.01440430e-01],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  2.16369629e-02,   2.16674805e-02],
                        [ -5.77697754e-02,  -5.78002930e-02],
                        [ -1.37817383e-01,  -1.37847900e-01],
                        [ -1.91101074e-01,  -1.91070557e-01],
                        [ -2.04650879e-01,  -2.04650879e-01],
                        [ -1.84844971e-01,  -1.84875488e-01],
                        [ -1.49688721e-01,  -1.49688721e-01],
                        [ -1.17004395e-01,  -1.16973877e-01],
                        [ -9.61303711e-02,  -9.61303711e-02],
                        [ -8.66394043e-02,  -8.66699219e-02],
                        [ -8.34655762e-02,  -8.34655762e-02],
                        [ -8.29772949e-02,  -8.29772949e-02],
                        [ -8.50219727e-02,  -8.50524902e-02],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -8.59680176e-02,  -8.59680176e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -5.65490723e-02,  -5.65490723e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -6.65893555e-02,  -6.65893555e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  4.44641113e-02,   4.44946289e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  1.01898193e-01,   1.01898193e-01],
                        [  1.00128174e-01,   1.00158691e-01],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  9.59777832e-02,   9.60083008e-02],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  1.22100830e-01,   1.22070312e-01],
                        [  1.34552002e-01,   1.34582520e-01],
                        [  1.44927979e-01,   1.44927979e-01],
                        [  1.58111572e-01,   1.58111572e-01],
                        [  1.77032471e-01,   1.77032471e-01],
                        [  1.96472168e-01,   1.96472168e-01],
                        [  2.05902100e-01,   2.05902100e-01],
                        [  1.93023682e-01,   1.92993164e-01],
                        [  1.45751953e-01,   1.45751953e-01],
                        [  5.96923828e-02,   5.96923828e-02],
                        [ -5.33447266e-02,  -5.33752441e-02],
                        [ -1.68975830e-01,  -1.68975830e-01],
                        [ -2.62969971e-01,  -2.62939453e-01],
                        [ -3.17108154e-01,  -3.17108154e-01],
                        [ -3.18969727e-01,  -3.18969727e-01],
                        [ -2.68920898e-01,  -2.68920898e-01],
                        [ -1.90185547e-01,  -1.90155029e-01],
                        [ -1.21124268e-01,  -1.21124268e-01],
                        [ -8.82568359e-02,  -8.82568359e-02],
                        [ -8.62731934e-02,  -8.62731934e-02],
                        [ -9.04846191e-02,  -9.04846191e-02],
                        [ -8.63342285e-02,  -8.63647461e-02],
                        [ -7.76977539e-02,  -7.76977539e-02],
                        [ -7.09533691e-02,  -7.09228516e-02],
                        [ -6.57958984e-02,  -6.58264160e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -7.14721680e-02,  -7.14721680e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.67022705e-01,   1.67022705e-01],
                        [  1.91558838e-01,   1.91558838e-01],
                        [  1.89666748e-01,   1.89666748e-01],
                        [  1.67297363e-01,   1.67327881e-01],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  1.09436035e-01,   1.09466553e-01],
                        [  1.06994629e-01,   1.06964111e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  8.71887207e-02,   8.72192383e-02],
                        [  7.64465332e-02,   7.64160156e-02],
                        [  6.02416992e-02,   6.02111816e-02],
                        [  3.64990234e-02,   3.65295410e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  8.08715820e-03,   8.05664062e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -1.19323730e-02,  -1.19018555e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -2.19421387e-02,  -2.19726562e-02],
                        [ -8.14819336e-03,  -8.17871094e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  4.91333008e-03,   4.94384766e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  7.93457031e-04,   7.62939453e-04],
                        [  9.39941406e-03,   9.42993164e-03],
                        [  2.89916992e-02,   2.90222168e-02],
                        [  5.23376465e-02,   5.23071289e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  8.55407715e-02,   8.55712891e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  7.09228516e-02,   7.09533691e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -1.22344971e-01,  -1.22344971e-01],
                        [ -1.74499512e-01,  -1.74468994e-01],
                        [ -1.89849854e-01,  -1.89849854e-01],
                        [ -1.68823242e-01,  -1.68823242e-01],
                        [ -1.29364014e-01,  -1.29364014e-01],
                        [ -9.63134766e-02,  -9.63134766e-02],
                        [ -8.38012695e-02,  -8.38012695e-02],
                        [ -8.81042480e-02,  -8.81042480e-02],
                        [ -9.61914062e-02,  -9.61914062e-02],
                        [ -9.77478027e-02,  -9.77478027e-02],
                        [ -9.20104980e-02,  -9.20410156e-02],
                        [ -8.69140625e-02,  -8.68835449e-02],
                        [ -8.79821777e-02,  -8.79516602e-02],
                        [ -8.75244141e-02,  -8.75244141e-02],
                        [ -7.46154785e-02,  -7.46154785e-02],
                        [ -5.54809570e-02,  -5.54504395e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -5.32226562e-02,  -5.32531738e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -6.49414062e-02,  -6.49108887e-02],
                        [ -5.89904785e-02,  -5.90209961e-02],
                        [ -4.21447754e-02,  -4.21752930e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [  2.52685547e-02,   2.52990723e-02],
                        [  6.30493164e-02,   6.30187988e-02],
                        [  9.45129395e-02,   9.45129395e-02],
                        [  1.12762451e-01,   1.12792969e-01],
                        [  1.12792969e-01,   1.12792969e-01],
                        [  1.00982666e-01,   1.00982666e-01],
                        [  9.17968750e-02,   9.18273926e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  1.04461670e-01,   1.04431152e-01],
                        [  1.17858887e-01,   1.17858887e-01],
                        [  1.32995605e-01,   1.33026123e-01],
                        [  1.53381348e-01,   1.53381348e-01],
                        [  1.77917480e-01,   1.77886963e-01],
                        [  1.97875977e-01,   1.97906494e-01],
                        [  2.04315186e-01,   2.04345703e-01],
                        [  1.92749023e-01,   1.92718506e-01],
                        [  1.58569336e-01,   1.58569336e-01],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  4.42504883e-03,   4.42504883e-03],
                        [ -1.03851318e-01,  -1.03851318e-01],
                        [ -2.10144043e-01,  -2.10144043e-01],
                        [ -2.88909912e-01,  -2.88909912e-01],
                        [ -3.14300537e-01,  -3.14300537e-01],
                        [ -2.79724121e-01,  -2.79724121e-01],
                        [ -2.09777832e-01,  -2.09777832e-01],
                        [ -1.44683838e-01,  -1.44714355e-01],
                        [ -1.10412598e-01,  -1.10412598e-01],
                        [ -1.02294922e-01,  -1.02294922e-01],
                        [ -9.80529785e-02,  -9.80529785e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -6.02722168e-02,  -6.02416992e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.05578613e-02,  -4.05883789e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  1.02478027e-01,   1.02478027e-01],
                        [  1.56738281e-01,   1.56768799e-01],
                        [  1.94030762e-01,   1.94030762e-01],
                        [  2.02087402e-01,   2.02056885e-01],
                        [  1.83471680e-01,   1.83502197e-01],
                        [  1.53808594e-01,   1.53839111e-01],
                        [  1.29760742e-01,   1.29760742e-01],
                        [  1.18591309e-01,   1.18591309e-01],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.03515625e-01,   1.03485107e-01],
                        [  9.17968750e-02,   9.17968750e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  8.92028809e-02,   8.92028809e-02],
                        [  8.36791992e-02,   8.36486816e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  3.48205566e-02,   3.48510742e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -7.32421875e-03,  -7.35473633e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -3.69262695e-03,  -3.66210938e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  6.53381348e-02,   6.53686523e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  1.02172852e-01,   1.02142334e-01],
                        [  1.03790283e-01,   1.03790283e-01],
                        [  9.28649902e-02,   9.28955078e-02],
                        [  6.27136230e-02,   6.27136230e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -1.41326904e-01,  -1.41326904e-01],
                        [ -1.84936523e-01,  -1.84967041e-01],
                        [ -1.85943604e-01,  -1.85943604e-01],
                        [ -1.60003662e-01,  -1.60003662e-01],
                        [ -1.33483887e-01,  -1.33483887e-01],
                        [ -1.21429443e-01,  -1.21429443e-01],
                        [ -1.21978760e-01,  -1.21978760e-01],
                        [ -1.23443604e-01,  -1.23443604e-01],
                        [ -1.15173340e-01,  -1.15173340e-01],
                        [ -9.78698730e-02,  -9.78698730e-02],
                        [ -8.43811035e-02,  -8.43811035e-02],
                        [ -8.35266113e-02,  -8.35266113e-02],
                        [ -8.69140625e-02,  -8.69140625e-02],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -6.95800781e-02,  -6.95495605e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -2.91442871e-02,  -2.91137695e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  5.15441895e-02,   5.15136719e-02],
                        [  9.04235840e-02,   9.04235840e-02],
                        [  1.08520508e-01,   1.08520508e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  1.07574463e-01,   1.07574463e-01],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  1.20330811e-01,   1.20330811e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.45996094e-01,   1.45996094e-01],
                        [  1.64306641e-01,   1.64306641e-01],
                        [  1.89605713e-01,   1.89605713e-01],
                        [  2.11914062e-01,   2.11944580e-01],
                        [  2.14111328e-01,   2.14111328e-01],
                        [  1.84448242e-01,   1.84448242e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  2.72827148e-02,   2.72827148e-02],
                        [ -8.25195312e-02,  -8.25195312e-02],
                        [ -1.90063477e-01,  -1.90063477e-01],
                        [ -2.73834229e-01,  -2.73803711e-01],
                        [ -3.11431885e-01,  -3.11431885e-01],
                        [ -2.91046143e-01,  -2.91046143e-01],
                        [ -2.28820801e-01,  -2.28820801e-01],
                        [ -1.64581299e-01,  -1.64581299e-01],
                        [ -1.29150391e-01,  -1.29150391e-01],
                        [ -1.19842529e-01,  -1.19842529e-01],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -9.72595215e-02,  -9.72290039e-02],
                        [ -7.69958496e-02,  -7.69958496e-02],
                        [ -6.65283203e-02,  -6.65588379e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -8.19396973e-02,  -8.19396973e-02],
                        [ -8.35571289e-02,  -8.35876465e-02],
                        [ -7.40661621e-02,  -7.40661621e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  1.35650635e-01,   1.35650635e-01],
                        [  1.90673828e-01,   1.90673828e-01],
                        [  2.17254639e-01,   2.17254639e-01],
                        [  2.08892822e-01,   2.08892822e-01],
                        [  1.78741455e-01,   1.78741455e-01],
                        [  1.48406982e-01,   1.48406982e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  9.25903320e-02,   9.25903320e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  7.90710449e-02,   7.90710449e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  3.20129395e-02,   3.20434570e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [ -1.23596191e-02,  -1.23901367e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.96020508e-02,  -2.95715332e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  7.55615234e-02,   7.55310059e-02],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.10839844e-01,   1.10809326e-01],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  7.93762207e-02,   7.93762207e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [ -3.20129395e-02,  -3.20434570e-02],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -1.67144775e-01,  -1.67144775e-01],
                        [ -1.94763184e-01,  -1.94763184e-01],
                        [ -1.87316895e-01,  -1.87316895e-01],
                        [ -1.59423828e-01,  -1.59423828e-01],
                        [ -1.31439209e-01,  -1.31439209e-01],
                        [ -1.13342285e-01,  -1.13342285e-01],
                        [ -1.03576660e-01,  -1.03576660e-01],
                        [ -1.00036621e-01,  -1.00036621e-01],
                        [ -1.03881836e-01,  -1.03881836e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -1.23352051e-01,  -1.23352051e-01],
                        [ -1.26586914e-01,  -1.26586914e-01],
                        [ -1.17645264e-01,  -1.17645264e-01],
                        [ -9.45434570e-02,  -9.45434570e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  8.49609375e-02,   8.49609375e-02],
                        [  1.13769531e-01,   1.13769531e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.23626709e-01,   1.23626709e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.30310059e-01,   1.30279541e-01],
                        [  1.40533447e-01,   1.40502930e-01],
                        [  1.57196045e-01,   1.57196045e-01],
                        [  1.78070068e-01,   1.78070068e-01],
                        [  1.98760986e-01,   1.98760986e-01],
                        [  2.12493896e-01,   2.12493896e-01],
                        [  2.07916260e-01,   2.07916260e-01],
                        [  1.72912598e-01,   1.72912598e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -1.02355957e-01,  -1.02355957e-01],
                        [ -2.07153320e-01,  -2.07153320e-01],
                        [ -2.82745361e-01,  -2.82745361e-01],
                        [ -3.07189941e-01,  -3.07189941e-01],
                        [ -2.76519775e-01,  -2.76519775e-01],
                        [ -2.13073730e-01,  -2.13073730e-01],
                        [ -1.52618408e-01,  -1.52618408e-01],
                        [ -1.18499756e-01,  -1.18499756e-01],
                        [ -1.09558105e-01,  -1.09558105e-01],
                        [ -1.11541748e-01,  -1.11572266e-01],
                        [ -1.14166260e-01,  -1.14166260e-01],
                        [ -1.14776611e-01,  -1.14776611e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -9.98535156e-02,  -9.98535156e-02],
                        [ -8.16345215e-02,  -8.16345215e-02],
                        [ -6.49108887e-02,  -6.49108887e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  1.13433838e-01,   1.13433838e-01],
                        [  1.76483154e-01,   1.76483154e-01],
                        [  2.19757080e-01,   2.19757080e-01],
                        [  2.29522705e-01,   2.29522705e-01],
                        [  2.10235596e-01,   2.10235596e-01],
                        [  1.78192139e-01,   1.78192139e-01],
                        [  1.49353027e-01,   1.49322510e-01],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.22039795e-01,   1.22039795e-01],
                        [  1.13067627e-01,   1.13037109e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  7.72705078e-02,   7.72705078e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.09033203e-02,   5.09033203e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  4.94384766e-03,   4.97436523e-03],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -1.79443359e-02,  -1.79138184e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -2.23693848e-02,  -2.23388672e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  4.05883789e-03,   4.02832031e-03],
                        [  4.57763672e-03,   4.60815430e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  7.73925781e-02,   7.73925781e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  9.63745117e-02,   9.63745117e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -1.31439209e-01,  -1.31439209e-01],
                        [ -1.82189941e-01,  -1.82189941e-01],
                        [ -1.97601318e-01,  -1.97601318e-01],
                        [ -1.82525635e-01,  -1.82495117e-01],
                        [ -1.58508301e-01,  -1.58508301e-01],
                        [ -1.43493652e-01,  -1.43493652e-01],
                        [ -1.37329102e-01,  -1.37329102e-01],
                        [ -1.28723145e-01,  -1.28723145e-01],
                        [ -1.14044189e-01,  -1.14044189e-01],
                        [ -1.03332520e-01,  -1.03332520e-01],
                        [ -1.04827881e-01,  -1.04827881e-01],
                        [ -1.11450195e-01,  -1.11419678e-01],
                        [ -1.08795166e-01,  -1.08795166e-01],
                        [ -9.17053223e-02,  -9.17053223e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.44641113e-02,  -4.44946289e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.52880859e-02,  -4.53186035e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -1.19323730e-02,  -1.19018555e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  7.67822266e-02,   7.67517090e-02],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  1.01287842e-01,   1.01287842e-01],
                        [  1.09558105e-01,   1.09558105e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.42974854e-01,   1.42974854e-01],
                        [  1.58386230e-01,   1.58386230e-01],
                        [  1.76757812e-01,   1.76757812e-01],
                        [  2.03094482e-01,   2.03094482e-01],
                        [  2.25036621e-01,   2.25036621e-01],
                        [  2.18933105e-01,   2.18933105e-01],
                        [  1.75384521e-01,   1.75384521e-01],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.39465332e-02,   1.39465332e-02],
                        [ -9.18579102e-02,  -9.18579102e-02],
                        [ -2.02392578e-01,  -2.02392578e-01],
                        [ -2.89642334e-01,  -2.89642334e-01],
                        [ -3.22601318e-01,  -3.22601318e-01],
                        [ -2.91320801e-01,  -2.91320801e-01],
                        [ -2.20214844e-01,  -2.20214844e-01],
                        [ -1.54266357e-01,  -1.54266357e-01],
                        [ -1.22161865e-01,  -1.22161865e-01],
                        [ -1.15905762e-01,  -1.15905762e-01],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -1.08581543e-01,  -1.08612061e-01],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -1.07391357e-01,  -1.07391357e-01],
                        [ -1.06262207e-01,  -1.06292725e-01],
                        [ -9.89379883e-02,  -9.89379883e-02],
                        [ -8.64257812e-02,  -8.64257812e-02],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  1.43615723e-01,   1.43615723e-01],
                        [  2.00653076e-01,   2.00653076e-01],
                        [  2.34161377e-01,   2.34161377e-01],
                        [  2.22320557e-01,   2.22320557e-01],
                        [  1.79321289e-01,   1.79321289e-01],
                        [  1.43127441e-01,   1.43127441e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.33697510e-01,   1.33697510e-01],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.17309570e-01,   1.17279053e-01],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  8.73413086e-02,   8.73413086e-02],
                        [  7.49511719e-02,   7.49206543e-02],
                        [  6.85119629e-02,   6.85119629e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  2.10571289e-03,   2.13623047e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -2.55432129e-02,  -2.55737305e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  2.83508301e-02,   2.83813477e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  2.74353027e-02,   2.74658203e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  5.03540039e-02,   5.03540039e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -1.17401123e-01,  -1.17401123e-01],
                        [ -1.92138672e-01,  -1.92138672e-01],
                        [ -2.25585938e-01,  -2.25585938e-01],
                        [ -2.08801270e-01,  -2.08770752e-01],
                        [ -1.65893555e-01,  -1.65893555e-01],
                        [ -1.31927490e-01,  -1.31927490e-01],
                        [ -1.19689941e-01,  -1.19659424e-01],
                        [ -1.19171143e-01,  -1.19171143e-01],
                        [ -1.18988037e-01,  -1.18988037e-01],
                        [ -1.16882324e-01,  -1.16882324e-01],
                        [ -1.14746094e-01,  -1.14746094e-01],
                        [ -1.11511230e-01,  -1.11511230e-01],
                        [ -1.03637695e-01,  -1.03637695e-01],
                        [ -9.09729004e-02,  -9.09729004e-02],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -7.93151855e-02,  -7.93151855e-02],
                        [ -8.45031738e-02,  -8.45031738e-02],
                        [ -8.35266113e-02,  -8.35266113e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  8.86535645e-02,   8.86230469e-02],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.19476318e-01,   1.19506836e-01],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  1.05377197e-01,   1.05377197e-01],
                        [  1.00036621e-01,   1.00036621e-01],
                        [  1.07482910e-01,   1.07482910e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.59362793e-01,   1.59362793e-01],
                        [  1.77642822e-01,   1.77642822e-01],
                        [  1.90155029e-01,   1.90155029e-01],
                        [  2.06756592e-01,   2.06756592e-01],
                        [  2.18139648e-01,   2.18139648e-01],
                        [  2.04132080e-01,   2.04132080e-01],
                        [  1.59667969e-01,   1.59667969e-01],
                        [  9.06677246e-02,   9.06677246e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.18103027e-01,  -1.18103027e-01],
                        [ -2.30133057e-01,  -2.30133057e-01],
                        [ -3.04351807e-01,  -3.04351807e-01],
                        [ -3.18542480e-01,  -3.18542480e-01],
                        [ -2.76489258e-01,  -2.76489258e-01],
                        [ -2.08465576e-01,  -2.08465576e-01],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.31469727e-01,  -1.31469727e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -1.23931885e-01,  -1.23931885e-01],
                        [ -1.13555908e-01,  -1.13525391e-01],
                        [ -1.05255127e-01,  -1.05255127e-01],
                        [ -1.01226807e-01,  -1.01226807e-01],
                        [ -9.78393555e-02,  -9.78088379e-02],
                        [ -9.30175781e-02,  -9.30175781e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  8.00781250e-02,   8.00781250e-02],
                        [  1.32232666e-01,   1.32232666e-01],
                        [  1.77917480e-01,   1.77917480e-01],
                        [  2.08892822e-01,   2.08892822e-01],
                        [  2.15789795e-01,   2.15759277e-01],
                        [  1.97418213e-01,   1.97418213e-01],
                        [  1.64093018e-01,   1.64093018e-01],
                        [  1.31713867e-01,   1.31713867e-01],
                        [  1.12121582e-01,   1.12152100e-01],
                        [  1.07116699e-01,   1.07116699e-01],
                        [  1.08825684e-01,   1.08825684e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  9.79919434e-02,   9.79614258e-02],
                        [  8.64868164e-02,   8.65173340e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  6.02416992e-02,   6.02416992e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  1.03759766e-01,   1.03790283e-01],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -1.42944336e-01,  -1.42944336e-01],
                        [ -2.05322266e-01,  -2.05322266e-01],
                        [ -2.20428467e-01,  -2.20428467e-01],
                        [ -1.94396973e-01,  -1.94396973e-01],
                        [ -1.51916504e-01,  -1.51916504e-01],
                        [ -1.17645264e-01,  -1.17645264e-01],
                        [ -1.03942871e-01,  -1.03942871e-01],
                        [ -1.07940674e-01,  -1.07940674e-01],
                        [ -1.15631104e-01,  -1.15631104e-01],
                        [ -1.14715576e-01,  -1.14715576e-01],
                        [ -1.06018066e-01,  -1.06018066e-01],
                        [ -9.71984863e-02,  -9.71984863e-02],
                        [ -8.92944336e-02,  -8.92944336e-02],
                        [ -8.06884766e-02,  -8.06884766e-02],
                        [ -7.66296387e-02,  -7.66601562e-02],
                        [ -7.99255371e-02,  -7.99255371e-02],
                        [ -8.04443359e-02,  -8.04443359e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.13555908e-01,   1.13555908e-01],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  1.36169434e-01,   1.36169434e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.71936035e-01,   1.71936035e-01],
                        [  1.87683105e-01,   1.87683105e-01],
                        [  1.98364258e-01,   1.98364258e-01],
                        [  1.97631836e-01,   1.97631836e-01],
                        [  1.76361084e-01,   1.76361084e-01],
                        [  1.23596191e-01,   1.23596191e-01],
                        [  3.57971191e-02,   3.57666016e-02],
                        [ -7.57141113e-02,  -7.57141113e-02],
                        [ -1.88934326e-01,  -1.88934326e-01],
                        [ -2.79479980e-01,  -2.79479980e-01],
                        [ -3.24462891e-01,  -3.24462891e-01],
                        [ -3.09326172e-01,  -3.09326172e-01],
                        [ -2.44415283e-01,  -2.44415283e-01],
                        [ -1.69555664e-01,  -1.69555664e-01],
                        [ -1.22985840e-01,  -1.22985840e-01],
                        [ -1.07299805e-01,  -1.07299805e-01],
                        [ -1.01806641e-01,  -1.01806641e-01],
                        [ -9.67712402e-02,  -9.68017578e-02],
                        [ -9.63134766e-02,  -9.63134766e-02],
                        [ -9.96093750e-02,  -9.96093750e-02],
                        [ -9.93652344e-02,  -9.93652344e-02],
                        [ -9.14306641e-02,  -9.14306641e-02],
                        [ -7.52258301e-02,  -7.52258301e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  1.29516602e-01,   1.29516602e-01],
                        [  1.88934326e-01,   1.88934326e-01],
                        [  2.22167969e-01,   2.22167969e-01],
                        [  2.17651367e-01,   2.17651367e-01],
                        [  1.84051514e-01,   1.84051514e-01],
                        [  1.43096924e-01,   1.43096924e-01],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  1.02630615e-01,   1.02630615e-01],
                        [  1.04125977e-01,   1.04125977e-01],
                        [  1.07360840e-01,   1.07360840e-01],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.22070312e-04,  -9.15527344e-05],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.48913574e-02,   4.48913574e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  8.90808105e-02,   8.90808105e-02],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  4.69970703e-03,   4.66918945e-03],
                        [ -8.02612305e-02,  -8.02612305e-02],
                        [ -1.63360596e-01,  -1.63360596e-01],
                        [ -2.13012695e-01,  -2.13012695e-01],
                        [ -2.11944580e-01,  -2.11944580e-01],
                        [ -1.72180176e-01,  -1.72180176e-01],
                        [ -1.23840332e-01,  -1.23840332e-01],
                        [ -9.10644531e-02,  -9.10644531e-02],
                        [ -8.23669434e-02,  -8.23669434e-02],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -1.08551025e-01,  -1.08551025e-01],
                        [ -1.13037109e-01,  -1.13037109e-01],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -9.98229980e-02,  -9.98229980e-02],
                        [ -9.57641602e-02,  -9.57641602e-02],
                        [ -8.51745605e-02,  -8.51745605e-02],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -3.24096680e-02,  -3.24401855e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  9.48791504e-02,   9.48791504e-02],
                        [  1.10046387e-01,   1.10046387e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  1.12365723e-01,   1.12365723e-01],
                        [  1.27380371e-01,   1.27380371e-01],
                        [  1.38610840e-01,   1.38610840e-01],
                        [  1.49261475e-01,   1.49261475e-01],
                        [  1.66473389e-01,   1.66473389e-01],
                        [  1.86553955e-01,   1.86523438e-01],
                        [  1.97357178e-01,   1.97357178e-01],
                        [  1.88232422e-01,   1.88232422e-01],
                        [  1.50451660e-01,   1.50451660e-01],
                        [  7.59582520e-02,   7.59582520e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [ -1.60552979e-01,  -1.60552979e-01],
                        [ -2.70477295e-01,  -2.70446777e-01],
                        [ -3.28887939e-01,  -3.28887939e-01],
                        [ -3.16864014e-01,  -3.16864014e-01],
                        [ -2.48718262e-01,  -2.48718262e-01],
                        [ -1.68884277e-01,  -1.68884277e-01],
                        [ -1.19689941e-01,  -1.19689941e-01],
                        [ -1.09771729e-01,  -1.09771729e-01],
                        [ -1.16333008e-01,  -1.16363525e-01],
                        [ -1.17706299e-01,  -1.17706299e-01],
                        [ -1.14532471e-01,  -1.14501953e-01],
                        [ -1.14898682e-01,  -1.14898682e-01],
                        [ -1.14746094e-01,  -1.14746094e-01],
                        [ -1.05834961e-01,  -1.05834961e-01],
                        [ -8.95996094e-02,  -8.96301270e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -3.74450684e-02,  -3.74145508e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  1.35070801e-01,   1.35070801e-01],
                        [  1.86309814e-01,   1.86279297e-01],
                        [  2.15026855e-01,   2.15026855e-01],
                        [  2.12554932e-01,   2.12554932e-01],
                        [  1.84600830e-01,   1.84570312e-01],
                        [  1.49841309e-01,   1.49841309e-01],
                        [  1.25488281e-01,   1.25488281e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  8.05053711e-02,   8.05053711e-02],
                        [  6.52160645e-02,   6.52160645e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  5.87463379e-02,   5.87158203e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  7.06481934e-02,   7.06481934e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -9.40856934e-02,  -9.40856934e-02],
                        [ -1.88323975e-01,  -1.88323975e-01],
                        [ -2.42736816e-01,  -2.42736816e-01],
                        [ -2.40509033e-01,  -2.40539551e-01],
                        [ -1.93206787e-01,  -1.93206787e-01],
                        [ -1.37054443e-01,  -1.37054443e-01],
                        [ -1.03363037e-01,  -1.03363037e-01],
                        [ -9.41162109e-02,  -9.41162109e-02],
                        [ -9.28344727e-02,  -9.28344727e-02],
                        [ -8.94165039e-02,  -8.94165039e-02],
                        [ -8.69445801e-02,  -8.69445801e-02],
                        [ -9.14306641e-02,  -9.14306641e-02],
                        [ -1.02416992e-01,  -1.02416992e-01],
                        [ -1.11968994e-01,  -1.11968994e-01],
                        [ -1.12487793e-01,  -1.12487793e-01],
                        [ -1.05133057e-01,  -1.05133057e-01],
                        [ -9.46044922e-02,  -9.46044922e-02],
                        [ -7.70568848e-02,  -7.70568848e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  5.56640625e-02,   5.56640625e-02],
                        [  1.02539062e-01,   1.02539062e-01],
                        [  1.32659912e-01,   1.32659912e-01],
                        [  1.37298584e-01,   1.37298584e-01],
                        [  1.19628906e-01,   1.19659424e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  8.18176270e-02,   8.18176270e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  1.00097656e-01,   1.00097656e-01],
                        [  1.22619629e-01,   1.22619629e-01],
                        [  1.44744873e-01,   1.44744873e-01],
                        [  1.67846680e-01,   1.67846680e-01],
                        [  1.97509766e-01,   1.97509766e-01],
                        [  2.25860596e-01,   2.25860596e-01],
                        [  2.30072021e-01,   2.30072021e-01],
                        [  1.92504883e-01,   1.92504883e-01],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -1.26190186e-01,  -1.26190186e-01],
                        [ -2.49114990e-01,  -2.49114990e-01],
                        [ -3.30932617e-01,  -3.30932617e-01],
                        [ -3.43078613e-01,  -3.43048096e-01],
                        [ -2.89550781e-01,  -2.89550781e-01],
                        [ -2.08770752e-01,  -2.08770752e-01],
                        [ -1.45172119e-01,  -1.45141602e-01],
                        [ -1.16760254e-01,  -1.16760254e-01],
                        [ -1.10687256e-01,  -1.10687256e-01],
                        [ -1.07879639e-01,  -1.07879639e-01],
                        [ -1.04187012e-01,  -1.04187012e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -1.11999512e-01,  -1.11999512e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -1.19537354e-01,  -1.19537354e-01],
                        [ -1.06811523e-01,  -1.06811523e-01],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  1.60186768e-01,   1.60186768e-01],
                        [  2.22900391e-01,   2.22900391e-01],
                        [  2.47528076e-01,   2.47528076e-01],
                        [  2.31292725e-01,   2.31292725e-01],
                        [  1.91314697e-01,   1.91314697e-01],
                        [  1.52008057e-01,   1.52008057e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  1.13433838e-01,   1.13433838e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  9.70458984e-02,   9.70153809e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  8.19396973e-02,   8.19396973e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  9.27734375e-03,   9.24682617e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -2.09350586e-02,  -2.09655762e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.13525391e-02,  -1.13220215e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  8.34960938e-02,   8.34960938e-02],
                        [  1.03607178e-01,   1.03576660e-01],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -1.32385254e-01,  -1.32385254e-01],
                        [ -1.94824219e-01,  -1.94824219e-01],
                        [ -2.19177246e-01,  -2.19177246e-01],
                        [ -2.04498291e-01,  -2.04498291e-01],
                        [ -1.70135498e-01,  -1.70135498e-01],
                        [ -1.40930176e-01,  -1.40930176e-01],
                        [ -1.24206543e-01,  -1.24206543e-01],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -9.87854004e-02,  -9.87854004e-02],
                        [ -9.29260254e-02,  -9.29260254e-02],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -9.15527344e-02,  -9.15527344e-02],
                        [ -8.70056152e-02,  -8.70056152e-02],
                        [ -8.40759277e-02,  -8.40759277e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -8.26416016e-02,  -8.26416016e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  1.38488770e-01,   1.38488770e-01],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.19293213e-01,   1.19293213e-01],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  7.83081055e-02,   7.83386230e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  9.53063965e-02,   9.53063965e-02],
                        [  1.15051270e-01,   1.15051270e-01],
                        [  1.40563965e-01,   1.40563965e-01],
                        [  1.75201416e-01,   1.75201416e-01],
                        [  2.11822510e-01,   2.11822510e-01],
                        [  2.30957031e-01,   2.30957031e-01],
                        [  2.14324951e-01,   2.14324951e-01],
                        [  1.55975342e-01,   1.55975342e-01],
                        [  6.24389648e-02,   6.24389648e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -1.66290283e-01,  -1.66290283e-01],
                        [ -2.59124756e-01,  -2.59124756e-01],
                        [ -3.04595947e-01,  -3.04595947e-01],
                        [ -2.87017822e-01,  -2.87017822e-01],
                        [ -2.21496582e-01,  -2.21496582e-01],
                        [ -1.54357910e-01,  -1.54357910e-01],
                        [ -1.24298096e-01,  -1.24298096e-01],
                        [ -1.28692627e-01,  -1.28692627e-01],
                        [ -1.39709473e-01,  -1.39678955e-01],
                        [ -1.40502930e-01,  -1.40502930e-01],
                        [ -1.33422852e-01,  -1.33422852e-01],
                        [ -1.26770020e-01,  -1.26770020e-01],
                        [ -1.24481201e-01,  -1.24481201e-01],
                        [ -1.20208740e-01,  -1.20208740e-01],
                        [ -1.00372314e-01,  -1.00372314e-01],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  1.40777588e-01,   1.40777588e-01],
                        [  1.93847656e-01,   1.93847656e-01],
                        [  2.18566895e-01,   2.18566895e-01],
                        [  2.14019775e-01,   2.14019775e-01],
                        [  1.90032959e-01,   1.90032959e-01],
                        [  1.60980225e-01,   1.60980225e-01],
                        [  1.39129639e-01,   1.39099121e-01],
                        [  1.24908447e-01,   1.24938965e-01],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.00616455e-01,   1.00616455e-01],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  9.20104980e-02,   9.20410156e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -1.17797852e-02,  -1.17492676e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [ -1.43432617e-03,  -1.46484375e-03],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  5.18798828e-02,   5.19104004e-02],
                        [  7.29370117e-02,   7.29370117e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  5.00183105e-02,   5.00183105e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -8.92028809e-02,  -8.92028809e-02],
                        [ -1.64825439e-01,  -1.64825439e-01],
                        [ -2.10052490e-01,  -2.10052490e-01],
                        [ -2.14172363e-01,  -2.14172363e-01],
                        [ -1.88262939e-01,  -1.88262939e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -1.15264893e-01,  -1.15264893e-01],
                        [ -1.06292725e-01,  -1.06292725e-01],
                        [ -9.60693359e-02,  -9.60693359e-02],
                        [ -8.49914551e-02,  -8.49914551e-02],
                        [ -7.90710449e-02,  -7.90710449e-02],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -9.20410156e-02,  -9.20410156e-02],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -9.32312012e-02,  -9.32312012e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  1.25000000e-01,   1.25000000e-01],
                        [  9.94262695e-02,   9.94262695e-02],
                        [  8.21228027e-02,   8.21228027e-02],
                        [  8.35876465e-02,   8.35876465e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.34307861e-01,   1.34307861e-01],
                        [  1.65313721e-01,   1.65313721e-01],
                        [  1.88629150e-01,   1.88659668e-01],
                        [  2.01416016e-01,   2.01385498e-01],
                        [  1.99340820e-01,   1.99340820e-01],
                        [  1.72180176e-01,   1.72210693e-01],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  1.15356445e-02,   1.15356445e-02],
                        [ -1.09497070e-01,  -1.09497070e-01],
                        [ -2.25006104e-01,  -2.25006104e-01],
                        [ -3.00689697e-01,  -3.00689697e-01],
                        [ -3.14392090e-01,  -3.14392090e-01],
                        [ -2.72338867e-01,  -2.72338867e-01],
                        [ -2.08404541e-01,  -2.08404541e-01],
                        [ -1.58843994e-01,  -1.58843994e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -1.29394531e-01,  -1.29394531e-01],
                        [ -1.28540039e-01,  -1.28540039e-01],
                        [ -1.30004883e-01,  -1.30004883e-01],
                        [ -1.32568359e-01,  -1.32537842e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -1.20422363e-01,  -1.20422363e-01],
                        [ -9.50012207e-02,  -9.49707031e-02],
                        [ -5.36499023e-02,  -5.36804199e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  1.51031494e-01,   1.51031494e-01],
                        [  2.08435059e-01,   2.08435059e-01],
                        [  2.29339600e-01,   2.29339600e-01],
                        [  2.11395264e-01,   2.11395264e-01],
                        [  1.71112061e-01,   1.71112061e-01],
                        [  1.32934570e-01,   1.32934570e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.16546631e-01,   1.16546631e-01],
                        [  1.25762939e-01,   1.25762939e-01],
                        [  1.28021240e-01,   1.28051758e-01],
                        [  1.20361328e-01,   1.20361328e-01],
                        [  1.09191895e-01,   1.09191895e-01],
                        [  9.84802246e-02,   9.84802246e-02],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  6.57043457e-02,   6.57043457e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  3.23486328e-02,   3.23791504e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.66931152e-02,   1.66625977e-02],
                        [  1.87988281e-02,   1.87683105e-02],
                        [  1.22375488e-02,   1.22680664e-02],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -3.72314453e-03,  -3.69262695e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  8.01086426e-02,   8.01086426e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -1.13067627e-01,  -1.13067627e-01],
                        [ -1.80786133e-01,  -1.80786133e-01],
                        [ -2.11120605e-01,  -2.11120605e-01],
                        [ -2.01293945e-01,  -2.01263428e-01],
                        [ -1.72149658e-01,  -1.72149658e-01],
                        [ -1.47094727e-01,  -1.47125244e-01],
                        [ -1.34582520e-01,  -1.34582520e-01],
                        [ -1.28662109e-01,  -1.28662109e-01],
                        [ -1.21276855e-01,  -1.21276855e-01],
                        [ -1.10015869e-01,  -1.10015869e-01],
                        [ -9.75646973e-02,  -9.75646973e-02],
                        [ -9.05761719e-02,  -9.05761719e-02],
                        [ -9.45434570e-02,  -9.45129395e-02],
                        [ -1.03210449e-01,  -1.03210449e-01],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -8.43505859e-02,  -8.43505859e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  7.36083984e-02,   7.36083984e-02],
                        [  1.14044189e-01,   1.14044189e-01],
                        [  1.32202148e-01,   1.32171631e-01],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.00891113e-01,   1.00921631e-01],
                        [  8.58459473e-02,   8.58459473e-02],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  1.12762451e-01,   1.12792969e-01],
                        [  1.40747070e-01,   1.40747070e-01],
                        [  1.70593262e-01,   1.70593262e-01],
                        [  1.96472168e-01,   1.96472168e-01],
                        [  2.10601807e-01,   2.10601807e-01],
                        [  2.08160400e-01,   2.08160400e-01],
                        [  1.81427002e-01,   1.81396484e-01],
                        [  1.16424561e-01,   1.16424561e-01],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -1.20300293e-01,  -1.20300293e-01],
                        [ -2.37121582e-01,  -2.37121582e-01],
                        [ -3.09936523e-01,  -3.09936523e-01],
                        [ -3.20343018e-01,  -3.20373535e-01],
                        [ -2.74627686e-01,  -2.74627686e-01],
                        [ -2.08435059e-01,  -2.08435059e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.44500732e-01,  -1.44500732e-01],
                        [ -1.40289307e-01,  -1.40289307e-01],
                        [ -1.35406494e-01,  -1.35406494e-01],
                        [ -1.32080078e-01,  -1.32080078e-01],
                        [ -1.32995605e-01,  -1.32995605e-01],
                        [ -1.29089355e-01,  -1.29089355e-01],
                        [ -1.10565186e-01,  -1.10565186e-01],
                        [ -7.85827637e-02,  -7.85827637e-02],
                        [ -3.52172852e-02,  -3.52478027e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  1.69677734e-01,   1.69677734e-01],
                        [  2.17620850e-01,   2.17620850e-01],
                        [  2.28881836e-01,   2.28881836e-01],
                        [  2.06481934e-01,   2.06481934e-01],
                        [  1.67938232e-01,   1.67938232e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  8.49609375e-02,   8.49609375e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  8.85314941e-02,   8.85314941e-02],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.39465332e-02,   1.39160156e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [ -1.83105469e-03,  -1.80053711e-03],
                        [ -1.67846680e-02,  -1.68151855e-02],
                        [ -2.52075195e-02,  -2.52380371e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.82897949e-02,  -2.83203125e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.41699219e-02,  -2.41394043e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -2.84729004e-02,  -2.85034180e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  4.49829102e-02,   4.49829102e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -1.14593506e-01,  -1.14593506e-01],
                        [ -1.80938721e-01,  -1.80938721e-01],
                        [ -2.09167480e-01,  -2.09167480e-01],
                        [ -1.96899414e-01,  -1.96899414e-01],
                        [ -1.66412354e-01,  -1.66412354e-01],
                        [ -1.42211914e-01,  -1.42211914e-01],
                        [ -1.32659912e-01,  -1.32659912e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -1.18316650e-01,  -1.18286133e-01],
                        [ -1.03698730e-01,  -1.03698730e-01],
                        [ -9.59777832e-02,  -9.59777832e-02],
                        [ -9.76257324e-02,  -9.76257324e-02],
                        [ -9.83581543e-02,  -9.83581543e-02],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  1.20330811e-01,   1.20330811e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.54724121e-01,   1.54724121e-01],
                        [  1.81518555e-01,   1.81518555e-01],
                        [  2.02972412e-01,   2.02972412e-01],
                        [  2.16247559e-01,   2.16217041e-01],
                        [  2.11242676e-01,   2.11273193e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  9.10644531e-02,   9.10339355e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -1.47766113e-01,  -1.47766113e-01],
                        [ -2.51190186e-01,  -2.51190186e-01],
                        [ -3.07617188e-01,  -3.07647705e-01],
                        [ -3.04779053e-01,  -3.04779053e-01],
                        [ -2.53417969e-01,  -2.53417969e-01],
                        [ -1.85974121e-01,  -1.86004639e-01],
                        [ -1.37176514e-01,  -1.37207031e-01],
                        [ -1.20483398e-01,  -1.20483398e-01],
                        [ -1.25579834e-01,  -1.25579834e-01],
                        [ -1.36627197e-01,  -1.36657715e-01],
                        [ -1.44866943e-01,  -1.44866943e-01],
                        [ -1.44012451e-01,  -1.44012451e-01],
                        [ -1.27075195e-01,  -1.27105713e-01],
                        [ -9.33837891e-02,  -9.33837891e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  5.78308105e-02,   5.78308105e-02],
                        [  1.18896484e-01,   1.18896484e-01],
                        [  1.74468994e-01,   1.74468994e-01],
                        [  2.08007812e-01,   2.08007812e-01],
                        [  2.07580566e-01,   2.07580566e-01],
                        [  1.80114746e-01,   1.80114746e-01],
                        [  1.46362305e-01,   1.46362305e-01],
                        [  1.20788574e-01,   1.20788574e-01],
                        [  1.05041504e-01,   1.05041504e-01],
                        [  9.59777832e-02,   9.59777832e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  8.71582031e-02,   8.71276855e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  8.70056152e-02,   8.70056152e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  7.44934082e-02,   7.44934082e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  5.50231934e-02,   5.50231934e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  3.60412598e-02,   3.60107422e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  2.04467773e-02,   2.04772949e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.54724121e-02,   1.55029297e-02],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -2.35900879e-02,  -2.35595703e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -4.91638184e-02,  -4.91943359e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -4.07409668e-02,  -4.07104492e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.49536133e-02,  -1.49230957e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.37121582e-02,   2.36816406e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  3.84216309e-02,   3.84521484e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  8.16345215e-02,   8.16650391e-02],
                        [  8.25805664e-02,   8.25805664e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  2.94494629e-02,   2.94799805e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -8.63342285e-02,  -8.63342285e-02],
                        [ -1.60430908e-01,  -1.60430908e-01],
                        [ -2.14019775e-01,  -2.13989258e-01],
                        [ -2.26409912e-01,  -2.26440430e-01],
                        [ -1.98760986e-01,  -1.98760986e-01],
                        [ -1.54937744e-01,  -1.54907227e-01],
                        [ -1.23291016e-01,  -1.23291016e-01],
                        [ -1.14105225e-01,  -1.14135742e-01],
                        [ -1.15600586e-01,  -1.15600586e-01],
                        [ -1.10198975e-01,  -1.10198975e-01],
                        [ -9.40551758e-02,  -9.40551758e-02],
                        [ -8.02001953e-02,  -8.02001953e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -9.14611816e-02,  -9.14916992e-02],
                        [ -9.50317383e-02,  -9.50317383e-02],
                        [ -8.11157227e-02,  -8.11157227e-02],
                        [ -5.06286621e-02,  -5.06591797e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  8.70666504e-02,   8.70666504e-02],
                        [  1.20391846e-01,   1.20391846e-01],
                        [  1.34796143e-01,   1.34796143e-01],
                        [  1.36535645e-01,   1.36535645e-01],
                        [  1.36352539e-01,   1.36352539e-01],
                        [  1.38916016e-01,   1.38916016e-01],
                        [  1.44134521e-01,   1.44134521e-01],
                        [  1.55334473e-01,   1.55334473e-01],
                        [  1.75811768e-01,   1.75811768e-01],
                        [  1.98089600e-01,   1.98089600e-01],
                        [  2.07550049e-01,   2.07550049e-01],
                        [  1.94488525e-01,   1.94488525e-01],
                        [  1.54785156e-01,   1.54785156e-01],
                        [  8.34350586e-02,   8.34655762e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.45019531e-01,  -1.45019531e-01],
                        [ -2.57476807e-01,  -2.57446289e-01],
                        [ -3.22570801e-01,  -3.22570801e-01],
                        [ -3.19671631e-01,  -3.19671631e-01],
                        [ -2.59490967e-01,  -2.59490967e-01],
                        [ -1.81793213e-01,  -1.81793213e-01],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -1.16271973e-01,  -1.16302490e-01],
                        [ -1.25762939e-01,  -1.25762939e-01],
                        [ -1.33270264e-01,  -1.33270264e-01],
                        [ -1.31225586e-01,  -1.31225586e-01],
                        [ -1.24633789e-01,  -1.24633789e-01],
                        [ -1.12548828e-01,  -1.12548828e-01],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  9.38110352e-02,   9.38415527e-02],
                        [  1.54388428e-01,   1.54388428e-01],
                        [  2.01263428e-01,   2.01263428e-01],
                        [  2.21099854e-01,   2.21099854e-01],
                        [  2.05230713e-01,   2.05230713e-01],
                        [  1.64550781e-01,   1.64550781e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  8.25805664e-02,   8.25805664e-02],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  7.70568848e-02,   7.70568848e-02],
                        [  7.37304688e-02,   7.37304688e-02],
                        [  7.08312988e-02,   7.08007812e-02],
                        [  6.79626465e-02,   6.79931641e-02],
                        [  6.04248047e-02,   6.03942871e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  3.17382812e-02,   3.17687988e-02],
                        [  2.18505859e-02,   2.18811035e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  4.27246094e-03,   4.30297852e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -3.05175781e-03,  -3.08227539e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -3.18298340e-02,  -3.18603516e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -4.55322266e-02,  -4.55017090e-02],
                        [ -4.88586426e-02,  -4.88891602e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [  7.93457031e-04,   7.93457031e-04],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  3.15856934e-02,   3.15551758e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  3.84216309e-02,   3.84521484e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  5.81054688e-02,   5.81359863e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  5.26733398e-02,   5.26428223e-02],
                        [  4.58679199e-02,   4.58984375e-02],
                        [  4.14733887e-02,   4.14733887e-02],
                        [  3.18298340e-02,   3.17993164e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -1.18652344e-01,  -1.18652344e-01],
                        [ -1.82922363e-01,  -1.82922363e-01],
                        [ -2.18994141e-01,  -2.18963623e-01],
                        [ -2.15209961e-01,  -2.15209961e-01],
                        [ -1.79962158e-01,  -1.79962158e-01],
                        [ -1.36718750e-01,  -1.36688232e-01],
                        [ -1.07421875e-01,  -1.07391357e-01],
                        [ -9.87548828e-02,  -9.87548828e-02],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -1.04705811e-01,  -1.04675293e-01],
                        [ -1.03210449e-01,  -1.03210449e-01],
                        [ -1.00158691e-01,  -1.00158691e-01],
                        [ -9.60388184e-02,  -9.60388184e-02],
                        [ -8.67004395e-02,  -8.67004395e-02],
                        [ -6.75659180e-02,  -6.75964355e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.28692627e-01,   1.28662109e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.35162354e-01,   1.35162354e-01],
                        [  1.56646729e-01,   1.56616211e-01],
                        [  1.87042236e-01,   1.87042236e-01],
                        [  2.10296631e-01,   2.10296631e-01],
                        [  2.12402344e-01,   2.12402344e-01],
                        [  1.88323975e-01,   1.88293457e-01],
                        [  1.33087158e-01,   1.33087158e-01],
                        [  3.92456055e-02,   3.92456055e-02],
                        [ -8.74633789e-02,  -8.74938965e-02],
                        [ -2.16857910e-01,  -2.16857910e-01],
                        [ -3.06152344e-01,  -3.06152344e-01],
                        [ -3.25836182e-01,  -3.25866699e-01],
                        [ -2.80426025e-01,  -2.80426025e-01],
                        [ -2.08221436e-01,  -2.08221436e-01],
                        [ -1.54663086e-01,  -1.54663086e-01],
                        [ -1.38244629e-01,  -1.38244629e-01],
                        [ -1.44287109e-01,  -1.44287109e-01],
                        [ -1.49078369e-01,  -1.49078369e-01],
                        [ -1.42028809e-01,  -1.42059326e-01],
                        [ -1.25122070e-01,  -1.25122070e-01],
                        [ -1.02478027e-01,  -1.02478027e-01],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  1.60491943e-01,   1.60491943e-01],
                        [  2.18475342e-01,   2.18505859e-01],
                        [  2.34436035e-01,   2.34436035e-01],
                        [  2.09747314e-01,   2.09747314e-01],
                        [  1.67236328e-01,   1.67236328e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.09619141e-01,   1.09619141e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  8.91113281e-02,   8.91418457e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  8.56323242e-02,   8.56628418e-02],
                        [  8.28552246e-02,   8.28552246e-02],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  6.63452148e-02,   6.63452148e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  6.13098145e-02,   6.13098145e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  5.61828613e-02,   5.61523438e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  4.17175293e-02,   4.17480469e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  2.18505859e-02,   2.18811035e-02],
                        [  6.10351562e-03,   6.07299805e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -2.04772949e-02,  -2.04467773e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -4.17175293e-02,  -4.16870117e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -4.80957031e-02,  -4.81262207e-02],
                        [ -5.10559082e-02,  -5.10864258e-02],
                        [ -5.08117676e-02,  -5.07812500e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -2.76184082e-02,  -2.76489258e-02],
                        [ -6.65283203e-03,  -6.62231445e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  2.22778320e-03,   2.25830078e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.78833008e-02,   1.79138184e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  3.39050293e-02,   3.38745117e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  3.08227539e-02,   3.07922363e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  8.23974609e-03,   8.27026367e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  2.76794434e-02,   2.77099609e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -1.46026611e-01,  -1.45996094e-01],
                        [ -2.03674316e-01,  -2.03674316e-01],
                        [ -2.20001221e-01,  -2.20001221e-01],
                        [ -1.92840576e-01,  -1.92810059e-01],
                        [ -1.49749756e-01,  -1.49749756e-01],
                        [ -1.18774414e-01,  -1.18804932e-01],
                        [ -1.04675293e-01,  -1.04675293e-01],
                        [ -9.81140137e-02,  -9.81140137e-02],
                        [ -9.49707031e-02,  -9.50012207e-02],
                        [ -9.70458984e-02,  -9.70764160e-02],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -1.05285645e-01,  -1.05285645e-01],
                        [ -9.90905762e-02,  -9.91210938e-02],
                        [ -8.14514160e-02,  -8.14514160e-02],
                        [ -5.13305664e-02,  -5.13000488e-02],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  9.15527344e-02,   9.15832520e-02],
                        [  1.31134033e-01,   1.31134033e-01],
                        [  1.50451660e-01,   1.50451660e-01],
                        [  1.48742676e-01,   1.48773193e-01],
                        [  1.41113281e-01,   1.41143799e-01],
                        [  1.49291992e-01,   1.49261475e-01],
                        [  1.77703857e-01,   1.77703857e-01],
                        [  2.08129883e-01,   2.08129883e-01],
                        [  2.22503662e-01,   2.22503662e-01],
                        [  2.17346191e-01,   2.17315674e-01],
                        [  1.89819336e-01,   1.89849854e-01],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  2.69165039e-02,   2.69165039e-02],
                        [ -9.78088379e-02,  -9.78088379e-02],
                        [ -2.17437744e-01,  -2.17437744e-01],
                        [ -3.02368164e-01,  -3.02368164e-01],
                        [ -3.26843262e-01,  -3.26843262e-01],
                        [ -2.84942627e-01,  -2.84912109e-01],
                        [ -2.07733154e-01,  -2.07733154e-01],
                        [ -1.45080566e-01,  -1.45080566e-01],
                        [ -1.22283936e-01,  -1.22314453e-01],
                        [ -1.26861572e-01,  -1.26831055e-01],
                        [ -1.35589600e-01,  -1.35589600e-01],
                        [ -1.38122559e-01,  -1.38153076e-01],
                        [ -1.33178711e-01,  -1.33178711e-01],
                        [ -1.17645264e-01,  -1.17645264e-01],
                        [ -8.60290527e-02,  -8.60595703e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [  4.08325195e-02,   4.08630371e-02],
                        [  1.26281738e-01,   1.26251221e-01],
                        [  1.94763184e-01,   1.94763184e-01],
                        [  2.20703125e-01,   2.20703125e-01],
                        [  2.05993652e-01,   2.05963135e-01],
                        [  1.73767090e-01,   1.73767090e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  7.91625977e-02,   7.91931152e-02],
                        [  7.94372559e-02,   7.94372559e-02],
                        [  7.87963867e-02,   7.87658691e-02],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  7.73010254e-02,   7.72705078e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -2.61535645e-02,  -2.61230469e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -4.27856445e-02,  -4.28161621e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.65295410e-02,  -3.65600586e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  7.04956055e-03,   7.08007812e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  7.41577148e-03,   7.38525391e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  6.74438477e-03,   6.71386719e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  4.31823730e-02,   4.32128906e-02],
                        [  5.35583496e-02,   5.35583496e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [ -2.64892578e-02,  -2.65197754e-02],
                        [ -8.96606445e-02,  -8.96606445e-02],
                        [ -1.54510498e-01,  -1.54479980e-01],
                        [ -1.95037842e-01,  -1.95037842e-01],
                        [ -1.99493408e-01,  -1.99493408e-01],
                        [ -1.79412842e-01,  -1.79412842e-01],
                        [ -1.56005859e-01,  -1.55975342e-01],
                        [ -1.41418457e-01,  -1.41448975e-01],
                        [ -1.32690430e-01,  -1.32690430e-01],
                        [ -1.20117188e-01,  -1.20086670e-01],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -8.70361328e-02,  -8.70666504e-02],
                        [ -8.22143555e-02,  -8.22143555e-02],
                        [ -8.08715820e-02,  -8.08715820e-02],
                        [ -7.14721680e-02,  -7.14721680e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.52160645e-01,   1.52160645e-01],
                        [  1.60278320e-01,   1.60308838e-01],
                        [  1.69769287e-01,   1.69738770e-01],
                        [  1.83074951e-01,   1.83074951e-01],
                        [  1.96075439e-01,   1.96075439e-01],
                        [  2.04101562e-01,   2.04101562e-01],
                        [  2.01263428e-01,   2.01263428e-01],
                        [  1.75415039e-01,   1.75415039e-01],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  1.53198242e-02,   1.53198242e-02],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -2.11639404e-01,  -2.11639404e-01],
                        [ -2.87139893e-01,  -2.87139893e-01],
                        [ -3.09356689e-01,  -3.09356689e-01],
                        [ -2.78656006e-01,  -2.78656006e-01],
                        [ -2.20001221e-01,  -2.20001221e-01],
                        [ -1.69250488e-01,  -1.69281006e-01],
                        [ -1.47949219e-01,  -1.47949219e-01],
                        [ -1.50390625e-01,  -1.50390625e-01],
                        [ -1.54235840e-01,  -1.54235840e-01],
                        [ -1.44378662e-01,  -1.44409180e-01],
                        [ -1.25244141e-01,  -1.25213623e-01],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -8.05664062e-02,  -8.05664062e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  1.37329102e-01,   1.37329102e-01],
                        [  2.05657959e-01,   2.05627441e-01],
                        [  2.33032227e-01,   2.33062744e-01],
                        [  2.15332031e-01,   2.15332031e-01],
                        [  1.68731689e-01,   1.68701172e-01],
                        [  1.20880127e-01,   1.20880127e-01],
                        [  9.14001465e-02,   9.14306641e-02],
                        [  7.98339844e-02,   7.98034668e-02],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  6.82373047e-02,   6.82678223e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  6.75964355e-02,   6.75659180e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  5.86242676e-02,   5.85937500e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  6.13403320e-02,   6.13403320e-02],
                        [  6.38122559e-02,   6.37817383e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  7.70568848e-02,   7.70874023e-02],
                        [  7.73620605e-02,   7.73620605e-02],
                        [  7.23266602e-02,   7.22961426e-02],
                        [  6.39953613e-02,   6.39953613e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -4.72412109e-02,  -4.72106934e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  7.78198242e-03,   7.75146484e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -1.01776123e-01,  -1.01776123e-01],
                        [ -1.65252686e-01,  -1.65252686e-01],
                        [ -1.99340820e-01,  -1.99340820e-01],
                        [ -1.93725586e-01,  -1.93725586e-01],
                        [ -1.62231445e-01,  -1.62231445e-01],
                        [ -1.32629395e-01,  -1.32598877e-01],
                        [ -1.19445801e-01,  -1.19476318e-01],
                        [ -1.13952637e-01,  -1.13983154e-01],
                        [ -1.02813721e-01,  -1.02813721e-01],
                        [ -8.64562988e-02,  -8.64562988e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -7.11059570e-02,  -7.10754395e-02],
                        [ -7.13500977e-02,  -7.13500977e-02],
                        [ -6.43310547e-02,  -6.43615723e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.47430420e-01,   1.47430420e-01],
                        [  1.57226562e-01,   1.57226562e-01],
                        [  1.64672852e-01,   1.64703369e-01],
                        [  1.82342529e-01,   1.82342529e-01],
                        [  2.08984375e-01,   2.08953857e-01],
                        [  2.28271484e-01,   2.28271484e-01],
                        [  2.20245361e-01,   2.20245361e-01],
                        [  1.74102783e-01,   1.74072266e-01],
                        [  9.10339355e-02,   9.10339355e-02],
                        [ -2.03857422e-02,  -2.03552246e-02],
                        [ -1.45355225e-01,  -1.45355225e-01],
                        [ -2.58453369e-01,  -2.58483887e-01],
                        [ -3.26843262e-01,  -3.26843262e-01],
                        [ -3.29589844e-01,  -3.29559326e-01],
                        [ -2.77526855e-01,  -2.77526855e-01],
                        [ -2.09960938e-01,  -2.09960938e-01],
                        [ -1.64489746e-01,  -1.64489746e-01],
                        [ -1.48254395e-01,  -1.48254395e-01],
                        [ -1.42150879e-01,  -1.42181396e-01],
                        [ -1.30554199e-01,  -1.30554199e-01],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -1.03271484e-01,  -1.03271484e-01],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  1.71600342e-01,   1.71600342e-01],
                        [  2.17681885e-01,   2.17681885e-01],
                        [  2.26226807e-01,   2.26226807e-01],
                        [  2.06207275e-01,   2.06207275e-01],
                        [  1.71142578e-01,   1.71142578e-01],
                        [  1.29516602e-01,   1.29547119e-01],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  7.28454590e-02,   7.28759766e-02],
                        [  6.41479492e-02,   6.41174316e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  4.90417480e-02,   4.90722656e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  5.80139160e-02,   5.80139160e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  5.59387207e-02,   5.59082031e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -6.15539551e-02,  -6.15844727e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.50146484e-02,  -1.49841309e-02],
                        [ -1.55639648e-02,  -1.55944824e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  4.27246094e-03,   4.24194336e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -1.03729248e-01,  -1.03729248e-01],
                        [ -1.57409668e-01,  -1.57409668e-01],
                        [ -1.85150146e-01,  -1.85180664e-01],
                        [ -1.76635742e-01,  -1.76635742e-01],
                        [ -1.48193359e-01,  -1.48193359e-01],
                        [ -1.23168945e-01,  -1.23168945e-01],
                        [ -1.08123779e-01,  -1.08123779e-01],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -8.69750977e-02,  -8.69750977e-02],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -5.14526367e-02,  -5.14831543e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  5.35583496e-02,   5.35278320e-02],
                        [  1.11511230e-01,   1.11480713e-01],
                        [  1.58874512e-01,   1.58874512e-01],
                        [  1.92657471e-01,   1.92657471e-01],
                        [  2.17559814e-01,   2.17559814e-01],
                        [  2.36267090e-01,   2.36267090e-01],
                        [  2.45300293e-01,   2.45300293e-01],
                        [  2.35839844e-01,   2.35839844e-01],
                        [  1.97540283e-01,   1.97540283e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  2.28271484e-02,   2.28271484e-02],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -2.21282959e-01,  -2.21282959e-01],
                        [ -3.18634033e-01,  -3.18634033e-01],
                        [ -3.55163574e-01,  -3.55194092e-01],
                        [ -3.17535400e-01,  -3.17535400e-01],
                        [ -2.39105225e-01,  -2.39105225e-01],
                        [ -1.76300049e-01,  -1.76300049e-01],
                        [ -1.55639648e-01,  -1.55639648e-01],
                        [ -1.58508301e-01,  -1.58508301e-01],
                        [ -1.55517578e-01,  -1.55517578e-01],
                        [ -1.37786865e-01,  -1.37786865e-01],
                        [ -1.12854004e-01,  -1.12884521e-01],
                        [ -8.50524902e-02,  -8.50524902e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  9.66491699e-02,   9.66186523e-02],
                        [  1.76727295e-01,   1.76727295e-01],
                        [  2.24060059e-01,   2.24060059e-01],
                        [  2.25189209e-01,   2.25189209e-01],
                        [  1.93786621e-01,   1.93786621e-01],
                        [  1.55212402e-01,   1.55212402e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  4.15649414e-02,   4.15954590e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  6.70166016e-02,   6.70166016e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  6.81457520e-02,   6.81457520e-02],
                        [  7.07702637e-02,   7.07702637e-02],
                        [  7.11975098e-02,   7.12280273e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  5.82580566e-02,   5.82580566e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.12609863e-02,   1.12304688e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  1.80053711e-03,   1.77001953e-03],
                        [  6.71386719e-04,   7.01904297e-04],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  1.51062012e-02,   1.50756836e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.36413574e-02,   1.36718750e-02],
                        [  6.86645508e-03,   6.83593750e-03],
                        [ -2.56347656e-03,  -2.59399414e-03],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  3.96728516e-04,   4.27246094e-04],
                        [  6.71386719e-03,   6.74438477e-03],
                        [  1.39160156e-02,   1.38854980e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  3.81164551e-02,   3.81469727e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  4.45861816e-02,   4.45556641e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -8.26416016e-02,  -8.26416016e-02],
                        [ -1.39129639e-01,  -1.39129639e-01],
                        [ -1.81457520e-01,  -1.81427002e-01],
                        [ -1.97326660e-01,  -1.97326660e-01],
                        [ -1.81396484e-01,  -1.81427002e-01],
                        [ -1.44805908e-01,  -1.44805908e-01],
                        [ -1.08856201e-01,  -1.08856201e-01],
                        [ -8.63647461e-02,  -8.63647461e-02],
                        [ -7.59582520e-02,  -7.59582520e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -7.24487305e-02,  -7.24487305e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -5.39855957e-02,  -5.39550781e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  8.56933594e-02,   8.56933594e-02],
                        [  1.34002686e-01,   1.34002686e-01],
                        [  1.70989990e-01,   1.70989990e-01],
                        [  2.00347900e-01,   2.00347900e-01],
                        [  2.20733643e-01,   2.20764160e-01],
                        [  2.27355957e-01,   2.27355957e-01],
                        [  2.20428467e-01,   2.20428467e-01],
                        [  1.99035645e-01,   1.99035645e-01],
                        [  1.52587891e-01,   1.52587891e-01],
                        [  7.12280273e-02,   7.12280273e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -1.57989502e-01,  -1.57958984e-01],
                        [ -2.60314941e-01,  -2.60314941e-01],
                        [ -3.20404053e-01,  -3.20404053e-01],
                        [ -3.20831299e-01,  -3.20831299e-01],
                        [ -2.69226074e-01,  -2.69226074e-01],
                        [ -2.02789307e-01,  -2.02789307e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.53656006e-01,  -1.53625488e-01],
                        [ -1.53808594e-01,  -1.53808594e-01],
                        [ -1.39312744e-01,  -1.39312744e-01],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -8.17871094e-02,  -8.17871094e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  1.43341064e-01,   1.43341064e-01],
                        [  1.94549561e-01,   1.94549561e-01],
                        [  2.12432861e-01,   2.12432861e-01],
                        [  1.97784424e-01,   1.97784424e-01],
                        [  1.65710449e-01,   1.65710449e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  1.08886719e-01,   1.08917236e-01],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  8.07495117e-02,   8.07800293e-02],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  7.39135742e-02,   7.39135742e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  5.33447266e-02,   5.33447266e-02],
                        [  4.77294922e-02,   4.77294922e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  3.53393555e-02,   3.53088379e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  2.78015137e-02,   2.78320312e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [ -4.63867188e-03,  -4.66918945e-03],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -3.02734375e-02,  -3.02429199e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  7.41577148e-03,   7.38525391e-03],
                        [  1.19934082e-02,   1.20239258e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  8.17871094e-03,   8.14819336e-03],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.27563477e-02,   1.27258301e-02],
                        [  1.07421875e-02,   1.07727051e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.54724121e-02,   1.54418945e-02],
                        [  1.52893066e-02,   1.53198242e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -1.10961914e-01,  -1.10961914e-01],
                        [ -1.61499023e-01,  -1.61499023e-01],
                        [ -1.86614990e-01,  -1.86614990e-01],
                        [ -1.75933838e-01,  -1.75933838e-01],
                        [ -1.41815186e-01,  -1.41784668e-01],
                        [ -1.09710693e-01,  -1.09710693e-01],
                        [ -9.29870605e-02,  -9.30175781e-02],
                        [ -8.59375000e-02,  -8.59069824e-02],
                        [ -8.02612305e-02,  -8.02612305e-02],
                        [ -7.62329102e-02,  -7.62634277e-02],
                        [ -7.58056641e-02,  -7.58056641e-02],
                        [ -7.43103027e-02,  -7.42797852e-02],
                        [ -6.08520508e-02,  -6.08825684e-02],
                        [ -2.56042480e-02,  -2.56347656e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.45477295e-01,   1.45477295e-01],
                        [  1.78741455e-01,   1.78741455e-01],
                        [  1.99188232e-01,   1.99188232e-01],
                        [  2.15850830e-01,   2.15850830e-01],
                        [  2.29736328e-01,   2.29736328e-01],
                        [  2.29980469e-01,   2.29980469e-01],
                        [  1.99249268e-01,   1.99249268e-01],
                        [  1.26861572e-01,   1.26861572e-01],
                        [  1.91345215e-02,   1.91345215e-02],
                        [ -1.03546143e-01,  -1.03546143e-01],
                        [ -2.17864990e-01,  -2.17864990e-01],
                        [ -3.00903320e-01,  -3.00903320e-01],
                        [ -3.31054688e-01,  -3.31054688e-01],
                        [ -3.02581787e-01,  -3.02581787e-01],
                        [ -2.40051270e-01,  -2.40051270e-01],
                        [ -1.84234619e-01,  -1.84234619e-01],
                        [ -1.58538818e-01,  -1.58538818e-01],
                        [ -1.54968262e-01,  -1.54968262e-01],
                        [ -1.51702881e-01,  -1.51702881e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -1.06109619e-01,  -1.06109619e-01],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [  6.62536621e-02,   6.62536621e-02],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  1.83013916e-01,   1.83013916e-01],
                        [  2.02697754e-01,   2.02697754e-01],
                        [  1.96014404e-01,   1.96014404e-01],
                        [  1.70898438e-01,   1.70928955e-01],
                        [  1.38397217e-01,   1.38397217e-01],
                        [  1.10015869e-01,   1.09985352e-01],
                        [  9.14306641e-02,   9.14306641e-02],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  5.35583496e-02,   5.35278320e-02],
                        [  5.55419922e-02,   5.55114746e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  7.47985840e-02,   7.47985840e-02],
                        [  7.12280273e-02,   7.12280273e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  5.55114746e-02,   5.55114746e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.17785645e-02,   4.18090820e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.61743164e-03,   1.64794922e-03],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.25427246e-02,  -1.25122070e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  2.10571289e-03,   2.10571289e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [  7.01904297e-03,   7.04956055e-03],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  2.25830078e-03,   2.28881836e-03],
                        [  8.72802734e-03,   8.69750977e-03],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.21350098e-02,   3.21044922e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -1.05895996e-01,  -1.05895996e-01],
                        [ -1.58447266e-01,  -1.58447266e-01],
                        [ -1.83685303e-01,  -1.83685303e-01],
                        [ -1.75262451e-01,  -1.75231934e-01],
                        [ -1.46392822e-01,  -1.46423340e-01],
                        [ -1.19506836e-01,  -1.19506836e-01],
                        [ -1.07391357e-01,  -1.07360840e-01],
                        [ -1.03424072e-01,  -1.03424072e-01],
                        [ -9.24682617e-02,  -9.24987793e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.61743164e-01,   1.61743164e-01],
                        [  1.99737549e-01,   1.99768066e-01],
                        [  2.19818115e-01,   2.19818115e-01],
                        [  2.28942871e-01,   2.28942871e-01],
                        [  2.29309082e-01,   2.29309082e-01],
                        [  2.08038330e-01,   2.08038330e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  5.13610840e-02,   5.13305664e-02],
                        [ -7.10449219e-02,  -7.10449219e-02],
                        [ -1.96533203e-01,  -1.96533203e-01],
                        [ -2.96661377e-01,  -2.96691895e-01],
                        [ -3.41003418e-01,  -3.41003418e-01],
                        [ -3.18878174e-01,  -3.18847656e-01],
                        [ -2.55157471e-01,  -2.55157471e-01],
                        [ -1.93511963e-01,  -1.93511963e-01],
                        [ -1.61621094e-01,  -1.61590576e-01],
                        [ -1.54968262e-01,  -1.54968262e-01],
                        [ -1.51611328e-01,  -1.51611328e-01],
                        [ -1.35955811e-01,  -1.35955811e-01],
                        [ -1.06170654e-01,  -1.06140137e-01],
                        [ -6.34765625e-02,  -6.35070801e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  6.39953613e-02,   6.39953613e-02],
                        [  1.35375977e-01,   1.35375977e-01],
                        [  1.90399170e-01,   1.90368652e-01],
                        [  2.14111328e-01,   2.14111328e-01],
                        [  2.03674316e-01,   2.03704834e-01],
                        [  1.71081543e-01,   1.71081543e-01],
                        [  1.33514404e-01,   1.33483887e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  8.31604004e-02,   8.31909180e-02],
                        [  7.70874023e-02,   7.70874023e-02],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  4.33959961e-02,   4.34265137e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  8.09631348e-02,   8.09326172e-02],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  5.49316406e-02,   5.49621582e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -3.80554199e-02,  -3.80249023e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -2.38952637e-02,  -2.39257812e-02],
                        [ -1.11694336e-02,  -1.11999512e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  5.06591797e-03,   5.09643555e-03],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  1.49536133e-03,   1.52587891e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -1.20239258e-02,  -1.19934082e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.63574219e-02,  -1.63879395e-02],
                        [ -1.51977539e-02,  -1.51672363e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -1.18835449e-01,  -1.18835449e-01],
                        [ -1.66625977e-01,  -1.66625977e-01],
                        [ -1.90185547e-01,  -1.90185547e-01],
                        [ -1.81549072e-01,  -1.81549072e-01],
                        [ -1.50482178e-01,  -1.50482178e-01],
                        [ -1.17858887e-01,  -1.17828369e-01],
                        [ -9.68322754e-02,  -9.68322754e-02],
                        [ -8.43505859e-02,  -8.43505859e-02],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  8.25195312e-02,   8.25195312e-02],
                        [  1.41998291e-01,   1.42028809e-01],
                        [  1.92352295e-01,   1.92352295e-01],
                        [  2.27813721e-01,   2.27783203e-01],
                        [  2.43225098e-01,   2.43225098e-01],
                        [  2.34893799e-01,   2.34893799e-01],
                        [  1.99981689e-01,   1.99981689e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  3.33557129e-02,   3.33862305e-02],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -2.11334229e-01,  -2.11364746e-01],
                        [ -3.01483154e-01,  -3.01483154e-01],
                        [ -3.36853027e-01,  -3.36853027e-01],
                        [ -3.11889648e-01,  -3.11889648e-01],
                        [ -2.50335693e-01,  -2.50335693e-01],
                        [ -1.94976807e-01,  -1.94976807e-01],
                        [ -1.72119141e-01,  -1.72119141e-01],
                        [ -1.70074463e-01,  -1.70074463e-01],
                        [ -1.59973145e-01,  -1.59973145e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -8.21533203e-02,  -8.21533203e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  1.14654541e-01,   1.14654541e-01],
                        [  1.73034668e-01,   1.73065186e-01],
                        [  2.02972412e-01,   2.02972412e-01],
                        [  2.02239990e-01,   2.02239990e-01],
                        [  1.80236816e-01,   1.80236816e-01],
                        [  1.51062012e-01,   1.51062012e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  8.21838379e-02,   8.22143555e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  6.09741211e-02,   6.09436035e-02],
                        [  6.72607422e-02,   6.72912598e-02],
                        [  6.88171387e-02,   6.88171387e-02],
                        [  5.84411621e-02,   5.84411621e-02],
                        [  4.40368652e-02,   4.40673828e-02],
                        [  3.56445312e-02,   3.56750488e-02],
                        [  3.57055664e-02,   3.56750488e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  5.49011230e-02,   5.49316406e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  8.23364258e-02,   8.23364258e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  2.86254883e-02,   2.85949707e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -1.51367188e-02,  -1.51062012e-02],
                        [ -1.54418945e-02,  -1.54113770e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -2.71911621e-02,  -2.72216797e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  2.01721191e-02,   2.01416016e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -1.18682861e-01,  -1.18682861e-01],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -1.57135010e-01,  -1.57104492e-01],
                        [ -1.33911133e-01,  -1.33911133e-01],
                        [ -1.05712891e-01,  -1.05743408e-01],
                        [ -8.91418457e-02,  -8.91418457e-02],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -7.97729492e-02,  -7.97729492e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -2.19421387e-02,  -2.19726562e-02],
                        [  1.62353516e-02,   1.62658691e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  1.25122070e-01,   1.25122070e-01],
                        [  1.78192139e-01,   1.78192139e-01],
                        [  2.18475342e-01,   2.18475342e-01],
                        [  2.38525391e-01,   2.38525391e-01],
                        [  2.30377197e-01,   2.30377197e-01],
                        [  1.88415527e-01,   1.88415527e-01],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  7.35473633e-03,   7.35473633e-03],
                        [ -1.17950439e-01,  -1.17950439e-01],
                        [ -2.40600586e-01,  -2.40600586e-01],
                        [ -3.25408936e-01,  -3.25408936e-01],
                        [ -3.44757080e-01,  -3.44757080e-01],
                        [ -3.02001953e-01,  -3.02001953e-01],
                        [ -2.31872559e-01,  -2.31872559e-01],
                        [ -1.77001953e-01,  -1.77001953e-01],
                        [ -1.57867432e-01,  -1.57867432e-01],
                        [ -1.59484863e-01,  -1.59484863e-01],
                        [ -1.50390625e-01,  -1.50390625e-01],
                        [ -1.15386963e-01,  -1.15386963e-01],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.82373047e-01,   1.82403564e-01],
                        [  2.10266113e-01,   2.10266113e-01],
                        [  2.06176758e-01,   2.06176758e-01],
                        [  1.83868408e-01,   1.83898926e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.07208252e-01,   1.07238770e-01],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  6.15539551e-02,   6.15234375e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  4.37011719e-02,   4.37011719e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  7.87353516e-03,   7.90405273e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [  3.05175781e-05,   3.05175781e-05],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -1.35589600e-01,  -1.35589600e-01],
                        [ -1.63299561e-01,  -1.63299561e-01],
                        [ -1.61132812e-01,  -1.61132812e-01],
                        [ -1.40045166e-01,  -1.40045166e-01],
                        [ -1.16271973e-01,  -1.16271973e-01],
                        [ -9.78698730e-02,  -9.78698730e-02],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  6.02416992e-02,   6.02416992e-02],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.84600830e-01,   1.84600830e-01],
                        [  2.31323242e-01,   2.31323242e-01],
                        [  2.41638184e-01,   2.41638184e-01],
                        [  2.12402344e-01,   2.12402344e-01],
                        [  1.48742676e-01,   1.48742676e-01],
                        [  5.43518066e-02,   5.43518066e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -1.86889648e-01,  -1.86889648e-01],
                        [ -2.84240723e-01,  -2.84240723e-01],
                        [ -3.28643799e-01,  -3.28643799e-01],
                        [ -3.11462402e-01,  -3.11462402e-01],
                        [ -2.53479004e-01,  -2.53479004e-01],
                        [ -1.95709229e-01,  -1.95709229e-01],
                        [ -1.67175293e-01,  -1.67175293e-01],
                        [ -1.61743164e-01,  -1.61743164e-01],
                        [ -1.51733398e-01,  -1.51733398e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -7.23571777e-02,  -7.23571777e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  9.36584473e-02,   9.36584473e-02],
                        [  1.47247314e-01,   1.47247314e-01],
                        [  1.82159424e-01,   1.82159424e-01],
                        [  1.91345215e-01,   1.91345215e-01],
                        [  1.79687500e-01,   1.79687500e-01],
                        [  1.58142090e-01,   1.58142090e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.11999512e-01,   1.11999512e-01],
                        [  8.74023438e-02,   8.74023438e-02],
                        [  6.41479492e-02,   6.41479492e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  6.61926270e-02,   6.61926270e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  5.58471680e-03,   5.55419922e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.82495117e-02,   1.82189941e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  2.70080566e-02,   2.70080566e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -1.00433350e-01,  -1.00433350e-01],
                        [ -1.37329102e-01,  -1.37329102e-01],
                        [ -1.50970459e-01,  -1.50970459e-01],
                        [ -1.40502930e-01,  -1.40502930e-01],
                        [ -1.12945557e-01,  -1.12945557e-01],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -3.30200195e-02,  -3.29895020e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  1.56158447e-01,   1.56158447e-01],
                        [  2.03247070e-01,   2.03247070e-01],
                        [  2.18719482e-01,   2.18719482e-01],
                        [  1.91558838e-01,   1.91558838e-01],
                        [  1.24816895e-01,   1.24816895e-01],
                        [  2.76489258e-02,   2.76489258e-02],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -2.08282471e-01,  -2.08282471e-01],
                        [ -2.95349121e-01,  -2.95349121e-01],
                        [ -3.21258545e-01,  -3.21258545e-01],
                        [ -2.87384033e-01,  -2.87384033e-01],
                        [ -2.30407715e-01,  -2.30407715e-01],
                        [ -1.89880371e-01,  -1.89880371e-01],
                        [ -1.73370361e-01,  -1.73370361e-01],
                        [ -1.60064697e-01,  -1.60064697e-01],
                        [ -1.33087158e-01,  -1.33087158e-01],
                        [ -9.48181152e-02,  -9.48181152e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  1.53198242e-01,   1.53198242e-01],
                        [  1.73980713e-01,   1.73980713e-01],
                        [  1.71386719e-01,   1.71386719e-01],
                        [  1.61499023e-01,   1.61499023e-01],
                        [  1.53961182e-01,   1.53961182e-01],
                        [  1.44500732e-01,   1.44500732e-01],
                        [  1.27166748e-01,   1.27166748e-01],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  5.30090332e-02,   5.30090332e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  3.46679688e-02,   3.46679688e-02],
                        [  5.14526367e-02,   5.14526367e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -1.25000000e-01,  -1.25000000e-01],
                        [ -1.54785156e-01,  -1.54785156e-01],
                        [ -1.54602051e-01,  -1.54602051e-01],
                        [ -1.29638672e-01,  -1.29638672e-01],
                        [ -9.41467285e-02,  -9.41467285e-02],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  1.33575439e-01,   1.33575439e-01],
                        [  1.97998047e-01,   1.97998047e-01],
                        [  2.39196777e-01,   2.39196777e-01],
                        [  2.37152100e-01,   2.37152100e-01],
                        [  1.87316895e-01,   1.87316895e-01],
                        [  9.86938477e-02,   9.86938477e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.49108887e-01,  -1.49108887e-01],
                        [ -2.71972656e-01,  -2.71972656e-01],
                        [ -3.49212646e-01,  -3.49212646e-01],
                        [ -3.56292725e-01,  -3.56292725e-01],
                        [ -3.07312012e-01,  -3.07312012e-01],
                        [ -2.46398926e-01,  -2.46398926e-01],
                        [ -2.08679199e-01,  -2.08679199e-01],
                        [ -1.92626953e-01,  -1.92626953e-01],
                        [ -1.72271729e-01,  -1.72271729e-01],
                        [ -1.30737305e-01,  -1.30737305e-01],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.62689209e-01,   1.62689209e-01],
                        [  1.88415527e-01,   1.88415527e-01],
                        [  1.91162109e-01,   1.91162109e-01],
                        [  1.82586670e-01,   1.82586670e-01],
                        [  1.71752930e-01,   1.71752930e-01],
                        [  1.55853271e-01,   1.55853271e-01],
                        [  1.27899170e-01,   1.27899170e-01],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  6.42089844e-02,   6.42089844e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  8.63342285e-02,   8.63342285e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -1.31652832e-01,  -1.31652832e-01],
                        [ -1.31927490e-01,  -1.31927490e-01],
                        [ -1.17401123e-01,  -1.17401123e-01],
                        [ -9.71374512e-02,  -9.71374512e-02],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  1.22863770e-01,   1.22863770e-01],
                        [  1.78436279e-01,   1.78436279e-01],
                        [  2.24670410e-01,   2.24670410e-01],
                        [  2.38983154e-01,   2.38983154e-01],
                        [  2.04528809e-01,   2.04528809e-01],
                        [  1.24511719e-01,   1.24511719e-01],
                        [  1.31530762e-02,   1.31530762e-02],
                        [ -1.17279053e-01,  -1.17248535e-01],
                        [ -2.47436523e-01,  -2.47436523e-01],
                        [ -3.40301514e-01,  -3.40301514e-01],
                        [ -3.62854004e-01,  -3.62854004e-01],
                        [ -3.21319580e-01,  -3.21319580e-01],
                        [ -2.58178711e-01,  -2.58178711e-01],
                        [ -2.10693359e-01,  -2.10693359e-01],
                        [ -1.83807373e-01,  -1.83807373e-01],
                        [ -1.62628174e-01,  -1.62628174e-01],
                        [ -1.34124756e-01,  -1.34124756e-01],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.71478271e-01,   1.71478271e-01],
                        [  1.79046631e-01,   1.79046631e-01],
                        [  1.78070068e-01,   1.78070068e-01],
                        [  1.69677734e-01,   1.69677734e-01],
                        [  1.54327393e-01,   1.54327393e-01],
                        [  1.32904053e-01,   1.32904053e-01],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  6.24084473e-02,   6.24389648e-02],
                        [  7.62329102e-02,   7.62329102e-02],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  7.77587891e-02,   7.77587891e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.06286621e-02,   5.06286621e-02],
                        [  4.03747559e-02,   4.03747559e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -7.65075684e-02,  -7.65075684e-02],
                        [ -1.08642578e-01,  -1.08642578e-01],
                        [ -1.23321533e-01,  -1.23321533e-01],
                        [ -1.16516113e-01,  -1.16516113e-01],
                        [ -9.70458984e-02,  -9.70458984e-02],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -7.90710449e-02,  -7.90710449e-02],
                        [ -7.41577148e-02,  -7.41577148e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  1.39709473e-01,   1.39709473e-01],
                        [  1.99829102e-01,   1.99829102e-01],
                        [  2.36267090e-01,   2.36267090e-01],
                        [  2.27752686e-01,   2.27752686e-01],
                        [  1.66503906e-01,   1.66503906e-01],
                        [  6.00280762e-02,   6.00280762e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -2.03186035e-01,  -2.03186035e-01],
                        [ -3.05816650e-01,  -3.05816650e-01],
                        [ -3.55072021e-01,  -3.55072021e-01],
                        [ -3.42132568e-01,  -3.42132568e-01],
                        [ -2.86102295e-01,  -2.86102295e-01],
                        [ -2.23999023e-01,  -2.23999023e-01],
                        [ -1.82678223e-01,  -1.82678223e-01],
                        [ -1.61224365e-01,  -1.61224365e-01],
                        [ -1.39953613e-01,  -1.39953613e-01],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  8.02001953e-02,   8.02001953e-02],
                        [  1.34246826e-01,   1.34246826e-01],
                        [  1.71356201e-01,   1.71356201e-01],
                        [  1.87652588e-01,   1.87652588e-01],
                        [  1.89727783e-01,   1.89727783e-01],
                        [  1.85119629e-01,   1.85119629e-01],
                        [  1.71600342e-01,   1.71600342e-01],
                        [  1.45080566e-01,   1.45080566e-01],
                        [  1.13281250e-01,   1.13281250e-01],
                        [  8.96301270e-02,   8.96301270e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  6.55212402e-02,   6.55517578e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  3.02429199e-02,   3.02124023e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  8.08715820e-02,   8.08715820e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  6.64978027e-02,   6.64978027e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.47497559e-02,  -2.47192383e-02],
                        [ -2.48718262e-02,  -2.48413086e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -9.70458984e-03,  -9.67407227e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -7.47680664e-03,  -7.50732422e-03],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -7.17163086e-03,  -7.20214844e-03],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -1.08428955e-01,  -1.08428955e-01],
                        [ -1.34368896e-01,  -1.34368896e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -9.76257324e-02,  -9.76257324e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -5.65490723e-02,  -5.65795898e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  1.30310059e-01,   1.30310059e-01],
                        [  1.82098389e-01,   1.82098389e-01],
                        [  2.15911865e-01,   2.15911865e-01],
                        [  2.15484619e-01,   2.15484619e-01],
                        [  1.71142578e-01,   1.71142578e-01],
                        [  8.16040039e-02,   8.16040039e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -1.79290771e-01,  -1.79290771e-01],
                        [ -2.90496826e-01,  -2.90496826e-01],
                        [ -3.45184326e-01,  -3.45184326e-01],
                        [ -3.35235596e-01,  -3.35235596e-01],
                        [ -2.83416748e-01,  -2.83416748e-01],
                        [ -2.27691650e-01,  -2.27691650e-01],
                        [ -1.93603516e-01,  -1.93603516e-01],
                        [ -1.78222656e-01,  -1.78222656e-01],
                        [ -1.59149170e-01,  -1.59149170e-01],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  1.41571045e-01,   1.41571045e-01],
                        [  1.61804199e-01,   1.61804199e-01],
                        [  1.59729004e-01,   1.59729004e-01],
                        [  1.52954102e-01,   1.52954102e-01],
                        [  1.56066895e-01,   1.56066895e-01],
                        [  1.63604736e-01,   1.63604736e-01],
                        [  1.57135010e-01,   1.57135010e-01],
                        [  1.30981445e-01,   1.30981445e-01],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  8.52966309e-02,   8.52966309e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  1.10778809e-02,   1.10473633e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.42822266e-02,   1.43127441e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.45666504e-02,   2.45361328e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -1.01837158e-01,  -1.01837158e-01],
                        [ -1.41174316e-01,  -1.41174316e-01],
                        [ -1.49230957e-01,  -1.49230957e-01],
                        [ -1.22894287e-01,  -1.22894287e-01],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  1.63269043e-01,   1.63299561e-01],
                        [  1.88079834e-01,   1.88079834e-01],
                        [  1.84936523e-01,   1.84936523e-01],
                        [  1.40747070e-01,   1.40777588e-01],
                        [  5.67016602e-02,   5.66711426e-02],
                        [ -5.56335449e-02,  -5.56640625e-02],
                        [ -1.79016113e-01,  -1.78985596e-01],
                        [ -2.85644531e-01,  -2.85644531e-01],
                        [ -3.40820312e-01,  -3.40850830e-01],
                        [ -3.26171875e-01,  -3.26171875e-01],
                        [ -2.62329102e-01,  -2.62329102e-01],
                        [ -1.98608398e-01,  -1.98608398e-01],
                        [ -1.69891357e-01,  -1.69921875e-01],
                        [ -1.66900635e-01,  -1.66870117e-01],
                        [ -1.54205322e-01,  -1.54205322e-01],
                        [ -1.09710693e-01,  -1.09710693e-01],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  1.06872559e-01,   1.06842041e-01],
                        [  1.48101807e-01,   1.48101807e-01],
                        [  1.60888672e-01,   1.60919189e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.53411865e-01,   1.53411865e-01],
                        [  1.54083252e-01,   1.54083252e-01],
                        [  1.50299072e-01,   1.50299072e-01],
                        [  1.32507324e-01,   1.32476807e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.50244141e-02,   2.50549316e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  7.37304688e-02,   7.37304688e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  6.20727539e-02,   6.20422363e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  4.64172363e-02,   4.64477539e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  1.41296387e-02,   1.41601562e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -1.36413574e-02,  -1.36108398e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.40380859e-02,  -1.40075684e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -5.00488281e-03,  -5.03540039e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  3.05175781e-05,   6.10351562e-05],
                        [ -7.93457031e-04,  -8.23974609e-04],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  6.40869141e-04,   6.71386719e-04],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -1.28173828e-03,  -1.31225586e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.69982910e-02,  -1.70288086e-02],
                        [ -3.10058594e-02,  -3.09753418e-02],
                        [ -3.97033691e-02,  -3.96728516e-02],
                        [ -4.12597656e-02,  -4.12902832e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -3.00903320e-02,  -3.01208496e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.80053711e-03,  -1.77001953e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  3.69873047e-02,   3.70178223e-02],
                        [  2.87170410e-02,   2.86865234e-02],
                        [  2.68554688e-03,   2.68554688e-03],
                        [ -3.77197266e-02,  -3.76892090e-02],
                        [ -8.26416016e-02,  -8.26721191e-02],
                        [ -1.19354248e-01,  -1.19354248e-01],
                        [ -1.34552002e-01,  -1.34521484e-01],
                        [ -1.23840332e-01,  -1.23840332e-01],
                        [ -9.65270996e-02,  -9.65576172e-02],
                        [ -6.59179688e-02,  -6.58874512e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  4.13513184e-02,   4.13818359e-02],
                        [  9.22241211e-02,   9.22241211e-02],
                        [  1.45996094e-01,   1.45965576e-01],
                        [  1.87377930e-01,   1.87408447e-01],
                        [  2.05596924e-01,   2.05596924e-01],
                        [  1.89422607e-01,   1.89422607e-01],
                        [  1.25946045e-01,   1.25946045e-01],
                        [  1.36108398e-02,   1.36108398e-02],
                        [ -1.26892090e-01,  -1.26922607e-01],
                        [ -2.59552002e-01,  -2.59582520e-01],
                        [ -3.47930908e-01,  -3.47900391e-01],
                        [ -3.68835449e-01,  -3.68835449e-01],
                        [ -3.27056885e-01,  -3.27087402e-01],
                        [ -2.57385254e-01,  -2.57385254e-01],
                        [ -1.99890137e-01,  -1.99859619e-01],
                        [ -1.69708252e-01,  -1.69738770e-01],
                        [ -1.52130127e-01,  -1.52160645e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [  9.73510742e-03,   9.70458984e-03],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  1.35131836e-01,   1.35162354e-01],
                        [  1.57714844e-01,   1.57684326e-01],
                        [  1.58294678e-01,   1.58325195e-01],
                        [  1.53717041e-01,   1.53717041e-01],
                        [  1.52008057e-01,   1.52008057e-01],
                        [  1.48559570e-01,   1.48559570e-01],
                        [  1.37268066e-01,   1.37268066e-01],
                        [  1.19140625e-01,   1.19140625e-01],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.14135742e-02,   1.13830566e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  4.27551270e-02,   4.27246094e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  6.52465820e-02,   6.52770996e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  3.04565430e-02,   3.04260254e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  1.45568848e-02,   1.45874023e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -2.06909180e-02,  -2.06604004e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.58789062e-02,  -2.59094238e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.74047852e-02,  -2.73742676e-02],
                        [ -2.25219727e-02,  -2.25524902e-02],
                        [ -1.23901367e-02,  -1.24206543e-02],
                        [ -1.73950195e-03,  -1.70898438e-03],
                        [  5.76782227e-03,   5.73730469e-03],
                        [  1.07116699e-02,   1.06811523e-02],
                        [  1.72729492e-02,   1.73034668e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.40881348e-02,   3.40576172e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -7.53784180e-03,  -7.50732422e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -3.39965820e-02,  -3.40270996e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -2.60925293e-02,  -2.61230469e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  3.34472656e-02,   3.34167480e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -1.05377197e-01,  -1.05377197e-01],
                        [ -1.41296387e-01,  -1.41296387e-01],
                        [ -1.47308350e-01,  -1.47308350e-01],
                        [ -1.23260498e-01,  -1.23260498e-01],
                        [ -8.35571289e-02,  -8.35571289e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  1.27380371e-01,   1.27380371e-01],
                        [  1.75262451e-01,   1.75262451e-01],
                        [  2.08557129e-01,   2.08587646e-01],
                        [  2.12554932e-01,   2.12554932e-01],
                        [  1.69860840e-01,   1.69860840e-01],
                        [  7.65075684e-02,   7.65380859e-02],
                        [ -5.09338379e-02,  -5.09033203e-02],
                        [ -1.86248779e-01,  -1.86248779e-01],
                        [ -3.01574707e-01,  -3.01544189e-01],
                        [ -3.69049072e-01,  -3.69049072e-01],
                        [ -3.72344971e-01,  -3.72344971e-01],
                        [ -3.21960449e-01,  -3.21960449e-01],
                        [ -2.52197266e-01,  -2.52197266e-01],
                        [ -1.95617676e-01,  -1.95617676e-01],
                        [ -1.59301758e-01,  -1.59301758e-01],
                        [ -1.25152588e-01,  -1.25152588e-01],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  1.28967285e-01,   1.28967285e-01],
                        [  1.35833740e-01,   1.35833740e-01],
                        [  1.40197754e-01,   1.40197754e-01],
                        [  1.46331787e-01,   1.46331787e-01],
                        [  1.50054932e-01,   1.50054932e-01],
                        [  1.44256592e-01,   1.44256592e-01],
                        [  1.28540039e-01,   1.28509521e-01],
                        [  1.11633301e-01,   1.11633301e-01],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  7.22961426e-02,   7.22961426e-02],
                        [  7.88574219e-02,   7.88574219e-02],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  6.97631836e-02,   6.97631836e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.64794922e-03,   1.67846680e-03],
                        [ -2.31933594e-03,  -2.34985352e-03],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  3.60107422e-03,   3.57055664e-03],
                        [  1.98364258e-03,   2.01416016e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.13623047e-02,   2.13928223e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  1.77001953e-02,   1.76696777e-02],
                        [  9.36889648e-03,   9.39941406e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -2.25830078e-03,  -2.28881836e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -6.34765625e-03,  -6.31713867e-03],
                        [ -9.55200195e-03,  -9.58251953e-03],
                        [ -1.65100098e-02,  -1.65405273e-02],
                        [ -2.34680176e-02,  -2.34375000e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -2.93884277e-02,  -2.94189453e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.49731445e-02,  -3.50036621e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.92761230e-02,  -3.93066406e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.33251953e-02,  -3.32946777e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  2.41699219e-02,   2.42004395e-02],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -5.34973145e-02,  -5.35278320e-02],
                        [ -1.01196289e-01,  -1.01165771e-01],
                        [ -1.29150391e-01,  -1.29150391e-01],
                        [ -1.29211426e-01,  -1.29241943e-01],
                        [ -1.07086182e-01,  -1.07086182e-01],
                        [ -7.44628906e-02,  -7.44323730e-02],
                        [ -4.50439453e-02,  -4.50744629e-02],
                        [ -2.63366699e-02,  -2.63671875e-02],
                        [ -9.73510742e-03,  -9.70458984e-03],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  6.62536621e-02,   6.62231445e-02],
                        [  1.22406006e-01,   1.22436523e-01],
                        [  1.74743652e-01,   1.74774170e-01],
                        [  2.05108643e-01,   2.05047607e-01],
                        [  1.97174072e-01,   1.97204590e-01],
                        [  1.44653320e-01,   1.44714355e-01],
                        [  4.90112305e-02,   4.89807129e-02],
                        [ -8.03527832e-02,  -8.03833008e-02],
                        [ -2.18658447e-01,  -2.18597412e-01],
                        [ -3.29833984e-01,  -3.29833984e-01],
                        [ -3.84674072e-01,  -3.84704590e-01],
                        [ -3.75305176e-01,  -3.75274658e-01],
                        [ -3.20526123e-01,  -3.20526123e-01],
                        [ -2.55981445e-01,  -2.56011963e-01],
                        [ -2.07214355e-01,  -2.07214355e-01],
                        [ -1.70501709e-01,  -1.70471191e-01],
                        [ -1.24206543e-01,  -1.24206543e-01],
                        [ -5.52673340e-02,  -5.52978516e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  1.04736328e-01,   1.04766846e-01],
                        [  1.52557373e-01,   1.52526855e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.60614014e-01,   1.60644531e-01],
                        [  1.53686523e-01,   1.53656006e-01],
                        [  1.50360107e-01,   1.50329590e-01],
                        [  1.44592285e-01,   1.44622803e-01],
                        [  1.29730225e-01,   1.29699707e-01],
                        [  1.05804443e-01,   1.05773926e-01],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.70898438e-03,   1.67846680e-03],
                        [ -6.71386719e-04,  -7.01904297e-04],
                        [  1.01928711e-02,   1.02233887e-02],
                        [  2.99072266e-02,   2.99377441e-02],
                        [  5.04760742e-02,   5.04455566e-02],
                        [  6.76269531e-02,   6.76574707e-02],
                        [  8.18481445e-02,   8.18481445e-02],
                        [  9.20715332e-02,   9.20410156e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.50317383e-02,   9.50622559e-02],
                        [  8.96301270e-02,   8.96301270e-02],
                        [  7.80334473e-02,   7.80029297e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  3.36303711e-02,   3.35998535e-02],
                        [  2.08129883e-02,   2.08435059e-02],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -1.46484375e-02,  -1.46789551e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [  4.42504883e-03,   4.39453125e-03],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  2.57873535e-02,   2.57568359e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -2.10876465e-02,  -2.11181641e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -3.28063965e-02,  -3.28369141e-02],
                        [ -3.26843262e-02,  -3.27148438e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.12597656e-02,  -4.12902832e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -2.45666504e-02,  -2.45361328e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  1.28479004e-02,   1.28784180e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.26745605e-02,   2.27050781e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -9.07592773e-02,  -9.07592773e-02],
                        [ -1.33270264e-01,  -1.33270264e-01],
                        [ -1.45080566e-01,  -1.45111084e-01],
                        [ -1.21490479e-01,  -1.21490479e-01],
                        [ -7.49816895e-02,  -7.49511719e-02],
                        [ -2.83813477e-02,  -2.84118652e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  1.70288086e-02,   1.70593262e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.50543213e-01,   1.50543213e-01],
                        [  1.82403564e-01,   1.82373047e-01],
                        [  1.82434082e-01,   1.82434082e-01],
                        [  1.37115479e-01,   1.37115479e-01],
                        [  4.36096191e-02,   4.36096191e-02],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -2.19757080e-01,  -2.19757080e-01],
                        [ -3.26477051e-01,  -3.26477051e-01],
                        [ -3.76220703e-01,  -3.76220703e-01],
                        [ -3.61724854e-01,  -3.61694336e-01],
                        [ -3.03771973e-01,  -3.03771973e-01],
                        [ -2.39562988e-01,  -2.39562988e-01],
                        [ -1.94824219e-01,  -1.94824219e-01],
                        [ -1.64489746e-01,  -1.64489746e-01],
                        [ -1.24145508e-01,  -1.24176025e-01],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  1.29791260e-01,   1.29791260e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.34124756e-01,   1.34124756e-01],
                        [  1.35131836e-01,   1.35101318e-01],
                        [  1.40594482e-01,   1.40594482e-01],
                        [  1.38916016e-01,   1.38946533e-01],
                        [  1.23229980e-01,   1.23199463e-01],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  7.70263672e-02,   7.70568848e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  4.50744629e-02,   4.50439453e-02],
                        [  3.32031250e-02,   3.32336426e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  2.58483887e-02,   2.58789062e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  5.38940430e-02,   5.38635254e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  8.89282227e-02,   8.88977051e-02],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [ -2.38037109e-03,  -2.41088867e-03],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  6.74438477e-03,   6.77490234e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -2.01721191e-02,  -2.02026367e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -3.03955078e-02,  -3.03649902e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.29492188e-02,  -2.29187012e-02],
                        [ -1.33361816e-02,  -1.33666992e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [  8.30078125e-03,   8.33129883e-03],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [ -6.25610352e-03,  -6.22558594e-03],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -7.29675293e-02,  -7.29980469e-02],
                        [ -9.56726074e-02,  -9.56420898e-02],
                        [ -9.16137695e-02,  -9.15832520e-02],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -1.73339844e-02,  -1.73034668e-02],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [  1.73645020e-02,   1.73339844e-02],
                        [  5.01708984e-02,   5.02014160e-02],
                        [  9.14916992e-02,   9.15222168e-02],
                        [  1.33697510e-01,   1.33666992e-01],
                        [  1.64306641e-01,   1.64276123e-01],
                        [  1.67663574e-01,   1.67663574e-01],
                        [  1.29211426e-01,   1.29211426e-01],
                        [  4.23889160e-02,   4.23889160e-02],
                        [ -8.21533203e-02,  -8.21533203e-02],
                        [ -2.14050293e-01,  -2.14050293e-01],
                        [ -3.14819336e-01,  -3.14819336e-01],
                        [ -3.57208252e-01,  -3.57238770e-01],
                        [ -3.38531494e-01,  -3.38531494e-01],
                        [ -2.80914307e-01,  -2.80914307e-01],
                        [ -2.17681885e-01,  -2.17712402e-01],
                        [ -1.70379639e-01,  -1.70379639e-01],
                        [ -1.35437012e-01,  -1.35437012e-01],
                        [ -9.50927734e-02,  -9.51232910e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  1.05133057e-01,   1.05163574e-01],
                        [  1.03057861e-01,   1.03057861e-01],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.21368408e-01,   1.21368408e-01],
                        [  1.32324219e-01,   1.32324219e-01],
                        [  1.33056641e-01,   1.33056641e-01],
                        [  1.22314453e-01,   1.22344971e-01],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  8.90197754e-02,   8.90197754e-02],
                        [  7.38220215e-02,   7.37915039e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  4.01306152e-02,   4.01000977e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  6.51245117e-02,   6.51245117e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  7.13500977e-02,   7.13195801e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  6.24084473e-02,   6.24389648e-02],
                        [  5.02014160e-02,   5.01708984e-02],
                        [  3.29284668e-02,   3.28979492e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -5.52368164e-03,  -5.55419922e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -8.17871094e-03,  -8.20922852e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  1.20239258e-02,   1.20544434e-02],
                        [  2.06909180e-02,   2.06604004e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  1.10778809e-02,   1.11083984e-02],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  2.68554688e-03,   2.65502930e-03],
                        [  1.27258301e-02,   1.27563477e-02],
                        [  2.74963379e-02,   2.75268555e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  1.53503418e-02,   1.53808594e-02],
                        [  5.70678711e-03,   5.73730469e-03],
                        [  3.57055664e-03,   3.54003906e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.22070312e-03,   1.25122070e-03],
                        [ -7.26318359e-03,  -7.29370117e-03],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -3.02429199e-02,  -3.02124023e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.77099609e-02,  -2.77404785e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -1.16882324e-02,  -1.16577148e-02],
                        [ -6.22558594e-03,  -6.25610352e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -2.80761719e-03,  -2.77709961e-03],
                        [ -7.32421875e-04,  -7.01904297e-04],
                        [ -3.38745117e-03,  -3.41796875e-03],
                        [ -1.47399902e-02,  -1.47094727e-02],
                        [ -3.10974121e-02,  -3.10668945e-02],
                        [ -4.73632812e-02,  -4.73937988e-02],
                        [ -6.00280762e-02,  -6.00585938e-02],
                        [ -6.38122559e-02,  -6.37817383e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -3.75366211e-02,  -3.75671387e-02],
                        [ -1.55639648e-02,  -1.55334473e-02],
                        [  6.07299805e-03,   6.10351562e-03],
                        [  2.06909180e-02,   2.06604004e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  1.57165527e-02,   1.57470703e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -4.20227051e-02,  -4.19921875e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -8.11767578e-03,  -8.14819336e-03],
                        [  1.11083984e-02,   1.10778809e-02],
                        [  3.07312012e-02,   3.07617188e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  1.33789062e-01,   1.33789062e-01],
                        [  1.56646729e-01,   1.56646729e-01],
                        [  1.44592285e-01,   1.44592285e-01],
                        [  8.52661133e-02,   8.52355957e-02],
                        [ -1.61437988e-02,  -1.61132812e-02],
                        [ -1.38610840e-01,  -1.38610840e-01],
                        [ -2.55859375e-01,  -2.55859375e-01],
                        [ -3.42010498e-01,  -3.42010498e-01],
                        [ -3.75732422e-01,  -3.75701904e-01],
                        [ -3.53637695e-01,  -3.53637695e-01],
                        [ -2.96752930e-01,  -2.96783447e-01],
                        [ -2.32696533e-01,  -2.32666016e-01],
                        [ -1.74530029e-01,  -1.74499512e-01],
                        [ -1.18835449e-01,  -1.18865967e-01],
                        [ -5.70373535e-02,  -5.70068359e-02],
                        [  1.21765137e-02,   1.22070312e-02],
                        [  7.65991211e-02,   7.65686035e-02],
                        [  1.19445801e-01,   1.19445801e-01],
                        [  1.33880615e-01,   1.33911133e-01],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.13006592e-01,   1.12976074e-01],
                        [  1.08245850e-01,   1.08276367e-01],
                        [  1.14868164e-01,   1.14868164e-01],
                        [  1.20208740e-01,   1.20178223e-01],
                        [  1.15509033e-01,   1.15509033e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  2.82592773e-02,   2.82287598e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.38244629e-02,   1.38549805e-02],
                        [  2.15148926e-02,   2.14843750e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  4.94079590e-02,   4.94384766e-02],
                        [  6.22863770e-02,   6.22863770e-02],
                        [  7.26623535e-02,   7.26318359e-02],
                        [  8.03222656e-02,   8.03527832e-02],
                        [  8.40454102e-02,   8.40454102e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  7.06481934e-02,   7.06787109e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  4.17785645e-02,   4.17480469e-02],
                        [  2.74658203e-02,   2.74963379e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -8.23974609e-03,  -8.20922852e-03],
                        [ -5.00488281e-03,  -4.97436523e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  6.86645508e-03,   6.89697266e-03],
                        [  1.83105469e-03,   1.80053711e-03],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -7.99560547e-03,  -7.96508789e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  2.61230469e-02,   2.60925293e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  1.75476074e-02,   1.75781250e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  4.97436523e-03,   5.00488281e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -1.11083984e-02,  -1.11389160e-02],
                        [ -2.54516602e-02,  -2.54211426e-02],
                        [ -3.54919434e-02,  -3.54614258e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.90417480e-02,  -4.90112305e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -5.30700684e-02,  -5.31005859e-02],
                        [ -5.29785156e-02,  -5.29479980e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -4.45251465e-02,  -4.45556641e-02],
                        [ -3.82080078e-02,  -3.81774902e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -5.37109375e-03,  -5.40161133e-03],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  3.26538086e-02,   3.26843262e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [ -2.75268555e-02,  -2.74963379e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -5.80749512e-02,  -5.80444336e-02],
                        [ -5.00793457e-02,  -5.00488281e-02],
                        [ -3.48815918e-02,  -3.49121094e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  4.78515625e-02,   4.78515625e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.61804199e-01,   1.61804199e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  8.05053711e-02,   8.05053711e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -1.50939941e-01,  -1.50939941e-01],
                        [ -2.79327393e-01,  -2.79327393e-01],
                        [ -3.66577148e-01,  -3.66577148e-01],
                        [ -3.89038086e-01,  -3.89038086e-01],
                        [ -3.51928711e-01,  -3.51959229e-01],
                        [ -2.81951904e-01,  -2.81951904e-01],
                        [ -2.10235596e-01,  -2.10205078e-01],
                        [ -1.54357910e-01,  -1.54388428e-01],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -5.09643555e-02,  -5.09338379e-02],
                        [  2.12707520e-02,   2.12402344e-02],
                        [  8.98437500e-02,   8.98132324e-02],
                        [  1.32141113e-01,   1.32141113e-01],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  1.31866455e-01,   1.31835938e-01],
                        [  1.20300293e-01,   1.20300293e-01],
                        [  1.16790771e-01,   1.16821289e-01],
                        [  1.16424561e-01,   1.16394043e-01],
                        [  1.11755371e-01,   1.11724854e-01],
                        [  1.03057861e-01,   1.03088379e-01],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  7.48291016e-02,   7.47985840e-02],
                        [  5.08117676e-02,   5.08422852e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  5.95092773e-03,   5.92041016e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -5.49316406e-03,  -5.46264648e-03],
                        [  1.27563477e-02,   1.27258301e-02],
                        [  3.97033691e-02,   3.96728516e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  8.00476074e-02,   8.00476074e-02],
                        [  8.78906250e-02,   8.78601074e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  8.25805664e-02,   8.26110840e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  7.12280273e-02,   7.12280273e-02],
                        [  6.05163574e-02,   6.05468750e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  9.21630859e-03,   9.18579102e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.74255371e-02,  -1.74560547e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.98364258e-02,   1.98669434e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.07116699e-02,   1.07421875e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.24206543e-02,   1.23901367e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.66320801e-02,   1.66015625e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  5.82885742e-03,   5.79833984e-03],
                        [ -1.19018555e-03,  -1.22070312e-03],
                        [ -1.01013184e-02,  -1.00708008e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -1.62963867e-02,  -1.63269043e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -4.21142578e-02,  -4.21447754e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -3.59191895e-02,  -3.58886719e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -6.89697266e-03,  -6.86645508e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  6.89697266e-03,   6.86645508e-03],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -6.34155273e-02,  -6.34460449e-02],
                        [ -7.80944824e-02,  -7.80944824e-02],
                        [ -7.36083984e-02,  -7.36083984e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  1.56829834e-01,   1.56860352e-01],
                        [  1.60095215e-01,   1.60095215e-01],
                        [  1.24298096e-01,   1.24267578e-01],
                        [  4.10766602e-02,   4.10766602e-02],
                        [ -8.28247070e-02,  -8.28247070e-02],
                        [ -2.20947266e-01,  -2.20947266e-01],
                        [ -3.33526611e-01,  -3.33526611e-01],
                        [ -3.86199951e-01,  -3.86199951e-01],
                        [ -3.70452881e-01,  -3.70483398e-01],
                        [ -3.08166504e-01,  -3.08166504e-01],
                        [ -2.35382080e-01,  -2.35382080e-01],
                        [ -1.75140381e-01,  -1.75140381e-01],
                        [ -1.22131348e-01,  -1.22131348e-01],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  1.18347168e-01,   1.18377686e-01],
                        [  1.05743408e-01,   1.05712891e-01],
                        [  9.44213867e-02,   9.43908691e-02],
                        [  9.25903320e-02,   9.25903320e-02],
                        [  9.50622559e-02,   9.50622559e-02],
                        [  9.10949707e-02,   9.10949707e-02],
                        [  7.97729492e-02,   7.98034668e-02],
                        [  7.01599121e-02,   7.01904297e-02],
                        [  6.70471191e-02,   6.70166016e-02],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  6.10656738e-02,   6.10961914e-02],
                        [  4.95605469e-02,   4.95300293e-02],
                        [  3.35083008e-02,   3.34777832e-02],
                        [  1.99279785e-02,   1.99584961e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.73645020e-02,   1.73339844e-02],
                        [  2.85949707e-02,   2.86254883e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  7.60192871e-02,   7.59887695e-02],
                        [  9.69848633e-02,   9.70153809e-02],
                        [  1.07757568e-01,   1.07788086e-01],
                        [  1.06933594e-01,   1.06903076e-01],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  8.18176270e-02,   8.18481445e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  5.28259277e-02,   5.27954102e-02],
                        [  3.50646973e-02,   3.50952148e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  4.45556641e-03,   4.42504883e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -6.65283203e-03,  -6.62231445e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -1.06201172e-02,  -1.05895996e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.89208984e-03,  -1.92260742e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -3.26538086e-03,  -3.23486328e-03],
                        [ -3.05175781e-04,  -3.35693359e-04],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.77001953e-02,   1.77307129e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  4.38842773e-02,   4.38537598e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  2.81066895e-02,   2.80761719e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -3.24401855e-02,  -3.24096680e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -6.43920898e-03,  -6.40869141e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -8.48388672e-03,  -8.45336914e-03],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -4.11682129e-02,  -4.11987305e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -3.99169922e-02,  -3.99475098e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.20635986e-01,   1.20666504e-01],
                        [  1.50115967e-01,   1.50115967e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  4.63562012e-02,   4.63562012e-02],
                        [ -7.39746094e-02,  -7.40051270e-02],
                        [ -2.11883545e-01,  -2.11883545e-01],
                        [ -3.25897217e-01,  -3.25897217e-01],
                        [ -3.78143311e-01,  -3.78143311e-01],
                        [ -3.59985352e-01,  -3.60015869e-01],
                        [ -2.96905518e-01,  -2.96905518e-01],
                        [ -2.26776123e-01,  -2.26776123e-01],
                        [ -1.71936035e-01,  -1.71936035e-01],
                        [ -1.27685547e-01,  -1.27685547e-01],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  1.05560303e-01,   1.05590820e-01],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  1.05224609e-01,   1.05224609e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  9.29260254e-02,   9.29260254e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  9.03625488e-02,   9.03320312e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  1.15783691e-01,   1.15814209e-01],
                        [  1.20422363e-01,   1.20391846e-01],
                        [  1.12731934e-01,   1.12731934e-01],
                        [  9.46350098e-02,   9.46655273e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -2.94799805e-02,  -2.95104980e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -5.03845215e-02,  -5.03540039e-02],
                        [ -4.05273438e-02,  -4.05578613e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  8.30078125e-03,   8.27026367e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -9.15527344e-05,  -6.10351562e-05],
                        [  5.18798828e-03,   5.15747070e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.46887207e-02,   2.47192383e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  3.96728516e-02,   3.97033691e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.10668945e-02,   3.10363770e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.41076660e-02,  -5.41076660e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  2.02941895e-02,   2.02636719e-02],
                        [  1.84020996e-02,   1.84326172e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -5.49316406e-03,  -5.52368164e-03],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -3.09448242e-02,  -3.09143066e-02],
                        [ -3.98559570e-02,  -3.98864746e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -7.82470703e-02,  -7.82470703e-02],
                        [ -7.66906738e-02,  -7.66906738e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.53472900e-01,   1.53472900e-01],
                        [  1.75781250e-01,   1.75750732e-01],
                        [  1.75598145e-01,   1.75598145e-01],
                        [  1.37695312e-01,   1.37695312e-01],
                        [  4.91027832e-02,   4.91027832e-02],
                        [ -8.88671875e-02,  -8.88671875e-02],
                        [ -2.49481201e-01,  -2.49481201e-01],
                        [ -3.84765625e-01,  -3.84765625e-01],
                        [ -4.50744629e-01,  -4.50744629e-01],
                        [ -4.34448242e-01,  -4.34448242e-01],
                        [ -3.60015869e-01,  -3.60015869e-01],
                        [ -2.70935059e-01,  -2.70965576e-01],
                        [ -1.98425293e-01,  -1.98425293e-01],
                        [ -1.40563965e-01,  -1.40563965e-01],
                        [ -7.62939453e-02,  -7.62939453e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.47949219e-01,   1.47949219e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  1.33850098e-01,   1.33850098e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.27807617e-01,   1.27807617e-01],
                        [  1.20239258e-01,   1.20239258e-01],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  8.97827148e-02,   8.97827148e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  6.82983398e-02,   6.82678223e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [ -2.09350586e-02,  -2.09655762e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -2.98156738e-02,  -2.97851562e-02],
                        [ -4.51660156e-03,  -4.54711914e-03],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  5.41076660e-02,   5.41381836e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  9.10949707e-02,   9.10949707e-02],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  1.13250732e-01,   1.13281250e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.00708008e-01,   1.00708008e-01],
                        [  8.66699219e-02,   8.67004395e-02],
                        [  6.91528320e-02,   6.91528320e-02],
                        [  5.09643555e-02,   5.09338379e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  1.68762207e-02,   1.69067383e-02],
                        [ -2.83813477e-03,  -2.86865234e-03],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -2.60009766e-02,  -2.59704590e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  4.09851074e-02,   4.09545898e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -7.07092285e-02,  -7.06787109e-02],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -7.62939453e-02,  -7.62939453e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -7.10449219e-02,  -7.10144043e-02],
                        [ -7.75146484e-02,  -7.75146484e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -3.08532715e-02,  -3.08227539e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  1.48193359e-01,   1.48193359e-01],
                        [  1.70654297e-01,   1.70654297e-01],
                        [  1.71386719e-01,   1.71386719e-01],
                        [  1.36932373e-01,   1.36962891e-01],
                        [  5.16052246e-02,   5.16052246e-02],
                        [ -8.51745605e-02,  -8.51745605e-02],
                        [ -2.40844727e-01,  -2.40814209e-01],
                        [ -3.62823486e-01,  -3.62823486e-01],
                        [ -4.13940430e-01,  -4.13940430e-01],
                        [ -3.91265869e-01,  -3.91265869e-01],
                        [ -3.20953369e-01,  -3.20922852e-01],
                        [ -2.40417480e-01,  -2.40417480e-01],
                        [ -1.74377441e-01,  -1.74377441e-01],
                        [ -1.20666504e-01,  -1.20666504e-01],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  8.16955566e-02,   8.16955566e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  8.78295898e-02,   8.78295898e-02],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  1.05651855e-01,   1.05651855e-01],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  4.88586426e-02,   4.88281250e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  7.97424316e-02,   7.97119141e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  7.60803223e-02,   7.61108398e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  5.34057617e-02,   5.33752441e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.76489258e-02,   2.76489258e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.52587891e-04,   1.22070312e-04],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  7.47680664e-03,   7.50732422e-03],
                        [  1.28173828e-02,   1.27868652e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -3.43017578e-02,  -3.42712402e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.53186035e-02,  -4.53491211e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  6.98242188e-02,   6.98242188e-02],
                        [  5.00183105e-02,   4.99877930e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -4.73022461e-02,  -4.73327637e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -2.64892578e-02,  -2.64587402e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  6.45751953e-02,   6.45751953e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.08306885e-01,  -1.08306885e-01],
                        [ -2.30590820e-01,  -2.30590820e-01],
                        [ -3.29956055e-01,  -3.29925537e-01],
                        [ -3.71917725e-01,  -3.71917725e-01],
                        [ -3.49456787e-01,  -3.49456787e-01],
                        [ -2.84667969e-01,  -2.84667969e-01],
                        [ -2.10632324e-01,  -2.10632324e-01],
                        [ -1.47705078e-01,  -1.47705078e-01],
                        [ -9.26208496e-02,  -9.26208496e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [  3.14941406e-02,   3.15246582e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  9.22851562e-02,   9.22851562e-02],
                        [  7.39440918e-02,   7.39440918e-02],
                        [  5.02624512e-02,   5.02624512e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  5.80749512e-02,   5.81054688e-02],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  8.65478516e-02,   8.65478516e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  7.82775879e-02,   7.82775879e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  1.70288086e-02,   1.70593262e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  1.03393555e-01,   1.03363037e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.07574463e-01,   1.07574463e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  2.97851562e-02,   2.98156738e-02],
                        [  3.69567871e-02,   3.69567871e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  1.02539062e-02,   1.02233887e-02],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  1.52587891e-04,   1.52587891e-04],
                        [ -2.41088867e-03,  -2.44140625e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -2.86865234e-02,  -2.86560059e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  1.23748779e-01,   1.23748779e-01],
                        [  1.48468018e-01,   1.48468018e-01],
                        [  1.38916016e-01,   1.38885498e-01],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [ -1.13372803e-01,  -1.13372803e-01],
                        [ -2.41241455e-01,  -2.41241455e-01],
                        [ -3.35754395e-01,  -3.35754395e-01],
                        [ -3.65081787e-01,  -3.65081787e-01],
                        [ -3.31146240e-01,  -3.31176758e-01],
                        [ -2.64770508e-01,  -2.64770508e-01],
                        [ -2.00531006e-01,  -2.00531006e-01],
                        [ -1.54052734e-01,  -1.54052734e-01],
                        [ -1.16973877e-01,  -1.16973877e-01],
                        [ -7.21130371e-02,  -7.21130371e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  4.93164062e-02,   4.93164062e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.13281250e-01,   1.13311768e-01],
                        [  1.17675781e-01,   1.17675781e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.08154297e-01,   1.08154297e-01],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  6.97631836e-02,   6.97631836e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  7.02819824e-02,   7.02514648e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.47290039e-02,   3.46984863e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.57165527e-02,   1.56860352e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -1.43127441e-02,  -1.43432617e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -6.67724609e-02,  -6.67724609e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  5.03540039e-02,   5.03540039e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  9.07287598e-02,   9.07287598e-02],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  1.09497070e-01,   1.09497070e-01],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -1.53045654e-01,  -1.53045654e-01],
                        [ -2.41668701e-01,  -2.41668701e-01],
                        [ -2.91076660e-01,  -2.91076660e-01],
                        [ -2.89489746e-01,  -2.89489746e-01],
                        [ -2.51281738e-01,  -2.51281738e-01],
                        [ -2.05749512e-01,  -2.05749512e-01],
                        [ -1.72302246e-01,  -1.72302246e-01],
                        [ -1.46240234e-01,  -1.46240234e-01],
                        [ -1.08886719e-01,  -1.08886719e-01],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  5.31921387e-02,   5.31921387e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  6.07299805e-02,   6.07299805e-02],
                        [  7.36389160e-02,   7.36389160e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  5.96008301e-02,   5.96313477e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.52478027e-02,   3.52172852e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  4.77905273e-02,   4.77905273e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  5.25817871e-02,   5.25817871e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.58081055e-01,   1.58081055e-01],
                        [  1.78039551e-01,   1.78039551e-01],
                        [  1.74468994e-01,   1.74468994e-01],
                        [  1.34796143e-01,   1.34796143e-01],
                        [  5.33142090e-02,   5.33142090e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -1.84387207e-01,  -1.84387207e-01],
                        [ -2.86071777e-01,  -2.86071777e-01],
                        [ -3.41125488e-01,  -3.41125488e-01],
                        [ -3.43322754e-01,  -3.43322754e-01],
                        [ -3.09448242e-01,  -3.09448242e-01],
                        [ -2.65899658e-01,  -2.65899658e-01],
                        [ -2.25830078e-01,  -2.25830078e-01],
                        [ -1.82739258e-01,  -1.82739258e-01],
                        [ -1.25762939e-01,  -1.25762939e-01],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  8.58154297e-02,   8.58154297e-02],
                        [  8.43505859e-02,   8.43505859e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  1.10717773e-01,   1.10717773e-01],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  9.51843262e-02,   9.51843262e-02],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  6.96411133e-02,   6.96411133e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -7.58056641e-02,  -7.58056641e-02],
                        [ -8.62121582e-02,  -8.62121582e-02],
                        [ -8.67919922e-02,  -8.67919922e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  4.14733887e-02,   4.14733887e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -8.61206055e-02,  -8.61206055e-02],
                        [ -8.85620117e-02,  -8.85620117e-02],
                        [ -7.65380859e-02,  -7.65380859e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  7.09228516e-02,   7.09228516e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  8.77380371e-02,   8.77380371e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  9.82666016e-02,   9.82666016e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -1.96868896e-01,  -1.96868896e-01],
                        [ -2.87200928e-01,  -2.87200928e-01],
                        [ -3.39996338e-01,  -3.39996338e-01],
                        [ -3.43383789e-01,  -3.43383789e-01],
                        [ -3.05938721e-01,  -3.05938721e-01],
                        [ -2.50885010e-01,  -2.50885010e-01],
                        [ -1.98822021e-01,  -1.98822021e-01],
                        [ -1.53808594e-01,  -1.53808594e-01],
                        [ -1.04644775e-01,  -1.04644775e-01],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  8.37402344e-02,   8.37402344e-02],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  9.19799805e-02,   9.19799805e-02],
                        [  8.59985352e-02,   8.59985352e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  5.80749512e-02,   5.80444336e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  3.18908691e-02,   3.18908691e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [ -2.99072266e-03,  -2.96020508e-03],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  3.83605957e-02,   3.83300781e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  8.64562988e-02,   8.64562988e-02],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  5.33447266e-02,   5.33752441e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -1.47094727e-01,  -1.47094727e-01],
                        [ -2.42309570e-01,  -2.42309570e-01],
                        [ -3.01025391e-01,  -3.01025391e-01],
                        [ -3.12042236e-01,  -3.12042236e-01],
                        [ -2.84423828e-01,  -2.84423828e-01],
                        [ -2.40661621e-01,  -2.40661621e-01],
                        [ -2.00744629e-01,  -2.00714111e-01],
                        [ -1.69525146e-01,  -1.69525146e-01],
                        [ -1.37542725e-01,  -1.37542725e-01],
                        [ -9.19494629e-02,  -9.19494629e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  1.17828369e-01,   1.17828369e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  1.14715576e-01,   1.14715576e-01],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  2.60925293e-02,   2.61230469e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  8.03833008e-02,   8.03833008e-02],
                        [  8.59985352e-02,   8.59985352e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  2.60620117e-02,   2.60314941e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -4.09545898e-02,  -4.09851074e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.73950195e-03,   1.70898438e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -1.14440918e-02,  -1.14135742e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -4.00085449e-02,  -3.99780273e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  7.45544434e-02,   7.45544434e-02],
                        [  1.11175537e-01,   1.11175537e-01],
                        [  1.47125244e-01,   1.47125244e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.82373047e-01,   1.82373047e-01],
                        [  1.66778564e-01,   1.66778564e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.60827637e-02,   1.60827637e-02],
                        [ -1.12091064e-01,  -1.12091064e-01],
                        [ -2.41455078e-01,  -2.41455078e-01],
                        [ -3.38745117e-01,  -3.38745117e-01],
                        [ -3.79821777e-01,  -3.79852295e-01],
                        [ -3.62030029e-01,  -3.62030029e-01],
                        [ -3.09051514e-01,  -3.09051514e-01],
                        [ -2.53784180e-01,  -2.53784180e-01],
                        [ -2.11181641e-01,  -2.11181641e-01],
                        [ -1.71417236e-01,  -1.71417236e-01],
                        [ -1.17706299e-01,  -1.17706299e-01],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  1.23962402e-01,   1.23962402e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.14349365e-01,   1.14318848e-01],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.48620605e-02,   1.48925781e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.42211914e-02,   1.41906738e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.53503418e-02,   1.53198242e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  4.46472168e-02,   4.46472168e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -2.67639160e-02,  -2.67333984e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [ -3.86657715e-02,  -3.86352539e-02],
                        [ -3.82385254e-02,  -3.82690430e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [  1.60522461e-02,   1.60827637e-02],
                        [  2.71301270e-02,   2.70996094e-02],
                        [  2.24609375e-02,   2.24914551e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -4.40673828e-02,  -4.40979004e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  7.62939453e-04,   7.93457031e-04],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  6.90307617e-02,   6.90307617e-02],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  8.52355957e-02,   8.52050781e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  8.92028809e-02,   8.92028809e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -1.57165527e-01,  -1.57165527e-01],
                        [ -2.39746094e-01,  -2.39746094e-01],
                        [ -2.86560059e-01,  -2.86560059e-01],
                        [ -2.92053223e-01,  -2.92053223e-01],
                        [ -2.67639160e-01,  -2.67639160e-01],
                        [ -2.32910156e-01,  -2.32910156e-01],
                        [ -2.03857422e-01,  -2.03857422e-01],
                        [ -1.83013916e-01,  -1.83013916e-01],
                        [ -1.58355713e-01,  -1.58355713e-01],
                        [ -1.16210938e-01,  -1.16210938e-01],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  6.80847168e-02,   6.81152344e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.34429932e-01,   1.34460449e-01],
                        [  1.44470215e-01,   1.44470215e-01],
                        [  1.38549805e-01,   1.38549805e-01],
                        [  1.23229980e-01,   1.23229980e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  4.90417480e-02,   4.90722656e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  8.48388672e-03,   8.48388672e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.17492676e-02,  -1.17187500e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.63562012e-02,   4.63562012e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -7.53784180e-03,  -7.50732422e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  2.93273926e-02,   2.93579102e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  8.85009766e-03,   8.85009766e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.01708984e-02,  -5.02014160e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -4.79125977e-03,  -4.76074219e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.38854980e-02,   1.38549805e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  1.23504639e-01,   1.23504639e-01],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  7.87963867e-02,   7.87658691e-02],
                        [  1.25122070e-03,   1.28173828e-03],
                        [ -1.11145020e-01,  -1.11145020e-01],
                        [ -2.30224609e-01,  -2.30255127e-01],
                        [ -3.18389893e-01,  -3.18389893e-01],
                        [ -3.52661133e-01,  -3.52661133e-01],
                        [ -3.36425781e-01,  -3.36456299e-01],
                        [ -2.92266846e-01,  -2.92266846e-01],
                        [ -2.44781494e-01,  -2.44750977e-01],
                        [ -2.04681396e-01,  -2.04681396e-01],
                        [ -1.66259766e-01,  -1.66259766e-01],
                        [ -1.18927002e-01,  -1.18927002e-01],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  1.04034424e-01,   1.04034424e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.39892578e-01,   1.39862061e-01],
                        [  1.47125244e-01,   1.47125244e-01],
                        [  1.49627686e-01,   1.49658203e-01],
                        [  1.44531250e-01,   1.44531250e-01],
                        [  1.30493164e-01,   1.30462646e-01],
                        [  1.08489990e-01,   1.08520508e-01],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  4.93164062e-02,   4.93164062e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  2.34375000e-02,   2.34680176e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  8.02307129e-02,   8.02307129e-02],
                        [  6.77490234e-02,   6.77795410e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  3.32946777e-02,   3.32641602e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  3.20434570e-03,   3.20434570e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.75781250e-02,  -1.75476074e-02],
                        [ -1.50756836e-02,  -1.51062012e-02],
                        [ -1.29394531e-02,  -1.29699707e-02],
                        [ -1.19018555e-02,  -1.18713379e-02],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  2.08129883e-02,   2.08435059e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  9.67407227e-03,   9.64355469e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -4.36401367e-03,  -4.33349609e-03],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -1.54724121e-02,  -1.55029297e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [ -1.30004883e-02,  -1.29699707e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -4.22973633e-02,  -4.22668457e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -5.15136719e-02,  -5.15441895e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -7.26318359e-03,  -7.23266602e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -6.13403320e-03,  -6.10351562e-03],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  4.43115234e-02,   4.42810059e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  3.99475098e-02,   3.99169922e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  6.04248047e-02,   6.04553223e-02],
                        [  7.36389160e-02,   7.36389160e-02],
                        [  8.55407715e-02,   8.55102539e-02],
                        [  9.31701660e-02,   9.31701660e-02],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  9.55810547e-02,   9.55505371e-02],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -1.36077881e-01,  -1.36077881e-01],
                        [ -2.36541748e-01,  -2.36541748e-01],
                        [ -3.04656982e-01,  -3.04656982e-01],
                        [ -3.24676514e-01,  -3.24676514e-01],
                        [ -3.04534912e-01,  -3.04534912e-01],
                        [ -2.68005371e-01,  -2.68005371e-01],
                        [ -2.35717773e-01,  -2.35717773e-01],
                        [ -2.09167480e-01,  -2.09167480e-01],
                        [ -1.72607422e-01,  -1.72607422e-01],
                        [ -1.12823486e-01,  -1.12823486e-01],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  8.16955566e-02,   8.16955566e-02],
                        [  1.02020264e-01,   1.02020264e-01],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  1.12213135e-01,   1.12213135e-01],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.06140137e-01,   1.06140137e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  7.28454590e-02,   7.28759766e-02],
                        [  5.87463379e-02,   5.87768555e-02],
                        [  5.41687012e-02,   5.41381836e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.34777832e-02,   3.34472656e-02],
                        [  2.17590332e-02,   2.17285156e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  2.68249512e-02,   2.68554688e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.29589844e-02,   3.29895020e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  5.60913086e-02,   5.60913086e-02],
                        [  5.61523438e-02,   5.61218262e-02],
                        [  4.90112305e-02,   4.90417480e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  4.69970703e-03,   4.66918945e-03],
                        [ -1.65710449e-02,  -1.65405273e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.89306641e-02,  -2.89611816e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.24511719e-02,  -1.24206543e-02],
                        [ -1.34277344e-03,  -1.37329102e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.02233887e-02,   1.02539062e-02],
                        [  4.66918945e-03,   4.63867188e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -1.15966797e-02,  -1.15661621e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.29187012e-02,  -2.28881836e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  3.35083008e-02,   3.34777832e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  1.08947754e-02,   1.09252930e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -1.55639648e-03,  -1.52587891e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.69372559e-02,   1.69067383e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  6.24389648e-02,   6.24694824e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  1.35437012e-01,   1.35437012e-01],
                        [  1.46240234e-01,   1.46240234e-01],
                        [  1.43981934e-01,   1.43981934e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  4.81872559e-02,   4.81872559e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -1.78497314e-01,  -1.78497314e-01],
                        [ -2.72949219e-01,  -2.72949219e-01],
                        [ -3.18237305e-01,  -3.18237305e-01],
                        [ -3.12286377e-01,  -3.12286377e-01],
                        [ -2.74566650e-01,  -2.74536133e-01],
                        [ -2.32666016e-01,  -2.32635498e-01],
                        [ -2.00775146e-01,  -2.00805664e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.35009766e-01,  -1.35009766e-01],
                        [ -8.40148926e-02,  -8.40454102e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [  2.40783691e-02,   2.41088867e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  8.64868164e-02,   8.64868164e-02],
                        [  9.79919434e-02,   9.79919434e-02],
                        [  1.01837158e-01,   1.01837158e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  7.51342773e-02,   7.51342773e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.78417969e-02,   3.78112793e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.79541016e-02,   2.79235840e-02],
                        [  3.19213867e-02,   3.19519043e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.54919434e-02,   3.54614258e-02],
                        [  3.56445312e-02,   3.56750488e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  1.96228027e-02,   1.95922852e-02],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -1.89208984e-02,  -1.88903809e-02],
                        [ -1.86767578e-02,  -1.87072754e-02],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  5.21850586e-03,   5.21850586e-03],
                        [ -1.12915039e-02,  -1.13220215e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.66320801e-02,  -1.66015625e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  5.76782227e-03,   5.79833984e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.28271484e-02,   2.27966309e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.79125977e-02,   4.79431152e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  1.80969238e-02,   1.81274414e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  2.22778320e-03,   2.22778320e-03],
                        [ -1.04064941e-02,  -1.03759766e-02],
                        [ -1.90734863e-02,  -1.91040039e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.85852051e-02,  -1.85546875e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -2.20642090e-02,  -2.20947266e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  2.92968750e-03,   2.89916992e-03],
                        [ -5.79833984e-03,  -5.82885742e-03],
                        [ -1.45568848e-02,  -1.45263672e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -2.96020508e-02,  -2.96325684e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -4.70581055e-02,  -4.70275879e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.10461426e-02,  -4.10156250e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -6.10351562e-03,  -6.07299805e-03],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  1.07116699e-02,   1.06811523e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  8.08715820e-03,   8.05664062e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.84521484e-02,   3.84216309e-02],
                        [  4.21752930e-02,   4.22058105e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  6.92138672e-02,   6.92138672e-02],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  1.19934082e-01,   1.19934082e-01],
                        [  1.34735107e-01,   1.34735107e-01],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  8.21228027e-02,   8.21228027e-02],
                        [  2.74658203e-04,   3.05175781e-04],
                        [ -1.10412598e-01,  -1.10412598e-01],
                        [ -2.25219727e-01,  -2.25219727e-01],
                        [ -3.12744141e-01,  -3.12744141e-01],
                        [ -3.50433350e-01,  -3.50433350e-01],
                        [ -3.35418701e-01,  -3.35418701e-01],
                        [ -2.84637451e-01,  -2.84606934e-01],
                        [ -2.23602295e-01,  -2.23602295e-01],
                        [ -1.72119141e-01,  -1.72149658e-01],
                        [ -1.33453369e-01,  -1.33453369e-01],
                        [ -9.40856934e-02,  -9.40551758e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  1.00372314e-01,   1.00372314e-01],
                        [  8.76159668e-02,   8.76159668e-02],
                        [  7.45239258e-02,   7.45544434e-02],
                        [  6.82373047e-02,   6.82067871e-02],
                        [  6.92749023e-02,   6.92749023e-02],
                        [  7.14416504e-02,   7.14721680e-02],
                        [  7.04650879e-02,   7.04345703e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  4.06799316e-02,   4.06494141e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  8.92944336e-02,   8.92944336e-02],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.42919922e-02,  -2.43225098e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [  2.04467773e-03,   2.04467773e-03],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  4.01306152e-02,   4.01000977e-02],
                        [  4.81262207e-02,   4.80957031e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  6.07299805e-02,   6.07299805e-02],
                        [  6.20422363e-02,   6.20422363e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  6.89697266e-03,   6.86645508e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.09558105e-02,  -1.09252930e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [ -9.73510742e-03,  -9.76562500e-03],
                        [ -1.13830566e-02,  -1.14135742e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.96118164e-02,  -3.96423340e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -4.82177734e-03,  -4.85229492e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  8.42285156e-03,   8.39233398e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [ -1.00708008e-03,  -9.76562500e-04],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -6.07299805e-03,  -6.10351562e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  2.49023438e-02,   2.49328613e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  8.29772949e-02,   8.30078125e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -1.83349609e-01,  -1.83349609e-01],
                        [ -2.86132812e-01,  -2.86132812e-01],
                        [ -3.39782715e-01,  -3.39782715e-01],
                        [ -3.32153320e-01,  -3.32153320e-01],
                        [ -2.83386230e-01,  -2.83386230e-01],
                        [ -2.29492188e-01,  -2.29492188e-01],
                        [ -1.93298340e-01,  -1.93298340e-01],
                        [ -1.69769287e-01,  -1.69769287e-01],
                        [ -1.38854980e-01,  -1.38854980e-01],
                        [ -8.85009766e-02,  -8.85009766e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  8.20007324e-02,   8.20007324e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.04339600e-01,   1.04370117e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.19903564e-01,   1.19903564e-01],
                        [  1.30218506e-01,   1.30249023e-01],
                        [  1.30767822e-01,   1.30767822e-01],
                        [  1.20635986e-01,   1.20605469e-01],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  8.35571289e-02,   8.35876465e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  1.07727051e-02,   1.07421875e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  1.19018555e-03,   1.22070312e-03],
                        [  1.11694336e-02,   1.11389160e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  4.42504883e-02,   4.42810059e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  6.25305176e-02,   6.25000000e-02],
                        [  5.88378906e-02,   5.88684082e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  2.55126953e-02,   2.54821777e-02],
                        [  8.88061523e-03,   8.91113281e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  4.47387695e-02,   4.47692871e-02],
                        [  4.03442383e-02,   4.03442383e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  2.40478516e-02,   2.40173340e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  1.65710449e-02,   1.66015625e-02],
                        [  1.32751465e-02,   1.32446289e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.15966797e-03,   1.19018555e-03],
                        [ -7.75146484e-03,  -7.78198242e-03],
                        [ -1.71203613e-02,  -1.71508789e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -3.96118164e-02,  -3.95812988e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -2.99072266e-03,  -3.02124023e-03],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -1.85241699e-02,  -1.84936523e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -1.55944824e-02,  -1.55639648e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -9.15527344e-04,  -8.85009766e-04],
                        [  3.26538086e-03,   3.23486328e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  5.49316406e-03,   5.52368164e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  4.97436523e-03,   5.00488281e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  3.58276367e-02,   3.57971191e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  9.01489258e-02,   9.01794434e-02],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.55090332e-01,   1.55090332e-01],
                        [  1.48376465e-01,   1.48376465e-01],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  3.38439941e-02,   3.38439941e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -1.79046631e-01,  -1.79046631e-01],
                        [ -2.79113770e-01,  -2.79113770e-01],
                        [ -3.37341309e-01,  -3.37341309e-01],
                        [ -3.40332031e-01,  -3.40332031e-01],
                        [ -3.02062988e-01,  -3.02062988e-01],
                        [ -2.51037598e-01,  -2.51037598e-01],
                        [ -2.07092285e-01,  -2.07122803e-01],
                        [ -1.71478271e-01,  -1.71478271e-01],
                        [ -1.31835938e-01,  -1.31835938e-01],
                        [ -7.74230957e-02,  -7.74230957e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  9.60083008e-02,   9.60083008e-02],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  1.02935791e-01,   1.02966309e-01],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  3.02124023e-02,   3.01818848e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.41088867e-03,   2.41088867e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  6.90917969e-02,   6.90917969e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.39343262e-02,  -6.39343262e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.62243652e-02,   3.62548828e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  4.20532227e-02,   4.20227051e-02],
                        [  4.69360352e-02,   4.69055176e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  5.22766113e-02,   5.22460938e-02],
                        [  5.61218262e-02,   5.61523438e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.25830078e-03,   2.22778320e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -5.43212891e-03,  -5.40161133e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.15148926e-02,  -2.15454102e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -2.74658203e-04,  -2.44140625e-04],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  1.09832764e-01,   1.09832764e-01],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -1.46789551e-01,  -1.46789551e-01],
                        [ -2.43804932e-01,  -2.43835449e-01],
                        [ -3.06976318e-01,  -3.06945801e-01],
                        [ -3.16833496e-01,  -3.16833496e-01],
                        [ -2.83142090e-01,  -2.83142090e-01],
                        [ -2.40631104e-01,  -2.40631104e-01],
                        [ -2.14477539e-01,  -2.14477539e-01],
                        [ -1.96014404e-01,  -1.96044922e-01],
                        [ -1.61102295e-01,  -1.61102295e-01],
                        [ -1.01562500e-01,  -1.01562500e-01],
                        [ -2.94189453e-02,  -2.94494629e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  7.82470703e-02,   7.82775879e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  8.88061523e-02,   8.88061523e-02],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  7.08923340e-02,   7.08923340e-02],
                        [  5.93566895e-02,   5.93566895e-02],
                        [  4.73937988e-02,   4.73632812e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  7.22656250e-02,   7.22656250e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  2.83508301e-02,   2.83813477e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  5.08117676e-02,   5.07812500e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.23693848e-02,   2.23999023e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.72119141e-02,   1.71813965e-02],
                        [  1.99890137e-02,   2.00195312e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  1.40075684e-02,   1.39770508e-02],
                        [  5.82885742e-03,   5.82885742e-03],
                        [ -3.75366211e-03,  -3.72314453e-03],
                        [ -1.16271973e-02,  -1.16577148e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -3.19519043e-02,  -3.19213867e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -5.62133789e-02,  -5.62438965e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  8.97216797e-03,   9.00268555e-03],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [  4.63867188e-03,   4.66918945e-03],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  3.28979492e-02,   3.28674316e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  5.20324707e-02,   5.20629883e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  6.80847168e-02,   6.80847168e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  8.34960938e-02,   8.35266113e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -1.63940430e-01,  -1.63909912e-01],
                        [ -2.55310059e-01,  -2.55340576e-01],
                        [ -3.12622070e-01,  -3.12652588e-01],
                        [ -3.21502686e-01,  -3.21472168e-01],
                        [ -2.89398193e-01,  -2.89398193e-01],
                        [ -2.39685059e-01,  -2.39715576e-01],
                        [ -1.96502686e-01,  -1.96502686e-01],
                        [ -1.67144775e-01,  -1.67144775e-01],
                        [ -1.38610840e-01,  -1.38610840e-01],
                        [ -9.45129395e-02,  -9.45129395e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  6.63146973e-02,   6.62841797e-02],
                        [  9.36584473e-02,   9.36584473e-02],
                        [  1.10107422e-01,   1.10107422e-01],
                        [  1.17218018e-01,   1.17187500e-01],
                        [  1.16760254e-01,   1.16760254e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  9.66186523e-02,   9.66186523e-02],
                        [  7.80944824e-02,   7.80944824e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  2.34680176e-02,   2.34375000e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  1.19934082e-02,   1.19628906e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  8.36181641e-02,   8.35876465e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -2.12402344e-02,  -2.12707520e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -3.03039551e-02,  -3.02734375e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.06396484e-02,  -3.06091309e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  3.93981934e-02,   3.93676758e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  2.33154297e-02,   2.32849121e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -1.91040039e-02,  -1.90734863e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  2.35595703e-02,   2.35290527e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  3.05175781e-04,   3.35693359e-04],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -2.89916992e-03,  -2.86865234e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  4.78515625e-02,   4.78820801e-02],
                        [  6.30493164e-02,   6.30493164e-02],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  1.13708496e-01,   1.13739014e-01],
                        [  1.33117676e-01,   1.33087158e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  6.28662109e-02,   6.28662109e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.41082764e-01,  -1.41082764e-01],
                        [ -2.47253418e-01,  -2.47253418e-01],
                        [ -3.13659668e-01,  -3.13659668e-01],
                        [ -3.22143555e-01,  -3.22113037e-01],
                        [ -2.80242920e-01,  -2.80273438e-01],
                        [ -2.22259521e-01,  -2.22259521e-01],
                        [ -1.86401367e-01,  -1.86370850e-01],
                        [ -1.81060791e-01,  -1.81060791e-01],
                        [ -1.80664062e-01,  -1.80664062e-01],
                        [ -1.56921387e-01,  -1.56890869e-01],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -3.84521484e-02,  -3.84826660e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  1.16027832e-01,   1.16027832e-01],
                        [  1.30950928e-01,   1.30950928e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  1.16821289e-01,   1.16821289e-01],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  1.08856201e-01,   1.08856201e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  9.20715332e-02,   9.20715332e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  3.34472656e-02,   3.34167480e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  2.94189453e-02,   2.93884277e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.23376465e-02,   5.23071289e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.99987793e-02,  -2.99682617e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.89294434e-02,  -5.89294434e-02],
                        [ -4.63562012e-02,  -4.63256836e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  2.53601074e-02,   2.53295898e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.28674316e-02,   3.28979492e-02],
                        [  2.95410156e-02,   2.95104980e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.32238770e-02,   2.31933594e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  1.58996582e-02,   1.59301758e-02],
                        [  1.49536133e-02,   1.49230957e-02],
                        [  1.86767578e-02,   1.86462402e-02],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.11181641e-02,   2.10876465e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  2.62451172e-03,   2.65502930e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -2.93884277e-02,  -2.93579102e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.15551758e-02,  -3.15856934e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -3.60107422e-02,  -3.59802246e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.10363770e-02,  -3.10058594e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -1.98669434e-02,  -1.98974609e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -8.51440430e-03,  -8.48388672e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -6.10351562e-04,  -5.79833984e-04],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  9.68627930e-02,   9.68933105e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -1.43798828e-01,  -1.43798828e-01],
                        [ -2.48443604e-01,  -2.48443604e-01],
                        [ -3.17840576e-01,  -3.17840576e-01],
                        [ -3.26751709e-01,  -3.26751709e-01],
                        [ -2.84637451e-01,  -2.84637451e-01],
                        [ -2.27325439e-01,  -2.27325439e-01],
                        [ -1.85272217e-01,  -1.85272217e-01],
                        [ -1.63391113e-01,  -1.63391113e-01],
                        [ -1.48223877e-01,  -1.48223877e-01],
                        [ -1.24664307e-01,  -1.24664307e-01],
                        [ -8.52355957e-02,  -8.52355957e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  6.17370605e-02,   6.17065430e-02],
                        [  9.61914062e-02,   9.61914062e-02],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.33331299e-01,   1.33331299e-01],
                        [  1.33850098e-01,   1.33850098e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.23596191e-01,   1.23596191e-01],
                        [  1.15051270e-01,   1.15051270e-01],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  5.95703125e-02,   5.95397949e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  4.60815430e-02,   4.61120605e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  4.93774414e-02,   4.94079590e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -2.28576660e-02,  -2.28271484e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.26647949e-02,  -1.26953125e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.08032227e-02,  -1.07727051e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.42517090e-02,  -1.42211914e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -4.30297852e-03,  -4.33349609e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  3.87878418e-02,   3.88183594e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  4.44335938e-02,   4.44030762e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  3.32336426e-02,   3.32641602e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  3.07312012e-02,   3.07006836e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [ -9.58251953e-03,  -9.55200195e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.23999023e-02,  -2.24304199e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.42004395e-02,  -2.41699219e-02],
                        [ -2.65808105e-02,  -2.66113281e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.10266113e-02,  -2.09960938e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.02844238e-02,  -1.02539062e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.40380859e-02,  -1.40075684e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  7.81250000e-03,   7.78198242e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  1.75781250e-02,   1.75476074e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.39068604e-01,   1.39099121e-01],
                        [  1.18225098e-01,   1.18225098e-01],
                        [  6.84814453e-02,   6.84509277e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.18682861e-01,  -1.18682861e-01],
                        [ -2.28302002e-01,  -2.28302002e-01],
                        [ -3.07159424e-01,  -3.07159424e-01],
                        [ -3.27880859e-01,  -3.27850342e-01],
                        [ -2.93457031e-01,  -2.93457031e-01],
                        [ -2.37945557e-01,  -2.37945557e-01],
                        [ -1.97845459e-01,  -1.97875977e-01],
                        [ -1.83471680e-01,  -1.83441162e-01],
                        [ -1.77154541e-01,  -1.77154541e-01],
                        [ -1.55639648e-01,  -1.55670166e-01],
                        [ -1.11785889e-01,  -1.11755371e-01],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  1.10961914e-01,   1.10992432e-01],
                        [  1.41662598e-01,   1.41632080e-01],
                        [  1.50970459e-01,   1.50939941e-01],
                        [  1.42974854e-01,   1.42974854e-01],
                        [  1.26831055e-01,   1.26800537e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  6.57653809e-02,   6.57653809e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.85021973e-02,   5.85327148e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -2.08435059e-02,  -2.08740234e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -2.01110840e-02,  -2.01416016e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.57263184e-02,  -2.56958008e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  4.42504883e-03,   4.45556641e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  2.31933594e-02,   2.32238770e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  3.87268066e-02,   3.86962891e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  3.98864746e-02,   3.99169922e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.72314453e-02,   3.72619629e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [  4.27246094e-04,   4.27246094e-04],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -4.88281250e-03,  -4.85229492e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -3.74755859e-02,  -3.75061035e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.42407227e-02,  -3.42102051e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.40478516e-02,  -2.40783691e-02],
                        [ -1.89819336e-02,  -1.89514160e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -5.73730469e-03,  -5.70678711e-03],
                        [ -8.27026367e-03,  -8.30078125e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.34277344e-02,  -1.33972168e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -7.47680664e-03,  -7.44628906e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.95922852e-02,  -1.95617676e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [  8.54492188e-04,   8.23974609e-04],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  8.81958008e-03,   8.85009766e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  7.17163086e-03,   7.14111328e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  6.14013672e-02,   6.14013672e-02],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  1.17248535e-01,   1.17248535e-01],
                        [  1.43005371e-01,   1.43005371e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  1.26892090e-01,   1.26892090e-01],
                        [  6.80236816e-02,   6.80236816e-02],
                        [ -2.62756348e-02,  -2.63061523e-02],
                        [ -1.43280029e-01,  -1.43249512e-01],
                        [ -2.54089355e-01,  -2.54089355e-01],
                        [ -3.25378418e-01,  -3.25378418e-01],
                        [ -3.39599609e-01,  -3.39599609e-01],
                        [ -3.04931641e-01,  -3.04931641e-01],
                        [ -2.48382568e-01,  -2.48382568e-01],
                        [ -1.99768066e-01,  -1.99768066e-01],
                        [ -1.72393799e-01,  -1.72363281e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.26159668e-01,  -1.26159668e-01],
                        [ -8.32214355e-02,  -8.32214355e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  9.58251953e-02,   9.58557129e-02],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  1.28112793e-01,   1.28082275e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  1.18255615e-01,   1.18225098e-01],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  7.63549805e-02,   7.63244629e-02],
                        [  7.06787109e-02,   7.06481934e-02],
                        [  7.93151855e-02,   7.93457031e-02],
                        [  8.79821777e-02,   8.79821777e-02],
                        [  8.30078125e-02,   8.29772949e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  1.39770508e-02,   1.39465332e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.02941895e-02,  -2.03247070e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -2.07519531e-03,  -2.10571289e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -1.92565918e-02,  -1.92260742e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -1.70593262e-02,  -1.70288086e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  3.16467285e-02,   3.16772461e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  3.66516113e-02,   3.66210938e-02],
                        [  2.32543945e-02,   2.32849121e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -2.12402344e-02,  -2.12097168e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.94494629e-02,  -2.94799805e-02],
                        [ -2.88391113e-02,  -2.88085938e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.29284668e-02,  -3.28979492e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -1.95922852e-02,  -1.95617676e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -1.41601562e-02,  -1.41906738e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -9.46044922e-04,  -9.15527344e-04],
                        [  1.80053711e-03,   1.77001953e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -1.06811523e-03,  -1.03759766e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.08337402e-02,   1.08642578e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  2.67639160e-02,   2.67333984e-02],
                        [  5.08728027e-02,   5.09033203e-02],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.52587891e-01,   1.52618408e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.26953125e-01,   1.26953125e-01],
                        [  6.32934570e-02,   6.32934570e-02],
                        [ -3.53698730e-02,  -3.53393555e-02],
                        [ -1.54296875e-01,  -1.54296875e-01],
                        [ -2.62634277e-01,  -2.62664795e-01],
                        [ -3.26751709e-01,  -3.26751709e-01],
                        [ -3.30474854e-01,  -3.30474854e-01],
                        [ -2.86376953e-01,  -2.86407471e-01],
                        [ -2.28820801e-01,  -2.28820801e-01],
                        [ -1.89910889e-01,  -1.89880371e-01],
                        [ -1.76239014e-01,  -1.76239014e-01],
                        [ -1.70227051e-01,  -1.70257568e-01],
                        [ -1.52343750e-01,  -1.52313232e-01],
                        [ -1.16699219e-01,  -1.16699219e-01],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [  4.87365723e-02,   4.87670898e-02],
                        [  1.05468750e-01,   1.05438232e-01],
                        [  1.46331787e-01,   1.46301270e-01],
                        [  1.61254883e-01,   1.61285400e-01],
                        [  1.55456543e-01,   1.55456543e-01],
                        [  1.43432617e-01,   1.43402100e-01],
                        [  1.31225586e-01,   1.31256104e-01],
                        [  1.17004395e-01,   1.17004395e-01],
                        [  1.03820801e-01,   1.03790283e-01],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  9.75952148e-02,   9.76257324e-02],
                        [  9.78088379e-02,   9.78088379e-02],
                        [  9.24682617e-02,   9.24377441e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -5.33142090e-02,  -5.33447266e-02],
                        [ -3.48510742e-02,  -3.48815918e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [  3.54003906e-03,   3.57055664e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  9.21630859e-03,   9.18579102e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.01416016e-02,   2.01721191e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  2.26745605e-02,   2.26440430e-02],
                        [  3.07006836e-02,   3.06701660e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  4.28771973e-02,   4.28466797e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  3.37219238e-02,   3.37524414e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  4.34570312e-02,   4.34875488e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  3.81469727e-02,   3.81164551e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.78527832e-02,   1.78833008e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.70690918e-02,  -2.70996094e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.09045410e-02,  -2.09350586e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.28271484e-02,  -2.27966309e-02],
                        [ -2.38037109e-02,  -2.38342285e-02],
                        [ -2.43835449e-02,  -2.44140625e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.81579590e-02,  -1.81884766e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.75476074e-02,  -1.75781250e-02],
                        [ -1.49230957e-02,  -1.49536133e-02],
                        [ -7.90405273e-03,  -7.87353516e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  1.55639648e-03,   1.52587891e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -6.10351562e-05,  -3.05175781e-05],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  1.25122070e-03,   1.28173828e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  6.53076172e-03,   6.50024414e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.33361816e-02,   1.33056641e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  3.25012207e-02,   3.25317383e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  6.77490234e-02,   6.77185059e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.24176025e-01,   1.24176025e-01],
                        [  9.98840332e-02,   9.98840332e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -1.39739990e-01,  -1.39739990e-01],
                        [ -2.39410400e-01,  -2.39410400e-01],
                        [ -3.06518555e-01,  -3.06518555e-01],
                        [ -3.19274902e-01,  -3.19274902e-01],
                        [ -2.83996582e-01,  -2.83966064e-01],
                        [ -2.34069824e-01,  -2.34069824e-01],
                        [ -1.99951172e-01,  -1.99951172e-01],
                        [ -1.83502197e-01,  -1.83471680e-01],
                        [ -1.66839600e-01,  -1.66839600e-01],
                        [ -1.38000488e-01,  -1.38000488e-01],
                        [ -9.92736816e-02,  -9.92736816e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.43798828e-01,   1.43829346e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.54602051e-01,   1.54602051e-01],
                        [  1.41571045e-01,   1.41571045e-01],
                        [  1.32537842e-01,   1.32537842e-01],
                        [  1.28265381e-01,   1.28234863e-01],
                        [  1.22680664e-01,   1.22711182e-01],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  1.00616455e-01,   1.00616455e-01],
                        [  9.04235840e-02,   9.03930664e-02],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  6.05468750e-02,   6.05468750e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [ -3.14331055e-03,  -3.11279297e-03],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -9.73510742e-03,  -9.76562500e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  3.50952148e-03,   3.47900391e-03],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.83105469e-02,   1.83410645e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  5.06896973e-02,   5.06896973e-02],
                        [  4.59899902e-02,   4.60205078e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  2.87780762e-02,   2.87475586e-02],
                        [  2.49633789e-02,   2.49938965e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  2.41394043e-02,   2.41088867e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  2.46582031e-02,   2.46887207e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.78320312e-02,   2.78625488e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.81066895e-02,  -2.80761719e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.26135254e-02,  -2.25830078e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -2.06604004e-02,  -2.06298828e-02],
                        [ -1.70898438e-02,  -1.70593262e-02],
                        [ -1.15051270e-02,  -1.15356445e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  7.72094727e-03,   7.69042969e-03],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  5.46264648e-03,   5.43212891e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -1.39770508e-02,  -1.39465332e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -6.92749023e-03,  -6.89697266e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  8.81958008e-03,   8.85009766e-03],
                        [  1.23291016e-02,   1.23596191e-02],
                        [  1.38244629e-02,   1.37939453e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  8.27941895e-02,   8.28247070e-02],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  1.31164551e-01,   1.31164551e-01],
                        [  1.34979248e-01,   1.35009766e-01],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  4.35180664e-02,   4.34875488e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -1.54785156e-01,  -1.54785156e-01],
                        [ -2.50976562e-01,  -2.51007080e-01],
                        [ -3.09600830e-01,  -3.09631348e-01],
                        [ -3.13415527e-01,  -3.13415527e-01],
                        [ -2.71881104e-01,  -2.71881104e-01],
                        [ -2.17590332e-01,  -2.17620850e-01],
                        [ -1.80603027e-01,  -1.80603027e-01],
                        [ -1.66137695e-01,  -1.66137695e-01],
                        [ -1.59576416e-01,  -1.59576416e-01],
                        [ -1.46789551e-01,  -1.46789551e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -8.97827148e-02,  -8.97827148e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  1.42883301e-01,   1.42913818e-01],
                        [  1.80511475e-01,   1.80511475e-01],
                        [  1.90063477e-01,   1.90063477e-01],
                        [  1.79534912e-01,   1.79565430e-01],
                        [  1.62139893e-01,   1.62139893e-01],
                        [  1.47094727e-01,   1.47094727e-01],
                        [  1.36199951e-01,   1.36230469e-01],
                        [  1.25427246e-01,   1.25427246e-01],
                        [  1.08612061e-01,   1.08612061e-01],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  2.31018066e-02,   2.30712891e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  3.81164551e-02,   3.81469727e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  4.18090820e-02,   4.18395996e-02],
                        [  2.67028809e-02,   2.66723633e-02],
                        [  2.14233398e-02,   2.13928223e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  4.94689941e-02,   4.94384766e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.34777832e-02,   3.35083008e-02],
                        [  2.43530273e-02,   2.43225098e-02],
                        [  1.57165527e-02,   1.56860352e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -1.16271973e-02,  -1.15966797e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.15246582e-02,  -3.14941406e-02],
                        [ -2.42309570e-02,  -2.42614746e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.34069824e-02,  -2.34375000e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -2.09960938e-02,  -2.10266113e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -2.12707520e-02,  -2.13012695e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -8.48388672e-03,  -8.45336914e-03],
                        [ -6.92749023e-03,  -6.95800781e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -9.67407227e-03,  -9.70458984e-03],
                        [ -1.11694336e-02,  -1.11389160e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  6.53076172e-03,   6.50024414e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -1.12915039e-03,  -1.09863281e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  5.69763184e-02,   5.69458008e-02],
                        [  7.55920410e-02,   7.56225586e-02],
                        [  1.02569580e-01,   1.02569580e-01],
                        [  1.28692627e-01,   1.28662109e-01],
                        [  1.37145996e-01,   1.37145996e-01],
                        [  1.13189697e-01,   1.13220215e-01],
                        [  5.12390137e-02,   5.12084961e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -1.55761719e-01,  -1.55761719e-01],
                        [ -2.57629395e-01,  -2.57629395e-01],
                        [ -3.17260742e-01,  -3.17291260e-01],
                        [ -3.16955566e-01,  -3.16955566e-01],
                        [ -2.69073486e-01,  -2.69073486e-01],
                        [ -2.08557129e-01,  -2.08557129e-01],
                        [ -1.66870117e-01,  -1.66900635e-01],
                        [ -1.51947021e-01,  -1.51916504e-01],
                        [ -1.49261475e-01,  -1.49230957e-01],
                        [ -1.40594482e-01,  -1.40625000e-01],
                        [ -1.19720459e-01,  -1.19720459e-01],
                        [ -8.94775391e-02,  -8.94470215e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  6.84509277e-02,   6.84814453e-02],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.68640137e-01,   1.68640137e-01],
                        [  1.85119629e-01,   1.85119629e-01],
                        [  1.84143066e-01,   1.84173584e-01],
                        [  1.74621582e-01,   1.74621582e-01],
                        [  1.62231445e-01,   1.62231445e-01],
                        [  1.46026611e-01,   1.46057129e-01],
                        [  1.22283936e-01,   1.22283936e-01],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -3.52172852e-02,  -3.52478027e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.52062988e-02,  -5.51757812e-02],
                        [ -3.76586914e-02,  -3.76892090e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -2.83813477e-03,  -2.80761719e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -4.79125977e-03,  -4.82177734e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  9.58251953e-03,   9.55200195e-03],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  3.74755859e-02,   3.75061035e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  6.25305176e-02,   6.25000000e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  2.20336914e-02,   2.20642090e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  2.05688477e-02,   2.05383301e-02],
                        [  2.49938965e-02,   2.50244141e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  2.91748047e-02,   2.91442871e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.59802246e-02,   3.60107422e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  3.29895020e-02,   3.29589844e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  3.76586914e-02,   3.76892090e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -4.63867188e-03,  -4.66918945e-03],
                        [ -5.21850586e-03,  -5.18798828e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -3.32031250e-02,  -3.32336426e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -5.28564453e-02,  -5.28259277e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -3.35083008e-02,  -3.35388184e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -1.96838379e-02,  -1.96533203e-02],
                        [ -1.41296387e-02,  -1.41601562e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -3.32641602e-03,  -3.35693359e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.33361816e-02,  -1.33666992e-02],
                        [ -6.95800781e-03,  -6.92749023e-03],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -2.16674805e-02,  -2.16369629e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.56555176e-02,  -1.56250000e-02],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.34887695e-02,   1.35192871e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.67236328e-02,   1.66931152e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  5.08728027e-02,   5.08422852e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  8.78601074e-02,   8.78601074e-02],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  1.34033203e-01,   1.34033203e-01],
                        [  1.36535645e-01,   1.36535645e-01],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  4.66918945e-02,   4.66613770e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -1.51519775e-01,  -1.51519775e-01],
                        [ -2.57110596e-01,  -2.57110596e-01],
                        [ -3.25958252e-01,  -3.25988770e-01],
                        [ -3.34259033e-01,  -3.34259033e-01],
                        [ -2.89154053e-01,  -2.89154053e-01],
                        [ -2.22625732e-01,  -2.22625732e-01],
                        [ -1.66595459e-01,  -1.66595459e-01],
                        [ -1.35192871e-01,  -1.35162354e-01],
                        [ -1.22985840e-01,  -1.22985840e-01],
                        [ -1.14685059e-01,  -1.14685059e-01],
                        [ -1.00067139e-01,  -1.00036621e-01],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -5.46264648e-02,  -5.46569824e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [  3.97338867e-02,   3.97644043e-02],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  1.66625977e-01,   1.66625977e-01],
                        [  1.97418213e-01,   1.97418213e-01],
                        [  1.98516846e-01,   1.98486328e-01],
                        [  1.84631348e-01,   1.84631348e-01],
                        [  1.68853760e-01,   1.68853760e-01],
                        [  1.49871826e-01,   1.49871826e-01],
                        [  1.18774414e-01,   1.18774414e-01],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -4.99877930e-02,  -4.99572754e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -2.71911621e-02,  -2.71606445e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  4.36096191e-02,   4.36401367e-02],
                        [  4.86450195e-02,   4.86145020e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  1.14746094e-02,   1.14440918e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.44958496e-02,   1.45263672e-02],
                        [  1.55639648e-02,   1.55334473e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  4.96215820e-02,   4.95910645e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [ -9.15527344e-05,  -6.10351562e-05],
                        [ -1.18713379e-02,  -1.19018555e-02],
                        [ -2.02941895e-02,  -2.02941895e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.63671875e-02,  -2.63977051e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.57153320e-02,  -4.57458496e-02],
                        [ -3.42407227e-02,  -3.42102051e-02],
                        [ -1.90124512e-02,  -1.89819336e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.97143555e-02,  -1.96838379e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -1.56555176e-02,  -1.56250000e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -2.89916992e-03,  -2.92968750e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -2.02941895e-02,  -2.03247070e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -5.64575195e-03,  -5.61523438e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.98669434e-02,  -1.98364258e-02],
                        [ -2.42004395e-02,  -2.42309570e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -1.74255371e-02,  -1.73950195e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  2.73742676e-02,   2.73437500e-02],
                        [  4.02526855e-02,   4.02221680e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  1.34582520e-01,   1.34582520e-01],
                        [  1.28967285e-01,   1.28967285e-01],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -1.57104492e-01,  -1.57073975e-01],
                        [ -2.53387451e-01,  -2.53387451e-01],
                        [ -3.10638428e-01,  -3.10638428e-01],
                        [ -3.11828613e-01,  -3.11828613e-01],
                        [ -2.67700195e-01,  -2.67700195e-01],
                        [ -2.08343506e-01,  -2.08343506e-01],
                        [ -1.63085938e-01,  -1.63085938e-01],
                        [ -1.43280029e-01,  -1.43280029e-01],
                        [ -1.38519287e-01,  -1.38519287e-01],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -1.14257812e-01,  -1.14257812e-01],
                        [ -8.89282227e-02,  -8.89282227e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  1.84020996e-01,   1.84020996e-01],
                        [  2.12768555e-01,   2.12768555e-01],
                        [  2.11059570e-01,   2.11059570e-01],
                        [  1.90826416e-01,   1.90826416e-01],
                        [  1.66625977e-01,   1.66656494e-01],
                        [  1.40045166e-01,   1.40014648e-01],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.50842285e-02,  -5.50842285e-02],
                        [ -4.07104492e-02,  -4.07409668e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.23083496e-02,  -2.22778320e-02],
                        [ -2.14843750e-02,  -2.15148926e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  3.30810547e-02,   3.30505371e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  5.31616211e-02,   5.31921387e-02],
                        [  5.88684082e-02,   5.88378906e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [ -4.02832031e-03,  -4.05883789e-03],
                        [ -5.31005859e-03,  -5.27954102e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  2.20031738e-02,   2.19726562e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  4.04357910e-02,   4.04663086e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  4.76379395e-02,   4.76684570e-02],
                        [  4.05883789e-02,   4.05578613e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  3.55529785e-02,   3.55834961e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  3.20434570e-03,   3.23486328e-03],
                        [ -6.40869141e-03,  -6.43920898e-03],
                        [ -1.45874023e-02,  -1.46179199e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -3.54614258e-02,  -3.54919434e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.23083496e-02,  -2.23388672e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -3.05175781e-04,  -2.74658203e-04],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.41601562e-02,  -1.41906738e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  1.09954834e-01,   1.09924316e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.34582520e-01,   1.34613037e-01],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  5.03234863e-02,   5.03234863e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -1.51855469e-01,  -1.51855469e-01],
                        [ -2.45697021e-01,  -2.45697021e-01],
                        [ -3.00201416e-01,  -3.00201416e-01],
                        [ -3.01483154e-01,  -3.01483154e-01],
                        [ -2.57965088e-01,  -2.57965088e-01],
                        [ -2.00317383e-01,  -2.00317383e-01],
                        [ -1.60736084e-01,  -1.60736084e-01],
                        [ -1.47399902e-01,  -1.47399902e-01],
                        [ -1.43798828e-01,  -1.43798828e-01],
                        [ -1.32965088e-01,  -1.32965088e-01],
                        [ -1.14227295e-01,  -1.14227295e-01],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [  3.27148438e-02,   3.26843262e-02],
                        [  1.10656738e-01,   1.10626221e-01],
                        [  1.83593750e-01,   1.83624268e-01],
                        [  2.27478027e-01,   2.27478027e-01],
                        [  2.30529785e-01,   2.30529785e-01],
                        [  2.01995850e-01,   2.01995850e-01],
                        [  1.60797119e-01,   1.60827637e-01],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -1.52587891e-02,  -1.52893066e-02],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -3.38745117e-03,  -3.35693359e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  5.43212891e-03,   5.46264648e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  5.20019531e-02,   5.19714355e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  8.37707520e-02,   8.37707520e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  5.20324707e-02,   5.20629883e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  2.83508301e-02,   2.83203125e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.44042969e-02,   1.44348145e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  3.18603516e-02,   3.18908691e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.60717773e-02,  -3.60412598e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.13928223e-02,  -2.13623047e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -1.51672363e-02,  -1.51977539e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -1.26647949e-02,  -1.26342773e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -8.75854492e-03,  -8.72802734e-03],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  4.78515625e-02,   4.78515625e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  1.20269775e-01,   1.20269775e-01],
                        [  1.39251709e-01,   1.39251709e-01],
                        [  1.42150879e-01,   1.42150879e-01],
                        [  1.15692139e-01,   1.15692139e-01],
                        [  5.50231934e-02,   5.50231934e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -1.31622314e-01,  -1.31622314e-01],
                        [ -2.24456787e-01,  -2.24456787e-01],
                        [ -2.84545898e-01,  -2.84545898e-01],
                        [ -2.90710449e-01,  -2.90710449e-01],
                        [ -2.49176025e-01,  -2.49145508e-01],
                        [ -1.94091797e-01,  -1.94091797e-01],
                        [ -1.58660889e-01,  -1.58660889e-01],
                        [ -1.50634766e-01,  -1.50604248e-01],
                        [ -1.56036377e-01,  -1.56036377e-01],
                        [ -1.58416748e-01,  -1.58416748e-01],
                        [ -1.50115967e-01,  -1.50085449e-01],
                        [ -1.29211426e-01,  -1.29211426e-01],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.71661377e-01,   1.71661377e-01],
                        [  2.20001221e-01,   2.20001221e-01],
                        [  2.37518311e-01,   2.37518311e-01],
                        [  2.21954346e-01,   2.21954346e-01],
                        [  1.77612305e-01,   1.77612305e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  4.13818359e-02,   4.13818359e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  1.04309082e-01,   1.04309082e-01],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  7.93151855e-02,   7.93151855e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  2.85644531e-02,   2.85339355e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.74353027e-02,   2.74658203e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  3.13720703e-02,   3.13415527e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  4.24194336e-02,   4.24499512e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  3.26232910e-02,   3.26538086e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  2.86560059e-02,   2.86254883e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -2.78625488e-02,  -2.78320312e-02],
                        [ -3.06396484e-02,  -3.06701660e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.26135254e-02,  -2.25830078e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.55944824e-02,  -1.56250000e-02],
                        [ -1.20239258e-02,  -1.19934082e-02],
                        [ -1.40991211e-02,  -1.40686035e-02],
                        [ -2.45361328e-02,  -2.45666504e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -1.82495117e-02,  -1.82800293e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.72119141e-02,  -1.71813965e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  3.03649902e-02,   3.03344727e-02],
                        [  4.03442383e-02,   4.03442383e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  6.86950684e-02,   6.86950684e-02],
                        [  9.24072266e-02,   9.24072266e-02],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.32843018e-01,   1.32812500e-01],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  5.88684082e-02,   5.88684082e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -1.25122070e-01,  -1.25122070e-01],
                        [ -2.23632812e-01,  -2.23602295e-01],
                        [ -2.90008545e-01,  -2.90008545e-01],
                        [ -2.99377441e-01,  -2.99377441e-01],
                        [ -2.56256104e-01,  -2.56256104e-01],
                        [ -1.95800781e-01,  -1.95800781e-01],
                        [ -1.52252197e-01,  -1.52252197e-01],
                        [ -1.33575439e-01,  -1.33575439e-01],
                        [ -1.28356934e-01,  -1.28356934e-01],
                        [ -1.24572754e-01,  -1.24572754e-01],
                        [ -1.17248535e-01,  -1.17248535e-01],
                        [ -1.05163574e-01,  -1.05133057e-01],
                        [ -8.43200684e-02,  -8.43200684e-02],
                        [ -4.58679199e-02,  -4.58984375e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  9.29565430e-02,   9.29870605e-02],
                        [  1.65466309e-01,   1.65466309e-01],
                        [  2.13531494e-01,   2.13531494e-01],
                        [  2.25616455e-01,   2.25646973e-01],
                        [  1.99645996e-01,   1.99645996e-01],
                        [  1.42639160e-01,   1.42608643e-01],
                        [  7.05261230e-02,   7.05261230e-02],
                        [  4.91333008e-03,   4.94384766e-03],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  2.19726562e-03,   2.19726562e-03],
                        [  1.00097656e-02,   9.97924805e-03],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  4.37316895e-02,   4.37622070e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  8.63037109e-02,   8.63037109e-02],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  9.66491699e-02,   9.66796875e-02],
                        [  8.71276855e-02,   8.71276855e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  2.36816406e-02,   2.36511230e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  2.92358398e-02,   2.92663574e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.51367188e-02,  -1.51672363e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.74145508e-02,  -3.73840332e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.27355957e-02,  -2.27050781e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.82592773e-02,  -2.82897949e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.88598633e-02,  -1.88293457e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -2.46582031e-02,  -2.46887207e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -2.38342285e-02,  -2.38037109e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.71911621e-02,  -2.72216797e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -1.40380859e-02,  -1.40075684e-02],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  2.17895508e-02,   2.17590332e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  5.62744141e-02,   5.62438965e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  8.67004395e-02,   8.67309570e-02],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -1.58203125e-01,  -1.58203125e-01],
                        [ -2.50061035e-01,  -2.50061035e-01],
                        [ -3.03985596e-01,  -3.03985596e-01],
                        [ -2.99011230e-01,  -2.99011230e-01],
                        [ -2.44812012e-01,  -2.44812012e-01],
                        [ -1.79016113e-01,  -1.79016113e-01],
                        [ -1.36169434e-01,  -1.36169434e-01],
                        [ -1.22131348e-01,  -1.22131348e-01],
                        [ -1.20849609e-01,  -1.20849609e-01],
                        [ -1.16973877e-01,  -1.16973877e-01],
                        [ -1.06933594e-01,  -1.06933594e-01],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -7.94982910e-02,  -7.94982910e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  1.49780273e-01,   1.49780273e-01],
                        [  2.13684082e-01,   2.13684082e-01],
                        [  2.30133057e-01,   2.30133057e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  2.94189453e-02,   2.94189453e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [ -6.68334961e-03,  -6.71386719e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  3.58581543e-02,   3.58276367e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  8.77075195e-02,   8.77075195e-02],
                        [  6.90002441e-02,   6.90002441e-02],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  2.25219727e-02,   2.25524902e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  2.87170410e-02,   2.86865234e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.26440430e-02,   2.26745605e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  3.21350098e-02,   3.21044922e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  2.36206055e-02,   2.36511230e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  2.82592773e-02,   2.82897949e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  9.39941406e-03,   9.42993164e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  3.41796875e-03,   3.44848633e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  9.61303711e-03,   9.58251953e-03],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  4.93164062e-02,   4.92858887e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.17156982e-01,   1.17126465e-01],
                        [  1.20330811e-01,   1.20361328e-01],
                        [  1.01623535e-01,   1.01623535e-01],
                        [  5.10864258e-02,   5.10559082e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -1.37908936e-01,  -1.37908936e-01],
                        [ -2.39379883e-01,  -2.39379883e-01],
                        [ -3.02978516e-01,  -3.02978516e-01],
                        [ -3.03802490e-01,  -3.03802490e-01],
                        [ -2.48535156e-01,  -2.48535156e-01],
                        [ -1.75903320e-01,  -1.75903320e-01],
                        [ -1.26007080e-01,  -1.26007080e-01],
                        [ -1.08917236e-01,  -1.08917236e-01],
                        [ -1.07238770e-01,  -1.07238770e-01],
                        [ -1.03210449e-01,  -1.03210449e-01],
                        [ -9.30786133e-02,  -9.30786133e-02],
                        [ -8.02917480e-02,  -8.02917480e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -4.47998047e-02,  -4.48303223e-02],
                        [ -9.76562500e-03,  -9.73510742e-03],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  1.06597900e-01,   1.06567383e-01],
                        [  1.58050537e-01,   1.58050537e-01],
                        [  1.73217773e-01,   1.73248291e-01],
                        [  1.43707275e-01,   1.43707275e-01],
                        [  8.44421387e-02,   8.44116211e-02],
                        [  2.40478516e-02,   2.40783691e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  5.03845215e-02,   5.03540039e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  2.21862793e-02,   2.22167969e-02],
                        [  2.62451172e-03,   2.62451172e-03],
                        [ -4.36401367e-03,  -4.39453125e-03],
                        [  3.84521484e-03,   3.87573242e-03],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  4.57763672e-02,   4.57458496e-02],
                        [  7.12280273e-02,   7.12280273e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.03515625e-01,   1.03485107e-01],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  7.68432617e-02,   7.68737793e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  3.57666016e-02,   3.57971191e-02],
                        [  2.15454102e-02,   2.15148926e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  1.91345215e-02,   1.91040039e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.00500488e-02,   2.00805664e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  1.40380859e-02,   1.40075684e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -2.12402344e-02,  -2.12097168e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -1.86462402e-02,  -1.86767578e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -1.14440918e-02,  -1.14746094e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -1.98059082e-02,  -1.98364258e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.65100098e-02,  -1.64794922e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [  3.63159180e-03,   3.66210938e-03],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  4.98352051e-02,   4.98046875e-02],
                        [  7.27233887e-02,   7.27233887e-02],
                        [  9.74731445e-02,   9.75036621e-02],
                        [  1.20269775e-01,   1.20239258e-01],
                        [  1.36077881e-01,   1.36077881e-01],
                        [  1.35711670e-01,   1.35711670e-01],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  5.50842285e-02,   5.50842285e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -1.24053955e-01,  -1.24084473e-01],
                        [ -2.21740723e-01,  -2.21740723e-01],
                        [ -2.87445068e-01,  -2.87414551e-01],
                        [ -2.94952393e-01,  -2.94952393e-01],
                        [ -2.48474121e-01,  -2.48474121e-01],
                        [ -1.84600830e-01,  -1.84600830e-01],
                        [ -1.39709473e-01,  -1.39709473e-01],
                        [ -1.21398926e-01,  -1.21398926e-01],
                        [ -1.16180420e-01,  -1.16149902e-01],
                        [ -1.11694336e-01,  -1.11694336e-01],
                        [ -1.02691650e-01,  -1.02691650e-01],
                        [ -8.64868164e-02,  -8.64868164e-02],
                        [ -6.38732910e-02,  -6.38427734e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  9.14916992e-02,   9.14916992e-02],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  7.74536133e-02,   7.74536133e-02],
                        [  5.27038574e-02,   5.27038574e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  2.82287598e-02,   2.81982422e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  3.50646973e-02,   3.50646973e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.57263184e-02,   2.56958008e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  8.79821777e-02,   8.80126953e-02],
                        [  9.93347168e-02,   9.93347168e-02],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  7.52868652e-02,   7.52868652e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  6.52160645e-02,   6.52160645e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  2.89611816e-02,   2.89306641e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  4.97436523e-03,   4.94384766e-03],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  2.31323242e-02,   2.31628418e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  2.31323242e-02,   2.31018066e-02],
                        [  2.18811035e-02,   2.19116211e-02],
                        [  2.39868164e-02,   2.40173340e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -5.85937500e-03,  -5.82885742e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -9.15527344e-04,  -9.46044922e-04],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -3.46374512e-02,  -3.46679688e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.03747559e-02,  -4.03442383e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -4.05578613e-02,  -4.05883789e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.12402344e-02,  -2.12707520e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -2.70690918e-02,  -2.70385742e-02],
                        [ -3.33862305e-02,  -3.34167480e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -1.57165527e-02,  -1.56860352e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -4.88281250e-03,  -4.85229492e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.51367188e-02,   1.51062012e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  4.19311523e-02,   4.19311523e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [  7.20214844e-02,   7.20520020e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  1.27807617e-01,   1.27807617e-01],
                        [  1.07910156e-01,   1.07879639e-01],
                        [  5.97839355e-02,   5.97839355e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.22863770e-01,  -1.22894287e-01],
                        [ -2.20581055e-01,  -2.20581055e-01],
                        [ -2.81005859e-01,  -2.81005859e-01],
                        [ -2.87292480e-01,  -2.87292480e-01],
                        [ -2.46643066e-01,  -2.46673584e-01],
                        [ -1.86584473e-01,  -1.86553955e-01],
                        [ -1.38153076e-01,  -1.38153076e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -1.01776123e-01,  -1.01776123e-01],
                        [ -8.91418457e-02,  -8.91418457e-02],
                        [ -7.44628906e-02,  -7.44628906e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -5.30395508e-02,  -5.30090332e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  5.17578125e-02,   5.17272949e-02],
                        [  6.69860840e-02,   6.69860840e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  2.70996094e-02,   2.71301270e-02],
                        [  2.60620117e-02,   2.60314941e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  3.87573242e-02,   3.87878418e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  6.24389648e-02,   6.24084473e-02],
                        [  8.20922852e-02,   8.20922852e-02],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  1.11938477e-01,   1.11938477e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  9.29260254e-02,   9.29565430e-02],
                        [  6.85729980e-02,   6.85424805e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  3.43322754e-02,   3.43627930e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  3.31726074e-02,   3.31420898e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  3.86047363e-02,   3.86352539e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.66821289e-02,   3.66516113e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  3.85437012e-02,   3.85742188e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -1.84020996e-02,  -1.84326172e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.78112793e-02,  -3.78417969e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  2.29797363e-02,   2.30102539e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  9.48791504e-02,   9.48791504e-02],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.29882812e-01,   1.29882812e-01],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -1.41143799e-01,  -1.41143799e-01],
                        [ -2.27569580e-01,  -2.27600098e-01],
                        [ -2.77893066e-01,  -2.77923584e-01],
                        [ -2.76000977e-01,  -2.76000977e-01],
                        [ -2.29064941e-01,  -2.29064941e-01],
                        [ -1.69677734e-01,  -1.69677734e-01],
                        [ -1.30676270e-01,  -1.30676270e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  7.77587891e-02,   7.77282715e-02],
                        [  9.72595215e-02,   9.72595215e-02],
                        [  9.32312012e-02,   9.32312012e-02],
                        [  7.34252930e-02,   7.34252930e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  4.03137207e-02,   4.03442383e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  3.47595215e-02,   3.47290039e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  9.10949707e-02,   9.10949707e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  7.77587891e-02,   7.77587891e-02],
                        [  6.89392090e-02,   6.89392090e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  5.06896973e-02,   5.06896973e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  3.50646973e-02,   3.50646973e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  4.30297852e-02,   4.29992676e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  2.72827148e-02,   2.72521973e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.69372559e-02,   1.69677734e-02],
                        [  2.33154297e-02,   2.32849121e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.07421875e-02,   1.07727051e-02],
                        [  9.24682617e-03,   9.21630859e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  6.56127930e-03,   6.59179688e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  3.17382812e-03,   3.14331055e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.48718262e-02,  -2.49023438e-02],
                        [ -2.74658203e-02,  -2.74353027e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.76892090e-02,  -3.77197266e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.90222168e-02,  -2.90527344e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.30615234e-02,  -1.30310059e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  2.55432129e-02,   2.55737305e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  3.15551758e-02,   3.15856934e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  9.32617188e-02,   9.32922363e-02],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.21398926e-01,   1.21368408e-01],
                        [  9.30480957e-02,   9.30786133e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [ -3.27453613e-02,  -3.27758789e-02],
                        [ -1.23291016e-01,  -1.23291016e-01],
                        [ -2.16308594e-01,  -2.16308594e-01],
                        [ -2.80517578e-01,  -2.80517578e-01],
                        [ -2.85034180e-01,  -2.85034180e-01],
                        [ -2.31719971e-01,  -2.31719971e-01],
                        [ -1.57775879e-01,  -1.57775879e-01],
                        [ -1.02142334e-01,  -1.02172852e-01],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -7.03735352e-02,  -7.03430176e-02],
                        [ -6.44226074e-02,  -6.44531250e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -4.29992676e-02,  -4.29687500e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -1.04034424e-01,  -1.04003906e-01],
                        [ -1.11663818e-01,  -1.11694336e-01],
                        [ -9.50927734e-02,  -9.51232910e-02],
                        [ -4.95910645e-02,  -4.95605469e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  7.13500977e-02,   7.13195801e-02],
                        [  1.02294922e-01,   1.02294922e-01],
                        [  1.02722168e-01,   1.02752686e-01],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  6.94580078e-02,   6.94580078e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  1.03057861e-01,   1.03057861e-01],
                        [  1.15295410e-01,   1.15295410e-01],
                        [  1.11816406e-01,   1.11785889e-01],
                        [  9.62829590e-02,   9.62829590e-02],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  5.49011230e-02,   5.48706055e-02],
                        [  4.79431152e-02,   4.79736328e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.19519043e-02,   3.19213867e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  2.62756348e-02,   2.62451172e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.88391113e-02,   2.88696289e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.68859863e-02,   2.69165039e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  2.30712891e-02,   2.30407715e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  8.30078125e-03,   8.27026367e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.45263672e-02,  -1.45568848e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -1.41601562e-02,  -1.41906738e-02],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.93786621e-02,   1.94091797e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.38702393e-01,   1.38702393e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.03057861e-01,   1.03057861e-01],
                        [  4.41894531e-02,   4.41894531e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -1.32141113e-01,  -1.32110596e-01],
                        [ -2.15301514e-01,  -2.15301514e-01],
                        [ -2.65838623e-01,  -2.65838623e-01],
                        [ -2.66601562e-01,  -2.66601562e-01],
                        [ -2.21130371e-01,  -2.21130371e-01],
                        [ -1.57531738e-01,  -1.57531738e-01],
                        [ -1.07513428e-01,  -1.07513428e-01],
                        [ -8.09326172e-02,  -8.09326172e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -8.02001953e-02,  -8.02001953e-02],
                        [ -1.18499756e-01,  -1.18499756e-01],
                        [ -1.47094727e-01,  -1.47094727e-01],
                        [ -1.50817871e-01,  -1.50817871e-01],
                        [ -1.22131348e-01,  -1.22131348e-01],
                        [ -6.43005371e-02,  -6.43310547e-02],
                        [  9.67407227e-03,   9.70458984e-03],
                        [  7.91931152e-02,   7.91931152e-02],
                        [  1.22314453e-01,   1.22314453e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  1.14196777e-01,   1.14196777e-01],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  6.57653809e-02,   6.57653809e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  5.25817871e-02,   5.26123047e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  8.70666504e-02,   8.70666504e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  1.00280762e-01,   1.00280762e-01],
                        [  8.62426758e-02,   8.62121582e-02],
                        [  7.41882324e-02,   7.42187500e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  5.42602539e-02,   5.42602539e-02],
                        [  4.98962402e-02,   4.99267578e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  3.06701660e-02,   3.07006836e-02],
                        [  2.95715332e-02,   2.96020508e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  2.28576660e-02,   2.28271484e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.04064941e-02,   1.03759766e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.24511719e-02,   1.24816895e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.67541504e-02,   1.67236328e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  2.44140625e-02,   2.44445801e-02],
                        [  1.96228027e-02,   1.95922852e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  6.46972656e-03,   6.50024414e-03],
                        [  8.85009766e-03,   8.81958008e-03],
                        [  1.22375488e-02,   1.22070312e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.85644531e-02,  -2.85339355e-02],
                        [ -3.25622559e-02,  -3.25317383e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -3.58276367e-02,  -3.57971191e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.99682617e-02,  -2.99987793e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.43225098e-02,  -2.42919922e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -4.11987305e-03,  -4.15039062e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  3.50646973e-02,   3.50952148e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  8.94775391e-02,   8.95080566e-02],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  1.24084473e-01,   1.24084473e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.39495850e-01,   1.39526367e-01],
                        [  1.13311768e-01,   1.13311768e-01],
                        [  5.76171875e-02,   5.76171875e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.20910645e-01,  -1.20910645e-01],
                        [ -2.12341309e-01,  -2.12341309e-01],
                        [ -2.72796631e-01,  -2.72796631e-01],
                        [ -2.82379150e-01,  -2.82379150e-01],
                        [ -2.42797852e-01,  -2.42797852e-01],
                        [ -1.78924561e-01,  -1.78924561e-01],
                        [ -1.19476318e-01,  -1.19476318e-01],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -1.08306885e-01,  -1.08306885e-01],
                        [ -1.52221680e-01,  -1.52221680e-01],
                        [ -1.77612305e-01,  -1.77612305e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.32659912e-01,  -1.32659912e-01],
                        [ -6.36291504e-02,  -6.36596680e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  1.35833740e-01,   1.35833740e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  9.65576172e-02,   9.65576172e-02],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  5.59387207e-02,   5.59082031e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  7.33337402e-02,   7.33642578e-02],
                        [  8.88671875e-02,   8.88671875e-02],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  1.18652344e-01,   1.18652344e-01],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  1.00708008e-01,   1.00708008e-01],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  7.03735352e-02,   7.03430176e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  6.71386719e-02,   6.71691895e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  6.21948242e-02,   6.22253418e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  3.43627930e-02,   3.43933105e-02],
                        [  2.98461914e-02,   2.98767090e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  2.27355957e-02,   2.27661133e-02],
                        [  2.25524902e-02,   2.25830078e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.14746094e-02,   1.15051270e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  2.13928223e-02,   2.14233398e-02],
                        [  2.43225098e-02,   2.43530273e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.18200684e-02,   2.18505859e-02],
                        [  1.94702148e-02,   1.94396973e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.95312500e-03,   1.92260742e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.25012207e-02,  -3.24707031e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.45764160e-02,  -3.45458984e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.88598633e-02,  -1.88903809e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -4.39453125e-03,  -4.36401367e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  7.03125000e-02,   7.02819824e-02],
                        [  9.03930664e-02,   9.04235840e-02],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  1.31896973e-01,   1.31866455e-01],
                        [  1.48803711e-01,   1.48803711e-01],
                        [  1.48620605e-01,   1.48620605e-01],
                        [  1.20483398e-01,   1.20452881e-01],
                        [  6.24694824e-02,   6.24694824e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -1.16516113e-01,  -1.16516113e-01],
                        [ -2.09991455e-01,  -2.09991455e-01],
                        [ -2.75360107e-01,  -2.75360107e-01],
                        [ -2.90374756e-01,  -2.90374756e-01],
                        [ -2.52593994e-01,  -2.52593994e-01],
                        [ -1.85119629e-01,  -1.85119629e-01],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -7.89184570e-02,  -7.89184570e-02],
                        [ -5.63964844e-02,  -5.63964844e-02],
                        [ -4.28161621e-02,  -4.28466797e-02],
                        [ -3.91845703e-02,  -3.92150879e-02],
                        [ -5.77392578e-02,  -5.77087402e-02],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -1.58386230e-01,  -1.58386230e-01],
                        [ -1.99707031e-01,  -1.99707031e-01],
                        [ -2.08953857e-01,  -2.08953857e-01],
                        [ -1.83013916e-01,  -1.83013916e-01],
                        [ -1.31317139e-01,  -1.31317139e-01],
                        [ -6.84509277e-02,  -6.84509277e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [  5.30395508e-02,   5.30395508e-02],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.47918701e-01,   1.47918701e-01],
                        [  1.30493164e-01,   1.30493164e-01],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  6.91528320e-02,   6.91528320e-02],
                        [  5.84411621e-02,   5.84716797e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  6.91528320e-02,   6.91223145e-02],
                        [  7.29370117e-02,   7.29675293e-02],
                        [  7.62023926e-02,   7.62023926e-02],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.36413574e-01,   1.36413574e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.24481201e-01,   1.24481201e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  7.75146484e-02,   7.75451660e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  4.83093262e-02,   4.82788086e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  1.47705078e-02,   1.48010254e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -4.88281250e-04,  -5.18798828e-04],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  3.05175781e-05,   3.05175781e-05],
                        [  1.25122070e-03,   1.22070312e-03],
                        [  6.53076172e-03,   6.56127930e-03],
                        [  1.31225586e-02,   1.31530762e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.88293457e-02,   1.88598633e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.15148926e-02,   2.14843750e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  4.08935547e-03,   4.11987305e-03],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -2.84423828e-02,  -2.84729004e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.06701660e-02,  -3.07006836e-02],
                        [ -3.31115723e-02,  -3.30810547e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -4.37622070e-02,  -4.37927246e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.01708984e-02,  -5.01403809e-02],
                        [ -4.89196777e-02,  -4.89501953e-02],
                        [ -4.64477539e-02,  -4.64782715e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -4.08020020e-02,  -4.08325195e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -4.55932617e-02,  -4.55627441e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  6.35681152e-02,   6.35986328e-02],
                        [  7.60498047e-02,   7.60498047e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.51855469e-01,   1.51855469e-01],
                        [  1.61804199e-01,   1.61773682e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  9.11865234e-02,   9.11865234e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [ -8.96606445e-02,  -8.96606445e-02],
                        [ -1.94000244e-01,  -1.93969727e-01],
                        [ -2.70690918e-01,  -2.70690918e-01],
                        [ -2.91137695e-01,  -2.91137695e-01],
                        [ -2.51037598e-01,  -2.51037598e-01],
                        [ -1.76147461e-01,  -1.76147461e-01],
                        [ -1.03576660e-01,  -1.03576660e-01],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -9.68933105e-02,  -9.68933105e-02],
                        [ -1.44989014e-01,  -1.44989014e-01],
                        [ -1.91833496e-01,  -1.91833496e-01],
                        [ -2.19024658e-01,  -2.19024658e-01],
                        [ -2.12188721e-01,  -2.12188721e-01],
                        [ -1.72485352e-01,  -1.72454834e-01],
                        [ -1.17462158e-01,  -1.17462158e-01],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  6.56433105e-02,   6.56127930e-02],
                        [  1.07543945e-01,   1.07543945e-01],
                        [  1.33697510e-01,   1.33697510e-01],
                        [  1.36230469e-01,   1.36230469e-01],
                        [  1.18957520e-01,   1.18927002e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  8.45947266e-02,   8.45947266e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  8.64257812e-02,   8.64257812e-02],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  9.17053223e-02,   9.16748047e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.20819092e-01,   1.20819092e-01],
                        [  1.36962891e-01,   1.36962891e-01],
                        [  1.46270752e-01,   1.46240234e-01],
                        [  1.44439697e-01,   1.44439697e-01],
                        [  1.30920410e-01,   1.30950928e-01],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  9.33227539e-02,   9.33227539e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  7.45544434e-02,   7.45544434e-02],
                        [  7.13500977e-02,   7.13500977e-02],
                        [  6.54907227e-02,   6.55212402e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  7.62939453e-04,   7.93457031e-04],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  1.89819336e-02,   1.89514160e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  4.57763672e-04,   4.27246094e-04],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -2.59399414e-03,  -2.56347656e-03],
                        [ -3.60107422e-03,  -3.63159180e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -4.63867188e-03,  -4.60815430e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.85644531e-02,  -2.85339355e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -4.89807129e-02,  -4.90112305e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -5.40771484e-02,  -5.41076660e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -3.94592285e-02,  -3.94287109e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.93066406e-02,  -3.93371582e-02],
                        [ -4.51965332e-02,  -4.51660156e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.55432129e-02,  -2.55737305e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -1.34277344e-03,  -1.31225586e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  8.74023438e-02,   8.74023438e-02],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  1.33087158e-01,   1.33087158e-01],
                        [  1.52435303e-01,   1.52435303e-01],
                        [  1.53747559e-01,   1.53747559e-01],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  8.63647461e-03,   8.66699219e-03],
                        [ -8.98132324e-02,  -8.98132324e-02],
                        [ -1.91070557e-01,  -1.91101074e-01],
                        [ -2.60406494e-01,  -2.60375977e-01],
                        [ -2.73406982e-01,  -2.73406982e-01],
                        [ -2.32482910e-01,  -2.32513428e-01],
                        [ -1.63665771e-01,  -1.63665771e-01],
                        [ -9.99450684e-02,  -9.99450684e-02],
                        [ -6.17065430e-02,  -6.17370605e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -7.03430176e-02,  -7.03430176e-02],
                        [ -1.05377197e-01,  -1.05377197e-01],
                        [ -1.52618408e-01,  -1.52618408e-01],
                        [ -1.95159912e-01,  -1.95159912e-01],
                        [ -2.14385986e-01,  -2.14416504e-01],
                        [ -2.02636719e-01,  -2.02606201e-01],
                        [ -1.67053223e-01,  -1.67053223e-01],
                        [ -1.23413086e-01,  -1.23443604e-01],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -4.36706543e-02,  -4.36401367e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  1.40777588e-01,   1.40777588e-01],
                        [  1.50695801e-01,   1.50695801e-01],
                        [  1.37878418e-01,   1.37847900e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  9.73205566e-02,   9.73205566e-02],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  9.88159180e-02,   9.88159180e-02],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  1.35131836e-01,   1.35131836e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.48040771e-01,   1.48040771e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  7.95898438e-02,   7.95898438e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  8.54797363e-02,   8.54492188e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  5.78002930e-02,   5.77697754e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  7.93457031e-04,   7.93457031e-04],
                        [  1.64794922e-03,   1.67846680e-03],
                        [  5.03540039e-03,   5.00488281e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.09863281e-02,   1.09558105e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -2.68554688e-02,  -2.68249512e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.85949707e-02,  -2.85644531e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.97546387e-02,  -2.97851562e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -3.65905762e-02,  -3.66210938e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -5.19714355e-02,  -5.20019531e-02],
                        [ -5.77087402e-02,  -5.77392578e-02],
                        [ -5.83190918e-02,  -5.82885742e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.35888672e-02,  -5.35583496e-02],
                        [ -4.34875488e-02,  -4.35180664e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -2.85644531e-02,  -2.85339355e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.70080566e-02,  -2.70385742e-02],
                        [ -2.93273926e-02,  -2.92968750e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -5.73730469e-03,  -5.70678711e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  3.14941406e-02,   3.15246582e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.22619629e-01,   1.22589111e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  1.14044189e-01,   1.14013672e-01],
                        [  6.10656738e-02,   6.10656738e-02],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.03271484e-01,  -1.03271484e-01],
                        [ -1.91619873e-01,  -1.91619873e-01],
                        [ -2.51525879e-01,  -2.51525879e-01],
                        [ -2.59307861e-01,  -2.59307861e-01],
                        [ -2.14721680e-01,  -2.14721680e-01],
                        [ -1.45629883e-01,  -1.45629883e-01],
                        [ -8.90197754e-02,  -8.89892578e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -8.44421387e-02,  -8.44421387e-02],
                        [ -1.08551025e-01,  -1.08551025e-01],
                        [ -1.40014648e-01,  -1.40014648e-01],
                        [ -1.72332764e-01,  -1.72332764e-01],
                        [ -1.91436768e-01,  -1.91406250e-01],
                        [ -1.87408447e-01,  -1.87408447e-01],
                        [ -1.64276123e-01,  -1.64276123e-01],
                        [ -1.34246826e-01,  -1.34246826e-01],
                        [ -1.04797363e-01,  -1.04797363e-01],
                        [ -7.50732422e-02,  -7.51037598e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  1.38763428e-01,   1.38763428e-01],
                        [  1.35925293e-01,   1.35925293e-01],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  9.93347168e-02,   9.93347168e-02],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  1.02050781e-01,   1.02050781e-01],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.24206543e-01,   1.24206543e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.36047363e-01,   1.36047363e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.14868164e-01,   1.14868164e-01],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  7.58361816e-02,   7.58056641e-02],
                        [  7.05871582e-02,   7.05566406e-02],
                        [  6.73217773e-02,   6.73522949e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  6.16760254e-02,   6.16455078e-02],
                        [  6.03637695e-02,   6.03942871e-02],
                        [  5.92346191e-02,   5.92346191e-02],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  3.57360840e-02,   3.57666016e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  2.28881836e-03,   2.28881836e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.62756348e-02,   2.63061523e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -4.36401367e-03,  -4.33349609e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  3.66210938e-04,   3.96728516e-04],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -3.19519043e-02,  -3.19824219e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -6.01806641e-02,  -6.02111816e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.18603516e-02,  -3.18908691e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.75781250e-02,   1.75476074e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  3.38745117e-02,   3.39050293e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  7.08923340e-02,   7.08923340e-02],
                        [  9.32006836e-02,   9.31701660e-02],
                        [  1.26373291e-01,   1.26342773e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.57653809e-01,   1.57623291e-01],
                        [  1.28387451e-01,   1.28387451e-01],
                        [  7.09533691e-02,   7.09533691e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.01867676e-01,  -1.01867676e-01],
                        [ -1.90399170e-01,  -1.90399170e-01],
                        [ -2.45941162e-01,  -2.45941162e-01],
                        [ -2.45819092e-01,  -2.45819092e-01],
                        [ -1.93206787e-01,  -1.93206787e-01],
                        [ -1.20605469e-01,  -1.20605469e-01],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -8.25805664e-02,  -8.25805664e-02],
                        [ -1.23596191e-01,  -1.23596191e-01],
                        [ -1.65313721e-01,  -1.65313721e-01],
                        [ -1.95831299e-01,  -1.95831299e-01],
                        [ -2.05230713e-01,  -2.05230713e-01],
                        [ -1.90490723e-01,  -1.90490723e-01],
                        [ -1.59667969e-01,  -1.59667969e-01],
                        [ -1.26373291e-01,  -1.26373291e-01],
                        [ -1.00280762e-01,  -1.00280762e-01],
                        [ -8.28552246e-02,  -8.28552246e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  1.04705811e-01,   1.04705811e-01],
                        [  1.32781982e-01,   1.32781982e-01],
                        [  1.40502930e-01,   1.40502930e-01],
                        [  1.31927490e-01,   1.31927490e-01],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.08489990e-01,   1.08489990e-01],
                        [  1.02416992e-01,   1.02416992e-01],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  1.08398438e-01,   1.08398438e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  1.52130127e-01,   1.52130127e-01],
                        [  1.66748047e-01,   1.66717529e-01],
                        [  1.65649414e-01,   1.65649414e-01],
                        [  1.48529053e-01,   1.48529053e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  9.01794434e-02,   9.01794434e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  6.52465820e-02,   6.52160645e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  6.77795410e-02,   6.77795410e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  5.82275391e-02,   5.82580566e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [ -2.50244141e-03,  -2.47192383e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -6.56127930e-02,  -6.56127930e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.55639648e-02,  -1.55334473e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [  1.17187500e-02,   1.17492676e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  4.84008789e-02,   4.84313965e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  9.60083008e-02,   9.60083008e-02],
                        [  1.24786377e-01,   1.24755859e-01],
                        [  1.46606445e-01,   1.46606445e-01],
                        [  1.50024414e-01,   1.50024414e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  7.83386230e-02,   7.83386230e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [ -8.10241699e-02,  -8.09936523e-02],
                        [ -1.67297363e-01,  -1.67297363e-01],
                        [ -2.25280762e-01,  -2.25280762e-01],
                        [ -2.32238770e-01,  -2.32238770e-01],
                        [ -1.90399170e-01,  -1.90399170e-01],
                        [ -1.30462646e-01,  -1.30462646e-01],
                        [ -9.09118652e-02,  -9.09118652e-02],
                        [ -9.07287598e-02,  -9.07287598e-02],
                        [ -1.19476318e-01,  -1.19476318e-01],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.78314209e-01,  -1.78314209e-01],
                        [ -1.88354492e-01,  -1.88354492e-01],
                        [ -1.83654785e-01,  -1.83654785e-01],
                        [ -1.67572021e-01,  -1.67572021e-01],
                        [ -1.48040771e-01,  -1.48040771e-01],
                        [ -1.31408691e-01,  -1.31408691e-01],
                        [ -1.17401123e-01,  -1.17401123e-01],
                        [ -1.02569580e-01,  -1.02569580e-01],
                        [ -8.47778320e-02,  -8.47778320e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  9.26208496e-02,   9.26513672e-02],
                        [  1.38397217e-01,   1.38397217e-01],
                        [  1.60858154e-01,   1.60858154e-01],
                        [  1.56433105e-01,   1.56433105e-01],
                        [  1.37359619e-01,   1.37359619e-01],
                        [  1.20269775e-01,   1.20269775e-01],
                        [  1.13769531e-01,   1.13739014e-01],
                        [  1.16699219e-01,   1.16699219e-01],
                        [  1.25183105e-01,   1.25183105e-01],
                        [  1.37695312e-01,   1.37695312e-01],
                        [  1.52801514e-01,   1.52801514e-01],
                        [  1.65222168e-01,   1.65222168e-01],
                        [  1.68548584e-01,   1.68548584e-01],
                        [  1.61376953e-01,   1.61376953e-01],
                        [  1.46972656e-01,   1.46972656e-01],
                        [  1.28021240e-01,   1.28021240e-01],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  3.05175781e-05,   6.10351562e-05],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  4.42504883e-03,   4.42504883e-03],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  1.81884766e-02,   1.82189941e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.69055176e-02,  -4.69055176e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -7.05261230e-02,  -7.05261230e-02],
                        [ -7.98950195e-02,  -7.98950195e-02],
                        [ -7.89489746e-02,  -7.89489746e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -4.00085449e-02,  -3.99780273e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -2.99987793e-02,  -2.99682617e-02],
                        [ -3.32641602e-02,  -3.32946777e-02],
                        [ -3.56445312e-02,  -3.56750488e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.62243652e-02,  -3.62548828e-02],
                        [ -3.31420898e-02,  -3.31115723e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  3.51562500e-02,   3.51562500e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.35284424e-01,   1.35284424e-01],
                        [  1.52282715e-01,   1.52282715e-01],
                        [  1.54754639e-01,   1.54754639e-01],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  7.92846680e-02,   7.92846680e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -9.20715332e-02,  -9.20715332e-02],
                        [ -1.75231934e-01,  -1.75231934e-01],
                        [ -2.24761963e-01,  -2.24792480e-01],
                        [ -2.24182129e-01,  -2.24182129e-01],
                        [ -1.81091309e-01,  -1.81091309e-01],
                        [ -1.29058838e-01,  -1.29058838e-01],
                        [ -1.04553223e-01,  -1.04553223e-01],
                        [ -1.20025635e-01,  -1.20025635e-01],
                        [ -1.59057617e-01,  -1.59057617e-01],
                        [ -1.93267822e-01,  -1.93298340e-01],
                        [ -2.02880859e-01,  -2.02880859e-01],
                        [ -1.86737061e-01,  -1.86737061e-01],
                        [ -1.58386230e-01,  -1.58386230e-01],
                        [ -1.32781982e-01,  -1.32781982e-01],
                        [ -1.16363525e-01,  -1.16363525e-01],
                        [ -1.07330322e-01,  -1.07330322e-01],
                        [ -1.00921631e-01,  -1.00921631e-01],
                        [ -9.30786133e-02,  -9.30786133e-02],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  8.92639160e-02,   8.92639160e-02],
                        [  1.36077881e-01,   1.36077881e-01],
                        [  1.60827637e-01,   1.60858154e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.47125244e-01,   1.47125244e-01],
                        [  1.31896973e-01,   1.31896973e-01],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.29425049e-01,   1.29425049e-01],
                        [  1.41052246e-01,   1.41052246e-01],
                        [  1.52709961e-01,   1.52709961e-01],
                        [  1.62078857e-01,   1.62078857e-01],
                        [  1.64794922e-01,   1.64794922e-01],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  1.38916016e-01,   1.38916016e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  9.16442871e-02,   9.16442871e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.78100586e-02,  -6.78100586e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.78210449e-02,  -4.77905273e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -6.67724609e-02,  -6.67724609e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  1.08123779e-01,   1.08123779e-01],
                        [  1.28021240e-01,   1.28021240e-01],
                        [  1.40289307e-01,   1.40289307e-01],
                        [  1.37817383e-01,   1.37847900e-01],
                        [  1.14959717e-01,   1.14959717e-01],
                        [  6.50329590e-02,   6.50329590e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -9.97619629e-02,  -9.97619629e-02],
                        [ -1.75445557e-01,  -1.75445557e-01],
                        [ -2.16278076e-01,  -2.16278076e-01],
                        [ -2.11059570e-01,  -2.11059570e-01],
                        [ -1.72027588e-01,  -1.72027588e-01],
                        [ -1.35833740e-01,  -1.35833740e-01],
                        [ -1.37176514e-01,  -1.37176514e-01],
                        [ -1.76971436e-01,  -1.76971436e-01],
                        [ -2.23266602e-01,  -2.23266602e-01],
                        [ -2.43438721e-01,  -2.43438721e-01],
                        [ -2.30285645e-01,  -2.30285645e-01],
                        [ -1.97967529e-01,  -1.97967529e-01],
                        [ -1.61682129e-01,  -1.61682129e-01],
                        [ -1.28601074e-01,  -1.28601074e-01],
                        [ -1.01623535e-01,  -1.01623535e-01],
                        [ -8.00781250e-02,  -8.00781250e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  7.05261230e-02,   7.05261230e-02],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.54907227e-01,   1.54907227e-01],
                        [  1.66046143e-01,   1.66046143e-01],
                        [  1.55975342e-01,   1.55975342e-01],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.11999512e-01,   1.11999512e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  1.40258789e-01,   1.40258789e-01],
                        [  1.63024902e-01,   1.63024902e-01],
                        [  1.79656982e-01,   1.79656982e-01],
                        [  1.84509277e-01,   1.84509277e-01],
                        [  1.76635742e-01,   1.76635742e-01],
                        [  1.57135010e-01,   1.57135010e-01],
                        [  1.29516602e-01,   1.29516602e-01],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -4.73022461e-03,  -4.76074219e-03],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -3.35693359e-03,  -3.32641602e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  4.99572754e-02,   4.99572754e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  1.57775879e-01,   1.57775879e-01],
                        [  1.42059326e-01,   1.42089844e-01],
                        [  1.02050781e-01,   1.02050781e-01],
                        [  4.05273438e-02,   4.05273438e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -1.24938965e-01,  -1.24938965e-01],
                        [ -1.95709229e-01,  -1.95709229e-01],
                        [ -2.29034424e-01,  -2.29034424e-01],
                        [ -2.25708008e-01,  -2.25708008e-01],
                        [ -2.12158203e-01,  -2.12158203e-01],
                        [ -2.12554932e-01,  -2.12554932e-01],
                        [ -2.24853516e-01,  -2.24853516e-01],
                        [ -2.29797363e-01,  -2.29797363e-01],
                        [ -2.14782715e-01,  -2.14782715e-01],
                        [ -1.83288574e-01,  -1.83288574e-01],
                        [ -1.49597168e-01,  -1.49597168e-01],
                        [ -1.27990723e-01,  -1.27990723e-01],
                        [ -1.20849609e-01,  -1.20849609e-01],
                        [ -1.15417480e-01,  -1.15417480e-01],
                        [ -9.85412598e-02,  -9.85412598e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  1.30065918e-01,   1.30065918e-01],
                        [  1.54907227e-01,   1.54907227e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.53106689e-01,   1.53106689e-01],
                        [  1.45660400e-01,   1.45660400e-01],
                        [  1.50360107e-01,   1.50360107e-01],
                        [  1.70410156e-01,   1.70410156e-01],
                        [  1.95373535e-01,   1.95373535e-01],
                        [  2.09289551e-01,   2.09289551e-01],
                        [  2.05322266e-01,   2.05322266e-01],
                        [  1.88415527e-01,   1.88415527e-01],
                        [  1.65557861e-01,   1.65557861e-01],
                        [  1.41479492e-01,   1.41479492e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  9.86938477e-02,   9.86938477e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  4.53796387e-02,   4.53796387e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -5.71594238e-02,  -5.71899414e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  1.68121338e-01,   1.68121338e-01],
                        [  1.85516357e-01,   1.85516357e-01],
                        [  1.80389404e-01,   1.80389404e-01],
                        [  1.53167725e-01,   1.53167725e-01],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  3.86352539e-02,   3.86352539e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -1.34490967e-01,  -1.34490967e-01],
                        [ -2.05108643e-01,  -2.05108643e-01],
                        [ -2.47344971e-01,  -2.47344971e-01],
                        [ -2.62817383e-01,  -2.62817383e-01],
                        [ -2.61108398e-01,  -2.61108398e-01],
                        [ -2.53875732e-01,  -2.53875732e-01],
                        [ -2.47344971e-01,  -2.47344971e-01],
                        [ -2.35961914e-01,  -2.35961914e-01],
                        [ -2.09686279e-01,  -2.09686279e-01],
                        [ -1.70684814e-01,  -1.70684814e-01],
                        [ -1.35375977e-01,  -1.35375977e-01],
                        [ -1.14837646e-01,  -1.14837646e-01],
                        [ -1.01043701e-01,  -1.01043701e-01],
                        [ -8.16040039e-02,  -8.16040039e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.29174805e-02,  -5.29174805e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  6.06994629e-02,   6.06994629e-02],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  1.27807617e-01,   1.27807617e-01],
                        [  1.51336670e-01,   1.51336670e-01],
                        [  1.64428711e-01,   1.64428711e-01],
                        [  1.67297363e-01,   1.67297363e-01],
                        [  1.67510986e-01,   1.67510986e-01],
                        [  1.73858643e-01,   1.73858643e-01],
                        [  1.85791016e-01,   1.85791016e-01],
                        [  1.94549561e-01,   1.94549561e-01],
                        [  1.93878174e-01,   1.93878174e-01],
                        [  1.84509277e-01,   1.84509277e-01],
                        [  1.68609619e-01,   1.68609619e-01],
                        [  1.48254395e-01,   1.48254395e-01],
                        [  1.27319336e-01,   1.27319336e-01],
                        [  1.08245850e-01,   1.08245850e-01],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  5.27038574e-02,   5.27038574e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  1.21734619e-01,   1.21734619e-01],
                        [  1.53717041e-01,   1.53717041e-01],
                        [  1.80755615e-01,   1.80755615e-01],
                        [  1.88659668e-01,   1.88659668e-01],
                        [  1.62414551e-01,   1.62414551e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -1.22406006e-01,  -1.22406006e-01],
                        [ -2.33428955e-01,  -2.33428955e-01],
                        [ -3.10882568e-01,  -3.10882568e-01],
                        [ -3.40240479e-01,  -3.40240479e-01],
                        [ -3.27239990e-01,  -3.27239990e-01],
                        [ -2.91198730e-01,  -2.91198730e-01],
                        [ -2.50274658e-01,  -2.50274658e-01],
                        [ -2.11822510e-01,  -2.11822510e-01],
                        [ -1.74835205e-01,  -1.74835205e-01],
                        [ -1.40106201e-01,  -1.40106201e-01],
                        [ -1.14044189e-01,  -1.14044189e-01],
                        [ -9.90295410e-02,  -9.90295410e-02],
                        [ -8.74328613e-02,  -8.74328613e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.55126953e-02,   2.55126953e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  1.48132324e-01,   1.48132324e-01],
                        [  1.76391602e-01,   1.76391602e-01],
                        [  1.88690186e-01,   1.88690186e-01],
                        [  1.94610596e-01,   1.94610596e-01],
                        [  2.02850342e-01,   2.02850342e-01],
                        [  2.11608887e-01,   2.11608887e-01],
                        [  2.11975098e-01,   2.11975098e-01],
                        [  2.00286865e-01,   2.00286865e-01],
                        [  1.83868408e-01,   1.83868408e-01],
                        [  1.71447754e-01,   1.71447754e-01],
                        [  1.61834717e-01,   1.61834717e-01],
                        [  1.47064209e-01,   1.47064209e-01],
                        [  1.24206543e-01,   1.24206543e-01],
                        [  9.92126465e-02,   9.92126465e-02],
                        [  7.91015625e-02,   7.91015625e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -8.63952637e-02,  -8.63952637e-02],
                        [ -8.74633789e-02,  -8.74633789e-02],
                        [ -7.91931152e-02,  -7.91931152e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  8.80432129e-02,   8.80432129e-02],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  1.66595459e-01,   1.66595459e-01],
                        [  1.97998047e-01,   1.97998047e-01],
                        [  2.04589844e-01,   2.04589844e-01],
                        [  1.76361084e-01,   1.76361084e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -1.28906250e-01,  -1.28906250e-01],
                        [ -2.61108398e-01,  -2.61108398e-01],
                        [ -3.59344482e-01,  -3.59344482e-01],
                        [ -3.94775391e-01,  -3.94775391e-01],
                        [ -3.67187500e-01,  -3.67187500e-01],
                        [ -3.06213379e-01,  -3.06213379e-01],
                        [ -2.45025635e-01,  -2.45025635e-01],
                        [ -1.98394775e-01,  -1.98394775e-01],
                        [ -1.64855957e-01,  -1.64855957e-01],
                        [ -1.38183594e-01,  -1.38183594e-01],
                        [ -1.13739014e-01,  -1.13739014e-01],
                        [ -9.23767090e-02,  -9.23767090e-02],
                        [ -7.98950195e-02,  -7.98950195e-02],
                        [ -7.77282715e-02,  -7.77282715e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  1.30462646e-01,   1.30462646e-01],
                        [  1.88201904e-01,   1.88201904e-01],
                        [  2.27874756e-01,   2.27874756e-01],
                        [  2.49786377e-01,   2.49786377e-01],
                        [  2.56713867e-01,   2.56713867e-01],
                        [  2.52166748e-01,   2.52166748e-01],
                        [  2.40081787e-01,   2.40081787e-01],
                        [  2.22412109e-01,   2.22412109e-01],
                        [  1.99218750e-01,   1.99218750e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.49627686e-01,   1.49627686e-01],
                        [  1.30981445e-01,   1.30981445e-01],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  7.00683594e-02,   7.00683594e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -7.29064941e-02,  -7.29064941e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -7.26318359e-02,  -7.26318359e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  8.00476074e-02,   8.00476074e-02],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  1.23474121e-01,   1.23474121e-01],
                        [  1.58630371e-01,   1.58630371e-01],
                        [  1.90673828e-01,   1.90673828e-01],
                        [  2.01324463e-01,   2.01324463e-01],
                        [  1.74682617e-01,   1.74682617e-01],
                        [  1.02142334e-01,   1.02142334e-01],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.59729004e-01,  -1.59729004e-01],
                        [ -2.99011230e-01,  -2.99011230e-01],
                        [ -3.90014648e-01,  -3.90014648e-01],
                        [ -4.06066895e-01,  -4.06066895e-01],
                        [ -3.55560303e-01,  -3.55560303e-01],
                        [ -2.74566650e-01,  -2.74566650e-01],
                        [ -2.01934814e-01,  -2.01934814e-01],
                        [ -1.58630371e-01,  -1.58630371e-01],
                        [ -1.40716553e-01,  -1.40716553e-01],
                        [ -1.28356934e-01,  -1.28356934e-01],
                        [ -1.07177734e-01,  -1.07177734e-01],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  8.79516602e-02,   8.79516602e-02],
                        [  1.64916992e-01,   1.64916992e-01],
                        [  2.34008789e-01,   2.34008789e-01],
                        [  2.73651123e-01,   2.73651123e-01],
                        [  2.78106689e-01,   2.78106689e-01],
                        [  2.62847900e-01,   2.62847900e-01],
                        [  2.45117188e-01,   2.45117188e-01],
                        [  2.27081299e-01,   2.27081299e-01],
                        [  2.04040527e-01,   2.04040527e-01],
                        [  1.78039551e-01,   1.78039551e-01],
                        [  1.53961182e-01,   1.53961182e-01],
                        [  1.31500244e-01,   1.31500244e-01],
                        [  1.08245850e-01,   1.08245850e-01],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -6.43615723e-02,  -6.43615723e-02],
                        [ -7.17773438e-02,  -7.17773438e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -7.92236328e-02,  -7.92236328e-02],
                        [ -7.65991211e-02,  -7.65991211e-02],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -5.68237305e-02,  -5.68237305e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  1.06323242e-01,   1.06323242e-01],
                        [  1.37725830e-01,   1.37725830e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.75964355e-01,   1.75964355e-01],
                        [  1.63360596e-01,   1.63360596e-01],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  2.55126953e-02,   2.55126953e-02],
                        [ -9.82055664e-02,  -9.82055664e-02],
                        [ -2.37091064e-01,  -2.37091064e-01],
                        [ -3.54217529e-01,  -3.54217529e-01],
                        [ -4.06646729e-01,  -4.06646729e-01],
                        [ -3.79028320e-01,  -3.79028320e-01],
                        [ -3.01055908e-01,  -3.01055908e-01],
                        [ -2.22564697e-01,  -2.22564697e-01],
                        [ -1.74011230e-01,  -1.74011230e-01],
                        [ -1.52618408e-01,  -1.52618408e-01],
                        [ -1.38183594e-01,  -1.38183594e-01],
                        [ -1.17614746e-01,  -1.17614746e-01],
                        [ -9.42687988e-02,  -9.42687988e-02],
                        [ -7.64770508e-02,  -7.64770508e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  1.74255371e-01,   1.74255371e-01],
                        [  2.37304688e-01,   2.37304688e-01],
                        [  2.77435303e-01,   2.77435303e-01],
                        [  2.86285400e-01,   2.86285400e-01],
                        [  2.67944336e-01,   2.67944336e-01],
                        [  2.36114502e-01,   2.36114502e-01],
                        [  2.05444336e-01,   2.05444336e-01],
                        [  1.82403564e-01,   1.82403564e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.46301270e-01,   1.46301270e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  7.86437988e-02,   7.86437988e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  1.07421875e-01,   1.07421875e-01],
                        [  1.31195068e-01,   1.31195068e-01],
                        [  1.60797119e-01,   1.60797119e-01],
                        [  1.84173584e-01,   1.84173584e-01],
                        [  1.83685303e-01,   1.83685303e-01],
                        [  1.47949219e-01,   1.47949219e-01],
                        [  7.32116699e-02,   7.32116699e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -1.78314209e-01,  -1.78314209e-01],
                        [ -3.09906006e-01,  -3.09906006e-01],
                        [ -3.91998291e-01,  -3.91998291e-01],
                        [ -3.98742676e-01,  -3.98742676e-01],
                        [ -3.41949463e-01,  -3.41949463e-01],
                        [ -2.63031006e-01,  -2.63031006e-01],
                        [ -2.00561523e-01,  -2.00561523e-01],
                        [ -1.66198730e-01,  -1.66198730e-01],
                        [ -1.48925781e-01,  -1.48925781e-01],
                        [ -1.33880615e-01,  -1.33880615e-01],
                        [ -1.15142822e-01,  -1.15142822e-01],
                        [ -9.56420898e-02,  -9.56420898e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [  4.03747559e-02,   4.03747559e-02],
                        [  1.15753174e-01,   1.15753174e-01],
                        [  1.95220947e-01,   1.95220947e-01],
                        [  2.61047363e-01,   2.61047363e-01],
                        [  2.98950195e-01,   2.98950195e-01],
                        [  3.01483154e-01,   3.01483154e-01],
                        [  2.73651123e-01,   2.73651123e-01],
                        [  2.34375000e-01,   2.34375000e-01],
                        [  2.03277588e-01,   2.03277588e-01],
                        [  1.84631348e-01,   1.84631348e-01],
                        [  1.70593262e-01,   1.70593262e-01],
                        [  1.54998779e-01,   1.54998779e-01],
                        [  1.37023926e-01,   1.37023926e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  9.13085938e-02,   9.13085938e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -8.20312500e-02,  -8.20312500e-02],
                        [ -8.98742676e-02,  -8.98742676e-02],
                        [ -8.70056152e-02,  -8.70056152e-02],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -6.75659180e-02,  -6.75659180e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  4.29992676e-02,   4.29992676e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  1.32446289e-01,   1.32446289e-01],
                        [  1.62719727e-01,   1.62719727e-01],
                        [  1.84356689e-01,   1.84356689e-01],
                        [  1.82739258e-01,   1.82739258e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  6.85424805e-02,   6.85424805e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -1.86553955e-01,  -1.86553955e-01],
                        [ -3.11096191e-01,  -3.11096191e-01],
                        [ -3.85284424e-01,  -3.85284424e-01],
                        [ -3.89953613e-01,  -3.89953613e-01],
                        [ -3.37066650e-01,  -3.37066650e-01],
                        [ -2.62023926e-01,  -2.62023926e-01],
                        [ -1.99371338e-01,  -1.99371338e-01],
                        [ -1.62811279e-01,  -1.62811279e-01],
                        [ -1.43981934e-01,  -1.43981934e-01],
                        [ -1.26922607e-01,  -1.26922607e-01],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -8.33740234e-02,  -8.33740234e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  1.76940918e-01,   1.76940918e-01],
                        [  2.58819580e-01,   2.58819580e-01],
                        [  3.14697266e-01,   3.14697266e-01],
                        [  3.27575684e-01,   3.27575684e-01],
                        [  3.01696777e-01,   3.01696777e-01],
                        [  2.58300781e-01,   2.58300781e-01],
                        [  2.16278076e-01,   2.16278076e-01],
                        [  1.81518555e-01,   1.81518555e-01],
                        [  1.52252197e-01,   1.52252197e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.08520508e-01,   1.08520508e-01],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  8.89587402e-02,   8.89587402e-02],
                        [  7.35473633e-02,   7.35473633e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -6.58569336e-02,  -6.58569336e-02],
                        [ -7.38525391e-02,  -7.38525391e-02],
                        [ -7.58361816e-02,  -7.58361816e-02],
                        [ -7.50122070e-02,  -7.50122070e-02],
                        [ -7.39440918e-02,  -7.39440918e-02],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -6.96411133e-02,  -6.96411133e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.79901123e-01,   1.79901123e-01],
                        [  1.80969238e-01,   1.80969238e-01],
                        [  1.48162842e-01,   1.48162842e-01],
                        [  8.41064453e-02,   8.41064453e-02],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -1.06079102e-01,  -1.06079102e-01],
                        [ -2.08831787e-01,  -2.08831787e-01],
                        [ -2.96966553e-01,  -2.96966553e-01],
                        [ -3.51959229e-01,  -3.51959229e-01],
                        [ -3.59954834e-01,  -3.59954834e-01],
                        [ -3.23211670e-01,  -3.23211670e-01],
                        [ -2.61444092e-01,  -2.61444092e-01],
                        [ -2.00592041e-01,  -2.00592041e-01],
                        [ -1.58020020e-01,  -1.58020020e-01],
                        [ -1.32537842e-01,  -1.32537842e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.83685303e-01,   1.83685303e-01],
                        [  2.54882812e-01,   2.54882812e-01],
                        [  2.98217773e-01,   2.98217773e-01],
                        [  3.04840088e-01,   3.04840088e-01],
                        [  2.81707764e-01,   2.81707764e-01],
                        [  2.44476318e-01,   2.44476318e-01],
                        [  2.04864502e-01,   2.04864502e-01],
                        [  1.68426514e-01,   1.68426514e-01],
                        [  1.39831543e-01,   1.39831543e-01],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  9.27124023e-02,   9.27124023e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -6.43920898e-02,  -6.43920898e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.70471191e-02,  -6.70471191e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  9.71984863e-02,   9.71984863e-02],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  1.41021729e-01,   1.41021729e-01],
                        [  1.56646729e-01,   1.56646729e-01],
                        [  1.56341553e-01,   1.56341553e-01],
                        [  1.31591797e-01,   1.31591797e-01],
                        [  8.28552246e-02,   8.28552246e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -1.45019531e-01,  -1.45019531e-01],
                        [ -2.29095459e-01,  -2.29095459e-01],
                        [ -3.00842285e-01,  -3.00842285e-01],
                        [ -3.44573975e-01,  -3.44573975e-01],
                        [ -3.45733643e-01,  -3.45733643e-01],
                        [ -3.03588867e-01,  -3.03588867e-01],
                        [ -2.39349365e-01,  -2.39349365e-01],
                        [ -1.83135986e-01,  -1.83135986e-01],
                        [ -1.48742676e-01,  -1.48742676e-01],
                        [ -1.25823975e-01,  -1.25823975e-01],
                        [ -9.85107422e-02,  -9.85107422e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  1.11633301e-01,   1.11633301e-01],
                        [  1.92321777e-01,   1.92321777e-01],
                        [  2.62573242e-01,   2.62573242e-01],
                        [  3.04412842e-01,   3.04412842e-01],
                        [  3.12164307e-01,   3.12164307e-01],
                        [  2.91137695e-01,   2.91137695e-01],
                        [  2.52258301e-01,   2.52258301e-01],
                        [  2.08099365e-01,   2.08099365e-01],
                        [  1.68365479e-01,   1.68365479e-01],
                        [  1.37603760e-01,   1.37603760e-01],
                        [  1.16790771e-01,   1.16790771e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  8.77075195e-02,   8.77075195e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  4.60815430e-03,   4.60815430e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -5.66101074e-02,  -5.66101074e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -7.08923340e-02,  -7.08923340e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.33789062e-01,   1.33789062e-01],
                        [  1.45660400e-01,   1.45660400e-01],
                        [  1.45233154e-01,   1.45233154e-01],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  9.45434570e-02,   9.45434570e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -8.85314941e-02,  -8.85314941e-02],
                        [ -1.62475586e-01,  -1.62475586e-01],
                        [ -2.35229492e-01,  -2.35229492e-01],
                        [ -3.02307129e-01,  -3.02307129e-01],
                        [ -3.47717285e-01,  -3.47717285e-01],
                        [ -3.48175049e-01,  -3.48175049e-01],
                        [ -2.97729492e-01,  -2.97729492e-01],
                        [ -2.21862793e-01,  -2.21862793e-01],
                        [ -1.57287598e-01,  -1.57287598e-01],
                        [ -1.20269775e-01,  -1.20269775e-01],
                        [ -1.00097656e-01,  -1.00097656e-01],
                        [ -8.08715820e-02,  -8.08715820e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  3.20434570e-03,   3.20434570e-03],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  3.92456055e-02,   3.92456055e-02],
                        [  9.53979492e-02,   9.53979492e-02],
                        [  1.61010742e-01,   1.61010742e-01],
                        [  2.24365234e-01,   2.24365234e-01],
                        [  2.72613525e-01,   2.72613525e-01],
                        [  2.95593262e-01,   2.95593262e-01],
                        [  2.88970947e-01,   2.88970947e-01],
                        [  2.58361816e-01,   2.58361816e-01],
                        [  2.19024658e-01,   2.19024658e-01],
                        [  1.85485840e-01,   1.85485840e-01],
                        [  1.61254883e-01,   1.61254883e-01],
                        [  1.41632080e-01,   1.41632080e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.05712891e-01,   1.05712891e-01],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  7.93151855e-02,   7.93151855e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -5.25207520e-02,  -5.25207520e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -7.69653320e-02,  -7.69653320e-02],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -1.24328613e-01,  -1.24328613e-01],
                        [ -1.88903809e-01,  -1.88903809e-01],
                        [ -2.70324707e-01,  -2.70324707e-01],
                        [ -3.31024170e-01,  -3.31024170e-01],
                        [ -3.34228516e-01,  -3.34228516e-01],
                        [ -2.79998779e-01,  -2.79998779e-01],
                        [ -2.02789307e-01,  -2.02789307e-01],
                        [ -1.40655518e-01,  -1.40655518e-01],
                        [ -1.08825684e-01,  -1.08825684e-01],
                        [ -9.50317383e-02,  -9.50317383e-02],
                        [ -7.80334473e-02,  -7.80334473e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.59088135e-01,   1.59088135e-01],
                        [  2.05169678e-01,   2.05169678e-01],
                        [  2.44995117e-01,   2.44995117e-01],
                        [  2.71514893e-01,   2.71514893e-01],
                        [  2.75787354e-01,   2.75787354e-01],
                        [  2.55645752e-01,   2.55645752e-01],
                        [  2.21801758e-01,   2.21801758e-01],
                        [  1.88171387e-01,   1.88171387e-01],
                        [  1.60522461e-01,   1.60522461e-01],
                        [  1.37878418e-01,   1.37878418e-01],
                        [  1.17858887e-01,   1.17858887e-01],
                        [  9.86633301e-02,   9.86633301e-02],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  2.55126953e-02,   2.55126953e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  7.94372559e-02,   7.94372559e-02],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.14929199e-01,   1.14929199e-01],
                        [  1.02630615e-01,   1.02630615e-01],
                        [  7.65686035e-02,   7.65686035e-02],
                        [  4.03137207e-02,   4.03137207e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -1.10534668e-01,  -1.10534668e-01],
                        [ -1.89544678e-01,  -1.89544678e-01],
                        [ -2.75268555e-01,  -2.75268555e-01],
                        [ -3.26324463e-01,  -3.26324463e-01],
                        [ -3.16406250e-01,  -3.16406250e-01],
                        [ -2.57385254e-01,  -2.57385254e-01],
                        [ -1.87622070e-01,  -1.87622070e-01],
                        [ -1.38366699e-01,  -1.38366699e-01],
                        [ -1.12823486e-01,  -1.12823486e-01],
                        [ -9.41162109e-02,  -9.41162109e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  1.48284912e-01,   1.48284912e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  2.31994629e-01,   2.31994629e-01],
                        [  2.68127441e-01,   2.68127441e-01],
                        [  2.88085938e-01,   2.88085938e-01],
                        [  2.79052734e-01,   2.79052734e-01],
                        [  2.41455078e-01,   2.41455078e-01],
                        [  1.93145752e-01,   1.93145752e-01],
                        [  1.52160645e-01,   1.52160645e-01],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.01104736e-01,   1.01104736e-01],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -6.75048828e-02,  -6.75048828e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -6.63452148e-02,  -6.63452148e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -7.08618164e-02,  -7.08618164e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -5.66101074e-02,  -5.66101074e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  7.73010254e-02,   7.73010254e-02],
                        [  8.92639160e-02,   8.92639160e-02],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -1.06872559e-01,  -1.06872559e-01],
                        [ -1.97052002e-01,  -1.97052002e-01],
                        [ -2.83142090e-01,  -2.83142090e-01],
                        [ -3.25286865e-01,  -3.25286865e-01],
                        [ -3.07220459e-01,  -3.07220459e-01],
                        [ -2.45727539e-01,  -2.45727539e-01],
                        [ -1.74865723e-01,  -1.74865723e-01],
                        [ -1.22497559e-01,  -1.22497559e-01],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  1.37054443e-01,   1.37054443e-01],
                        [  1.60583496e-01,   1.60583496e-01],
                        [  1.91894531e-01,   1.91894531e-01],
                        [  2.29034424e-01,   2.29034424e-01],
                        [  2.57843018e-01,   2.57843018e-01],
                        [  2.62542725e-01,   2.62542725e-01],
                        [  2.43194580e-01,   2.43194580e-01],
                        [  2.12768555e-01,   2.12768555e-01],
                        [  1.80297852e-01,   1.80297852e-01],
                        [  1.47735596e-01,   1.47735596e-01],
                        [  1.18682861e-01,   1.18682861e-01],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  4.65698242e-02,   4.65698242e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -5.95092773e-02,  -5.95092773e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -6.72607422e-02,  -6.72607422e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  2.27966309e-02,   2.27966309e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -7.88574219e-02,  -7.88574219e-02],
                        [ -1.73309326e-01,  -1.73309326e-01],
                        [ -2.59368896e-01,  -2.59368896e-01],
                        [ -3.06945801e-01,  -3.06945801e-01],
                        [ -2.99011230e-01,  -2.99011230e-01],
                        [ -2.45239258e-01,  -2.45239258e-01],
                        [ -1.76086426e-01,  -1.76086426e-01],
                        [ -1.19354248e-01,  -1.19354248e-01],
                        [ -8.43505859e-02,  -8.43505859e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.17095947e-01,   1.17095947e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.80419922e-01,   1.80419922e-01],
                        [  2.19970703e-01,   2.19970703e-01],
                        [  2.41607666e-01,   2.41607666e-01],
                        [  2.34558105e-01,   2.34558105e-01],
                        [  2.02850342e-01,   2.02850342e-01],
                        [  1.61224365e-01,   1.61224365e-01],
                        [  1.26373291e-01,   1.26373291e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  3.60107422e-03,   3.60107422e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -7.02514648e-02,  -7.02514648e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -8.78295898e-02,  -8.78295898e-02],
                        [ -9.97314453e-02,  -9.97314453e-02],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -1.31225586e-01,  -1.31225586e-01],
                        [ -2.08770752e-01,  -2.08770752e-01],
                        [ -2.60467529e-01,  -2.60467529e-01],
                        [ -2.65014648e-01,  -2.65014648e-01],
                        [ -2.26684570e-01,  -2.26684570e-01],
                        [ -1.71630859e-01,  -1.71630859e-01],
                        [ -1.24450684e-01,  -1.24450684e-01],
                        [ -9.34448242e-02,  -9.34448242e-02],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [  2.71606445e-03,   2.71606445e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  6.88171387e-02,   6.88171387e-02],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  1.06750488e-01,   1.06750488e-01],
                        [  1.23504639e-01,   1.23504639e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.92840576e-01,   1.92840576e-01],
                        [  2.23175049e-01,   2.23175049e-01],
                        [  2.35412598e-01,   2.35412598e-01],
                        [  2.26379395e-01,   2.26379395e-01],
                        [  2.00195312e-01,   2.00195312e-01],
                        [  1.68487549e-01,   1.68487549e-01],
                        [  1.42578125e-01,   1.42578125e-01],
                        [  1.21765137e-01,   1.21765137e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  5.79223633e-02,   5.79223633e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  3.37524414e-02,   3.37524414e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -7.49206543e-02,  -7.49206543e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -7.25097656e-02,  -7.25097656e-02],
                        [ -6.66809082e-02,  -6.66809082e-02],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  9.52453613e-02,   9.52453613e-02],
                        [  9.86633301e-02,   9.86633301e-02],
                        [  8.62731934e-02,   8.62731934e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -9.75952148e-02,  -9.75952148e-02],
                        [ -1.07574463e-01,  -1.07574463e-01],
                        [ -8.06579590e-02,  -8.06579590e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -9.68017578e-02,  -9.68017578e-02],
                        [ -1.80938721e-01,  -1.80938721e-01],
                        [ -2.56835938e-01,  -2.56835938e-01],
                        [ -2.91473389e-01,  -2.91473389e-01],
                        [ -2.69134521e-01,  -2.69134521e-01],
                        [ -2.06390381e-01,  -2.06390381e-01],
                        [ -1.38183594e-01,  -1.38183594e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  6.75659180e-02,   6.75659180e-02],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.58416748e-01,   1.58416748e-01],
                        [  1.99066162e-01,   1.99066162e-01],
                        [  2.27233887e-01,   2.27233887e-01],
                        [  2.32543945e-01,   2.32543945e-01],
                        [  2.16400146e-01,   2.16400146e-01],
                        [  1.89392090e-01,   1.89392090e-01],
                        [  1.61651611e-01,   1.61651611e-01],
                        [  1.39068604e-01,   1.39068604e-01],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.07421875e-01,   1.07421875e-01],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -6.92443848e-02,  -6.92443848e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -6.83288574e-02,  -6.83288574e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  8.64562988e-02,   8.64562988e-02],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -1.09436035e-01,  -1.09436035e-01],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -1.04827881e-01,  -1.04827881e-01],
                        [ -1.87164307e-01,  -1.87164307e-01],
                        [ -2.50427246e-01,  -2.50427246e-01],
                        [ -2.68524170e-01,  -2.68524170e-01],
                        [ -2.37518311e-01,  -2.37518311e-01],
                        [ -1.80725098e-01,  -1.80725098e-01],
                        [ -1.28723145e-01,  -1.28723145e-01],
                        [ -9.70153809e-02,  -9.70153809e-02],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  9.07897949e-02,   9.07897949e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  1.09466553e-01,   1.09466553e-01],
                        [  1.43402100e-01,   1.43402100e-01],
                        [  1.83258057e-01,   1.83258057e-01],
                        [  2.14263916e-01,   2.14263916e-01],
                        [  2.24853516e-01,   2.24853516e-01],
                        [  2.13012695e-01,   2.13012695e-01],
                        [  1.85913086e-01,   1.85913086e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  5.44738770e-02,   5.44738770e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  9.65881348e-02,   9.65881348e-02],
                        [  8.05664062e-02,   8.05664062e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -6.62231445e-02,  -6.62231445e-02],
                        [ -1.13677979e-01,  -1.13677979e-01],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  5.70678711e-03,   5.70678711e-03],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -2.10601807e-01,  -2.10601807e-01],
                        [ -2.61932373e-01,  -2.61932373e-01],
                        [ -2.62298584e-01,  -2.62298584e-01],
                        [ -2.18048096e-01,  -2.18048096e-01],
                        [ -1.54113770e-01,  -1.54113770e-01],
                        [ -9.76562500e-02,  -9.76562500e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  6.53076172e-02,   6.53076172e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  1.25762939e-01,   1.25762939e-01],
                        [  1.33666992e-01,   1.33666992e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  7.28454590e-02,   7.28454590e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  1.00036621e-01,   1.00036621e-01],
                        [  1.45202637e-01,   1.45202637e-01],
                        [  1.88262939e-01,   1.88262939e-01],
                        [  2.17254639e-01,   2.17254639e-01],
                        [  2.23846436e-01,   2.23846436e-01],
                        [  2.05718994e-01,   2.05718994e-01],
                        [  1.72882080e-01,   1.72882080e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  7.93762207e-02,   7.93762207e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -7.13500977e-02,  -7.13500977e-02],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -1.03546143e-01,  -1.03546143e-01],
                        [ -1.44592285e-01,  -1.44592285e-01],
                        [ -1.42211914e-01,  -1.42211914e-01],
                        [ -9.79919434e-02,  -9.79919434e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  7.58666992e-02,   7.58666992e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -1.78558350e-01,  -1.78558350e-01],
                        [ -2.55126953e-01,  -2.55126953e-01],
                        [ -2.83843994e-01,  -2.83843994e-01],
                        [ -2.54608154e-01,  -2.54608154e-01],
                        [ -1.88507080e-01,  -1.88507080e-01],
                        [ -1.24084473e-01,  -1.24084473e-01],
                        [ -8.79516602e-02,  -8.79516602e-02],
                        [ -7.77587891e-02,  -7.77587891e-02],
                        [ -7.35778809e-02,  -7.35778809e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  1.28387451e-01,   1.28387451e-01],
                        [  1.40106201e-01,   1.40106201e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  9.71374512e-02,   9.71374512e-02],
                        [  1.41540527e-01,   1.41540527e-01],
                        [  1.90429688e-01,   1.90429688e-01],
                        [  2.27233887e-01,   2.27233887e-01],
                        [  2.39288330e-01,   2.39288330e-01],
                        [  2.23083496e-01,   2.23083496e-01],
                        [  1.86553955e-01,   1.86553955e-01],
                        [  1.46820068e-01,   1.46820068e-01],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  5.92651367e-02,   5.92651367e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -6.62231445e-02,  -6.62231445e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.21948242e-02,  -6.21948242e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -8.06884766e-02,  -8.06884766e-02],
                        [ -1.22833252e-01,  -1.22833252e-01],
                        [ -1.29119873e-01,  -1.29119873e-01],
                        [ -9.66491699e-02,  -9.66491699e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -2.19360352e-01,  -2.19360352e-01],
                        [ -2.73498535e-01,  -2.73498535e-01],
                        [ -2.72521973e-01,  -2.72521973e-01],
                        [ -2.23999023e-01,  -2.23999023e-01],
                        [ -1.58325195e-01,  -1.58325195e-01],
                        [ -1.05407715e-01,  -1.05407715e-01],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  6.90002441e-02,   6.90002441e-02],
                        [  1.03302002e-01,   1.03302002e-01],
                        [  1.29150391e-01,   1.29150391e-01],
                        [  1.35162354e-01,   1.35162354e-01],
                        [  1.20269775e-01,   1.20269775e-01],
                        [  9.41162109e-02,   9.41162109e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  6.52160645e-02,   6.52160645e-02],
                        [  7.64770508e-02,   7.64770508e-02],
                        [  1.01959229e-01,   1.01959229e-01],
                        [  1.37207031e-01,   1.37207031e-01],
                        [  1.75354004e-01,   1.75354004e-01],
                        [  2.04803467e-01,   2.04803467e-01],
                        [  2.14477539e-01,   2.14477539e-01],
                        [  2.01782227e-01,   2.01782227e-01],
                        [  1.74987793e-01,   1.74987793e-01],
                        [  1.47460938e-01,   1.47460938e-01],
                        [  1.26892090e-01,   1.26892090e-01],
                        [  1.09924316e-01,   1.09924316e-01],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  6.52770996e-02,   6.52770996e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.95092773e-02,  -5.95092773e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  7.67211914e-02,   7.67211914e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -1.31408691e-01,  -1.31408691e-01],
                        [ -1.64459229e-01,  -1.64459229e-01],
                        [ -1.49169922e-01,  -1.49169922e-01],
                        [ -9.60388184e-02,  -9.60388184e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  6.53991699e-02,   6.53991699e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  3.69567871e-02,   3.69567871e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -1.15112305e-01,  -1.15112305e-01],
                        [ -2.04284668e-01,  -2.04284668e-01],
                        [ -2.58331299e-01,  -2.58331299e-01],
                        [ -2.56011963e-01,  -2.56011963e-01],
                        [ -2.06268311e-01,  -2.06268311e-01],
                        [ -1.43066406e-01,  -1.43066406e-01],
                        [ -9.78088379e-02,  -9.78088379e-02],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  1.46514893e-01,   1.46514893e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  5.14526367e-02,   5.14526367e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.68395996e-01,   1.68395996e-01],
                        [  2.07885742e-01,   2.07885742e-01],
                        [  2.24151611e-01,   2.24151611e-01],
                        [  2.12799072e-01,   2.12799072e-01],
                        [  1.82250977e-01,   1.82250977e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.00128174e-01,   1.00128174e-01],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  8.07189941e-02,   8.07189941e-02],
                        [  7.78198242e-02,   7.78198242e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  6.45446777e-02,   6.45446777e-02],
                        [  5.31921387e-02,   5.31921387e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  3.96728516e-03,   3.96728516e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.93359375e-02,  -6.93359375e-02],
                        [ -7.36083984e-02,  -7.36083984e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -6.92443848e-02,  -6.92443848e-02],
                        [ -7.58361816e-02,  -7.58361816e-02],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  4.48913574e-02,   4.48913574e-02],
                        [  5.58471680e-02,   5.58471680e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -1.21490479e-01,  -1.21490479e-01],
                        [ -1.57012939e-01,  -1.57012939e-01],
                        [ -1.47338867e-01,  -1.47338867e-01],
                        [ -1.03942871e-01,  -1.03942871e-01],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  4.18701172e-02,   4.18701172e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  5.30700684e-02,   5.30700684e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -1.40045166e-01,  -1.40045166e-01],
                        [ -2.15332031e-01,  -2.15332031e-01],
                        [ -2.47222900e-01,  -2.47222900e-01],
                        [ -2.30712891e-01,  -2.30712891e-01],
                        [ -1.83380127e-01,  -1.83380127e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -8.66088867e-02,  -8.66088867e-02],
                        [ -6.59179688e-02,  -6.59179688e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  6.52770996e-02,   6.52770996e-02],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  1.53533936e-01,   1.53533936e-01],
                        [  1.52801514e-01,   1.52801514e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  5.10864258e-02,   5.10864258e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  1.40106201e-01,   1.40106201e-01],
                        [  1.78161621e-01,   1.78161621e-01],
                        [  2.01141357e-01,   2.01141357e-01],
                        [  2.03796387e-01,   2.03796387e-01],
                        [  1.88568115e-01,   1.88568115e-01],
                        [  1.65802002e-01,   1.65802002e-01],
                        [  1.47277832e-01,   1.47277832e-01],
                        [  1.33941650e-01,   1.33941650e-01],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  4.93164062e-02,   4.93164062e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  7.90405273e-03,   7.90405273e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -7.00683594e-02,  -7.00683594e-02],
                        [ -7.54394531e-02,  -7.54394531e-02],
                        [ -7.73010254e-02,  -7.73010254e-02],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -7.27844238e-02,  -7.27844238e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  7.44323730e-02,   7.44323730e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -1.02355957e-01,  -1.02355957e-01],
                        [ -1.56707764e-01,  -1.56707764e-01],
                        [ -1.68731689e-01,  -1.68731689e-01],
                        [ -1.38580322e-01,  -1.38580322e-01],
                        [ -8.45031738e-02,  -8.45031738e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.05957031e-01,  -1.05957031e-01],
                        [ -1.91223145e-01,  -1.91223145e-01],
                        [ -2.49542236e-01,  -2.49542236e-01],
                        [ -2.61688232e-01,  -2.61688232e-01],
                        [ -2.27508545e-01,  -2.27508545e-01],
                        [ -1.68121338e-01,  -1.68121338e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -8.20922852e-02,  -8.20922852e-02],
                        [ -7.01599121e-02,  -7.01599121e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  1.02691650e-01,   1.02691650e-01],
                        [  1.35833740e-01,   1.35833740e-01],
                        [  1.48986816e-01,   1.48986816e-01],
                        [  1.37603760e-01,   1.37603760e-01],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.63787842e-01,   1.63787842e-01],
                        [  2.04864502e-01,   2.04864502e-01],
                        [  2.27050781e-01,   2.27050781e-01],
                        [  2.22045898e-01,   2.22045898e-01],
                        [  1.93725586e-01,   1.93725586e-01],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -6.74743652e-02,  -6.74743652e-02],
                        [ -7.37609863e-02,  -7.37609863e-02],
                        [ -7.33947754e-02,  -7.33947754e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -9.21936035e-02,  -9.21936035e-02],
                        [ -1.56097412e-01,  -1.56097412e-01],
                        [ -1.85485840e-01,  -1.85485840e-01],
                        [ -1.65893555e-01,  -1.65893555e-01],
                        [ -1.06964111e-01,  -1.06964111e-01],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -1.39343262e-01,  -1.39343262e-01],
                        [ -2.23052979e-01,  -2.23052979e-01],
                        [ -2.63549805e-01,  -2.63549805e-01],
                        [ -2.50823975e-01,  -2.50823975e-01],
                        [ -2.00317383e-01,  -2.00317383e-01],
                        [ -1.40441895e-01,  -1.40441895e-01],
                        [ -9.67102051e-02,  -9.67102051e-02],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  1.22467041e-01,   1.22467041e-01],
                        [  1.26586914e-01,   1.26586914e-01],
                        [  1.15905762e-01,   1.15905762e-01],
                        [  9.71984863e-02,   9.71984863e-02],
                        [  7.82775879e-02,   7.82775879e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  5.21545410e-02,   5.21545410e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  1.40411377e-01,   1.40411377e-01],
                        [  1.83929443e-01,   1.83929443e-01],
                        [  2.13165283e-01,   2.13165283e-01],
                        [  2.16888428e-01,   2.16888428e-01],
                        [  1.96166992e-01,   1.96166992e-01],
                        [  1.65588379e-01,   1.65588379e-01],
                        [  1.39678955e-01,   1.39678955e-01],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  5.30090332e-02,   5.30090332e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  4.46472168e-02,   4.46472168e-02],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -1.27716064e-01,  -1.27716064e-01],
                        [ -1.66870117e-01,  -1.66870117e-01],
                        [ -1.69006348e-01,  -1.69006348e-01],
                        [ -1.35101318e-01,  -1.35101318e-01],
                        [ -8.17565918e-02,  -8.17565918e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  5.11474609e-02,   5.11474609e-02],
                        [  6.41479492e-02,   6.41479492e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -1.98547363e-01,  -1.98547363e-01],
                        [ -2.32849121e-01,  -2.32849121e-01],
                        [ -2.17895508e-01,  -2.17895508e-01],
                        [ -1.69250488e-01,  -1.69250488e-01],
                        [ -1.17950439e-01,  -1.17950439e-01],
                        [ -8.71582031e-02,  -8.71582031e-02],
                        [ -7.78808594e-02,  -7.78808594e-02],
                        [ -7.61718750e-02,  -7.61718750e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  1.27136230e-01,   1.27136230e-01],
                        [  1.27807617e-01,   1.27807617e-01],
                        [  1.18347168e-01,   1.18347168e-01],
                        [  1.03546143e-01,   1.03546143e-01],
                        [  8.66088867e-02,   8.66088867e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  1.58508301e-01,   1.58508301e-01],
                        [  1.95465088e-01,   1.95465088e-01],
                        [  2.15728760e-01,   2.15728760e-01],
                        [  2.13256836e-01,   2.13256836e-01],
                        [  1.89544678e-01,   1.89544678e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.16088867e-01,   1.16088867e-01],
                        [  8.72802734e-02,   8.72802734e-02],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -7.26623535e-02,  -7.26623535e-02],
                        [ -6.86950684e-02,  -6.86950684e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.99060059e-02,  -5.99060059e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  7.03125000e-02,   7.03125000e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -1.26647949e-01,  -1.26647949e-01],
                        [ -1.63757324e-01,  -1.63757324e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.27746582e-01,  -1.27746582e-01],
                        [ -8.32214355e-02,  -8.32214355e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -1.43005371e-01,  -1.43005371e-01],
                        [ -2.11517334e-01,  -2.11517334e-01],
                        [ -2.38281250e-01,  -2.38281250e-01],
                        [ -2.16796875e-01,  -2.16796875e-01],
                        [ -1.63757324e-01,  -1.63757324e-01],
                        [ -1.09619141e-01,  -1.09619141e-01],
                        [ -7.69348145e-02,  -7.69348145e-02],
                        [ -6.62231445e-02,  -6.62231445e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.34674072e-01,   1.34674072e-01],
                        [  1.41510010e-01,   1.41510010e-01],
                        [  1.34460449e-01,   1.34460449e-01],
                        [  1.18041992e-01,   1.18041992e-01],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  1.40167236e-01,   1.40167236e-01],
                        [  1.84143066e-01,   1.84143066e-01],
                        [  2.06817627e-01,   2.06817627e-01],
                        [  2.03674316e-01,   2.03674316e-01],
                        [  1.80389404e-01,   1.80389404e-01],
                        [  1.48254395e-01,   1.48254395e-01],
                        [  1.17156982e-01,   1.17156982e-01],
                        [  9.16442871e-02,   9.16442871e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  5.58471680e-02,   5.58471680e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -7.20214844e-02,  -7.20214844e-02],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -7.88879395e-02,  -7.88879395e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -1.28143311e-01,  -1.28143311e-01],
                        [ -1.74896240e-01,  -1.74896240e-01],
                        [ -1.84082031e-01,  -1.84082031e-01],
                        [ -1.52893066e-01,  -1.52893066e-01],
                        [ -1.01226807e-01,  -1.01226807e-01],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  6.62536621e-02,   6.62536621e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -1.51733398e-01,  -1.51733398e-01],
                        [ -2.07244873e-01,  -2.07244873e-01],
                        [ -2.22137451e-01,  -2.22137451e-01],
                        [ -1.97753906e-01,  -1.97753906e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.17706299e-01,  -1.17706299e-01],
                        [ -9.86938477e-02,  -9.86938477e-02],
                        [ -8.85314941e-02,  -8.85314941e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  9.10339355e-02,   9.10339355e-02],
                        [  1.24145508e-01,   1.24145508e-01],
                        [  1.43951416e-01,   1.43951416e-01],
                        [  1.47277832e-01,   1.47277832e-01],
                        [  1.35375977e-01,   1.35375977e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  8.29162598e-02,   8.29162598e-02],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.82220459e-01,   1.82220459e-01],
                        [  2.14355469e-01,   2.14355469e-01],
                        [  2.19177246e-01,   2.19177246e-01],
                        [  1.95739746e-01,   1.95739746e-01],
                        [  1.55120850e-01,   1.55120850e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  9.23156738e-02,   9.23156738e-02],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  6.88171387e-02,   6.88171387e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -1.06811523e-01,  -1.06811523e-01],
                        [ -1.63482666e-01,  -1.63482666e-01],
                        [ -1.90734863e-01,  -1.90734863e-01],
                        [ -1.75750732e-01,  -1.75750732e-01],
                        [ -1.30004883e-01,  -1.30004883e-01],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -1.44042969e-01,  -1.44042969e-01],
                        [ -2.01477051e-01,  -2.01477051e-01],
                        [ -2.20642090e-01,  -2.20642090e-01],
                        [ -1.98730469e-01,  -1.98730469e-01],
                        [ -1.54876709e-01,  -1.54876709e-01],
                        [ -1.14166260e-01,  -1.14166260e-01],
                        [ -8.70361328e-02,  -8.70361328e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  1.33819580e-01,   1.33819580e-01],
                        [  1.49047852e-01,   1.49047852e-01],
                        [  1.46270752e-01,   1.46270752e-01],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  8.93249512e-02,   8.93249512e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.62475586e-01,   1.62475586e-01],
                        [  1.91406250e-01,   1.91406250e-01],
                        [  1.96807861e-01,   1.96807861e-01],
                        [  1.78344727e-01,   1.78344727e-01],
                        [  1.48345947e-01,   1.48345947e-01],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  8.06884766e-02,   8.06884766e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -7.38830566e-02,  -7.38830566e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -1.37725830e-01,  -1.37725830e-01],
                        [ -1.89117432e-01,  -1.89117432e-01],
                        [ -2.05383301e-01,  -2.05383301e-01],
                        [ -1.84020996e-01,  -1.84020996e-01],
                        [ -1.38946533e-01,  -1.38946533e-01],
                        [ -8.90197754e-02,  -8.90197754e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -1.24359131e-01,  -1.24359131e-01],
                        [ -1.90826416e-01,  -1.90826416e-01],
                        [ -2.20184326e-01,  -2.20184326e-01],
                        [ -2.05291748e-01,  -2.05291748e-01],
                        [ -1.63635254e-01,  -1.63635254e-01],
                        [ -1.20819092e-01,  -1.20819092e-01],
                        [ -9.14916992e-02,  -9.14916992e-02],
                        [ -7.49206543e-02,  -7.49206543e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  4.65698242e-02,   4.65698242e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  1.16943359e-01,   1.16943359e-01],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.16882324e-01,   1.16882324e-01],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  9.95788574e-02,   9.95788574e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  1.03912354e-01,   1.03912354e-01],
                        [  1.43524170e-01,   1.43524170e-01],
                        [  1.76818848e-01,   1.76818848e-01],
                        [  1.92779541e-01,   1.92779541e-01],
                        [  1.82434082e-01,   1.82434082e-01],
                        [  1.52862549e-01,   1.52862549e-01],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  8.15124512e-02,   8.15124512e-02],
                        [  7.29370117e-02,   7.29370117e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  7.30285645e-02,   7.30285645e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -1.21490479e-01,  -1.21490479e-01],
                        [ -1.84661865e-01,  -1.84661865e-01],
                        [ -2.07885742e-01,  -2.07885742e-01],
                        [ -1.88720703e-01,  -1.88720703e-01],
                        [ -1.46636963e-01,  -1.46636963e-01],
                        [ -1.06872559e-01,  -1.06872559e-01],
                        [ -8.05969238e-02,  -8.05969238e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  8.19396973e-02,   8.19396973e-02],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  5.02014160e-02,   5.02014160e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -1.38854980e-01,  -1.38854980e-01],
                        [ -2.14416504e-01,  -2.14416504e-01],
                        [ -2.42218018e-01,  -2.42218018e-01],
                        [ -2.19238281e-01,  -2.19238281e-01],
                        [ -1.66259766e-01,  -1.66259766e-01],
                        [ -1.14532471e-01,  -1.14532471e-01],
                        [ -8.50524902e-02,  -8.50524902e-02],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.14013672e-01,   1.14013672e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  4.49829102e-02,   4.49829102e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.47857666e-01,   1.47857666e-01],
                        [  1.78985596e-01,   1.78985596e-01],
                        [  1.92596436e-01,   1.92596436e-01],
                        [  1.80236816e-01,   1.80236816e-01],
                        [  1.50726318e-01,   1.50726318e-01],
                        [  1.22863770e-01,   1.22863770e-01],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  6.71386719e-04,   6.71386719e-04],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.75048828e-02,  -6.75048828e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -9.07897949e-02,  -9.07897949e-02],
                        [ -1.59606934e-01,  -1.59606934e-01],
                        [ -1.96777344e-01,  -1.96777344e-01],
                        [ -1.95526123e-01,  -1.95526123e-01],
                        [ -1.67297363e-01,  -1.67297363e-01],
                        [ -1.30554199e-01,  -1.30554199e-01],
                        [ -9.90295410e-02,  -9.90295410e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [  9.46044922e-04,   9.46044922e-04],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  1.18682861e-01,   1.18682861e-01],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  4.99877930e-02,   4.99877930e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -1.35375977e-01,  -1.35375977e-01],
                        [ -2.13256836e-01,  -2.13256836e-01],
                        [ -2.42095947e-01,  -2.42095947e-01],
                        [ -2.20397949e-01,  -2.20397949e-01],
                        [ -1.70349121e-01,  -1.70349121e-01],
                        [ -1.21673584e-01,  -1.21673584e-01],
                        [ -9.04846191e-02,  -9.04846191e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  1.32873535e-01,   1.32873535e-01],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  1.04553223e-01,   1.04553223e-01],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  9.22241211e-02,   9.22241211e-02],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.64306641e-01,   1.64306641e-01],
                        [  1.80450439e-01,   1.80450439e-01],
                        [  1.70745850e-01,   1.70745850e-01],
                        [  1.44500732e-01,   1.44500732e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -7.22045898e-02,  -7.22045898e-02],
                        [ -7.51342773e-02,  -7.51342773e-02],
                        [ -7.37609863e-02,  -7.37609863e-02],
                        [ -6.90307617e-02,  -6.90307617e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -1.10351562e-01,  -1.10351562e-01],
                        [ -1.63635254e-01,  -1.63635254e-01],
                        [ -1.93817139e-01,  -1.93817139e-01],
                        [ -1.93817139e-01,  -1.93817139e-01],
                        [ -1.67510986e-01,  -1.67510986e-01],
                        [ -1.31134033e-01,  -1.31134033e-01],
                        [ -9.96704102e-02,  -9.96704102e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  9.07287598e-02,   9.07287598e-02],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.46026611e-01,   1.46026611e-01],
                        [  1.43707275e-01,   1.43707275e-01],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  2.49938965e-02,   2.49938965e-02],
                        [ -8.34960938e-02,  -8.34960938e-02],
                        [ -1.87225342e-01,  -1.87225342e-01],
                        [ -2.50823975e-01,  -2.50823975e-01],
                        [ -2.55950928e-01,  -2.55950928e-01],
                        [ -2.12097168e-01,  -2.12097168e-01],
                        [ -1.50360107e-01,  -1.50360107e-01],
                        [ -1.01837158e-01,  -1.01837158e-01],
                        [ -7.55920410e-02,  -7.55920410e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  6.69860840e-02,   6.69860840e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  1.17858887e-01,   1.17858887e-01],
                        [  1.25457764e-01,   1.25457764e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  1.05255127e-01,   1.05255127e-01],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  1.20819092e-01,   1.20819092e-01],
                        [  1.54449463e-01,   1.54449463e-01],
                        [  1.74133301e-01,   1.74133301e-01],
                        [  1.71691895e-01,   1.71691895e-01],
                        [  1.50695801e-01,   1.50695801e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.07543945e-01,   1.07543945e-01],
                        [  9.66796875e-02,   9.66796875e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  4.42504883e-03,   4.42504883e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  5.88073730e-02,   5.88073730e-02],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -1.02050781e-01,  -1.02050781e-01],
                        [ -1.73950195e-01,  -1.73950195e-01],
                        [ -2.21191406e-01,  -2.21191406e-01],
                        [ -2.27355957e-01,  -2.27355957e-01],
                        [ -1.93511963e-01,  -1.93511963e-01],
                        [ -1.40411377e-01,  -1.40411377e-01],
                        [ -9.35668945e-02,  -9.35668945e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.38366699e-01,   1.38366699e-01],
                        [  1.10839844e-01,   1.10839844e-01],
                        [  4.58984375e-02,   4.58984375e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -1.51885986e-01,  -1.51885986e-01],
                        [ -2.26531982e-01,  -2.26531982e-01],
                        [ -2.47772217e-01,  -2.47772217e-01],
                        [ -2.17559814e-01,  -2.17559814e-01],
                        [ -1.62506104e-01,  -1.62506104e-01],
                        [ -1.13067627e-01,  -1.13067627e-01],
                        [ -8.32214355e-02,  -8.32214355e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  7.96508789e-02,   7.96508789e-02],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.55517578e-01,   1.55517578e-01],
                        [  1.44378662e-01,   1.44378662e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  9.06372070e-02,   9.06372070e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.76055908e-01,   1.76055908e-01],
                        [  1.90093994e-01,   1.90093994e-01],
                        [  1.75659180e-01,   1.75659180e-01],
                        [  1.46911621e-01,   1.46911621e-01],
                        [  1.20300293e-01,   1.20300293e-01],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -7.90100098e-02,  -7.90100098e-02],
                        [ -8.00476074e-02,  -8.00476074e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -7.16857910e-02,  -7.16857910e-02],
                        [ -1.39678955e-01,  -1.39678955e-01],
                        [ -1.95465088e-01,  -1.95465088e-01],
                        [ -2.21618652e-01,  -2.21618652e-01],
                        [ -2.07672119e-01,  -2.07672119e-01],
                        [ -1.65405273e-01,  -1.65405273e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -9.35668945e-02,  -9.35668945e-02],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -6.93664551e-02,  -6.93664551e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.22467041e-01,   1.22467041e-01],
                        [  1.38610840e-01,   1.38610840e-01],
                        [  1.33453369e-01,   1.33453369e-01],
                        [  1.01654053e-01,   1.01654053e-01],
                        [  3.85437012e-02,   3.85437012e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -1.50604248e-01,  -1.50604248e-01],
                        [ -2.23541260e-01,  -2.23541260e-01],
                        [ -2.45269775e-01,  -2.45269775e-01],
                        [ -2.13714600e-01,  -2.13714600e-01],
                        [ -1.53991699e-01,  -1.53991699e-01],
                        [ -1.00158691e-01,  -1.00158691e-01],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  1.25762939e-01,   1.25762939e-01],
                        [  1.47613525e-01,   1.47613525e-01],
                        [  1.52221680e-01,   1.52221680e-01],
                        [  1.39739990e-01,   1.39739990e-01],
                        [  1.19689941e-01,   1.19689941e-01],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  3.50646973e-02,   3.50646973e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.64093018e-01,   1.64093018e-01],
                        [  1.63085938e-01,   1.63085938e-01],
                        [  1.43554688e-01,   1.43554688e-01],
                        [  1.19140625e-01,   1.19140625e-01],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -7.91931152e-02,  -7.91931152e-02],
                        [ -8.89587402e-02,  -8.89587402e-02],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  7.37609863e-02,   7.37609863e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -1.52770996e-01,  -1.52770996e-01],
                        [ -2.24639893e-01,  -2.24639893e-01],
                        [ -2.52716064e-01,  -2.52716064e-01],
                        [ -2.34222412e-01,  -2.34222412e-01],
                        [ -1.85974121e-01,  -1.85974121e-01],
                        [ -1.32263184e-01,  -1.32263184e-01],
                        [ -9.04846191e-02,  -9.04846191e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.54113770e-01,   1.54113770e-01],
                        [  1.62506104e-01,   1.62506104e-01],
                        [  1.33056641e-01,   1.33056641e-01],
                        [  5.72814941e-02,   5.72814941e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -1.53503418e-01,  -1.53503418e-01],
                        [ -2.27447510e-01,  -2.27447510e-01],
                        [ -2.50885010e-01,  -2.50885010e-01],
                        [ -2.21984863e-01,  -2.21984863e-01],
                        [ -1.62658691e-01,  -1.62658691e-01],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  1.19659424e-01,   1.19659424e-01],
                        [  1.43310547e-01,   1.43310547e-01],
                        [  1.48590088e-01,   1.48590088e-01],
                        [  1.38977051e-01,   1.38977051e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  8.41979980e-02,   8.41979980e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  1.36474609e-01,   1.36474609e-01],
                        [  1.59698486e-01,   1.59698486e-01],
                        [  1.57928467e-01,   1.57928467e-01],
                        [  1.37268066e-01,   1.37268066e-01],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  1.00372314e-01,   1.00372314e-01],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -7.20825195e-02,  -7.20825195e-02],
                        [ -7.45239258e-02,  -7.45239258e-02],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -5.84411621e-02,  -5.84411621e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  6.97631836e-02,   6.97631836e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -9.05151367e-02,  -9.05151367e-02],
                        [ -1.72973633e-01,  -1.72973633e-01],
                        [ -2.33001709e-01,  -2.33001709e-01],
                        [ -2.51373291e-01,  -2.51373291e-01],
                        [ -2.24761963e-01,  -2.24761963e-01],
                        [ -1.72180176e-01,  -1.72180176e-01],
                        [ -1.22894287e-01,  -1.22894287e-01],
                        [ -9.18579102e-02,  -9.18579102e-02],
                        [ -7.30590820e-02,  -7.30590820e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  7.67211914e-02,   7.67211914e-02],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  1.38092041e-01,   1.38092041e-01],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  7.41577148e-03,   7.41577148e-03],
                        [ -8.76159668e-02,  -8.76159668e-02],
                        [ -1.78131104e-01,  -1.78131104e-01],
                        [ -2.32940674e-01,  -2.32940674e-01],
                        [ -2.35229492e-01,  -2.35229492e-01],
                        [ -1.94030762e-01,  -1.94030762e-01],
                        [ -1.38763428e-01,  -1.38763428e-01],
                        [ -9.74121094e-02,  -9.74121094e-02],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  1.14410400e-01,   1.14410400e-01],
                        [  1.36840820e-01,   1.36840820e-01],
                        [  1.46057129e-01,   1.46057129e-01],
                        [  1.39038086e-01,   1.39038086e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  9.19189453e-02,   9.19189453e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.46209717e-01,   1.46209717e-01],
                        [  1.69921875e-01,   1.69921875e-01],
                        [  1.68029785e-01,   1.68029785e-01],
                        [  1.44470215e-01,   1.44470215e-01],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  7.58361816e-02,   7.58361816e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -1.18621826e-01,  -1.18621826e-01],
                        [ -1.95037842e-01,  -1.95037842e-01],
                        [ -2.40234375e-01,  -2.40234375e-01],
                        [ -2.38525391e-01,  -2.38525391e-01],
                        [ -1.99493408e-01,  -1.99493408e-01],
                        [ -1.48590088e-01,  -1.48590088e-01],
                        [ -1.06903076e-01,  -1.06903076e-01],
                        [ -8.01696777e-02,  -8.01696777e-02],
                        [ -6.35681152e-02,  -6.35681152e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  1.02203369e-01,   1.02203369e-01],
                        [  1.38885498e-01,   1.38885498e-01],
                        [  1.55700684e-01,   1.55700684e-01],
                        [  1.44592285e-01,   1.44592285e-01],
                        [  9.97314453e-02,   9.97619629e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [ -8.34960938e-02,  -8.34960938e-02],
                        [ -1.78771973e-01,  -1.78771973e-01],
                        [ -2.33123779e-01,  -2.33123779e-01],
                        [ -2.30804443e-01,  -2.30804443e-01],
                        [ -1.83593750e-01,  -1.83593750e-01],
                        [ -1.23046875e-01,  -1.23046875e-01],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.43310547e-01,   1.43310547e-01],
                        [  1.44256592e-01,   1.44256592e-01],
                        [  1.28417969e-01,   1.28417969e-01],
                        [  1.13067627e-01,   1.13067627e-01],
                        [  1.07910156e-01,   1.07910156e-01],
                        [  1.09771729e-01,   1.09771729e-01],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  1.32659912e-01,   1.32659912e-01],
                        [  1.65527344e-01,   1.65527344e-01],
                        [  1.66961670e-01,   1.66961670e-01],
                        [  1.43768311e-01,   1.43768311e-01],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  5.19104004e-02,   5.19104004e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -1.18835449e-01,  -1.18835449e-01],
                        [ -1.81732178e-01,  -1.81732178e-01],
                        [ -2.16796875e-01,  -2.16796875e-01],
                        [ -2.13104248e-01,  -2.13104248e-01],
                        [ -1.77337646e-01,  -1.77337646e-01],
                        [ -1.32080078e-01,  -1.32080078e-01],
                        [ -9.95483398e-02,  -9.95483398e-02],
                        [ -8.52661133e-02,  -8.52661133e-02],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -7.05261230e-02,  -7.05261230e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -4.35180664e-02,  -4.34875488e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  1.29638672e-01,   1.29638672e-01],
                        [  1.43035889e-01,   1.43035889e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.02996826e-01,   1.02996826e-01],
                        [  4.09240723e-02,   4.09240723e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -1.34979248e-01,  -1.34979248e-01],
                        [ -2.01171875e-01,  -2.01171875e-01],
                        [ -2.20397949e-01,  -2.20397949e-01],
                        [ -1.91314697e-01,  -1.91314697e-01],
                        [ -1.36749268e-01,  -1.36749268e-01],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -6.25000000e-02,  -6.25000000e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  1.13616943e-01,   1.13616943e-01],
                        [  1.38519287e-01,   1.38519287e-01],
                        [  1.44927979e-01,   1.44927979e-01],
                        [  1.39434814e-01,   1.39434814e-01],
                        [  1.32446289e-01,   1.32446289e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  1.18316650e-01,   1.18316650e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  5.10253906e-02,   5.09948730e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  5.29785156e-02,   5.29785156e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  1.56311035e-01,   1.56311035e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  4.75769043e-02,   4.75769043e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  3.28979492e-02,   3.28979492e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -1.49841309e-02,  -1.50146484e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -7.16857910e-02,  -7.17163086e-02],
                        [ -7.42187500e-02,  -7.42187500e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -7.29675293e-02,  -7.29675293e-02],
                        [ -7.63244629e-02,  -7.63244629e-02],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -7.66906738e-02,  -7.66906738e-02],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [ -5.00488281e-03,  -5.03540039e-03],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -1.15692139e-01,  -1.15692139e-01],
                        [ -1.77246094e-01,  -1.77246094e-01],
                        [ -2.15942383e-01,  -2.15942383e-01],
                        [ -2.16979980e-01,  -2.16979980e-01],
                        [ -1.81610107e-01,  -1.81610107e-01],
                        [ -1.28662109e-01,  -1.28662109e-01],
                        [ -8.57849121e-02,  -8.57849121e-02],
                        [ -6.93359375e-02,  -6.93359375e-02],
                        [ -7.11364746e-02,  -7.11364746e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -3.30810547e-02,  -3.30810547e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  1.15539551e-01,   1.15539551e-01],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.31317139e-01,   1.31317139e-01],
                        [  1.01837158e-01,   1.01837158e-01],
                        [  4.37316895e-02,   4.37316895e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -1.26525879e-01,  -1.26525879e-01],
                        [ -1.95526123e-01,  -1.95526123e-01],
                        [ -2.19848633e-01,  -2.19848633e-01],
                        [ -1.95617676e-01,  -1.95617676e-01],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -9.62524414e-02,  -9.62524414e-02],
                        [ -7.07092285e-02,  -7.07397461e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -3.45764160e-02,  -3.46069336e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  5.24902344e-03,   5.21850586e-03],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  1.41113281e-01,   1.41113281e-01],
                        [  1.57958984e-01,   1.57958984e-01],
                        [  1.54602051e-01,   1.54632568e-01],
                        [  1.40197754e-01,   1.40228271e-01],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.06445312e-01,   1.06445312e-01],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  8.92639160e-02,   8.92639160e-02],
                        [  8.39843750e-02,   8.39843750e-02],
                        [  7.58666992e-02,   7.58666992e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.34887695e-01,   1.34887695e-01],
                        [  1.36474609e-01,   1.36474609e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  9.24377441e-02,   9.24377441e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  6.24084473e-02,   6.23779297e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.39465332e-02,  -1.39770508e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -7.32421875e-02,  -7.32727051e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -1.17126465e-01,  -1.17126465e-01],
                        [ -1.84631348e-01,  -1.84631348e-01],
                        [ -2.27813721e-01,  -2.27813721e-01],
                        [ -2.30407715e-01,  -2.30407715e-01],
                        [ -1.95495605e-01,  -1.95495605e-01],
                        [ -1.43890381e-01,  -1.43890381e-01],
                        [ -9.99450684e-02,  -9.99450684e-02],
                        [ -7.58972168e-02,  -7.58972168e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -5.00488281e-02,  -5.00183105e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  6.15539551e-02,   6.15539551e-02],
                        [ -1.30920410e-02,  -1.30615234e-02],
                        [ -9.82055664e-02,  -9.82055664e-02],
                        [ -1.72119141e-01,  -1.72119141e-01],
                        [ -2.11944580e-01,  -2.11944580e-01],
                        [ -2.05718994e-01,  -2.05718994e-01],
                        [ -1.63757324e-01,  -1.63757324e-01],
                        [ -1.13067627e-01,  -1.13067627e-01],
                        [ -7.65380859e-02,  -7.65380859e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  7.04040527e-02,   7.04040527e-02],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.50817871e-01,   1.50817871e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.37542725e-01,   1.37542725e-01],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  9.39331055e-02,   9.39331055e-02],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  7.64465332e-02,   7.64465332e-02],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.40777588e-01,   1.40777588e-01],
                        [  1.31774902e-01,   1.31774902e-01],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -1.30065918e-01,  -1.30065918e-01],
                        [ -1.95251465e-01,  -1.95251465e-01],
                        [ -2.32971191e-01,  -2.32971191e-01],
                        [ -2.28332520e-01,  -2.28332520e-01],
                        [ -1.87622070e-01,  -1.87622070e-01],
                        [ -1.36169434e-01,  -1.36169434e-01],
                        [ -9.95483398e-02,  -9.95483398e-02],
                        [ -8.44726562e-02,  -8.44726562e-02],
                        [ -7.83081055e-02,  -7.83081055e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  1.32019043e-01,   1.32019043e-01],
                        [  1.53839111e-01,   1.53839111e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.30767822e-01,   1.30737305e-01],
                        [  6.77795410e-02,   6.77795410e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.21154785e-01,  -1.21154785e-01],
                        [ -1.99890137e-01,  -1.99890137e-01],
                        [ -2.35412598e-01,  -2.35412598e-01],
                        [ -2.17773438e-01,  -2.17773438e-01],
                        [ -1.63909912e-01,  -1.63909912e-01],
                        [ -1.08886719e-01,  -1.08886719e-01],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.68151855e-02,   1.67846680e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  4.37011719e-02,   4.37011719e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  1.59729004e-01,   1.59729004e-01],
                        [  1.69860840e-01,   1.69860840e-01],
                        [  1.67755127e-01,   1.67755127e-01],
                        [  1.57287598e-01,   1.57287598e-01],
                        [  1.40747070e-01,   1.40747070e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  9.77478027e-02,   9.77478027e-02],
                        [  8.45031738e-02,   8.45031738e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  3.06396484e-02,   3.06701660e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.68151855e-02,  -1.67846680e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  3.50646973e-02,   3.50646973e-02],
                        [  7.47985840e-02,   7.47985840e-02],
                        [  1.16088867e-01,   1.16088867e-01],
                        [  1.47460938e-01,   1.47460938e-01],
                        [  1.56860352e-01,   1.56860352e-01],
                        [  1.42578125e-01,   1.42578125e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  1.42822266e-02,   1.42517090e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -7.41577148e-02,  -7.41577148e-02],
                        [ -7.42187500e-02,  -7.42187500e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.69970703e-03,   4.69970703e-03],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -1.39953613e-01,  -1.39953613e-01],
                        [ -2.11364746e-01,  -2.11364746e-01],
                        [ -2.53662109e-01,  -2.53662109e-01],
                        [ -2.52227783e-01,  -2.52227783e-01],
                        [ -2.12585449e-01,  -2.12585449e-01],
                        [ -1.59637451e-01,  -1.59637451e-01],
                        [ -1.17980957e-01,  -1.17980957e-01],
                        [ -9.31091309e-02,  -9.31091309e-02],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  1.02050781e-01,   1.02050781e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.39099121e-01,   1.39099121e-01],
                        [  1.26739502e-01,   1.26739502e-01],
                        [  7.76672363e-02,   7.76672363e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -1.19140625e-01,  -1.19140625e-01],
                        [ -2.10388184e-01,  -2.10388184e-01],
                        [ -2.51708984e-01,  -2.51739502e-01],
                        [ -2.32940674e-01,  -2.32940674e-01],
                        [ -1.70104980e-01,  -1.70104980e-01],
                        [ -9.80834961e-02,  -9.80834961e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  7.30590820e-02,   7.30590820e-02],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  1.41906738e-01,   1.41906738e-01],
                        [  1.62689209e-01,   1.62689209e-01],
                        [  1.64245605e-01,   1.64245605e-01],
                        [  1.51672363e-01,   1.51672363e-01],
                        [  1.36535645e-01,   1.36566162e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  9.86328125e-02,   9.86022949e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  1.48559570e-01,   1.48559570e-01],
                        [  1.80480957e-01,   1.80480957e-01],
                        [  1.77886963e-01,   1.77886963e-01],
                        [  1.48956299e-01,   1.48956299e-01],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  3.05175781e-04,   2.74658203e-04],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -2.38037109e-02,  -2.38342285e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.30603027e-02,  -4.30297852e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -6.53686523e-02,  -6.53686523e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -6.40258789e-02,  -6.39953613e-02],
                        [ -6.36901855e-02,  -6.37207031e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  7.01904297e-03,   7.01904297e-03],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -1.07696533e-01,  -1.07696533e-01],
                        [ -1.75201416e-01,  -1.75201416e-01],
                        [ -2.16522217e-01,  -2.16522217e-01],
                        [ -2.14294434e-01,  -2.14294434e-01],
                        [ -1.79656982e-01,  -1.79656982e-01],
                        [ -1.41174316e-01,  -1.41174316e-01],
                        [ -1.17919922e-01,  -1.17919922e-01],
                        [ -1.08123779e-01,  -1.08123779e-01],
                        [ -1.00250244e-01,  -1.00250244e-01],
                        [ -8.72497559e-02,  -8.72497559e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -5.00488281e-02,  -5.00793457e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  7.89184570e-02,   7.88879395e-02],
                        [  1.12060547e-01,   1.12060547e-01],
                        [  1.34735107e-01,   1.34735107e-01],
                        [  1.43310547e-01,   1.43310547e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [ -8.03222656e-02,  -8.03222656e-02],
                        [ -1.66961670e-01,  -1.66961670e-01],
                        [ -2.15240479e-01,  -2.15270996e-01],
                        [ -2.14172363e-01,  -2.14172363e-01],
                        [ -1.73126221e-01,  -1.73126221e-01],
                        [ -1.18621826e-01,  -1.18621826e-01],
                        [ -7.89184570e-02,  -7.89184570e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  5.79833984e-03,   5.76782227e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  7.96508789e-02,   7.96203613e-02],
                        [  1.16546631e-01,   1.16546631e-01],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.52526855e-01,   1.52526855e-01],
                        [  1.43798828e-01,   1.43798828e-01],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  1.25183105e-01,   1.25152588e-01],
                        [  1.25671387e-01,   1.25671387e-01],
                        [  1.24572754e-01,   1.24572754e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  9.98229980e-02,   9.98229980e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  4.80651855e-02,   4.80346680e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [ -1.12304688e-02,  -1.11999512e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.41571045e-01,   1.41571045e-01],
                        [  1.47888184e-01,   1.47888184e-01],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  7.34252930e-02,   7.34252930e-02],
                        [  6.20117188e-02,   6.20117188e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -2.58483887e-02,  -2.58178711e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -6.06689453e-02,  -6.06689453e-02],
                        [ -6.37207031e-02,  -6.37207031e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  4.17785645e-02,   4.17480469e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  7.06481934e-02,   7.06176758e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -1.30889893e-01,  -1.30889893e-01],
                        [ -2.07427979e-01,  -2.07427979e-01],
                        [ -2.50152588e-01,  -2.50152588e-01],
                        [ -2.46795654e-01,  -2.46795654e-01],
                        [ -2.08526611e-01,  -2.08526611e-01],
                        [ -1.59729004e-01,  -1.59729004e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -1.00189209e-01,  -1.00189209e-01],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -7.42492676e-02,  -7.42187500e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.36779785e-01,   1.36779785e-01],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  9.45434570e-02,   9.45434570e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -1.64733887e-01,  -1.64703369e-01],
                        [ -2.15270996e-01,  -2.15240479e-01],
                        [ -2.16796875e-01,  -2.16796875e-01],
                        [ -1.78436279e-01,  -1.78466797e-01],
                        [ -1.22619629e-01,  -1.22650146e-01],
                        [ -7.44323730e-02,  -7.44628906e-02],
                        [ -4.58984375e-02,  -4.59289551e-02],
                        [ -3.01513672e-02,  -3.01208496e-02],
                        [ -1.66320801e-02,  -1.66015625e-02],
                        [ -5.34057617e-03,  -5.31005859e-03],
                        [ -6.71386719e-04,  -6.40869141e-04],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  2.18811035e-02,   2.18505859e-02],
                        [  4.68139648e-02,   4.67529297e-02],
                        [  6.00585938e-02,   6.00280762e-02],
                        [  5.15136719e-02,   5.14831543e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  6.43920898e-03,   6.46972656e-03],
                        [ -7.78198242e-03,  -7.75146484e-03],
                        [ -1.20849609e-02,  -1.20544434e-02],
                        [ -1.19018555e-03,  -1.15966797e-03],
                        [  2.98156738e-02,   2.98461914e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  1.25488281e-01,   1.25457764e-01],
                        [  1.63940430e-01,   1.63879395e-01],
                        [  1.81945801e-01,   1.81884766e-01],
                        [  1.78100586e-01,   1.78070068e-01],
                        [  1.60552979e-01,   1.60522461e-01],
                        [  1.42120361e-01,   1.42150879e-01],
                        [  1.30554199e-01,   1.30615234e-01],
                        [  1.22131348e-01,   1.22192383e-01],
                        [  1.09130859e-01,   1.09191895e-01],
                        [  9.32312012e-02,   9.32617188e-02],
                        [  8.32824707e-02,   8.33129883e-02],
                        [  8.05358887e-02,   8.05053711e-02],
                        [  7.48596191e-02,   7.47985840e-02],
                        [  5.80444336e-02,   5.79528809e-02],
                        [  3.35083008e-02,   3.34167480e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -1.01318359e-02,  -1.00708008e-02],
                        [ -2.32238770e-02,  -2.30712891e-02],
                        [ -2.53295898e-02,  -2.52075195e-02],
                        [ -1.23901367e-02,  -1.22985840e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  6.29577637e-02,   6.28662109e-02],
                        [  1.11267090e-01,   1.11114502e-01],
                        [  1.43707275e-01,   1.43585205e-01],
                        [  1.47888184e-01,   1.47827148e-01],
                        [  1.27593994e-01,   1.27624512e-01],
                        [  9.79919434e-02,   9.81140137e-02],
                        [  7.11669922e-02,   7.12890625e-02],
                        [  4.82788086e-02,   4.83703613e-02],
                        [  2.72827148e-02,   2.73132324e-02],
                        [  1.20849609e-02,   1.20239258e-02],
                        [  7.90405273e-03,   7.84301758e-03],
                        [  1.26647949e-02,   1.26037598e-02],
                        [  1.91955566e-02,   1.91345215e-02],
                        [  2.31018066e-02,   2.30407715e-02],
                        [  2.15759277e-02,   2.15148926e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [ -6.98852539e-03,  -6.95800781e-03],
                        [ -2.23999023e-02,  -2.23083496e-02],
                        [ -2.77709961e-02,  -2.76489258e-02],
                        [ -2.41088867e-02,  -2.40173340e-02],
                        [ -1.75781250e-02,  -1.75170898e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -1.56860352e-02,  -1.57470703e-02],
                        [ -1.84631348e-02,  -1.86462402e-02],
                        [ -2.05078125e-02,  -2.07519531e-02],
                        [ -2.47192383e-02,  -2.48718262e-02],
                        [ -3.43933105e-02,  -3.43322754e-02],
                        [ -4.80651855e-02,  -4.78210449e-02],
                        [ -5.99060059e-02,  -5.96008301e-02],
                        [ -6.46972656e-02,  -6.45141602e-02],
                        [ -6.28662109e-02,  -6.28356934e-02],
                        [ -5.98754883e-02,  -5.99975586e-02],
                        [ -5.99060059e-02,  -6.00891113e-02],
                        [ -6.08215332e-02,  -6.10046387e-02],
                        [ -5.82580566e-02,  -5.83801270e-02],
                        [ -5.23986816e-02,  -5.24291992e-02],
                        [ -4.71191406e-02,  -4.70886230e-02],
                        [ -4.39758301e-02,  -4.38842773e-02],
                        [ -4.01916504e-02,  -4.00390625e-02],
                        [ -3.16467285e-02,  -3.14636230e-02],
                        [ -1.74560547e-02,  -1.73034668e-02],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  1.43432617e-02,   1.42517090e-02],
                        [  2.83508301e-02,   2.81677246e-02],
                        [  4.14123535e-02,   4.12292480e-02],
                        [  5.13305664e-02,   5.11474609e-02],
                        [  5.24597168e-02,   5.23071289e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [ -5.76782227e-03,  -5.55419922e-03],
                        [ -7.10754395e-02,  -7.07092285e-02],
                        [ -1.44744873e-01,  -1.44378662e-01],
                        [ -2.04254150e-01,  -2.04101562e-01],
                        [ -2.30316162e-01,  -2.30438232e-01],
                        [ -2.16888428e-01,  -2.17224121e-01],
                        [ -1.77490234e-01,  -1.77825928e-01],
                        [ -1.36718750e-01,  -1.36901855e-01],
                        [ -1.10626221e-01,  -1.10626221e-01],
                        [ -9.75646973e-02,  -9.75036621e-02],
                        [ -8.68225098e-02,  -8.67004395e-02],
                        [ -7.05566406e-02,  -7.04345703e-02],
                        [ -4.94995117e-02,  -4.93469238e-02],
                        [ -2.94189453e-02,  -2.92358398e-02],
                        [ -1.35498047e-02,  -1.33666992e-02],
                        [  1.31225586e-03,   1.37329102e-03],
                        [  2.01721191e-02,   2.00805664e-02],
                        [  4.44030762e-02,   4.41589355e-02],
                        [  7.16857910e-02,   7.13500977e-02],
                        [  9.90905762e-02,   9.87548828e-02],
                        [  1.22772217e-01,   1.22558594e-01],
                        [  1.35833740e-01,   1.35864258e-01],
                        [  1.27227783e-01,   1.27532959e-01],
                        [  8.34655762e-02,   8.39843750e-02],
                        [ -8.23974609e-04,  -3.35693359e-04],
                        [ -1.07482910e-01,  -1.07208252e-01],
                        [ -1.97021484e-01,  -1.97082520e-01],
                        [ -2.34527588e-01,  -2.34893799e-01],
                        [ -2.12738037e-01,  -2.13226318e-01],
                        [ -1.53442383e-01,  -1.53930664e-01],
                        [ -9.05761719e-02,  -9.09118652e-02],
                        [ -4.88281250e-02,  -4.88891602e-02],
                        [ -3.26843262e-02,  -3.24707031e-02],
                        [ -3.01818848e-02,  -2.96936035e-02],
                        [ -2.60009766e-02,  -2.54516602e-02],
                        [ -1.49841309e-02,  -1.45568848e-02],
                        [ -3.90625000e-03,  -3.75366211e-03],
                        [  6.40869141e-04,   5.18798828e-04],
                        [  2.68554688e-03,   2.31933594e-03],
                        [  1.05895996e-02,   1.01013184e-02],
                        [  2.45971680e-02,   2.40783691e-02],
                        [  3.74450684e-02,   3.71093750e-02],
                        [  4.51049805e-02,   4.51354980e-02],
                        [  4.74853516e-02,   4.78515625e-02],
                        [  4.25415039e-02,   4.31213379e-02],
                        [  2.94189453e-02,   2.99072266e-02],
                        [  1.37939453e-02,   1.40075684e-02],
                        [  4.24194336e-03,   4.08935547e-03],
                        [  5.88989258e-03,   5.52368164e-03],
                        [  1.94396973e-02,   1.91040039e-02],
                        [  4.42810059e-02,   4.41589355e-02],
                        [  7.99560547e-02,   8.00170898e-02],
                        [  1.21185303e-01,   1.21246338e-01],
                        [  1.54083252e-01,   1.54022217e-01],
                        [  1.65679932e-01,   1.65527344e-01],
                        [  1.58142090e-01,   1.58050537e-01],
                        [  1.46636963e-01,   1.46820068e-01],
                        [  1.41418457e-01,   1.41876221e-01],
                        [  1.39068604e-01,   1.39587402e-01],
                        [  1.32202148e-01,   1.32415771e-01],
                        [  1.19598389e-01,   1.19323730e-01],
                        [  1.03546143e-01,   1.02874756e-01],
                        [  8.52355957e-02,   8.45031738e-02],
                        [  6.53686523e-02,   6.49108887e-02],
                        [  4.49218750e-02,   4.49829102e-02],
                        [  2.40783691e-02,   2.46887207e-02],
                        [  2.04467773e-03,   2.96020508e-03],
                        [ -1.99584961e-02,  -1.91345215e-02],
                        [ -3.60717773e-02,  -3.57971191e-02],
                        [ -3.90625000e-02,  -3.95507812e-02],
                        [ -2.46582031e-02,  -2.56652832e-02],
                        [  7.69042969e-03,   6.74438477e-03],
                        [  5.23681641e-02,   5.19409180e-02],
                        [  9.57336426e-02,   9.60083008e-02],
                        [  1.23352051e-01,   1.24023438e-01],
                        [  1.29425049e-01,   1.30065918e-01],
                        [  1.18133545e-01,   1.18469238e-01],
                        [  9.81445312e-02,   9.82055664e-02],
                        [  7.70568848e-02,   7.69958496e-02],
                        [  5.80749512e-02,   5.80139160e-02],
                        [  4.04663086e-02,   4.04052734e-02],
                        [  2.37731934e-02,   2.35900879e-02],
                        [  1.02844238e-02,   9.88769531e-03],
                        [  2.38037109e-03,   1.92260742e-03],
                        [ -1.83105469e-04,  -4.88281250e-04],
                        [  1.03759766e-03,   1.12915039e-03],
                        [  3.72314453e-03,   4.24194336e-03],
                        [  5.12695312e-03,   5.82885742e-03],
                        [  4.18090820e-03,   4.73022461e-03],
                        [  1.00708008e-03,   1.06811523e-03],
                        [ -6.07299805e-03,  -6.56127930e-03],
                        [ -1.83715820e-02,  -1.91040039e-02],
                        [ -3.27758789e-02,  -3.32946777e-02],
                        [ -4.26940918e-02,  -4.27551270e-02],
                        [ -4.38232422e-02,  -4.35180664e-02],
                        [ -3.84216309e-02,  -3.80554199e-02],
                        [ -3.28979492e-02,  -3.27453613e-02],
                        [ -3.16772461e-02,  -3.17077637e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -4.19921875e-02,  -4.18395996e-02],
                        [ -4.91943359e-02,  -4.89196777e-02],
                        [ -5.25817871e-02,  -5.24597168e-02],
                        [ -5.16052246e-02,  -5.17578125e-02],
                        [ -5.08117676e-02,  -5.13000488e-02],
                        [ -5.34057617e-02,  -5.40771484e-02],
                        [ -5.66406250e-02,  -5.72509766e-02],
                        [ -5.77392578e-02,  -5.79223633e-02],
                        [ -5.85937500e-02,  -5.80749512e-02],
                        [ -6.09130859e-02,  -5.97839355e-02],
                        [ -6.24389648e-02,  -6.11572266e-02],
                        [ -5.99365234e-02,  -5.91735840e-02],
                        [ -5.14831543e-02,  -5.17578125e-02],
                        [ -3.57055664e-02,  -3.69873047e-02],
                        [ -1.24816895e-02,  -1.41296387e-02],
                        [  1.52893066e-02,   1.42211914e-02],
                        [  4.13208008e-02,   4.13818359e-02],
                        [  5.90515137e-02,   6.00280762e-02],
                        [  6.57043457e-02,   6.68945312e-02],
                        [  6.02416992e-02,   6.10046387e-02],
                        [  3.68041992e-02,   3.69567871e-02],
                        [ -1.19018555e-02,  -1.21154785e-02],
                        [ -8.21533203e-02,  -8.24584961e-02],
                        [ -1.55639648e-01,  -1.55914307e-01],
                        [ -2.09594727e-01,  -2.09808350e-01],
                        [ -2.27508545e-01,  -2.27722168e-01],
                        [ -2.07641602e-01,  -2.07855225e-01],
                        [ -1.67236328e-01,  -1.67419434e-01],
                        [ -1.31378174e-01,  -1.31408691e-01],
                        [ -1.11785889e-01,  -1.11663818e-01],
                        [ -1.00891113e-01,  -1.00646973e-01],
                        [ -8.68835449e-02,  -8.65173340e-02],
                        [ -6.77185059e-02,  -6.73217773e-02],
                        [ -4.91943359e-02,  -4.89501953e-02],
                        [ -3.53088379e-02,  -3.54003906e-02],
                        [ -2.50549316e-02,  -2.54821777e-02],
                        [ -1.45874023e-02,  -1.51367188e-02],
                        [  8.85009766e-04,   5.79833984e-04],
                        [  2.49328613e-02,   2.50244141e-02],
                        [  5.73730469e-02,   5.77087402e-02],
                        [  9.39941406e-02,   9.42687988e-02],
                        [  1.26403809e-01,   1.26403809e-01],
                        [  1.44042969e-01,   1.43859863e-01],
                        [  1.37573242e-01,   1.37451172e-01],
                        [  9.82666016e-02,   9.83581543e-02],
                        [  2.13928223e-02,   2.16369629e-02],
                        [ -8.17871094e-02,  -8.15734863e-02],
                        [ -1.78680420e-01,  -1.78619385e-01],
                        [ -2.31018066e-01,  -2.31170654e-01],
                        [ -2.22351074e-01,  -2.22656250e-01],
                        [ -1.71600342e-01,  -1.71936035e-01],
                        [ -1.14044189e-01,  -1.14227295e-01],
                        [ -7.14721680e-02,  -7.13500977e-02],
                        [ -4.49523926e-02,  -4.44946289e-02],
                        [ -2.67333984e-02,  -2.61535645e-02],
                        [ -1.04064941e-02,  -1.01623535e-02],
                        [  3.47900391e-03,   3.11279297e-03],
                        [  9.06372070e-03,   8.17871094e-03],
                        [  5.55419922e-03,   4.76074219e-03],
                        [  3.60107422e-03,   3.54003906e-03],
                        [  1.41296387e-02,   1.50146484e-02],
                        [  3.31726074e-02,   3.44238281e-02],
                        [  4.66308594e-02,   4.74548340e-02],
                        [  4.85534668e-02,   4.84619141e-02],
                        [  4.40368652e-02,   4.30908203e-02],
                        [  3.71704102e-02,   3.59191895e-02],
                        [  2.73742676e-02,   2.64892578e-02],
                        [  1.47399902e-02,   1.44348145e-02],
                        [  2.34985352e-03,   2.68554688e-03],
                        [ -2.59399414e-03,  -1.73950195e-03],
                        [  8.33129883e-03,   9.39941406e-03],
                        [  3.73535156e-02,   3.82995605e-02],
                        [  7.75756836e-02,   7.79724121e-02],
                        [  1.17401123e-01,   1.16943359e-01],
                        [  1.45629883e-01,   1.44561768e-01],
                        [  1.56768799e-01,   1.55670166e-01],
                        [  1.54663086e-01,   1.54144287e-01],
                        [  1.49658203e-01,   1.49902344e-01],
                        [  1.49261475e-01,   1.49932861e-01],
                        [  1.51916504e-01,   1.52374268e-01],
                        [  1.49871826e-01,   1.49902344e-01],
                        [  1.37908936e-01,   1.37664795e-01],
                        [  1.17767334e-01,   1.17736816e-01],
                        [  9.52453613e-02,   9.56726074e-02],
                        [  7.46154785e-02,   7.52258301e-02],
                        [  5.63049316e-02,   5.65490723e-02],
                        [  3.77502441e-02,   3.74145508e-02],
                        [  1.62353516e-02,   1.55334473e-02],
                        [ -7.47680664e-03,  -8.08715820e-03],
                        [ -2.82287598e-02,  -2.85644531e-02],
                        [ -4.00695801e-02,  -4.02526855e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -2.34375000e-02,  -2.30102539e-02],
                        [  1.13220215e-02,   1.23596191e-02],
                        [  6.20422363e-02,   6.33239746e-02],
                        [  1.13250732e-01,   1.13922119e-01],
                        [  1.44012451e-01,   1.43402100e-01],
                        [  1.44042969e-01,   1.42333984e-01],
                        [  1.19720459e-01,   1.17950439e-01],
                        [  8.63037109e-02,   8.55712891e-02],
                        [  5.74035645e-02,   5.79833984e-02],
                        [  3.94897461e-02,   4.08020020e-02],
                        [  3.25927734e-02,   3.38134766e-02],
                        [  3.32336426e-02,   3.39355469e-02],
                        [  3.65905762e-02,   3.68652344e-02],
                        [  3.87878418e-02,   3.87573242e-02],
                        [  3.71398926e-02,   3.68041992e-02],
                        [  2.86560059e-02,   2.79541016e-02],
                        [  1.16882324e-02,   1.07421875e-02],
                        [ -1.10778809e-02,  -1.19323730e-02],
                        [ -3.40270996e-02,  -3.44543457e-02],
                        [ -5.13305664e-02,  -5.12390137e-02],
                        [ -5.91125488e-02,  -5.85937500e-02],
                        [ -5.78613281e-02,  -5.70373535e-02],
                        [ -5.02014160e-02,  -4.91943359e-02],
                        [ -3.75671387e-02,  -3.66821289e-02],
                        [ -2.39562988e-02,  -2.35290527e-02],
                        [ -1.76391602e-02,  -1.79443359e-02],
                        [ -2.27661133e-02,  -2.36816406e-02],
                        [ -3.26843262e-02,  -3.37524414e-02],
                        [ -3.86047363e-02,  -3.93981934e-02],
                        [ -4.09851074e-02,  -4.12902832e-02],
                        [ -4.48303223e-02,  -4.47387695e-02],
                        [ -4.87060547e-02,  -4.83703613e-02],
                        [ -4.85839844e-02,  -4.81872559e-02],
                        [ -4.70275879e-02,  -4.65698242e-02],
                        [ -4.89807129e-02,  -4.84008789e-02],
                        [ -5.37109375e-02,  -5.30700684e-02],
                        [ -5.69458008e-02,  -5.65185547e-02],
                        [ -5.73120117e-02,  -5.74035645e-02],
                        [ -5.63049316e-02,  -5.70068359e-02],
                        [ -5.46569824e-02,  -5.56945801e-02],
                        [ -5.12695312e-02,  -5.22766113e-02],
                        [ -4.40368652e-02,  -4.45861816e-02],
                        [ -2.85339355e-02,  -2.83508301e-02],
                        [ -7.62939453e-04,   1.22070312e-04],
                        [  3.52478027e-02,   3.65905762e-02],
                        [  6.70166016e-02,   6.81457520e-02],
                        [  8.27941895e-02,   8.30993652e-02],
                        [  7.68127441e-02,   7.60803223e-02],
                        [  4.39758301e-02,   4.26330566e-02],
                        [ -2.01110840e-02,  -2.13623047e-02],
                        [ -1.06414795e-01,  -1.06994629e-01],
                        [ -1.87683105e-01,  -1.87438965e-01],
                        [ -2.35321045e-01,  -2.34466553e-01],
                        [ -2.38861084e-01,  -2.37670898e-01],
                        [ -2.08892822e-01,  -2.07824707e-01],
                        [ -1.67541504e-01,  -1.66961670e-01],
                        [ -1.33880615e-01,  -1.34063721e-01],
                        [ -1.13037109e-01,  -1.14013672e-01],
                        [ -9.73205566e-02,  -9.87243652e-02],
                        [ -7.87963867e-02,  -8.00476074e-02],
                        [ -5.94177246e-02,  -6.00280762e-02],
                        [ -4.60815430e-02,  -4.57763672e-02],
                        [ -3.84826660e-02,  -3.75061035e-02],
                        [ -2.90527344e-02,  -2.77709961e-02],
                        [ -1.19934082e-02,  -1.07421875e-02],
                        [  1.43432617e-02,   1.51367188e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  8.70361328e-02,   8.61206055e-02],
                        [  1.19537354e-01,   1.18133545e-01],
                        [  1.40441895e-01,   1.39190674e-01],
                        [  1.46850586e-01,   1.46301270e-01],
                        [  1.33056641e-01,   1.33209229e-01],
                        [  8.85620117e-02,   8.90197754e-02],
                        [  8.85009766e-03,   9.21630859e-03],
                        [ -9.06982422e-02,  -9.03625488e-02],
                        [ -1.77062988e-01,  -1.76361084e-01],
                        [ -2.19543457e-01,  -2.18353271e-01],
                        [ -2.09625244e-01,  -2.08465576e-01],
                        [ -1.64642334e-01,  -1.64459229e-01],
                        [ -1.13586426e-01,  -1.14685059e-01],
                        [ -7.65686035e-02,  -7.84912109e-02],
                        [ -5.53588867e-02,  -5.71289062e-02],
                        [ -3.91540527e-02,  -4.01306152e-02],
                        [ -1.89208984e-02,  -1.89514160e-02],
                        [  2.68554688e-03,   3.47900391e-03],
                        [  1.60827637e-02,   1.75781250e-02],
                        [  1.85852051e-02,   2.05078125e-02],
                        [  1.85546875e-02,   2.03247070e-02],
                        [  2.40783691e-02,   2.49938965e-02],
                        [  3.28674316e-02,   3.23486328e-02],
                        [  3.69567871e-02,   3.50646973e-02],
                        [  3.32641602e-02,   3.08837891e-02],
                        [  2.52380371e-02,   2.34985352e-02],
                        [  1.66625977e-02,   1.61743164e-02],
                        [  7.69042969e-03,   8.27026367e-03],
                        [ -2.07519531e-03,  -1.03759766e-03],
                        [ -9.18579102e-03,  -8.02612305e-03],
                        [ -6.77490234e-03,  -5.49316406e-03],
                        [  1.07727051e-02,   1.21459961e-02],
                        [  4.47692871e-02,   4.57153320e-02],
                        [  9.04846191e-02,   9.03320312e-02],
                        [  1.37298584e-01,   1.35772705e-01],
                        [  1.72210693e-01,   1.69952393e-01],
                        [  1.86096191e-01,   1.84204102e-01],
                        [  1.78985596e-01,   1.78436279e-01],
                        [  1.61071777e-01,   1.62170410e-01],
                        [  1.45141602e-01,   1.47125244e-01],
                        [  1.35559082e-01,   1.37207031e-01],
                        [  1.27105713e-01,   1.27502441e-01],
                        [  1.13983154e-01,   1.13250732e-01],
                        [  9.67712402e-02,   9.57946777e-02],
                        [  8.03222656e-02,   7.98339844e-02],
                        [  6.75659180e-02,   6.75964355e-02],
                        [  5.63659668e-02,   5.64880371e-02],
                        [  4.06799316e-02,   4.05883789e-02],
                        [  1.66320801e-02,   1.65100098e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -3.12500000e-02,  -3.11889648e-02],
                        [ -4.06494141e-02,  -4.06799316e-02],
                        [ -3.88793945e-02,  -3.87573242e-02],
                        [ -2.34680176e-02,  -2.27355957e-02],
                        [  8.02612305e-03,   9.24682617e-03],
                        [  5.13305664e-02,   5.20629883e-02],
                        [  9.61914062e-02,   9.52758789e-02],
                        [  1.30554199e-01,   1.28021240e-01],
                        [  1.43676758e-01,   1.41021729e-01],
                        [  1.31744385e-01,   1.30889893e-01],
                        [  1.02996826e-01,   1.04797363e-01],
                        [  7.36694336e-02,   7.71484375e-02],
                        [  5.49011230e-02,   5.79833984e-02],
                        [  4.55932617e-02,   4.65393066e-02],
                        [  3.73229980e-02,   3.57666016e-02],
                        [  2.49633789e-02,   2.20947266e-02],
                        [  1.21459961e-02,   9.73510742e-03],
                        [  4.97436523e-03,   4.11987305e-03],
                        [  2.74658203e-03,   3.41796875e-03],
                        [ -1.09863281e-03,   3.05175781e-04],
                        [ -1.01623535e-02,  -8.94165039e-03],
                        [ -2.14233398e-02,  -2.08129883e-02],
                        [ -2.97851562e-02,  -2.99682617e-02],
                        [ -3.39660645e-02,  -3.47595215e-02],
                        [ -3.56140137e-02,  -3.64685059e-02],
                        [ -3.48205566e-02,  -3.49426270e-02],
                        [ -3.13720703e-02,  -3.04260254e-02],
                        [ -2.92053223e-02,  -2.76794434e-02],
                        [ -3.28063965e-02,  -3.19824219e-02],
                        [ -4.03442383e-02,  -4.11376953e-02],
                        [ -4.43420410e-02,  -4.62951660e-02],
                        [ -4.08935547e-02,  -4.24804688e-02],
                        [ -3.46374512e-02,  -3.46679688e-02],
                        [ -3.25012207e-02,  -3.12194824e-02],
                        [ -3.66210938e-02,  -3.54003906e-02],
                        [ -4.44641113e-02,  -4.43420410e-02],
                        [ -5.20935059e-02,  -5.27038574e-02],
                        [ -5.68847656e-02,  -5.72814941e-02],
                        [ -5.88378906e-02,  -5.85327148e-02],
                        [ -5.71594238e-02,  -5.66406250e-02],
                        [ -5.03845215e-02,  -5.02929688e-02],
                        [ -4.14428711e-02,  -4.18090820e-02],
                        [ -3.58276367e-02,  -3.61022949e-02],
                        [ -3.35083008e-02,  -3.33251953e-02],
                        [ -2.79235840e-02,  -2.75268555e-02],
                        [ -1.30310059e-02,  -1.29394531e-02],
                        [  1.13830566e-02,   1.11083984e-02],
                        [  4.01611328e-02,   3.97644043e-02],
                        [  6.44226074e-02,   6.41784668e-02],
                        [  7.22961426e-02,   7.20214844e-02],
                        [  5.15136719e-02,   5.10864258e-02],
                        [ -3.78417969e-03,  -4.15039062e-03],
                        [ -8.71887207e-02,  -8.70056152e-02],
                        [ -1.78131104e-01,  -1.77124023e-01],
                        [ -2.46582031e-01,  -2.45117188e-01],
                        [ -2.68035889e-01,  -2.66937256e-01],
                        [ -2.39868164e-01,  -2.39807129e-01],
                        [ -1.84478760e-01,  -1.85455322e-01],
                        [ -1.33087158e-01,  -1.34613037e-01],
                        [ -1.02233887e-01,  -1.03576660e-01],
                        [ -8.51440430e-02,  -8.56628418e-02],
                        [ -6.78710938e-02,  -6.74743652e-02],
                        [ -4.83398438e-02,  -4.74853516e-02],
                        [ -3.45458984e-02,  -3.38134766e-02],
                        [ -3.05786133e-02,  -3.03955078e-02],
                        [ -3.10058594e-02,  -3.11584473e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -7.47680664e-03,  -7.04956055e-03],
                        [  2.32238770e-02,   2.38952637e-02],
                        [  5.95703125e-02,   5.99365234e-02],
                        [  9.36584473e-02,   9.33837891e-02],
                        [  1.21307373e-01,   1.20513916e-01],
                        [  1.40258789e-01,   1.39404297e-01],
                        [  1.45477295e-01,   1.44866943e-01],
                        [  1.28448486e-01,   1.28021240e-01],
                        [  8.05969238e-02,   8.02612305e-02],
                        [ -1.25122070e-03,  -1.28173828e-03],
                        [ -1.03912354e-01,  -1.03118896e-01],
                        [ -1.91986084e-01,  -1.90307617e-01],
                        [ -2.27905273e-01,  -2.26104736e-01],
                        [ -2.03979492e-01,  -2.03186035e-01],
                        [ -1.46911621e-01,  -1.47705078e-01],
                        [ -9.05761719e-02,  -9.23767090e-02],
                        [ -5.16662598e-02,  -5.33447266e-02],
                        [ -2.83203125e-02,  -2.91137695e-02],
                        [ -1.24206543e-02,  -1.23901367e-02],
                        [  1.83105469e-04,   5.18798828e-04],
                        [  7.56835938e-03,   7.99560547e-03],
                        [  7.04956055e-03,   7.65991211e-03],
                        [  5.79833984e-04,   1.46484375e-03],
                        [ -4.63867188e-03,  -3.78417969e-03],
                        [ -2.16674805e-03,  -1.89208984e-03],
                        [  7.56835938e-03,   7.17163086e-03],
                        [  1.83105469e-02,   1.76086426e-02],
                        [  2.44445801e-02,   2.39868164e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.82897949e-02,   2.84423828e-02],
                        [  2.77709961e-02,   2.75573730e-02],
                        [  2.12402344e-02,   2.04772949e-02],
                        [  1.37023926e-02,   1.27258301e-02],
                        [  1.61437988e-02,   1.57165527e-02],
                        [  3.34167480e-02,   3.40270996e-02],
                        [  6.30798340e-02,   6.45446777e-02],
                        [  1.01531982e-01,   1.03240967e-01],
                        [  1.43218994e-01,   1.44317627e-01],
                        [  1.76788330e-01,   1.76696777e-01],
                        [  1.90765381e-01,   1.89514160e-01],
                        [  1.83288574e-01,   1.81610107e-01],
                        [  1.62811279e-01,   1.61651611e-01],
                        [  1.39953613e-01,   1.39770508e-01],
                        [  1.20880127e-01,   1.21337891e-01],
                        [  1.06262207e-01,   1.06781006e-01],
                        [  9.40246582e-02,   9.42993164e-02],
                        [  8.43200684e-02,   8.46252441e-02],
                        [  7.95288086e-02,   7.99865723e-02],
                        [  7.84301758e-02,   7.87353516e-02],
                        [  7.47375488e-02,   7.45849609e-02],
                        [  6.14318848e-02,   6.09741211e-02],
                        [  3.69873047e-02,   3.67736816e-02],
                        [  7.84301758e-03,   8.17871094e-03],
                        [ -1.78527832e-02,  -1.74255371e-02],
                        [ -3.71093750e-02,  -3.72314453e-02],
                        [ -4.64477539e-02,  -4.70886230e-02],
                        [ -3.72924805e-02,  -3.76892090e-02],
                        [ -5.12695312e-03,  -4.63867188e-03],
                        [  4.22058105e-02,   4.29687500e-02],
                        [  8.98132324e-02,   8.96301270e-02],
                        [  1.25427246e-01,   1.23901367e-01],
                        [  1.41235352e-01,   1.39617920e-01],
                        [  1.32843018e-01,   1.32873535e-01],
                        [  1.03729248e-01,   1.05773926e-01],
                        [  6.83593750e-02,   7.08618164e-02],
                        [  4.23583984e-02,   4.33654785e-02],
                        [  3.02429199e-02,   2.91748047e-02],
                        [  2.58483887e-02,   2.38647461e-02],
                        [  2.32543945e-02,   2.20031738e-02],
                        [  2.28576660e-02,   2.30407715e-02],
                        [  2.58178711e-02,   2.69470215e-02],
                        [  2.72827148e-02,   2.83203125e-02],
                        [  2.09350586e-02,   2.11791992e-02],
                        [  7.14111328e-03,   6.34765625e-03],
                        [ -1.01928711e-02,  -1.18713379e-02],
                        [ -2.81066895e-02,  -2.99682617e-02],
                        [ -4.13513184e-02,  -4.22363281e-02],
                        [ -4.43115234e-02,  -4.31518555e-02],
                        [ -3.98864746e-02,  -3.65905762e-02],
                        [ -3.70788574e-02,  -3.31726074e-02],
                        [ -3.82080078e-02,  -3.60717773e-02],
                        [ -3.79638672e-02,  -3.92761230e-02],
                        [ -3.50341797e-02,  -3.93371582e-02],
                        [ -3.45458984e-02,  -3.93981934e-02],
                        [ -3.87878418e-02,  -4.13208008e-02],
                        [ -4.34570312e-02,  -4.22363281e-02],
                        [ -4.34570312e-02,  -3.96728516e-02],
                        [ -3.86962891e-02,  -3.50646973e-02],
                        [ -3.37829590e-02,  -3.24707031e-02],
                        [ -3.35998535e-02,  -3.46069336e-02],
                        [ -3.80554199e-02,  -3.98254395e-02],
                        [ -4.25415039e-02,  -4.36096191e-02],
                        [ -4.43115234e-02,  -4.45251465e-02],
                        [ -4.46166992e-02,  -4.45861816e-02],
                        [ -4.39453125e-02,  -4.40368652e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -3.13110352e-02,  -3.10974121e-02],
                        [ -1.74865723e-02,  -1.73339844e-02],
                        [  9.76562500e-04,   7.93457031e-04],
                        [  2.19421387e-02,   2.18505859e-02],
                        [  4.06188965e-02,   4.13513184e-02],
                        [  5.05065918e-02,   5.20019531e-02],
                        [  4.45556641e-02,   4.57153320e-02],
                        [  1.66320801e-02,   1.60522461e-02],
                        [ -3.63464355e-02,  -3.88793945e-02],
                        [ -1.09802246e-01,  -1.12915039e-01],
                        [ -1.85943604e-01,  -1.87652588e-01],
                        [ -2.36877441e-01,  -2.36022949e-01],
                        [ -2.41821289e-01,  -2.38800049e-01],
                        [ -2.06054688e-01,  -2.02423096e-01],
                        [ -1.58050537e-01,  -1.55578613e-01],
                        [ -1.23748779e-01,  -1.23443604e-01],
                        [ -1.06231689e-01,  -1.07788086e-01],
                        [ -9.35058594e-02,  -9.57641602e-02],
                        [ -7.94067383e-02,  -8.15124512e-02],
                        [ -6.83593750e-02,  -7.02514648e-02],
                        [ -6.36291504e-02,  -6.53381348e-02],
                        [ -5.92346191e-02,  -6.02111816e-02],
                        [ -4.52880859e-02,  -4.44641113e-02],
                        [ -1.77307129e-02,  -1.47705078e-02],
                        [  1.85546875e-02,   2.26135254e-02],
                        [  5.55419922e-02,   5.87768555e-02],
                        [  8.80737305e-02,   8.89892578e-02],
                        [  1.14410400e-01,   1.12854004e-01],
                        [  1.34002686e-01,   1.30920410e-01],
                        [  1.45599365e-01,   1.42272949e-01],
                        [  1.43218994e-01,   1.40625000e-01],
                        [  1.13586426e-01,   1.12213135e-01],
                        [  4.58679199e-02,   4.59594727e-02],
                        [ -5.17883301e-02,  -5.00488281e-02],
                        [ -1.50115967e-01,  -1.46972656e-01],
                        [ -2.15026855e-01,  -2.11608887e-01],
                        [ -2.27020264e-01,  -2.25006104e-01],
                        [ -1.90979004e-01,  -1.91345215e-01],
                        [ -1.32934570e-01,  -1.35009766e-01],
                        [ -8.24584961e-02,  -8.46557617e-02],
                        [ -5.24902344e-02,  -5.37719727e-02],
                        [ -3.48815918e-02,  -3.55224609e-02],
                        [ -1.70593262e-02,  -1.77307129e-02],
                        [  1.89208984e-03,   1.03759766e-03],
                        [  1.26342773e-02,   1.23291016e-02],
                        [  9.88769531e-03,   1.09252930e-02],
                        [  1.09863281e-03,   3.44848633e-03],
                        [ -2.44140625e-04,   2.44140625e-03],
                        [  1.10168457e-02,   1.27258301e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  4.02526855e-02,   3.86962891e-02],
                        [  4.39453125e-02,   4.15039062e-02],
                        [  3.88488770e-02,   3.63159180e-02],
                        [  2.78015137e-02,   2.58789062e-02],
                        [  1.43127441e-02,   1.37329102e-02],
                        [  3.05175781e-04,   1.49536133e-03],
                        [ -1.12915039e-02,  -8.75854492e-03],
                        [ -1.25427246e-02,  -9.70458984e-03],
                        [  5.58471680e-03,   7.53784180e-03],
                        [  4.34875488e-02,   4.38537598e-02],
                        [  9.25292969e-02,   9.13391113e-02],
                        [  1.42639160e-01,   1.40411377e-01],
                        [  1.82983398e-01,   1.80541992e-01],
                        [  2.01080322e-01,   1.99249268e-01],
                        [  1.92169189e-01,   1.91680908e-01],
                        [  1.66839600e-01,   1.68090820e-01],
                        [  1.42150879e-01,   1.44805908e-01],
                        [  1.27075195e-01,   1.29943848e-01],
                        [  1.17645264e-01,   1.19232178e-01],
                        [  1.05224609e-01,   1.04553223e-01],
                        [  8.78295898e-02,   8.53576660e-02],
                        [  7.10449219e-02,   6.81762695e-02],
                        [  5.83801270e-02,   5.64270020e-02],
                        [  4.77905273e-02,   4.74243164e-02],
                        [  3.57666016e-02,   3.69262695e-02],
                        [  1.93481445e-02,   2.15454102e-02],
                        [ -3.17382812e-03,  -8.23974609e-04],
                        [ -2.94189453e-02,  -2.78625488e-02],
                        [ -5.12084961e-02,  -5.09948730e-02],
                        [ -5.92346191e-02,  -6.02111816e-02],
                        [ -5.01403809e-02,  -5.16052246e-02],
                        [ -2.58178711e-02,  -2.71911621e-02],
                        [  1.28479004e-02,   1.17492676e-02],
                        [  6.36901855e-02,   6.27441406e-02],
                        [  1.14440918e-01,   1.13708496e-01],
                        [  1.45477295e-01,   1.45233154e-01],
                        [  1.45599365e-01,   1.46301270e-01],
                        [  1.22589111e-01,   1.24481201e-01],
                        [  9.43908691e-02,   9.70153809e-02],
                        [  7.18383789e-02,   7.40661621e-02],
                        [  5.52978516e-02,   5.60607910e-02],
                        [  4.34570312e-02,   4.24499512e-02],
                        [  3.47595215e-02,   3.25622559e-02],
                        [  2.40478516e-02,   2.15454102e-02],
                        [  8.08715820e-03,   6.01196289e-03],
                        [ -8.48388672e-03,  -9.82666016e-03],
                        [ -1.95312500e-02,  -1.97143555e-02],
                        [ -2.46276855e-02,  -2.34985352e-02],
                        [ -2.67944336e-02,  -2.45971680e-02],
                        [ -2.76184082e-02,  -2.51770020e-02],
                        [ -2.83508301e-02,  -2.65502930e-02],
                        [ -3.07312012e-02,  -2.98767090e-02],
                        [ -3.43627930e-02,  -3.42712402e-02],
                        [ -3.70178223e-02,  -3.77197266e-02],
                        [ -3.79638672e-02,  -3.98864746e-02],
                        [ -3.84216309e-02,  -4.16870117e-02],
                        [ -3.86047363e-02,  -4.20837402e-02],
                        [ -3.67736816e-02,  -3.82995605e-02],
                        [ -3.21044922e-02,  -3.00903320e-02],
                        [ -2.72216797e-02,  -2.23999023e-02],
                        [ -2.58483887e-02,  -2.11486816e-02],
                        [ -2.87780762e-02,  -2.70690918e-02],
                        [ -3.52478027e-02,  -3.70788574e-02],
                        [ -4.51049805e-02,  -4.86450195e-02],
                        [ -5.70678711e-02,  -5.99670410e-02],
                        [ -6.68029785e-02,  -6.80236816e-02],
                        [ -6.98852539e-02,  -6.99157715e-02],
                        [ -6.57043457e-02,  -6.52465820e-02],
                        [ -5.67321777e-02,  -5.57556152e-02],
                        [ -4.46777344e-02,  -4.29077148e-02],
                        [ -2.69165039e-02,  -2.48718262e-02],
                        [  9.15527344e-05,   1.09863281e-03],
                        [  3.38134766e-02,   3.30505371e-02],
                        [  6.45751953e-02,   6.28051758e-02],
                        [  8.12683105e-02,   8.00170898e-02],
                        [  7.68127441e-02,   7.69348145e-02],
                        [  4.89196777e-02,   4.96826172e-02],
                        [ -2.56347656e-03,  -2.59399414e-03],
                        [ -7.50732422e-02,  -7.65686035e-02],
                        [ -1.57165527e-01,  -1.59179688e-01],
                        [ -2.25311279e-01,  -2.26104736e-01],
                        [ -2.54669189e-01,  -2.53051758e-01],
                        [ -2.38433838e-01,  -2.34924316e-01],
                        [ -1.95159912e-01,  -1.91680908e-01],
                        [ -1.51977539e-01,  -1.50512695e-01],
                        [ -1.22161865e-01,  -1.23382568e-01],
                        [ -1.02386475e-01,  -1.05499268e-01],
                        [ -8.57238770e-02,  -8.93249512e-02],
                        [ -7.15942383e-02,  -7.44018555e-02],
                        [ -6.44531250e-02,  -6.55822754e-02],
                        [ -6.35070801e-02,  -6.25305176e-02],
                        [ -5.80139160e-02,  -5.49621582e-02],
                        [ -3.79333496e-02,  -3.37829590e-02],
                        [ -4.39453125e-03,  -1.12915039e-03],
                        [  3.38745117e-02,   3.42712402e-02],
                        [  6.84204102e-02,   6.55212402e-02],
                        [  9.50317383e-02,   9.06066895e-02],
                        [  1.14624023e-01,   1.11541748e-01],
                        [  1.28723145e-01,   1.28875732e-01],
                        [  1.35101318e-01,   1.37908936e-01],
                        [  1.28723145e-01,   1.31866455e-01],
                        [  1.01928711e-01,   1.03271484e-01],
                        [  4.46777344e-02,   4.37622070e-02],
                        [ -4.42810059e-02,  -4.63562012e-02],
                        [ -1.43035889e-01,  -1.44714355e-01],
                        [ -2.11761475e-01,  -2.12249756e-01],
                        [ -2.22137451e-01,  -2.21466064e-01],
                        [ -1.80999756e-01,  -1.79748535e-01],
                        [ -1.22344971e-01,  -1.21154785e-01],
                        [ -7.80334473e-02,  -7.73925781e-02],
                        [ -5.69763184e-02,  -5.71594238e-02],
                        [ -4.62646484e-02,  -4.70886230e-02],
                        [ -3.04260254e-02,  -3.14025879e-02],
                        [ -9.46044922e-03,  -9.85717773e-03],
                        [  6.22558594e-03,   6.68334961e-03],
                        [  1.28173828e-02,   1.34887695e-02],
                        [  1.61743164e-02,   1.61437988e-02],
                        [  2.34680176e-02,   2.23999023e-02],
                        [  3.61938477e-02,   3.48205566e-02],
                        [  4.81262207e-02,   4.77600098e-02],
                        [  5.11779785e-02,   5.24902344e-02],
                        [  4.47387695e-02,   4.69970703e-02],
                        [  3.47900391e-02,   3.65905762e-02],
                        [  2.48718262e-02,   2.52380371e-02],
                        [  1.40686035e-02,   1.29699707e-02],
                        [  2.89916992e-03,   1.15966797e-03],
                        [ -3.69262695e-03,  -5.31005859e-03],
                        [  2.44140625e-04,  -8.85009766e-04],
                        [  1.72729492e-02,   1.67541504e-02],
                        [  4.62646484e-02,   4.64477539e-02],
                        [  8.50524902e-02,   8.58154297e-02],
                        [  1.30187988e-01,   1.31256104e-01],
                        [  1.72271729e-01,   1.73339844e-01],
                        [  1.96319580e-01,   1.97326660e-01],
                        [  1.93756104e-01,   1.94946289e-01],
                        [  1.72241211e-01,   1.73675537e-01],
                        [  1.48376465e-01,   1.49444580e-01],
                        [  1.32446289e-01,   1.31744385e-01],
                        [  1.22497559e-01,   1.18865967e-01],
                        [  1.11511230e-01,   1.05712891e-01],
                        [  9.72290039e-02,   9.24377441e-02],
                        [  8.33740234e-02,   8.31298828e-02],
                        [  7.16857910e-02,   7.69958496e-02],
                        [  5.88989258e-02,   6.71081543e-02],
                        [  4.25415039e-02,   4.90417480e-02],
                        [  2.39868164e-02,   2.54516602e-02],
                        [  4.85229492e-03,   9.76562500e-04],
                        [ -1.53808594e-02,  -2.19726562e-02],
                        [ -3.60107422e-02,  -4.18395996e-02],
                        [ -5.29174805e-02,  -5.55114746e-02],
                        [ -5.88989258e-02,  -5.79223633e-02],
                        [ -4.56848145e-02,  -4.24499512e-02],
                        [ -8.72802734e-03,  -5.12695312e-03],
                        [  4.64782715e-02,   4.90112305e-02],
                        [  1.03424072e-01,   1.04217529e-01],
                        [  1.41540527e-01,   1.40777588e-01],
                        [  1.47979736e-01,   1.46575928e-01],
                        [  1.27197266e-01,   1.26281738e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  7.64770508e-02,   7.65991211e-02],
                        [  6.42700195e-02,   6.33239746e-02],
                        [  5.37719727e-02,   5.16357422e-02],
                        [  4.02221680e-02,   3.83911133e-02],
                        [  2.42919922e-02,   2.46582031e-02],
                        [  9.42993164e-03,   1.25732422e-02],
                        [ -2.44140625e-04,   4.05883789e-03],
                        [ -4.39453125e-03,  -1.55639648e-03],
                        [ -8.33129883e-03,  -8.75854492e-03],
                        [ -1.71508789e-02,  -2.06298828e-02],
                        [ -2.93884277e-02,  -3.39355469e-02],
                        [ -3.87573242e-02,  -4.20227051e-02],
                        [ -4.11682129e-02,  -4.17175293e-02],
                        [ -3.82690430e-02,  -3.63159180e-02],
                        [ -3.51257324e-02,  -3.21350098e-02],
                        [ -3.45764160e-02,  -3.20739746e-02],
                        [ -3.43322754e-02,  -3.30505371e-02],
                        [ -3.10974121e-02,  -3.06396484e-02],
                        [ -2.70080566e-02,  -2.66418457e-02],
                        [ -2.78625488e-02,  -2.74353027e-02],
                        [ -3.42407227e-02,  -3.46069336e-02],
                        [ -4.04968262e-02,  -4.28161621e-02],
                        [ -4.36096191e-02,  -4.80346680e-02],
                        [ -4.64782715e-02,  -5.12084961e-02],
                        [ -5.10253906e-02,  -5.29174805e-02],
                        [ -5.46875000e-02,  -5.16967773e-02],
                        [ -5.55725098e-02,  -4.85229492e-02],
                        [ -5.47485352e-02,  -4.73022461e-02],
                        [ -5.18798828e-02,  -4.82177734e-02],
                        [ -4.36706543e-02,  -4.56848145e-02],
                        [ -2.75573730e-02,  -3.37829590e-02],
                        [ -3.93676758e-03,  -1.10473633e-02],
                        [  2.34680176e-02,   1.87072754e-02],
                        [  4.79431152e-02,   4.73022461e-02],
                        [  6.31713867e-02,   6.66503906e-02],
                        [  6.54602051e-02,   7.13500977e-02],
                        [  4.92553711e-02,   5.47180176e-02],
                        [  6.83593750e-03,   9.09423828e-03],
                        [ -6.20727539e-02,  -6.39343262e-02],
                        [ -1.44470215e-01,  -1.48803711e-01],
                        [ -2.19635010e-01,  -2.23571777e-01],
                        [ -2.65350342e-01,  -2.66876221e-01],
                        [ -2.64648438e-01,  -2.63885498e-01],
                        [ -2.20642090e-01,  -2.19146729e-01],
                        [ -1.62139893e-01,  -1.61468506e-01],
                        [ -1.21337891e-01,  -1.21765137e-01],
                        [ -1.05194092e-01,  -1.05560303e-01],
                        [ -9.72900391e-02,  -9.61303711e-02],
                        [ -8.41369629e-02,  -8.11462402e-02],
                        [ -6.80847168e-02,  -6.47583008e-02],
                        [ -5.58776855e-02,  -5.44738770e-02],
                        [ -4.73022461e-02,  -4.93164062e-02],
                        [ -3.83911133e-02,  -4.33044434e-02],
                        [ -2.57568359e-02,  -3.14025879e-02],
                        [ -4.79125977e-03,  -8.51440430e-03],
                        [  2.67028809e-02,   2.65808105e-02],
                        [  6.21643066e-02,   6.55212402e-02],
                        [  9.17053223e-02,   9.70153809e-02],
                        [  1.12304688e-01,   1.17645264e-01],
                        [  1.25854492e-01,   1.29760742e-01],
                        [  1.30981445e-01,   1.32385254e-01],
                        [  1.21582031e-01,   1.19842529e-01],
                        [  9.06372070e-02,   8.59985352e-02],
                        [  3.33557129e-02,   2.72216797e-02],
                        [ -4.78210449e-02,  -5.32226562e-02],
                        [ -1.35528564e-01,  -1.38214111e-01],
                        [ -1.98547363e-01,  -1.97814941e-01],
                        [ -2.10937500e-01,  -2.07122803e-01],
                        [ -1.73400879e-01,  -1.67663574e-01],
                        [ -1.14654541e-01,  -1.08520508e-01],
                        [ -6.84814453e-02,  -6.40258789e-02],
                        [ -4.76379395e-02,  -4.66918945e-02],
                        [ -3.89709473e-02,  -4.22973633e-02],
                        [ -2.52380371e-02,  -3.15856934e-02],
                        [ -5.73730469e-03,  -1.23596191e-02],
                        [  7.81250000e-03,   3.63159180e-03],
                        [  8.63647461e-03,   8.20922852e-03],
                        [  2.47192383e-03,   5.31005859e-03],
                        [  7.62939453e-04,   5.34057617e-03],
                        [  8.88061523e-03,   1.35192871e-02],
                        [  2.20642090e-02,   2.54516602e-02],
                        [  3.15246582e-02,   3.28369141e-02],
                        [  3.31115723e-02,   3.21655273e-02],
                        [  2.97546387e-02,   2.72216797e-02],
                        [  2.59704590e-02,   2.30712891e-02],
                        [  2.11791992e-02,   1.87988281e-02],
                        [  1.27563477e-02,   1.08947754e-02],
                        [  4.88281250e-03,   3.20434570e-03],
                        [  6.37817383e-03,   5.06591797e-03],
                        [  2.13623047e-02,   2.16979980e-02],
                        [  4.92553711e-02,   5.24597168e-02],
                        [  8.88061523e-02,   9.45434570e-02],
                        [  1.35284424e-01,   1.41021729e-01],
                        [  1.75354004e-01,   1.77703857e-01],
                        [  1.93420410e-01,   1.90704346e-01],
                        [  1.85760498e-01,   1.79382324e-01],
                        [  1.64031982e-01,   1.57531738e-01],
                        [  1.42059326e-01,   1.38519287e-01],
                        [  1.24603271e-01,   1.24694824e-01],
                        [  1.10626221e-01,   1.13159180e-01],
                        [  9.98535156e-02,   1.03363037e-01],
                        [  9.20104980e-02,   9.57641602e-02],
                        [  8.46862793e-02,   8.80737305e-02],
                        [  7.54089355e-02,   7.73620605e-02],
                        [  6.47277832e-02,   6.43310547e-02],
                        [  5.32836914e-02,   5.06896973e-02],
                        [  3.71398926e-02,   3.34777832e-02],
                        [  1.22985840e-02,   8.94165039e-03],
                        [ -1.64184570e-02,  -1.87072754e-02],
                        [ -3.83911133e-02,  -3.92761230e-02],
                        [ -4.79125977e-02,  -4.71801758e-02],
                        [ -4.75769043e-02,  -4.50439453e-02],
                        [ -4.08630371e-02,  -3.67126465e-02],
                        [ -2.44140625e-02,  -1.97753906e-02],
                        [  7.99560547e-03,   1.11999512e-02],
                        [  5.42602539e-02,   5.38330078e-02],
                        [  1.00097656e-01,   9.52758789e-02],
                        [  1.28509521e-01,   1.21154785e-01],
                        [  1.30218506e-01,   1.24298096e-01],
                        [  1.07879639e-01,   1.06811523e-01],
                        [  7.52868652e-02,   7.93457031e-02],
                        [  4.92858887e-02,   5.56640625e-02],
                        [  3.72924805e-02,   4.25109863e-02],
                        [  3.41491699e-02,   3.63464355e-02],
                        [  3.18298340e-02,   3.13415527e-02],
                        [  2.80456543e-02,   2.60009766e-02],
                        [  2.37731934e-02,   2.09960938e-02],
                        [  1.85546875e-02,   1.54113770e-02],
                        [  9.73510742e-03,   6.80541992e-03],
                        [ -4.57763672e-03,  -6.25610352e-03],
                        [ -2.12707520e-02,  -2.11486816e-02],
                        [ -3.36608887e-02,  -3.19824219e-02],
                        [ -3.83300781e-02,  -3.60107422e-02],
                        [ -3.75976562e-02,  -3.51562500e-02],
                        [ -3.42712402e-02,  -3.15856934e-02],
                        [ -2.90832520e-02,  -2.63366699e-02],
                        [ -2.33764648e-02,  -2.17895508e-02],
                        [ -1.99584961e-02,  -2.11791992e-02],
                        [ -2.09655762e-02,  -2.54516602e-02],
                        [ -2.53295898e-02,  -3.14331055e-02],
                        [ -3.00292969e-02,  -3.47595215e-02],
                        [ -3.39050293e-02,  -3.50646973e-02],
                        [ -3.88488770e-02,  -3.61328125e-02],
                        [ -4.63867188e-02,  -4.10156250e-02],
                        [ -5.44128418e-02,  -4.81567383e-02],
                        [ -5.77392578e-02,  -5.27038574e-02],
                        [ -5.39855957e-02,  -5.24291992e-02],
                        [ -4.63256836e-02,  -4.95605469e-02],
                        [ -3.72619629e-02,  -4.42504883e-02],
                        [ -2.47802734e-02,  -3.22265625e-02],
                        [ -8.81958008e-03,  -1.30004883e-02],
                        [  7.93457031e-03,   8.78906250e-03],
                        [  2.64587402e-02,   3.14025879e-02],
                        [  4.82482910e-02,   5.46569824e-02],
                        [  6.48803711e-02,   7.01599121e-02],
                        [  6.03637695e-02,   6.28051758e-02],
                        [  2.44140625e-02,   2.37121582e-02],
                        [ -3.96728516e-02,  -4.29077148e-02],
                        [ -1.19323730e-01,  -1.23870850e-01],
                        [ -1.97235107e-01,  -2.01812744e-01],
                        [ -2.51403809e-01,  -2.54913330e-01],
                        [ -2.62908936e-01,  -2.64343262e-01],
                        [ -2.31872559e-01,  -2.30499268e-01],
                        [ -1.80358887e-01,  -1.76300049e-01],
                        [ -1.35467529e-01,  -1.30004883e-01],
                        [ -1.10473633e-01,  -1.05712891e-01],
                        [ -9.99755859e-02,  -9.75341797e-02],
                        [ -9.07592773e-02,  -9.11865234e-02],
                        [ -7.80029297e-02,  -8.08105469e-02],
                        [ -6.70776367e-02,  -7.12585449e-02],
                        [ -6.03027344e-02,  -6.48498535e-02],
                        [ -5.10559082e-02,  -5.49621582e-02],
                        [ -3.25927734e-02,  -3.48510742e-02],
                        [ -6.62231445e-03,  -6.46972656e-03],
                        [  2.01416016e-02,   2.29187012e-02],
                        [  4.42810059e-02,   4.90722656e-02],
                        [  6.72607422e-02,   7.26013184e-02],
                        [  9.10339355e-02,   9.52148438e-02],
                        [  1.15722656e-01,   1.17645264e-01],
                        [  1.38366699e-01,   1.37725830e-01],
                        [  1.50878906e-01,   1.47766113e-01],
                        [  1.43249512e-01,   1.37756348e-01],
                        [  1.08795166e-01,   1.01837158e-01],
                        [  4.53796387e-02,   3.94287109e-02],
                        [ -4.26025391e-02,  -4.42810059e-02],
                        [ -1.36871338e-01,  -1.32568359e-01],
                        [ -2.05657959e-01,  -1.96929932e-01],
                        [ -2.22473145e-01,  -2.13500977e-01],
                        [ -1.87255859e-01,  -1.82403564e-01],
                        [ -1.27288818e-01,  -1.28601074e-01],
                        [ -7.52563477e-02,  -8.14208984e-02],
                        [ -4.64172363e-02,  -5.38330078e-02],
                        [ -3.46374512e-02,  -3.97644043e-02],
                        [ -2.65197754e-02,  -2.75878906e-02],
                        [ -1.56860352e-02,  -1.32446289e-02],
                        [ -5.34057617e-03,  -1.43432617e-03],
                        [  1.52587891e-04,   3.26538086e-03],
                        [  3.17382812e-03,   4.30297852e-03],
                        [  1.05590820e-02,   1.00402832e-02],
                        [  2.35595703e-02,   2.27355957e-02],
                        [  3.47290039e-02,   3.45458984e-02],
                        [  3.72009277e-02,   3.75366211e-02],
                        [  3.28063965e-02,   3.29589844e-02],
                        [  2.71606445e-02,   2.65197754e-02],
                        [  2.02331543e-02,   1.87683105e-02],
                        [  9.49096680e-03,   7.59887695e-03],
                        [ -1.70898438e-03,  -3.17382812e-03],
                        [ -5.67626953e-03,  -5.64575195e-03],
                        [  1.52587891e-03,   3.72314453e-03],
                        [  2.00195312e-02,   2.37731934e-02],
                        [  5.02929688e-02,   5.36804199e-02],
                        [  9.11865234e-02,   9.20104980e-02],
                        [  1.36016846e-01,   1.33300781e-01],
                        [  1.73248291e-01,   1.68212891e-01],
                        [  1.91802979e-01,   1.87225342e-01],
                        [  1.88751221e-01,   1.87408447e-01],
                        [  1.72821045e-01,   1.75598145e-01],
                        [  1.56524658e-01,   1.61743164e-01],
                        [  1.45629883e-01,   1.50115967e-01],
                        [  1.37542725e-01,   1.38854980e-01],
                        [  1.26922607e-01,   1.24908447e-01],
                        [  1.11572266e-01,   1.08154297e-01],
                        [  9.40246582e-02,   9.13696289e-02],
                        [  7.68432617e-02,   7.57446289e-02],
                        [  5.91735840e-02,   5.90515137e-02],
                        [  3.94897461e-02,   3.95507812e-02],
                        [  1.91040039e-02,   1.92871094e-02],
                        [  5.18798828e-04,   1.49536133e-03],
                        [ -1.51977539e-02,  -1.31835938e-02],
                        [ -2.88391113e-02,  -2.64892578e-02],
                        [ -4.01000977e-02,  -3.86047363e-02],
                        [ -4.60815430e-02,  -4.60510254e-02],
                        [ -4.47692871e-02,  -4.58984375e-02],
                        [ -3.56140137e-02,  -3.73840332e-02],
                        [ -1.40075684e-02,  -1.63269043e-02],
                        [  2.71606445e-02,   2.43835449e-02],
                        [  8.25195312e-02,   8.02307129e-02],
                        [  1.28936768e-01,   1.28692627e-01],
                        [  1.44104004e-01,   1.46820068e-01],
                        [  1.27258301e-01,   1.31958008e-01],
                        [  9.52758789e-02,   9.94567871e-02],
                        [  6.49414062e-02,   6.64062500e-02],
                        [  4.39758301e-02,   4.23583984e-02],
                        [  3.27148438e-02,   2.96020508e-02],
                        [  2.75268555e-02,   2.50854492e-02],
                        [  2.47192383e-02,   2.36816406e-02],
                        [  2.26440430e-02,   2.20031738e-02],
                        [  1.94396973e-02,   1.80969238e-02],
                        [  1.16882324e-02,   1.01013184e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -1.66015625e-02,  -1.38244629e-02],
                        [ -2.78930664e-02,  -2.33764648e-02],
                        [ -3.37829590e-02,  -2.99682617e-02],
                        [ -3.67431641e-02,  -3.55529785e-02],
                        [ -4.04968262e-02,  -4.22973633e-02],
                        [ -4.46166992e-02,  -4.84313965e-02],
                        [ -4.40979004e-02,  -4.84313965e-02],
                        [ -3.71398926e-02,  -4.04357910e-02],
                        [ -2.93579102e-02,  -3.02124023e-02],
                        [ -2.66418457e-02,  -2.43835449e-02],
                        [ -2.90222168e-02,  -2.45971680e-02],
                        [ -3.34167480e-02,  -2.92053223e-02],
                        [ -3.73535156e-02,  -3.56750488e-02],
                        [ -3.97949219e-02,  -4.11376953e-02],
                        [ -4.20227051e-02,  -4.47998047e-02],
                        [ -4.65698242e-02,  -4.87365723e-02],
                        [ -5.29785156e-02,  -5.38024902e-02],
                        [ -5.53588867e-02,  -5.56945801e-02],
                        [ -4.71191406e-02,  -4.79431152e-02],
                        [ -2.86254883e-02,  -2.97241211e-02],
                        [ -6.89697266e-03,  -6.98852539e-03],
                        [  1.35803223e-02,   1.55944824e-02],
                        [  3.34472656e-02,   3.72619629e-02],
                        [  5.05676270e-02,   5.43212891e-02],
                        [  5.56030273e-02,   5.71289062e-02],
                        [  3.79333496e-02,   3.60107422e-02],
                        [ -7.56835938e-03,  -1.22375488e-02],
                        [ -7.69653320e-02,  -8.20312500e-02],
                        [ -1.55914307e-01,  -1.58843994e-01],
                        [ -2.22503662e-01,  -2.22137451e-01],
                        [ -2.56591797e-01,  -2.53662109e-01],
                        [ -2.49877930e-01,  -2.46124268e-01],
                        [ -2.10021973e-01,  -2.07000732e-01],
                        [ -1.58752441e-01,  -1.57135010e-01],
                        [ -1.21002197e-01,  -1.20971680e-01],
                        [ -1.06323242e-01,  -1.07635498e-01],
                        [ -1.01776123e-01,  -1.03698730e-01],
                        [ -9.03320312e-02,  -9.17968750e-02],
                        [ -7.07397461e-02,  -7.10144043e-02],
                        [ -5.38635254e-02,  -5.35583496e-02],
                        [ -4.75463867e-02,  -4.81872559e-02],
                        [ -4.82482910e-02,  -5.05981445e-02],
                        [ -4.40673828e-02,  -4.67224121e-02],
                        [ -2.50549316e-02,  -2.52990723e-02],
                        [  7.72094727e-03,   1.15051270e-02],
                        [  4.43420410e-02,   5.05065918e-02],
                        [  7.55310059e-02,   8.00781250e-02],
                        [  9.91821289e-02,   9.90600586e-02],
                        [  1.17706299e-01,   1.13281250e-01],
                        [  1.30798340e-01,   1.25366211e-01],
                        [  1.34063721e-01,   1.30889893e-01],
                        [  1.22253418e-01,   1.22222900e-01],
                        [  9.03320312e-02,   9.20715332e-02],
                        [  3.34472656e-02,   3.52783203e-02],
                        [ -4.77294922e-02,  -4.64782715e-02],
                        [ -1.37939453e-01,  -1.37207031e-01],
                        [ -2.04956055e-01,  -2.04711914e-01],
                        [ -2.17956543e-01,  -2.18322754e-01],
                        [ -1.77001953e-01,  -1.77795410e-01],
                        [ -1.16424561e-01,  -1.16973877e-01],
                        [ -7.30285645e-02,  -7.26013184e-02],
                        [ -5.60913086e-02,  -5.45043945e-02],
                        [ -4.98962402e-02,  -4.80346680e-02],
                        [ -3.79943848e-02,  -3.73229980e-02],
                        [ -1.99890137e-02,  -2.16064453e-02],
                        [ -6.10351562e-03,  -9.55200195e-03],
                        [ -1.19018555e-03,  -4.54711914e-03],
                        [  9.15527344e-04,  -2.13623047e-04],
                        [  8.51440430e-03,   1.00097656e-02],
                        [  2.19421387e-02,   2.47497559e-02],
                        [  3.40576172e-02,   3.64379883e-02],
                        [  3.82690430e-02,   3.94592285e-02],
                        [  3.38439941e-02,   3.43627930e-02],
                        [  2.49328613e-02,   2.56042480e-02],
                        [  1.56860352e-02,   1.64184570e-02],
                        [  7.26318359e-03,   7.04956055e-03],
                        [  1.00708008e-03,  -1.03759766e-03],
                        [  2.19726562e-03,  -1.25122070e-03],
                        [  1.65100098e-02,   1.33056641e-02],
                        [  4.47692871e-02,   4.35180664e-02],
                        [  8.44421387e-02,   8.55407715e-02],
                        [  1.29211426e-01,   1.31652832e-01],
                        [  1.65985107e-01,   1.68304443e-01],
                        [  1.82037354e-01,   1.83502197e-01],
                        [  1.76940918e-01,   1.77856445e-01],
                        [  1.61651611e-01,   1.62719727e-01],
                        [  1.46820068e-01,   1.48223877e-01],
                        [  1.37023926e-01,   1.37939453e-01],
                        [  1.31072998e-01,   1.30218506e-01],
                        [  1.23870850e-01,   1.20666504e-01],
                        [  1.11938477e-01,   1.07299805e-01],
                        [  9.79614258e-02,   9.39025879e-02],
                        [  8.51440430e-02,   8.35571289e-02],
                        [  7.12280273e-02,   7.28454590e-02],
                        [  5.48706055e-02,   5.90209961e-02],
                        [  4.03747559e-02,   4.55322266e-02],
                        [  3.01818848e-02,   3.46069336e-02],
                        [  1.94702148e-02,   2.14538574e-02],
                        [  2.41088867e-03,   1.00708008e-03],
                        [ -2.07519531e-02,  -2.50549316e-02],
                        [ -4.36401367e-02,  -4.87060547e-02],
                        [ -5.92041016e-02,  -6.21337891e-02],
                        [ -6.46362305e-02,  -6.38732910e-02],
                        [ -5.88684082e-02,  -5.54504395e-02],
                        [ -3.73229980e-02,  -3.43017578e-02],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  5.70678711e-02,   5.40466309e-02],
                        [  1.06750488e-01,   1.03302002e-01],
                        [  1.34857178e-01,   1.34124756e-01],
                        [  1.33605957e-01,   1.36535645e-01],
                        [  1.10961914e-01,   1.15753174e-01],
                        [  8.47778320e-02,   8.83178711e-02],
                        [  6.60705566e-02,   6.64062500e-02],
                        [  5.13916016e-02,   4.87670898e-02],
                        [  3.44543457e-02,   3.08227539e-02],
                        [  1.84631348e-02,   1.58081055e-02],
                        [  9.09423828e-03,   8.17871094e-03],
                        [  4.30297852e-03,   4.85229492e-03],
                        [ -3.05175781e-04,   9.46044922e-04],
                        [ -3.84521484e-03,  -2.47192383e-03],
                        [ -4.18090820e-03,  -3.38745117e-03],
                        [ -4.33349609e-03,  -4.73022461e-03],
                        [ -1.04064941e-02,  -1.17797852e-02],
                        [ -2.28881836e-02,  -2.38647461e-02],
                        [ -3.39050293e-02,  -3.30200195e-02],
                        [ -3.70483398e-02,  -3.44238281e-02],
                        [ -3.47290039e-02,  -3.21655273e-02],
                        [ -3.14025879e-02,  -3.08532715e-02],
                        [ -2.91137695e-02,  -3.07617188e-02],
                        [ -3.15246582e-02,  -3.38134766e-02],
                        [ -4.03747559e-02,  -4.18701172e-02],
                        [ -4.88891602e-02,  -4.94689941e-02],
                        [ -4.97741699e-02,  -5.03540039e-02],
                        [ -4.58374023e-02,  -4.68139648e-02],
                        [ -4.30603027e-02,  -4.35791016e-02],
                        [ -4.01306152e-02,  -3.90625000e-02],
                        [ -3.33557129e-02,  -3.08532715e-02],
                        [ -2.44750977e-02,  -2.22473145e-02],
                        [ -1.63574219e-02,  -1.57775879e-02],
                        [ -6.95800781e-03,  -7.65991211e-03],
                        [  5.67626953e-03,   5.21850586e-03],
                        [  1.85546875e-02,   1.89819336e-02],
                        [  2.88085938e-02,   2.91748047e-02],
                        [  3.70483398e-02,   3.60717773e-02],
                        [  4.15344238e-02,   3.92761230e-02],
                        [  3.38745117e-02,   3.17077637e-02],
                        [  1.64794922e-03,   9.76562500e-04],
                        [ -6.23168945e-02,  -6.12182617e-02],
                        [ -1.47857666e-01,  -1.46087646e-01],
                        [ -2.26593018e-01,  -2.25463867e-01],
                        [ -2.69104004e-01,  -2.69104004e-01],
                        [ -2.63824463e-01,  -2.64282227e-01],
                        [ -2.21008301e-01,  -2.20855713e-01],
                        [ -1.64459229e-01,  -1.63269043e-01],
                        [ -1.17797852e-01,  -1.16302490e-01],
                        [ -9.10949707e-02,  -9.04846191e-02],
                        [ -7.83996582e-02,  -7.92846680e-02],
                        [ -6.96716309e-02,  -7.15332031e-02],
                        [ -6.17980957e-02,  -6.34460449e-02],
                        [ -5.61828613e-02,  -5.69152832e-02],
                        [ -5.06591797e-02,  -5.08117676e-02],
                        [ -3.89404297e-02,  -3.92456055e-02],
                        [ -1.75781250e-02,  -1.80358887e-02],
                        [  1.04064941e-02,   1.06811523e-02],
                        [  3.92761230e-02,   4.09851074e-02],
                        [  6.48498535e-02,   6.73828125e-02],
                        [  8.54187012e-02,   8.70666504e-02],
                        [  1.00250244e-01,   9.98535156e-02],
                        [  1.08581543e-01,   1.06750488e-01],
                        [  1.11083984e-01,   1.09863281e-01],
                        [  1.09985352e-01,   1.10656738e-01],
                        [  1.01043701e-01,   1.02630615e-01],
                        [  6.86645508e-02,   6.88171387e-02],
                        [  1.28173828e-03,  -1.22070312e-03],
                        [ -8.83789062e-02,  -9.20410156e-02],
                        [ -1.66503906e-01,  -1.68457031e-01],
                        [ -2.02514648e-01,  -2.01293945e-01],
                        [ -1.88812256e-01,  -1.85760498e-01],
                        [ -1.42333984e-01,  -1.39953613e-01],
                        [ -9.04235840e-02,  -8.96301270e-02],
                        [ -5.33447266e-02,  -5.29174805e-02],
                        [ -3.52478027e-02,  -3.36914062e-02],
                        [ -2.74658203e-02,  -2.53295898e-02],
                        [ -2.14843750e-02,  -2.11181641e-02],
                        [ -1.87988281e-02,  -2.18811035e-02],
                        [ -2.39562988e-02,  -2.94799805e-02],
                        [ -3.17993164e-02,  -3.65905762e-02],
                        [ -2.95104980e-02,  -3.07312012e-02],
                        [ -1.15356445e-02,  -8.85009766e-03],
                        [  1.39770508e-02,   1.84326172e-02],
                        [  3.37829590e-02,   3.73840332e-02],
                        [  4.03442383e-02,   4.19006348e-02],
                        [  3.45764160e-02,   3.47290039e-02],
                        [  2.22167969e-02,   2.20642090e-02],
                        [  9.09423828e-03,   8.81958008e-03],
                        [ -8.85009766e-04,  -1.77001953e-03],
                        [ -3.20434570e-03,  -4.82177734e-03],
                        [  8.14819336e-03,   6.53076172e-03],
                        [  3.62854004e-02,   3.52172852e-02],
                        [  7.69042969e-02,   7.59582520e-02],
                        [  1.20300293e-01,   1.18804932e-01],
                        [  1.55609131e-01,   1.53930664e-01],
                        [  1.74163818e-01,   1.74041748e-01],
                        [  1.73980713e-01,   1.77032471e-01],
                        [  1.61529541e-01,   1.67358398e-01],
                        [  1.47186279e-01,   1.53076172e-01],
                        [  1.38977051e-01,   1.41540527e-01],
                        [  1.37664795e-01,   1.35223389e-01],
                        [  1.35711670e-01,   1.29455566e-01],
                        [  1.25366211e-01,   1.18347168e-01],
                        [  1.07910156e-01,   1.03149414e-01],
                        [  9.00268555e-02,   8.91418457e-02],
                        [  7.31201172e-02,   7.60192871e-02],
                        [  5.40466309e-02,   5.92651367e-02],
                        [  3.35693359e-02,   3.86962891e-02],
                        [  1.56250000e-02,   1.83105469e-02],
                        [  1.43432617e-03,   8.23974609e-04],
                        [ -9.36889648e-03,  -1.19934082e-02],
                        [ -1.65405273e-02,  -1.88293457e-02],
                        [ -2.22473145e-02,  -2.27355957e-02],
                        [ -3.08532715e-02,  -3.00598145e-02],
                        [ -4.22363281e-02,  -4.16870117e-02],
                        [ -4.89196777e-02,  -4.95605469e-02],
                        [ -4.30297852e-02,  -4.45861816e-02],
                        [ -2.40173340e-02,  -2.57873535e-02],
                        [  3.84521484e-03,   2.41088867e-03],
                        [  3.83911133e-02,   3.78112793e-02],
                        [  7.77587891e-02,   7.89489746e-02],
                        [  1.12609863e-01,   1.16088867e-01],
                        [  1.28051758e-01,   1.32476807e-01],
                        [  1.17340088e-01,   1.20025635e-01],
                        [  9.07287598e-02,   8.97827148e-02],
                        [  6.51245117e-02,   6.12487793e-02],
                        [  4.71191406e-02,   4.30603027e-02],
                        [  3.20434570e-02,   3.01208496e-02],
                        [  1.62963867e-02,   1.66015625e-02],
                        [  2.86865234e-03,   4.15039062e-03],
                        [ -3.78417969e-03,  -2.56347656e-03],
                        [ -3.38745117e-03,  -2.38037109e-03],
                        [ -3.05175781e-04,   6.40869141e-04],
                        [  1.40380859e-03,   2.07519531e-03],
                        [  1.22070312e-03,   1.03759766e-03],
                        [ -7.32421875e-04,  -1.86157227e-03],
                        [ -4.82177734e-03,  -6.13403320e-03],
                        [ -1.02844238e-02,  -1.08032227e-02],
                        [ -1.69372559e-02,  -1.64489746e-02],
                        [ -2.62451172e-02,  -2.54516602e-02],
                        [ -3.70788574e-02,  -3.64990234e-02],
                        [ -4.46472168e-02,  -4.38232422e-02],
                        [ -4.54711914e-02,  -4.39758301e-02],
                        [ -4.16870117e-02,  -4.04968262e-02],
                        [ -3.84216309e-02,  -3.94592285e-02],
                        [ -3.71704102e-02,  -4.08935547e-02],
                        [ -3.44848633e-02,  -3.86047363e-02],
                        [ -2.95715332e-02,  -3.09143066e-02],
                        [ -2.77099609e-02,  -2.52685547e-02],
                        [ -3.18908691e-02,  -2.79235840e-02],
                        [ -3.69262695e-02,  -3.45458984e-02],
                        [ -3.48510742e-02,  -3.50646973e-02],
                        [ -2.31628418e-02,  -2.44445801e-02],
                        [ -5.88989258e-03,  -5.98144531e-03],
                        [  1.26953125e-02,   1.42822266e-02],
                        [  3.15856934e-02,   3.33862305e-02],
                        [  4.88281250e-02,   4.87976074e-02],
                        [  5.55725098e-02,   5.30395508e-02],
                        [  3.81469727e-02,   3.41796875e-02],
                        [ -1.20849609e-02,  -1.56250000e-02],
                        [ -9.03015137e-02,  -9.19189453e-02],
                        [ -1.78039551e-01,  -1.77124023e-01],
                        [ -2.48016357e-01,  -2.44720459e-01],
                        [ -2.73895264e-01,  -2.69165039e-01],
                        [ -2.48291016e-01,  -2.43774414e-01],
                        [ -1.92932129e-01,  -1.90551758e-01],
                        [ -1.40808105e-01,  -1.41723633e-01],
                        [ -1.08367920e-01,  -1.12091064e-01],
                        [ -9.16137695e-02,  -9.62524414e-02],
                        [ -8.17565918e-02,  -8.52661133e-02],
                        [ -7.39746094e-02,  -7.53173828e-02],
                        [ -6.58874512e-02,  -6.50634766e-02],
                        [ -5.63964844e-02,  -5.43212891e-02],
                        [ -4.54711914e-02,  -4.34265137e-02],
                        [ -3.08227539e-02,  -2.95410156e-02],
                        [ -8.88061523e-03,  -8.08715820e-03],
                        [  1.94091797e-02,   2.05078125e-02],
                        [  4.78515625e-02,   4.93774414e-02],
                        [  7.06787109e-02,   7.13195801e-02],
                        [  8.60595703e-02,   8.42895508e-02],
                        [  9.64355469e-02,   9.24072266e-02],
                        [  1.05499268e-01,   1.01593018e-01],
                        [  1.12731934e-01,   1.11846924e-01],
                        [  1.13311768e-01,   1.16333008e-01],
                        [  1.00463867e-01,   1.05285645e-01],
                        [  6.47583008e-02,   6.80847168e-02],
                        [ -7.01904297e-04,  -8.54492188e-04],
                        [ -8.68530273e-02,  -8.97827148e-02],
                        [ -1.65283203e-01,  -1.68762207e-01],
                        [ -2.04071045e-01,  -2.06268311e-01],
                        [ -1.88995361e-01,  -1.89544678e-01],
                        [ -1.35406494e-01,  -1.34704590e-01],
                        [ -7.94677734e-02,  -7.78198242e-02],
                        [ -4.98657227e-02,  -4.73937988e-02],
                        [ -4.55017090e-02,  -4.26635742e-02],
                        [ -4.52270508e-02,  -4.32434082e-02],
                        [ -3.64074707e-02,  -3.65600586e-02],
                        [ -2.40173340e-02,  -2.65808105e-02],
                        [ -1.54418945e-02,  -1.90124512e-02],
                        [ -9.09423828e-03,  -1.16271973e-02],
                        [  5.49316406e-04,   6.10351562e-05],
                        [  1.44348145e-02,   1.51062012e-02],
                        [  2.63671875e-02,   2.66418457e-02],
                        [  2.79846191e-02,   2.74963379e-02],
                        [  1.81274414e-02,   1.83410645e-02],
                        [  4.30297852e-03,   6.89697266e-03],
                        [ -5.95092773e-03,  -1.12915039e-03],
                        [ -9.09423828e-03,  -4.42504883e-03],
                        [ -2.71606445e-03,  -1.22070312e-03],
                        [  1.58386230e-02,   1.27258301e-02],
                        [  4.78820801e-02,   4.13208008e-02],
                        [  9.04541016e-02,   8.33129883e-02],
                        [  1.33697510e-01,   1.28814697e-01],
                        [  1.64947510e-01,   1.63940430e-01],
                        [  1.77520752e-01,   1.80664062e-01],
                        [  1.73522949e-01,   1.79901123e-01],
                        [  1.60461426e-01,   1.68151855e-01],
                        [  1.47644043e-01,   1.53869629e-01],
                        [  1.40869141e-01,   1.42883301e-01],
                        [  1.36749268e-01,   1.33636475e-01],
                        [  1.27502441e-01,   1.20849609e-01],
                        [  1.13494873e-01,   1.06445312e-01],
                        [  1.02325439e-01,   9.76562500e-02],
                        [  9.43908691e-02,   9.29870605e-02],
                        [  8.17871094e-02,   8.31298828e-02],
                        [  6.33544922e-02,   6.66198730e-02],
                        [  4.61730957e-02,   5.05981445e-02],
                        [  3.19213867e-02,   3.64379883e-02],
                        [  1.68762207e-02,   1.98364258e-02],
                        [  2.68554688e-03,   2.96020508e-03],
                        [ -4.63867188e-03,  -6.80541992e-03],
                        [ -5.92041016e-03,  -9.00268555e-03],
                        [ -9.09423828e-03,  -1.16882324e-02],
                        [ -1.83410645e-02,  -2.00195312e-02],
                        [ -2.94494629e-02,  -3.04260254e-02],
                        [ -3.75976562e-02,  -3.80554199e-02],
                        [ -4.18395996e-02,  -4.15649414e-02],
                        [ -3.81164551e-02,  -3.69262695e-02],
                        [ -1.79138184e-02,  -1.61132812e-02],
                        [  1.96228027e-02,   2.14233398e-02],
                        [  6.17065430e-02,   6.30798340e-02],
                        [  9.31091309e-02,   9.40856934e-02],
                        [  1.07177734e-01,   1.07666016e-01],
                        [  1.04003906e-01,   1.03302002e-01],
                        [  8.70666504e-02,   8.44421387e-02],
                        [  6.51550293e-02,   6.11572266e-02],
                        [  4.89501953e-02,   4.58374023e-02],
                        [  4.18701172e-02,   4.20532227e-02],
                        [  3.79333496e-02,   4.17480469e-02],
                        [  3.03649902e-02,   3.55834961e-02],
                        [  2.05383301e-02,   2.41699219e-02],
                        [  1.63269043e-02,   1.66931152e-02],
                        [  2.08435059e-02,   1.80664062e-02],
                        [  2.56042480e-02,   2.10876465e-02],
                        [  1.90124512e-02,   1.46484375e-02],
                        [ -3.35693359e-04,  -2.68554688e-03],
                        [ -2.35290527e-02,  -2.26440430e-02],
                        [ -4.22668457e-02,  -3.85437012e-02],
                        [ -5.37719727e-02,  -4.92248535e-02],
                        [ -5.63354492e-02,  -5.32531738e-02],
                        [ -4.87365723e-02,  -4.80651855e-02],
                        [ -3.55224609e-02,  -3.66516113e-02],
                        [ -2.42614746e-02,  -2.62145996e-02],
                        [ -1.70898438e-02,  -1.93786621e-02],
                        [ -1.22375488e-02,  -1.46789551e-02],
                        [ -1.19934082e-02,  -1.40991211e-02],
                        [ -2.13317871e-02,  -2.21557617e-02],
                        [ -3.78723145e-02,  -3.68957520e-02],
                        [ -5.11779785e-02,  -4.89196777e-02],
                        [ -5.32836914e-02,  -5.09643555e-02],
                        [ -4.47692871e-02,  -4.33654785e-02],
                        [ -2.96630859e-02,  -2.89916992e-02],
                        [ -1.00097656e-02,  -9.30786133e-03],
                        [  1.21459961e-02,   1.29089355e-02],
                        [  3.28369141e-02,   3.27148438e-02],
                        [  4.86145020e-02,   4.65698242e-02],
                        [  5.57861328e-02,   5.22155762e-02],
                        [  4.61425781e-02,   4.28161621e-02],
                        [  7.62939453e-03,   6.34765625e-03],
                        [ -6.43920898e-02,  -6.30187988e-02],
                        [ -1.54754639e-01,  -1.51580811e-01],
                        [ -2.33093262e-01,  -2.29583740e-01],
                        [ -2.73223877e-01,  -2.70690918e-01],
                        [ -2.67730713e-01,  -2.66906738e-01],
                        [ -2.27722168e-01,  -2.28668213e-01],
                        [ -1.75659180e-01,  -1.78009033e-01],
                        [ -1.33605957e-01,  -1.36474609e-01],
                        [ -1.08642578e-01,  -1.10900879e-01],
                        [ -9.03625488e-02,  -9.09118652e-02],
                        [ -6.81762695e-02,  -6.68334961e-02],
                        [ -4.73632812e-02,  -4.51965332e-02],
                        [ -3.95812988e-02,  -3.80249023e-02],
                        [ -4.24499512e-02,  -4.20532227e-02],
                        [ -4.11987305e-02,  -4.14733887e-02],
                        [ -2.86560059e-02,  -2.90527344e-02],
                        [ -1.07421875e-02,  -1.11389160e-02],
                        [  7.56835938e-03,   7.01904297e-03],
                        [  2.89306641e-02,   2.83203125e-02],
                        [  5.36499023e-02,   5.31616211e-02],
                        [  7.43408203e-02,   7.39440918e-02],
                        [  8.56933594e-02,   8.55407715e-02],
                        [  9.18273926e-02,   9.24682617e-02],
                        [  9.82666016e-02,   1.00189209e-01],
                        [  1.02844238e-01,   1.05407715e-01],
                        [  9.71374512e-02,   9.85107422e-02],
                        [  7.10754395e-02,   6.97326660e-02],
                        [  1.72119141e-02,   1.33666992e-02],
                        [ -6.09436035e-02,  -6.52160645e-02],
                        [ -1.41510010e-01,  -1.43615723e-01],
                        [ -1.92352295e-01,  -1.91131592e-01],
                        [ -1.94458008e-01,  -1.90795898e-01],
                        [ -1.56616211e-01,  -1.52557373e-01],
                        [ -1.05834961e-01,  -1.03149414e-01],
                        [ -6.56738281e-02,  -6.48803711e-02],
                        [ -4.31518555e-02,  -4.38232422e-02],
                        [ -3.18908691e-02,  -3.36608887e-02],
                        [ -2.40173340e-02,  -2.68554688e-02],
                        [ -1.74865723e-02,  -2.08740234e-02],
                        [ -1.31835938e-02,  -1.58996582e-02],
                        [ -1.00402832e-02,  -1.07727051e-02],
                        [ -5.92041016e-03,  -4.27246094e-03],
                        [ -1.19018555e-03,   1.80053711e-03],
                        [  2.25830078e-03,   5.15747070e-03],
                        [  4.91333008e-03,   6.98852539e-03],
                        [  7.08007812e-03,   8.42285156e-03],
                        [  5.18798828e-03,   6.01196289e-03],
                        [ -9.15527344e-04,  -8.85009766e-04],
                        [ -2.44140625e-04,  -1.64794922e-03],
                        [  1.83410645e-02,   1.51672363e-02],
                        [  5.26733398e-02,   4.84008789e-02],
                        [  9.21325684e-02,   8.83483887e-02],
                        [  1.28479004e-01,   1.26922607e-01],
                        [  1.56188965e-01,   1.57775879e-01],
                        [  1.69464111e-01,   1.73736572e-01],
                        [  1.65313721e-01,   1.70745850e-01],
                        [  1.49047852e-01,   1.53747559e-01],
                        [  1.32934570e-01,   1.35223389e-01],
                        [  1.26037598e-01,   1.24938965e-01],
                        [  1.26129150e-01,   1.21887207e-01],
                        [  1.24755859e-01,   1.19049072e-01],
                        [  1.18438721e-01,   1.13769531e-01],
                        [  1.10260010e-01,   1.08581543e-01],
                        [  1.02142334e-01,   1.03759766e-01],
                        [  9.17358398e-02,   9.53369141e-02],
                        [  7.73620605e-02,   8.10546875e-02],
                        [  6.01196289e-02,   6.25305176e-02],
                        [  4.22058105e-02,   4.29077148e-02],
                        [  2.75268555e-02,   2.67028809e-02],
                        [  2.03247070e-02,   1.85241699e-02],
                        [  1.86767578e-02,   1.67236328e-02],
                        [  1.37023926e-02,   1.25427246e-02],
                        [ -3.05175781e-04,  -1.52587891e-04],
                        [ -1.92260742e-02,  -1.82189941e-02],
                        [ -3.55834961e-02,  -3.46984863e-02],
                        [ -4.65087891e-02,  -4.63867188e-02],
                        [ -5.20629883e-02,  -5.24597168e-02],
                        [ -4.94689941e-02,  -4.96520996e-02],
                        [ -3.32946777e-02,  -3.29895020e-02],
                        [ -1.40380859e-03,  -1.06811523e-03],
                        [  4.00085449e-02,   3.96728516e-02],
                        [  7.80334473e-02,   7.70263672e-02],
                        [  1.00494385e-01,   9.95178223e-02],
                        [  1.02264404e-01,   1.02050781e-01],
                        [  8.67614746e-02,   8.74328613e-02],
                        [  6.47583008e-02,   6.57958984e-02],
                        [  4.78820801e-02,   4.90112305e-02],
                        [  3.98559570e-02,   4.11987305e-02],
                        [  3.58276367e-02,   3.73229980e-02],
                        [  3.05480957e-02,   3.13720703e-02],
                        [  2.36816406e-02,   2.26440430e-02],
                        [  1.81274414e-02,   1.49230957e-02],
                        [  1.52893066e-02,   1.11083984e-02],
                        [  1.27563477e-02,   9.70458984e-03],
                        [  7.08007812e-03,   6.77490234e-03],
                        [ -3.35693359e-03,  -6.71386719e-04],
                        [ -1.77917480e-02,  -1.32446289e-02],
                        [ -3.19519043e-02,  -2.74047852e-02],
                        [ -3.98559570e-02,  -3.71704102e-02],
                        [ -3.98559570e-02,  -4.01611328e-02],
                        [ -3.61328125e-02,  -3.91235352e-02],
                        [ -3.37524414e-02,  -3.78112793e-02],
                        [ -3.47290039e-02,  -3.78417969e-02],
                        [ -3.72314453e-02,  -3.82385254e-02],
                        [ -3.86047363e-02,  -3.78417969e-02],
                        [ -3.91540527e-02,  -3.77197266e-02],
                        [ -3.95812988e-02,  -3.82995605e-02],
                        [ -3.77807617e-02,  -3.67126465e-02],
                        [ -3.20739746e-02,  -3.10668945e-02],
                        [ -2.39257812e-02,  -2.33154297e-02],
                        [ -1.60522461e-02,  -1.62353516e-02],
                        [ -1.07421875e-02,  -1.16577148e-02],
                        [ -8.30078125e-03,  -9.24682617e-03],
                        [ -4.97436523e-03,  -5.27954102e-03],
                        [  4.39453125e-03,   4.66918945e-03],
                        [  2.13012695e-02,   2.15759277e-02],
                        [  4.02832031e-02,   4.01000977e-02],
                        [  4.94995117e-02,   4.91333008e-02],
                        [  3.65905762e-02,   3.66821289e-02],
                        [ -5.12695312e-03,  -4.33349609e-03],
                        [ -7.39135742e-02,  -7.29980469e-02],
                        [ -1.57379150e-01,  -1.57257080e-01],
                        [ -2.31353760e-01,  -2.32391357e-01],
                        [ -2.68096924e-01,  -2.69836426e-01],
                        [ -2.53967285e-01,  -2.55554199e-01],
                        [ -2.03125000e-01,  -2.03826904e-01],
                        [ -1.49108887e-01,  -1.48498535e-01],
                        [ -1.16760254e-01,  -1.14685059e-01],
                        [ -1.05438232e-01,  -1.02264404e-01],
                        [ -9.96704102e-02,  -9.66186523e-02],
                        [ -8.86230469e-02,  -8.72192383e-02],
                        [ -7.33337402e-02,  -7.47375488e-02],
                        [ -6.10961914e-02,  -6.50329590e-02],
                        [ -5.39855957e-02,  -5.88073730e-02],
                        [ -4.48608398e-02,  -4.84008789e-02],
                        [ -2.66723633e-02,  -2.75573730e-02],
                        [ -6.71386719e-04,   1.22070312e-03],
                        [  2.66418457e-02,   3.05175781e-02],
                        [  5.00488281e-02,   5.44738770e-02],
                        [  6.75354004e-02,   7.10144043e-02],
                        [  8.01696777e-02,   8.14514160e-02],
                        [  9.05151367e-02,   8.92639160e-02],
                        [  1.00830078e-01,   9.78088379e-02],
                        [  1.10687256e-01,   1.07269287e-01],
                        [  1.14044189e-01,   1.11541748e-01],
                        [  9.89379883e-02,   9.78088379e-02],
                        [  5.45959473e-02,   5.46264648e-02],
                        [ -1.75476074e-02,  -1.69067383e-02],
                        [ -1.00189209e-01,  -9.91516113e-02],
                        [ -1.66442871e-01,  -1.64855957e-01],
                        [ -1.93023682e-01,  -1.90765381e-01],
                        [ -1.74499512e-01,  -1.72210693e-01],
                        [ -1.29180908e-01,  -1.27929688e-01],
                        [ -8.56628418e-02,  -8.62121582e-02],
                        [ -5.95703125e-02,  -6.16455078e-02],
                        [ -4.61425781e-02,  -4.86755371e-02],
                        [ -3.45458984e-02,  -3.66516113e-02],
                        [ -2.22167969e-02,  -2.35290527e-02],
                        [ -1.26037598e-02,  -1.30920410e-02],
                        [ -6.89697266e-03,  -6.28662109e-03],
                        [ -2.56347656e-03,  -5.79833984e-04],
                        [  3.41796875e-03,   6.37817383e-03],
                        [  1.15356445e-02,   1.41906738e-02],
                        [  1.89514160e-02,   1.98364258e-02],
                        [  2.23693848e-02,   2.08129883e-02],
                        [  1.98059082e-02,   1.67541504e-02],
                        [  1.00402832e-02,   7.29370117e-03],
                        [ -3.17382812e-03,  -4.11987305e-03],
                        [ -6.62231445e-03,  -5.64575195e-03],
                        [  1.23901367e-02,   1.41906738e-02],
                        [  5.23681641e-02,   5.37109375e-02],
                        [  9.96704102e-02,   1.00097656e-01],
                        [  1.40380859e-01,   1.40258789e-01],
                        [  1.64855957e-01,   1.64581299e-01],
                        [  1.69158936e-01,   1.68823242e-01],
                        [  1.58813477e-01,   1.58386230e-01],
                        [  1.46270752e-01,   1.45904541e-01],
                        [  1.39465332e-01,   1.39190674e-01],
                        [  1.35192871e-01,   1.34918213e-01],
                        [  1.27380371e-01,   1.27197266e-01],
                        [  1.16882324e-01,   1.17156982e-01],
                        [  1.07818604e-01,   1.08825684e-01],
                        [  1.00189209e-01,   1.01623535e-01],
                        [  9.24072266e-02,   9.32922363e-02],
                        [  8.47167969e-02,   8.43811035e-02],
                        [  7.56225586e-02,   7.41882324e-02],
                        [  6.10656738e-02,   5.92041016e-02],
                        [  4.15649414e-02,   4.00695801e-02],
                        [  2.42004395e-02,   2.35900879e-02],
                        [  1.46484375e-02,   1.51672363e-02],
                        [  1.04675293e-02,   1.20544434e-02],
                        [  3.44848633e-03,   5.64575195e-03],
                        [ -1.19018555e-02,  -9.88769531e-03],
                        [ -3.18298340e-02,  -3.10058594e-02],
                        [ -4.70886230e-02,  -4.78820801e-02],
                        [ -5.32836914e-02,  -5.53283691e-02],
                        [ -5.38940430e-02,  -5.60913086e-02],
                        [ -4.93774414e-02,  -5.05981445e-02],
                        [ -2.95715332e-02,  -2.96630859e-02],
                        [  1.34582520e-02,   1.39160156e-02],
                        [  6.87255859e-02,   6.91528320e-02],
                        [  1.12335205e-01,   1.12731934e-01],
                        [  1.28417969e-01,   1.29241943e-01],
                        [  1.17340088e-01,   1.18713379e-01],
                        [  9.03320312e-02,   9.16748047e-02],
                        [  6.21643066e-02,   6.27136230e-02],
                        [  4.27856445e-02,   4.23278809e-02],
                        [  3.18603516e-02,   3.06701660e-02],
                        [  2.28271484e-02,   2.13928223e-02],
                        [  1.03759766e-02,   9.06372070e-03],
                        [ -5.34057617e-03,  -6.43920898e-03],
                        [ -1.80969238e-02,  -1.87377930e-02],
                        [ -2.17590332e-02,  -2.13623047e-02],
                        [ -1.74560547e-02,  -1.57165527e-02],
                        [ -1.15966797e-02,  -9.06372070e-03],
                        [ -9.36889648e-03,  -7.32421875e-03],
                        [ -1.21154785e-02,  -1.16271973e-02],
                        [ -1.66320801e-02,  -1.79443359e-02],
                        [ -1.85852051e-02,  -2.09960938e-02],
                        [ -1.85852051e-02,  -2.10266113e-02],
                        [ -2.13623047e-02,  -2.28576660e-02],
                        [ -2.81372070e-02,  -2.79541016e-02],
                        [ -3.44238281e-02,  -3.25012207e-02],
                        [ -3.64379883e-02,  -3.36608887e-02],
                        [ -3.54309082e-02,  -3.34167480e-02],
                        [ -3.45153809e-02,  -3.43933105e-02],
                        [ -3.43627930e-02,  -3.59802246e-02],
                        [ -3.49121094e-02,  -3.69873047e-02],
                        [ -3.65295410e-02,  -3.78723145e-02],
                        [ -3.78112793e-02,  -3.81469727e-02],
                        [ -3.59802246e-02,  -3.57360840e-02],
                        [ -2.92053223e-02,  -2.87170410e-02],
                        [ -1.61132812e-02,  -1.54113770e-02],
                        [  3.11279297e-03,   3.99780273e-03],
                        [  2.45971680e-02,   2.54821777e-02],
                        [  4.25109863e-02,   4.30908203e-02],
                        [  5.14526367e-02,   5.15747070e-02],
                        [  4.66308594e-02,   4.63867188e-02],
                        [  2.40783691e-02,   2.35900879e-02],
                        [ -1.87988281e-02,  -1.96228027e-02],
                        [ -8.16650391e-02,  -8.29467773e-02],
                        [ -1.56372070e-01,  -1.57867432e-01],
                        [ -2.25158691e-01,  -2.26165771e-01],
                        [ -2.65441895e-01,  -2.65319824e-01],
                        [ -2.61840820e-01,  -2.60406494e-01],
                        [ -2.20214844e-01,  -2.18078613e-01],
                        [ -1.67999268e-01,  -1.65893555e-01],
                        [ -1.29913330e-01,  -1.28417969e-01],
                        [ -1.06689453e-01,  -1.06079102e-01],
                        [ -8.55102539e-02,  -8.61511230e-02],
                        [ -6.33850098e-02,  -6.55517578e-02],
                        [ -4.83703613e-02,  -5.15747070e-02],
                        [ -4.39453125e-02,  -4.69665527e-02],
                        [ -4.35180664e-02,  -4.49218750e-02],
                        [ -3.79638672e-02,  -3.70483398e-02],
                        [ -2.27966309e-02,  -2.00195312e-02],
                        [ -2.13623047e-04,   3.20434570e-03],
                        [  2.35900879e-02,   2.64282227e-02],
                        [  4.41589355e-02,   4.55017090e-02],
                        [  6.14624023e-02,   6.10351562e-02],
                        [  7.78503418e-02,   7.57446289e-02],
                        [  9.49096680e-02,   9.18579102e-02],
                        [  1.11968994e-01,   1.09191895e-01],
                        [  1.24938965e-01,   1.23626709e-01],
                        [  1.26770020e-01,   1.27410889e-01],
                        [  1.09130859e-01,   1.11083984e-01],
                        [  6.39953613e-02,   6.60095215e-02],
                        [ -1.18713379e-02,  -1.08032227e-02],
                        [ -1.06353760e-01,  -1.06262207e-01],
                        [ -1.86645508e-01,  -1.86859131e-01],
                        [ -2.16705322e-01,  -2.16613770e-01],
                        [ -1.87469482e-01,  -1.87194824e-01],
                        [ -1.25885010e-01,  -1.26098633e-01],
                        [ -7.04956055e-02,  -7.15332031e-02],
                        [ -3.99475098e-02,  -4.13513184e-02],
                        [ -2.62145996e-02,  -2.72216797e-02],
                        [ -1.52282715e-02,  -1.52893066e-02],
                        [ -6.19506836e-03,  -5.43212891e-03],
                        [ -5.79833984e-03,  -4.69970703e-03],
                        [ -1.24816895e-02,  -1.15051270e-02],
                        [ -1.72729492e-02,  -1.66320801e-02],
                        [ -1.51672363e-02,  -1.49230957e-02],
                        [ -8.60595703e-03,  -8.81958008e-03],
                        [ -2.62451172e-03,  -3.44848633e-03],
                        [  2.44140625e-04,  -1.06811523e-03],
                        [  1.34277344e-03,   2.44140625e-04],
                        [  4.11987305e-03,   4.05883789e-03],
                        [  1.32141113e-02,   1.44348145e-02],
                        [  3.38745117e-02,   3.56140137e-02],
                        [  6.72302246e-02,   6.83288574e-02],
                        [  1.07421875e-01,   1.07086182e-01],
                        [  1.43127441e-01,   1.41723633e-01],
                        [  1.62353516e-01,   1.60919189e-01],
                        [  1.60278320e-01,   1.59667969e-01],
                        [  1.45233154e-01,   1.45446777e-01],
                        [  1.32537842e-01,   1.33056641e-01],
                        [  1.30187988e-01,   1.30554199e-01],
                        [  1.33056641e-01,   1.33331299e-01],
                        [  1.32568359e-01,   1.32995605e-01],
                        [  1.27593994e-01,   1.28295898e-01],
                        [  1.21917725e-01,   1.22619629e-01],
                        [  1.15020752e-01,   1.15295410e-01],
                        [  1.04156494e-01,   1.03698730e-01],
                        [  9.00573730e-02,   8.88977051e-02],
                        [  7.45849609e-02,   7.30285645e-02],
                        [  5.77392578e-02,   5.65185547e-02],
                        [  4.11682129e-02,   4.08630371e-02],
                        [  2.72216797e-02,   2.79846191e-02],
                        [  1.48925781e-02,   1.63574219e-02],
                        [  2.25830078e-03,   3.78417969e-03],
                        [ -9.30786133e-03,  -8.27026367e-03],
                        [ -1.69067383e-02,  -1.66015625e-02],
                        [ -2.04162598e-02,  -2.09350586e-02],
                        [ -2.33154297e-02,  -2.44140625e-02],
                        [ -2.92053223e-02,  -3.04260254e-02],
                        [ -3.85131836e-02,  -3.93066406e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -4.13818359e-02,  -4.08325195e-02],
                        [ -1.38549805e-02,  -1.33972168e-02],
                        [  3.57360840e-02,   3.57055664e-02],
                        [  8.94165039e-02,   8.90502930e-02],
                        [  1.21673584e-01,   1.21582031e-01],
                        [  1.20422363e-01,   1.21124268e-01],
                        [  9.62829590e-02,   9.74426270e-02],
                        [  6.83288574e-02,   6.90307617e-02],
                        [  4.62646484e-02,   4.58984375e-02],
                        [  2.93273926e-02,   2.81372070e-02],
                        [  1.55334473e-02,   1.44958496e-02],
                        [  6.56127930e-03,   6.28662109e-03],
                        [  4.91333008e-03,   5.24902344e-03],
                        [  9.27734375e-03,   9.70458984e-03],
                        [  1.35803223e-02,   1.37939453e-02],
                        [  1.17492676e-02,   1.19018555e-02],
                        [  2.56347656e-03,   2.77709961e-03],
                        [ -1.11083984e-02,  -1.09558105e-02],
                        [ -2.45666504e-02,  -2.47192383e-02],
                        [ -3.26843262e-02,  -3.30505371e-02],
                        [ -3.38439941e-02,  -3.41491699e-02],
                        [ -3.26538086e-02,  -3.26843262e-02],
                        [ -3.28979492e-02,  -3.27148438e-02],
                        [ -3.11584473e-02,  -3.08837891e-02],
                        [ -2.34985352e-02,  -2.32238770e-02],
                        [ -1.46484375e-02,  -1.43432617e-02],
                        [ -1.29394531e-02,  -1.26037598e-02],
                        [ -2.01416016e-02,  -2.00805664e-02],
                        [ -3.14941406e-02,  -3.19824219e-02],
                        [ -4.22058105e-02,  -4.32128906e-02],
                        [ -4.99572754e-02,  -5.09338379e-02],
                        [ -5.28564453e-02,  -5.31005859e-02],
                        [ -4.82788086e-02,  -4.76379395e-02],
                        [ -3.51867676e-02,  -3.41491699e-02],
                        [ -1.62658691e-02,  -1.54418945e-02],
                        [  4.63867188e-03,   4.91333008e-03],
                        [  2.56042480e-02,   2.54821777e-02],
                        [  4.47998047e-02,   4.44641113e-02],
                        [  5.65795898e-02,   5.61828613e-02],
                        [  5.30395508e-02,   5.26733398e-02],
                        [  2.74353027e-02,   2.72827148e-02],
                        [ -2.32238770e-02,  -2.31018066e-02],
                        [ -9.47570801e-02,  -9.45739746e-02],
                        [ -1.73095703e-01,  -1.73217773e-01],
                        [ -2.36755371e-01,  -2.37243652e-01],
                        [ -2.64282227e-01,  -2.64831543e-01],
                        [ -2.46337891e-01,  -2.46459961e-01],
                        [ -1.96075439e-01,  -1.95495605e-01],
                        [ -1.43768311e-01,  -1.42669678e-01],
                        [ -1.13006592e-01,  -1.11907959e-01],
                        [ -1.02691650e-01,  -1.02081299e-01],
                        [ -9.67102051e-02,  -9.68933105e-02],
                        [ -8.62121582e-02,  -8.72192383e-02],
                        [ -7.46459961e-02,  -7.60498047e-02],
                        [ -6.57348633e-02,  -6.70166016e-02],
                        [ -5.75256348e-02,  -5.80139160e-02],
                        [ -4.68139648e-02,  -4.62951660e-02],
                        [ -3.17993164e-02,  -3.06396484e-02],
                        [ -1.06811523e-02,  -9.52148438e-03],
                        [  1.63574219e-02,   1.69372559e-02],
                        [  4.42810059e-02,   4.42504883e-02],
                        [  6.57653809e-02,   6.54296875e-02],
                        [  7.69042969e-02,   7.66296387e-02],
                        [  8.09326172e-02,   8.07495117e-02],
                        [  8.51440430e-02,   8.49304199e-02],
                        [  9.45739746e-02,   9.42993164e-02],
                        [  1.07604980e-01,   1.07299805e-01],
                        [  1.14135742e-01,   1.13983154e-01],
                        [  9.87243652e-02,   9.86938477e-02],
                        [  5.05981445e-02,   5.05676270e-02],
                        [ -2.52685547e-02,  -2.52380371e-02],
                        [ -1.06170654e-01,  -1.05895996e-01],
                        [ -1.61834717e-01,  -1.61193848e-01],
                        [ -1.72302246e-01,  -1.71539307e-01],
                        [ -1.42456055e-01,  -1.41998291e-01],
                        [ -9.87243652e-02,  -9.89379883e-02],
                        [ -6.88171387e-02,  -6.96105957e-02],
                        [ -6.05773926e-02,  -6.14929199e-02],
                        [ -5.96618652e-02,  -6.01501465e-02],
                        [ -5.02014160e-02,  -5.01403809e-02],
                        [ -3.40270996e-02,  -3.36608887e-02],
                        [ -2.28576660e-02,  -2.26135254e-02],
                        [ -2.06298828e-02,  -2.05383301e-02],
                        [ -2.31628418e-02,  -2.30407715e-02],
                        [ -2.77709961e-02,  -2.74047852e-02],
                        [ -3.25317383e-02,  -3.20739746e-02],
                        [ -3.17382812e-02,  -3.15246582e-02],
                        [ -1.93786621e-02,  -1.96838379e-02],
                        [  3.93676758e-03,   3.35693359e-03],
                        [  3.47900391e-02,   3.44238281e-02],
                        [  7.36999512e-02,   7.37304688e-02],
                        [  1.18804932e-01,   1.19018555e-01],
                        [  1.57348633e-01,   1.57440186e-01],
                        [  1.74224854e-01,   1.74072266e-01],
                        [  1.66625977e-01,   1.66351318e-01],
                        [  1.45507812e-01,   1.45446777e-01],
                        [  1.26037598e-01,   1.26251221e-01],
                        [  1.16455078e-01,   1.16790771e-01],
                        [  1.14624023e-01,   1.14837646e-01],
                        [  1.14898682e-01,   1.14929199e-01],
                        [  1.15112305e-01,   1.15051270e-01],
                        [  1.14776611e-01,   1.14746094e-01],
                        [  1.12060547e-01,   1.12060547e-01],
                        [  1.05957031e-01,   1.05865479e-01],
                        [  9.84191895e-02,   9.82360840e-02],
                        [  9.11560059e-02,   9.09118652e-02],
                        [  8.24279785e-02,   8.23364258e-02],
                        [  7.04040527e-02,   7.04956055e-02],
                        [  5.67016602e-02,   5.68847656e-02],
                        [  4.32434082e-02,   4.33959961e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  1.28173828e-02,   1.27563477e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -1.50451660e-02,  -1.49230957e-02],
                        [ -2.38647461e-02,  -2.36511230e-02],
                        [ -3.30505371e-02,  -3.29284668e-02],
                        [ -4.60205078e-02,  -4.60815430e-02],
                        [ -5.90820312e-02,  -5.93261719e-02],
                        [ -6.35986328e-02,  -6.38427734e-02],
                        [ -5.26733398e-02,  -5.27954102e-02],
                        [ -2.30407715e-02,  -2.29797363e-02],
                        [  2.36511230e-02,   2.37121582e-02],
                        [  7.56225586e-02,   7.55615234e-02],
                        [  1.12884521e-01,   1.12792969e-01],
                        [  1.21063232e-01,   1.21124268e-01],
                        [  1.03698730e-01,   1.03912354e-01],
                        [  7.83691406e-02,   7.86132812e-02],
                        [  5.98449707e-02,   5.99365234e-02],
                        [  4.83093262e-02,   4.82788086e-02],
                        [  3.55834961e-02,   3.54919434e-02],
                        [  1.88903809e-02,   1.88293457e-02],
                        [  4.02832031e-03,   3.96728516e-03],
                        [ -3.44848633e-03,  -3.60107422e-03],
                        [ -3.84521484e-03,  -4.05883789e-03],
                        [ -3.96728516e-04,  -5.49316406e-04],
                        [  3.02124023e-03,   3.08227539e-03],
                        [  1.80053711e-03,   2.04467773e-03],
                        [ -5.46264648e-03,  -5.24902344e-03],
                        [ -1.40075684e-02,  -1.39160156e-02],
                        [ -1.85241699e-02,  -1.86157227e-02],
                        [ -1.95007324e-02,  -1.95922852e-02],
                        [ -2.01416016e-02,  -2.01721191e-02],
                        [ -2.16369629e-02,  -2.15759277e-02],
                        [ -2.41394043e-02,  -2.40173340e-02],
                        [ -2.96630859e-02,  -2.95715332e-02],
                        [ -3.98864746e-02,  -3.98254395e-02],
                        [ -5.06286621e-02,  -5.07202148e-02],
                        [ -5.38940430e-02,  -5.41076660e-02],
                        [ -4.73632812e-02,  -4.76379395e-02],
                        [ -3.84521484e-02,  -3.86657715e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -3.48510742e-02,  -3.45764160e-02],
                        [ -3.18603516e-02,  -3.15246582e-02],
                        [ -2.17895508e-02,  -2.15759277e-02],
                        [ -3.57055664e-03,  -3.63159180e-03],
                        [  2.23999023e-02,   2.21862793e-02],
                        [  5.08728027e-02,   5.06591797e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  7.33337402e-02,   7.35168457e-02],
                        [  5.42602539e-02,   5.44738770e-02],
                        [  1.14440918e-02,   1.15051270e-02],
                        [ -5.77392578e-02,  -5.79223633e-02],
                        [ -1.47613525e-01,  -1.47918701e-01],
                        [ -2.34527588e-01,  -2.34802246e-01],
                        [ -2.84790039e-01,  -2.84881592e-01],
                        [ -2.78991699e-01,  -2.78900146e-01],
                        [ -2.29034424e-01,  -2.28790283e-01],
                        [ -1.68457031e-01,  -1.68151855e-01],
                        [ -1.25122070e-01,  -1.24877930e-01],
                        [ -1.03485107e-01,  -1.03393555e-01],
                        [ -9.18884277e-02,  -9.19494629e-02],
                        [ -8.01696777e-02,  -8.03833008e-02],
                        [ -6.69555664e-02,  -6.71997070e-02],
                        [ -5.53588867e-02,  -5.55114746e-02],
                        [ -4.78820801e-02,  -4.79125977e-02],
                        [ -4.36096191e-02,  -4.35485840e-02],
                        [ -3.71704102e-02,  -3.71093750e-02],
                        [ -2.33154297e-02,  -2.32849121e-02],
                        [ -2.86865234e-03,  -2.83813477e-03],
                        [  1.92260742e-02,   1.92871094e-02],
                        [  4.02526855e-02,   4.03747559e-02],
                        [  5.96008301e-02,   5.97229004e-02],
                        [  7.54394531e-02,   7.55004883e-02],
                        [  8.77380371e-02,   8.76770020e-02],
                        [  1.00189209e-01,   1.00067139e-01],
                        [  1.13006592e-01,   1.12884521e-01],
                        [  1.18560791e-01,   1.18469238e-01],
                        [  1.08215332e-01,   1.08184814e-01],
                        [  7.73315430e-02,   7.73620605e-02],
                        [  2.30712891e-02,   2.31018066e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -1.29333496e-01,  -1.29302979e-01],
                        [ -1.77642822e-01,  -1.77581787e-01],
                        [ -1.77886963e-01,  -1.77764893e-01],
                        [ -1.40502930e-01,  -1.40441895e-01],
                        [ -9.44519043e-02,  -9.45129395e-02],
                        [ -6.21948242e-02,  -6.23168945e-02],
                        [ -4.71191406e-02,  -4.72412109e-02],
                        [ -3.93676758e-02,  -3.94287109e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -1.63269043e-02,  -1.62658691e-02],
                        [ -1.09558105e-02,  -1.09252930e-02],
                        [ -2.15759277e-02,  -2.15454102e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -5.82885742e-02,  -5.83190918e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  3.69873047e-02,   3.70178223e-02],
                        [  7.74536133e-02,   7.74841309e-02],
                        [  1.19628906e-01,   1.19689941e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.82250977e-01,   1.82159424e-01],
                        [  1.89300537e-01,   1.89178467e-01],
                        [  1.75445557e-01,   1.75354004e-01],
                        [  1.46545410e-01,   1.46545410e-01],
                        [  1.17553711e-01,   1.17645264e-01],
                        [  1.01135254e-01,   1.01257324e-01],
                        [  9.79919434e-02,   9.80834961e-02],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.08001709e-01,   1.07940674e-01],
                        [  1.12121582e-01,   1.12060547e-01],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  9.23156738e-02,   9.23156738e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  6.04553223e-02,   6.04248047e-02],
                        [  5.14221191e-02,   5.13916016e-02],
                        [  3.97949219e-02,   3.97644043e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.34069824e-02,   2.34375000e-02],
                        [  2.38647461e-02,   2.38952637e-02],
                        [  2.11791992e-02,   2.12402344e-02],
                        [  1.30920410e-02,   1.31225586e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -1.75170898e-02,  -1.75476074e-02],
                        [ -4.54711914e-02,  -4.55322266e-02],
                        [ -7.18078613e-02,  -7.18688965e-02],
                        [ -7.81555176e-02,  -7.81860352e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -1.61437988e-02,  -1.61132812e-02],
                        [  3.32031250e-02,   3.32641602e-02],
                        [  8.01086426e-02,   8.01391602e-02],
                        [  1.10229492e-01,   1.10229492e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  8.92333984e-02,   8.92333984e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.69055176e-02,   4.68750000e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  1.92565918e-02,   1.92871094e-02],
                        [  4.60815430e-03,   4.63867188e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.01623535e-02,  -1.01928711e-02],
                        [ -1.47705078e-02,  -1.48010254e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.02734375e-02,  -3.02429199e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.29895020e-02,  -3.30200195e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -1.94702148e-02,  -1.94396973e-02],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  5.65185547e-02,   5.65185547e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.95129395e-01,  -1.95129395e-01],
                        [ -2.57873535e-01,  -2.57873535e-01],
                        [ -2.74291992e-01,  -2.74291992e-01],
                        [ -2.43988037e-01,  -2.43988037e-01],
                        [ -1.89056396e-01,  -1.89056396e-01],
                        [ -1.40136719e-01,  -1.40136719e-01],
                        [ -1.16149902e-01,  -1.16149902e-01],
                        [ -1.12548828e-01,  -1.12548828e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -1.01684570e-01,  -1.01684570e-01],
                        [ -8.62121582e-02,  -8.62121582e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  7.21435547e-02,   7.21435547e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.24420166e-01,   1.24420166e-01],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  5.20629883e-02,   5.20629883e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.04278564e-01,  -1.04278564e-01],
                        [ -1.67266846e-01,  -1.67266846e-01],
                        [ -1.88262939e-01,  -1.88262939e-01],
                        [ -1.64794922e-01,  -1.64794922e-01],
                        [ -1.16729736e-01,  -1.16729736e-01],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  5.17883301e-02,   5.17883301e-02],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  1.43859863e-01,   1.43859863e-01],
                        [  1.72241211e-01,   1.72241211e-01],
                        [  1.76544189e-01,   1.76544189e-01],
                        [  1.59027100e-01,   1.59027100e-01],
                        [  1.29211426e-01,   1.29211426e-01],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  8.73413086e-02,   8.73413086e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.35589600e-01,   1.35589600e-01],
                        [  1.28143311e-01,   1.28143311e-01],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  6.82373047e-02,   6.82373047e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  8.35876465e-02,   8.35876465e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.89807129e-02,  -4.89807129e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  5.11474609e-02,   5.11474609e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -1.34704590e-01,  -1.34704590e-01],
                        [ -2.12066650e-01,  -2.12066650e-01],
                        [ -2.62847900e-01,  -2.62847900e-01],
                        [ -2.71331787e-01,  -2.71331787e-01],
                        [ -2.40295410e-01,  -2.40295410e-01],
                        [ -1.90124512e-01,  -1.90124512e-01],
                        [ -1.44561768e-01,  -1.44561768e-01],
                        [ -1.17462158e-01,  -1.17462158e-01],
                        [ -1.08764648e-01,  -1.08764648e-01],
                        [ -1.07025146e-01,  -1.07025146e-01],
                        [ -9.93347168e-02,  -9.93347168e-02],
                        [ -8.19091797e-02,  -8.19091797e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  7.87658691e-02,   7.87658691e-02],
                        [  9.77172852e-02,   9.77172852e-02],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  1.34094238e-01,   1.34094238e-01],
                        [  1.36901855e-01,   1.36901855e-01],
                        [  1.14349365e-01,   1.14349365e-01],
                        [  5.33752441e-02,   5.33752441e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -1.37207031e-01,  -1.37207031e-01],
                        [ -1.91833496e-01,  -1.91833496e-01],
                        [ -1.88323975e-01,  -1.88323975e-01],
                        [ -1.44409180e-01,  -1.44409180e-01],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -6.70471191e-02,  -6.70471191e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  7.34558105e-02,   7.34558105e-02],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.82647705e-01,   1.82647705e-01],
                        [  2.14111328e-01,   2.14111328e-01],
                        [  2.10388184e-01,   2.10388184e-01],
                        [  1.77185059e-01,   1.77185059e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  7.81555176e-02,   7.81555176e-02],
                        [  7.37915039e-02,   7.37915039e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  9.04541016e-02,   9.04541016e-02],
                        [  9.75341797e-02,   9.75341797e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  9.66186523e-02,   9.66186523e-02],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.18743896e-01,   1.18743896e-01],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  5.24902344e-03,   5.24902344e-03],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -4.69055176e-02,  -4.69055176e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  5.57250977e-02,   5.57250977e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -1.38946533e-01,  -1.38946533e-01],
                        [ -2.14080811e-01,  -2.14080811e-01],
                        [ -2.60589600e-01,  -2.60589600e-01],
                        [ -2.63885498e-01,  -2.63885498e-01],
                        [ -2.31872559e-01,  -2.31872559e-01],
                        [ -1.88201904e-01,  -1.88201904e-01],
                        [ -1.51580811e-01,  -1.51580811e-01],
                        [ -1.25610352e-01,  -1.25610352e-01],
                        [ -1.06384277e-01,  -1.06384277e-01],
                        [ -9.14611816e-02,  -9.14611816e-02],
                        [ -7.98950195e-02,  -7.98950195e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  5.17883301e-02,   5.17883301e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  8.51440430e-02,   8.51440430e-02],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  1.15936279e-01,   1.15936279e-01],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -1.37084961e-01,  -1.37084961e-01],
                        [ -1.69433594e-01,  -1.69433594e-01],
                        [ -1.62292480e-01,  -1.62292480e-01],
                        [ -1.27685547e-01,  -1.27685547e-01],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  7.51342773e-02,   7.51342773e-02],
                        [  1.31286621e-01,   1.31286621e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.94458008e-01,   1.94458008e-01],
                        [  1.92596436e-01,   1.92596436e-01],
                        [  1.71478271e-01,   1.71478271e-01],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  9.75036621e-02,   9.75036621e-02],
                        [  1.02081299e-01,   1.02081299e-01],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  4.42504883e-03,   4.42504883e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  7.33337402e-02,   7.33337402e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -9.65576172e-02,  -9.65576172e-02],
                        [ -1.68853760e-01,  -1.68853760e-01],
                        [ -2.22839355e-01,  -2.22839355e-01],
                        [ -2.39105225e-01,  -2.39105225e-01],
                        [ -2.19482422e-01,  -2.19482422e-01],
                        [ -1.83959961e-01,  -1.83959961e-01],
                        [ -1.52313232e-01,  -1.52313232e-01],
                        [ -1.31164551e-01,  -1.31164551e-01],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -9.93652344e-02,  -9.93652344e-02],
                        [ -8.05053711e-02,  -8.05053711e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  8.89587402e-02,   8.89587402e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.14929199e-01,   1.14929199e-01],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  8.58764648e-02,   8.58764648e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [ -7.10754395e-02,  -7.10754395e-02],
                        [ -1.50970459e-01,  -1.50970459e-01],
                        [ -1.89636230e-01,  -1.89636230e-01],
                        [ -1.77978516e-01,  -1.77978516e-01],
                        [ -1.36810303e-01,  -1.36810303e-01],
                        [ -9.55810547e-02,  -9.55810547e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  4.71496582e-02,   4.71496582e-02],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.59667969e-01,   1.59667969e-01],
                        [  1.62170410e-01,   1.62170410e-01],
                        [  1.51336670e-01,   1.51336670e-01],
                        [  1.35711670e-01,   1.35711670e-01],
                        [  1.19689941e-01,   1.19689941e-01],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  1.01593018e-01,   1.01593018e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  7.64465332e-02,   7.64465332e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.16699219e-01,   1.16699219e-01],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  7.93457031e-04,   7.93457031e-04],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  5.37414551e-02,   5.37414551e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -1.14898682e-01,  -1.14898682e-01],
                        [ -1.92443848e-01,  -1.92443848e-01],
                        [ -2.44232178e-01,  -2.44232178e-01],
                        [ -2.55737305e-01,  -2.55737305e-01],
                        [ -2.34161377e-01,  -2.34161377e-01],
                        [ -1.98913574e-01,  -1.98913574e-01],
                        [ -1.64093018e-01,  -1.64093018e-01],
                        [ -1.33941650e-01,  -1.33941650e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -9.51232910e-02,  -9.51232910e-02],
                        [ -8.88977051e-02,  -8.88977051e-02],
                        [ -8.60290527e-02,  -8.60290527e-02],
                        [ -7.85522461e-02,  -7.85522461e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.17584229e-01,   1.17584229e-01],
                        [  1.28143311e-01,   1.28143311e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [ -7.67517090e-02,  -7.67517090e-02],
                        [ -1.51214600e-01,  -1.51214600e-01],
                        [ -1.84173584e-01,  -1.84173584e-01],
                        [ -1.69830322e-01,  -1.69830322e-01],
                        [ -1.28631592e-01,  -1.28631592e-01],
                        [ -8.86840820e-02,  -8.86840820e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -6.39343262e-02,  -6.39343262e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  1.28387451e-01,   1.28387451e-01],
                        [  1.63299561e-01,   1.63299561e-01],
                        [  1.76635742e-01,   1.76635742e-01],
                        [  1.70989990e-01,   1.70989990e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.36901855e-01,   1.36901855e-01],
                        [  1.18835449e-01,   1.18835449e-01],
                        [  1.01623535e-01,   1.01623535e-01],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  9.78088379e-02,   9.78088379e-02],
                        [  1.08856201e-01,   1.08856201e-01],
                        [  9.28344727e-02,   9.28344727e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -1.51855469e-01,  -1.51855469e-01],
                        [ -2.26135254e-01,  -2.26135254e-01],
                        [ -2.69195557e-01,  -2.69195557e-01],
                        [ -2.69897461e-01,  -2.69897461e-01],
                        [ -2.36755371e-01,  -2.36755371e-01],
                        [ -1.91680908e-01,  -1.91680908e-01],
                        [ -1.53717041e-01,  -1.53717041e-01],
                        [ -1.28356934e-01,  -1.28356934e-01],
                        [ -1.11145020e-01,  -1.11145020e-01],
                        [ -9.43603516e-02,  -9.43603516e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  1.08337402e-01,   1.08337402e-01],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -1.32110596e-01,  -1.32110596e-01],
                        [ -1.64337158e-01,  -1.64337158e-01],
                        [ -1.56097412e-01,  -1.56097412e-01],
                        [ -1.25823975e-01,  -1.25823975e-01],
                        [ -9.73815918e-02,  -9.73815918e-02],
                        [ -8.24890137e-02,  -8.24890137e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -7.14111328e-02,  -7.14111328e-02],
                        [ -6.39648438e-02,  -6.39648438e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.60247803e-01,   1.60247803e-01],
                        [  1.75170898e-01,   1.75170898e-01],
                        [  1.71386719e-01,   1.71386719e-01],
                        [  1.57958984e-01,   1.57958984e-01],
                        [  1.43463135e-01,   1.43463135e-01],
                        [  1.29455566e-01,   1.29455566e-01],
                        [  1.12121582e-01,   1.12121582e-01],
                        [  9.13085938e-02,   9.13085938e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  5.60913086e-02,   5.60913086e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  1.01135254e-01,   1.01135254e-01],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.02233887e-01,  -1.02233887e-01],
                        [ -1.78131104e-01,  -1.78131104e-01],
                        [ -2.38433838e-01,  -2.38433838e-01],
                        [ -2.62573242e-01,  -2.62573242e-01],
                        [ -2.47802734e-01,  -2.47802734e-01],
                        [ -2.09625244e-01,  -2.09625244e-01],
                        [ -1.69494629e-01,  -1.69494629e-01],
                        [ -1.41082764e-01,  -1.41082764e-01],
                        [ -1.24023438e-01,  -1.24023438e-01],
                        [ -1.09893799e-01,  -1.09893799e-01],
                        [ -9.23767090e-02,  -9.23767090e-02],
                        [ -7.23571777e-02,  -7.23571777e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.19750977e-01,   1.19750977e-01],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [ -8.76770020e-02,  -8.76770020e-02],
                        [ -1.69860840e-01,  -1.69860840e-01],
                        [ -2.06268311e-01,  -2.06268311e-01],
                        [ -1.86950684e-01,  -1.86950684e-01],
                        [ -1.35375977e-01,  -1.35375977e-01],
                        [ -8.80737305e-02,  -8.80737305e-02],
                        [ -6.45751953e-02,  -6.45751953e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  1.45385742e-01,   1.45385742e-01],
                        [  1.57836914e-01,   1.57836914e-01],
                        [  1.50054932e-01,   1.50054932e-01],
                        [  1.29455566e-01,   1.29455566e-01],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  8.66699219e-02,   8.66699219e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  8.06884766e-02,   8.06884766e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -1.94061279e-01,  -1.94061279e-01],
                        [ -2.62756348e-01,  -2.62756348e-01],
                        [ -2.87841797e-01,  -2.87841797e-01],
                        [ -2.65197754e-01,  -2.65197754e-01],
                        [ -2.12677002e-01,  -2.12677002e-01],
                        [ -1.61102295e-01,  -1.61102295e-01],
                        [ -1.31591797e-01,  -1.31591797e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -1.07513428e-01,  -1.07513428e-01],
                        [ -8.35266113e-02,  -8.35266113e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  1.12823486e-01,   1.12823486e-01],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -1.07940674e-01,  -1.07940674e-01],
                        [ -1.58721924e-01,  -1.58721924e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -1.47705078e-01,  -1.47705078e-01],
                        [ -1.14471436e-01,  -1.14471436e-01],
                        [ -9.27734375e-02,  -9.27734375e-02],
                        [ -8.95996094e-02,  -8.95996094e-02],
                        [ -9.33837891e-02,  -9.33837891e-02],
                        [ -8.53576660e-02,  -8.53576660e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.41998291e-01,   1.41998291e-01],
                        [  1.57379150e-01,   1.57379150e-01],
                        [  1.51916504e-01,   1.51916504e-01],
                        [  1.39160156e-01,   1.39160156e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.10839844e-01,   1.10839844e-01],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  9.28344727e-02,   9.28344727e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  7.52868652e-02,   7.52868652e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  6.90307617e-02,   6.90307617e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  7.62023926e-02,   7.62023926e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -2.16064453e-01,  -2.16064453e-01],
                        [ -2.82562256e-01,  -2.82562256e-01],
                        [ -3.00323486e-01,  -3.00323486e-01],
                        [ -2.64892578e-01,  -2.64892578e-01],
                        [ -1.99737549e-01,  -1.99737549e-01],
                        [ -1.40869141e-01,  -1.40869141e-01],
                        [ -1.10107422e-01,  -1.10107422e-01],
                        [ -1.02416992e-01,  -1.02416992e-01],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -8.19702148e-02,  -8.19702148e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  7.87963867e-02,   7.87963867e-02],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  1.36749268e-01,   1.36749268e-01],
                        [  1.23779297e-01,   1.23779297e-01],
                        [  6.95495605e-02,   6.95495605e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -1.17645264e-01,  -1.17645264e-01],
                        [ -1.86309814e-01,  -1.86309814e-01],
                        [ -2.07244873e-01,  -2.07244873e-01],
                        [ -1.85455322e-01,  -1.85455322e-01],
                        [ -1.42791748e-01,  -1.42791748e-01],
                        [ -1.04431152e-01,  -1.04431152e-01],
                        [ -8.15124512e-02,  -8.15124512e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.37481689e-01,   1.37481689e-01],
                        [  1.29302979e-01,   1.29302979e-01],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  1.03240967e-01,   1.03240967e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  1.02142334e-01,   1.02142334e-01],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  4.93164062e-02,   4.93164062e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  9.67102051e-02,   9.67102051e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  8.18176270e-02,   8.18176270e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -1.38793945e-01,  -1.38793945e-01],
                        [ -2.24975586e-01,  -2.24975586e-01],
                        [ -2.80761719e-01,  -2.80761719e-01],
                        [ -2.89825439e-01,  -2.89825439e-01],
                        [ -2.55615234e-01,  -2.55615234e-01],
                        [ -1.99310303e-01,  -1.99310303e-01],
                        [ -1.47766113e-01,  -1.47766113e-01],
                        [ -1.16210938e-01,  -1.16210938e-01],
                        [ -1.01257324e-01,  -1.01257324e-01],
                        [ -9.20410156e-02,  -9.20410156e-02],
                        [ -8.29162598e-02,  -8.29162598e-02],
                        [ -7.14721680e-02,  -7.14721680e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  1.33758545e-01,   1.33758545e-01],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  3.75671387e-02,   3.75671387e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -1.48620605e-01,  -1.48620605e-01],
                        [ -2.07122803e-01,  -2.07122803e-01],
                        [ -2.12585449e-01,  -2.12585449e-01],
                        [ -1.75140381e-01,  -1.75140381e-01],
                        [ -1.21520996e-01,  -1.21520996e-01],
                        [ -7.20825195e-02,  -7.20825195e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  1.03179932e-01,   1.03179932e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.07543945e-01,   1.07543945e-01],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.06414795e-01,   1.06414795e-01],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  8.21228027e-02,   8.21228027e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  8.98742676e-02,   8.98742676e-02],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  1.02264404e-01,   1.02264404e-01],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  4.42199707e-02,   4.42199707e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -1.30950928e-01,  -1.30950928e-01],
                        [ -1.93389893e-01,  -1.93389893e-01],
                        [ -2.37731934e-01,  -2.37731934e-01],
                        [ -2.51770020e-01,  -2.51770020e-01],
                        [ -2.31231689e-01,  -2.31231689e-01],
                        [ -1.90460205e-01,  -1.90460205e-01],
                        [ -1.55212402e-01,  -1.55212402e-01],
                        [ -1.38000488e-01,  -1.38000488e-01],
                        [ -1.29150391e-01,  -1.29150391e-01],
                        [ -1.14440918e-01,  -1.14440918e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.30004883e-01,   1.30004883e-01],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -1.58630371e-01,  -1.58630371e-01],
                        [ -2.03887939e-01,  -2.03887939e-01],
                        [ -1.90429688e-01,  -1.90429688e-01],
                        [ -1.30828857e-01,  -1.30828857e-01],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  6.36596680e-02,   6.36596680e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  1.05651855e-01,   1.05651855e-01],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  7.81250000e-02,   7.81250000e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -1.13433838e-01,  -1.13433838e-01],
                        [ -1.45751953e-01,  -1.45751953e-01],
                        [ -1.70318604e-01,  -1.70318604e-01],
                        [ -1.83258057e-01,  -1.83258057e-01],
                        [ -1.83868408e-01,  -1.83868408e-01],
                        [ -1.75476074e-01,  -1.75476074e-01],
                        [ -1.62567139e-01,  -1.62567139e-01],
                        [ -1.48132324e-01,  -1.48132324e-01],
                        [ -1.31896973e-01,  -1.31896973e-01],
                        [ -1.12274170e-01,  -1.12274170e-01],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -7.08618164e-02,  -7.08618164e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  7.36389160e-02,   7.36389160e-02],
                        [  1.00341797e-01,   1.00341797e-01],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.44714355e-01,   1.44714355e-01],
                        [  1.44989014e-01,   1.44989014e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  6.31408691e-02,   6.31408691e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -1.06048584e-01,  -1.06048584e-01],
                        [ -1.68853760e-01,  -1.68853760e-01],
                        [ -1.84295654e-01,  -1.84295654e-01],
                        [ -1.51245117e-01,  -1.51245117e-01],
                        [ -9.31091309e-02,  -9.31091309e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  9.29260254e-02,   9.29260254e-02],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.11785889e-01,   1.11785889e-01],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  7.96508789e-02,   7.96508789e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -9.80834961e-02,  -9.80834961e-02],
                        [ -1.52374268e-01,  -1.52374268e-01],
                        [ -1.96594238e-01,  -1.96594238e-01],
                        [ -2.17010498e-01,  -2.17010498e-01],
                        [ -2.11822510e-01,  -2.11822510e-01],
                        [ -1.93572998e-01,  -1.93572998e-01],
                        [ -1.74316406e-01,  -1.74316406e-01],
                        [ -1.55456543e-01,  -1.55456543e-01],
                        [ -1.33209229e-01,  -1.33209229e-01],
                        [ -1.08978271e-01,  -1.08978271e-01],
                        [ -8.85009766e-02,  -8.85009766e-02],
                        [ -7.38525391e-02,  -7.38525391e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  8.62426758e-02,   8.62426758e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.44348145e-01,   1.44348145e-01],
                        [  1.31591797e-01,   1.31591797e-01],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -1.41784668e-01,  -1.41784668e-01],
                        [ -1.75079346e-01,  -1.75079346e-01],
                        [ -1.50238037e-01,  -1.50238037e-01],
                        [ -8.09631348e-02,  -8.09631348e-02],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  6.65283203e-02,   6.65283203e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  5.24291992e-02,   5.24291992e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  5.14526367e-02,   5.14526367e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  8.38623047e-02,   8.38623047e-02],
                        [  8.63342285e-02,   8.63342285e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -1.30279541e-01,  -1.30279541e-01],
                        [ -2.06817627e-01,  -2.06817627e-01],
                        [ -2.60375977e-01,  -2.60375977e-01],
                        [ -2.77313232e-01,  -2.77313232e-01],
                        [ -2.55004883e-01,  -2.55004883e-01],
                        [ -2.06970215e-01,  -2.06970215e-01],
                        [ -1.57226562e-01,  -1.57226562e-01],
                        [ -1.23779297e-01,  -1.23779297e-01],
                        [ -1.07666016e-01,  -1.07666016e-01],
                        [ -9.96093750e-02,  -9.96093750e-02],
                        [ -9.29565430e-02,  -9.29565430e-02],
                        [ -8.64257812e-02,  -8.64257812e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -7.77282715e-02,  -7.77282715e-02],
                        [ -1.16546631e-01,  -1.16546631e-01],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.17431641e-01,   1.17431641e-01],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -1.04125977e-01,  -1.04125977e-01],
                        [ -1.78649902e-01,  -1.78649902e-01],
                        [ -2.26409912e-01,  -2.26409912e-01],
                        [ -2.37060547e-01,  -2.37060547e-01],
                        [ -2.17468262e-01,  -2.17468262e-01],
                        [ -1.85699463e-01,  -1.85699463e-01],
                        [ -1.58630371e-01,  -1.58630371e-01],
                        [ -1.41815186e-01,  -1.41815186e-01],
                        [ -1.30004883e-01,  -1.30004883e-01],
                        [ -1.15539551e-01,  -1.15539551e-01],
                        [ -9.73205566e-02,  -9.73205566e-02],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -7.16247559e-02,  -7.16247559e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.37725830e-01,   1.37725830e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -7.22045898e-02,  -7.22045898e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  5.92651367e-02,   5.92651367e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  7.06787109e-02,   7.06787109e-02],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.10809326e-01,   1.10809326e-01],
                        [  7.90405273e-02,   7.90405273e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -1.69189453e-01,  -1.69189453e-01],
                        [ -2.32238770e-01,  -2.32238770e-01],
                        [ -2.56622314e-01,  -2.56622314e-01],
                        [ -2.40753174e-01,  -2.40753174e-01],
                        [ -2.05474854e-01,  -2.05474854e-01],
                        [ -1.74163818e-01,  -1.74163818e-01],
                        [ -1.55090332e-01,  -1.55090332e-01],
                        [ -1.40716553e-01,  -1.40716553e-01],
                        [ -1.21307373e-01,  -1.21307373e-01],
                        [ -9.73815918e-02,  -9.73815918e-02],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  1.13037109e-01,   1.13037109e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.32934570e-01,   1.32934570e-01],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  5.88378906e-02,   5.88378906e-02],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -6.75354004e-02,  -6.75354004e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  4.36401367e-02,   4.36401367e-02],
                        [  5.30700684e-02,   5.30700684e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  1.16760254e-01,   1.16760254e-01],
                        [  1.18804932e-01,   1.18804932e-01],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  8.20007324e-02,   8.20007324e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -2.03704834e-01,  -2.03704834e-01],
                        [ -2.43591309e-01,  -2.43591309e-01],
                        [ -2.52502441e-01,  -2.52502441e-01],
                        [ -2.34466553e-01,  -2.34466553e-01],
                        [ -2.01019287e-01,  -2.01019287e-01],
                        [ -1.66320801e-01,  -1.66320801e-01],
                        [ -1.39648438e-01,  -1.39648438e-01],
                        [ -1.20910645e-01,  -1.20910645e-01],
                        [ -1.04034424e-01,  -1.04034424e-01],
                        [ -8.38317871e-02,  -8.38317871e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  1.49536133e-03,   1.49536133e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  1.38519287e-01,   1.38519287e-01],
                        [  1.80755615e-01,   1.80755615e-01],
                        [  2.14263916e-01,   2.14263916e-01],
                        [  2.22534180e-01,   2.22534180e-01],
                        [  1.90704346e-01,   1.90704346e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  1.21765137e-02,   1.21765137e-02],
                        [ -7.70874023e-02,  -7.70874023e-02],
                        [ -1.16027832e-01,  -1.16027832e-01],
                        [ -9.93957520e-02,  -9.93957520e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.94384766e-02,   4.94384766e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  1.22680664e-01,   1.22680664e-01],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  7.66296387e-02,   7.66296387e-02],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  8.05664062e-02,   8.05664062e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -9.52758789e-02,  -9.52758789e-02],
                        [ -1.82403564e-01,  -1.82403564e-01],
                        [ -2.54608154e-01,  -2.54608154e-01],
                        [ -2.89245605e-01,  -2.89245605e-01],
                        [ -2.74688721e-01,  -2.74688721e-01],
                        [ -2.25677490e-01,  -2.25677490e-01],
                        [ -1.75476074e-01,  -1.75476074e-01],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -1.26922607e-01,  -1.26922607e-01],
                        [ -1.12426758e-01,  -1.12426758e-01],
                        [ -1.00097656e-01,  -1.00097656e-01],
                        [ -9.05761719e-02,  -9.05761719e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  4.27246094e-04,   4.27246094e-04],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  1.59332275e-01,   1.59332275e-01],
                        [  2.10205078e-01,   2.10205078e-01],
                        [  2.55493164e-01,   2.55493164e-01],
                        [  2.77313232e-01,   2.77313232e-01],
                        [  2.56072998e-01,   2.56072998e-01],
                        [  1.79748535e-01,   1.79748535e-01],
                        [  6.11877441e-02,   6.11877441e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -1.35925293e-01,  -1.35925293e-01],
                        [ -1.53320312e-01,  -1.53320312e-01],
                        [ -1.25305176e-01,  -1.25305176e-01],
                        [ -8.16955566e-02,  -8.16955566e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  3.46679688e-02,   3.46679688e-02],
                        [  4.71496582e-02,   4.71496582e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  6.75659180e-02,   6.75659180e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  1.08367920e-01,   1.08367920e-01],
                        [  9.12780762e-02,   9.12780762e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.70898438e-02,   1.70593262e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -3.14331055e-02,  -3.14636230e-02],
                        [ -1.99584961e-02,  -1.99890137e-02],
                        [ -8.05664062e-03,  -8.08715820e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  9.67407227e-03,   9.70458984e-03],
                        [  2.13317871e-02,   2.13623047e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  5.04150391e-02,   5.04150391e-02],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  1.07269287e-01,   1.07269287e-01],
                        [  1.19750977e-01,   1.19750977e-01],
                        [  1.15905762e-01,   1.15875244e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [ -1.02233887e-02,  -1.01623535e-02],
                        [ -8.22753906e-02,  -8.22143555e-02],
                        [ -1.66412354e-01,  -1.66381836e-01],
                        [ -2.42218018e-01,  -2.42248535e-01],
                        [ -2.81829834e-01,  -2.81890869e-01],
                        [ -2.74871826e-01,  -2.74932861e-01],
                        [ -2.36358643e-01,  -2.36389160e-01],
                        [ -1.92230225e-01,  -1.92199707e-01],
                        [ -1.60003662e-01,  -1.59973145e-01],
                        [ -1.40625000e-01,  -1.40594482e-01],
                        [ -1.24816895e-01,  -1.24786377e-01],
                        [ -1.06719971e-01,  -1.06689453e-01],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -7.55615234e-02,  -7.56225586e-02],
                        [ -6.49108887e-02,  -6.49414062e-02],
                        [ -5.41076660e-02,  -5.41381836e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -2.87170410e-02,  -2.86865234e-02],
                        [ -1.61132812e-02,  -1.60827637e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.32751465e-02,   1.32446289e-02],
                        [  1.33972168e-02,   1.33361816e-02],
                        [  8.51440430e-03,   8.48388672e-03],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [ -4.82177734e-03,  -4.76074219e-03],
                        [ -1.19018555e-03,  -1.12915039e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  3.99780273e-03,   3.96728516e-03],
                        [ -3.44848633e-03,  -3.50952148e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [  1.30615234e-02,   1.30920410e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  1.45965576e-01,   1.45935059e-01],
                        [  2.28485107e-01,   2.28454590e-01],
                        [  2.93121338e-01,   2.93151855e-01],
                        [  3.25042725e-01,   3.25134277e-01],
                        [  3.16772461e-01,   3.16833496e-01],
                        [  2.63671875e-01,   2.63641357e-01],
                        [  1.67541504e-01,   1.67419434e-01],
                        [  4.47082520e-02,   4.45556641e-02],
                        [ -7.37304688e-02,  -7.37609863e-02],
                        [ -1.52709961e-01,  -1.52618408e-01],
                        [ -1.71295166e-01,  -1.71142578e-01],
                        [ -1.37725830e-01,  -1.37603760e-01],
                        [ -8.55102539e-02,  -8.55407715e-02],
                        [ -4.73632812e-02,  -4.74548340e-02],
                        [ -3.14331055e-02,  -3.15856934e-02],
                        [ -2.70080566e-02,  -2.70690918e-02],
                        [ -2.56347656e-02,  -2.56042480e-02],
                        [ -2.82592773e-02,  -2.81066895e-02],
                        [ -3.53698730e-02,  -3.52478027e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -3.23181152e-02,  -3.24096680e-02],
                        [ -7.78198242e-03,  -7.90405273e-03],
                        [  2.40173340e-02,   2.39868164e-02],
                        [  4.86145020e-02,   4.87060547e-02],
                        [  6.06689453e-02,   6.08215332e-02],
                        [  6.43615723e-02,   6.44531250e-02],
                        [  6.17675781e-02,   6.17065430e-02],
                        [  5.01098633e-02,   4.99267578e-02],
                        [  2.99072266e-02,   2.97241211e-02],
                        [  8.57543945e-03,   8.51440430e-03],
                        [ -5.88989258e-03,  -5.79833984e-03],
                        [ -1.08032227e-02,  -1.05590820e-02],
                        [ -9.15527344e-03,  -8.94165039e-03],
                        [ -5.95092773e-03,  -5.88989258e-03],
                        [ -3.60107422e-03,  -3.78417969e-03],
                        [ -2.74658203e-03,  -3.05175781e-03],
                        [ -5.49316406e-03,  -5.73730469e-03],
                        [ -1.33972168e-02,  -1.34277344e-02],
                        [ -2.38952637e-02,  -2.36511230e-02],
                        [ -3.37219238e-02,  -3.33862305e-02],
                        [ -4.21142578e-02,  -4.19006348e-02],
                        [ -4.72412109e-02,  -4.73327637e-02],
                        [ -4.38232422e-02,  -4.40673828e-02],
                        [ -2.54821777e-02,  -2.56958008e-02],
                        [  1.10473633e-02,   1.09558105e-02],
                        [  6.06994629e-02,   6.07910156e-02],
                        [  1.06811523e-01,   1.06903076e-01],
                        [  1.30187988e-01,   1.30249023e-01],
                        [  1.25823975e-01,   1.25793457e-01],
                        [  1.04553223e-01,   1.04522705e-01],
                        [  8.00170898e-02,   8.00170898e-02],
                        [  6.03637695e-02,   6.03942871e-02],
                        [  4.79431152e-02,   4.80346680e-02],
                        [  3.89099121e-02,   3.89709473e-02],
                        [  2.78015137e-02,   2.77404785e-02],
                        [  1.55334473e-02,   1.52893066e-02],
                        [  6.80541992e-03,   6.50024414e-03],
                        [  9.46044922e-04,   8.54492188e-04],
                        [ -7.99560547e-03,  -7.78198242e-03],
                        [ -2.26440430e-02,  -2.22167969e-02],
                        [ -3.65905762e-02,  -3.62548828e-02],
                        [ -3.96118164e-02,  -3.95812988e-02],
                        [ -2.85339355e-02,  -2.88696289e-02],
                        [ -1.06201172e-02,  -1.11083984e-02],
                        [  5.03540039e-03,   4.73022461e-03],
                        [  1.52587891e-02,   1.53503418e-02],
                        [  2.15454102e-02,   2.19421387e-02],
                        [  2.63977051e-02,   2.67333984e-02],
                        [  3.21044922e-02,   3.21960449e-02],
                        [  3.88183594e-02,   3.86657715e-02],
                        [  4.42504883e-02,   4.40673828e-02],
                        [  5.02929688e-02,   5.02624512e-02],
                        [  6.42700195e-02,   6.43615723e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  1.10229492e-01,   1.10046387e-01],
                        [  1.18560791e-01,   1.18347168e-01],
                        [  1.05041504e-01,   1.04980469e-01],
                        [  6.87255859e-02,   6.89392090e-02],
                        [  1.37329102e-02,   1.40686035e-02],
                        [ -5.55725098e-02,  -5.52673340e-02],
                        [ -1.36688232e-01,  -1.36627197e-01],
                        [ -2.19879150e-01,  -2.20092773e-01],
                        [ -2.81188965e-01,  -2.81555176e-01],
                        [ -2.95806885e-01,  -2.96142578e-01],
                        [ -2.60437012e-01,  -2.60620117e-01],
                        [ -1.98669434e-01,  -1.98577881e-01],
                        [ -1.42944336e-01,  -1.42517090e-01],
                        [ -1.13098145e-01,  -1.12548828e-01],
                        [ -1.08123779e-01,  -1.07788086e-01],
                        [ -1.11938477e-01,  -1.12121582e-01],
                        [ -1.08398438e-01,  -1.09039307e-01],
                        [ -9.54589844e-02,  -9.60388184e-02],
                        [ -8.24584961e-02,  -8.25805664e-02],
                        [ -7.26623535e-02,  -7.22656250e-02],
                        [ -5.67321777e-02,  -5.61523438e-02],
                        [ -2.85034180e-02,  -2.81982422e-02],
                        [  2.34985352e-03,   2.13623047e-03],
                        [  2.17285156e-02,   2.12707520e-02],
                        [  2.71606445e-02,   2.69165039e-02],
                        [  2.37426758e-02,   2.38952637e-02],
                        [  1.23291016e-02,   1.26647949e-02],
                        [ -7.47680664e-03,  -7.26318359e-03],
                        [ -2.77404785e-02,  -2.78625488e-02],
                        [ -3.62854004e-02,  -3.65905762e-02],
                        [ -3.08227539e-02,  -3.10974121e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.24206543e-02,  -1.21765137e-02],
                        [ -5.70678711e-03,  -5.46264648e-03],
                        [ -1.67846680e-03,  -1.61743164e-03],
                        [ -4.05883789e-03,  -4.08935547e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [  6.34765625e-03,   6.22558594e-03],
                        [  3.59497070e-02,   3.56750488e-02],
                        [  8.39843750e-02,   8.37402344e-02],
                        [  1.50665283e-01,   1.50665283e-01],
                        [  2.23937988e-01,   2.24334717e-01],
                        [  2.82806396e-01,   2.83416748e-01],
                        [  3.11157227e-01,   3.11523438e-01],
                        [  3.05328369e-01,   3.05053711e-01],
                        [  2.69805908e-01,   2.69073486e-01],
                        [  2.08984375e-01,   2.08343506e-01],
                        [  1.23870850e-01,   1.23870850e-01],
                        [  1.95617676e-02,   2.01416016e-02],
                        [ -8.41979980e-02,  -8.35571289e-02],
                        [ -1.55609131e-01,  -1.55364990e-01],
                        [ -1.70349121e-01,  -1.70593262e-01],
                        [ -1.32873535e-01,  -1.33270264e-01],
                        [ -7.76672363e-02,  -7.79113770e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -3.61022949e-02,  -3.59802246e-02],
                        [ -4.32739258e-02,  -4.31518555e-02],
                        [ -4.94384766e-02,  -4.93469238e-02],
                        [ -5.52368164e-02,  -5.51757812e-02],
                        [ -6.30187988e-02,  -6.30493164e-02],
                        [ -6.49414062e-02,  -6.51245117e-02],
                        [ -5.06286621e-02,  -5.08117676e-02],
                        [ -1.97143555e-02,  -1.96838379e-02],
                        [  1.75170898e-02,   1.77917480e-02],
                        [  4.80957031e-02,   4.84313965e-02],
                        [  6.35375977e-02,   6.36596680e-02],
                        [  6.33850098e-02,   6.31103516e-02],
                        [  5.37109375e-02,   5.31616211e-02],
                        [  4.08630371e-02,   4.03747559e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  1.16882324e-02,   1.22680664e-02],
                        [ -1.83105469e-03,  -1.00708008e-03],
                        [ -8.54492188e-03,  -8.08715820e-03],
                        [ -8.54492188e-03,  -8.78906250e-03],
                        [ -8.81958008e-03,  -9.70458984e-03],
                        [ -1.43127441e-02,  -1.51977539e-02],
                        [ -2.13012695e-02,  -2.15148926e-02],
                        [ -2.45056152e-02,  -2.39257812e-02],
                        [ -2.54821777e-02,  -2.46276855e-02],
                        [ -2.95410156e-02,  -2.90832520e-02],
                        [ -3.78723145e-02,  -3.80554199e-02],
                        [ -4.55017090e-02,  -4.59594727e-02],
                        [ -4.46777344e-02,  -4.49523926e-02],
                        [ -2.90832520e-02,  -2.90527344e-02],
                        [  2.07519531e-03,   2.25830078e-03],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  8.30688477e-02,   8.27941895e-02],
                        [  1.11389160e-01,   1.11022949e-01],
                        [  1.19018555e-01,   1.19018555e-01],
                        [  1.03973389e-01,   1.04431152e-01],
                        [  7.42797852e-02,   7.49511719e-02],
                        [  4.50744629e-02,   4.55017090e-02],
                        [  2.71301270e-02,   2.69775391e-02],
                        [  1.95007324e-02,   1.87988281e-02],
                        [  1.60217285e-02,   1.51367188e-02],
                        [  1.38854980e-02,   1.33972168e-02],
                        [  1.15661621e-02,   1.17492676e-02],
                        [  6.25610352e-03,   6.95800781e-03],
                        [ -1.70898438e-03,  -7.93457031e-04],
                        [ -7.90405273e-03,  -7.26318359e-03],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -7.72094727e-03,  -8.45336914e-03],
                        [ -4.97436523e-03,  -6.07299805e-03],
                        [ -3.44848633e-03,  -4.18090820e-03],
                        [ -4.39453125e-03,  -4.21142578e-03],
                        [ -7.01904297e-03,  -6.10351562e-03],
                        [ -7.96508789e-03,  -7.01904297e-03],
                        [ -3.20434570e-03,  -2.99072266e-03],
                        [  8.85009766e-03,   8.23974609e-03],
                        [  2.67944336e-02,   2.60620117e-02],
                        [  4.67224121e-02,   4.66003418e-02],
                        [  6.44531250e-02,   6.49414062e-02],
                        [  7.87963867e-02,   7.93457031e-02],
                        [  9.11254883e-02,   9.12170410e-02],
                        [  1.02600098e-01,   1.02050781e-01],
                        [  1.12213135e-01,   1.11358643e-01],
                        [  1.12060547e-01,   1.11602783e-01],
                        [  8.63647461e-02,   8.67004395e-02],
                        [  2.42004395e-02,   2.52685547e-02],
                        [ -6.66198730e-02,  -6.54602051e-02],
                        [ -1.64581299e-01,  -1.64093018e-01],
                        [ -2.48443604e-01,  -2.49084473e-01],
                        [ -3.00445557e-01,  -3.02032471e-01],
                        [ -3.06121826e-01,  -3.07708740e-01],
                        [ -2.66357422e-01,  -2.66693115e-01],
                        [ -2.07519531e-01,  -2.06207275e-01],
                        [ -1.63085938e-01,  -1.61010742e-01],
                        [ -1.41632080e-01,  -1.40350342e-01],
                        [ -1.25061035e-01,  -1.25488281e-01],
                        [ -9.82055664e-02,  -9.99145508e-02],
                        [ -6.79321289e-02,  -6.96411133e-02],
                        [ -5.07202148e-02,  -5.12084961e-02],
                        [ -5.12390137e-02,  -5.02014160e-02],
                        [ -5.80749512e-02,  -5.63964844e-02],
                        [ -5.66406250e-02,  -5.56945801e-02],
                        [ -4.27246094e-02,  -4.32739258e-02],
                        [ -2.44140625e-02,  -2.58178711e-02],
                        [ -1.15661621e-02,  -1.26037598e-02],
                        [ -5.58471680e-03,  -5.37109375e-03],
                        [ -1.34277344e-03,  -1.52587891e-04],
                        [  3.17382812e-03,   4.36401367e-03],
                        [  4.08935547e-03,   4.30297852e-03],
                        [ -2.59399414e-03,  -3.57055664e-03],
                        [ -1.52282715e-02,  -1.65710449e-02],
                        [ -2.73742676e-02,  -2.80151367e-02],
                        [ -3.45458984e-02,  -3.40881348e-02],
                        [ -3.73840332e-02,  -3.63159180e-02],
                        [ -3.77197266e-02,  -3.68041992e-02],
                        [ -3.58886719e-02,  -3.56445312e-02],
                        [ -3.22265625e-02,  -3.26538086e-02],
                        [ -2.52075195e-02,  -2.58789062e-02],
                        [ -8.20922852e-03,  -8.75854492e-03],
                        [  2.61840820e-02,   2.58789062e-02],
                        [  7.81555176e-02,   7.81250000e-02],
                        [  1.39587402e-01,   1.39984131e-01],
                        [  1.99279785e-01,   2.00042725e-01],
                        [  2.46093750e-01,   2.46704102e-01],
                        [  2.70141602e-01,   2.70019531e-01],
                        [  2.68096924e-01,   2.67364502e-01],
                        [  2.48229980e-01,   2.47619629e-01],
                        [  2.25067139e-01,   2.25097656e-01],
                        [  2.04406738e-01,   2.04895020e-01],
                        [  1.75140381e-01,   1.75476074e-01],
                        [  1.19628906e-01,   1.19354248e-01],
                        [  3.38745117e-02,   3.32946777e-02],
                        [ -6.28051758e-02,  -6.29577637e-02],
                        [ -1.37573242e-01,  -1.36901855e-01],
                        [ -1.66748047e-01,  -1.65710449e-01],
                        [ -1.53381348e-01,  -1.53106689e-01],
                        [ -1.22131348e-01,  -1.23016357e-01],
                        [ -9.59167480e-02,  -9.72290039e-02],
                        [ -8.08715820e-02,  -8.13598633e-02],
                        [ -7.09838867e-02,  -7.01904297e-02],
                        [ -5.94787598e-02,  -5.81665039e-02],
                        [ -4.41284180e-02,  -4.34875488e-02],
                        [ -2.67639160e-02,  -2.73742676e-02],
                        [ -1.24816895e-02,  -1.37023926e-02],
                        [ -5.55419922e-03,  -6.10351562e-03],
                        [ -2.80761719e-03,  -2.07519531e-03],
                        [  4.05883789e-03,   5.37109375e-03],
                        [  1.58691406e-02,   1.63574219e-02],
                        [  2.39868164e-02,   2.30102539e-02],
                        [  2.45056152e-02,   2.28576660e-02],
                        [  2.43530273e-02,   2.35595703e-02],
                        [  2.75878906e-02,   2.85339355e-02],
                        [  2.67333984e-02,   2.86254883e-02],
                        [  1.62048340e-02,   1.74560547e-02],
                        [  3.69262695e-03,   3.23486328e-03],
                        [ -3.41796875e-03,  -5.03540039e-03],
                        [ -9.97924805e-03,  -1.13220215e-02],
                        [ -1.97143555e-02,  -1.98364258e-02],
                        [ -2.42309570e-02,  -2.34375000e-02],
                        [ -1.96228027e-02,  -1.87683105e-02],
                        [ -1.89514160e-02,  -1.86462402e-02],
                        [ -3.29895020e-02,  -3.31115723e-02],
                        [ -5.08728027e-02,  -5.09948730e-02],
                        [ -5.39245605e-02,  -5.37414551e-02],
                        [ -3.93066406e-02,  -3.90930176e-02],
                        [ -1.84936523e-02,  -1.87072754e-02],
                        [  1.89208984e-03,   1.15966797e-03],
                        [  2.57568359e-02,   2.49938965e-02],
                        [  5.53894043e-02,   5.51757812e-02],
                        [  8.32824707e-02,   8.38012695e-02],
                        [  9.89685059e-02,   1.00036621e-01],
                        [  9.88464355e-02,   9.98840332e-02],
                        [  8.63342285e-02,   8.66699219e-02],
                        [  6.86035156e-02,   6.79626465e-02],
                        [  5.35583496e-02,   5.22766113e-02],
                        [  4.32739258e-02,   4.22363281e-02],
                        [  3.26232910e-02,   3.24401855e-02],
                        [  1.92260742e-02,   1.97143555e-02],
                        [  9.27734375e-03,   1.01013184e-02],
                        [  8.27026367e-03,   9.12475586e-03],
                        [  1.09252930e-02,   1.15356445e-02],
                        [  8.17871094e-03,   8.23974609e-03],
                        [ -5.49316406e-04,  -1.22070312e-03],
                        [ -9.70458984e-03,  -1.08947754e-02],
                        [ -1.71813965e-02,  -1.81884766e-02],
                        [ -2.21862793e-02,  -2.21252441e-02],
                        [ -1.97753906e-02,  -1.85546875e-02],
                        [ -6.65283203e-03,  -5.24902344e-03],
                        [  1.20544434e-02,   1.23596191e-02],
                        [  2.72827148e-02,   2.61840820e-02],
                        [  3.52478027e-02,   3.38134766e-02],
                        [  4.06799316e-02,   4.02526855e-02],
                        [  5.07812500e-02,   5.18188477e-02],
                        [  6.78710938e-02,   6.95190430e-02],
                        [  8.98437500e-02,   9.06677246e-02],
                        [  1.13494873e-01,   1.12670898e-01],
                        [  1.33880615e-01,   1.31927490e-01],
                        [  1.42669678e-01,   1.41082764e-01],
                        [  1.29455566e-01,   1.29516602e-01],
                        [  8.61511230e-02,   8.78601074e-02],
                        [  1.11999512e-02,   1.33666992e-02],
                        [ -8.81347656e-02,  -8.70361328e-02],
                        [ -1.93572998e-01,  -1.94152832e-01],
                        [ -2.76580811e-01,  -2.78472900e-01],
                        [ -3.11889648e-01,  -3.13934326e-01],
                        [ -2.94219971e-01,  -2.95074463e-01],
                        [ -2.41516113e-01,  -2.40631104e-01],
                        [ -1.83349609e-01,  -1.81365967e-01],
                        [ -1.41845703e-01,  -1.40136719e-01],
                        [ -1.17828369e-01,  -1.17492676e-01],
                        [ -9.81750488e-02,  -9.93347168e-02],
                        [ -7.68127441e-02,  -7.86132812e-02],
                        [ -6.21337891e-02,  -6.32629395e-02],
                        [ -6.30187988e-02,  -6.25915527e-02],
                        [ -7.40356445e-02,  -7.23876953e-02],
                        [ -7.88879395e-02,  -7.74230957e-02],
                        [ -6.70166016e-02,  -6.71081543e-02],
                        [ -4.16564941e-02,  -4.32739258e-02],
                        [ -1.25122070e-02,  -1.42517090e-02],
                        [  1.21459961e-02,   1.19018555e-02],
                        [  2.78625488e-02,   2.94799805e-02],
                        [  3.42712402e-02,   3.64685059e-02],
                        [  3.10058594e-02,   3.18908691e-02],
                        [  1.49230957e-02,   1.37329102e-02],
                        [ -1.24206543e-02,  -1.47399902e-02],
                        [ -3.85742188e-02,  -4.02221680e-02],
                        [ -5.07507324e-02,  -5.05371094e-02],
                        [ -4.93774414e-02,  -4.75463867e-02],
                        [ -4.52575684e-02,  -4.32434082e-02],
                        [ -4.51660156e-02,  -4.44641113e-02],
                        [ -4.44335938e-02,  -4.54101562e-02],
                        [ -3.39660645e-02,  -3.57666016e-02],
                        [ -1.04675293e-02,  -1.15661621e-02],
                        [  2.52075195e-02,   2.55737305e-02],
                        [  7.44934082e-02,   7.58361816e-02],
                        [  1.36566162e-01,   1.37603760e-01],
                        [  1.97875977e-01,   1.97692871e-01],
                        [  2.36145020e-01,   2.34954834e-01],
                        [  2.40417480e-01,   2.39349365e-01],
                        [  2.23571777e-01,   2.23632812e-01],
                        [  2.09594727e-01,   2.10784912e-01],
                        [  2.09533691e-01,   2.10968018e-01],
                        [  2.14599609e-01,   2.15179443e-01],
                        [  2.09320068e-01,   2.08465576e-01],
                        [  1.83197021e-01,   1.81304932e-01],
                        [  1.32110596e-01,   1.30432129e-01],
                        [  5.78918457e-02,   5.77392578e-02],
                        [ -2.87475586e-02,  -2.70080566e-02],
                        [ -1.07635498e-01,  -1.05072021e-01],
                        [ -1.56616211e-01,  -1.55120850e-01],
                        [ -1.64123535e-01,  -1.65008545e-01],
                        [ -1.37542725e-01,  -1.40350342e-01],
                        [ -9.99450684e-02,  -1.02447510e-01],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -6.57348633e-02,  -6.32324219e-02],
                        [ -6.12182617e-02,  -5.85937500e-02],
                        [ -5.01098633e-02,  -4.98046875e-02],
                        [ -3.45764160e-02,  -3.66516113e-02],
                        [ -2.01721191e-02,  -2.24304199e-02],
                        [ -7.69042969e-03,  -7.87353516e-03],
                        [  4.08935547e-03,   6.10351562e-03],
                        [  1.51977539e-02,   1.73645020e-02],
                        [  2.42919922e-02,   2.43530273e-02],
                        [  2.89611816e-02,   2.66113281e-02],
                        [  2.78015137e-02,   2.52380371e-02],
                        [  2.30102539e-02,   2.27050781e-02],
                        [  1.92565918e-02,   2.14538574e-02],
                        [  2.01721191e-02,   2.28576660e-02],
                        [  2.49023438e-02,   2.59094238e-02],
                        [  2.63977051e-02,   2.53295898e-02],
                        [  1.66320801e-02,   1.46179199e-02],
                        [ -4.15039062e-03,  -5.70678711e-03],
                        [ -2.64587402e-02,  -2.68859863e-02],
                        [ -4.18701172e-02,  -4.12597656e-02],
                        [ -4.94384766e-02,  -4.82482910e-02],
                        [ -5.18188477e-02,  -5.06591797e-02],
                        [ -5.02014160e-02,  -4.94689941e-02],
                        [ -4.41589355e-02,  -4.41284180e-02],
                        [ -3.40881348e-02,  -3.49121094e-02],
                        [ -2.14538574e-02,  -2.27355957e-02],
                        [ -6.53076172e-03,  -7.44628906e-03],
                        [  1.17187500e-02,   1.16882324e-02],
                        [  3.41796875e-02,   3.49121094e-02],
                        [  6.10046387e-02,   6.18591309e-02],
                        [  8.81958008e-02,   8.86535645e-02],
                        [  1.04888916e-01,   1.04827881e-01],
                        [  1.01501465e-01,   1.01226807e-01],
                        [  8.05664062e-02,   8.05053711e-02],
                        [  5.48095703e-02,   5.50537109e-02],
                        [  3.49426270e-02,   3.50646973e-02],
                        [  2.34069824e-02,   2.27966309e-02],
                        [  1.74865723e-02,   1.62963867e-02],
                        [  1.51367188e-02,   1.43432617e-02],
                        [  1.65100098e-02,   1.71203613e-02],
                        [  2.06909180e-02,   2.26440430e-02],
                        [  2.27050781e-02,   2.45666504e-02],
                        [  1.68151855e-02,   1.69372559e-02],
                        [  4.15039062e-03,   2.22778320e-03],
                        [ -8.11767578e-03,  -1.05590820e-02],
                        [ -1.55334473e-02,  -1.64794922e-02],
                        [ -1.82189941e-02,  -1.69067383e-02],
                        [ -1.61437988e-02,  -1.38244629e-02],
                        [ -1.01928711e-02,  -9.00268555e-03],
                        [ -3.38745117e-03,  -4.27246094e-03],
                        [  4.54711914e-03,   2.62451172e-03],
                        [  1.78222656e-02,   1.67846680e-02],
                        [  3.80554199e-02,   3.88793945e-02],
                        [  6.23779297e-02,   6.41784668e-02],
                        [  8.89587402e-02,   8.99963379e-02],
                        [  1.19140625e-01,   1.18499756e-01],
                        [  1.49444580e-01,   1.47827148e-01],
                        [  1.66625977e-01,   1.65435791e-01],
                        [  1.57745361e-01,   1.57684326e-01],
                        [  1.20849609e-01,   1.21734619e-01],
                        [  5.92346191e-02,   6.02722168e-02],
                        [ -2.66418457e-02,  -2.59094238e-02],
                        [ -1.30676270e-01,  -1.30432129e-01],
                        [ -2.30712891e-01,  -2.30957031e-01],
                        [ -2.95501709e-01,  -2.96234131e-01],
                        [ -3.05236816e-01,  -3.06335449e-01],
                        [ -2.65411377e-01,  -2.66296387e-01],
                        [ -2.03857422e-01,  -2.03826904e-01],
                        [ -1.53839111e-01,  -1.52618408e-01],
                        [ -1.32446289e-01,  -1.30798340e-01],
                        [ -1.30920410e-01,  -1.30279541e-01],
                        [ -1.28936768e-01,  -1.30004883e-01],
                        [ -1.15844727e-01,  -1.17736816e-01],
                        [ -9.47265625e-02,  -9.55810547e-02],
                        [ -7.21740723e-02,  -7.10449219e-02],
                        [ -5.13000488e-02,  -4.92553711e-02],
                        [ -3.12805176e-02,  -3.03344727e-02],
                        [ -1.18713379e-02,  -1.31530762e-02],
                        [  9.76562500e-04,  -1.49536133e-03],
                        [  5.79833984e-04,  -8.54492188e-04],
                        [ -9.58251953e-03,  -8.54492188e-03],
                        [ -1.74865723e-02,  -1.48010254e-02],
                        [ -1.65405273e-02,  -1.44348145e-02],
                        [ -1.27563477e-02,  -1.29089355e-02],
                        [ -1.51977539e-02,  -1.72729492e-02],
                        [ -2.31323242e-02,  -2.53295898e-02],
                        [ -2.88696289e-02,  -2.96020508e-02],
                        [ -3.12194824e-02,  -3.03649902e-02],
                        [ -3.61328125e-02,  -3.47595215e-02],
                        [ -4.34875488e-02,  -4.27551270e-02],
                        [ -4.39147949e-02,  -4.40063477e-02],
                        [ -3.00598145e-02,  -3.03649902e-02],
                        [ -4.18090820e-03,  -4.08935547e-03],
                        [  2.72827148e-02,   2.75878906e-02],
                        [  6.17065430e-02,   6.17675781e-02],
                        [  1.01196289e-01,   1.00677490e-01],
                        [  1.46392822e-01,   1.45385742e-01],
                        [  1.91162109e-01,   1.90277100e-01],
                        [  2.22930908e-01,   2.22961426e-01],
                        [  2.31231689e-01,   2.32299805e-01],
                        [  2.19299316e-01,   2.20825195e-01],
                        [  2.04223633e-01,   2.05230713e-01],
                        [  2.00195312e-01,   2.00164795e-01],
                        [  2.05810547e-01,   2.04925537e-01],
                        [  2.08557129e-01,   2.07122803e-01],
                        [  1.94213867e-01,   1.92749023e-01],
                        [  1.52862549e-01,   1.52069092e-01],
                        [  8.20617676e-02,   8.25805664e-02],
                        [ -1.02539062e-02,  -8.33129883e-03],
                        [ -1.04187012e-01,  -1.01684570e-01],
                        [ -1.72790527e-01,  -1.71447754e-01],
                        [ -1.97143555e-01,  -1.98425293e-01],
                        [ -1.80145264e-01,  -1.83532715e-01],
                        [ -1.45080566e-01,  -1.47888184e-01],
                        [ -1.17553711e-01,  -1.17126465e-01],
                        [ -1.04187012e-01,  -1.00891113e-01],
                        [ -9.02099609e-02,  -8.71887207e-02],
                        [ -6.06994629e-02,  -6.07910156e-02],
                        [ -2.01416016e-02,  -2.29797363e-02],
                        [  1.36108398e-02,   1.09558105e-02],
                        [  2.97546387e-02,   2.99987793e-02],
                        [  3.23486328e-02,   3.53393555e-02],
                        [  2.83203125e-02,   3.10974121e-02],
                        [  1.81884766e-02,   1.77612305e-02],
                        [  3.14331055e-03,  -3.66210938e-04],
                        [ -9.88769531e-03,  -1.33056641e-02],
                        [ -1.66625977e-02,  -1.66931152e-02],
                        [ -1.79748535e-02,  -1.45568848e-02],
                        [ -1.29394531e-02,  -9.06372070e-03],
                        [ -1.98364258e-03,  -7.62939453e-04],
                        [  5.73730469e-03,   3.63159180e-03],
                        [  1.12915039e-03,  -2.41088867e-03],
                        [ -1.06201172e-02,  -1.30615234e-02],
                        [ -1.68762207e-02,  -1.66931152e-02],
                        [ -1.54418945e-02,  -1.30920410e-02],
                        [ -1.47705078e-02,  -1.20849609e-02],
                        [ -1.95922852e-02,  -1.83410645e-02],
                        [ -2.61230469e-02,  -2.69775391e-02],
                        [ -3.08532715e-02,  -3.29589844e-02],
                        [ -3.52783203e-02,  -3.70483398e-02],
                        [ -4.00390625e-02,  -4.01000977e-02],
                        [ -3.77502441e-02,  -3.61938477e-02],
                        [ -1.68457031e-02,  -1.51062012e-02],
                        [  2.48107910e-02,   2.50549316e-02],
                        [  7.29980469e-02,   7.14416504e-02],
                        [  1.06842041e-01,   1.04858398e-01],
                        [  1.14776611e-01,   1.14227295e-01],
                        [  1.00921631e-01,   1.02569580e-01],
                        [  7.91015625e-02,   8.18176270e-02],
                        [  6.22558594e-02,   6.37817383e-02],
                        [  5.42602539e-02,   5.31311035e-02],
                        [  4.77294922e-02,   4.45861816e-02],
                        [  3.20434570e-02,   2.92053223e-02],
                        [  6.77490234e-03,   6.40869141e-03],
                        [ -1.68762207e-02,  -1.43127441e-02],
                        [ -2.80456543e-02,  -2.43835449e-02],
                        [ -2.44750977e-02,  -2.25524902e-02],
                        [ -1.10473633e-02,  -1.24511719e-02],
                        [  2.50244141e-03,  -1.00708008e-03],
                        [  6.19506836e-03,   3.57055664e-03],
                        [ -1.80053711e-03,  -1.40380859e-03],
                        [ -1.15356445e-02,  -8.69750977e-03],
                        [ -1.14135742e-02,  -8.75854492e-03],
                        [ -1.86157227e-03,  -1.70898438e-03],
                        [  8.02612305e-03,   5.61523438e-03],
                        [  1.62658691e-02,   1.35192871e-02],
                        [  2.96630859e-02,   2.89916992e-02],
                        [  5.13305664e-02,   5.32226562e-02],
                        [  7.72705078e-02,   8.03527832e-02],
                        [  1.02691650e-01,   1.04644775e-01],
                        [  1.23352051e-01,   1.22741699e-01],
                        [  1.35070801e-01,   1.32171631e-01],
                        [  1.34094238e-01,   1.30706787e-01],
                        [  1.16058350e-01,   1.14562988e-01],
                        [  7.71789551e-02,   7.86743164e-02],
                        [  1.79443359e-02,   2.15148926e-02],
                        [ -5.71899414e-02,  -5.38635254e-02],
                        [ -1.42486572e-01,  -1.41448975e-01],
                        [ -2.26257324e-01,  -2.28210449e-01],
                        [ -2.85491943e-01,  -2.89306641e-01],
                        [ -2.97027588e-01,  -3.00140381e-01],
                        [ -2.62023926e-01,  -2.62176514e-01],
                        [ -2.10144043e-01,  -2.07275391e-01],
                        [ -1.70532227e-01,  -1.66961670e-01],
                        [ -1.46026611e-01,  -1.44500732e-01],
                        [ -1.23565674e-01,  -1.25061035e-01],
                        [ -9.85717773e-02,  -1.01562500e-01],
                        [ -7.72705078e-02,  -7.91931152e-02],
                        [ -6.31713867e-02,  -6.23779297e-02],
                        [ -5.34362793e-02,  -5.07202148e-02],
                        [ -4.51354980e-02,  -4.30603027e-02],
                        [ -3.55834961e-02,  -3.61633301e-02],
                        [ -2.05993652e-02,  -2.32849121e-02],
                        [ -9.15527344e-04,  -3.23486328e-03],
                        [  1.32751465e-02,   1.31530762e-02],
                        [  1.19628906e-02,   1.38854980e-02],
                        [ -2.99072266e-03,  -6.40869141e-04],
                        [ -2.10571289e-02,  -1.97143555e-02],
                        [ -3.32946777e-02,  -3.34167480e-02],
                        [ -3.63769531e-02,  -3.75976562e-02],
                        [ -3.16772461e-02,  -3.33557129e-02],
                        [ -2.55737305e-02,  -2.72216797e-02],
                        [ -2.80456543e-02,  -2.90527344e-02],
                        [ -4.32434082e-02,  -4.28161621e-02],
                        [ -6.04553223e-02,  -5.83496094e-02],
                        [ -6.17065430e-02,  -5.90820312e-02],
                        [ -3.94287109e-02,  -3.80859375e-02],
                        [ -1.37329102e-03,  -2.10571289e-03],
                        [  4.25720215e-02,   4.04357910e-02],
                        [  9.18273926e-02,   8.96301270e-02],
                        [  1.49169922e-01,   1.48040771e-01],
                        [  2.04925537e-01,   2.05383301e-01],
                        [  2.37060547e-01,   2.38677979e-01],
                        [  2.34130859e-01,   2.35687256e-01],
                        [  2.10479736e-01,   2.10937500e-01],
                        [  1.89910889e-01,   1.89453125e-01],
                        [  1.81884766e-01,   1.81488037e-01],
                        [  1.81060791e-01,   1.81335449e-01],
                        [  1.81823730e-01,   1.82128906e-01],
                        [  1.81274414e-01,   1.80603027e-01],
                        [  1.72271729e-01,   1.70379639e-01],
                        [  1.42547607e-01,   1.40747070e-01],
                        [  8.29467773e-02,   8.32214355e-02],
                        [ -3.66210938e-03,  -6.40869141e-04],
                        [ -9.79003906e-02,  -9.41772461e-02],
                        [ -1.71081543e-01,  -1.69982910e-01],
                        [ -2.01934814e-01,  -2.04772949e-01],
                        [ -1.88751221e-01,  -1.93206787e-01],
                        [ -1.48773193e-01,  -1.50970459e-01],
                        [ -1.07208252e-01,  -1.05377197e-01],
                        [ -7.94067383e-02,  -7.54394531e-02],
                        [ -6.11267090e-02,  -5.87768555e-02],
                        [ -4.07104492e-02,  -4.19006348e-02],
                        [ -1.79138184e-02,  -2.11181641e-02],
                        [ -4.60815430e-03,  -6.40869141e-03],
                        [ -8.42285156e-03,  -7.04956055e-03],
                        [ -2.11791992e-02,  -1.81579590e-02],
                        [ -2.65808105e-02,  -2.50854492e-02],
                        [ -1.74560547e-02,  -1.90734863e-02],
                        [ -6.10351562e-05,  -3.35693359e-03],
                        [  1.67541504e-02,   1.48010254e-02],
                        [  2.73437500e-02,   2.85949707e-02],
                        [  2.60314941e-02,   2.93884277e-02],
                        [  1.01013184e-02,   1.24206543e-02],
                        [ -1.13830566e-02,  -1.20544434e-02],
                        [ -2.30407715e-02,  -2.56652832e-02],
                        [ -2.22167969e-02,  -2.40173340e-02],
                        [ -2.00195312e-02,  -1.95922852e-02],
                        [ -2.11181641e-02,  -1.95922852e-02],
                        [ -1.85852051e-02,  -1.78833008e-02],
                        [ -1.13220215e-02,  -1.21765137e-02],
                        [ -9.21630859e-03,  -1.05285645e-02],
                        [ -1.75170898e-02,  -1.76086426e-02],
                        [ -3.06396484e-02,  -2.89611816e-02],
                        [ -4.21752930e-02,  -4.01916504e-02],
                        [ -4.97741699e-02,  -4.94689941e-02],
                        [ -4.70581055e-02,  -4.87365723e-02],
                        [ -2.24304199e-02,  -2.45361328e-02],
                        [  2.60925293e-02,   2.49938965e-02],
                        [  8.17871094e-02,   8.18786621e-02],
                        [  1.21795654e-01,   1.22680664e-01],
                        [  1.33453369e-01,   1.35009766e-01],
                        [  1.19018555e-01,   1.20941162e-01],
                        [  9.24072266e-02,   9.36889648e-02],
                        [  6.86340332e-02,   6.79626465e-02],
                        [  5.07202148e-02,   4.80346680e-02],
                        [  3.23486328e-02,   2.91748047e-02],
                        [  1.09863281e-02,   9.67407227e-03],
                        [ -7.78198242e-03,  -5.85937500e-03],
                        [ -1.65100098e-02,  -1.24816895e-02],
                        [ -1.21765137e-02,  -9.24682617e-03],
                        [  3.05175781e-05,  -6.10351562e-04],
                        [  8.42285156e-03,   4.69970703e-03],
                        [  4.66918945e-03,   9.76562500e-04],
                        [ -5.82885742e-03,  -6.43920898e-03],
                        [ -9.12475586e-03,  -5.92041016e-03],
                        [ -3.05175781e-04,   4.18090820e-03],
                        [  1.10168457e-02,   1.27868652e-02],
                        [  1.71813965e-02,   1.42211914e-02],
                        [  2.37121582e-02,   1.82495117e-02],
                        [  3.77197266e-02,   3.43017578e-02],
                        [  5.56335449e-02,   5.72204590e-02],
                        [  7.18383789e-02,   7.75146484e-02],
                        [  8.94470215e-02,   9.51538086e-02],
                        [  1.13189697e-01,   1.14654541e-01],
                        [  1.38061523e-01,   1.33789062e-01],
                        [  1.50634766e-01,   1.43585205e-01],
                        [  1.38000488e-01,   1.33483887e-01],
                        [  9.37194824e-02,   9.49096680e-02],
                        [  2.11181641e-02,   2.65502930e-02],
                        [ -6.90002441e-02,  -6.35070801e-02],
                        [ -1.64794922e-01,  -1.62536621e-01],
                        [ -2.51190186e-01,  -2.52868652e-01],
                        [ -3.03009033e-01,  -3.07128906e-01],
                        [ -2.99133301e-01,  -3.02978516e-01],
                        [ -2.49786377e-01,  -2.51037598e-01],
                        [ -1.93603516e-01,  -1.91864014e-01],
                        [ -1.58508301e-01,  -1.55487061e-01],
                        [ -1.38885498e-01,  -1.36840820e-01],
                        [ -1.16577148e-01,  -1.16821289e-01],
                        [ -9.03015137e-02,  -9.23767090e-02],
                        [ -7.31506348e-02,  -7.50427246e-02],
                        [ -6.99462891e-02,  -6.94885254e-02],
                        [ -7.04345703e-02,  -6.76879883e-02],
                        [ -6.22863770e-02,  -5.99670410e-02],
                        [ -4.18090820e-02,  -4.26025391e-02],
                        [ -1.45568848e-02,  -1.82189941e-02],
                        [  7.72094727e-03,   4.05883789e-03],
                        [  1.44348145e-02,   1.37329102e-02],
                        [  5.40161133e-03,   8.30078125e-03],
                        [ -1.04980469e-02,  -6.07299805e-03],
                        [ -2.52990723e-02,  -2.23083496e-02],
                        [ -3.51562500e-02,  -3.52478027e-02],
                        [ -3.93371582e-02,  -4.20532227e-02],
                        [ -4.12902832e-02,  -4.50439453e-02],
                        [ -4.54101562e-02,  -4.83703613e-02],
                        [ -5.08728027e-02,  -5.15441895e-02],
                        [ -5.46569824e-02,  -5.25817871e-02],
                        [ -5.49316406e-02,  -5.12390137e-02],
                        [ -4.56848145e-02,  -4.26330566e-02],
                        [ -1.81884766e-02,  -1.75476074e-02],
                        [  2.73437500e-02,   2.54516602e-02],
                        [  8.20617676e-02,   7.90710449e-02],
                        [  1.38305664e-01,   1.36230469e-01],
                        [  1.87713623e-01,   1.87744141e-01],
                        [  2.16644287e-01,   2.18170166e-01],
                        [  2.17407227e-01,   2.18719482e-01],
                        [  1.99310303e-01,   1.99279785e-01],
                        [  1.78985596e-01,   1.78131104e-01],
                        [  1.64855957e-01,   1.64611816e-01],
                        [  1.56005859e-01,   1.57318115e-01],
                        [  1.49414062e-01,   1.51580811e-01],
                        [  1.44226074e-01,   1.45141602e-01],
                        [  1.43035889e-01,   1.40960693e-01],
                        [  1.47613525e-01,   1.43432617e-01],
                        [  1.49932861e-01,   1.47064209e-01],
                        [  1.33209229e-01,   1.34338379e-01],
                        [  8.59680176e-02,   9.03320312e-02],
                        [  1.01013184e-02,   1.44348145e-02],
                        [ -8.09631348e-02,  -7.96203613e-02],
                        [ -1.62475586e-01,  -1.64855957e-01],
                        [ -2.03552246e-01,  -2.07794189e-01],
                        [ -1.87957764e-01,  -1.91040039e-01],
                        [ -1.34704590e-01,  -1.34674072e-01],
                        [ -8.62426758e-02,  -8.36486816e-02],
                        [ -6.75048828e-02,  -6.45751953e-02],
                        [ -6.54296875e-02,  -6.40563965e-02],
                        [ -5.69152832e-02,  -5.76171875e-02],
                        [ -4.21447754e-02,  -4.39758301e-02],
                        [ -3.61022949e-02,  -3.75976562e-02],
                        [ -4.15649414e-02,  -4.17175293e-02],
                        [ -4.55627441e-02,  -4.45556641e-02],
                        [ -3.63769531e-02,  -3.53698730e-02],
                        [ -1.51367188e-02,  -1.49230957e-02],
                        [  8.36181641e-03,   7.96508789e-03],
                        [  2.52380371e-02,   2.47192383e-02],
                        [  3.12500000e-02,   3.05786133e-02],
                        [  2.53906250e-02,   2.46276855e-02],
                        [  9.39941406e-03,   9.36889648e-03],
                        [ -1.19323730e-02,  -1.04675293e-02],
                        [ -3.06091309e-02,  -2.81372070e-02],
                        [ -3.74755859e-02,  -3.60717773e-02],
                        [ -3.00903320e-02,  -3.15856934e-02],
                        [ -1.61743164e-02,  -2.01721191e-02],
                        [ -5.03540039e-03,  -8.54492188e-03],
                        [ -6.71386719e-04,  -5.79833984e-04],
                        [ -5.64575195e-03,  -1.55639648e-03],
                        [ -2.17590332e-02,  -1.68762207e-02],
                        [ -4.40673828e-02,  -4.22973633e-02],
                        [ -6.09741211e-02,  -6.33544922e-02],
                        [ -6.30493164e-02,  -6.71386719e-02],
                        [ -4.59899902e-02,  -4.86755371e-02],
                        [ -7.38525391e-03,  -7.41577148e-03],
                        [  4.87365723e-02,   5.05065918e-02],
                        [  1.02874756e-01,   1.04827881e-01],
                        [  1.30004883e-01,   1.30981445e-01],
                        [  1.23168945e-01,   1.23291016e-01],
                        [  9.76867676e-02,   9.77172852e-02],
                        [  7.06176758e-02,   7.07397461e-02],
                        [  4.80346680e-02,   4.74548340e-02],
                        [  3.25012207e-02,   3.07922363e-02],
                        [  2.78320312e-02,   2.61230469e-02],
                        [  3.14941406e-02,   3.14636230e-02],
                        [  3.29284668e-02,   3.48815918e-02],
                        [  2.61535645e-02,   2.85949707e-02],
                        [  1.56250000e-02,   1.64489746e-02],
                        [  6.40869141e-03,   4.76074219e-03],
                        [ -2.56347656e-03,  -5.40161133e-03],
                        [ -1.30920410e-02,  -1.44042969e-02],
                        [ -2.25219727e-02,  -2.05383301e-02],
                        [ -2.52990723e-02,  -2.14843750e-02],
                        [ -1.61132812e-02,  -1.41906738e-02],
                        [  7.72094727e-03,   5.34057617e-03],
                        [  4.21752930e-02,   3.71093750e-02],
                        [  7.59277344e-02,   7.24182129e-02],
                        [  9.86938477e-02,   9.97924805e-02],
                        [  1.10992432e-01,   1.16119385e-01],
                        [  1.20086670e-01,   1.25488281e-01],
                        [  1.27624512e-01,   1.29394531e-01],
                        [  1.29272461e-01,   1.26342773e-01],
                        [  1.21826172e-01,   1.16638184e-01],
                        [  9.99450684e-02,   9.60388184e-02],
                        [  5.11474609e-02,   5.03234863e-02],
                        [ -3.21350098e-02,  -3.02734375e-02],
                        [ -1.37573242e-01,  -1.34216309e-01],
                        [ -2.36724854e-01,  -2.33215332e-01],
                        [ -2.99560547e-01,  -2.97485352e-01],
                        [ -3.06182861e-01,  -3.06793213e-01],
                        [ -2.58514404e-01,  -2.61505127e-01],
                        [ -1.86523438e-01,  -1.90063477e-01],
                        [ -1.29394531e-01,  -1.31347656e-01],
                        [ -1.04034424e-01,  -1.03363037e-01],
                        [ -9.86328125e-02,  -9.62524414e-02],
                        [ -9.56115723e-02,  -9.37500000e-02],
                        [ -8.87756348e-02,  -8.88061523e-02],
                        [ -8.09631348e-02,  -8.19396973e-02],
                        [ -7.55004883e-02,  -7.52868652e-02],
                        [ -6.94580078e-02,  -6.75354004e-02],
                        [ -5.46569824e-02,  -5.30090332e-02],
                        [ -2.87780762e-02,  -2.97851562e-02],
                        [ -1.37329102e-03,  -5.34057617e-03],
                        [  1.61132812e-02,   1.17492676e-02],
                        [  2.03857422e-02,   1.92565918e-02],
                        [  1.38549805e-02,   1.74560547e-02],
                        [  5.49316406e-04,   6.59179688e-03],
                        [ -1.37939453e-02,  -9.61303711e-03],
                        [ -2.50244141e-02,  -2.55126953e-02],
                        [ -3.56750488e-02,  -4.01611328e-02],
                        [ -5.10559082e-02,  -5.63964844e-02],
                        [ -6.95190430e-02,  -7.22656250e-02],
                        [ -8.13903809e-02,  -8.01391602e-02],
                        [ -7.81250000e-02,  -7.44018555e-02],
                        [ -5.76782227e-02,  -5.45959473e-02],
                        [ -2.15759277e-02,  -2.08129883e-02],
                        [  2.85339355e-02,   2.75268555e-02],
                        [  8.96301270e-02,   8.82568359e-02],
                        [  1.54937744e-01,   1.54113770e-01],
                        [  2.11303711e-01,   2.11303711e-01],
                        [  2.40966797e-01,   2.41516113e-01],
                        [  2.34313965e-01,   2.34588623e-01],
                        [  2.02270508e-01,   2.01385498e-01],
                        [  1.67144775e-01,   1.65374756e-01],
                        [  1.41235352e-01,   1.40075684e-01],
                        [  1.22589111e-01,   1.23596191e-01],
                        [  1.08520508e-01,   1.11907959e-01],
                        [  1.02264404e-01,   1.06170654e-01],
                        [  1.06262207e-01,   1.07513428e-01],
                        [  1.17462158e-01,   1.14257812e-01],
                        [  1.30767822e-01,   1.24877930e-01],
                        [  1.40930176e-01,   1.36627197e-01],
                        [  1.38366699e-01,   1.38824463e-01],
                        [  1.09161377e-01,   1.13922119e-01],
                        [  4.53796387e-02,   5.11169434e-02],
                        [ -4.42199707e-02,  -4.10766602e-02],
                        [ -1.33270264e-01,  -1.34460449e-01],
                        [ -1.88751221e-01,  -1.93176270e-01],
                        [ -1.91253662e-01,  -1.95953369e-01],
                        [ -1.51611328e-01,  -1.53839111e-01],
                        [ -1.03820801e-01,  -1.02539062e-01],
                        [ -7.69958496e-02,  -7.32421875e-02],
                        [ -7.48596191e-02,  -7.10449219e-02],
                        [ -7.90710449e-02,  -7.77282715e-02],
                        [ -6.94580078e-02,  -7.14721680e-02],
                        [ -4.44335938e-02,  -4.80651855e-02],
                        [ -2.23999023e-02,  -2.46276855e-02],
                        [ -1.90734863e-02,  -1.83105469e-02],
                        [ -2.81982422e-02,  -2.53295898e-02],
                        [ -3.16772461e-02,  -2.91748047e-02],
                        [ -2.24304199e-02,  -2.23999023e-02],
                        [ -6.83593750e-03,  -9.36889648e-03],
                        [  7.72094727e-03,   4.60815430e-03],
                        [  1.60827637e-02,   1.49536133e-02],
                        [  1.40380859e-02,   1.58996582e-02],
                        [  3.17382812e-03,   6.77490234e-03],
                        [ -9.39941406e-03,  -6.50024414e-03],
                        [ -1.88293457e-02,  -1.86767578e-02],
                        [ -2.42614746e-02,  -2.73437500e-02],
                        [ -2.49938965e-02,  -2.94494629e-02],
                        [ -2.18200684e-02,  -2.43835449e-02],
                        [ -1.92260742e-02,  -1.78833008e-02],
                        [ -2.10266113e-02,  -1.69677734e-02],
                        [ -2.73437500e-02,  -2.36816406e-02],
                        [ -3.72924805e-02,  -3.64990234e-02],
                        [ -4.87365723e-02,  -5.09338379e-02],
                        [ -5.32836914e-02,  -5.63049316e-02],
                        [ -3.82080078e-02,  -3.96118164e-02],
                        [  4.57763672e-04,   1.28173828e-03],
                        [  5.13000488e-02,   5.27343750e-02],
                        [  9.59472656e-02,   9.61303711e-02],
                        [  1.18286133e-01,   1.17248535e-01],
                        [  1.09619141e-01,   1.08886719e-01],
                        [  7.56530762e-02,   7.64770508e-02],
                        [  3.84826660e-02,   4.06188965e-02],
                        [  1.96228027e-02,   2.14538574e-02],
                        [  2.15148926e-02,   2.12707520e-02],
                        [  3.14941406e-02,   2.89001465e-02],
                        [  3.80859375e-02,   3.50341797e-02],
                        [  3.59802246e-02,   3.49426270e-02],
                        [  2.49938965e-02,   2.65197754e-02],
                        [  1.32751465e-02,   1.56250000e-02],
                        [  1.13525391e-02,   1.26037598e-02],
                        [  1.69677734e-02,   1.68762207e-02],
                        [  1.72424316e-02,   1.68457031e-02],
                        [  8.69750977e-03,   8.81958008e-03],
                        [  3.41796875e-03,   3.81469727e-03],
                        [  1.35803223e-02,   1.32751465e-02],
                        [  3.75366211e-02,   3.58886719e-02],
                        [  6.34155273e-02,   6.11267090e-02],
                        [  8.31298828e-02,   8.20312500e-02],
                        [  9.83276367e-02,   9.95483398e-02],
                        [  1.12152100e-01,   1.14959717e-01],
                        [  1.23596191e-01,   1.26312256e-01],
                        [  1.32110596e-01,   1.33544922e-01],
                        [  1.35742188e-01,   1.35498047e-01],
                        [  1.24420166e-01,   1.22497559e-01],
                        [  8.53271484e-02,   8.20922852e-02],
                        [  1.48620605e-02,   1.12915039e-02],
                        [ -7.96203613e-02,  -8.15429688e-02],
                        [ -1.82250977e-01,  -1.80633545e-01],
                        [ -2.68463135e-01,  -2.63366699e-01],
                        [ -3.09844971e-01,  -3.04107666e-01],
                        [ -2.91076660e-01,  -2.88604736e-01],
                        [ -2.26440430e-01,  -2.29248047e-01],
                        [ -1.56036377e-01,  -1.62170410e-01],
                        [ -1.16058350e-01,  -1.21154785e-01],
                        [ -1.09619141e-01,  -1.10412598e-01],
                        [ -1.11846924e-01,  -1.08703613e-01],
                        [ -1.02111816e-01,  -9.83276367e-02],
                        [ -8.18786621e-02,  -8.01696777e-02],
                        [ -6.19201660e-02,  -6.20727539e-02],
                        [ -4.73937988e-02,  -4.73327637e-02],
                        [ -3.81164551e-02,  -3.72009277e-02],
                        [ -3.13720703e-02,  -3.11889648e-02],
                        [ -2.25219727e-02,  -2.47497559e-02],
                        [ -1.17492676e-02,  -1.57165527e-02],
                        [ -5.37109375e-03,  -8.30078125e-03],
                        [ -5.85937500e-03,  -5.18798828e-03],
                        [ -9.55200195e-03,  -5.18798828e-03],
                        [ -1.64184570e-02,  -1.10168457e-02],
                        [ -2.97851562e-02,  -2.72827148e-02],
                        [ -4.80346680e-02,  -5.02624512e-02],
                        [ -6.50939941e-02,  -7.00683594e-02],
                        [ -7.74841309e-02,  -8.12683105e-02],
                        [ -8.35571289e-02,  -8.37402344e-02],
                        [ -7.77282715e-02,  -7.52258301e-02],
                        [ -5.27648926e-02,  -5.01708984e-02],
                        [ -8.91113281e-03,  -8.05664062e-03],
                        [  4.53186035e-02,   4.45251465e-02],
                        [  1.02783203e-01,   1.01776123e-01],
                        [  1.59973145e-01,   1.59759521e-01],
                        [  2.07489014e-01,   2.08038330e-01],
                        [  2.30133057e-01,   2.30773926e-01],
                        [  2.21221924e-01,   2.21496582e-01],
                        [  1.90490723e-01,   1.90216064e-01],
                        [  1.55639648e-01,   1.54663086e-01],
                        [  1.29211426e-01,   1.27563477e-01],
                        [  1.13891602e-01,   1.12365723e-01],
                        [  1.07543945e-01,   1.07696533e-01],
                        [  1.09039307e-01,   1.11602783e-01],
                        [  1.17675781e-01,   1.21643066e-01],
                        [  1.30950928e-01,   1.33544922e-01],
                        [  1.44073486e-01,   1.42883301e-01],
                        [  1.51367188e-01,   1.46453857e-01],
                        [  1.48071289e-01,   1.42608643e-01],
                        [  1.30615234e-01,   1.28631592e-01],
                        [  9.34753418e-02,   9.66796875e-02],
                        [  3.12500000e-02,   3.74755859e-02],
                        [ -5.18493652e-02,  -4.71496582e-02],
                        [ -1.36566162e-01,  -1.36749268e-01],
                        [ -1.95953369e-01,  -2.00531006e-01],
                        [ -2.10632324e-01,  -2.15942383e-01],
                        [ -1.81671143e-01,  -1.83746338e-01],
                        [ -1.29730225e-01,  -1.27380371e-01],
                        [ -8.15124512e-02,  -7.71179199e-02],
                        [ -5.43823242e-02,  -5.16967773e-02],
                        [ -4.80651855e-02,  -4.91027832e-02],
                        [ -4.87060547e-02,  -5.21850586e-02],
                        [ -4.45251465e-02,  -4.72412109e-02],
                        [ -3.72924805e-02,  -3.68041992e-02],
                        [ -3.49121094e-02,  -3.16772461e-02],
                        [ -3.81164551e-02,  -3.50036621e-02],
                        [ -3.90319824e-02,  -3.85742188e-02],
                        [ -3.11584473e-02,  -3.35998535e-02],
                        [ -1.66320801e-02,  -2.00805664e-02],
                        [ -2.38037109e-03,  -4.51660156e-03],
                        [  7.17163086e-03,   7.50732422e-03],
                        [  9.46044922e-03,   1.19018555e-02],
                        [  1.89208984e-03,   5.03540039e-03],
                        [ -1.22985840e-02,  -1.01318359e-02],
                        [ -2.29187012e-02,  -2.28271484e-02],
                        [ -2.36816406e-02,  -2.56652832e-02],
                        [ -1.99584961e-02,  -2.29797363e-02],
                        [ -2.10266113e-02,  -2.35290527e-02],
                        [ -2.76794434e-02,  -2.82592773e-02],
                        [ -3.29284668e-02,  -3.13110352e-02],
                        [ -3.42407227e-02,  -3.17077637e-02],
                        [ -3.73535156e-02,  -3.55834961e-02],
                        [ -4.34570312e-02,  -4.29382324e-02],
                        [ -4.15344238e-02,  -4.16870117e-02],
                        [ -1.94091797e-02,  -1.97448730e-02],
                        [  2.38037109e-02,   2.29492188e-02],
                        [  7.51953125e-02,   7.34558105e-02],
                        [  1.12640381e-01,   1.10412598e-01],
                        [  1.18041992e-01,   1.16516113e-01],
                        [  9.41162109e-02,   9.45739746e-02],
                        [  6.35070801e-02,   6.64062500e-02],
                        [  4.68750000e-02,   5.10864258e-02],
                        [  4.59289551e-02,   4.89807129e-02],
                        [  4.87060547e-02,   4.83093262e-02],
                        [  4.47692871e-02,   4.07714844e-02],
                        [  3.27758789e-02,   2.74963379e-02],
                        [  1.81884766e-02,   1.48315430e-02],
                        [  7.84301758e-03,   8.33129883e-03],
                        [  5.27954102e-03,   9.18579102e-03],
                        [  8.88061523e-03,   1.37634277e-02],
                        [  1.37023926e-02,   1.67236328e-02],
                        [  1.56860352e-02,   1.53808594e-02],
                        [  1.47705078e-02,   1.18103027e-02],
                        [  1.46179199e-02,   1.11389160e-02],
                        [  1.98974609e-02,   1.80053711e-02],
                        [  3.33251953e-02,   3.35388184e-02],
                        [  5.50842285e-02,   5.64270020e-02],
                        [  8.34655762e-02,   8.45336914e-02],
                        [  1.13647461e-01,   1.13739014e-01],
                        [  1.38305664e-01,   1.37969971e-01],
                        [  1.51641846e-01,   1.52191162e-01],
                        [  1.49993896e-01,   1.52252197e-01],
                        [  1.29272461e-01,   1.32019043e-01],
                        [  8.59680176e-02,   8.63037109e-02],
                        [  2.00195312e-02,   1.59912109e-02],
                        [ -6.68029785e-02,  -7.32116699e-02],
                        [ -1.68670654e-01,  -1.72424316e-01],
                        [ -2.64923096e-01,  -2.62481689e-01],
                        [ -3.19061279e-01,  -3.11889648e-01],
                        [ -3.04077148e-01,  -2.97454834e-01],
                        [ -2.33703613e-01,  -2.32238770e-01],
                        [ -1.57257080e-01,  -1.61224365e-01],
                        [ -1.15142822e-01,  -1.20819092e-01],
                        [ -1.05834961e-01,  -1.09283447e-01],
                        [ -1.02569580e-01,  -1.02691650e-01],
                        [ -9.04846191e-02,  -8.89892578e-02],
                        [ -7.65991211e-02,  -7.51953125e-02],
                        [ -7.07092285e-02,  -6.94580078e-02],
                        [ -7.04650879e-02,  -6.86035156e-02],
                        [ -6.59790039e-02,  -6.36291504e-02],
                        [ -5.19714355e-02,  -5.06896973e-02],
                        [ -3.22265625e-02,  -3.36303711e-02],
                        [ -1.40380859e-02,  -1.81274414e-02],
                        [ -2.34985352e-03,  -6.80541992e-03],
                        [  4.27246094e-04,  -1.22070312e-03],
                        [ -5.85937500e-03,  -3.41796875e-03],
                        [ -1.69372559e-02,  -1.20849609e-02],
                        [ -2.63977051e-02,  -2.25830078e-02],
                        [ -3.48205566e-02,  -3.43627930e-02],
                        [ -4.90417480e-02,  -5.17272949e-02],
                        [ -6.91528320e-02,  -7.25402832e-02],
                        [ -8.32519531e-02,  -8.49304199e-02],
                        [ -7.89489746e-02,  -7.83996582e-02],
                        [ -5.30700684e-02,  -5.16357422e-02],
                        [ -9.24682617e-03,  -8.42285156e-03],
                        [  4.75158691e-02,   4.74548340e-02],
                        [  1.11328125e-01,   1.11145020e-01],
                        [  1.71539307e-01,   1.71722412e-01],
                        [  2.11547852e-01,   2.11853027e-01],
                        [  2.18688965e-01,   2.18688965e-01],
                        [  1.96777344e-01,   1.96594238e-01],
                        [  1.62994385e-01,   1.63238525e-01],
                        [  1.32781982e-01,   1.33392334e-01],
                        [  1.12121582e-01,   1.12091064e-01],
                        [  1.00677490e-01,   9.92431641e-02],
                        [  9.47875977e-02,   9.25903320e-02],
                        [  9.11865234e-02,   8.99658203e-02],
                        [  9.21936035e-02,   9.34753418e-02],
                        [  1.02813721e-01,   1.06475830e-01],
                        [  1.19293213e-01,   1.23107910e-01],
                        [  1.28479004e-01,   1.29302979e-01],
                        [  1.23687744e-01,   1.20178223e-01],
                        [  1.12487793e-01,   1.06994629e-01],
                        [  1.02447510e-01,   9.92126465e-02],
                        [  8.71276855e-02,   8.85314941e-02],
                        [  5.31311035e-02,   5.76782227e-02],
                        [ -5.06591797e-03,  -1.03759766e-03],
                        [ -8.05664062e-02,  -7.96813965e-02],
                        [ -1.55609131e-01,  -1.57836914e-01],
                        [ -2.04193115e-01,  -2.07183838e-01],
                        [ -2.04620361e-01,  -2.05902100e-01],
                        [ -1.61163330e-01,  -1.60156250e-01],
                        [ -1.05834961e-01,  -1.04309082e-01],
                        [ -6.94274902e-02,  -6.93664551e-02],
                        [ -5.59997559e-02,  -5.75256348e-02],
                        [ -5.17578125e-02,  -5.30700684e-02],
                        [ -4.79125977e-02,  -4.73022461e-02],
                        [ -4.57153320e-02,  -4.33654785e-02],
                        [ -4.75158691e-02,  -4.52270508e-02],
                        [ -5.15441895e-02,  -5.12390137e-02],
                        [ -5.30090332e-02,  -5.49316406e-02],
                        [ -4.65087891e-02,  -4.90112305e-02],
                        [ -2.94799805e-02,  -3.07312012e-02],
                        [ -5.09643555e-03,  -4.82177734e-03],
                        [  1.82800293e-02,   1.90429688e-02],
                        [  3.05175781e-02,   3.10668945e-02],
                        [  2.67639160e-02,   2.74047852e-02],
                        [  1.28479004e-02,   1.41601562e-02],
                        [  3.35693359e-04,   1.98364258e-03],
                        [ -7.23266602e-03,  -6.43920898e-03],
                        [ -1.68762207e-02,  -1.81579590e-02],
                        [ -3.31115723e-02,  -3.63159180e-02],
                        [ -4.99877930e-02,  -5.31311035e-02],
                        [ -6.10351562e-02,  -6.20117188e-02],
                        [ -6.93359375e-02,  -6.75659180e-02],
                        [ -7.93151855e-02,  -7.58972168e-02],
                        [ -8.42895508e-02,  -8.10546875e-02],
                        [ -7.02209473e-02,  -6.86645508e-02],
                        [ -2.93884277e-02,  -3.00598145e-02],
                        [  3.24707031e-02,   3.00292969e-02],
                        [  9.68933105e-02,   9.38110352e-02],
                        [  1.39770508e-01,   1.37054443e-01],
                        [  1.46667480e-01,   1.45172119e-01],
                        [  1.23657227e-01,   1.24206543e-01],
                        [  8.92944336e-02,   9.23767090e-02],
                        [  5.91735840e-02,   6.39648438e-02],
                        [  3.93981934e-02,   4.34570312e-02],
                        [  2.86254883e-02,   2.92968750e-02],
                        [  2.36816406e-02,   1.98974609e-02],
                        [  2.34375000e-02,   1.68762207e-02],
                        [  2.67944336e-02,   2.12707520e-02],
                        [  2.88085938e-02,   2.80761719e-02],
                        [  2.37426758e-02,   2.84118652e-02],
                        [  1.22070312e-02,   1.90429688e-02],
                        [  2.86865234e-03,   7.41577148e-03],
                        [  4.05883789e-03,   3.81469727e-03],
                        [  1.42211914e-02,   1.01318359e-02],
                        [  2.58178711e-02,   2.11486816e-02],
                        [  3.66210938e-02,   3.43933105e-02],
                        [  5.09948730e-02,   5.18188477e-02],
                        [  7.19604492e-02,   7.39440918e-02],
                        [  9.89074707e-02,   9.97314453e-02],
                        [  1.28814697e-01,   1.28265381e-01],
                        [  1.53228760e-01,   1.53106689e-01],
                        [  1.58996582e-01,   1.60797119e-01],
                        [  1.38458252e-01,   1.41418457e-01],
                        [  9.44824219e-02,   9.59472656e-02],
                        [  3.06396484e-02,   2.85034180e-02],
                        [ -5.52673340e-02,  -6.01806641e-02],
                        [ -1.58843994e-01,  -1.62811279e-01],
                        [ -2.55218506e-01,  -2.55096436e-01],
                        [ -3.06732178e-01,  -3.03039551e-01],
                        [ -2.89886475e-01,  -2.85858154e-01],
                        [ -2.20184326e-01,  -2.18475342e-01],
                        [ -1.47125244e-01,  -1.47796631e-01],
                        [ -1.11083984e-01,  -1.12518311e-01],
                        [ -1.08123779e-01,  -1.09069824e-01],
                        [ -1.08184814e-01,  -1.08734131e-01],
                        [ -9.71984863e-02,  -9.82360840e-02],
                        [ -8.41674805e-02,  -8.58154297e-02],
                        [ -7.72094727e-02,  -7.82165527e-02],
                        [ -7.22351074e-02,  -7.11975098e-02],
                        [ -6.27441406e-02,  -5.99670410e-02],
                        [ -4.77905273e-02,  -4.49523926e-02],
                        [ -2.98156738e-02,  -2.85644531e-02],
                        [ -1.22985840e-02,  -1.32141113e-02],
                        [  3.05175781e-04,  -2.25830078e-03],
                        [  3.75366211e-03,   8.85009766e-04],
                        [ -4.42504883e-03,  -6.10351562e-03],
                        [ -2.22167969e-02,  -2.17895508e-02],
                        [ -4.02832031e-02,  -3.82690430e-02],
                        [ -4.92248535e-02,  -4.69360352e-02],
                        [ -5.12390137e-02,  -4.99877930e-02],
                        [ -5.61218262e-02,  -5.61828613e-02],
                        [ -6.41479492e-02,  -6.50024414e-02],
                        [ -6.31408691e-02,  -6.39343262e-02],
                        [ -4.13513184e-02,  -4.19616699e-02],
                        [  3.63159180e-03,   2.96020508e-03],
                        [  6.63146973e-02,   6.56433105e-02],
                        [  1.34399414e-01,   1.34338379e-01],
                        [  1.90277100e-01,   1.90979004e-01],
                        [  2.18536377e-01,   2.19421387e-01],
                        [  2.15209961e-01,   2.15637207e-01],
                        [  1.88507080e-01,   1.88446045e-01],
                        [  1.53045654e-01,   1.53015137e-01],
                        [  1.23382568e-01,   1.23840332e-01],
                        [  1.06719971e-01,   1.07330322e-01],
                        [  9.93957520e-02,   9.93957520e-02],
                        [  9.33227539e-02,   9.20410156e-02],
                        [  8.41064453e-02,   8.17260742e-02],
                        [  7.29370117e-02,   7.08923340e-02],
                        [  6.40869141e-02,   6.41479492e-02],
                        [  6.03332520e-02,   6.32934570e-02],
                        [  6.04553223e-02,   6.50634766e-02],
                        [  6.33239746e-02,   6.64978027e-02],
                        [  7.24182129e-02,   7.15026855e-02],
                        [  9.14001465e-02,   8.66394043e-02],
                        [  1.14837646e-01,   1.09405518e-01],
                        [  1.26953125e-01,   1.24420166e-01],
                        [  1.11419678e-01,   1.13098145e-01],
                        [  6.19201660e-02,   6.63452148e-02],
                        [ -1.48620605e-02,  -1.05285645e-02],
                        [ -1.00830078e-01,  -9.88464355e-02],
                        [ -1.70104980e-01,  -1.70959473e-01],
                        [ -1.99127197e-01,  -2.01751709e-01],
                        [ -1.83898926e-01,  -1.86767578e-01],
                        [ -1.46209717e-01,  -1.48315430e-01],
                        [ -1.14532471e-01,  -1.15447998e-01],
                        [ -9.75646973e-02,  -9.70153809e-02],
                        [ -8.38928223e-02,  -8.17260742e-02],
                        [ -6.60705566e-02,  -6.31408691e-02],
                        [ -5.16967773e-02,  -4.96520996e-02],
                        [ -4.78820801e-02,  -4.79125977e-02],
                        [ -4.97741699e-02,  -5.15441895e-02],
                        [ -4.91027832e-02,  -5.13000488e-02],
                        [ -4.34265137e-02,  -4.49218750e-02],
                        [ -3.32946777e-02,  -3.36914062e-02],
                        [ -2.02941895e-02,  -1.98364258e-02],
                        [ -9.21630859e-03,  -8.63647461e-03],
                        [ -4.05883789e-03,  -3.72314453e-03],
                        [ -1.52587891e-03,  -8.54492188e-04],
                        [  2.59399414e-03,   4.18090820e-03],
                        [  4.08935547e-03,   5.98144531e-03],
                        [ -2.96020508e-03,  -2.34985352e-03],
                        [ -1.65710449e-02,  -1.82495117e-02],
                        [ -3.21350098e-02,  -3.55529785e-02],
                        [ -4.95300293e-02,  -5.28564453e-02],
                        [ -6.72607422e-02,  -6.83898926e-02],
                        [ -8.02917480e-02,  -7.81860352e-02],
                        [ -8.63342285e-02,  -8.20617676e-02],
                        [ -8.40454102e-02,  -8.02001953e-02],
                        [ -6.63146973e-02,  -6.51550293e-02],
                        [ -2.78625488e-02,  -2.96630859e-02],
                        [  2.30712891e-02,   1.98059082e-02],
                        [  7.00988770e-02,   6.70471191e-02],
                        [  1.02081299e-01,   1.00219727e-01],
                        [  1.16149902e-01,   1.15875244e-01],
                        [  1.14227295e-01,   1.15509033e-01],
                        [  1.01348877e-01,   1.03973389e-01],
                        [  8.37402344e-02,   8.71276855e-02],
                        [  6.56738281e-02,   6.84204102e-02],
                        [  4.89196777e-02,   4.91333008e-02],
                        [  3.52783203e-02,   3.21960449e-02],
                        [  2.83508301e-02,   2.35290527e-02],
                        [  2.94189453e-02,   2.58483887e-02],
                        [  3.29895020e-02,   3.28063965e-02],
                        [  3.23486328e-02,   3.53088379e-02],
                        [  2.82897949e-02,   3.23486328e-02],
                        [  2.57568359e-02,   2.85644531e-02],
                        [  2.50854492e-02,   2.56042480e-02],
                        [  2.60925293e-02,   2.47497559e-02],
                        [  3.38745117e-02,   3.18908691e-02],
                        [  5.25512695e-02,   5.06896973e-02],
                        [  7.83996582e-02,   7.66601562e-02],
                        [  1.05224609e-01,   1.04034424e-01],
                        [  1.30615234e-01,   1.30950928e-01],
                        [  1.50390625e-01,   1.52709961e-01],
                        [  1.55242920e-01,   1.58416748e-01],
                        [  1.37664795e-01,   1.39678955e-01],
                        [  9.41772461e-02,   9.36279297e-02],
                        [  2.13928223e-02,   1.85852051e-02],
                        [ -7.68737793e-02,  -7.98034668e-02],
                        [ -1.80511475e-01,  -1.81182861e-01],
                        [ -2.60803223e-01,  -2.58911133e-01],
                        [ -2.94281006e-01,  -2.91961670e-01],
                        [ -2.72155762e-01,  -2.72033691e-01],
                        [ -2.11151123e-01,  -2.13439941e-01],
                        [ -1.49169922e-01,  -1.51275635e-01],
                        [ -1.15142822e-01,  -1.14471436e-01],
                        [ -1.06658936e-01,  -1.03363037e-01],
                        [ -1.03332520e-01,  -1.00189209e-01],
                        [ -9.42077637e-02,  -9.40856934e-02],
                        [ -8.56628418e-02,  -8.86230469e-02],
                        [ -8.48388672e-02,  -8.83483887e-02],
                        [ -8.44116211e-02,  -8.60900879e-02],
                        [ -7.07397461e-02,  -7.03430176e-02],
                        [ -4.21447754e-02,  -4.07104492e-02],
                        [ -1.20849609e-02,  -1.02844238e-02],
                        [  5.03540039e-03,   7.08007812e-03],
                        [  7.53784180e-03,   9.49096680e-03],
                        [  3.14331055e-03,   3.84521484e-03],
                        [ -5.24902344e-03,  -6.98852539e-03],
                        [ -2.06298828e-02,  -2.44750977e-02],
                        [ -4.02832031e-02,  -4.39758301e-02],
                        [ -5.59082031e-02,  -5.68542480e-02],
                        [ -6.34765625e-02,  -6.09741211e-02],
                        [ -6.28967285e-02,  -5.87463379e-02],
                        [ -5.30090332e-02,  -4.99267578e-02],
                        [ -3.17687988e-02,  -3.12194824e-02],
                        [  3.41796875e-03,   1.61743164e-03],
                        [  5.36804199e-02,   5.08728027e-02],
                        [  1.13800049e-01,   1.11633301e-01],
                        [  1.69921875e-01,   1.69403076e-01],
                        [  2.04406738e-01,   2.05200195e-01],
                        [  2.06512451e-01,   2.07672119e-01],
                        [  1.81365967e-01,   1.82312012e-01],
                        [  1.46026611e-01,   1.46545410e-01],
                        [  1.16058350e-01,   1.16119385e-01],
                        [  9.77783203e-02,   9.76562500e-02],
                        [  8.89282227e-02,   8.89892578e-02],
                        [  8.32824707e-02,   8.37707520e-02],
                        [  7.78503418e-02,   7.82470703e-02],
                        [  7.43713379e-02,   7.36999512e-02],
                        [  7.29064941e-02,   7.08007812e-02],
                        [  6.89086914e-02,   6.64062500e-02],
                        [  6.05163574e-02,   5.96008301e-02],
                        [  5.32531738e-02,   5.53283691e-02],
                        [  5.29479980e-02,   5.74035645e-02],
                        [  5.87463379e-02,   6.28662109e-02],
                        [  6.77185059e-02,   6.85424805e-02],
                        [  8.09936523e-02,   7.75756836e-02],
                        [  9.74426270e-02,   9.15832520e-02],
                        [  1.06079102e-01,   1.01348877e-01],
                        [  9.23156738e-02,   9.18579102e-02],
                        [  5.00488281e-02,   5.42297363e-02],
                        [ -1.38549805e-02,  -7.78198242e-03],
                        [ -8.12683105e-02,  -7.72705078e-02],
                        [ -1.30676270e-01,  -1.30950928e-01],
                        [ -1.50177002e-01,  -1.53808594e-01],
                        [ -1.44226074e-01,  -1.48529053e-01],
                        [ -1.26434326e-01,  -1.28997803e-01],
                        [ -1.07666016e-01,  -1.07635498e-01],
                        [ -9.20715332e-02,  -9.02099609e-02],
                        [ -7.94372559e-02,  -7.73315430e-02],
                        [ -6.79321289e-02,  -6.66198730e-02],
                        [ -5.71899414e-02,  -5.67016602e-02],
                        [ -4.97436523e-02,  -4.95605469e-02],
                        [ -4.65698242e-02,  -4.64477539e-02],
                        [ -4.23889160e-02,  -4.26330566e-02],
                        [ -2.99987793e-02,  -3.10668945e-02],
                        [ -9.94873047e-03,  -1.18408203e-02],
                        [  8.11767578e-03,   6.31713867e-03],
                        [  1.52282715e-02,   1.47705078e-02],
                        [  1.14440918e-02,   1.27868652e-02],
                        [  3.29589844e-03,   5.70678711e-03],
                        [ -3.66210938e-03,  -1.28173828e-03],
                        [ -7.96508789e-03,  -6.53076172e-03],
                        [ -1.15966797e-02,  -1.18103027e-02],
                        [ -1.86462402e-02,  -2.07519531e-02],
                        [ -3.37524414e-02,  -3.69873047e-02],
                        [ -5.72509766e-02,  -6.00585938e-02],
                        [ -8.10241699e-02,  -8.19091797e-02],
                        [ -9.33227539e-02,  -9.16137695e-02],
                        [ -8.95690918e-02,  -8.58154297e-02],
                        [ -7.26013184e-02,  -6.88171387e-02],
                        [ -4.34265137e-02,  -4.19311523e-02],
                        [ -1.09863281e-03,  -2.77709961e-03],
                        [  4.65393066e-02,   4.30297852e-02],
                        [  8.20922852e-02,   7.89489746e-02],
                        [  9.38110352e-02,   9.25598145e-02],
                        [  8.74328613e-02,   8.82263184e-02],
                        [  7.64465332e-02,   7.83996582e-02],
                        [  6.59484863e-02,   6.77490234e-02],
                        [  5.27648926e-02,   5.37109375e-02],
                        [  3.71398926e-02,   3.75366211e-02],
                        [  2.52685547e-02,   2.56652832e-02],
                        [  2.28576660e-02,   2.30102539e-02],
                        [  3.01818848e-02,   2.92358398e-02],
                        [  4.16564941e-02,   3.93371582e-02],
                        [  4.98046875e-02,   4.71801758e-02],
                        [  5.11474609e-02,   4.99267578e-02],
                        [  4.68750000e-02,   4.81262207e-02],
                        [  4.00390625e-02,   4.34265137e-02],
                        [  3.50952148e-02,   3.89099121e-02],
                        [  3.75366211e-02,   3.95202637e-02],
                        [  5.08728027e-02,   4.94689941e-02],
                        [  7.36999512e-02,   6.95495605e-02],
                        [  1.00463867e-01,   9.61914062e-02],
                        [  1.25030518e-01,   1.23504639e-01],
                        [  1.42395020e-01,   1.44470215e-01],
                        [  1.45629883e-01,   1.49658203e-01],
                        [  1.24603271e-01,   1.27563477e-01],
                        [  7.11364746e-02,   7.09838867e-02],
                        [ -1.35498047e-02,  -1.62353516e-02],
                        [ -1.15783691e-01,  -1.18316650e-01],
                        [ -2.11669922e-01,  -2.11730957e-01],
                        [ -2.74230957e-01,  -2.72033691e-01],
                        [ -2.85980225e-01,  -2.83905029e-01],
                        [ -2.52502441e-01,  -2.52807617e-01],
                        [ -2.00439453e-01,  -2.03063965e-01],
                        [ -1.54449463e-01,  -1.57196045e-01],
                        [ -1.20910645e-01,  -1.21459961e-01],
                        [ -9.59472656e-02,  -9.37805176e-02],
                        [ -7.86437988e-02,  -7.54699707e-02],
                        [ -7.04040527e-02,  -6.83288574e-02],
                        [ -6.90307617e-02,  -6.89392090e-02],
                        [ -6.84204102e-02,  -6.97326660e-02],
                        [ -6.27746582e-02,  -6.48803711e-02],
                        [ -5.08422852e-02,  -5.34057617e-02],
                        [ -3.51562500e-02,  -3.74450684e-02],
                        [ -1.97143555e-02,  -2.02941895e-02],
                        [ -9.21630859e-03,  -7.01904297e-03],
                        [ -6.59179688e-03,  -2.07519531e-03],
                        [ -9.55200195e-03,  -5.15747070e-03],
                        [ -1.53198242e-02,  -1.40991211e-02],
                        [ -2.58789062e-02,  -2.91748047e-02],
                        [ -4.23889160e-02,  -4.84313965e-02],
                        [ -5.78918457e-02,  -6.26831055e-02],
                        [ -6.20422363e-02,  -6.23168945e-02],
                        [ -5.12084961e-02,  -4.70275879e-02],
                        [ -2.76794434e-02,  -2.22167969e-02],
                        [  8.85009766e-03,   1.19628906e-02],
                        [  6.10656738e-02,   6.02111816e-02],
                        [  1.23626709e-01,   1.20208740e-01],
                        [  1.78833008e-01,   1.75567627e-01],
                        [  2.06542969e-01,   2.05474854e-01],
                        [  1.99676514e-01,   2.00927734e-01],
                        [  1.68701172e-01,   1.70623779e-01],
                        [  1.31439209e-01,   1.32202148e-01],
                        [  1.01562500e-01,   1.00769043e-01],
                        [  8.29467773e-02,   8.17871094e-02],
                        [  7.04956055e-02,   7.03430176e-02],
                        [  5.90515137e-02,   6.02416992e-02],
                        [  5.28259277e-02,   5.44128418e-02],
                        [  5.79833984e-02,   5.87463379e-02],
                        [  6.80236816e-02,   6.75048828e-02],
                        [  6.82373047e-02,   6.68334961e-02],
                        [  5.44128418e-02,   5.26428223e-02],
                        [  3.86352539e-02,   3.70483398e-02],
                        [  3.49426270e-02,   3.43017578e-02],
                        [  4.47387695e-02,   4.58068848e-02],
                        [  5.92041016e-02,   6.21643066e-02],
                        [  7.28454590e-02,   7.63854980e-02],
                        [  8.75549316e-02,   8.93249512e-02],
                        [  1.04736328e-01,   1.02935791e-01],
                        [  1.18804932e-01,   1.14074707e-01],
                        [  1.19354248e-01,   1.14776611e-01],
                        [  9.54589844e-02,   9.42993164e-02],
                        [  3.93676758e-02,   4.22973633e-02],
                        [ -4.53796387e-02,  -4.07104492e-02],
                        [ -1.34826660e-01,  -1.31561279e-01],
                        [ -1.92993164e-01,  -1.92718506e-01],
                        [ -2.00012207e-01,  -2.02056885e-01],
                        [ -1.69219971e-01,  -1.71813965e-01],
                        [ -1.32293701e-01,  -1.34094238e-01],
                        [ -1.10595703e-01,  -1.11236572e-01],
                        [ -1.02661133e-01,  -1.02508545e-01],
                        [ -9.50317383e-02,  -9.45129395e-02],
                        [ -7.90710449e-02,  -7.82775879e-02],
                        [ -5.63049316e-02,  -5.49926758e-02],
                        [ -3.42102051e-02,  -3.24096680e-02],
                        [ -2.11791992e-02,  -1.98364258e-02],
                        [ -1.91345215e-02,  -1.95312500e-02],
                        [ -1.89208984e-02,  -2.13928223e-02],
                        [ -1.12609863e-02,  -1.43432617e-02],
                        [  9.15527344e-05,  -1.52587891e-03],
                        [  3.35693359e-03,   4.11987305e-03],
                        [ -5.27954102e-03,  -2.89916992e-03],
                        [ -1.72119141e-02,  -1.47705078e-02],
                        [ -2.24304199e-02,  -2.11181641e-02],
                        [ -2.07824707e-02,  -2.08435059e-02],
                        [ -2.06604004e-02,  -2.17285156e-02],
                        [ -3.00903320e-02,  -3.15551758e-02],
                        [ -5.05065918e-02,  -5.20019531e-02],
                        [ -7.44323730e-02,  -7.56530762e-02],
                        [ -8.90197754e-02,  -8.93249512e-02],
                        [ -8.57849121e-02,  -8.45947266e-02],
                        [ -6.57043457e-02,  -6.34765625e-02],
                        [ -3.34167480e-02,  -3.17077637e-02],
                        [  7.59887695e-03,   7.47680664e-03],
                        [  5.13000488e-02,   4.96826172e-02],
                        [  8.67614746e-02,   8.52355957e-02],
                        [  1.04522705e-01,   1.04431152e-01],
                        [  1.03912354e-01,   1.05163574e-01],
                        [  9.14001465e-02,   9.23461914e-02],
                        [  7.36999512e-02,   7.27539062e-02],
                        [  5.63964844e-02,   5.39550781e-02],
                        [  4.42504883e-02,   4.26635742e-02],
                        [  3.72924805e-02,   3.86352539e-02],
                        [  3.32031250e-02,   3.70483398e-02],
                        [  3.55529785e-02,   3.92150879e-02],
                        [  4.94995117e-02,   5.00793457e-02],
                        [  6.83288574e-02,   6.50329590e-02],
                        [  7.72094727e-02,   7.18994141e-02],
                        [  7.11059570e-02,   6.73217773e-02],
                        [  5.90515137e-02,   5.95092773e-02],
                        [  5.12390137e-02,   5.56030273e-02],
                        [  5.20935059e-02,   5.72814941e-02],
                        [  6.45751953e-02,   6.72912598e-02],
                        [  8.88366699e-02,   8.77075195e-02],
                        [  1.16760254e-01,   1.12945557e-01],
                        [  1.36810303e-01,   1.33117676e-01],
                        [  1.42822266e-01,   1.41540527e-01],
                        [  1.30310059e-01,   1.31591797e-01],
                        [  9.08203125e-02,   9.28649902e-02],
                        [  1.87988281e-02,   1.98669434e-02],
                        [ -7.83691406e-02,  -7.83691406e-02],
                        [ -1.79809570e-01,  -1.79809570e-01],
                        [ -2.56469727e-01,  -2.55920410e-01],
                        [ -2.82104492e-01,  -2.81646729e-01],
                        [ -2.52777100e-01,  -2.53173828e-01],
                        [ -1.95404053e-01,  -1.96624756e-01],
                        [ -1.46881104e-01,  -1.48101807e-01],
                        [ -1.23718262e-01,  -1.24084473e-01],
                        [ -1.16210938e-01,  -1.15722656e-01],
                        [ -1.08612061e-01,  -1.08062744e-01],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -8.89587402e-02,  -8.89282227e-02],
                        [ -8.30383301e-02,  -8.20007324e-02],
                        [ -7.08923340e-02,  -6.89086914e-02],
                        [ -4.87976074e-02,  -4.75463867e-02],
                        [ -2.36206055e-02,  -2.48413086e-02],
                        [ -3.84521484e-03,  -7.35473633e-03],
                        [  5.67626953e-03,   2.04467773e-03],
                        [  3.38745117e-03,   2.28881836e-03],
                        [ -5.70678711e-03,  -3.17382812e-03],
                        [ -1.40075684e-02,  -9.18579102e-03],
                        [ -2.26745605e-02,  -1.86462402e-02],
                        [ -3.84521484e-02,  -3.80249023e-02],
                        [ -5.71899414e-02,  -6.06689453e-02],
                        [ -6.46972656e-02,  -6.95495605e-02],
                        [ -5.52368164e-02,  -5.82580566e-02],
                        [ -3.41491699e-02,  -3.35998535e-02],
                        [ -1.03759766e-03,   2.25830078e-03],
                        [  5.11779785e-02,   5.46569824e-02],
                        [  1.18682861e-01,   1.19903564e-01],
                        [  1.82556152e-01,   1.81182861e-01],
                        [  2.22534180e-01,   2.20367432e-01],
                        [  2.27325439e-01,   2.26501465e-01],
                        [  1.99523926e-01,   2.00347900e-01],
                        [  1.55517578e-01,   1.56616211e-01],
                        [  1.14685059e-01,   1.14624023e-01],
                        [  8.67004395e-02,   8.53576660e-02],
                        [  7.09228516e-02,   6.95495605e-02],
                        [  6.23168945e-02,   6.21948242e-02],
                        [  5.59692383e-02,   5.74340820e-02],
                        [  5.04760742e-02,   5.23681641e-02],
                        [  4.56848145e-02,   4.66918945e-02],
                        [  3.93066406e-02,   3.90625000e-02],
                        [  2.91748047e-02,   2.81677246e-02],
                        [  1.78222656e-02,   1.66015625e-02],
                        [  1.19934082e-02,   1.07727051e-02],
                        [  1.75781250e-02,   1.66931152e-02],
                        [  3.45458984e-02,   3.44848633e-02],
                        [  5.56030273e-02,   5.67016602e-02],
                        [  7.35168457e-02,   7.55004883e-02],
                        [  8.82263184e-02,   9.01489258e-02],
                        [  1.03485107e-01,   1.04125977e-01],
                        [  1.17706299e-01,   1.16394043e-01],
                        [  1.22314453e-01,   1.19842529e-01],
                        [  1.07147217e-01,   1.05194092e-01],
                        [  6.42089844e-02,   6.38732910e-02],
                        [ -8.60595703e-03,  -7.56835938e-03],
                        [ -9.96093750e-02,  -9.82055664e-02],
                        [ -1.80267334e-01,  -1.79229736e-01],
                        [ -2.18780518e-01,  -2.18170166e-01],
                        [ -2.04376221e-01,  -2.03979492e-01],
                        [ -1.56982422e-01,  -1.56860352e-01],
                        [ -1.08734131e-01,  -1.09222412e-01],
                        [ -7.76367188e-02,  -7.90100098e-02],
                        [ -6.15844727e-02,  -6.35375977e-02],
                        [ -5.21240234e-02,  -5.36499023e-02],
                        [ -4.64172363e-02,  -4.62036133e-02],
                        [ -4.71801758e-02,  -4.47692871e-02],
                        [ -5.45959473e-02,  -5.11474609e-02],
                        [ -5.99670410e-02,  -5.78308105e-02],
                        [ -5.27343750e-02,  -5.35888672e-02],
                        [ -3.31115723e-02,  -3.64379883e-02],
                        [ -1.26342773e-02,  -1.60827637e-02],
                        [ -1.46484375e-03,  -2.74658203e-03],
                        [ -2.13623047e-04,   1.06811523e-03],
                        [ -3.93676758e-03,  -1.40380859e-03],
                        [ -9.76562500e-03,  -7.65991211e-03],
                        [ -1.83715820e-02,  -1.76086426e-02],
                        [ -3.01818848e-02,  -3.06396484e-02],
                        [ -4.30908203e-02,  -4.41894531e-02],
                        [ -5.62133789e-02,  -5.74340820e-02],
                        [ -7.18078613e-02,  -7.27844238e-02],
                        [ -8.80432129e-02,  -8.83789062e-02],
                        [ -9.19189453e-02,  -9.14306641e-02],
                        [ -6.94580078e-02,  -6.83898926e-02],
                        [ -2.29797363e-02,  -2.21862793e-02],
                        [  2.96020508e-02,   2.94799805e-02],
                        [  7.19604492e-02,   7.11669922e-02],
                        [  9.82666016e-02,   9.77172852e-02],
                        [  1.08459473e-01,   1.08947754e-01],
                        [  1.03698730e-01,   1.04980469e-01],
                        [  8.73413086e-02,   8.81347656e-02],
                        [  6.81152344e-02,   6.74133301e-02],
                        [  5.69458008e-02,   5.48095703e-02],
                        [  5.56030273e-02,   5.34057617e-02],
                        [  5.59082031e-02,   5.53894043e-02],
                        [  5.32836914e-02,   5.52673340e-02],
                        [  5.22460938e-02,   5.57556152e-02],
                        [  5.59692383e-02,   5.85937500e-02],
                        [  5.98449707e-02,   5.96618652e-02],
                        [  5.85937500e-02,   5.56030273e-02],
                        [  5.44433594e-02,   5.06591797e-02],
                        [  5.52368164e-02,   5.31921387e-02],
                        [  6.45141602e-02,   6.52770996e-02],
                        [  7.78808594e-02,   8.05969238e-02],
                        [  9.18579102e-02,   9.46044922e-02],
                        [  1.08245850e-01,   1.09588623e-01],
                        [  1.26159668e-01,   1.25793457e-01],
                        [  1.36779785e-01,   1.35406494e-01],
                        [  1.29119873e-01,   1.27593994e-01],
                        [  9.49401855e-02,   9.37194824e-02],
                        [  2.87170410e-02,   2.79235840e-02],
                        [ -6.73522949e-02,  -6.72607422e-02],
                        [ -1.74072266e-01,  -1.72851562e-01],
                        [ -2.58483887e-01,  -2.56622314e-01],
                        [ -2.92510986e-01,  -2.91259766e-01],
                        [ -2.71484375e-01,  -2.71789551e-01],
                        [ -2.15698242e-01,  -2.17254639e-01],
                        [ -1.54846191e-01,  -1.56341553e-01],
                        [ -1.10351562e-01,  -1.10504150e-01],
                        [ -8.80126953e-02,  -8.68530273e-02],
                        [ -8.16345215e-02,  -8.03833008e-02],
                        [ -8.05664062e-02,  -8.05969238e-02],
                        [ -7.88574219e-02,  -8.02612305e-02],
                        [ -7.83081055e-02,  -7.97729492e-02],
                        [ -7.91931152e-02,  -7.92846680e-02],
                        [ -7.30590820e-02,  -7.14416504e-02],
                        [ -5.35583496e-02,  -5.13305664e-02],
                        [ -2.80761719e-02,  -2.69165039e-02],
                        [ -8.48388672e-03,  -9.30786133e-03],
                        [  3.35693359e-03,   1.06811523e-03],
                        [  1.05285645e-02,   8.30078125e-03],
                        [  8.33129883e-03,   7.59887695e-03],
                        [ -1.01013184e-02,  -9.06372070e-03],
                        [ -3.86047363e-02,  -3.65905762e-02],
                        [ -6.06384277e-02,  -5.88684082e-02],
                        [ -6.59790039e-02,  -6.53381348e-02],
                        [ -5.50537109e-02,  -5.56640625e-02],
                        [ -2.81372070e-02,  -2.94799805e-02],
                        [  1.69677734e-02,   1.57775879e-02],
                        [  7.55004883e-02,   7.50122070e-02],
                        [  1.32781982e-01,   1.32843018e-01],
                        [  1.72973633e-01,   1.73156738e-01],
                        [  1.87316895e-01,   1.87500000e-01],
                        [  1.76116943e-01,   1.76605225e-01],
                        [  1.49414062e-01,   1.50329590e-01],
                        [  1.23901367e-01,   1.24877930e-01],
                        [  1.10992432e-01,   1.11389160e-01],
                        [  1.07299805e-01,   1.06689453e-01],
                        [  1.02111816e-01,   1.00585938e-01],
                        [  9.16442871e-02,   8.99658203e-02],
                        [  7.91320801e-02,   7.83386230e-02],
                        [  6.47583008e-02,   6.54602051e-02],
                        [  4.67834473e-02,   4.85534668e-02],
                        [  2.97851562e-02,   3.15551758e-02],
                        [  1.91345215e-02,   1.99279785e-02],
                        [  1.01013184e-02,   9.67407227e-03],
                        [ -2.99072266e-03,  -4.30297852e-03],
                        [ -1.09252930e-02,  -1.24206543e-02],
                        [ -9.46044922e-04,  -1.89208984e-03],
                        [  2.05383301e-02,   2.04467773e-02],
                        [  3.57666016e-02,   3.64379883e-02],
                        [  4.22973633e-02,   4.33654785e-02],
                        [  5.30395508e-02,   5.41076660e-02],
                        [  7.49511719e-02,   7.55615234e-02],
                        [  1.02447510e-01,   1.02233887e-01],
                        [  1.25091553e-01,   1.24298096e-01],
                        [  1.28234863e-01,   1.27410889e-01],
                        [  9.49096680e-02,   9.44519043e-02],
                        [  2.17285156e-02,   2.16064453e-02],
                        [ -7.22045898e-02,  -7.21740723e-02],
                        [ -1.57226562e-01,  -1.57135010e-01],
                        [ -2.08465576e-01,  -2.08251953e-01],
                        [ -2.13562012e-01,  -2.13012695e-01],
                        [ -1.79321289e-01,  -1.78436279e-01],
                        [ -1.31072998e-01,  -1.30310059e-01],
                        [ -9.45434570e-02,  -9.45129395e-02],
                        [ -7.75756836e-02,  -7.86437988e-02],
                        [ -7.24487305e-02,  -7.42187500e-02],
                        [ -7.00988770e-02,  -7.15637207e-02],
                        [ -6.74438477e-02,  -6.75659180e-02],
                        [ -6.44836426e-02,  -6.28662109e-02],
                        [ -6.08520508e-02,  -5.84411621e-02],
                        [ -5.53283691e-02,  -5.36804199e-02],
                        [ -4.51049805e-02,  -4.52880859e-02],
                        [ -2.76184082e-02,  -2.94799805e-02],
                        [ -7.11059570e-03,  -9.39941406e-03],
                        [  4.79125977e-03,   3.44848633e-03],
                        [  1.83105469e-04,   4.88281250e-04],
                        [ -1.57165527e-02,  -1.41296387e-02],
                        [ -3.18298340e-02,  -3.01208496e-02],
                        [ -4.32739258e-02,  -4.25109863e-02],
                        [ -5.18188477e-02,  -5.21545410e-02],
                        [ -5.95397949e-02,  -6.04858398e-02],
                        [ -6.76879883e-02,  -6.84814453e-02],
                        [ -7.55310059e-02,  -7.57751465e-02],
                        [ -7.66601562e-02,  -7.65075684e-02],
                        [ -6.09130859e-02,  -6.07299805e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [  2.36816406e-02,   2.36206055e-02],
                        [  6.77490234e-02,   6.77795410e-02],
                        [  9.56115723e-02,   9.57946777e-02],
                        [  1.03851318e-01,   1.04187012e-01],
                        [  9.57641602e-02,   9.61608887e-02],
                        [  7.99865723e-02,   8.02917480e-02],
                        [  6.88781738e-02,   6.86950684e-02],
                        [  6.79016113e-02,   6.71386719e-02],
                        [  6.93664551e-02,   6.84204102e-02],
                        [  6.57653809e-02,   6.51550293e-02],
                        [  6.31408691e-02,   6.33239746e-02],
                        [  6.91528320e-02,   7.01904297e-02],
                        [  7.56835938e-02,   7.70874023e-02],
                        [  6.96105957e-02,   7.04650879e-02],
                        [  5.49926758e-02,   5.46569824e-02],
                        [  4.78820801e-02,   4.66918945e-02],
                        [  5.39245605e-02,   5.26733398e-02],
                        [  6.60705566e-02,   6.55212402e-02],
                        [  8.19396973e-02,   8.21533203e-02],
                        [  1.05651855e-01,   1.06262207e-01],
                        [  1.32354736e-01,   1.32995605e-01],
                        [  1.45080566e-01,   1.45629883e-01],
                        [  1.30035400e-01,   1.30493164e-01],
                        [  8.64868164e-02,   8.66088867e-02],
                        [  1.94396973e-02,   1.89208984e-02],
                        [ -6.67114258e-02,  -6.77795410e-02],
                        [ -1.61102295e-01,  -1.61987305e-01],
                        [ -2.39135742e-01,  -2.39105225e-01],
                        [ -2.73864746e-01,  -2.72949219e-01],
                        [ -2.57629395e-01,  -2.56652832e-01],
                        [ -2.08862305e-01,  -2.08648682e-01],
                        [ -1.56738281e-01,  -1.57348633e-01],
                        [ -1.21093750e-01,  -1.21765137e-01],
                        [ -1.04675293e-01,  -1.04614258e-01],
                        [ -9.82055664e-02,  -9.75341797e-02],
                        [ -9.14611816e-02,  -9.09118652e-02],
                        [ -8.20922852e-02,  -8.22753906e-02],
                        [ -7.41577148e-02,  -7.49816895e-02],
                        [ -6.82373047e-02,  -6.90307617e-02],
                        [ -5.90515137e-02,  -5.92041016e-02],
                        [ -4.39453125e-02,  -4.33959961e-02],
                        [ -2.58789062e-02,  -2.50244141e-02],
                        [ -8.66699219e-03,  -8.05664062e-03],
                        [  3.14331055e-03,   3.23486328e-03],
                        [  4.11987305e-03,   3.81469727e-03],
                        [ -7.29370117e-03,  -7.75146484e-03],
                        [ -2.89611816e-02,  -2.94799805e-02],
                        [ -5.65795898e-02,  -5.70983887e-02],
                        [ -7.71484375e-02,  -7.74841309e-02],
                        [ -7.23571777e-02,  -7.22045898e-02],
                        [ -3.82995605e-02,  -3.75671387e-02],
                        [  1.19628906e-02,   1.30004883e-02],
                        [  6.99462891e-02,   7.07092285e-02],
                        [  1.35559082e-01,   1.35498047e-01],
                        [  1.95556641e-01,   1.94671631e-01],
                        [  2.24090576e-01,   2.22900391e-01],
                        [  2.11975098e-01,   2.11212158e-01],
                        [  1.77032471e-01,   1.77093506e-01],
                        [  1.40686035e-01,   1.41357422e-01],
                        [  1.10656738e-01,   1.11450195e-01],
                        [  8.75244141e-02,   8.81347656e-02],
                        [  7.27539062e-02,   7.30590820e-02],
                        [  6.68945312e-02,   6.68334961e-02],
                        [  6.80236816e-02,   6.75964355e-02],
                        [  7.23571777e-02,   7.16552734e-02],
                        [  7.35168457e-02,   7.27844238e-02],
                        [  6.46972656e-02,   6.42700195e-02],
                        [  4.47998047e-02,   4.50439453e-02],
                        [  2.03857422e-02,   2.12707520e-02],
                        [  9.15527344e-05,   1.06811523e-03],
                        [ -1.15661621e-02,  -1.11083984e-02],
                        [ -1.38854980e-02,  -1.41296387e-02],
                        [ -5.79833984e-03,  -6.53076172e-03],
                        [  1.32141113e-02,   1.24816895e-02],
                        [  3.87268066e-02,   3.83605957e-02],
                        [  6.17370605e-02,   6.18591309e-02],
                        [  7.59887695e-02,   7.63854980e-02],
                        [  8.22143555e-02,   8.25500488e-02],
                        [  8.62121582e-02,   8.63647461e-02],
                        [  9.34448242e-02,   9.35058594e-02],
                        [  1.02508545e-01,   1.02630615e-01],
                        [  1.01898193e-01,   1.01989746e-01],
                        [  7.54089355e-02,   7.53479004e-02],
                        [  1.51062012e-02,   1.48315430e-02],
                        [ -6.96411133e-02,  -7.00683594e-02],
                        [ -1.53259277e-01,  -1.53594971e-01],
                        [ -2.04925537e-01,  -2.04925537e-01],
                        [ -2.06298828e-01,  -2.05902100e-01],
                        [ -1.65863037e-01,  -1.65283203e-01],
                        [ -1.11907959e-01,  -1.11480713e-01],
                        [ -6.83288574e-02,  -6.82373047e-02],
                        [ -4.17480469e-02,  -4.19006348e-02],
                        [ -3.11889648e-02,  -3.15856934e-02],
                        [ -3.64685059e-02,  -3.69873047e-02],
                        [ -5.20019531e-02,  -5.24597168e-02],
                        [ -6.64367676e-02,  -6.65893555e-02],
                        [ -7.50427246e-02,  -7.47070312e-02],
                        [ -8.13293457e-02,  -8.05664062e-02],
                        [ -8.33435059e-02,  -8.25500488e-02],
                        [ -7.11975098e-02,  -7.08923340e-02],
                        [ -4.35485840e-02,  -4.40063477e-02],
                        [ -1.53198242e-02,  -1.62353516e-02],
                        [ -1.67846680e-03,  -2.50244141e-03],
                        [ -2.41088867e-03,  -2.56347656e-03],
                        [ -7.65991211e-03,  -7.14111328e-03],
                        [ -1.37329102e-02,  -1.29699707e-02],
                        [ -2.63977051e-02,  -2.59094238e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -7.79418945e-02,  -7.82775879e-02],
                        [ -9.53674316e-02,  -9.57336426e-02],
                        [ -9.02099609e-02,  -9.03930664e-02],
                        [ -6.04858398e-02,  -6.04553223e-02],
                        [ -1.29089355e-02,  -1.28173828e-02],
                        [  4.12292480e-02,   4.12902832e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  1.19232178e-01,   1.19201660e-01],
                        [  1.27624512e-01,   1.27685547e-01],
                        [  1.17950439e-01,   1.18103027e-01],
                        [  9.93652344e-02,   9.94567871e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  6.48193359e-02,   6.46972656e-02],
                        [  5.38940430e-02,   5.37719727e-02],
                        [  4.79125977e-02,   4.78210449e-02],
                        [  4.69360352e-02,   4.68444824e-02],
                        [  4.99877930e-02,   4.98657227e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  5.68847656e-02,   5.70373535e-02],
                        [  5.92956543e-02,   5.96008301e-02],
                        [  6.73828125e-02,   6.76574707e-02],
                        [  8.30383301e-02,   8.30688477e-02],
                        [  1.01409912e-01,   1.01196289e-01],
                        [  1.18438721e-01,   1.18072510e-01],
                        [  1.32507324e-01,   1.32171631e-01],
                        [  1.38183594e-01,   1.38061523e-01],
                        [  1.26312256e-01,   1.26464844e-01],
                        [  8.84399414e-02,   8.87756348e-02],
                        [  1.82495117e-02,   1.85852051e-02],
                        [ -8.16955566e-02,  -8.15734863e-02],
                        [ -1.90063477e-01,  -1.90185547e-01],
                        [ -2.72583008e-01,  -2.72796631e-01],
                        [ -3.04199219e-01,  -3.04321289e-01],
                        [ -2.83050537e-01,  -2.83111572e-01],
                        [ -2.28271484e-01,  -2.28363037e-01],
                        [ -1.68304443e-01,  -1.68457031e-01],
                        [ -1.24877930e-01,  -1.24938965e-01],
                        [ -1.00860596e-01,  -1.00646973e-01],
                        [ -8.63952637e-02,  -8.59680176e-02],
                        [ -7.44018555e-02,  -7.40356445e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -5.44433594e-02,  -5.48706055e-02],
                        [ -4.10461426e-02,  -4.15344238e-02],
                        [ -2.22778320e-02,  -2.25219727e-02],
                        [ -2.10571289e-03,  -1.95312500e-03],
                        [  1.26647949e-02,   1.29699707e-02],
                        [  1.78222656e-02,   1.79748535e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [ -6.19506836e-03,  -6.22558594e-03],
                        [ -3.94592285e-02,  -3.93981934e-02],
                        [ -7.81250000e-02,  -7.79418945e-02],
                        [ -1.01898193e-01,  -1.01806641e-01],
                        [ -9.59167480e-02,  -9.61303711e-02],
                        [ -6.29577637e-02,  -6.33850098e-02],
                        [ -1.55334473e-02,  -1.58996582e-02],
                        [  3.97338867e-02,   3.97033691e-02],
                        [  1.02966309e-01,   1.03363037e-01],
                        [  1.67144775e-01,   1.67724609e-01],
                        [  2.12799072e-01,   2.13195801e-01],
                        [  2.23968506e-01,   2.23907471e-01],
                        [  2.03887939e-01,   2.03430176e-01],
                        [  1.70562744e-01,   1.70013428e-01],
                        [  1.40716553e-01,   1.40411377e-01],
                        [  1.19689941e-01,   1.19750977e-01],
                        [  1.02508545e-01,   1.02813721e-01],
                        [  8.33435059e-02,   8.37402344e-02],
                        [  6.38732910e-02,   6.40869141e-02],
                        [  5.02624512e-02,   5.02929688e-02],
                        [  4.34570312e-02,   4.33349609e-02],
                        [  3.60412598e-02,   3.58581543e-02],
                        [  2.05993652e-02,   2.03857422e-02],
                        [ -2.13623047e-04,  -3.96728516e-04],
                        [ -1.43127441e-02,  -1.43737793e-02],
                        [ -1.34277344e-02,  -1.33361816e-02],
                        [ -2.25830078e-03,  -2.04467773e-03],
                        [  8.54492188e-03,   8.78906250e-03],
                        [  1.42211914e-02,   1.43432617e-02],
                        [  1.65405273e-02,   1.64794922e-02],
                        [  1.88903809e-02,   1.86767578e-02],
                        [  2.60009766e-02,   2.57873535e-02],
                        [  4.26025391e-02,   4.25415039e-02],
                        [  6.59484863e-02,   6.59790039e-02],
                        [  8.51440430e-02,   8.52355957e-02],
                        [  9.42993164e-02,   9.43908691e-02],
                        [  9.96704102e-02,   9.97009277e-02],
                        [  1.06140137e-01,   1.06170654e-01],
                        [  1.02783203e-01,   1.02813721e-01],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  3.96728516e-04,   3.35693359e-04],
                        [ -9.32922363e-02,  -9.34143066e-02],
                        [ -1.79382324e-01,  -1.79473877e-01],
                        [ -2.24609375e-01,  -2.24578857e-01],
                        [ -2.16400146e-01,  -2.16278076e-01],
                        [ -1.73095703e-01,  -1.72973633e-01],
                        [ -1.27380371e-01,  -1.27349854e-01],
                        [ -9.91516113e-02,  -9.92126465e-02],
                        [ -8.60900879e-02,  -8.61511230e-02],
                        [ -7.62939453e-02,  -7.62939453e-02],
                        [ -6.44226074e-02,  -6.43615723e-02],
                        [ -5.41381836e-02,  -5.41076660e-02],
                        [ -4.94995117e-02,  -4.95605469e-02],
                        [ -4.88281250e-02,  -4.89807129e-02],
                        [ -4.76074219e-02,  -4.76989746e-02],
                        [ -4.26940918e-02,  -4.26330566e-02],
                        [ -3.31115723e-02,  -3.29284668e-02],
                        [ -2.05993652e-02,  -2.04162598e-02],
                        [ -1.05590820e-02,  -1.04980469e-02],
                        [ -8.17871094e-03,  -8.30078125e-03],
                        [ -1.40686035e-02,  -1.42822266e-02],
                        [ -2.74047852e-02,  -2.75573730e-02],
                        [ -4.89807129e-02,  -4.89501953e-02],
                        [ -7.52563477e-02,  -7.51037598e-02],
                        [ -9.51232910e-02,  -9.49707031e-02],
                        [ -9.99145508e-02,  -9.98535156e-02],
                        [ -9.05456543e-02,  -9.05761719e-02],
                        [ -6.92443848e-02,  -6.93359375e-02],
                        [ -3.29284668e-02,  -3.29895020e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  7.68432617e-02,   7.68737793e-02],
                        [  1.24786377e-01,   1.24786377e-01],
                        [  1.48925781e-01,   1.48925781e-01],
                        [  1.43310547e-01,   1.43310547e-01],
                        [  1.14044189e-01,   1.14074707e-01],
                        [  7.88574219e-02,   7.88574219e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  6.22863770e-02,   6.23168945e-02],
                        [  6.92749023e-02,   6.93054199e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  7.84606934e-02,   7.83996582e-02],
                        [  8.71887207e-02,   8.70971680e-02],
                        [  9.56420898e-02,   9.55810547e-02],
                        [  1.00219727e-01,   1.00250244e-01],
                        [  1.01562500e-01,   1.01654053e-01],
                        [  1.03332520e-01,   1.03424072e-01],
                        [  1.09161377e-01,   1.09222412e-01],
                        [  1.19812012e-01,   1.19781494e-01],
                        [  1.28021240e-01,   1.27929688e-01],
                        [  1.16943359e-01,   1.16851807e-01],
                        [  7.01293945e-02,   7.00988770e-02],
                        [ -1.47399902e-02,  -1.47094727e-02],
                        [ -1.22100830e-01,  -1.22039795e-01],
                        [ -2.22503662e-01,  -2.22473145e-01],
                        [ -2.82257080e-01,  -2.82226562e-01],
                        [ -2.82531738e-01,  -2.82501221e-01],
                        [ -2.36663818e-01,  -2.36663818e-01],
                        [ -1.80969238e-01,  -1.80969238e-01],
                        [ -1.44226074e-01,  -1.44287109e-01],
                        [ -1.28479004e-01,  -1.28570557e-01],
                        [ -1.17797852e-01,  -1.17858887e-01],
                        [ -1.00250244e-01,  -1.00250244e-01],
                        [ -7.76977539e-02,  -7.76062012e-02],
                        [ -5.77087402e-02,  -5.76171875e-02],
                        [ -4.41589355e-02,  -4.41284180e-02],
                        [ -3.66821289e-02,  -3.67431641e-02],
                        [ -3.23181152e-02,  -3.24096680e-02],
                        [ -2.64892578e-02,  -2.65502930e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -9.39941406e-03,  -9.36889648e-03],
                        [ -9.36889648e-03,  -9.33837891e-03],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  4.20532227e-02,   4.20227051e-02],
                        [  9.95788574e-02,   9.95483398e-02],
                        [  1.60156250e-01,   1.60125732e-01],
                        [  2.01385498e-01,   2.01385498e-01],
                        [  2.04956055e-01,   2.04986572e-01],
                        [  1.77459717e-01,   1.77490234e-01],
                        [  1.46209717e-01,   1.46240234e-01],
                        [  1.32232666e-01,   1.32232666e-01],
                        [  1.31164551e-01,   1.31164551e-01],
                        [  1.24481201e-01,   1.24481201e-01],
                        [  1.04797363e-01,   1.04766846e-01],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  6.34765625e-02,   6.35070801e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -2.99072266e-03,  -3.02124023e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  4.57458496e-02,   4.57458496e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  8.37707520e-02,   8.37707520e-02],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  1.05468750e-01,   1.05468750e-01],
                        [  1.06536865e-01,   1.06536865e-01],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -1.15356445e-01,  -1.15356445e-01],
                        [ -1.88293457e-01,  -1.88293457e-01],
                        [ -2.10723877e-01,  -2.10723877e-01],
                        [ -1.83807373e-01,  -1.83807373e-01],
                        [ -1.39282227e-01,  -1.39282227e-01],
                        [ -1.07666016e-01,  -1.07666016e-01],
                        [ -9.48791504e-02,  -9.48791504e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -8.48999023e-02,  -8.48999023e-02],
                        [ -7.59582520e-02,  -7.59582520e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -7.49816895e-02,  -7.49816895e-02],
                        [ -8.98132324e-02,  -8.98132324e-02],
                        [ -9.60388184e-02,  -9.60388184e-02],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  1.20666504e-01,   1.20666504e-01],
                        [  1.35253906e-01,   1.35253906e-01],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  9.50317383e-02,   9.50317383e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  8.37097168e-02,   8.37097168e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  1.20361328e-01,   1.20361328e-01],
                        [  1.38244629e-01,   1.38244629e-01],
                        [  1.43829346e-01,   1.43829346e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  7.08007812e-02,   7.08007812e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -1.00097656e-01,  -1.00097656e-01],
                        [ -1.95800781e-01,  -1.95800781e-01],
                        [ -2.67883301e-01,  -2.67883301e-01],
                        [ -2.89367676e-01,  -2.89367676e-01],
                        [ -2.56805420e-01,  -2.56805420e-01],
                        [ -1.97143555e-01,  -1.97143555e-01],
                        [ -1.45629883e-01,  -1.45629883e-01],
                        [ -1.20727539e-01,  -1.20727539e-01],
                        [ -1.17401123e-01,  -1.17401123e-01],
                        [ -1.17309570e-01,  -1.17309570e-01],
                        [ -1.05926514e-01,  -1.05926514e-01],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  1.05224609e-01,   1.05224609e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.80389404e-01,   1.80389404e-01],
                        [  1.82861328e-01,   1.82861328e-01],
                        [  1.64520264e-01,   1.64520264e-01],
                        [  1.44348145e-01,   1.44348145e-01],
                        [  1.36749268e-01,   1.36749268e-01],
                        [  1.36749268e-01,   1.36749268e-01],
                        [  1.29577637e-01,   1.29577637e-01],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  8.20922852e-02,   8.20922852e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  6.57653809e-02,   6.57653809e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.13067627e-01,   1.13067627e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  5.97839355e-02,   5.97839355e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.85028076e-01,  -1.85028076e-01],
                        [ -2.15850830e-01,  -2.15850830e-01],
                        [ -1.97601318e-01,  -1.97601318e-01],
                        [ -1.51580811e-01,  -1.51580811e-01],
                        [ -1.06567383e-01,  -1.06567383e-01],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -8.19702148e-02,  -8.19702148e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -7.16857910e-02,  -7.16857910e-02],
                        [ -7.48596191e-02,  -7.48596191e-02],
                        [ -7.01293945e-02,  -7.01293945e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  1.06323242e-01,   1.06323242e-01],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  9.62829590e-02,   9.62829590e-02],
                        [  1.08093262e-01,   1.08093262e-01],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  1.27746582e-01,   1.27746582e-01],
                        [  1.29180908e-01,   1.29180908e-01],
                        [  1.37207031e-01,   1.37207031e-01],
                        [  1.40411377e-01,   1.40411377e-01],
                        [  1.20666504e-01,   1.20666504e-01],
                        [  6.88476562e-02,   6.88476562e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -9.25903320e-02,  -9.25903320e-02],
                        [ -1.76239014e-01,  -1.76239014e-01],
                        [ -2.47253418e-01,  -2.47253418e-01],
                        [ -2.83325195e-01,  -2.83325195e-01],
                        [ -2.65930176e-01,  -2.65930176e-01],
                        [ -2.09716797e-01,  -2.09716797e-01],
                        [ -1.56219482e-01,  -1.56219482e-01],
                        [ -1.30310059e-01,  -1.30310059e-01],
                        [ -1.20483398e-01,  -1.20483398e-01],
                        [ -1.06903076e-01,  -1.06903076e-01],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -7.74841309e-02,  -7.74841309e-02],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -7.13500977e-02,  -7.13500977e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  2.00134277e-01,   2.00134277e-01],
                        [  1.94335938e-01,   1.94335938e-01],
                        [  1.67907715e-01,   1.67907715e-01],
                        [  1.40380859e-01,   1.40380859e-01],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  5.52673340e-02,   5.52673340e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.14379883e-01,   1.14379883e-01],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [ -8.95080566e-02,  -8.95080566e-02],
                        [ -1.72851562e-01,  -1.72851562e-01],
                        [ -2.08496094e-01,  -2.08496094e-01],
                        [ -1.88354492e-01,  -1.88354492e-01],
                        [ -1.39434814e-01,  -1.39434814e-01],
                        [ -1.00708008e-01,  -1.00708008e-01],
                        [ -8.89282227e-02,  -8.89282227e-02],
                        [ -9.08813477e-02,  -9.08813477e-02],
                        [ -8.69140625e-02,  -8.69140625e-02],
                        [ -7.44018555e-02,  -7.44018555e-02],
                        [ -6.44836426e-02,  -6.44836426e-02],
                        [ -6.25000000e-02,  -6.25000000e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -7.87963867e-02,  -7.87963867e-02],
                        [ -9.46655273e-02,  -9.46655273e-02],
                        [ -1.01440430e-01,  -1.01440430e-01],
                        [ -9.09729004e-02,  -9.09729004e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  1.18591309e-01,   1.18591309e-01],
                        [  1.30706787e-01,   1.30706787e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  9.21936035e-02,   9.21936035e-02],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  8.58764648e-02,   8.58764648e-02],
                        [  9.10339355e-02,   9.10339355e-02],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  1.15264893e-01,   1.15264893e-01],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.31927490e-01,   1.31927490e-01],
                        [  1.45355225e-01,   1.45355225e-01],
                        [  1.55731201e-01,   1.55731201e-01],
                        [  1.53656006e-01,   1.53656006e-01],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  7.13500977e-02,   7.13500977e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.12365723e-01,  -1.12365723e-01],
                        [ -2.07885742e-01,  -2.07885742e-01],
                        [ -2.80487061e-01,  -2.80487061e-01],
                        [ -3.06213379e-01,  -3.06213379e-01],
                        [ -2.73468018e-01,  -2.73468018e-01],
                        [ -2.05810547e-01,  -2.05810547e-01],
                        [ -1.47949219e-01,  -1.47949219e-01],
                        [ -1.21337891e-01,  -1.21337891e-01],
                        [ -1.10412598e-01,  -1.10412598e-01],
                        [ -9.56115723e-02,  -9.56115723e-02],
                        [ -7.99560547e-02,  -7.99560547e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -7.52258301e-02,  -7.52258301e-02],
                        [ -7.11975098e-02,  -7.11975098e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  1.36474609e-01,   1.36474609e-01],
                        [  1.86889648e-01,   1.86889648e-01],
                        [  2.12524414e-01,   2.12524414e-01],
                        [  2.10357666e-01,   2.10357666e-01],
                        [  1.85729980e-01,   1.85729980e-01],
                        [  1.54907227e-01,   1.54907227e-01],
                        [  1.31927490e-01,   1.31927490e-01],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  5.02624512e-02,   5.02624512e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  7.30285645e-02,   7.30285645e-02],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  8.70666504e-02,   8.70666504e-02],
                        [  8.11462402e-02,   8.11462402e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -9.57336426e-02,  -9.57336426e-02],
                        [ -1.69036865e-01,  -1.69036865e-01],
                        [ -2.01538086e-01,  -2.01538086e-01],
                        [ -1.83044434e-01,  -1.83044434e-01],
                        [ -1.35253906e-01,  -1.35253906e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -7.87048340e-02,  -7.87048340e-02],
                        [ -8.14514160e-02,  -8.14514160e-02],
                        [ -8.17260742e-02,  -8.17260742e-02],
                        [ -7.39135742e-02,  -7.39135742e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -7.80944824e-02,  -7.80944824e-02],
                        [ -9.01184082e-02,  -9.01184082e-02],
                        [ -9.60388184e-02,  -9.60388184e-02],
                        [ -9.33837891e-02,  -9.33837891e-02],
                        [ -8.08715820e-02,  -8.08715820e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -7.11669922e-02,  -7.11669922e-02],
                        [ -7.76977539e-02,  -7.76977539e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  8.35266113e-02,   8.35266113e-02],
                        [  8.00170898e-02,   8.00170898e-02],
                        [  9.07287598e-02,   9.07287598e-02],
                        [  1.04461670e-01,   1.04461670e-01],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  1.24084473e-01,   1.24084473e-01],
                        [  1.43066406e-01,   1.43066406e-01],
                        [  1.61804199e-01,   1.61804199e-01],
                        [  1.75750732e-01,   1.75750732e-01],
                        [  1.79687500e-01,   1.79687500e-01],
                        [  1.64581299e-01,   1.64581299e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  5.61218262e-02,   5.61218262e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -1.41357422e-01,  -1.41357422e-01],
                        [ -2.41485596e-01,  -2.41485596e-01],
                        [ -3.02917480e-01,  -3.02917480e-01],
                        [ -3.07128906e-01,  -3.07128906e-01],
                        [ -2.65472412e-01,  -2.65472412e-01],
                        [ -2.08831787e-01,  -2.08831787e-01],
                        [ -1.64001465e-01,  -1.64001465e-01],
                        [ -1.37390137e-01,  -1.37390137e-01],
                        [ -1.17431641e-01,  -1.17431641e-01],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  6.90917969e-02,   6.90917969e-02],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.69403076e-01,   1.69403076e-01],
                        [  1.98944092e-01,   1.98944092e-01],
                        [  2.10388184e-01,   2.10388184e-01],
                        [  2.01293945e-01,   2.01293945e-01],
                        [  1.78009033e-01,   1.78009033e-01],
                        [  1.53381348e-01,   1.53381348e-01],
                        [  1.35772705e-01,   1.35772705e-01],
                        [  1.23199463e-01,   1.23199463e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  8.77075195e-02,   8.77075195e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  4.08935547e-03,   4.08935547e-03],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  8.58154297e-02,   8.58154297e-02],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  9.29260254e-02,   9.29260254e-02],
                        [  8.67614746e-02,   8.67614746e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -1.16333008e-01,  -1.16333008e-01],
                        [ -1.74102783e-01,  -1.74102783e-01],
                        [ -1.92962646e-01,  -1.92962646e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -1.22741699e-01,  -1.22741699e-01],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -6.79931641e-02,  -6.79931641e-02],
                        [ -7.94067383e-02,  -7.94067383e-02],
                        [ -8.63952637e-02,  -8.63952637e-02],
                        [ -9.05456543e-02,  -9.05456543e-02],
                        [ -9.56420898e-02,  -9.56420898e-02],
                        [ -9.88464355e-02,  -9.88464355e-02],
                        [ -9.40551758e-02,  -9.40551758e-02],
                        [ -8.02917480e-02,  -8.02917480e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  6.89392090e-02,   6.89392090e-02],
                        [  1.02203369e-01,   1.02203369e-01],
                        [  1.24511719e-01,   1.24511719e-01],
                        [  1.32843018e-01,   1.32843018e-01],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  9.23156738e-02,   9.23156738e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  1.06323242e-01,   1.06323242e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.24450684e-01,   1.24450684e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.68395996e-01,   1.68395996e-01],
                        [  1.94061279e-01,   1.94061279e-01],
                        [  1.98150635e-01,   1.98150635e-01],
                        [  1.66931152e-01,   1.66931152e-01],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -1.15295410e-01,  -1.15295410e-01],
                        [ -2.28149414e-01,  -2.28149414e-01],
                        [ -3.07159424e-01,  -3.07159424e-01],
                        [ -3.27728271e-01,  -3.27728271e-01],
                        [ -2.84118652e-01,  -2.84118652e-01],
                        [ -2.02178955e-01,  -2.02178955e-01],
                        [ -1.30706787e-01,  -1.30706787e-01],
                        [ -1.01531982e-01,  -1.01531982e-01],
                        [ -1.02996826e-01,  -1.02996826e-01],
                        [ -1.04003906e-01,  -1.04003906e-01],
                        [ -9.24377441e-02,  -9.24377441e-02],
                        [ -7.83386230e-02,  -7.83386230e-02],
                        [ -7.11669922e-02,  -7.11669922e-02],
                        [ -6.82067871e-02,  -6.82067871e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  8.58459473e-02,   8.58459473e-02],
                        [  1.37847900e-01,   1.37847900e-01],
                        [  1.79595947e-01,   1.79595947e-01],
                        [  2.03399658e-01,   2.03399658e-01],
                        [  1.99523926e-01,   1.99523926e-01],
                        [  1.70318604e-01,   1.70318604e-01],
                        [  1.36810303e-01,   1.36810303e-01],
                        [  1.19689941e-01,   1.19689941e-01],
                        [  1.18713379e-01,   1.18713379e-01],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  8.06274414e-02,   8.06274414e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -1.27868652e-01,  -1.27868652e-01],
                        [ -1.79748535e-01,  -1.79748535e-01],
                        [ -1.94671631e-01,  -1.94671631e-01],
                        [ -1.75415039e-01,  -1.75415039e-01],
                        [ -1.43524170e-01,  -1.43524170e-01],
                        [ -1.15539551e-01,  -1.15539551e-01],
                        [ -9.63745117e-02,  -9.63745117e-02],
                        [ -8.82263184e-02,  -8.82263184e-02],
                        [ -8.99658203e-02,  -8.99658203e-02],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -9.30175781e-02,  -9.30175781e-02],
                        [ -8.91113281e-02,  -8.91113281e-02],
                        [ -8.21228027e-02,  -8.21228027e-02],
                        [ -6.82373047e-02,  -6.82373047e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -8.04748535e-02,  -8.04748535e-02],
                        [ -8.25195312e-02,  -8.25195312e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.38153076e-01,   1.38153076e-01],
                        [  1.36566162e-01,   1.36566162e-01],
                        [  1.28387451e-01,   1.28387451e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  8.30688477e-02,   8.30688477e-02],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  1.32781982e-01,   1.32781982e-01],
                        [  1.57501221e-01,   1.57501221e-01],
                        [  1.73767090e-01,   1.73767090e-01],
                        [  1.71234131e-01,   1.71234131e-01],
                        [  1.38244629e-01,   1.38244629e-01],
                        [  6.89392090e-02,   6.89392090e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -1.42059326e-01,  -1.42059326e-01],
                        [ -2.41363525e-01,  -2.41363525e-01],
                        [ -2.98004150e-01,  -2.98004150e-01],
                        [ -2.91595459e-01,  -2.91595459e-01],
                        [ -2.32635498e-01,  -2.32635498e-01],
                        [ -1.62445068e-01,  -1.62445068e-01],
                        [ -1.21429443e-01,  -1.21429443e-01],
                        [ -1.16394043e-01,  -1.16394043e-01],
                        [ -1.23840332e-01,  -1.23840332e-01],
                        [ -1.22314453e-01,  -1.22314453e-01],
                        [ -1.09771729e-01,  -1.09771729e-01],
                        [ -9.22851562e-02,  -9.22851562e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.70166016e-01,   1.70166016e-01],
                        [  2.03979492e-01,   2.03979492e-01],
                        [  2.03491211e-01,   2.03491211e-01],
                        [  1.82586670e-01,   1.82586670e-01],
                        [  1.61224365e-01,   1.61224365e-01],
                        [  1.45874023e-01,   1.45874023e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  8.95996094e-02,   8.95996094e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  9.52758789e-02,   9.52758789e-02],
                        [  7.18383789e-02,   7.18383789e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -1.34002686e-01,  -1.34002686e-01],
                        [ -1.85333252e-01,  -1.85333252e-01],
                        [ -1.99432373e-01,  -1.99432373e-01],
                        [ -1.79626465e-01,  -1.79626465e-01],
                        [ -1.44317627e-01,  -1.44317627e-01],
                        [ -1.14501953e-01,  -1.14501953e-01],
                        [ -9.98535156e-02,  -9.98535156e-02],
                        [ -9.57336426e-02,  -9.57336426e-02],
                        [ -9.22241211e-02,  -9.22241211e-02],
                        [ -8.57238770e-02,  -8.57238770e-02],
                        [ -8.20007324e-02,  -8.20007324e-02],
                        [ -8.53881836e-02,  -8.53881836e-02],
                        [ -8.85925293e-02,  -8.85925293e-02],
                        [ -8.24279785e-02,  -8.24279785e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -6.90307617e-02,  -6.90307617e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.06628418e-01,   1.06628418e-01],
                        [  1.00067139e-01,   1.00067139e-01],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  1.39282227e-01,   1.39282227e-01],
                        [  1.65802002e-01,   1.65802002e-01],
                        [  1.88171387e-01,   1.88171387e-01],
                        [  2.03735352e-01,   2.03735352e-01],
                        [  2.08435059e-01,   2.08435059e-01],
                        [  1.92413330e-01,   1.92413330e-01],
                        [  1.42974854e-01,   1.42974854e-01],
                        [  5.51452637e-02,   5.51452637e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -1.79229736e-01,  -1.79229736e-01],
                        [ -2.78472900e-01,  -2.78472900e-01],
                        [ -3.37982178e-01,  -3.37982178e-01],
                        [ -3.41918945e-01,  -3.41918945e-01],
                        [ -2.88208008e-01,  -2.88208008e-01],
                        [ -2.01202393e-01,  -2.01202393e-01],
                        [ -1.22711182e-01,  -1.22711182e-01],
                        [ -8.21533203e-02,  -8.21533203e-02],
                        [ -7.70874023e-02,  -7.70874023e-02],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -8.34960938e-02,  -8.34960938e-02],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -7.30590820e-02,  -7.30590820e-02],
                        [ -7.03125000e-02,  -7.03125000e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -7.52868652e-02,  -7.52868652e-02],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  1.26190186e-01,   1.26190186e-01],
                        [  1.69647217e-01,   1.69647217e-01],
                        [  1.91436768e-01,   1.91436768e-01],
                        [  1.88171387e-01,   1.88171387e-01],
                        [  1.68762207e-01,   1.68762207e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.38366699e-01,   1.38366699e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.13677979e-01,   1.13677979e-01],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  2.68249512e-02,   2.68249512e-02],
                        [  3.57055664e-03,   3.57055664e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  3.28369141e-02,   3.28369141e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  5.80139160e-02,   5.80139160e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -1.11694336e-01,  -1.11694336e-01],
                        [ -1.75201416e-01,  -1.75201416e-01],
                        [ -1.97418213e-01,  -1.97418213e-01],
                        [ -1.79626465e-01,  -1.79626465e-01],
                        [ -1.42578125e-01,  -1.42578125e-01],
                        [ -1.12335205e-01,  -1.12335205e-01],
                        [ -1.01745605e-01,  -1.01745605e-01],
                        [ -1.04583740e-01,  -1.04583740e-01],
                        [ -1.06445312e-01,  -1.06445312e-01],
                        [ -1.00708008e-01,  -1.00708008e-01],
                        [ -9.34448242e-02,  -9.34448242e-02],
                        [ -9.29260254e-02,  -9.29260254e-02],
                        [ -9.62524414e-02,  -9.62524414e-02],
                        [ -9.15832520e-02,  -9.15832520e-02],
                        [ -7.47070312e-02,  -7.47070312e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  1.11785889e-01,   1.11785889e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.32904053e-01,   1.32904053e-01],
                        [  1.48040771e-01,   1.48040771e-01],
                        [  1.70440674e-01,   1.70440674e-01],
                        [  1.89056396e-01,   1.89056396e-01],
                        [  1.95434570e-01,   1.95434570e-01],
                        [  1.87683105e-01,   1.87683105e-01],
                        [  1.60369873e-01,   1.60369873e-01],
                        [  1.02478027e-01,   1.02478027e-01],
                        [  1.07116699e-02,   1.07116699e-02],
                        [ -1.03332520e-01,  -1.03332520e-01],
                        [ -2.16705322e-01,  -2.16705322e-01],
                        [ -3.00140381e-01,  -3.00140381e-01],
                        [ -3.27758789e-01,  -3.27758789e-01],
                        [ -2.95562744e-01,  -2.95562744e-01],
                        [ -2.28240967e-01,  -2.28240967e-01],
                        [ -1.62261963e-01,  -1.62261963e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -1.06506348e-01,  -1.06506348e-01],
                        [ -1.00616455e-01,  -1.00616455e-01],
                        [ -8.93554688e-02,  -8.93554688e-02],
                        [ -7.36999512e-02,  -7.36999512e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -6.20117188e-02,  -6.20117188e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  1.56524658e-01,   1.56524658e-01],
                        [  1.89605713e-01,   1.89605713e-01],
                        [  1.90734863e-01,   1.90734863e-01],
                        [  1.70715332e-01,   1.70715332e-01],
                        [  1.48620605e-01,   1.48620605e-01],
                        [  1.35681152e-01,   1.35681152e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.32049561e-01,   1.32049561e-01],
                        [  1.30767822e-01,   1.30767822e-01],
                        [  1.22955322e-01,   1.22955322e-01],
                        [  1.07482910e-01,   1.07482910e-01],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  7.34558105e-02,   7.34558105e-02],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  7.95593262e-02,   7.95593262e-02],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  1.12487793e-01,   1.12487793e-01],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -1.59729004e-01,  -1.59729004e-01],
                        [ -1.96441650e-01,  -1.96441650e-01],
                        [ -1.92504883e-01,  -1.92504883e-01],
                        [ -1.63452148e-01,  -1.63452148e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -1.10443115e-01,  -1.10443115e-01],
                        [ -1.04644775e-01,  -1.04644775e-01],
                        [ -1.10443115e-01,  -1.10443115e-01],
                        [ -1.16058350e-01,  -1.16058350e-01],
                        [ -1.13342285e-01,  -1.13342285e-01],
                        [ -1.07238770e-01,  -1.07238770e-01],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -9.11254883e-02,  -9.11254883e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  1.13433838e-01,   1.13433838e-01],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.32873535e-01,   1.32873535e-01],
                        [  1.40411377e-01,   1.40411377e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.85424805e-01,   1.85424805e-01],
                        [  2.15179443e-01,   2.15179443e-01],
                        [  2.22961426e-01,   2.22961426e-01],
                        [  1.94732666e-01,   1.94732666e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  2.55737305e-02,   2.55737305e-02],
                        [ -9.14001465e-02,  -9.14001465e-02],
                        [ -2.00592041e-01,  -2.00592041e-01],
                        [ -2.83172607e-01,  -2.83172607e-01],
                        [ -3.21411133e-01,  -3.21411133e-01],
                        [ -3.02337646e-01,  -3.02337646e-01],
                        [ -2.39257812e-01,  -2.39257812e-01],
                        [ -1.72760010e-01,  -1.72760010e-01],
                        [ -1.34643555e-01,  -1.34643555e-01],
                        [ -1.22528076e-01,  -1.22528076e-01],
                        [ -1.15386963e-01,  -1.15386963e-01],
                        [ -1.01226807e-01,  -1.01226807e-01],
                        [ -8.44726562e-02,  -8.44726562e-02],
                        [ -7.61413574e-02,  -7.61413574e-02],
                        [ -7.99865723e-02,  -7.99865723e-02],
                        [ -8.71582031e-02,  -8.71582031e-02],
                        [ -8.51440430e-02,  -8.51440430e-02],
                        [ -7.17773438e-02,  -7.17773438e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  7.51342773e-02,   7.51342773e-02],
                        [  1.36169434e-01,   1.36169434e-01],
                        [  1.85546875e-01,   1.85546875e-01],
                        [  2.06634521e-01,   2.06634521e-01],
                        [  1.96929932e-01,   1.96929932e-01],
                        [  1.71142578e-01,   1.71142578e-01],
                        [  1.48132324e-01,   1.48132324e-01],
                        [  1.35772705e-01,   1.35772705e-01],
                        [  1.29760742e-01,   1.29760742e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  7.76367188e-02,   7.76367188e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  1.08123779e-01,   1.08123779e-01],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -9.72290039e-02,  -9.72290039e-02],
                        [ -1.63085938e-01,  -1.63085938e-01],
                        [ -1.98425293e-01,  -1.98425293e-01],
                        [ -1.96136475e-01,  -1.96136475e-01],
                        [ -1.69403076e-01,  -1.69403076e-01],
                        [ -1.41571045e-01,  -1.41571045e-01],
                        [ -1.25701904e-01,  -1.25701904e-01],
                        [ -1.18011475e-01,  -1.18011475e-01],
                        [ -1.11083984e-01,  -1.11083984e-01],
                        [ -1.06018066e-01,  -1.06018066e-01],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -1.18560791e-01,  -1.18560791e-01],
                        [ -1.25518799e-01,  -1.25518799e-01],
                        [ -1.17889404e-01,  -1.17889404e-01],
                        [ -9.20715332e-02,  -9.20715332e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  1.20300293e-01,   1.20300293e-01],
                        [  1.33758545e-01,   1.33758545e-01],
                        [  1.36108398e-01,   1.36108398e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.19934082e-01,   1.19934082e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.51306152e-01,   1.51306152e-01],
                        [  1.75933838e-01,   1.75933838e-01],
                        [  1.99615479e-01,   1.99615479e-01],
                        [  2.17742920e-01,   2.17742920e-01],
                        [  2.17376709e-01,   2.17376709e-01],
                        [  1.82708740e-01,   1.82708740e-01],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.28479004e-02,   1.28479004e-02],
                        [ -9.85717773e-02,  -9.85717773e-02],
                        [ -2.09197998e-01,  -2.09197998e-01],
                        [ -2.94952393e-01,  -2.94952393e-01],
                        [ -3.28125000e-01,  -3.28125000e-01],
                        [ -2.99224854e-01,  -2.99224854e-01],
                        [ -2.30529785e-01,  -2.30529785e-01],
                        [ -1.63360596e-01,  -1.63360596e-01],
                        [ -1.26342773e-01,  -1.26342773e-01],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -1.17858887e-01,  -1.17858887e-01],
                        [ -1.16455078e-01,  -1.16455078e-01],
                        [ -1.11694336e-01,  -1.11694336e-01],
                        [ -1.03820801e-01,  -1.03820801e-01],
                        [ -9.19189453e-02,  -9.19189453e-02],
                        [ -7.69042969e-02,  -7.69042969e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  1.16882324e-01,   1.16882324e-01],
                        [  1.81701660e-01,   1.81701660e-01],
                        [  2.25860596e-01,   2.25860596e-01],
                        [  2.34344482e-01,   2.34344482e-01],
                        [  2.10296631e-01,   2.10296631e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.43249512e-01,   1.43249512e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.25091553e-01,   1.25091553e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  1.11511230e-01,   1.11511230e-01],
                        [  1.17889404e-01,   1.17889404e-01],
                        [  1.05926514e-01,   1.05926514e-01],
                        [  6.67419434e-02,   6.67419434e-02],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [ -8.21838379e-02,  -8.21838379e-02],
                        [ -1.56768799e-01,  -1.56768799e-01],
                        [ -2.02301025e-01,  -2.02301025e-01],
                        [ -2.06542969e-01,  -2.06542969e-01],
                        [ -1.79473877e-01,  -1.79473877e-01],
                        [ -1.48345947e-01,  -1.48345947e-01],
                        [ -1.32476807e-01,  -1.32507324e-01],
                        [ -1.28143311e-01,  -1.28143311e-01],
                        [ -1.21734619e-01,  -1.21734619e-01],
                        [ -1.09222412e-01,  -1.09222412e-01],
                        [ -9.76562500e-02,  -9.76562500e-02],
                        [ -9.41467285e-02,  -9.41467285e-02],
                        [ -9.68322754e-02,  -9.68627930e-02],
                        [ -9.64660645e-02,  -9.64660645e-02],
                        [ -8.68530273e-02,  -8.68530273e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -5.95092773e-02,  -5.95397949e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.03912354e-01,   1.03912354e-01],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  1.27319336e-01,   1.27319336e-01],
                        [  1.47369385e-01,   1.47369385e-01],
                        [  1.63635254e-01,   1.63635254e-01],
                        [  1.81488037e-01,   1.81488037e-01],
                        [  2.06909180e-01,   2.06909180e-01],
                        [  2.28851318e-01,   2.28851318e-01],
                        [  2.24700928e-01,   2.24700928e-01],
                        [  1.83624268e-01,   1.83624268e-01],
                        [  1.11938477e-01,   1.11938477e-01],
                        [  1.77001953e-02,   1.77001953e-02],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -2.07763672e-01,  -2.07763672e-01],
                        [ -2.95104980e-01,  -2.95104980e-01],
                        [ -3.25103760e-01,  -3.25103760e-01],
                        [ -2.88146973e-01,  -2.88146973e-01],
                        [ -2.13256836e-01,  -2.13256836e-01],
                        [ -1.51794434e-01,  -1.51794434e-01],
                        [ -1.30126953e-01,  -1.30126953e-01],
                        [ -1.30065918e-01,  -1.30065918e-01],
                        [ -1.25030518e-01,  -1.25030518e-01],
                        [ -1.14440918e-01,  -1.14440918e-01],
                        [ -1.10229492e-01,  -1.10229492e-01],
                        [ -1.11389160e-01,  -1.11389160e-01],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -9.49096680e-02,  -9.49096680e-02],
                        [ -7.88574219e-02,  -7.88574219e-02],
                        [ -6.20117188e-02,  -6.20117188e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.97845459e-01,   1.97845459e-01],
                        [  2.35900879e-01,   2.35900879e-01],
                        [  2.33154297e-01,   2.33154297e-01],
                        [  1.95800781e-01,   1.95800781e-01],
                        [  1.54907227e-01,   1.54907227e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  8.64562988e-02,   8.64868164e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  8.49609375e-02,   8.49609375e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -1.25000000e-01,  -1.25000000e-01],
                        [ -1.86004639e-01,  -1.86004639e-01],
                        [ -2.10296631e-01,  -2.10296631e-01],
                        [ -1.93939209e-01,  -1.93969727e-01],
                        [ -1.56890869e-01,  -1.56890869e-01],
                        [ -1.25823975e-01,  -1.25823975e-01],
                        [ -1.11907959e-01,  -1.11907959e-01],
                        [ -1.09069824e-01,  -1.09069824e-01],
                        [ -1.08978271e-01,  -1.08978271e-01],
                        [ -1.10198975e-01,  -1.10198975e-01],
                        [ -1.13769531e-01,  -1.13769531e-01],
                        [ -1.16027832e-01,  -1.16027832e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -9.40246582e-02,  -9.40246582e-02],
                        [ -7.45239258e-02,  -7.45239258e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -6.06689453e-02,  -6.06689453e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  7.61718750e-02,   7.61718750e-02],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.25885010e-01,   1.25885010e-01],
                        [  1.22222900e-01,   1.22222900e-01],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  1.44348145e-01,   1.44348145e-01],
                        [  1.69158936e-01,   1.69189453e-01],
                        [  1.87530518e-01,   1.87530518e-01],
                        [  2.08160400e-01,   2.08160400e-01],
                        [  2.22106934e-01,   2.22106934e-01],
                        [  2.09381104e-01,   2.09411621e-01],
                        [  1.65863037e-01,   1.65863037e-01],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [ -1.02020264e-01,  -1.02020264e-01],
                        [ -2.18261719e-01,  -2.18261719e-01],
                        [ -3.00445557e-01,  -3.00445557e-01],
                        [ -3.19885254e-01,  -3.19885254e-01],
                        [ -2.78961182e-01,  -2.78961182e-01],
                        [ -2.10845947e-01,  -2.10845947e-01],
                        [ -1.57348633e-01,  -1.57318115e-01],
                        [ -1.37786865e-01,  -1.37786865e-01],
                        [ -1.37084961e-01,  -1.37084961e-01],
                        [ -1.29974365e-01,  -1.29974365e-01],
                        [ -1.12396240e-01,  -1.12396240e-01],
                        [ -9.90295410e-02,  -9.90295410e-02],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -9.90905762e-02,  -9.90905762e-02],
                        [ -9.36889648e-02,  -9.36889648e-02],
                        [ -7.94677734e-02,  -7.94677734e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  1.29180908e-01,   1.29180908e-01],
                        [  1.82006836e-01,   1.82006836e-01],
                        [  2.15057373e-01,   2.15057373e-01],
                        [  2.20764160e-01,   2.20764160e-01],
                        [  2.01354980e-01,   2.01354980e-01],
                        [  1.67297363e-01,   1.67297363e-01],
                        [  1.35162354e-01,   1.35162354e-01],
                        [  1.19934082e-01,   1.19934082e-01],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  1.28021240e-01,   1.28021240e-01],
                        [  1.21490479e-01,   1.21459961e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  8.67309570e-02,   8.67614746e-02],
                        [  6.97631836e-02,   6.97326660e-02],
                        [  5.06896973e-02,   5.06896973e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  9.12475586e-03,   9.15527344e-03],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  1.53808594e-02,   1.53503418e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  7.98645020e-02,   7.98339844e-02],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [ -4.11071777e-02,  -4.10766602e-02],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -2.05352783e-01,  -2.05352783e-01],
                        [ -2.26715088e-01,  -2.26715088e-01],
                        [ -2.03247070e-01,  -2.03247070e-01],
                        [ -1.57714844e-01,  -1.57714844e-01],
                        [ -1.16821289e-01,  -1.16821289e-01],
                        [ -9.79309082e-02,  -9.79309082e-02],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -1.04309082e-01,  -1.04309082e-01],
                        [ -9.98535156e-02,  -9.98535156e-02],
                        [ -8.98437500e-02,  -8.98437500e-02],
                        [ -8.34350586e-02,  -8.34350586e-02],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -8.05969238e-02,  -8.05969238e-02],
                        [ -8.15124512e-02,  -8.15124512e-02],
                        [ -8.22753906e-02,  -8.22448730e-02],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  9.83886719e-02,   9.84191895e-02],
                        [  1.13525391e-01,   1.13525391e-01],
                        [  1.10260010e-01,   1.10229492e-01],
                        [  9.93347168e-02,   9.93652344e-02],
                        [  9.21936035e-02,   9.22241211e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  1.23626709e-01,   1.23626709e-01],
                        [  1.52526855e-01,   1.52526855e-01],
                        [  1.71813965e-01,   1.71813965e-01],
                        [  1.79901123e-01,   1.79870605e-01],
                        [  1.84600830e-01,   1.84600830e-01],
                        [  1.90063477e-01,   1.90093994e-01],
                        [  1.91040039e-01,   1.91040039e-01],
                        [  1.73858643e-01,   1.73858643e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  3.43627930e-02,   3.43627930e-02],
                        [ -7.57751465e-02,  -7.58056641e-02],
                        [ -1.81732178e-01,  -1.81732178e-01],
                        [ -2.62176514e-01,  -2.62176514e-01],
                        [ -3.01025391e-01,  -3.01025391e-01],
                        [ -2.86468506e-01,  -2.86468506e-01],
                        [ -2.26287842e-01,  -2.26287842e-01],
                        [ -1.56677246e-01,  -1.56677246e-01],
                        [ -1.15661621e-01,  -1.15661621e-01],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.11267090e-01,  -1.11297607e-01],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -9.36889648e-02,  -9.36889648e-02],
                        [ -9.53063965e-02,  -9.53063965e-02],
                        [ -9.80224609e-02,  -9.80224609e-02],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -7.82775879e-02,  -7.82775879e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -2.92968750e-03,  -2.89916992e-03],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  1.34979248e-01,   1.34979248e-01],
                        [  2.01141357e-01,   2.01110840e-01],
                        [  2.34222412e-01,   2.34222412e-01],
                        [  2.24853516e-01,   2.24853516e-01],
                        [  1.85241699e-01,   1.85241699e-01],
                        [  1.39587402e-01,   1.39587402e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.10656738e-01,   1.10656738e-01],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  1.17767334e-01,   1.17767334e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.04309082e-01,   1.04309082e-01],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  7.48291016e-02,   7.47985840e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.15661621e-02,   1.15356445e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -2.32238770e-02,  -2.32543945e-02],
                        [ -2.86560059e-02,  -2.86865234e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.98059082e-02,   1.98364258e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  8.11767578e-02,   8.11767578e-02],
                        [  9.61303711e-02,   9.61303711e-02],
                        [  9.80834961e-02,   9.80529785e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -1.38183594e-01,  -1.38183594e-01],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -1.93969727e-01,  -1.93969727e-01],
                        [ -1.64367676e-01,  -1.64398193e-01],
                        [ -1.24633789e-01,  -1.24633789e-01],
                        [ -1.00189209e-01,  -1.00189209e-01],
                        [ -9.90295410e-02,  -9.90295410e-02],
                        [ -1.11267090e-01,  -1.11267090e-01],
                        [ -1.20849609e-01,  -1.20849609e-01],
                        [ -1.18530273e-01,  -1.18530273e-01],
                        [ -1.09191895e-01,  -1.09191895e-01],
                        [ -1.03698730e-01,  -1.03698730e-01],
                        [ -1.01348877e-01,  -1.01348877e-01],
                        [ -9.22546387e-02,  -9.22546387e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -6.90917969e-02,  -6.90917969e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  8.37097168e-02,   8.37097168e-02],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.22406006e-01,   1.22375488e-01],
                        [  1.17828369e-01,   1.17828369e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  1.03118896e-01,   1.03118896e-01],
                        [  1.11785889e-01,   1.11755371e-01],
                        [  1.25427246e-01,   1.25457764e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.51641846e-01,   1.51641846e-01],
                        [  1.72851562e-01,   1.72851562e-01],
                        [  1.94854736e-01,   1.94854736e-01],
                        [  2.04956055e-01,   2.04956055e-01],
                        [  1.93603516e-01,   1.93603516e-01],
                        [  1.53900146e-01,   1.53930664e-01],
                        [  7.89184570e-02,   7.89184570e-02],
                        [ -2.95410156e-02,  -2.95715332e-02],
                        [ -1.52221680e-01,  -1.52191162e-01],
                        [ -2.57690430e-01,  -2.57690430e-01],
                        [ -3.15124512e-01,  -3.15124512e-01],
                        [ -3.06793213e-01,  -3.06762695e-01],
                        [ -2.43896484e-01,  -2.43865967e-01],
                        [ -1.68701172e-01,  -1.68701172e-01],
                        [ -1.24664307e-01,  -1.24664307e-01],
                        [ -1.19720459e-01,  -1.19689941e-01],
                        [ -1.28051758e-01,  -1.28051758e-01],
                        [ -1.27624512e-01,  -1.27624512e-01],
                        [ -1.21185303e-01,  -1.21154785e-01],
                        [ -1.18103027e-01,  -1.18103027e-01],
                        [ -1.15936279e-01,  -1.15966797e-01],
                        [ -1.08581543e-01,  -1.08581543e-01],
                        [ -9.48486328e-02,  -9.48181152e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.83044434e-01,   1.83044434e-01],
                        [  2.16064453e-01,   2.16064453e-01],
                        [  2.19024658e-01,   2.18994141e-01],
                        [  1.92077637e-01,   1.92077637e-01],
                        [  1.53839111e-01,   1.53869629e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.09832764e-01,   1.09863281e-01],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  9.53674316e-02,   9.53369141e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  5.34667969e-02,   5.34973145e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.32849121e-02,  -2.32543945e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [  4.63867188e-03,   4.60815430e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  3.41796875e-03,   3.38745117e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  1.85852051e-02,   1.85546875e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  3.86352539e-02,   3.86657715e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  7.06176758e-02,   7.05871582e-02],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  1.03454590e-01,   1.03424072e-01],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [ -7.86743164e-02,  -7.87048340e-02],
                        [ -1.62292480e-01,  -1.62292480e-01],
                        [ -2.13439941e-01,  -2.13439941e-01],
                        [ -2.18902588e-01,  -2.18902588e-01],
                        [ -1.88903809e-01,  -1.88903809e-01],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -1.25579834e-01,  -1.25579834e-01],
                        [ -1.15936279e-01,  -1.15936279e-01],
                        [ -1.11938477e-01,  -1.11907959e-01],
                        [ -1.06842041e-01,  -1.06842041e-01],
                        [ -1.01348877e-01,  -1.01348877e-01],
                        [ -1.00036621e-01,  -1.00036621e-01],
                        [ -1.04461670e-01,  -1.04461670e-01],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -1.04095459e-01,  -1.04125977e-01],
                        [ -9.49401855e-02,  -9.49401855e-02],
                        [ -8.49914551e-02,  -8.49609375e-02],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  1.32537842e-01,   1.32537842e-01],
                        [  1.47552490e-01,   1.47552490e-01],
                        [  1.33880615e-01,   1.33850098e-01],
                        [  1.05712891e-01,   1.05712891e-01],
                        [  8.41369629e-02,   8.41369629e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.35253906e-01,   1.35284424e-01],
                        [  1.63574219e-01,   1.63543701e-01],
                        [  2.02484131e-01,   2.02484131e-01],
                        [  2.37731934e-01,   2.37762451e-01],
                        [  2.42218018e-01,   2.42187500e-01],
                        [  1.99951172e-01,   1.99920654e-01],
                        [  1.14135742e-01,   1.14166260e-01],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -1.31683350e-01,  -1.31713867e-01],
                        [ -2.51281738e-01,  -2.51281738e-01],
                        [ -3.30505371e-01,  -3.30505371e-01],
                        [ -3.44268799e-01,  -3.44268799e-01],
                        [ -2.93243408e-01,  -2.93243408e-01],
                        [ -2.11700439e-01,  -2.11669922e-01],
                        [ -1.44470215e-01,  -1.44470215e-01],
                        [ -1.12213135e-01,  -1.12213135e-01],
                        [ -1.03790283e-01,  -1.03790283e-01],
                        [ -1.00738525e-01,  -1.00738525e-01],
                        [ -9.73205566e-02,  -9.73510742e-02],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -1.03240967e-01,  -1.03210449e-01],
                        [ -1.10168457e-01,  -1.10168457e-01],
                        [ -1.10900879e-01,  -1.10900879e-01],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -5.55419922e-03,  -5.58471680e-03],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  1.46087646e-01,   1.46118164e-01],
                        [  2.05963135e-01,   2.05932617e-01],
                        [  2.37579346e-01,   2.37579346e-01],
                        [  2.33917236e-01,   2.33917236e-01],
                        [  2.01385498e-01,   2.01385498e-01],
                        [  1.60217285e-01,   1.60217285e-01],
                        [  1.27716064e-01,   1.27746582e-01],
                        [  1.06750488e-01,   1.06750488e-01],
                        [  9.39636230e-02,   9.39331055e-02],
                        [  8.77380371e-02,   8.77380371e-02],
                        [  8.64257812e-02,   8.64257812e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  9.03015137e-02,   9.03015137e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  6.21337891e-02,   6.21032715e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  3.76586914e-02,   3.76892090e-02],
                        [  2.85034180e-02,   2.84729004e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  1.10778809e-02,   1.11083984e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  5.76782227e-03,   5.73730469e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.30004883e-02,  -1.30310059e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.44042969e-02,  -1.44348145e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -3.95812988e-02,  -3.95507812e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.34582520e-02,  -1.34887695e-02],
                        [ -8.94165039e-03,  -8.97216797e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  6.01196289e-02,   6.01196289e-02],
                        [  8.13293457e-02,   8.13293457e-02],
                        [  9.54284668e-02,   9.54284668e-02],
                        [  9.92431641e-02,   9.92431641e-02],
                        [  9.01794434e-02,   9.01794434e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [ -5.64880371e-02,  -5.65185547e-02],
                        [ -1.23962402e-01,  -1.23962402e-01],
                        [ -1.76025391e-01,  -1.76025391e-01],
                        [ -2.01049805e-01,  -2.01049805e-01],
                        [ -1.94610596e-01,  -1.94610596e-01],
                        [ -1.65344238e-01,  -1.65313721e-01],
                        [ -1.32263184e-01,  -1.32232666e-01],
                        [ -1.08337402e-01,  -1.08337402e-01],
                        [ -9.27734375e-02,  -9.27734375e-02],
                        [ -8.27026367e-02,  -8.26721191e-02],
                        [ -8.07495117e-02,  -8.07495117e-02],
                        [ -8.83789062e-02,  -8.84094238e-02],
                        [ -1.00738525e-01,  -1.00708008e-01],
                        [ -1.10076904e-01,  -1.10076904e-01],
                        [ -1.11968994e-01,  -1.11999512e-01],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -1.02264404e-01,  -1.02233887e-01],
                        [ -9.16748047e-02,  -9.17053223e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -2.08435059e-02,  -2.08129883e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  1.05377197e-01,   1.05346680e-01],
                        [  1.43920898e-01,   1.43951416e-01],
                        [  1.48956299e-01,   1.48986816e-01],
                        [  1.31195068e-01,   1.31195068e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  9.31091309e-02,   9.31396484e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  1.18957520e-01,   1.18988037e-01],
                        [  1.48193359e-01,   1.48193359e-01],
                        [  1.80084229e-01,   1.80084229e-01],
                        [  2.10449219e-01,   2.10449219e-01],
                        [  2.28149414e-01,   2.28179932e-01],
                        [  2.16735840e-01,   2.16705322e-01],
                        [  1.64459229e-01,   1.64459229e-01],
                        [  7.31201172e-02,   7.31201172e-02],
                        [ -4.28466797e-02,  -4.28161621e-02],
                        [ -1.63543701e-01,  -1.63574219e-01],
                        [ -2.65960693e-01,  -2.65960693e-01],
                        [ -3.21350098e-01,  -3.21350098e-01],
                        [ -3.07586670e-01,  -3.07617188e-01],
                        [ -2.37091064e-01,  -2.37121582e-01],
                        [ -1.60461426e-01,  -1.60461426e-01],
                        [ -1.22741699e-01,  -1.22741699e-01],
                        [ -1.23138428e-01,  -1.23168945e-01],
                        [ -1.31378174e-01,  -1.31378174e-01],
                        [ -1.29577637e-01,  -1.29547119e-01],
                        [ -1.22833252e-01,  -1.22863770e-01],
                        [ -1.21124268e-01,  -1.21124268e-01],
                        [ -1.24786377e-01,  -1.24755859e-01],
                        [ -1.24359131e-01,  -1.24359131e-01],
                        [ -1.07177734e-01,  -1.07177734e-01],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [  9.46044922e-04,   9.76562500e-04],
                        [  7.88574219e-02,   7.88269043e-02],
                        [  1.50512695e-01,   1.50512695e-01],
                        [  1.99127197e-01,   1.99157715e-01],
                        [  2.18322754e-01,   2.18292236e-01],
                        [  2.11303711e-01,   2.11303711e-01],
                        [  1.85638428e-01,   1.85668945e-01],
                        [  1.54235840e-01,   1.54235840e-01],
                        [  1.32141113e-01,   1.32110596e-01],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  1.13464355e-01,   1.13464355e-01],
                        [  1.02630615e-01,   1.02600098e-01],
                        [  9.61303711e-02,   9.60998535e-02],
                        [  9.63439941e-02,   9.64050293e-02],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  9.30480957e-02,   9.30175781e-02],
                        [  8.37707520e-02,   8.38012695e-02],
                        [  7.05566406e-02,   7.05871582e-02],
                        [  5.54504395e-02,   5.54199219e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  2.57873535e-02,   2.58178711e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  8.08715820e-03,   8.05664062e-03],
                        [  7.90405273e-03,   7.93457031e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  5.79833984e-03,   5.76782227e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  8.02612305e-03,   8.05664062e-03],
                        [  5.37109375e-03,   5.34057617e-03],
                        [ -9.76562500e-04,  -1.00708008e-03],
                        [ -1.24206543e-02,  -1.23901367e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -4.89807129e-02,  -4.90112305e-02],
                        [ -5.40466309e-02,  -5.40161133e-02],
                        [ -4.38537598e-02,  -4.38232422e-02],
                        [ -3.06701660e-02,  -3.07006836e-02],
                        [ -2.45666504e-02,  -2.45971680e-02],
                        [ -2.05993652e-02,  -2.05688477e-02],
                        [ -7.75146484e-03,  -7.78198242e-03],
                        [  1.14746094e-02,   1.14440918e-02],
                        [  2.12402344e-02,   2.12707520e-02],
                        [  1.51367188e-02,   1.51672363e-02],
                        [  4.54711914e-03,   4.51660156e-03],
                        [ -1.22070312e-03,  -1.19018555e-03],
                        [ -3.20434570e-03,  -3.17382812e-03],
                        [ -1.52587891e-04,  -1.83105469e-04],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  2.27355957e-02,   2.27661133e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  5.54199219e-02,   5.53894043e-02],
                        [  8.54492188e-02,   8.54797363e-02],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  1.03851318e-01,   1.03820801e-01],
                        [  7.82470703e-02,   7.82470703e-02],
                        [  3.70483398e-02,   3.70788574e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -1.61010742e-01,  -1.60980225e-01],
                        [ -2.03186035e-01,  -2.03186035e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.80908203e-01,  -1.80908203e-01],
                        [ -1.50482178e-01,  -1.50482178e-01],
                        [ -1.27960205e-01,  -1.27990723e-01],
                        [ -1.15142822e-01,  -1.15142822e-01],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -9.97619629e-02,  -9.97619629e-02],
                        [ -8.99047852e-02,  -8.99047852e-02],
                        [ -8.57238770e-02,  -8.57238770e-02],
                        [ -9.18579102e-02,  -9.18273926e-02],
                        [ -9.99450684e-02,  -9.99450684e-02],
                        [ -9.80529785e-02,  -9.80834961e-02],
                        [ -8.56018066e-02,  -8.56018066e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -4.61425781e-02,  -4.61730957e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  8.28857422e-02,   8.28857422e-02],
                        [  1.16027832e-01,   1.15997314e-01],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.06353760e-01,   1.06353760e-01],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  9.19189453e-02,   9.19189453e-02],
                        [  1.05865479e-01,   1.05865479e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.72576904e-01,   1.72576904e-01],
                        [  2.05810547e-01,   2.05810547e-01],
                        [  2.25128174e-01,   2.25128174e-01],
                        [  2.24121094e-01,   2.24151611e-01],
                        [  1.94335938e-01,   1.94335938e-01],
                        [  1.25823975e-01,   1.25823975e-01],
                        [  1.65405273e-02,   1.65405273e-02],
                        [ -1.18255615e-01,  -1.18255615e-01],
                        [ -2.44537354e-01,  -2.44537354e-01],
                        [ -3.22570801e-01,  -3.22570801e-01],
                        [ -3.29864502e-01,  -3.29864502e-01],
                        [ -2.77954102e-01,  -2.77954102e-01],
                        [ -2.06604004e-01,  -2.06604004e-01],
                        [ -1.55090332e-01,  -1.55090332e-01],
                        [ -1.35925293e-01,  -1.35925293e-01],
                        [ -1.36932373e-01,  -1.36932373e-01],
                        [ -1.41204834e-01,  -1.41204834e-01],
                        [ -1.40289307e-01,  -1.40289307e-01],
                        [ -1.34704590e-01,  -1.34704590e-01],
                        [ -1.28112793e-01,  -1.28112793e-01],
                        [ -1.20025635e-01,  -1.20025635e-01],
                        [ -1.02020264e-01,  -1.02020264e-01],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  1.60369873e-01,   1.60369873e-01],
                        [  2.12158203e-01,   2.12158203e-01],
                        [  2.30133057e-01,   2.30133057e-01],
                        [  2.16156006e-01,   2.16156006e-01],
                        [  1.80938721e-01,   1.80969238e-01],
                        [  1.41632080e-01,   1.41632080e-01],
                        [  1.15753174e-01,   1.15753174e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  1.22650146e-01,   1.22619629e-01],
                        [  1.20727539e-01,   1.20727539e-01],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  9.17968750e-02,   9.17968750e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  5.02929688e-02,   5.03234863e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.79333496e-02,   3.79028320e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  2.97241211e-02,   2.96936035e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  2.85034180e-02,   2.85339355e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -1.23291016e-02,  -1.22985840e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -2.34375000e-02,  -2.34680176e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -3.12805176e-02,  -3.12500000e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -3.30200195e-02,  -3.30505371e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -1.58691406e-02,  -1.58996582e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -3.14331055e-03,  -3.11279297e-03],
                        [  9.15527344e-05,   6.10351562e-05],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  7.44628906e-03,   7.47680664e-03],
                        [  8.33129883e-03,   8.30078125e-03],
                        [  9.64355469e-03,   9.61303711e-03],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  7.37915039e-02,   7.38220215e-02],
                        [  8.64257812e-02,   8.63952637e-02],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [ -3.76281738e-02,  -3.75976562e-02],
                        [ -1.10504150e-01,  -1.10534668e-01],
                        [ -1.79382324e-01,  -1.79382324e-01],
                        [ -2.16522217e-01,  -2.16491699e-01],
                        [ -2.12432861e-01,  -2.12463379e-01],
                        [ -1.81091309e-01,  -1.81121826e-01],
                        [ -1.43859863e-01,  -1.43859863e-01],
                        [ -1.16027832e-01,  -1.16027832e-01],
                        [ -1.02935791e-01,  -1.02966309e-01],
                        [ -1.00738525e-01,  -1.00738525e-01],
                        [ -1.01043701e-01,  -1.01013184e-01],
                        [ -9.85717773e-02,  -9.86022949e-02],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -9.74426270e-02,  -9.74121094e-02],
                        [ -9.96398926e-02,  -9.96704102e-02],
                        [ -9.44213867e-02,  -9.44519043e-02],
                        [ -8.08715820e-02,  -8.08410645e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -3.23791504e-02,  -3.24096680e-02],
                        [  1.12609863e-02,   1.12915039e-02],
                        [  6.25000000e-02,   6.25305176e-02],
                        [  1.04858398e-01,   1.04827881e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  1.13586426e-01,   1.13616943e-01],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  8.22143555e-02,   8.21838379e-02],
                        [  9.25292969e-02,   9.25598145e-02],
                        [  1.14715576e-01,   1.14746094e-01],
                        [  1.42395020e-01,   1.42364502e-01],
                        [  1.76666260e-01,   1.76666260e-01],
                        [  2.10571289e-01,   2.10601807e-01],
                        [  2.29034424e-01,   2.29003906e-01],
                        [  2.23449707e-01,   2.23419189e-01],
                        [  1.89575195e-01,   1.89605713e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  7.35473633e-03,   7.32421875e-03],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -2.47467041e-01,  -2.47467041e-01],
                        [ -3.24859619e-01,  -3.24859619e-01],
                        [ -3.35998535e-01,  -3.35998535e-01],
                        [ -2.84790039e-01,  -2.84759521e-01],
                        [ -2.08892822e-01,  -2.08892822e-01],
                        [ -1.55761719e-01,  -1.55761719e-01],
                        [ -1.40380859e-01,  -1.40380859e-01],
                        [ -1.40319824e-01,  -1.40289307e-01],
                        [ -1.34460449e-01,  -1.34490967e-01],
                        [ -1.27685547e-01,  -1.27685547e-01],
                        [ -1.29364014e-01,  -1.29333496e-01],
                        [ -1.29852295e-01,  -1.29852295e-01],
                        [ -1.14929199e-01,  -1.14959717e-01],
                        [ -8.57849121e-02,  -8.57543945e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [  1.22985840e-02,   1.22680664e-02],
                        [  9.30175781e-02,   9.30175781e-02],
                        [  1.76025391e-01,   1.76055908e-01],
                        [  2.30804443e-01,   2.30804443e-01],
                        [  2.41149902e-01,   2.41149902e-01],
                        [  2.14385986e-01,   2.14416504e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  1.35253906e-01,   1.35253906e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  9.66796875e-02,   9.66796875e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  8.56323242e-02,   8.56323242e-02],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  1.01776123e-01,   1.01745605e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  3.24707031e-02,   3.25012207e-02],
                        [  3.73840332e-02,   3.73840332e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  1.39770508e-02,   1.40075684e-02],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -1.11389160e-02,  -1.11083984e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.40478516e-02,  -2.40783691e-02],
                        [ -2.24609375e-02,  -2.24304199e-02],
                        [ -2.02941895e-02,  -2.02636719e-02],
                        [ -2.39868164e-02,  -2.40173340e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -3.14025879e-02,  -3.13720703e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -2.98156738e-02,  -2.98461914e-02],
                        [ -2.99987793e-02,  -2.99682617e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.62145996e-02,  -2.62451172e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -1.80969238e-02,  -1.80664062e-02],
                        [ -6.71386719e-03,  -6.74438477e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  3.23791504e-02,   3.24096680e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  4.11682129e-02,   4.11682129e-02],
                        [  4.79125977e-02,   4.79431152e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  6.33850098e-02,   6.33544922e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  6.75659180e-02,   6.75964355e-02],
                        [  4.59899902e-02,   4.59594727e-02],
                        [  5.00488281e-03,   4.97436523e-03],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -1.30187988e-01,  -1.30187988e-01],
                        [ -1.92718506e-01,  -1.92749023e-01],
                        [ -2.17254639e-01,  -2.17224121e-01],
                        [ -2.02392578e-01,  -2.02362061e-01],
                        [ -1.71325684e-01,  -1.71325684e-01],
                        [ -1.47369385e-01,  -1.47369385e-01],
                        [ -1.36444092e-01,  -1.36413574e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -1.14440918e-01,  -1.14471436e-01],
                        [ -9.62219238e-02,  -9.62219238e-02],
                        [ -8.48693848e-02,  -8.48388672e-02],
                        [ -8.40148926e-02,  -8.40454102e-02],
                        [ -8.78906250e-02,  -8.78906250e-02],
                        [ -9.07287598e-02,  -9.06982422e-02],
                        [ -8.92333984e-02,  -8.92333984e-02],
                        [ -7.69348145e-02,  -7.69653320e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  4.91943359e-02,   4.91638184e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.31622314e-01,   1.31622314e-01],
                        [  1.27502441e-01,   1.27502441e-01],
                        [  1.22039795e-01,   1.22039795e-01],
                        [  1.24908447e-01,   1.24908447e-01],
                        [  1.37542725e-01,   1.37512207e-01],
                        [  1.53961182e-01,   1.53961182e-01],
                        [  1.69586182e-01,   1.69586182e-01],
                        [  1.86859131e-01,   1.86859131e-01],
                        [  2.07427979e-01,   2.07397461e-01],
                        [  2.17529297e-01,   2.17529297e-01],
                        [  1.90063477e-01,   1.90063477e-01],
                        [  1.08184814e-01,   1.08154297e-01],
                        [ -1.63574219e-02,  -1.63269043e-02],
                        [ -1.50817871e-01,  -1.50787354e-01],
                        [ -2.60375977e-01,  -2.60406494e-01],
                        [ -3.19610596e-01,  -3.19610596e-01],
                        [ -3.17138672e-01,  -3.17108154e-01],
                        [ -2.61657715e-01,  -2.61657715e-01],
                        [ -1.85516357e-01,  -1.85546875e-01],
                        [ -1.29791260e-01,  -1.29791260e-01],
                        [ -1.13708496e-01,  -1.13708496e-01],
                        [ -1.24877930e-01,  -1.24908447e-01],
                        [ -1.41906738e-01,  -1.41906738e-01],
                        [ -1.53289795e-01,  -1.53259277e-01],
                        [ -1.53656006e-01,  -1.53686523e-01],
                        [ -1.38885498e-01,  -1.38885498e-01],
                        [ -1.09191895e-01,  -1.09161377e-01],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.88873291e-01,   1.88842773e-01],
                        [  2.33886719e-01,   2.33917236e-01],
                        [  2.37701416e-01,   2.37701416e-01],
                        [  2.02850342e-01,   2.02819824e-01],
                        [  1.56158447e-01,   1.56158447e-01],
                        [  1.22009277e-01,   1.22009277e-01],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  9.75952148e-02,   9.75952148e-02],
                        [  9.32312012e-02,   9.32312012e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  8.92028809e-02,   8.91723633e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  8.49914551e-02,   8.49609375e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  6.00585938e-02,   6.00891113e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  2.20336914e-02,   2.20031738e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.61230469e-02,   2.61535645e-02],
                        [  5.06591797e-03,   5.03540039e-03],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.35388184e-02,  -3.35693359e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -9.18579102e-03,  -9.18579102e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.35290527e-02,   2.35595703e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  5.00488281e-02,   5.00793457e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  9.85717773e-02,   9.86022949e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [ -4.50134277e-02,  -4.49829102e-02],
                        [ -1.12854004e-01,  -1.12854004e-01],
                        [ -1.77886963e-01,  -1.77886963e-01],
                        [ -2.21343994e-01,  -2.21343994e-01],
                        [ -2.30224609e-01,  -2.30224609e-01],
                        [ -2.05993652e-01,  -2.05993652e-01],
                        [ -1.66839600e-01,  -1.66809082e-01],
                        [ -1.36169434e-01,  -1.36169434e-01],
                        [ -1.22253418e-01,  -1.22253418e-01],
                        [ -1.12976074e-01,  -1.12976074e-01],
                        [ -9.50317383e-02,  -9.50317383e-02],
                        [ -7.18994141e-02,  -7.19299316e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -7.90405273e-02,  -7.90405273e-02],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -8.52050781e-02,  -8.51745605e-02],
                        [ -6.39648438e-02,  -6.39648438e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  7.04040527e-02,   7.03735352e-02],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.41815186e-01,   1.41845703e-01],
                        [  1.54663086e-01,   1.54663086e-01],
                        [  1.56188965e-01,   1.56188965e-01],
                        [  1.51794434e-01,   1.51794434e-01],
                        [  1.46789551e-01,   1.46820068e-01],
                        [  1.50726318e-01,   1.50695801e-01],
                        [  1.71081543e-01,   1.71081543e-01],
                        [  2.00378418e-01,   2.00378418e-01],
                        [  2.18444824e-01,   2.18414307e-01],
                        [  2.08923340e-01,   2.08923340e-01],
                        [  1.65527344e-01,   1.65557861e-01],
                        [  8.75549316e-02,   8.75549316e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -1.45904541e-01,  -1.45904541e-01],
                        [ -2.60803223e-01,  -2.60803223e-01],
                        [ -3.29223633e-01,  -3.29223633e-01],
                        [ -3.27423096e-01,  -3.27392578e-01],
                        [ -2.67333984e-01,  -2.67333984e-01],
                        [ -1.92840576e-01,  -1.92871094e-01],
                        [ -1.45812988e-01,  -1.45812988e-01],
                        [ -1.35284424e-01,  -1.35284424e-01],
                        [ -1.40960693e-01,  -1.40960693e-01],
                        [ -1.42211914e-01,  -1.42242432e-01],
                        [ -1.36322021e-01,  -1.36322021e-01],
                        [ -1.29943848e-01,  -1.29943848e-01],
                        [ -1.20239258e-01,  -1.20269775e-01],
                        [ -9.16748047e-02,  -9.16748047e-02],
                        [ -3.43627930e-02,  -3.43322754e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.75384521e-01,   1.75384521e-01],
                        [  2.17956543e-01,   2.17956543e-01],
                        [  2.33215332e-01,   2.33184814e-01],
                        [  2.11151123e-01,   2.11151123e-01],
                        [  1.63055420e-01,   1.63055420e-01],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  8.90197754e-02,   8.90197754e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  9.60083008e-02,   9.59777832e-02],
                        [  8.85314941e-02,   8.85314941e-02],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  6.02722168e-02,   6.02722168e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  3.06701660e-02,   3.07006836e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.24304199e-02,   2.23999023e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  6.05773926e-02,   6.05773926e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  6.12792969e-02,   6.12487793e-02],
                        [  5.63964844e-02,   5.64270020e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -1.17218018e-01,  -1.17218018e-01],
                        [ -1.78344727e-01,  -1.78344727e-01],
                        [ -2.13378906e-01,  -2.13409424e-01],
                        [ -2.11486816e-01,  -2.11486816e-01],
                        [ -1.79534912e-01,  -1.79534912e-01],
                        [ -1.39801025e-01,  -1.39801025e-01],
                        [ -1.15966797e-01,  -1.15966797e-01],
                        [ -1.14593506e-01,  -1.14562988e-01],
                        [ -1.20697021e-01,  -1.20727539e-01],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -1.04644775e-01,  -1.04644775e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -8.81958008e-02,  -8.81958008e-02],
                        [ -8.25195312e-02,  -8.25195312e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -4.50744629e-02,  -4.51049805e-02],
                        [ -2.62451172e-03,  -2.59399414e-03],
                        [  4.98962402e-02,   4.99267578e-02],
                        [  9.67407227e-02,   9.67102051e-02],
                        [  1.26373291e-01,   1.26373291e-01],
                        [  1.38946533e-01,   1.38977051e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  1.41357422e-01,   1.41326904e-01],
                        [  1.43615723e-01,   1.43646240e-01],
                        [  1.54541016e-01,   1.54541016e-01],
                        [  1.75659180e-01,   1.75659180e-01],
                        [  1.98577881e-01,   1.98577881e-01],
                        [  2.09289551e-01,   2.09289551e-01],
                        [  1.99035645e-01,   1.99035645e-01],
                        [  1.65710449e-01,   1.65679932e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  1.11694336e-02,   1.11694336e-02],
                        [ -1.07757568e-01,  -1.07757568e-01],
                        [ -2.23358154e-01,  -2.23358154e-01],
                        [ -2.97698975e-01,  -2.97698975e-01],
                        [ -3.05572510e-01,  -3.05603027e-01],
                        [ -2.55432129e-01,  -2.55401611e-01],
                        [ -1.87561035e-01,  -1.87561035e-01],
                        [ -1.43524170e-01,  -1.43524170e-01],
                        [ -1.34857178e-01,  -1.34857178e-01],
                        [ -1.44073486e-01,  -1.44042969e-01],
                        [ -1.50085449e-01,  -1.50085449e-01],
                        [ -1.45416260e-01,  -1.45446777e-01],
                        [ -1.31774902e-01,  -1.31774902e-01],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  8.83789062e-02,   8.83789062e-02],
                        [  1.69097900e-01,   1.69097900e-01],
                        [  2.29370117e-01,   2.29370117e-01],
                        [  2.46002197e-01,   2.46002197e-01],
                        [  2.19055176e-01,   2.19055176e-01],
                        [  1.71264648e-01,   1.71264648e-01],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  9.98535156e-02,   9.98535156e-02],
                        [  8.45336914e-02,   8.45336914e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  6.82678223e-02,   6.82678223e-02],
                        [  6.82373047e-02,   6.82373047e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  5.93566895e-02,   5.93566895e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [ -7.50732422e-03,  -7.53784180e-03],
                        [ -1.94702148e-02,  -1.94396973e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -6.75354004e-02,  -6.75048828e-02],
                        [ -6.30798340e-02,  -6.30798340e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  1.85241699e-02,   1.84936523e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  7.14111328e-03,   7.11059570e-03],
                        [  9.33837891e-03,   9.36889648e-03],
                        [  1.21154785e-02,   1.21459961e-02],
                        [  1.58081055e-02,   1.57775879e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  2.93273926e-02,   2.93579102e-02],
                        [  3.24401855e-02,   3.24096680e-02],
                        [  3.07006836e-02,   3.06701660e-02],
                        [  2.38342285e-02,   2.38647461e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.48010254e-02,   1.47705078e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  4.93774414e-02,   4.94079590e-02],
                        [  5.85632324e-02,   5.85327148e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  2.50549316e-02,   2.50854492e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -8.47778320e-02,  -8.48083496e-02],
                        [ -1.53625488e-01,  -1.53625488e-01],
                        [ -2.03552246e-01,  -2.03521729e-01],
                        [ -2.14996338e-01,  -2.15026855e-01],
                        [ -1.88354492e-01,  -1.88354492e-01],
                        [ -1.47369385e-01,  -1.47338867e-01],
                        [ -1.17736816e-01,  -1.17736816e-01],
                        [ -1.05255127e-01,  -1.05285645e-01],
                        [ -1.02508545e-01,  -1.02478027e-01],
                        [ -1.03698730e-01,  -1.03698730e-01],
                        [ -1.04522705e-01,  -1.04553223e-01],
                        [ -1.00006104e-01,  -1.00006104e-01],
                        [ -9.03930664e-02,  -9.03625488e-02],
                        [ -8.04138184e-02,  -8.04138184e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -4.71496582e-02,  -4.71191406e-02],
                        [ -9.18579102e-03,  -9.18579102e-03],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  1.29058838e-01,   1.29089355e-01],
                        [  1.49291992e-01,   1.49291992e-01],
                        [  1.49993896e-01,   1.49993896e-01],
                        [  1.44775391e-01,   1.44805908e-01],
                        [  1.53472900e-01,   1.53472900e-01],
                        [  1.81060791e-01,   1.81030273e-01],
                        [  2.11395264e-01,   2.11395264e-01],
                        [  2.26745605e-01,   2.26776123e-01],
                        [  2.21649170e-01,   2.21618652e-01],
                        [  1.90948486e-01,   1.90948486e-01],
                        [  1.22100830e-01,   1.22100830e-01],
                        [  1.14440918e-02,   1.14440918e-02],
                        [ -1.21002197e-01,  -1.21002197e-01],
                        [ -2.41333008e-01,  -2.41333008e-01],
                        [ -3.18664551e-01,  -3.18634033e-01],
                        [ -3.31878662e-01,  -3.31878662e-01],
                        [ -2.80303955e-01,  -2.80303955e-01],
                        [ -1.96777344e-01,  -1.96777344e-01],
                        [ -1.31072998e-01,  -1.31072998e-01],
                        [ -1.07940674e-01,  -1.07971191e-01],
                        [ -1.13952637e-01,  -1.13922119e-01],
                        [ -1.24938965e-01,  -1.24938965e-01],
                        [ -1.30401611e-01,  -1.30432129e-01],
                        [ -1.28997803e-01,  -1.28997803e-01],
                        [ -1.16973877e-01,  -1.16943359e-01],
                        [ -8.74938965e-02,  -8.74938965e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  1.30340576e-01,   1.30340576e-01],
                        [  1.98791504e-01,   1.98791504e-01],
                        [  2.23419189e-01,   2.23419189e-01],
                        [  2.06909180e-01,   2.06909180e-01],
                        [  1.72271729e-01,   1.72271729e-01],
                        [  1.37603760e-01,   1.37603760e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  8.18481445e-02,   8.18176270e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  8.76159668e-02,   8.76159668e-02],
                        [  8.90502930e-02,   8.90197754e-02],
                        [  8.75244141e-02,   8.75549316e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  6.90612793e-02,   6.90307617e-02],
                        [  6.16149902e-02,   6.16455078e-02],
                        [  5.50231934e-02,   5.50537109e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  4.87060547e-02,   4.86755371e-02],
                        [  5.46875000e-02,   5.47180176e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.94079590e-02,   4.93774414e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -1.80053711e-02,  -1.79748535e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -4.45556641e-02,  -4.45251465e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.91345215e-02,  -1.91040039e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -2.41088867e-02,  -2.40783691e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [  3.02124023e-03,   3.05175781e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  1.72119141e-02,   1.72424316e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [ -3.05175781e-05,  -6.10351562e-05],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  4.11376953e-02,   4.11682129e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  2.94799805e-02,   2.95104980e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -9.32312012e-02,  -9.32312012e-02],
                        [ -1.55883789e-01,  -1.55883789e-01],
                        [ -1.95953369e-01,  -1.95953369e-01],
                        [ -1.98272705e-01,  -1.98272705e-01],
                        [ -1.72973633e-01,  -1.72973633e-01],
                        [ -1.44409180e-01,  -1.44409180e-01],
                        [ -1.28631592e-01,  -1.28662109e-01],
                        [ -1.23168945e-01,  -1.23168945e-01],
                        [ -1.15875244e-01,  -1.15875244e-01],
                        [ -1.01196289e-01,  -1.01226807e-01],
                        [ -8.66088867e-02,  -8.66088867e-02],
                        [ -8.09936523e-02,  -8.09631348e-02],
                        [ -7.94067383e-02,  -7.94067383e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -4.26330566e-02,  -4.26025391e-02],
                        [ -1.06506348e-02,  -1.06811523e-02],
                        [  2.42004395e-02,   2.41699219e-02],
                        [  6.33544922e-02,   6.33850098e-02],
                        [  1.02355957e-01,   1.02386475e-01],
                        [  1.30523682e-01,   1.30523682e-01],
                        [  1.44531250e-01,   1.44531250e-01],
                        [  1.53533936e-01,   1.53533936e-01],
                        [  1.67175293e-01,   1.67175293e-01],
                        [  1.84295654e-01,   1.84295654e-01],
                        [  1.97082520e-01,   1.97082520e-01],
                        [  2.00286865e-01,   2.00286865e-01],
                        [  1.91192627e-01,   1.91162109e-01],
                        [  1.62109375e-01,   1.62109375e-01],
                        [  1.01196289e-01,   1.01226807e-01],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -1.09405518e-01,  -1.09405518e-01],
                        [ -2.17315674e-01,  -2.17315674e-01],
                        [ -2.90710449e-01,  -2.90710449e-01],
                        [ -3.10455322e-01,  -3.10455322e-01],
                        [ -2.76489258e-01,  -2.76489258e-01],
                        [ -2.13439941e-01,  -2.13439941e-01],
                        [ -1.58386230e-01,  -1.58416748e-01],
                        [ -1.35467529e-01,  -1.35467529e-01],
                        [ -1.40258789e-01,  -1.40258789e-01],
                        [ -1.49658203e-01,  -1.49658203e-01],
                        [ -1.46118164e-01,  -1.46118164e-01],
                        [ -1.30950928e-01,  -1.30920410e-01],
                        [ -1.11755371e-01,  -1.11755371e-01],
                        [ -8.24584961e-02,  -8.24584961e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.99371338e-01,   1.99340820e-01],
                        [  2.23999023e-01,   2.23999023e-01],
                        [  2.07031250e-01,   2.07031250e-01],
                        [  1.63879395e-01,   1.63879395e-01],
                        [  1.20239258e-01,   1.20239258e-01],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  8.20617676e-02,   8.20312500e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  8.89587402e-02,   8.89282227e-02],
                        [  8.12377930e-02,   8.12683105e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  5.72814941e-02,   5.72509766e-02],
                        [  5.53588867e-02,   5.53894043e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  7.29980469e-02,   7.29980469e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.71508789e-02,  -1.71203613e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -1.34582520e-02,  -1.34277344e-02],
                        [ -1.19323730e-02,  -1.19628906e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -2.67944336e-02,  -2.67639160e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.49023438e-02,  -2.48718262e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  1.79138184e-02,   1.79443359e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  2.52685547e-02,   2.52380371e-02],
                        [  2.34985352e-02,   2.35290527e-02],
                        [  2.07519531e-02,   2.07824707e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  5.37109375e-03,   5.40161133e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -1.04797363e-01,  -1.04797363e-01],
                        [ -1.66351318e-01,  -1.66351318e-01],
                        [ -2.00073242e-01,  -2.00073242e-01],
                        [ -1.95526123e-01,  -1.95526123e-01],
                        [ -1.64245605e-01,  -1.64245605e-01],
                        [ -1.34246826e-01,  -1.34246826e-01],
                        [ -1.21276855e-01,  -1.21276855e-01],
                        [ -1.14715576e-01,  -1.14715576e-01],
                        [ -1.00280762e-01,  -1.00280762e-01],
                        [ -8.11767578e-02,  -8.11767578e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  8.83789062e-02,   8.83789062e-02],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.39739990e-01,   1.39739990e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.53503418e-01,   1.53503418e-01],
                        [  1.72882080e-01,   1.72882080e-01],
                        [  2.02056885e-01,   2.02056885e-01],
                        [  2.24029541e-01,   2.24029541e-01],
                        [  2.16461182e-01,   2.16461182e-01],
                        [  1.67449951e-01,   1.67449951e-01],
                        [  8.30993652e-02,   8.30993652e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -1.34002686e-01,  -1.34002686e-01],
                        [ -2.34680176e-01,  -2.34680176e-01],
                        [ -2.97485352e-01,  -2.97485352e-01],
                        [ -3.03070068e-01,  -3.03070068e-01],
                        [ -2.60528564e-01,  -2.60559082e-01],
                        [ -2.05718994e-01,  -2.05718994e-01],
                        [ -1.72363281e-01,  -1.72363281e-01],
                        [ -1.64978027e-01,  -1.64978027e-01],
                        [ -1.63574219e-01,  -1.63574219e-01],
                        [ -1.52313232e-01,  -1.52313232e-01],
                        [ -1.33117676e-01,  -1.33117676e-01],
                        [ -1.11450195e-01,  -1.11450195e-01],
                        [ -8.29162598e-02,  -8.29162598e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  1.58538818e-01,   1.58538818e-01],
                        [  1.99859619e-01,   1.99829102e-01],
                        [  2.08343506e-01,   2.08343506e-01],
                        [  1.91497803e-01,   1.91497803e-01],
                        [  1.61102295e-01,   1.61102295e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  8.93554688e-02,   8.93554688e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  8.01086426e-02,   8.01086426e-02],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  9.28344727e-02,   9.28039551e-02],
                        [  7.80944824e-02,   7.80944824e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -2.56042480e-02,  -2.56347656e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -1.61743164e-02,  -1.61437988e-02],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.14941406e-02,   3.14636230e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  1.22375488e-02,   1.22070312e-02],
                        [  1.79443359e-02,   1.79748535e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  1.84936523e-02,   1.85241699e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -9.55505371e-02,  -9.55505371e-02],
                        [ -1.51367188e-01,  -1.51367188e-01],
                        [ -1.84387207e-01,  -1.84387207e-01],
                        [ -1.82464600e-01,  -1.82464600e-01],
                        [ -1.56738281e-01,  -1.56738281e-01],
                        [ -1.27899170e-01,  -1.27899170e-01],
                        [ -1.06536865e-01,  -1.06536865e-01],
                        [ -9.26208496e-02,  -9.26208496e-02],
                        [ -8.59375000e-02,  -8.59375000e-02],
                        [ -8.58459473e-02,  -8.58459473e-02],
                        [ -8.59985352e-02,  -8.59985352e-02],
                        [ -7.98950195e-02,  -7.98950195e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.57409668e-01,   1.57409668e-01],
                        [  1.78466797e-01,   1.78466797e-01],
                        [  1.94702148e-01,   1.94702148e-01],
                        [  2.11090088e-01,   2.11090088e-01],
                        [  2.22259521e-01,   2.22259521e-01],
                        [  2.17376709e-01,   2.17376709e-01],
                        [  1.86614990e-01,   1.86614990e-01],
                        [  1.24908447e-01,   1.24938965e-01],
                        [  3.38745117e-02,   3.38745117e-02],
                        [ -7.89489746e-02,  -7.89489746e-02],
                        [ -1.98822021e-01,  -1.98822021e-01],
                        [ -2.97790527e-01,  -2.97790527e-01],
                        [ -3.40118408e-01,  -3.40148926e-01],
                        [ -3.11248779e-01,  -3.11248779e-01],
                        [ -2.40478516e-01,  -2.40478516e-01],
                        [ -1.79382324e-01,  -1.79382324e-01],
                        [ -1.55059814e-01,  -1.55059814e-01],
                        [ -1.54693604e-01,  -1.54663086e-01],
                        [ -1.54022217e-01,  -1.54022217e-01],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -1.27410889e-01,  -1.27410889e-01],
                        [ -1.00372314e-01,  -1.00372314e-01],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.06414795e-01,   1.06414795e-01],
                        [  1.88293457e-01,   1.88293457e-01],
                        [  2.33459473e-01,   2.33459473e-01],
                        [  2.29522705e-01,   2.29522705e-01],
                        [  1.91436768e-01,   1.91436768e-01],
                        [  1.47552490e-01,   1.47552490e-01],
                        [  1.14349365e-01,   1.14349365e-01],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  3.92150879e-02,   3.92456055e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  7.00683594e-02,   7.00683594e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  8.14514160e-02,   8.14208984e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  7.74536133e-02,   7.74841309e-02],
                        [  7.70874023e-02,   7.70874023e-02],
                        [  7.50732422e-02,   7.50732422e-02],
                        [  7.09838867e-02,   7.10144043e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  2.99072266e-02,   2.99377441e-02],
                        [  2.06909180e-02,   2.06604004e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -2.96020508e-02,  -2.95715332e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -4.02526855e-02,  -4.02221680e-02],
                        [ -3.68652344e-02,  -3.68652344e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -1.61437988e-02,  -1.61132812e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [  6.34765625e-03,   6.31713867e-03],
                        [  1.14440918e-02,   1.14135742e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -9.05761719e-02,  -9.05456543e-02],
                        [ -1.44897461e-01,  -1.44897461e-01],
                        [ -1.81335449e-01,  -1.81365967e-01],
                        [ -1.90216064e-01,  -1.90216064e-01],
                        [ -1.71417236e-01,  -1.71417236e-01],
                        [ -1.37237549e-01,  -1.37237549e-01],
                        [ -1.04980469e-01,  -1.04980469e-01],
                        [ -8.55407715e-02,  -8.55102539e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -7.77893066e-02,  -7.77893066e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  8.33129883e-02,   8.33129883e-02],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.60919189e-01,   1.60919189e-01],
                        [  1.89636230e-01,   1.89636230e-01],
                        [  2.15301514e-01,   2.15301514e-01],
                        [  2.31353760e-01,   2.31353760e-01],
                        [  2.31903076e-01,   2.31872559e-01],
                        [  2.10418701e-01,   2.10418701e-01],
                        [  1.55303955e-01,   1.55303955e-01],
                        [  5.99670410e-02,   5.99670410e-02],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -1.85333252e-01,  -1.85333252e-01],
                        [ -2.76824951e-01,  -2.76824951e-01],
                        [ -3.19427490e-01,  -3.19427490e-01],
                        [ -3.08410645e-01,  -3.08410645e-01],
                        [ -2.55065918e-01,  -2.55065918e-01],
                        [ -1.91040039e-01,  -1.91040039e-01],
                        [ -1.52984619e-01,  -1.52984619e-01],
                        [ -1.50115967e-01,  -1.50115967e-01],
                        [ -1.57287598e-01,  -1.57287598e-01],
                        [ -1.48193359e-01,  -1.48223877e-01],
                        [ -1.22436523e-01,  -1.22436523e-01],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  1.50878906e-01,   1.50878906e-01],
                        [  2.02545166e-01,   2.02514648e-01],
                        [  2.15057373e-01,   2.15057373e-01],
                        [  1.94183350e-01,   1.94183350e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.29974365e-01,   1.29974365e-01],
                        [  1.09130859e-01,   1.09130859e-01],
                        [  9.33837891e-02,   9.33837891e-02],
                        [  8.02917480e-02,   8.02612305e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.39160156e-02,  -1.39465332e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -1.69616699e-01,  -1.69616699e-01],
                        [ -2.01568604e-01,  -2.01568604e-01],
                        [ -1.93176270e-01,  -1.93176270e-01],
                        [ -1.56311035e-01,  -1.56311035e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -8.93859863e-02,  -8.93859863e-02],
                        [ -7.85217285e-02,  -7.85217285e-02],
                        [ -7.91320801e-02,  -7.91320801e-02],
                        [ -8.56323242e-02,  -8.56323242e-02],
                        [ -9.07287598e-02,  -9.07287598e-02],
                        [ -8.60900879e-02,  -8.60900879e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  9.51843262e-02,   9.51843262e-02],
                        [  1.47430420e-01,   1.47430420e-01],
                        [  1.86553955e-01,   1.86553955e-01],
                        [  2.12402344e-01,   2.12402344e-01],
                        [  2.27813721e-01,   2.27813721e-01],
                        [  2.34741211e-01,   2.34741211e-01],
                        [  2.28637695e-01,   2.28637695e-01],
                        [  1.96594238e-01,   1.96594238e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  1.80053711e-02,   1.80053711e-02],
                        [ -1.09252930e-01,  -1.09252930e-01],
                        [ -2.28363037e-01,  -2.28363037e-01],
                        [ -3.11157227e-01,  -3.11157227e-01],
                        [ -3.36547852e-01,  -3.36547852e-01],
                        [ -3.04687500e-01,  -3.04687500e-01],
                        [ -2.43774414e-01,  -2.43774414e-01],
                        [ -1.91711426e-01,  -1.91711426e-01],
                        [ -1.65283203e-01,  -1.65283203e-01],
                        [ -1.52832031e-01,  -1.52832031e-01],
                        [ -1.36413574e-01,  -1.36413574e-01],
                        [ -1.12274170e-01,  -1.12274170e-01],
                        [ -8.52661133e-02,  -8.52966309e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  1.38580322e-01,   1.38580322e-01],
                        [  1.93420410e-01,   1.93420410e-01],
                        [  2.16186523e-01,   2.16186523e-01],
                        [  2.08831787e-01,   2.08831787e-01],
                        [  1.79443359e-01,   1.79443359e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  7.05261230e-02,   7.05261230e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  4.37316895e-02,   4.37316895e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  7.29980469e-02,   7.29980469e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  7.79113770e-02,   7.79113770e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  5.21850586e-03,   5.21850586e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -1.06384277e-01,  -1.06384277e-01],
                        [ -1.63665771e-01,  -1.63665771e-01],
                        [ -1.88781738e-01,  -1.88781738e-01],
                        [ -1.78222656e-01,  -1.78222656e-01],
                        [ -1.49444580e-01,  -1.49444580e-01],
                        [ -1.25183105e-01,  -1.25183105e-01],
                        [ -1.15844727e-01,  -1.15844727e-01],
                        [ -1.13525391e-01,  -1.13525391e-01],
                        [ -1.04125977e-01,  -1.04125977e-01],
                        [ -8.51135254e-02,  -8.51135254e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.64947510e-01,   1.64947510e-01],
                        [  2.07702637e-01,   2.07702637e-01],
                        [  2.36877441e-01,   2.36877441e-01],
                        [  2.51831055e-01,   2.51831055e-01],
                        [  2.48016357e-01,   2.48016357e-01],
                        [  2.15393066e-01,   2.15393066e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  4.36706543e-02,   4.36706543e-02],
                        [ -8.07189941e-02,  -8.07189941e-02],
                        [ -2.06695557e-01,  -2.06695557e-01],
                        [ -3.06610107e-01,  -3.06610107e-01],
                        [ -3.50952148e-01,  -3.50952148e-01],
                        [ -3.28125000e-01,  -3.28125000e-01],
                        [ -2.60650635e-01,  -2.60650635e-01],
                        [ -1.92993164e-01,  -1.92993164e-01],
                        [ -1.56494141e-01,  -1.56494141e-01],
                        [ -1.48651123e-01,  -1.48651123e-01],
                        [ -1.45660400e-01,  -1.45660400e-01],
                        [ -1.29150391e-01,  -1.29150391e-01],
                        [ -9.74121094e-02,  -9.74121094e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  1.35559082e-01,   1.35559082e-01],
                        [  1.90307617e-01,   1.90307617e-01],
                        [  2.15148926e-01,   2.15148926e-01],
                        [  2.07183838e-01,   2.07183838e-01],
                        [  1.77001953e-01,   1.77001953e-01],
                        [  1.40502930e-01,   1.40502930e-01],
                        [  1.08856201e-01,   1.08856201e-01],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  9.08813477e-02,   9.08813477e-02],
                        [  9.72290039e-02,   9.72290039e-02],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  9.68017578e-02,   9.68017578e-02],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -1.18469238e-01,  -1.18469238e-01],
                        [ -1.68029785e-01,  -1.68029785e-01],
                        [ -1.89178467e-01,  -1.89178467e-01],
                        [ -1.80572510e-01,  -1.80572510e-01],
                        [ -1.53991699e-01,  -1.53991699e-01],
                        [ -1.25793457e-01,  -1.25793457e-01],
                        [ -1.05346680e-01,  -1.05346680e-01],
                        [ -9.15832520e-02,  -9.15832520e-02],
                        [ -8.02917480e-02,  -8.02917480e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.93969727e-01,   1.93969727e-01],
                        [  2.36511230e-01,   2.36511230e-01],
                        [  2.53662109e-01,   2.53662109e-01],
                        [  2.41699219e-01,   2.41699219e-01],
                        [  2.01385498e-01,   2.01385498e-01],
                        [  1.32873535e-01,   1.32873535e-01],
                        [  3.54614258e-02,   3.54614258e-02],
                        [ -8.42285156e-02,  -8.42285156e-02],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -3.00720215e-01,  -3.00720215e-01],
                        [ -3.42926025e-01,  -3.42926025e-01],
                        [ -3.24279785e-01,  -3.24279785e-01],
                        [ -2.66143799e-01,  -2.66143799e-01],
                        [ -2.09533691e-01,  -2.09533691e-01],
                        [ -1.80511475e-01,  -1.80511475e-01],
                        [ -1.69494629e-01,  -1.69494629e-01],
                        [ -1.51763916e-01,  -1.51763916e-01],
                        [ -1.18347168e-01,  -1.18347168e-01],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.68151855e-01,   1.68151855e-01],
                        [  2.09259033e-01,   2.09259033e-01],
                        [  2.18078613e-01,   2.18078613e-01],
                        [  1.98028564e-01,   1.98028564e-01],
                        [  1.63635254e-01,   1.63635254e-01],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  9.99450684e-02,   9.99450684e-02],
                        [  7.22961426e-02,   7.22961426e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  9.45434570e-02,   9.45434570e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  2.03552246e-02,   2.03247070e-02],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -8.85009766e-03,  -8.85009766e-03],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -2.85644531e-02,  -2.85339355e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  2.32238770e-02,   2.31933594e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  1.43737793e-02,   1.43432617e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -1.17645264e-01,  -1.17645264e-01],
                        [ -1.60217285e-01,  -1.60217285e-01],
                        [ -1.69494629e-01,  -1.69494629e-01],
                        [ -1.46392822e-01,  -1.46392822e-01],
                        [ -1.13708496e-01,  -1.13708496e-01],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -8.34350586e-02,  -8.34350586e-02],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  7.82775879e-02,   7.82775879e-02],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  1.78710938e-01,   1.78741455e-01],
                        [  2.15240479e-01,   2.15240479e-01],
                        [  2.34375000e-01,   2.34375000e-01],
                        [  2.27569580e-01,   2.27569580e-01],
                        [  1.86035156e-01,   1.86035156e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [ -6.10351562e-04,  -6.40869141e-04],
                        [ -1.29760742e-01,  -1.29760742e-01],
                        [ -2.54394531e-01,  -2.54394531e-01],
                        [ -3.36242676e-01,  -3.36242676e-01],
                        [ -3.48663330e-01,  -3.48663330e-01],
                        [ -3.00659180e-01,  -3.00659180e-01],
                        [ -2.30590820e-01,  -2.30590820e-01],
                        [ -1.78070068e-01,  -1.78039551e-01],
                        [ -1.58691406e-01,  -1.58691406e-01],
                        [ -1.57043457e-01,  -1.57043457e-01],
                        [ -1.44409180e-01,  -1.44409180e-01],
                        [ -1.06964111e-01,  -1.06964111e-01],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  6.41479492e-02,   6.41479492e-02],
                        [  1.25579834e-01,   1.25579834e-01],
                        [  1.76239014e-01,   1.76239014e-01],
                        [  2.00439453e-01,   2.00408936e-01],
                        [  1.95709229e-01,   1.95739746e-01],
                        [  1.73919678e-01,   1.73950195e-01],
                        [  1.47247314e-01,   1.47247314e-01],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  9.27124023e-02,   9.27124023e-02],
                        [  6.82373047e-02,   6.82373047e-02],
                        [  5.35278320e-02,   5.34973145e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  8.00476074e-02,   8.00781250e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  3.86047363e-02,   3.86352539e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [  6.34765625e-02,   6.35070801e-02],
                        [  6.90002441e-02,   6.90002441e-02],
                        [  7.01904297e-02,   7.01904297e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  5.77087402e-02,   5.77392578e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.74145508e-02,  -3.74450684e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -1.01318359e-02,  -1.01013184e-02],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -1.00708008e-03,  -1.03759766e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.18713379e-02,   1.18408203e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.62963867e-02,   1.63269043e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  1.06811523e-03,   1.09863281e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -1.61437988e-02,  -1.61132812e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.67028809e-02,  -2.67333984e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.05786133e-02,  -3.05480957e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -3.02734375e-02,  -3.03039551e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.56555176e-02,   1.56860352e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  2.34375000e-02,   2.34069824e-02],
                        [  1.17797852e-02,   1.17492676e-02],
                        [ -2.42614746e-02,  -2.42309570e-02],
                        [ -8.08105469e-02,  -8.08105469e-02],
                        [ -1.36291504e-01,  -1.36322021e-01],
                        [ -1.66534424e-01,  -1.66534424e-01],
                        [ -1.63818359e-01,  -1.63818359e-01],
                        [ -1.39495850e-01,  -1.39495850e-01],
                        [ -1.10351562e-01,  -1.10382080e-01],
                        [ -8.67614746e-02,  -8.67919922e-02],
                        [ -7.09533691e-02,  -7.09228516e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -2.86865234e-02,  -2.87170410e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  2.74353027e-02,   2.74658203e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  1.25915527e-01,   1.25885010e-01],
                        [  1.82586670e-01,   1.82586670e-01],
                        [  2.21588135e-01,   2.21588135e-01],
                        [  2.28332520e-01,   2.28332520e-01],
                        [  2.00256348e-01,   2.00256348e-01],
                        [  1.41937256e-01,   1.41937256e-01],
                        [  5.52368164e-02,   5.52673340e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -1.80145264e-01,  -1.80145264e-01],
                        [ -2.80670166e-01,  -2.80639648e-01],
                        [ -3.28735352e-01,  -3.28704834e-01],
                        [ -3.14910889e-01,  -3.14941406e-01],
                        [ -2.59582520e-01,  -2.59613037e-01],
                        [ -2.01202393e-01,  -2.01202393e-01],
                        [ -1.67907715e-01,  -1.67877197e-01],
                        [ -1.57531738e-01,  -1.57531738e-01],
                        [ -1.47277832e-01,  -1.47308350e-01],
                        [ -1.19750977e-01,  -1.19750977e-01],
                        [ -7.56835938e-02,  -7.56530762e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [  3.35083008e-02,   3.34777832e-02],
                        [  9.24987793e-02,   9.24682617e-02],
                        [  1.42730713e-01,   1.42761230e-01],
                        [  1.72485352e-01,   1.72515869e-01],
                        [  1.80328369e-01,   1.80297852e-01],
                        [  1.73980713e-01,   1.73950195e-01],
                        [  1.61285400e-01,   1.61315918e-01],
                        [  1.44836426e-01,   1.44866943e-01],
                        [  1.22985840e-01,   1.22955322e-01],
                        [  9.55810547e-02,   9.55505371e-02],
                        [  6.87561035e-02,   6.87866211e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.51757812e-02,   5.51452637e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  6.02722168e-02,   6.02722168e-02],
                        [  5.88378906e-02,   5.88073730e-02],
                        [  5.74645996e-02,   5.74340820e-02],
                        [  5.73425293e-02,   5.73730469e-02],
                        [  5.96923828e-02,   5.97229004e-02],
                        [  6.32629395e-02,   6.32324219e-02],
                        [  6.54296875e-02,   6.53991699e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  6.77795410e-02,   6.78100586e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  6.38122559e-02,   6.37817383e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  3.47900391e-02,   3.48205566e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  6.92749023e-03,   6.86645508e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -1.95312500e-03,  -1.92260742e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -7.59887695e-03,  -7.62939453e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.38244629e-02,  -1.37939453e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -1.78222656e-02,  -1.78527832e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -5.58471680e-03,  -5.55419922e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -7.35473633e-03,  -7.38525391e-03],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [  3.23486328e-03,   3.26538086e-03],
                        [  8.63647461e-03,   8.66699219e-03],
                        [  7.93457031e-03,   7.90405273e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  5.61523438e-03,   5.64575195e-03],
                        [  1.00708008e-02,   1.01013184e-02],
                        [  1.59606934e-02,   1.59301758e-02],
                        [  1.92565918e-02,   1.92260742e-02],
                        [  1.61132812e-02,   1.61437988e-02],
                        [  6.07299805e-03,   6.10351562e-03],
                        [ -7.53784180e-03,  -7.56835938e-03],
                        [ -2.05688477e-02,  -2.05993652e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -3.03649902e-02,  -3.03344727e-02],
                        [ -2.44445801e-02,  -2.44750977e-02],
                        [ -1.52282715e-02,  -1.52587891e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -6.16455078e-03,  -6.13403320e-03],
                        [ -1.11389160e-02,  -1.11694336e-02],
                        [ -1.88598633e-02,  -1.88903809e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.07519531e-02,  -2.06909180e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [  4.88281250e-04,   4.57763672e-04],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  2.87780762e-02,   2.88085938e-02],
                        [  3.53698730e-02,   3.54003906e-02],
                        [  2.50549316e-02,   2.50244141e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -5.60607910e-02,  -5.60302734e-02],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -1.36566162e-01,  -1.36596680e-01],
                        [ -1.49566650e-01,  -1.49597168e-01],
                        [ -1.41235352e-01,  -1.41174316e-01],
                        [ -1.16058350e-01,  -1.16027832e-01],
                        [ -8.65173340e-02,  -8.65783691e-02],
                        [ -6.44836426e-02,  -6.45141602e-02],
                        [ -5.07202148e-02,  -5.06591797e-02],
                        [ -3.90014648e-02,  -3.89709473e-02],
                        [ -2.57263184e-02,  -2.57873535e-02],
                        [ -8.88061523e-03,  -8.91113281e-03],
                        [  1.63879395e-02,   1.64184570e-02],
                        [  5.44738770e-02,   5.45043945e-02],
                        [  1.05438232e-01,   1.05407715e-01],
                        [  1.63024902e-01,   1.62994385e-01],
                        [  2.11486816e-01,   2.11517334e-01],
                        [  2.28088379e-01,   2.28118896e-01],
                        [  1.97601318e-01,   1.97570801e-01],
                        [  1.23535156e-01,   1.23504639e-01],
                        [  2.10571289e-02,   2.10876465e-02],
                        [ -9.51843262e-02,  -9.51538086e-02],
                        [ -2.09594727e-01,  -2.09625244e-01],
                        [ -2.96997070e-01,  -2.97058105e-01],
                        [ -3.30810547e-01,  -3.30780029e-01],
                        [ -3.07250977e-01,  -3.07189941e-01],
                        [ -2.54180908e-01,  -2.54211426e-01],
                        [ -2.06024170e-01,  -2.06085205e-01],
                        [ -1.73858643e-01,  -1.73858643e-01],
                        [ -1.46667480e-01,  -1.46606445e-01],
                        [ -1.13983154e-01,  -1.13983154e-01],
                        [ -7.62939453e-02,  -7.63244629e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [  5.95092773e-03,   6.01196289e-03],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  1.03271484e-01,   1.03210449e-01],
                        [  1.42425537e-01,   1.42425537e-01],
                        [  1.60766602e-01,   1.60827637e-01],
                        [  1.61193848e-01,   1.61193848e-01],
                        [  1.56127930e-01,   1.56066895e-01],
                        [  1.50939941e-01,   1.50909424e-01],
                        [  1.40533447e-01,   1.40594482e-01],
                        [  1.22314453e-01,   1.22344971e-01],
                        [  1.00891113e-01,   1.00830078e-01],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  6.42395020e-02,   6.43005371e-02],
                        [  5.37719727e-02,   5.38024902e-02],
                        [  4.90112305e-02,   4.89501953e-02],
                        [  4.48303223e-02,   4.47998047e-02],
                        [  3.83911133e-02,   3.84521484e-02],
                        [  3.43017578e-02,   3.43627930e-02],
                        [  3.72314453e-02,   3.72009277e-02],
                        [  4.42504883e-02,   4.41894531e-02],
                        [  4.98352051e-02,   4.98962402e-02],
                        [  5.30090332e-02,   5.30700684e-02],
                        [  5.46875000e-02,   5.46264648e-02],
                        [  5.40161133e-02,   5.39550781e-02],
                        [  5.12695312e-02,   5.13000488e-02],
                        [  4.84619141e-02,   4.85229492e-02],
                        [  4.54101562e-02,   4.53796387e-02],
                        [  3.97033691e-02,   3.96423340e-02],
                        [  3.20434570e-02,   3.20739746e-02],
                        [  2.61230469e-02,   2.61840820e-02],
                        [  2.16674805e-02,   2.16369629e-02],
                        [  1.34582520e-02,   1.33972168e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -1.55334473e-02,  -1.54724121e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.72521973e-02,  -2.73132324e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -7.23266602e-03,  -7.14111328e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  9.79614258e-03,   9.73510742e-03],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.04370117e-02,   1.04980469e-02],
                        [  6.40869141e-04,   6.71386719e-04],
                        [ -1.26037598e-02,  -1.26647949e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -1.69677734e-02,  -1.69067383e-02],
                        [ -6.28662109e-03,  -6.25610352e-03],
                        [  4.88281250e-03,   4.82177734e-03],
                        [  1.24206543e-02,   1.23901367e-02],
                        [  1.70593262e-02,   1.71203613e-02],
                        [  2.05078125e-02,   2.05383301e-02],
                        [  2.13928223e-02,   2.13317871e-02],
                        [  1.69067383e-02,   1.68762207e-02],
                        [  7.87353516e-03,   7.93457031e-03],
                        [ -1.22070312e-03,  -1.19018555e-03],
                        [ -7.50732422e-03,  -7.56835938e-03],
                        [ -1.24816895e-02,  -1.25427246e-02],
                        [ -1.85852051e-02,  -1.85241699e-02],
                        [ -2.64892578e-02,  -2.64282227e-02],
                        [ -3.51562500e-02,  -3.51867676e-02],
                        [ -4.18395996e-02,  -4.19006348e-02],
                        [ -4.44946289e-02,  -4.44641113e-02],
                        [ -4.48608398e-02,  -4.47998047e-02],
                        [ -4.53796387e-02,  -4.54101562e-02],
                        [ -4.36096191e-02,  -4.36706543e-02],
                        [ -3.53088379e-02,  -3.52783203e-02],
                        [ -2.05688477e-02,  -2.05078125e-02],
                        [ -2.28881836e-03,  -2.31933594e-03],
                        [  1.79138184e-02,   1.78222656e-02],
                        [  3.72924805e-02,   3.73229980e-02],
                        [  4.94689941e-02,   4.95300293e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  2.10571289e-02,   2.09960938e-02],
                        [ -2.60009766e-02,  -2.59704590e-02],
                        [ -8.34655762e-02,  -8.34045410e-02],
                        [ -1.30249023e-01,  -1.30279541e-01],
                        [ -1.49536133e-01,  -1.49597168e-01],
                        [ -1.40441895e-01,  -1.40441895e-01],
                        [ -1.14715576e-01,  -1.14654541e-01],
                        [ -8.53271484e-02,  -8.53271484e-02],
                        [ -6.08520508e-02,  -6.09130859e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.97033691e-02,  -3.96118164e-02],
                        [ -3.76892090e-02,  -3.76586914e-02],
                        [ -2.95104980e-02,  -2.96020508e-02],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [  4.38842773e-02,   4.39758301e-02],
                        [  1.13159180e-01,   1.13189697e-01],
                        [  1.88690186e-01,   1.88629150e-01],
                        [  2.44049072e-01,   2.43988037e-01],
                        [  2.53662109e-01,   2.53723145e-01],
                        [  2.08801270e-01,   2.08831787e-01],
                        [  1.18499756e-01,   1.18438721e-01],
                        [ -1.86157227e-03,  -1.92260742e-03],
                        [ -1.35986328e-01,  -1.35925293e-01],
                        [ -2.60040283e-01,  -2.59979248e-01],
                        [ -3.40759277e-01,  -3.40820312e-01],
                        [ -3.53698730e-01,  -3.53759766e-01],
                        [ -3.09020996e-01,  -3.08959961e-01],
                        [ -2.48779297e-01,  -2.48718262e-01],
                        [ -2.09503174e-01,  -2.09564209e-01],
                        [ -1.92138672e-01,  -1.92230225e-01],
                        [ -1.73095703e-01,  -1.73034668e-01],
                        [ -1.35345459e-01,  -1.35284424e-01],
                        [ -8.10546875e-02,  -8.10852051e-02],
                        [ -1.92565918e-02,  -1.93481445e-02],
                        [  4.55017090e-02,   4.55322266e-02],
                        [  1.08306885e-01,   1.08398438e-01],
                        [  1.57653809e-01,   1.57653809e-01],
                        [  1.83929443e-01,   1.83837891e-01],
                        [  1.88964844e-01,   1.88964844e-01],
                        [  1.81823730e-01,   1.81945801e-01],
                        [  1.69189453e-01,   1.69189453e-01],
                        [  1.51489258e-01,   1.51397705e-01],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  9.80834961e-02,   9.81750488e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  6.32629395e-02,   6.31713867e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  5.45654297e-02,   5.46264648e-02],
                        [  4.23889160e-02,   4.24194336e-02],
                        [  2.82897949e-02,   2.82287598e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.30712891e-02,   2.31628418e-02],
                        [  3.28063965e-02,   3.28369141e-02],
                        [  4.50134277e-02,   4.49218750e-02],
                        [  5.61218262e-02,   5.60607910e-02],
                        [  6.45446777e-02,   6.46362305e-02],
                        [  7.04345703e-02,   7.04956055e-02],
                        [  7.35168457e-02,   7.34558105e-02],
                        [  7.12890625e-02,   7.12280273e-02],
                        [  6.21337891e-02,   6.21948242e-02],
                        [  4.94384766e-02,   4.94995117e-02],
                        [  3.82995605e-02,   3.82080078e-02],
                        [  2.96020508e-02,   2.95410156e-02],
                        [  2.20642090e-02,   2.21252441e-02],
                        [  1.67236328e-02,   1.67846680e-02],
                        [  1.38854980e-02,   1.38244629e-02],
                        [  9.15527344e-03,   9.09423828e-03],
                        [ -1.25122070e-03,  -1.22070312e-03],
                        [ -1.50146484e-02,  -1.49230957e-02],
                        [ -2.65502930e-02,  -2.65808105e-02],
                        [ -3.24707031e-02,  -3.25622559e-02],
                        [ -3.17382812e-02,  -3.17077637e-02],
                        [ -2.45361328e-02,  -2.44140625e-02],
                        [ -1.35498047e-02,  -1.35803223e-02],
                        [ -4.91333008e-03,  -5.00488281e-03],
                        [ -2.01416016e-03,  -1.98364258e-03],
                        [  4.57763672e-04,   5.79833984e-04],
                        [  9.42993164e-03,   9.39941406e-03],
                        [  2.06909180e-02,   2.05993652e-02],
                        [  2.42309570e-02,   2.42614746e-02],
                        [  2.08740234e-02,   2.09655762e-02],
                        [  2.08740234e-02,   2.08435059e-02],
                        [  2.60009766e-02,   2.59094238e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.71813965e-02,   1.72729492e-02],
                        [  3.35693359e-03,   3.35693359e-03],
                        [ -7.62939453e-03,  -7.72094727e-03],
                        [ -1.51977539e-02,  -1.52282715e-02],
                        [ -2.19726562e-02,  -2.18811035e-02],
                        [ -2.82287598e-02,  -2.81677246e-02],
                        [ -3.22875977e-02,  -3.23791504e-02],
                        [ -3.32031250e-02,  -3.32641602e-02],
                        [ -3.23791504e-02,  -3.22875977e-02],
                        [ -3.14025879e-02,  -3.13415527e-02],
                        [ -3.03649902e-02,  -3.04870605e-02],
                        [ -3.02124023e-02,  -3.02734375e-02],
                        [ -3.24707031e-02,  -3.23791504e-02],
                        [ -3.41491699e-02,  -3.40881348e-02],
                        [ -2.92968750e-02,  -2.93579102e-02],
                        [ -1.77307129e-02,  -1.78222656e-02],
                        [ -4.94384766e-03,  -4.88281250e-03],
                        [  6.56127930e-03,   6.62231445e-03],
                        [  1.73339844e-02,   1.72729492e-02],
                        [  2.61535645e-02,   2.60620117e-02],
                        [  3.10363770e-02,   3.10974121e-02],
                        [  3.11584473e-02,   3.12805176e-02],
                        [  2.19116211e-02,   2.18505859e-02],
                        [ -5.06591797e-03,  -5.15747070e-03],
                        [ -4.98046875e-02,  -4.97436523e-02],
                        [ -9.66796875e-02,  -9.65576172e-02],
                        [ -1.26190186e-01,  -1.26220703e-01],
                        [ -1.31408691e-01,  -1.31500244e-01],
                        [ -1.18560791e-01,  -1.18530273e-01],
                        [ -9.88159180e-02,  -9.87243652e-02],
                        [ -8.40148926e-02,  -8.40454102e-02],
                        [ -7.97119141e-02,  -7.98034668e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -5.23071289e-02,  -5.21850586e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  5.71289062e-02,   5.70068359e-02],
                        [  1.21887207e-01,   1.21887207e-01],
                        [  1.87377930e-01,   1.87500000e-01],
                        [  2.41424561e-01,   2.41455078e-01],
                        [  2.58239746e-01,   2.58117676e-01],
                        [  2.20428467e-01,   2.20367432e-01],
                        [  1.33911133e-01,   1.34033203e-01],
                        [  1.55944824e-02,   1.56250000e-02],
                        [ -1.20666504e-01,  -1.20788574e-01],
                        [ -2.54455566e-01,  -2.54486084e-01],
                        [ -3.48937988e-01,  -3.48815918e-01],
                        [ -3.73168945e-01,  -3.73107910e-01],
                        [ -3.35144043e-01,  -3.35235596e-01],
                        [ -2.75543213e-01,  -2.75604248e-01],
                        [ -2.27264404e-01,  -2.27172852e-01],
                        [ -1.94000244e-01,  -1.93939209e-01],
                        [ -1.63787842e-01,  -1.63879395e-01],
                        [ -1.26068115e-01,  -1.26159668e-01],
                        [ -7.52258301e-02,  -7.51647949e-02],
                        [ -1.06201172e-02,  -1.05285645e-02],
                        [  6.01196289e-02,   6.00280762e-02],
                        [  1.21704102e-01,   1.21612549e-01],
                        [  1.61437988e-01,   1.61499023e-01],
                        [  1.78100586e-01,   1.78192139e-01],
                        [  1.79504395e-01,   1.79443359e-01],
                        [  1.73614502e-01,   1.73522949e-01],
                        [  1.64550781e-01,   1.64611816e-01],
                        [  1.51947021e-01,   1.52038574e-01],
                        [  1.33422852e-01,   1.33361816e-01],
                        [  1.11053467e-01,   1.10961914e-01],
                        [  9.25903320e-02,   9.26208496e-02],
                        [  8.17871094e-02,   8.19091797e-02],
                        [  7.20520020e-02,   7.20214844e-02],
                        [  5.50842285e-02,   5.49926758e-02],
                        [  3.32031250e-02,   3.32336426e-02],
                        [  1.55944824e-02,   1.57165527e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  6.43920898e-03,   6.31713867e-03],
                        [  1.71813965e-02,   1.71508789e-02],
                        [  3.86962891e-02,   3.88183594e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  8.04748535e-02,   8.03527832e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  8.80737305e-02,   8.81958008e-02],
                        [  7.79724121e-02,   7.80029297e-02],
                        [  6.25000000e-02,   6.23779297e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  4.52880859e-02,   4.53796387e-02],
                        [  3.92761230e-02,   3.93066406e-02],
                        [  2.57873535e-02,   2.56958008e-02],
                        [  1.10168457e-02,   1.09558105e-02],
                        [  4.02832031e-03,   4.11987305e-03],
                        [  2.92968750e-03,   3.02124023e-03],
                        [ -6.10351562e-04,  -7.01904297e-04],
                        [ -9.97924805e-03,  -1.00708008e-02],
                        [ -2.20642090e-02,  -2.19726562e-02],
                        [ -3.09448242e-02,  -3.08532715e-02],
                        [ -3.24707031e-02,  -3.25622559e-02],
                        [ -2.79235840e-02,  -2.80151367e-02],
                        [ -2.13317871e-02,  -2.12402344e-02],
                        [ -1.36108398e-02,  -1.34887695e-02],
                        [ -3.57055664e-03,  -3.63159180e-03],
                        [  6.95800781e-03,   6.86645508e-03],
                        [  1.44042969e-02,   1.44653320e-02],
                        [  1.80358887e-02,   1.81274414e-02],
                        [  1.92260742e-02,   1.91650391e-02],
                        [  1.93481445e-02,   1.92260742e-02],
                        [  2.11791992e-02,   2.12097168e-02],
                        [  2.62451172e-02,   2.63671875e-02],
                        [  2.85644531e-02,   2.85034180e-02],
                        [  2.04467773e-02,   2.03247070e-02],
                        [  5.37109375e-03,   5.40161133e-03],
                        [ -6.31713867e-03,  -6.22558594e-03],
                        [ -1.23596191e-02,  -1.23901367e-02],
                        [ -1.83715820e-02,  -1.84936523e-02],
                        [ -2.57263184e-02,  -2.56958008e-02],
                        [ -3.05175781e-02,  -3.03955078e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.36914062e-02,  -3.38134766e-02],
                        [ -3.50952148e-02,  -3.51257324e-02],
                        [ -3.50952148e-02,  -3.49731445e-02],
                        [ -3.56750488e-02,  -3.56445312e-02],
                        [ -3.78112793e-02,  -3.79333496e-02],
                        [ -3.72924805e-02,  -3.73535156e-02],
                        [ -3.22265625e-02,  -3.21044922e-02],
                        [ -2.71301270e-02,  -2.70690918e-02],
                        [ -2.39562988e-02,  -2.40783691e-02],
                        [ -1.75476074e-02,  -1.76086426e-02],
                        [ -4.15039062e-03,  -4.02832031e-03],
                        [  1.36108398e-02,   1.36718750e-02],
                        [  2.97241211e-02,   2.96020508e-02],
                        [  3.77502441e-02,   3.76586914e-02],
                        [  3.11584473e-02,   3.12500000e-02],
                        [  5.79833984e-03,   5.85937500e-03],
                        [ -3.64379883e-02,  -3.65295410e-02],
                        [ -8.56628418e-02,  -8.57238770e-02],
                        [ -1.25396729e-01,  -1.25305176e-01],
                        [ -1.38641357e-01,  -1.38549805e-01],
                        [ -1.20483398e-01,  -1.20574951e-01],
                        [ -8.74633789e-02,  -8.75549316e-02],
                        [ -6.49414062e-02,  -6.48803711e-02],
                        [ -6.11267090e-02,  -6.10046387e-02],
                        [ -5.98754883e-02,  -5.99060059e-02],
                        [ -4.22058105e-02,  -4.23278809e-02],
                        [ -6.13403320e-03,  -6.10351562e-03],
                        [  3.85437012e-02,   3.86657715e-02],
                        [  8.67614746e-02,   8.67309570e-02],
                        [  1.39129639e-01,   1.39007568e-01],
                        [  1.88201904e-01,   1.88232422e-01],
                        [  2.15454102e-01,   2.15606689e-01],
                        [  2.03948975e-01,   2.03918457e-01],
                        [  1.47430420e-01,   1.47308350e-01],
                        [  4.94995117e-02,   4.94995117e-02],
                        [ -7.76977539e-02,  -7.75451660e-02],
                        [ -2.11029053e-01,  -2.11029053e-01],
                        [ -3.17108154e-01,  -3.17230225e-01],
                        [ -3.63647461e-01,  -3.63677979e-01],
                        [ -3.42498779e-01,  -3.42346191e-01],
                        [ -2.80090332e-01,  -2.80059814e-01],
                        [ -2.16644287e-01,  -2.16796875e-01],
                        [ -1.75323486e-01,  -1.75384521e-01],
                        [ -1.51824951e-01,  -1.51702881e-01],
                        [ -1.26068115e-01,  -1.26007080e-01],
                        [ -8.27026367e-02,  -8.28247070e-02],
                        [ -2.42614746e-02,  -2.42919922e-02],
                        [  3.67431641e-02,   3.68652344e-02],
                        [  9.22241211e-02,   9.22546387e-02],
                        [  1.36993408e-01,   1.36871338e-01],
                        [  1.63635254e-01,   1.63543701e-01],
                        [  1.71569824e-01,   1.71661377e-01],
                        [  1.71966553e-01,   1.72058105e-01],
                        [  1.72485352e-01,   1.72393799e-01],
                        [  1.66503906e-01,   1.66412354e-01],
                        [  1.46423340e-01,   1.46514893e-01],
                        [  1.18621826e-01,   1.18713379e-01],
                        [  9.51538086e-02,   9.50622559e-02],
                        [  7.87048340e-02,   7.85827637e-02],
                        [  6.32629395e-02,   6.33544922e-02],
                        [  4.56237793e-02,   4.57458496e-02],
                        [  2.83508301e-02,   2.82897949e-02],
                        [  1.56250000e-02,   1.55029297e-02],
                        [  1.02844238e-02,   1.03149414e-02],
                        [  1.29394531e-02,   1.30615234e-02],
                        [  2.26440430e-02,   2.26135254e-02],
                        [  3.74450684e-02,   3.72924805e-02],
                        [  5.36804199e-02,   5.37414551e-02],
                        [  6.69860840e-02,   6.71386719e-02],
                        [  7.54699707e-02,   7.54089355e-02],
                        [  7.90710449e-02,   7.89489746e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  6.96411133e-02,   6.97937012e-02],
                        [  6.18591309e-02,   6.18286133e-02],
                        [  5.62133789e-02,   5.60913086e-02],
                        [  5.03540039e-02,   5.03234863e-02],
                        [  4.11376953e-02,   4.12902832e-02],
                        [  2.82287598e-02,   2.82592773e-02],
                        [  1.27258301e-02,   1.26037598e-02],
                        [ -3.35693359e-03,  -3.38745117e-03],
                        [ -1.67846680e-02,  -1.66625977e-02],
                        [ -2.50244141e-02,  -2.49633789e-02],
                        [ -2.78930664e-02,  -2.80151367e-02],
                        [ -2.76184082e-02,  -2.76794434e-02],
                        [ -2.60009766e-02,  -2.58789062e-02],
                        [ -2.25830078e-02,  -2.25219727e-02],
                        [ -1.72729492e-02,  -1.73950195e-02],
                        [ -1.22375488e-02,  -1.22985840e-02],
                        [ -8.36181641e-03,  -8.23974609e-03],
                        [ -3.23486328e-03,  -3.14331055e-03],
                        [  4.73022461e-03,   4.63867188e-03],
                        [  1.32446289e-02,   1.31225586e-02],
                        [  1.98059082e-02,   1.98974609e-02],
                        [  2.60009766e-02,   2.60925293e-02],
                        [  3.32946777e-02,   3.32031250e-02],
                        [  3.80554199e-02,   3.79333496e-02],
                        [  3.55834961e-02,   3.56445312e-02],
                        [  2.70385742e-02,   2.71606445e-02],
                        [  1.72119141e-02,   1.71508789e-02],
                        [  8.08715820e-03,   7.96508789e-03],
                        [ -1.15966797e-03,  -1.09863281e-03],
                        [ -1.08032227e-02,  -1.06506348e-02],
                        [ -1.94396973e-02,  -1.95007324e-02],
                        [ -2.58178711e-02,  -2.59399414e-02],
                        [ -3.09753418e-02,  -3.09448242e-02],
                        [ -3.74755859e-02,  -3.73535156e-02],
                        [ -4.46166992e-02,  -4.46472168e-02],
                        [ -4.67834473e-02,  -4.69055176e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -2.56347656e-02,  -2.54821777e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.57165527e-02,  -1.58386230e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.60314941e-02,  -2.58789062e-02],
                        [ -2.05993652e-02,  -2.05688477e-02],
                        [ -9.09423828e-03,  -9.24682617e-03],
                        [  3.81469727e-03,   3.78417969e-03],
                        [  1.66320801e-02,   1.67541504e-02],
                        [  2.63061523e-02,   2.63366699e-02],
                        [  2.53906250e-02,   2.52380371e-02],
                        [  9.24682617e-03,   9.18579102e-03],
                        [ -1.98364258e-02,  -1.96838379e-02],
                        [ -5.76477051e-02,  -5.75866699e-02],
                        [ -9.80224609e-02,  -9.81750488e-02],
                        [ -1.25976562e-01,  -1.26037598e-01],
                        [ -1.24633789e-01,  -1.24511719e-01],
                        [ -9.60693359e-02,  -9.59777832e-02],
                        [ -6.44836426e-02,  -6.45751953e-02],
                        [ -5.12695312e-02,  -5.13610840e-02],
                        [ -5.25207520e-02,  -5.24291992e-02],
                        [ -4.74853516e-02,  -4.73937988e-02],
                        [ -2.22778320e-02,  -2.23693848e-02],
                        [  2.16979980e-02,   2.15759277e-02],
                        [  7.64465332e-02,   7.65380859e-02],
                        [  1.34216309e-01,   1.34338379e-01],
                        [  1.85607910e-01,   1.85546875e-01],
                        [  2.16705322e-01,   2.16583252e-01],
                        [  2.12280273e-01,   2.12341309e-01],
                        [  1.63360596e-01,   1.63482666e-01],
                        [  7.18994141e-02,   7.18383789e-02],
                        [ -5.00793457e-02,  -5.02014160e-02],
                        [ -1.80999756e-01,  -1.80969238e-01],
                        [ -2.91259766e-01,  -2.91137695e-01],
                        [ -3.51318359e-01,  -3.51348877e-01],
                        [ -3.47351074e-01,  -3.47503662e-01],
                        [ -2.94036865e-01,  -2.94006348e-01],
                        [ -2.28485107e-01,  -2.28332520e-01],
                        [ -1.82952881e-01,  -1.82952881e-01],
                        [ -1.60339355e-01,  -1.60522461e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -9.66491699e-02,  -9.64965820e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [  3.60412598e-02,   3.59191895e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.33911133e-01,   1.34063721e-01],
                        [  1.54296875e-01,   1.54327393e-01],
                        [  1.56494141e-01,   1.56372070e-01],
                        [  1.49108887e-01,   1.49078369e-01],
                        [  1.45782471e-01,   1.45935059e-01],
                        [  1.47949219e-01,   1.48010254e-01],
                        [  1.41082764e-01,   1.40960693e-01],
                        [  1.18194580e-01,   1.18133545e-01],
                        [  9.25903320e-02,   9.27124023e-02],
                        [  7.55920410e-02,   7.56835938e-02],
                        [  5.96923828e-02,   5.96008301e-02],
                        [  3.71398926e-02,   3.70178223e-02],
                        [  1.76696777e-02,   1.77917480e-02],
                        [  1.38244629e-02,   1.39465332e-02],
                        [  2.12097168e-02,   2.10876465e-02],
                        [  2.71606445e-02,   2.70385742e-02],
                        [  2.94799805e-02,   2.96020508e-02],
                        [  3.55834961e-02,   3.56750488e-02],
                        [  4.81567383e-02,   4.80651855e-02],
                        [  6.21032715e-02,   6.19812012e-02],
                        [  7.32727051e-02,   7.33642578e-02],
                        [  8.21228027e-02,   8.22448730e-02],
                        [  8.80126953e-02,   8.79516602e-02],
                        [  8.75244141e-02,   8.74023438e-02],
                        [  7.97729492e-02,   7.98339844e-02],
                        [  6.72912598e-02,   6.74133301e-02],
                        [  5.19104004e-02,   5.18798828e-02],
                        [  3.43322754e-02,   3.42102051e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  8.85009766e-04,   1.03759766e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.11791992e-02,  -2.13317871e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -2.94189453e-02,  -2.92663574e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -2.72521973e-02,  -2.74047852e-02],
                        [ -1.67541504e-02,  -1.67846680e-02],
                        [ -5.49316406e-03,  -5.34057617e-03],
                        [ -1.83105469e-04,  -1.52587891e-04],
                        [  1.52587891e-04,   0.00000000e+00],
                        [  2.13623047e-03,   2.10571289e-03],
                        [  9.52148438e-03,   9.64355469e-03],
                        [  1.96533203e-02,   1.97143555e-02],
                        [  2.81372070e-02,   2.80151367e-02],
                        [  3.23486328e-02,   3.22875977e-02],
                        [  3.06396484e-02,   3.07617188e-02],
                        [  2.26135254e-02,   2.26745605e-02],
                        [  1.10168457e-02,   1.08947754e-02],
                        [  3.05175781e-04,   2.44140625e-04],
                        [ -5.55419922e-03,  -5.46264648e-03],
                        [ -5.95092773e-03,  -5.85937500e-03],
                        [ -5.34057617e-03,  -5.46264648e-03],
                        [ -8.60595703e-03,  -8.72802734e-03],
                        [ -1.47399902e-02,  -1.46484375e-02],
                        [ -2.05993652e-02,  -2.04772949e-02],
                        [ -2.64282227e-02,  -2.65197754e-02],
                        [ -3.19824219e-02,  -3.21044922e-02],
                        [ -3.39355469e-02,  -3.38439941e-02],
                        [ -3.12500000e-02,  -3.10974121e-02],
                        [ -2.71301270e-02,  -2.72216797e-02],
                        [ -2.42614746e-02,  -2.43835449e-02],
                        [ -2.18505859e-02,  -2.17895508e-02],
                        [ -1.98669434e-02,  -1.97143555e-02],
                        [ -2.09655762e-02,  -2.10266113e-02],
                        [ -2.42614746e-02,  -2.44140625e-02],
                        [ -2.18505859e-02,  -2.18200684e-02],
                        [ -8.11767578e-03,  -7.96508789e-03],
                        [  1.13220215e-02,   1.12915039e-02],
                        [  2.56652832e-02,   2.55126953e-02],
                        [  3.02734375e-02,   3.03039551e-02],
                        [  2.72521973e-02,   2.73742676e-02],
                        [  1.66015625e-02,   1.65710449e-02],
                        [ -7.93457031e-03,  -8.08715820e-03],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -9.86022949e-02,  -9.84497070e-02],
                        [ -1.34674072e-01,  -1.34643555e-01],
                        [ -1.41845703e-01,  -1.41967773e-01],
                        [ -1.19201660e-01,  -1.19262695e-01],
                        [ -8.32519531e-02,  -8.30993652e-02],
                        [ -5.43518066e-02,  -5.42907715e-02],
                        [ -3.80554199e-02,  -3.82080078e-02],
                        [ -2.39868164e-02,  -2.40173340e-02],
                        [ -3.96728516e-04,  -2.44140625e-04],
                        [  3.61633301e-02,   3.62243652e-02],
                        [  8.25500488e-02,   8.24279785e-02],
                        [  1.33514404e-01,   1.33422852e-01],
                        [  1.81976318e-01,   1.82098389e-01],
                        [  2.13989258e-01,   2.14080811e-01],
                        [  2.09197998e-01,   2.09075928e-01],
                        [  1.54266357e-01,   1.54144287e-01],
                        [  5.38024902e-02,   5.38940430e-02],
                        [ -7.41271973e-02,  -7.40051270e-02],
                        [ -2.05596924e-01,  -2.05688477e-01],
                        [ -3.11645508e-01,  -3.11767578e-01],
                        [ -3.61968994e-01,  -3.61877441e-01],
                        [ -3.42620850e-01,  -3.42498779e-01],
                        [ -2.75024414e-01,  -2.75115967e-01],
                        [ -2.05993652e-01,  -2.06115723e-01],
                        [ -1.68823242e-01,  -1.68731689e-01],
                        [ -1.56494141e-01,  -1.56372070e-01],
                        [ -1.37664795e-01,  -1.37695312e-01],
                        [ -9.16748047e-02,  -9.17968750e-02],
                        [ -2.31323242e-02,  -2.30712891e-02],
                        [  5.01098633e-02,   5.02319336e-02],
                        [  1.11297607e-01,   1.11267090e-01],
                        [  1.49047852e-01,   1.48895264e-01],
                        [  1.60308838e-01,   1.60339355e-01],
                        [  1.55426025e-01,   1.55578613e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.53411865e-01,   1.53259277e-01],
                        [  1.51306152e-01,   1.51275635e-01],
                        [  1.32354736e-01,   1.32507324e-01],
                        [  9.93957520e-02,   9.94262695e-02],
                        [  6.65283203e-02,   6.63757324e-02],
                        [  4.22973633e-02,   4.22668457e-02],
                        [  2.56042480e-02,   2.57568359e-02],
                        [  1.50756836e-02,   1.51062012e-02],
                        [  1.22070312e-02,   1.20544434e-02],
                        [  1.75170898e-02,   1.74560547e-02],
                        [  2.92358398e-02,   2.93884277e-02],
                        [  4.39147949e-02,   4.39758301e-02],
                        [  5.67321777e-02,   5.66101074e-02],
                        [  6.50024414e-02,   6.49414062e-02],
                        [  7.00683594e-02,   7.01904297e-02],
                        [  7.43103027e-02,   7.44018555e-02],
                        [  7.78198242e-02,   7.76977539e-02],
                        [  7.83386230e-02,   7.82470703e-02],
                        [  7.30895996e-02,   7.31811523e-02],
                        [  6.19506836e-02,   6.20422363e-02],
                        [  4.89501953e-02,   4.88586426e-02],
                        [  3.85742188e-02,   3.84826660e-02],
                        [  3.12500000e-02,   3.13415527e-02],
                        [  2.46276855e-02,   2.47497559e-02],
                        [  1.75781250e-02,   1.74865723e-02],
                        [  9.09423828e-03,   8.97216797e-03],
                        [ -2.41088867e-03,  -2.34985352e-03],
                        [ -1.46789551e-02,  -1.45568848e-02],
                        [ -2.25219727e-02,  -2.25830078e-02],
                        [ -2.50549316e-02,  -2.51770020e-02],
                        [ -2.38342285e-02,  -2.38037109e-02],
                        [ -1.69982910e-02,  -1.68762207e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  4.69970703e-03,   4.54711914e-03],
                        [  7.84301758e-03,   7.87353516e-03],
                        [  8.81958008e-03,   8.97216797e-03],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.58081055e-02,   1.56250000e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  1.69372559e-02,   1.70898438e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  1.92260742e-02,   1.90734863e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  9.73510742e-03,   9.85717773e-03],
                        [  1.28173828e-03,   1.31225586e-03],
                        [ -8.85009766e-03,  -9.00268555e-03],
                        [ -1.88598633e-02,  -1.89208984e-02],
                        [ -2.23999023e-02,  -2.22473145e-02],
                        [ -1.74255371e-02,  -1.73645020e-02],
                        [ -1.27868652e-02,  -1.29089355e-02],
                        [ -1.74865723e-02,  -1.75476074e-02],
                        [ -2.74353027e-02,  -2.73437500e-02],
                        [ -3.12500000e-02,  -3.11889648e-02],
                        [ -2.62756348e-02,  -2.63977051e-02],
                        [ -1.89514160e-02,  -1.90429688e-02],
                        [ -1.28784180e-02,  -1.27868652e-02],
                        [ -7.87353516e-03,  -7.75146484e-03],
                        [ -6.89697266e-03,  -6.98852539e-03],
                        [ -1.32751465e-02,  -1.33972168e-02],
                        [ -2.30102539e-02,  -2.29187012e-02],
                        [ -2.77404785e-02,  -2.76184082e-02],
                        [ -2.38952637e-02,  -2.40173340e-02],
                        [ -1.55944824e-02,  -1.57165527e-02],
                        [ -8.02612305e-03,  -7.90405273e-03],
                        [  1.52587891e-04,   3.05175781e-04],
                        [  1.33056641e-02,   1.32141113e-02],
                        [  2.70385742e-02,   2.69165039e-02],
                        [  2.77404785e-02,   2.78320312e-02],
                        [  6.25610352e-03,   6.37817383e-03],
                        [ -3.45153809e-02,  -3.45458984e-02],
                        [ -8.31909180e-02,  -8.33129883e-02],
                        [ -1.23382568e-01,  -1.23352051e-01],
                        [ -1.38641357e-01,  -1.38488770e-01],
                        [ -1.24176025e-01,  -1.24206543e-01],
                        [ -9.14916992e-02,  -9.16442871e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -2.76489258e-02,  -2.74963379e-02],
                        [ -6.19506836e-03,  -6.16455078e-03],
                        [  1.48315430e-02,   1.46789551e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  9.28039551e-02,   9.29565430e-02],
                        [  1.43249512e-01,   1.43280029e-01],
                        [  1.81610107e-01,   1.81457520e-01],
                        [  1.95861816e-01,   1.95831299e-01],
                        [  1.76239014e-01,   1.76361084e-01],
                        [  1.12426758e-01,   1.12487793e-01],
                        [  3.14331055e-03,   2.99072266e-03],
                        [ -1.33911133e-01,  -1.33972168e-01],
                        [ -2.65228271e-01,  -2.65075684e-01],
                        [ -3.54003906e-01,  -3.53912354e-01],
                        [ -3.76037598e-01,  -3.76159668e-01],
                        [ -3.35510254e-01,  -3.35571289e-01],
                        [ -2.65747070e-01,  -2.65625000e-01],
                        [ -2.05596924e-01,  -2.05535889e-01],
                        [ -1.70440674e-01,  -1.70532227e-01],
                        [ -1.45385742e-01,  -1.45477295e-01],
                        [ -1.05590820e-01,  -1.05499268e-01],
                        [ -4.15649414e-02,  -4.14428711e-02],
                        [  3.48510742e-02,   3.47595215e-02],
                        [  1.03698730e-01,   1.03576660e-01],
                        [  1.48712158e-01,   1.48803711e-01],
                        [  1.63848877e-01,   1.63970947e-01],
                        [  1.58294678e-01,   1.58203125e-01],
                        [  1.49658203e-01,   1.49505615e-01],
                        [  1.45233154e-01,   1.45324707e-01],
                        [  1.37908936e-01,   1.38031006e-01],
                        [  1.21185303e-01,   1.21124268e-01],
                        [  9.86022949e-02,   9.84802246e-02],
                        [  7.68737793e-02,   7.69042969e-02],
                        [  5.86853027e-02,   5.88378906e-02],
                        [  4.42504883e-02,   4.42199707e-02],
                        [  3.44848633e-02,   3.43627930e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.88085938e-02,   2.89611816e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  3.40576172e-02,   3.39355469e-02],
                        [  4.47692871e-02,   4.47387695e-02],
                        [  5.83801270e-02,   5.85327148e-02],
                        [  6.82373047e-02,   6.82678223e-02],
                        [  7.18994141e-02,   7.17468262e-02],
                        [  7.28759766e-02,   7.28149414e-02],
                        [  7.35473633e-02,   7.36999512e-02],
                        [  7.15026855e-02,   7.15637207e-02],
                        [  6.35070801e-02,   6.33544922e-02],
                        [  4.97741699e-02,   4.97131348e-02],
                        [  3.35693359e-02,   3.37219238e-02],
                        [  1.93786621e-02,   1.94396973e-02],
                        [  1.00708008e-02,   9.91821289e-03],
                        [  4.48608398e-03,   4.42504883e-03],
                        [  2.44140625e-04,   3.96728516e-04],
                        [ -2.44140625e-03,  -2.38037109e-03],
                        [ -3.63159180e-03,  -3.75366211e-03],
                        [ -5.06591797e-03,  -5.12695312e-03],
                        [ -6.40869141e-03,  -6.31713867e-03],
                        [ -5.55419922e-03,  -5.46264648e-03],
                        [ -3.47900391e-03,  -3.54003906e-03],
                        [ -2.96020508e-03,  -3.08227539e-03],
                        [ -3.38745117e-03,  -3.32641602e-03],
                        [ -2.28881836e-03,  -2.13623047e-03],
                        [  5.18798828e-04,   4.57763672e-04],
                        [  3.26538086e-03,   3.11279297e-03],
                        [  4.63867188e-03,   4.69970703e-03],
                        [  5.64575195e-03,   5.79833984e-03],
                        [  1.00097656e-02,   9.94873047e-03],
                        [  1.89514160e-02,   1.87988281e-02],
                        [  2.59399414e-02,   2.60009766e-02],
                        [  2.37426758e-02,   2.39257812e-02],
                        [  1.42211914e-02,   1.41601562e-02],
                        [  3.75366211e-03,   3.60107422e-03],
                        [ -5.00488281e-03,  -4.94384766e-03],
                        [ -1.11083984e-02,  -1.09558105e-02],
                        [ -1.29089355e-02,  -1.29394531e-02],
                        [ -1.14746094e-02,  -1.16271973e-02],
                        [ -9.91821289e-03,  -9.94873047e-03],
                        [ -9.61303711e-03,  -9.49096680e-03],
                        [ -1.19323730e-02,  -1.19018555e-02],
                        [ -1.87683105e-02,  -1.88903809e-02],
                        [ -2.67028809e-02,  -2.67333984e-02],
                        [ -2.81372070e-02,  -2.80151367e-02],
                        [ -2.22167969e-02,  -2.21557617e-02],
                        [ -1.70593262e-02,  -1.72119141e-02],
                        [ -1.82495117e-02,  -1.83105469e-02],
                        [ -2.30407715e-02,  -2.29187012e-02],
                        [ -2.83813477e-02,  -2.82897949e-02],
                        [ -3.45153809e-02,  -3.46374512e-02],
                        [ -3.98254395e-02,  -3.99169922e-02],
                        [ -3.99169922e-02,  -3.97949219e-02],
                        [ -3.32336426e-02,  -3.31420898e-02],
                        [ -2.11486816e-02,  -2.12707520e-02],
                        [ -3.72314453e-03,  -3.84521484e-03],
                        [  1.82495117e-02,   1.83715820e-02],
                        [  3.69262695e-02,   3.70178223e-02],
                        [  3.82080078e-02,   3.81164551e-02],
                        [  1.33666992e-02,   1.32751465e-02],
                        [ -3.17993164e-02,  -3.17077637e-02],
                        [ -8.06884766e-02,  -8.05664062e-02],
                        [ -1.16271973e-01,  -1.16333008e-01],
                        [ -1.26800537e-01,  -1.26953125e-01],
                        [ -1.10198975e-01,  -1.10107422e-01],
                        [ -7.79113770e-02,  -7.77893066e-02],
                        [ -4.81872559e-02,  -4.82482910e-02],
                        [ -2.81982422e-02,  -2.83508301e-02],
                        [ -8.33129883e-03,  -8.27026367e-03],
                        [  2.35595703e-02,   2.37121582e-02],
                        [  6.81152344e-02,   6.80847168e-02],
                        [  1.17614746e-01,   1.17492676e-01],
                        [  1.64794922e-01,   1.64794922e-01],
                        [  2.00561523e-01,   2.00683594e-01],
                        [  2.07641602e-01,   2.07641602e-01],
                        [  1.67755127e-01,   1.67602539e-01],
                        [  7.70263672e-02,   7.69958496e-02],
                        [ -5.01403809e-02,  -4.99877930e-02],
                        [ -1.89147949e-01,  -1.89117432e-01],
                        [ -3.09600830e-01,  -3.09753418e-01],
                        [ -3.79730225e-01,  -3.79760742e-01],
                        [ -3.82080078e-01,  -3.81927490e-01],
                        [ -3.28338623e-01,  -3.28308105e-01],
                        [ -2.53997803e-01,  -2.54150391e-01],
                        [ -1.92779541e-01,  -1.92840576e-01],
                        [ -1.52496338e-01,  -1.52343750e-01],
                        [ -1.15539551e-01,  -1.15478516e-01],
                        [ -6.38427734e-02,  -6.39953613e-02],
                        [  1.12915039e-03,   1.06811523e-03],
                        [  6.34765625e-02,   6.35986328e-02],
                        [  1.09161377e-01,   1.09252930e-01],
                        [  1.34307861e-01,   1.34185791e-01],
                        [  1.43188477e-01,   1.43096924e-01],
                        [  1.44439697e-01,   1.44561768e-01],
                        [  1.45721436e-01,   1.45812988e-01],
                        [  1.45812988e-01,   1.45721436e-01],
                        [  1.36444092e-01,   1.36352539e-01],
                        [  1.16058350e-01,   1.16149902e-01],
                        [  9.57031250e-02,   9.58251953e-02],
                        [  8.44726562e-02,   8.43811035e-02],
                        [  7.72399902e-02,   7.71179199e-02],
                        [  6.35986328e-02,   6.36596680e-02],
                        [  4.16870117e-02,   4.18090820e-02],
                        [  1.87683105e-02,   1.87072754e-02],
                        [  3.60107422e-03,   3.47900391e-03],
                        [  1.73950195e-03,   1.80053711e-03],
                        [  1.37023926e-02,   1.38549805e-02],
                        [  3.41491699e-02,   3.41186523e-02],
                        [  5.45349121e-02,   5.44128418e-02],
                        [  6.99157715e-02,   6.99462891e-02],
                        [  8.08105469e-02,   8.09631348e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  8.93859863e-02,   8.92333984e-02],
                        [  8.37402344e-02,   8.37402344e-02],
                        [  7.14721680e-02,   7.16552734e-02],
                        [  5.51452637e-02,   5.51452637e-02],
                        [  3.83300781e-02,   3.81469727e-02],
                        [  2.24914551e-02,   2.24609375e-02],
                        [  7.38525391e-03,   7.56835938e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -8.51440430e-03,  -8.66699219e-03],
                        [ -6.68334961e-03,  -6.71386719e-03],
                        [ -3.78417969e-03,  -3.66210938e-03],
                        [ -2.10571289e-03,  -2.04467773e-03],
                        [ -1.06811523e-03,  -1.19018555e-03],
                        [ -1.46484375e-03,  -1.52587891e-03],
                        [ -3.72314453e-03,  -3.60107422e-03],
                        [ -4.54711914e-03,  -4.45556641e-03],
                        [ -4.27246094e-04,  -5.49316406e-04],
                        [  6.77490234e-03,   6.68334961e-03],
                        [  1.20849609e-02,   1.21765137e-02],
                        [  1.27258301e-02,   1.28173828e-02],
                        [  9.24682617e-03,   9.15527344e-03],
                        [  4.85229492e-03,   4.73022461e-03],
                        [  4.39453125e-03,   4.51660156e-03],
                        [  9.64355469e-03,   9.79614258e-03],
                        [  1.62963867e-02,   1.62048340e-02],
                        [  1.86157227e-02,   1.84936523e-02],
                        [  1.61132812e-02,   1.62048340e-02],
                        [  1.24816895e-02,   1.26037598e-02],
                        [  9.73510742e-03,   9.67407227e-03],
                        [  6.65283203e-03,   6.53076172e-03],
                        [  3.20434570e-03,   3.26538086e-03],
                        [  1.52587891e-04,   3.05175781e-04],
                        [ -6.19506836e-03,  -6.22558594e-03],
                        [ -1.96228027e-02,  -1.97753906e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -4.47387695e-02,  -4.45861816e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.08020020e-02,  -4.09851074e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -2.34680176e-02,  -2.33154297e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -2.13012695e-02,  -2.14233398e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.85034180e-02,  -2.83813477e-02],
                        [ -2.42309570e-02,  -2.42004395e-02],
                        [ -1.50756836e-02,  -1.51977539e-02],
                        [ -3.72314453e-03,  -3.78417969e-03],
                        [  7.96508789e-03,   8.08715820e-03],
                        [  1.77612305e-02,   1.78222656e-02],
                        [  2.33764648e-02,   2.32543945e-02],
                        [  2.34985352e-02,   2.34375000e-02],
                        [  1.46484375e-02,   1.47705078e-02],
                        [ -9.94873047e-03,  -9.85717773e-03],
                        [ -5.04455566e-02,  -5.05676270e-02],
                        [ -9.22851562e-02,  -9.23767090e-02],
                        [ -1.16577148e-01,  -1.16455078e-01],
                        [ -1.16058350e-01,  -1.15936279e-01],
                        [ -9.56115723e-02,  -9.57336426e-02],
                        [ -6.52160645e-02,  -6.53381348e-02],
                        [ -3.67126465e-02,  -3.65600586e-02],
                        [ -1.56860352e-02,  -1.55639648e-02],
                        [  4.97436523e-03,   4.85229492e-03],
                        [  3.51867676e-02,   3.50952148e-02],
                        [  7.59887695e-02,   7.60803223e-02],
                        [  1.21337891e-01,   1.21429443e-01],
                        [  1.61956787e-01,   1.61895752e-01],
                        [  1.84356689e-01,   1.84234619e-01],
                        [  1.75109863e-01,   1.75170898e-01],
                        [  1.26220703e-01,   1.26342773e-01],
                        [  3.54919434e-02,   3.54614258e-02],
                        [ -8.85314941e-02,  -8.86535645e-02],
                        [ -2.20458984e-01,  -2.20428467e-01],
                        [ -3.25256348e-01,  -3.25103760e-01],
                        [ -3.74328613e-01,  -3.74328613e-01],
                        [ -3.59802246e-01,  -3.59985352e-01],
                        [ -3.02124023e-01,  -3.02124023e-01],
                        [ -2.40264893e-01,  -2.40081787e-01],
                        [ -2.00592041e-01,  -2.00592041e-01],
                        [ -1.74530029e-01,  -1.74713135e-01],
                        [ -1.34063721e-01,  -1.34063721e-01],
                        [ -6.41479492e-02,  -6.39953613e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  1.03057861e-01,   1.02935791e-01],
                        [  1.48406982e-01,   1.48376465e-01],
                        [  1.58325195e-01,   1.58447266e-01],
                        [  1.52709961e-01,   1.52740479e-01],
                        [  1.49871826e-01,   1.49780273e-01],
                        [  1.51641846e-01,   1.51580811e-01],
                        [  1.49749756e-01,   1.49871826e-01],
                        [  1.37023926e-01,   1.37115479e-01],
                        [  1.13342285e-01,   1.13220215e-01],
                        [  8.62731934e-02,   8.61816406e-02],
                        [  6.39038086e-02,   6.40258789e-02],
                        [  4.71191406e-02,   4.72106934e-02],
                        [  3.17382812e-02,   3.16162109e-02],
                        [  1.59301758e-02,   1.58386230e-02],
                        [  3.41796875e-03,   3.54003906e-03],
                        [  1.22070312e-03,   1.34277344e-03],
                        [  1.33361816e-02,   1.32141113e-02],
                        [  3.46984863e-02,   3.46069336e-02],
                        [  5.50842285e-02,   5.51757812e-02],
                        [  6.94580078e-02,   6.95495605e-02],
                        [  7.99255371e-02,   7.98339844e-02],
                        [  8.78601074e-02,   8.77380371e-02],
                        [  9.09118652e-02,   9.09729004e-02],
                        [  8.78906250e-02,   8.80126953e-02],
                        [  7.97729492e-02,   7.97119141e-02],
                        [  6.65588379e-02,   6.64062500e-02],
                        [  4.88586426e-02,   4.88891602e-02],
                        [  3.09143066e-02,   3.10668945e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  5.85937500e-03,   5.67626953e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -1.40686035e-02,  -1.39160156e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -1.81884766e-02,  -1.83410645e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -1.58386230e-02,  -1.56860352e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.26342773e-02,  -1.27563477e-02],
                        [ -1.23901367e-02,  -1.24206543e-02],
                        [ -9.09423828e-03,  -8.97216797e-03],
                        [  4.27246094e-03,   4.30297852e-03],
                        [  2.45056152e-02,   2.43835449e-02],
                        [  4.16259766e-02,   4.15649414e-02],
                        [  5.22460938e-02,   5.23681641e-02],
                        [  5.87463379e-02,   5.88073730e-02],
                        [  5.85327148e-02,   5.84106445e-02],
                        [  4.61120605e-02,   4.59899902e-02],
                        [  2.36816406e-02,   2.37731934e-02],
                        [  5.79833984e-04,   7.01904297e-04],
                        [ -1.56250000e-02,  -1.57165527e-02],
                        [ -2.27355957e-02,  -2.28271484e-02],
                        [ -2.24609375e-02,  -2.23693848e-02],
                        [ -1.95617676e-02,  -1.94396973e-02],
                        [ -2.00195312e-02,  -2.01110840e-02],
                        [ -2.70385742e-02,  -2.71606445e-02],
                        [ -3.75366211e-02,  -3.74450684e-02],
                        [ -4.40063477e-02,  -4.38842773e-02],
                        [ -4.26025391e-02,  -4.26635742e-02],
                        [ -3.66821289e-02,  -3.68041992e-02],
                        [ -3.02124023e-02,  -3.01513672e-02],
                        [ -2.22778320e-02,  -2.21557617e-02],
                        [ -1.25732422e-02,  -1.26037598e-02],
                        [ -6.86645508e-03,  -6.98852539e-03],
                        [ -1.03149414e-02,  -1.02844238e-02],
                        [ -1.81579590e-02,  -1.80358887e-02],
                        [ -2.06604004e-02,  -2.06909180e-02],
                        [ -1.63574219e-02,  -1.65100098e-02],
                        [ -1.16577148e-02,  -1.16271973e-02],
                        [ -8.27026367e-03,  -8.11767578e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  7.99560547e-03,   7.84301758e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.11486816e-02,   2.13012695e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  3.87573242e-03,   3.72314453e-03],
                        [ -2.86254883e-02,  -2.86560059e-02],
                        [ -7.26013184e-02,  -7.24487305e-02],
                        [ -1.09710693e-01,  -1.09649658e-01],
                        [ -1.23962402e-01,  -1.24114990e-01],
                        [ -1.12945557e-01,  -1.13006592e-01],
                        [ -8.46557617e-02,  -8.45336914e-02],
                        [ -5.15441895e-02,  -5.14526367e-02],
                        [ -2.52380371e-02,  -2.53601074e-02],
                        [ -7.84301758e-03,  -7.93457031e-03],
                        [  1.16577148e-02,   1.17492676e-02],
                        [  4.64782715e-02,   4.65698242e-02],
                        [  9.80834961e-02,   9.79919434e-02],
                        [  1.53411865e-01,   1.53320312e-01],
                        [  1.92993164e-01,   1.93084717e-01],
                        [  1.99737549e-01,   1.99798584e-01],
                        [  1.61499023e-01,   1.61407471e-01],
                        [  7.33337402e-02,   7.32421875e-02],
                        [ -5.48400879e-02,  -5.47180176e-02],
                        [ -1.94732666e-01,  -1.94610596e-01],
                        [ -3.09844971e-01,  -3.09936523e-01],
                        [ -3.70391846e-01,  -3.70544434e-01],
                        [ -3.65997314e-01,  -3.65936279e-01],
                        [ -3.13415527e-01,  -3.13262939e-01],
                        [ -2.49176025e-01,  -2.49237061e-01],
                        [ -2.03704834e-01,  -2.03826904e-01],
                        [ -1.77612305e-01,  -1.77612305e-01],
                        [ -1.46545410e-01,  -1.46423340e-01],
                        [ -8.94470215e-02,  -8.94470215e-02],
                        [ -1.01318359e-02,  -1.02539062e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  1.18865967e-01,   1.18988037e-01],
                        [  1.39739990e-01,   1.39709473e-01],
                        [  1.43981934e-01,   1.43859863e-01],
                        [  1.48864746e-01,   1.48895264e-01],
                        [  1.56829834e-01,   1.56982422e-01],
                        [  1.57104492e-01,   1.57104492e-01],
                        [  1.42852783e-01,   1.42700195e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  9.52758789e-02,   9.54284668e-02],
                        [  7.20214844e-02,   7.20825195e-02],
                        [  4.76379395e-02,   4.74853516e-02],
                        [  2.44750977e-02,   2.44140625e-02],
                        [  8.11767578e-03,   8.27026367e-03],
                        [  7.32421875e-04,   7.93457031e-04],
                        [  2.31933594e-03,   2.16674805e-03],
                        [  1.44958496e-02,   1.44042969e-02],
                        [  3.59191895e-02,   3.60717773e-02],
                        [  5.92041016e-02,   5.92651367e-02],
                        [  7.69348145e-02,   7.68127441e-02],
                        [  8.77380371e-02,   8.76464844e-02],
                        [  9.38110352e-02,   9.39636230e-02],
                        [  9.54284668e-02,   9.55200195e-02],
                        [  9.04541016e-02,   9.03015137e-02],
                        [  7.96508789e-02,   7.95288086e-02],
                        [  6.74743652e-02,   6.75964355e-02],
                        [  5.50231934e-02,   5.51757812e-02],
                        [  3.74755859e-02,   3.73840332e-02],
                        [  1.37939453e-02,   1.36413574e-02],
                        [ -6.80541992e-03,  -6.74438477e-03],
                        [ -1.76391602e-02,  -1.74865723e-02],
                        [ -2.50244141e-02,  -2.50549316e-02],
                        [ -3.57055664e-02,  -3.58581543e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.01916504e-02,  -4.00695801e-02],
                        [ -2.80761719e-02,  -2.81066895e-02],
                        [ -1.48620605e-02,  -1.50146484e-02],
                        [ -3.35693359e-03,  -3.32641602e-03],
                        [  6.56127930e-03,   6.71386719e-03],
                        [  1.44653320e-02,   1.44348145e-02],
                        [  2.21252441e-02,   2.19421387e-02],
                        [  3.32031250e-02,   3.32336426e-02],
                        [  4.77600098e-02,   4.79125977e-02],
                        [  5.90209961e-02,   5.90515137e-02],
                        [  5.98144531e-02,   5.96313477e-02],
                        [  5.06591797e-02,   5.06286621e-02],
                        [  3.75976562e-02,   3.77502441e-02],
                        [  2.23388672e-02,   2.23999023e-02],
                        [  3.44848633e-03,   3.32641602e-03],
                        [ -1.50146484e-02,  -1.50756836e-02],
                        [ -2.51464844e-02,  -2.50244141e-02],
                        [ -2.53906250e-02,  -2.53295898e-02],
                        [ -2.38342285e-02,  -2.39257812e-02],
                        [ -2.87780762e-02,  -2.88085938e-02],
                        [ -3.87878418e-02,  -3.86962891e-02],
                        [ -4.54406738e-02,  -4.54101562e-02],
                        [ -4.38537598e-02,  -4.39758301e-02],
                        [ -3.57360840e-02,  -3.57666016e-02],
                        [ -2.39257812e-02,  -2.38342285e-02],
                        [ -1.09558105e-02,  -1.08947754e-02],
                        [ -1.61743164e-03,  -1.73950195e-03],
                        [  3.05175781e-04,   2.13623047e-04],
                        [ -2.07519531e-03,  -1.98364258e-03],
                        [ -4.30297852e-03,  -4.18090820e-03],
                        [ -8.78906250e-03,  -8.85009766e-03],
                        [ -1.95312500e-02,  -1.96533203e-02],
                        [ -3.28369141e-02,  -3.28063965e-02],
                        [ -3.99169922e-02,  -3.97949219e-02],
                        [ -3.60107422e-02,  -3.60717773e-02],
                        [ -2.28881836e-02,  -2.30102539e-02],
                        [ -6.01196289e-03,  -5.95092773e-03],
                        [  9.61303711e-03,   9.73510742e-03],
                        [  2.14538574e-02,   2.13623047e-02],
                        [  2.67333984e-02,   2.66113281e-02],
                        [  1.96533203e-02,   1.97448730e-02],
                        [ -3.47900391e-03,  -3.35693359e-03],
                        [ -3.85131836e-02,  -3.85742188e-02],
                        [ -7.48596191e-02,  -7.49816895e-02],
                        [ -9.85717773e-02,  -9.85717773e-02],
                        [ -9.76562500e-02,  -9.75341797e-02],
                        [ -7.33337402e-02,  -7.33337402e-02],
                        [ -4.19311523e-02,  -4.20227051e-02],
                        [ -1.74865723e-02,  -1.75476074e-02],
                        [  1.52587891e-03,   1.61743164e-03],
                        [  2.44140625e-02,   2.44445801e-02],
                        [  5.58471680e-02,   5.57556152e-02],
                        [  9.44213867e-02,   9.43908691e-02],
                        [  1.33911133e-01,   1.34063721e-01],
                        [  1.62658691e-01,   1.62689209e-01],
                        [  1.65313721e-01,   1.65161133e-01],
                        [  1.27044678e-01,   1.27014160e-01],
                        [  4.08630371e-02,   4.10461426e-02],
                        [ -8.24584961e-02,  -8.23974609e-02],
                        [ -2.13378906e-01,  -2.13531494e-01],
                        [ -3.15704346e-01,  -3.15795898e-01],
                        [ -3.61206055e-01,  -3.61083984e-01],
                        [ -3.42010498e-01,  -3.41918945e-01],
                        [ -2.78503418e-01,  -2.78594971e-01],
                        [ -2.08801270e-01,  -2.08923340e-01],
                        [ -1.60217285e-01,  -1.60156250e-01],
                        [ -1.29791260e-01,  -1.29669189e-01],
                        [ -9.51538086e-02,  -9.52148438e-02],
                        [ -4.16564941e-02,  -4.17480469e-02],
                        [  2.22473145e-02,   2.23388672e-02],
                        [  7.32116699e-02,   7.33337402e-02],
                        [  9.65270996e-02,   9.64050293e-02],
                        [  9.98229980e-02,   9.96704102e-02],
                        [  1.01745605e-01,   1.01867676e-01],
                        [  1.10900879e-01,   1.11083984e-01],
                        [  1.22344971e-01,   1.22222900e-01],
                        [  1.29272461e-01,   1.29058838e-01],
                        [  1.29394531e-01,   1.29455566e-01],
                        [  1.22741699e-01,   1.22955322e-01],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  9.31701660e-02,   9.29870605e-02],
                        [  7.40661621e-02,   7.40051270e-02],
                        [  5.53894043e-02,   5.55114746e-02],
                        [  3.88488770e-02,   3.88793945e-02],
                        [  2.64282227e-02,   2.63061523e-02],
                        [  2.14233398e-02,   2.13928223e-02],
                        [  2.38647461e-02,   2.39868164e-02],
                        [  2.92358398e-02,   2.92663574e-02],
                        [  3.59191895e-02,   3.57666016e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  6.17370605e-02,   6.19201660e-02],
                        [  7.08923340e-02,   7.09228516e-02],
                        [  7.02209473e-02,   7.00073242e-02],
                        [  6.52465820e-02,   6.51855469e-02],
                        [  6.20422363e-02,   6.22863770e-02],
                        [  6.08215332e-02,   6.09130859e-02],
                        [  5.94482422e-02,   5.92346191e-02],
                        [  5.45043945e-02,   5.43823242e-02],
                        [  4.14428711e-02,   4.15954590e-02],
                        [  2.22167969e-02,   2.22778320e-02],
                        [  7.14111328e-03,   7.01904297e-03],
                        [  1.70898438e-03,   1.67846680e-03],
                        [ -4.57763672e-04,  -3.35693359e-04],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -1.06506348e-02,  -1.07727051e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -6.10351562e-03,  -5.98144531e-03],
                        [  9.46044922e-04,   1.00708008e-03],
                        [  6.83593750e-03,   6.71386719e-03],
                        [  1.01623535e-02,   1.00402832e-02],
                        [  1.26342773e-02,   1.27258301e-02],
                        [  1.56860352e-02,   1.58691406e-02],
                        [  1.87683105e-02,   1.87072754e-02],
                        [  2.20336914e-02,   2.18505859e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.55126953e-02,   2.56652832e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  2.56347656e-03,   2.41088867e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -3.66210938e-04,  -2.74658203e-04],
                        [  3.54003906e-03,   3.50952148e-03],
                        [  3.05175781e-03,   2.96020508e-03],
                        [ -1.98364258e-03,  -1.92260742e-03],
                        [ -9.67407227e-03,  -9.55200195e-03],
                        [ -1.68151855e-02,  -1.68762207e-02],
                        [ -1.95312500e-02,  -1.96838379e-02],
                        [ -1.65405273e-02,  -1.64794922e-02],
                        [ -1.04370117e-02,  -1.02539062e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -4.63867188e-03,  -4.76074219e-03],
                        [ -7.75146484e-03,  -7.78198242e-03],
                        [ -1.06201172e-02,  -1.05285645e-02],
                        [ -1.11999512e-02,  -1.11083984e-02],
                        [ -1.34277344e-02,  -1.35192871e-02],
                        [ -2.10571289e-02,  -2.11181641e-02],
                        [ -3.31115723e-02,  -3.30505371e-02],
                        [ -4.81567383e-02,  -4.80651855e-02],
                        [ -6.29272461e-02,  -6.30187988e-02],
                        [ -6.83288574e-02,  -6.83898926e-02],
                        [ -5.73120117e-02,  -5.71594238e-02],
                        [ -3.40270996e-02,  -3.39965820e-02],
                        [ -7.35473633e-03,  -7.53784180e-03],
                        [  1.75170898e-02,   1.74560547e-02],
                        [  3.59191895e-02,   3.61328125e-02],
                        [  4.26025391e-02,   4.26635742e-02],
                        [  3.54003906e-02,   3.51867676e-02],
                        [  1.47094727e-02,   1.46179199e-02],
                        [ -1.62658691e-02,  -1.61132812e-02],
                        [ -4.79736328e-02,  -4.78515625e-02],
                        [ -6.67724609e-02,  -6.68945312e-02],
                        [ -6.52160645e-02,  -6.53076172e-02],
                        [ -4.80651855e-02,  -4.79736328e-02],
                        [ -2.56042480e-02,  -2.55126953e-02],
                        [ -3.05175781e-03,  -3.11279297e-03],
                        [  2.09960938e-02,   2.09350586e-02],
                        [  4.96215820e-02,   4.96826172e-02],
                        [  8.43200684e-02,   8.44116211e-02],
                        [  1.21795654e-01,   1.21734619e-01],
                        [  1.49383545e-01,   1.49261475e-01],
                        [  1.46820068e-01,   1.46881104e-01],
                        [  9.82055664e-02,   9.83581543e-02],
                        [  3.75366211e-03,   3.72314453e-03],
                        [ -1.19232178e-01,  -1.19384766e-01],
                        [ -2.42431641e-01,  -2.42431641e-01],
                        [ -3.33709717e-01,  -3.33587646e-01],
                        [ -3.69781494e-01,  -3.69781494e-01],
                        [ -3.50524902e-01,  -3.50646973e-01],
                        [ -2.98858643e-01,  -2.98889160e-01],
                        [ -2.41821289e-01,  -2.41729736e-01],
                        [ -1.91925049e-01,  -1.91894531e-01],
                        [ -1.43493652e-01,  -1.43585205e-01],
                        [ -8.29772949e-02,  -8.29772949e-02],
                        [ -6.13403320e-03,  -6.01196289e-03],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  1.26525879e-01,   1.26373291e-01],
                        [  1.45538330e-01,   1.45507812e-01],
                        [  1.38061523e-01,   1.38244629e-01],
                        [  1.25549316e-01,   1.25579834e-01],
                        [  1.23962402e-01,   1.23748779e-01],
                        [  1.30737305e-01,   1.30676270e-01],
                        [  1.30859375e-01,   1.31042480e-01],
                        [  1.17736816e-01,   1.17797852e-01],
                        [  9.97619629e-02,   9.96704102e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  7.07702637e-02,   7.08007812e-02],
                        [  5.56030273e-02,   5.55419922e-02],
                        [  4.15954590e-02,   4.15649414e-02],
                        [  3.13720703e-02,   3.14331055e-02],
                        [  2.73742676e-02,   2.74047852e-02],
                        [  3.23791504e-02,   3.23486328e-02],
                        [  4.34875488e-02,   4.34570312e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  5.78613281e-02,   5.78918457e-02],
                        [  6.14624023e-02,   6.15844727e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  6.93359375e-02,   6.91528320e-02],
                        [  7.21740723e-02,   7.21435547e-02],
                        [  7.16857910e-02,   7.18688965e-02],
                        [  6.50939941e-02,   6.51855469e-02],
                        [  5.23376465e-02,   5.21850586e-02],
                        [  3.58581543e-02,   3.57360840e-02],
                        [  1.88293457e-02,   1.89208984e-02],
                        [  4.42504883e-03,   4.51660156e-03],
                        [ -3.96728516e-03,  -4.02832031e-03],
                        [ -4.88281250e-03,  -4.94384766e-03],
                        [ -1.67846680e-03,  -1.61743164e-03],
                        [ -4.57763672e-04,  -4.27246094e-04],
                        [ -3.14331055e-03,  -3.23486328e-03],
                        [ -5.00488281e-03,  -4.97436523e-03],
                        [  2.44140625e-04,   3.35693359e-04],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  2.44750977e-02,   2.43530273e-02],
                        [  2.82897949e-02,   2.82287598e-02],
                        [  2.68554688e-02,   2.69165039e-02],
                        [  2.75878906e-02,   2.77099609e-02],
                        [  3.04260254e-02,   3.03955078e-02],
                        [  3.05175781e-02,   3.03344727e-02],
                        [  2.69470215e-02,   2.69165039e-02],
                        [  1.97143555e-02,   1.98974609e-02],
                        [  7.14111328e-03,   7.20214844e-03],
                        [ -8.75854492e-03,  -8.91113281e-03],
                        [ -2.24914551e-02,  -2.25219727e-02],
                        [ -3.11889648e-02,  -3.10974121e-02],
                        [ -3.40881348e-02,  -3.41186523e-02],
                        [ -2.92663574e-02,  -2.93884277e-02],
                        [ -1.62048340e-02,  -1.61437988e-02],
                        [  0.00000000e+00,   1.22070312e-04],
                        [  1.14440918e-02,   1.13525391e-02],
                        [  1.51977539e-02,   1.50146484e-02],
                        [  1.50146484e-02,   1.51062012e-02],
                        [  1.54113770e-02,   1.55639648e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  1.00097656e-02,   9.85717773e-03],
                        [ -3.50952148e-03,  -3.57055664e-03],
                        [ -1.96228027e-02,  -1.95312500e-02],
                        [ -3.25317383e-02,  -3.24096680e-02],
                        [ -4.27551270e-02,  -4.27856445e-02],
                        [ -5.11474609e-02,  -5.13000488e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -5.54199219e-02,  -5.53283691e-02],
                        [ -5.22766113e-02,  -5.23071289e-02],
                        [ -4.49218750e-02,  -4.49523926e-02],
                        [ -3.52172852e-02,  -3.50952148e-02],
                        [ -2.84118652e-02,  -2.83813477e-02],
                        [ -2.28576660e-02,  -2.30712891e-02],
                        [ -1.14746094e-02,  -1.15051270e-02],
                        [  5.58471680e-03,   5.82885742e-03],
                        [  2.12097168e-02,   2.12402344e-02],
                        [  3.11889648e-02,   3.09143066e-02],
                        [  3.30200195e-02,   3.29589844e-02],
                        [  2.16979980e-02,   2.19116211e-02],
                        [ -3.78417969e-03,  -3.72314453e-03],
                        [ -3.47290039e-02,  -3.48510742e-02],
                        [ -5.89904785e-02,  -5.90515137e-02],
                        [ -6.96105957e-02,  -6.95190430e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -4.84924316e-02,  -4.85534668e-02],
                        [ -2.41394043e-02,  -2.41088867e-02],
                        [  5.09643555e-03,   5.18798828e-03],
                        [  4.06799316e-02,   4.06494141e-02],
                        [  8.30688477e-02,   8.29162598e-02],
                        [  1.23901367e-01,   1.23870850e-01],
                        [  1.46789551e-01,   1.46972656e-01],
                        [  1.36505127e-01,   1.36535645e-01],
                        [  8.44726562e-02,   8.43200684e-02],
                        [ -1.09558105e-02,  -1.10473633e-02],
                        [ -1.38153076e-01,  -1.38061523e-01],
                        [ -2.64801025e-01,  -2.64709473e-01],
                        [ -3.49914551e-01,  -3.49945068e-01],
                        [ -3.69415283e-01,  -3.69506836e-01],
                        [ -3.29193115e-01,  -3.29223633e-01],
                        [ -2.58666992e-01,  -2.58605957e-01],
                        [ -1.92077637e-01,  -1.92077637e-01],
                        [ -1.45263672e-01,  -1.45294189e-01],
                        [ -1.07086182e-01,  -1.07055664e-01],
                        [ -5.73425293e-02,  -5.72814941e-02],
                        [  7.65991211e-03,   7.62939453e-03],
                        [  7.06176758e-02,   7.05261230e-02],
                        [  1.11083984e-01,   1.11114502e-01],
                        [  1.22985840e-01,   1.23138428e-01],
                        [  1.16668701e-01,   1.16638184e-01],
                        [  1.08062744e-01,   1.07910156e-01],
                        [  1.05133057e-01,   1.05163574e-01],
                        [  1.05194092e-01,   1.05316162e-01],
                        [  1.04339600e-01,   1.04309082e-01],
                        [  1.02539062e-01,   1.02416992e-01],
                        [  9.75646973e-02,   9.76257324e-02],
                        [  8.50830078e-02,   8.51440430e-02],
                        [  6.64367676e-02,   6.63452148e-02],
                        [  4.80957031e-02,   4.80346680e-02],
                        [  3.31726074e-02,   3.33251953e-02],
                        [  2.24609375e-02,   2.25524902e-02],
                        [  2.05688477e-02,   2.04467773e-02],
                        [  2.95410156e-02,   2.94189453e-02],
                        [  4.10461426e-02,   4.11376953e-02],
                        [  4.64477539e-02,   4.66003418e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  5.74340820e-02,   5.73120117e-02],
                        [  7.02209473e-02,   7.01599121e-02],
                        [  8.03527832e-02,   8.04138184e-02],
                        [  8.26721191e-02,   8.27636719e-02],
                        [  7.65991211e-02,   7.65686035e-02],
                        [  6.43615723e-02,   6.42395020e-02],
                        [  4.98657227e-02,   4.98352051e-02],
                        [  3.68652344e-02,   3.69262695e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  2.18811035e-02,   2.18505859e-02],
                        [  1.56250000e-02,   1.56860352e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [ -4.02832031e-03,  -4.15039062e-03],
                        [ -1.15356445e-02,  -1.15661621e-02],
                        [ -1.68151855e-02,  -1.66931152e-02],
                        [ -1.92260742e-02,  -1.91345215e-02],
                        [ -1.46179199e-02,  -1.47399902e-02],
                        [ -2.41088867e-03,  -2.53295898e-03],
                        [  1.05285645e-02,   1.05590820e-02],
                        [  1.79443359e-02,   1.80664062e-02],
                        [  2.08129883e-02,   2.08740234e-02],
                        [  2.23693848e-02,   2.23083496e-02],
                        [  2.33459473e-02,   2.32238770e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  1.83105469e-02,   1.84020996e-02],
                        [  1.22375488e-02,   1.22680664e-02],
                        [  9.15527344e-03,   9.12475586e-03],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  1.87988281e-02,   1.87683105e-02],
                        [  2.84729004e-02,   2.83813477e-02],
                        [  3.52478027e-02,   3.53088379e-02],
                        [  3.28979492e-02,   3.30200195e-02],
                        [  2.21862793e-02,   2.21252441e-02],
                        [  9.15527344e-03,   8.97216797e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [ -1.77307129e-02,  -1.75781250e-02],
                        [ -3.12500000e-02,  -3.12194824e-02],
                        [ -4.27246094e-02,  -4.28161621e-02],
                        [ -5.45654297e-02,  -5.45959473e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -7.68127441e-02,  -7.68127441e-02],
                        [ -7.46765137e-02,  -7.46154785e-02],
                        [ -6.05773926e-02,  -6.05163574e-02],
                        [ -4.02221680e-02,  -4.02526855e-02],
                        [ -2.00805664e-02,  -2.02026367e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  6.71386719e-03,   6.80541992e-03],
                        [  1.58996582e-02,   1.59606934e-02],
                        [  2.73742676e-02,   2.73437500e-02],
                        [  3.82995605e-02,   3.82385254e-02],
                        [  3.94897461e-02,   3.94592285e-02],
                        [  2.59094238e-02,   2.59399414e-02],
                        [  3.57055664e-03,   3.63159180e-03],
                        [ -1.68457031e-02,  -1.67846680e-02],
                        [ -3.01208496e-02,  -3.01818848e-02],
                        [ -3.72314453e-02,  -3.73535156e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.77294922e-02,  -4.76074219e-02],
                        [ -6.13403320e-02,  -6.12792969e-02],
                        [ -7.70874023e-02,  -7.71789551e-02],
                        [ -8.07495117e-02,  -8.08715820e-02],
                        [ -6.25000000e-02,  -6.25000000e-02],
                        [ -2.74963379e-02,  -2.73742676e-02],
                        [  1.05590820e-02,   1.06201172e-02],
                        [  4.42504883e-02,   4.41894531e-02],
                        [  7.65686035e-02,   7.65075684e-02],
                        [  1.11602783e-01,   1.11572266e-01],
                        [  1.45111084e-01,   1.45172119e-01],
                        [  1.65863037e-01,   1.65924072e-01],
                        [  1.60156250e-01,   1.60156250e-01],
                        [  1.14410400e-01,   1.14349365e-01],
                        [  2.19726562e-02,   2.19116211e-02],
                        [ -1.06414795e-01,  -1.06353760e-01],
                        [ -2.41058350e-01,  -2.40966797e-01],
                        [ -3.44360352e-01,  -3.44329834e-01],
                        [ -3.87817383e-01,  -3.87878418e-01],
                        [ -3.67431641e-01,  -3.67492676e-01],
                        [ -3.06243896e-01,  -3.06274414e-01],
                        [ -2.39135742e-01,  -2.39074707e-01],
                        [ -1.87133789e-01,  -1.87042236e-01],
                        [ -1.42364502e-01,  -1.42364502e-01],
                        [ -8.21228027e-02,  -8.22143555e-02],
                        [ -2.10571289e-03,  -2.13623047e-03],
                        [  7.26928711e-02,   7.27233887e-02],
                        [  1.14379883e-01,   1.14440918e-01],
                        [  1.19384766e-01,   1.19476318e-01],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  9.60388184e-02,   9.59167480e-02],
                        [  9.95483398e-02,   9.95178223e-02],
                        [  1.08917236e-01,   1.09100342e-01],
                        [  1.10870361e-01,   1.10931396e-01],
                        [  1.02752686e-01,   1.02600098e-01],
                        [  9.23156738e-02,   9.22851562e-02],
                        [  8.59680176e-02,   8.60900879e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  7.91015625e-02,   7.90405273e-02],
                        [  6.79931641e-02,   6.80236816e-02],
                        [  4.84924316e-02,   4.85229492e-02],
                        [  2.62756348e-02,   2.62145996e-02],
                        [  9.09423828e-03,   9.03320312e-03],
                        [  1.31225586e-03,   1.37329102e-03],
                        [  5.85937500e-03,   5.95092773e-03],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  4.53186035e-02,   4.52270508e-02],
                        [  6.55212402e-02,   6.54602051e-02],
                        [  8.10546875e-02,   8.11157227e-02],
                        [  9.12475586e-02,   9.13391113e-02],
                        [  9.39025879e-02,   9.39025879e-02],
                        [  8.80432129e-02,   8.79211426e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  5.35583496e-02,   5.36193848e-02],
                        [  2.94799805e-02,   2.94494629e-02],
                        [  8.75854492e-03,   8.72802734e-03],
                        [ -3.35693359e-03,  -3.29589844e-03],
                        [ -5.55419922e-03,  -5.49316406e-03],
                        [  6.10351562e-04,   5.18798828e-04],
                        [  1.01623535e-02,   1.01013184e-02],
                        [  1.70593262e-02,   1.71813965e-02],
                        [  1.90124512e-02,   1.91345215e-02],
                        [  1.84020996e-02,   1.83105469e-02],
                        [  1.84326172e-02,   1.82800293e-02],
                        [  1.91040039e-02,   1.91345215e-02],
                        [  1.83715820e-02,   1.84936523e-02],
                        [  1.54113770e-02,   1.54724121e-02],
                        [  1.12915039e-02,   1.11999512e-02],
                        [  9.00268555e-03,   8.88061523e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.60827637e-02,   1.61743164e-02],
                        [  1.59301758e-02,   1.59912109e-02],
                        [  9.70458984e-03,   9.64355469e-03],
                        [  2.83813477e-03,   2.74658203e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  5.03540039e-03,   5.09643555e-03],
                        [  1.08642578e-02,   1.08947754e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  1.49536133e-02,   1.49841309e-02],
                        [  8.39233398e-03,   8.33129883e-03],
                        [ -1.95312500e-03,  -2.04467773e-03],
                        [ -1.02233887e-02,  -1.01623535e-02],
                        [ -1.45263672e-02,  -1.43737793e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -2.75573730e-02,  -2.77099609e-02],
                        [ -3.78417969e-02,  -3.79028320e-02],
                        [ -4.52880859e-02,  -4.51965332e-02],
                        [ -4.69360352e-02,  -4.68139648e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -2.85034180e-02,  -2.85949707e-02],
                        [ -1.23291016e-02,  -1.23901367e-02],
                        [  3.05175781e-05,   9.15527344e-05],
                        [  1.19018555e-03,   1.28173828e-03],
                        [ -7.99560547e-03,  -7.96508789e-03],
                        [ -1.83105469e-02,  -1.83715820e-02],
                        [ -2.23083496e-02,  -2.23693848e-02],
                        [ -1.88598633e-02,  -1.88293457e-02],
                        [ -1.02844238e-02,  -1.02233887e-02],
                        [  3.35693359e-04,   3.66210938e-04],
                        [  1.03149414e-02,   1.02844238e-02],
                        [  1.71813965e-02,   1.71203613e-02],
                        [  1.88293457e-02,   1.87988281e-02],
                        [  1.46789551e-02,   1.47094727e-02],
                        [  5.03540039e-03,   5.06591797e-03],
                        [ -1.19018555e-02,  -1.18713379e-02],
                        [ -3.72009277e-02,  -3.72314453e-02],
                        [ -6.35986328e-02,  -6.36901855e-02],
                        [ -7.75146484e-02,  -7.75146484e-02],
                        [ -7.13806152e-02,  -7.12890625e-02],
                        [ -4.78515625e-02,  -4.77905273e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [  2.52990723e-02,   2.52685547e-02],
                        [  6.78710938e-02,   6.77795410e-02],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.56860352e-01,   1.57012939e-01],
                        [  1.79718018e-01,   1.79779053e-01],
                        [  1.63970947e-01,   1.63787842e-01],
                        [  9.64050293e-02,   9.62829590e-02],
                        [ -2.19726562e-02,  -2.18811035e-02],
                        [ -1.66839600e-01,  -1.66717529e-01],
                        [ -2.93212891e-01,  -2.93243408e-01],
                        [ -3.59069824e-01,  -3.59130859e-01],
                        [ -3.53668213e-01,  -3.53668213e-01],
                        [ -3.01910400e-01,  -3.01910400e-01],
                        [ -2.42797852e-01,  -2.42767334e-01],
                        [ -2.01141357e-01,  -2.01080322e-01],
                        [ -1.73339844e-01,  -1.73309326e-01],
                        [ -1.37939453e-01,  -1.38000488e-01],
                        [ -8.16955566e-02,  -8.17871094e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [  3.92150879e-02,   3.93371582e-02],
                        [  6.60095215e-02,   6.61010742e-02],
                        [  7.38220215e-02,   7.37304688e-02],
                        [  8.47778320e-02,   8.45947266e-02],
                        [  1.11419678e-01,   1.11450195e-01],
                        [  1.43096924e-01,   1.43280029e-01],
                        [  1.59790039e-01,   1.59851074e-01],
                        [  1.54754639e-01,   1.54602051e-01],
                        [  1.37390137e-01,   1.37298584e-01],
                        [  1.18469238e-01,   1.18530273e-01],
                        [  9.90600586e-02,   9.91516113e-02],
                        [  7.41577148e-02,   7.41882324e-02],
                        [  4.29687500e-02,   4.29077148e-02],
                        [  1.28479004e-02,   1.27868652e-02],
                        [ -4.79125977e-03,  -4.82177734e-03],
                        [ -2.99072266e-03,  -2.96020508e-03],
                        [  1.50146484e-02,   1.50756836e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  6.08215332e-02,   6.07604980e-02],
                        [  7.49206543e-02,   7.48901367e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  9.03320312e-02,   9.03625488e-02],
                        [  9.30480957e-02,   9.31091309e-02],
                        [  8.75854492e-02,   8.75549316e-02],
                        [  7.48291016e-02,   7.47375488e-02],
                        [  5.89904785e-02,   5.89599609e-02],
                        [  4.11682129e-02,   4.12597656e-02],
                        [  2.10876465e-02,   2.11181641e-02],
                        [  1.77001953e-03,   1.67846680e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -2.01110840e-02,  -2.00500488e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.27563477e-02,  -1.28173828e-02],
                        [  2.13623047e-03,   2.16674805e-03],
                        [  1.81579590e-02,   1.82495117e-02],
                        [  2.97241211e-02,   2.96936035e-02],
                        [  3.69873047e-02,   3.68652344e-02],
                        [  4.08020020e-02,   4.07714844e-02],
                        [  3.79943848e-02,   3.81164551e-02],
                        [  2.64892578e-02,   2.65502930e-02],
                        [  9.73510742e-03,   9.64355469e-03],
                        [ -5.52368164e-03,  -5.61523438e-03],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.64794922e-02,  -1.63879395e-02],
                        [ -1.40991211e-02,  -1.40686035e-02],
                        [ -7.23266602e-03,  -7.29370117e-03],
                        [  2.71606445e-03,   2.65502930e-03],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.54516602e-02,   2.54821777e-02],
                        [  3.10058594e-02,   3.10668945e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  2.33154297e-02,   2.32238770e-02],
                        [  6.98852539e-03,   6.92749023e-03],
                        [ -1.07421875e-02,  -1.06506348e-02],
                        [ -2.38952637e-02,  -2.37731934e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -3.56750488e-02,  -3.58276367e-02],
                        [ -3.60107422e-02,  -3.61022949e-02],
                        [ -3.20434570e-02,  -3.19213867e-02],
                        [ -2.67944336e-02,  -2.66113281e-02],
                        [ -2.27050781e-02,  -2.27355957e-02],
                        [ -1.88598633e-02,  -1.90429688e-02],
                        [ -1.53808594e-02,  -1.54418945e-02],
                        [ -1.61437988e-02,  -1.60217285e-02],
                        [ -2.26440430e-02,  -2.25524902e-02],
                        [ -2.92358398e-02,  -2.92968750e-02],
                        [ -2.92663574e-02,  -2.93273926e-02],
                        [ -2.25830078e-02,  -2.26440430e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -6.95800781e-03,  -6.89697266e-03],
                        [ -5.03540039e-03,  -4.97436523e-03],
                        [ -7.04956055e-03,  -7.11059570e-03],
                        [ -9.21630859e-03,  -9.27734375e-03],
                        [ -7.81250000e-03,  -7.78198242e-03],
                        [ -2.47192383e-03,  -2.41088867e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -4.65698242e-02,  -4.66003418e-02],
                        [ -6.12487793e-02,  -6.12792969e-02],
                        [ -5.43518066e-02,  -5.43212891e-02],
                        [ -2.58178711e-02,  -2.57263184e-02],
                        [  1.65405273e-02,   1.65100098e-02],
                        [  6.24389648e-02,   6.23474121e-02],
                        [  1.03942871e-01,   1.03881836e-01],
                        [  1.36291504e-01,   1.36322021e-01],
                        [  1.54296875e-01,   1.54357910e-01],
                        [  1.49169922e-01,   1.49200439e-01],
                        [  1.09008789e-01,   1.08947754e-01],
                        [  2.46582031e-02,   2.45666504e-02],
                        [ -1.00189209e-01,  -1.00219727e-01],
                        [ -2.42401123e-01,  -2.42340088e-01],
                        [ -3.62396240e-01,  -3.62304688e-01],
                        [ -4.20318604e-01,  -4.20318604e-01],
                        [ -4.01031494e-01,  -4.01184082e-01],
                        [ -3.26019287e-01,  -3.26110840e-01],
                        [ -2.38708496e-01,  -2.38586426e-01],
                        [ -1.72393799e-01,  -1.72210693e-01],
                        [ -1.26434326e-01,  -1.26495361e-01],
                        [ -7.65380859e-02,  -7.67517090e-02],
                        [ -1.01928711e-02,  -1.02233887e-02],
                        [  5.67932129e-02,   5.69763184e-02],
                        [  1.00341797e-01,   1.00402832e-01],
                        [  1.14105225e-01,   1.14044189e-01],
                        [  1.12731934e-01,   1.12670898e-01],
                        [  1.14379883e-01,   1.14379883e-01],
                        [  1.24542236e-01,   1.24542236e-01],
                        [  1.34368896e-01,   1.34429932e-01],
                        [  1.32690430e-01,   1.32751465e-01],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  9.93652344e-02,   9.92431641e-02],
                        [  8.39538574e-02,   8.38623047e-02],
                        [  6.92749023e-02,   6.94274902e-02],
                        [  4.66308594e-02,   4.67834473e-02],
                        [  1.55944824e-02,   1.55029297e-02],
                        [ -1.15966797e-02,  -1.17797852e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.58996582e-02,  -1.57775879e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  2.49023438e-02,   2.48718262e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  6.03027344e-02,   6.02416992e-02],
                        [  7.43103027e-02,   7.42492676e-02],
                        [  8.83483887e-02,   8.84399414e-02],
                        [  9.69543457e-02,   9.71069336e-02],
                        [  9.60388184e-02,   9.59472656e-02],
                        [  8.85314941e-02,   8.83483887e-02],
                        [  7.75756836e-02,   7.76367188e-02],
                        [  6.33239746e-02,   6.35375977e-02],
                        [  4.74548340e-02,   4.74243164e-02],
                        [  3.27148438e-02,   3.25622559e-02],
                        [  1.84326172e-02,   1.84631348e-02],
                        [  3.72314453e-03,   3.81469727e-03],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -7.81250000e-03,  -7.87353516e-03],
                        [ -3.26538086e-03,  -3.23486328e-03],
                        [ -3.47900391e-03,  -3.44848633e-03],
                        [ -1.14746094e-02,  -1.15051270e-02],
                        [ -1.85852051e-02,  -1.86462402e-02],
                        [ -1.60217285e-02,  -1.59912109e-02],
                        [ -5.64575195e-03,  -5.58471680e-03],
                        [  2.56347656e-03,   2.59399414e-03],
                        [  2.07519531e-03,   2.01416016e-03],
                        [ -2.86865234e-03,  -2.92968750e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  8.14819336e-03,   8.20922852e-03],
                        [  2.32238770e-02,   2.32849121e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.94897461e-02,   3.94287109e-02],
                        [  3.78723145e-02,   3.78112793e-02],
                        [  3.20129395e-02,   3.21044922e-02],
                        [  2.12707520e-02,   2.13623047e-02],
                        [  6.16455078e-03,   6.16455078e-03],
                        [ -9.00268555e-03,  -9.09423828e-03],
                        [ -2.02026367e-02,  -2.02636719e-02],
                        [ -2.69165039e-02,  -2.68859863e-02],
                        [ -3.02429199e-02,  -3.01818848e-02],
                        [ -3.04870605e-02,  -3.04565430e-02],
                        [ -2.80761719e-02,  -2.81677246e-02],
                        [ -2.51464844e-02,  -2.52380371e-02],
                        [ -2.44445801e-02,  -2.44140625e-02],
                        [ -2.77709961e-02,  -2.76489258e-02],
                        [ -3.34167480e-02,  -3.33862305e-02],
                        [ -3.69262695e-02,  -3.70178223e-02],
                        [ -3.68041992e-02,  -3.68652344e-02],
                        [ -3.65600586e-02,  -3.65295410e-02],
                        [ -3.90930176e-02,  -3.90319824e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.60217285e-02,  -1.60522461e-02],
                        [ -4.63867188e-03,  -4.60815430e-03],
                        [  8.36181641e-03,   8.42285156e-03],
                        [  2.07519531e-02,   2.07214355e-02],
                        [  3.03039551e-02,   3.02429199e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.89404297e-02,   3.89709473e-02],
                        [  3.62854004e-02,   3.63159180e-02],
                        [  2.26745605e-02,   2.27050781e-02],
                        [ -6.43920898e-03,  -6.46972656e-03],
                        [ -4.50134277e-02,  -4.50744629e-02],
                        [ -7.52258301e-02,  -7.52868652e-02],
                        [ -8.01391602e-02,  -8.00781250e-02],
                        [ -5.60302734e-02,  -5.59082031e-02],
                        [ -1.30310059e-02,  -1.30615234e-02],
                        [  3.56140137e-02,   3.54309082e-02],
                        [  8.31604004e-02,   8.31298828e-02],
                        [  1.26312256e-01,   1.26495361e-01],
                        [  1.59027100e-01,   1.59118652e-01],
                        [  1.71844482e-01,   1.71691895e-01],
                        [  1.48651123e-01,   1.48559570e-01],
                        [  7.03430176e-02,   7.04345703e-02],
                        [ -6.28967285e-02,  -6.28662109e-02],
                        [ -2.17315674e-01,  -2.17376709e-01],
                        [ -3.43200684e-01,  -3.43170166e-01],
                        [ -4.04663086e-01,  -4.04571533e-01],
                        [ -3.94775391e-01,  -3.94897461e-01],
                        [ -3.34533691e-01,  -3.34686279e-01],
                        [ -2.60162354e-01,  -2.60040283e-01],
                        [ -1.98822021e-01,  -1.98638916e-01],
                        [ -1.49169922e-01,  -1.49230957e-01],
                        [ -9.22851562e-02,  -9.24987793e-02],
                        [ -2.30407715e-02,  -2.30712891e-02],
                        [  3.92456055e-02,   3.93981934e-02],
                        [  7.28454590e-02,   7.29675293e-02],
                        [  7.83386230e-02,   7.82775879e-02],
                        [  7.70568848e-02,   7.69348145e-02],
                        [  8.81958008e-02,   8.81652832e-02],
                        [  1.11785889e-01,   1.11816406e-01],
                        [  1.34277344e-01,   1.34368896e-01],
                        [  1.44805908e-01,   1.44866943e-01],
                        [  1.43157959e-01,   1.43096924e-01],
                        [  1.34887695e-01,   1.34735107e-01],
                        [  1.22863770e-01,   1.22802734e-01],
                        [  1.04125977e-01,   1.04309082e-01],
                        [  7.69653320e-02,   7.70874023e-02],
                        [  4.86450195e-02,   4.84924316e-02],
                        [  3.02429199e-02,   3.00598145e-02],
                        [  2.32238770e-02,   2.32849121e-02],
                        [  1.97143555e-02,   1.98669434e-02],
                        [  1.66015625e-02,   1.65710449e-02],
                        [  1.94396973e-02,   1.93176270e-02],
                        [  3.13415527e-02,   3.13720703e-02],
                        [  4.83703613e-02,   4.84313965e-02],
                        [  6.63452148e-02,   6.62841797e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  9.25292969e-02,   9.26208496e-02],
                        [  8.92333984e-02,   8.92639160e-02],
                        [  7.17163086e-02,   7.16247559e-02],
                        [  4.61730957e-02,   4.60815430e-02],
                        [  2.37121582e-02,   2.37731934e-02],
                        [  1.37023926e-02,   1.38244629e-02],
                        [  1.57775879e-02,   1.58081055e-02],
                        [  2.10571289e-02,   2.09960938e-02],
                        [  2.14538574e-02,   2.13623047e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  5.27954102e-03,   5.37109375e-03],
                        [ -2.96020508e-03,  -2.86865234e-03],
                        [ -5.03540039e-03,  -5.09643555e-03],
                        [  1.92260742e-03,   1.73950195e-03],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  3.04565430e-02,   3.06396484e-02],
                        [  3.58886719e-02,   3.59802246e-02],
                        [  3.08532715e-02,   3.07617188e-02],
                        [  1.93176270e-02,   1.92260742e-02],
                        [  6.74438477e-03,   6.77490234e-03],
                        [ -1.00708008e-03,  -9.46044922e-04],
                        [ -8.23974609e-04,  -7.62939453e-04],
                        [  3.78417969e-03,   3.81469727e-03],
                        [  6.62231445e-03,   6.56127930e-03],
                        [  7.93457031e-03,   7.84301758e-03],
                        [  1.27258301e-02,   1.27563477e-02],
                        [  2.21557617e-02,   2.23083496e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  4.48303223e-02,   4.47082520e-02],
                        [  5.22460938e-02,   5.22155762e-02],
                        [  5.01708984e-02,   5.02319336e-02],
                        [  3.59497070e-02,   3.59802246e-02],
                        [  1.34582520e-02,   1.34887695e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -2.70080566e-02,  -2.70690918e-02],
                        [ -3.53088379e-02,  -3.54003906e-02],
                        [ -3.78723145e-02,  -3.78112793e-02],
                        [ -4.20227051e-02,  -4.19006348e-02],
                        [ -5.04455566e-02,  -5.04760742e-02],
                        [ -5.93872070e-02,  -5.95092773e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -7.55615234e-02,  -7.54699707e-02],
                        [ -8.36486816e-02,  -8.36181641e-02],
                        [ -8.57849121e-02,  -8.58154297e-02],
                        [ -7.83691406e-02,  -7.83691406e-02],
                        [ -6.36596680e-02,  -6.36291504e-02],
                        [ -4.67834473e-02,  -4.68139648e-02],
                        [ -3.08227539e-02,  -3.08532715e-02],
                        [ -1.46789551e-02,  -1.46484375e-02],
                        [  3.87573242e-03,   3.93676758e-03],
                        [  2.56042480e-02,   2.55432129e-02],
                        [  4.92248535e-02,   4.91333008e-02],
                        [  7.11669922e-02,   7.11975098e-02],
                        [  8.66699219e-02,   8.67614746e-02],
                        [  9.24377441e-02,   9.24072266e-02],
                        [  8.52355957e-02,   8.52050781e-02],
                        [  6.00280762e-02,   6.00891113e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [ -3.00292969e-02,  -3.01818848e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -8.00476074e-02,  -7.98645020e-02],
                        [ -7.41271973e-02,  -7.40966797e-02],
                        [ -5.07812500e-02,  -5.10253906e-02],
                        [ -1.48925781e-02,  -1.50146484e-02],
                        [  2.34985352e-02,   2.37121582e-02],
                        [  5.27954102e-02,   5.29785156e-02],
                        [  6.50634766e-02,   6.49414062e-02],
                        [  5.11474609e-02,   5.09643555e-02],
                        [ -7.62939453e-04,  -7.01904297e-04],
                        [ -9.07592773e-02,  -9.06066895e-02],
                        [ -1.94366455e-01,  -1.94335938e-01],
                        [ -2.71911621e-01,  -2.71942139e-01],
                        [ -2.94677734e-01,  -2.94677734e-01],
                        [ -2.63916016e-01,  -2.63977051e-01],
                        [ -2.07336426e-01,  -2.07366943e-01],
                        [ -1.56707764e-01,  -1.56616211e-01],
                        [ -1.24847412e-01,  -1.24725342e-01],
                        [ -9.93041992e-02,  -9.93957520e-02],
                        [ -6.10656738e-02,  -6.12487793e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [  3.59191895e-02,   3.60717773e-02],
                        [  5.55114746e-02,   5.55725098e-02],
                        [  5.04150391e-02,   5.03234863e-02],
                        [  3.98864746e-02,   3.97644043e-02],
                        [  4.12292480e-02,   4.12597656e-02],
                        [  5.39855957e-02,   5.41076660e-02],
                        [  6.61315918e-02,   6.61621094e-02],
                        [  7.08312988e-02,   7.07702637e-02],
                        [  7.07702637e-02,   7.07397461e-02],
                        [  7.05871582e-02,   7.06176758e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  7.36083984e-02,   7.36083984e-02],
                        [  7.05871582e-02,   7.06176758e-02],
                        [  6.08825684e-02,   6.09130859e-02],
                        [  4.89807129e-02,   4.88891602e-02],
                        [  4.29382324e-02,   4.28771973e-02],
                        [  4.71191406e-02,   4.71496582e-02],
                        [  5.98754883e-02,   5.99670410e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  9.32312012e-02,   9.31701660e-02],
                        [  1.05560303e-01,   1.05529785e-01],
                        [  1.09802246e-01,   1.09832764e-01],
                        [  1.02081299e-01,   1.02111816e-01],
                        [  8.06579590e-02,   8.06884766e-02],
                        [  4.86145020e-02,   4.86450195e-02],
                        [  1.43737793e-02,   1.43432617e-02],
                        [ -1.03149414e-02,  -1.03759766e-02],
                        [ -1.66320801e-02,  -1.66015625e-02],
                        [ -6.13403320e-03,  -5.98144531e-03],
                        [  1.03454590e-02,   1.04370117e-02],
                        [  2.36816406e-02,   2.35900879e-02],
                        [  3.29589844e-02,   3.28369141e-02],
                        [  3.95507812e-02,   3.95812988e-02],
                        [  4.17175293e-02,   4.18395996e-02],
                        [  3.72924805e-02,   3.73535156e-02],
                        [  2.70080566e-02,   2.69165039e-02],
                        [  1.38854980e-02,   1.37634277e-02],
                        [  1.61743164e-03,   1.55639648e-03],
                        [ -8.11767578e-03,  -7.99560547e-03],
                        [ -1.56860352e-02,  -1.55029297e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -1.74255371e-02,  -1.76696777e-02],
                        [ -4.94384766e-03,  -5.03540039e-03],
                        [  1.01318359e-02,   1.03454590e-02],
                        [  1.79748535e-02,   1.81579590e-02],
                        [  1.82800293e-02,   1.81579590e-02],
                        [  1.78222656e-02,   1.76391602e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.70593262e-02,   1.72119141e-02],
                        [  9.42993164e-03,   9.49096680e-03],
                        [ -3.66210938e-04,  -3.96728516e-04],
                        [ -6.46972656e-03,  -6.53076172e-03],
                        [ -5.95092773e-03,  -6.04248047e-03],
                        [  3.05175781e-05,   6.10351562e-05],
                        [  7.04956055e-03,   7.14111328e-03],
                        [  1.05285645e-02,   1.05895996e-02],
                        [  1.01623535e-02,   1.01013184e-02],
                        [  8.17871094e-03,   8.08715820e-03],
                        [  4.73022461e-03,   4.76074219e-03],
                        [ -3.20434570e-03,  -3.11279297e-03],
                        [ -1.74865723e-02,  -1.74560547e-02],
                        [ -3.36303711e-02,  -3.36914062e-02],
                        [ -4.38842773e-02,  -4.39758301e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -4.15344238e-02,  -4.14733887e-02],
                        [ -4.00085449e-02,  -3.99780273e-02],
                        [ -4.42810059e-02,  -4.43420410e-02],
                        [ -5.23376465e-02,  -5.23681641e-02],
                        [ -5.97839355e-02,  -5.97229004e-02],
                        [ -6.16760254e-02,  -6.16455078e-02],
                        [ -5.23376465e-02,  -5.23681641e-02],
                        [ -3.07922363e-02,  -3.07617188e-02],
                        [ -5.37109375e-03,  -5.31005859e-03],
                        [  1.30310059e-02,   1.30004883e-02],
                        [  2.15454102e-02,   2.14843750e-02],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  2.70690918e-02,   2.71301270e-02],
                        [  3.12805176e-02,   3.13110352e-02],
                        [  3.44543457e-02,   3.44238281e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [ -1.05895996e-02,  -1.06506348e-02],
                        [ -2.46582031e-02,  -2.45971680e-02],
                        [ -2.15454102e-02,  -2.14233398e-02],
                        [ -2.74658203e-04,  -3.05175781e-04],
                        [  3.39660645e-02,   3.38134766e-02],
                        [  7.14416504e-02,   7.13806152e-02],
                        [  9.73510742e-02,   9.75036621e-02],
                        [  9.92126465e-02,   9.93652344e-02],
                        [  7.48291016e-02,   7.47070312e-02],
                        [  2.60009766e-02,   2.58178711e-02],
                        [ -4.93164062e-02,  -4.92858887e-02],
                        [ -1.49444580e-01,  -1.49291992e-01],
                        [ -2.54302979e-01,  -2.54272461e-01],
                        [ -3.27117920e-01,  -3.27209473e-01],
                        [ -3.38684082e-01,  -3.38745117e-01],
                        [ -2.91656494e-01,  -2.91625977e-01],
                        [ -2.19116211e-01,  -2.19116211e-01],
                        [ -1.58966064e-01,  -1.58935547e-01],
                        [ -1.26312256e-01,  -1.26251221e-01],
                        [ -1.06323242e-01,  -1.06384277e-01],
                        [ -7.36999512e-02,  -7.38220215e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [  2.72216797e-02,   2.73742676e-02],
                        [  4.88281250e-02,   4.88891602e-02],
                        [  4.26330566e-02,   4.24804688e-02],
                        [  3.26843262e-02,   3.25622559e-02],
                        [  4.08630371e-02,   4.09545898e-02],
                        [  6.72302246e-02,   6.73522949e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  1.12976074e-01,   1.12884521e-01],
                        [  1.16729736e-01,   1.16699219e-01],
                        [  1.11999512e-01,   1.12091064e-01],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  9.38720703e-02,   9.38415527e-02],
                        [  8.03527832e-02,   8.03833008e-02],
                        [  6.43615723e-02,   6.43920898e-02],
                        [  5.11169434e-02,   5.10864258e-02],
                        [  4.55627441e-02,   4.55322266e-02],
                        [  4.78820801e-02,   4.78515625e-02],
                        [  5.56640625e-02,   5.56640625e-02],
                        [  6.59179688e-02,   6.60095215e-02],
                        [  7.43103027e-02,   7.43408203e-02],
                        [  7.80029297e-02,   7.78503418e-02],
                        [  7.73620605e-02,   7.72705078e-02],
                        [  7.19909668e-02,   7.21130371e-02],
                        [  6.11877441e-02,   6.13098145e-02],
                        [  4.83703613e-02,   4.82788086e-02],
                        [  3.77197266e-02,   3.75671387e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  2.16979980e-02,   2.17895508e-02],
                        [  1.64489746e-02,   1.65405273e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  1.38549805e-02,   1.37329102e-02],
                        [  1.41906738e-02,   1.40686035e-02],
                        [  1.45263672e-02,   1.46179199e-02],
                        [  1.48315430e-02,   1.49536133e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  2.18505859e-02,   2.17590332e-02],
                        [  2.59094238e-02,   2.58483887e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.79541016e-02,   2.80456543e-02],
                        [  2.81677246e-02,   2.82897949e-02],
                        [  2.56042480e-02,   2.55432129e-02],
                        [  1.97753906e-02,   1.96228027e-02],
                        [  1.29394531e-02,   1.29089355e-02],
                        [  6.19506836e-03,   6.34765625e-03],
                        [  1.03759766e-03,   1.09863281e-03],
                        [  1.06811523e-03,   1.00708008e-03],
                        [  7.29370117e-03,   7.23266602e-03],
                        [  1.62658691e-02,   1.62353516e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.79235840e-02,   2.80151367e-02],
                        [  2.57873535e-02,   2.59094238e-02],
                        [  1.87072754e-02,   1.86157227e-02],
                        [  1.18713379e-02,   1.16882324e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  8.42285156e-03,   8.63647461e-03],
                        [  3.20434570e-03,   3.29589844e-03],
                        [ -6.19506836e-03,  -6.37817383e-03],
                        [ -1.60827637e-02,  -1.62353516e-02],
                        [ -2.42614746e-02,  -2.41394043e-02],
                        [ -3.06701660e-02,  -3.05175781e-02],
                        [ -3.54614258e-02,  -3.54919434e-02],
                        [ -3.74145508e-02,  -3.75366211e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -4.01611328e-02,  -4.01000977e-02],
                        [ -4.67529297e-02,  -4.67834473e-02],
                        [ -5.23986816e-02,  -5.24291992e-02],
                        [ -5.28564453e-02,  -5.27954102e-02],
                        [ -4.85229492e-02,  -4.84924316e-02],
                        [ -4.25109863e-02,  -4.26025391e-02],
                        [ -3.86352539e-02,  -3.86962891e-02],
                        [ -3.99475098e-02,  -3.98559570e-02],
                        [ -4.48608398e-02,  -4.47998047e-02],
                        [ -4.70581055e-02,  -4.71191406e-02],
                        [ -4.15954590e-02,  -4.16564941e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [  2.89916992e-03,   2.92968750e-03],
                        [  1.69982910e-02,   1.70593262e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.36914062e-02,   3.35998535e-02],
                        [  3.05480957e-02,   3.04870605e-02],
                        [  1.87072754e-02,   1.87988281e-02],
                        [  1.70898438e-03,   1.83105469e-03],
                        [ -1.39465332e-02,  -1.39770508e-02],
                        [ -2.31018066e-02,  -2.32543945e-02],
                        [ -2.44445801e-02,  -2.45056152e-02],
                        [ -1.87683105e-02,  -1.86767578e-02],
                        [ -8.85009766e-03,  -8.75854492e-03],
                        [  2.41088867e-03,   2.38037109e-03],
                        [  1.55639648e-02,   1.54418945e-02],
                        [  3.32641602e-02,   3.32336426e-02],
                        [  5.69458008e-02,   5.70373535e-02],
                        [  8.50524902e-02,   8.51135254e-02],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  1.30035400e-01,   1.29974365e-01],
                        [  1.30218506e-01,   1.30157471e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  4.55017090e-02,   4.55932617e-02],
                        [ -4.88281250e-02,  -4.87670898e-02],
                        [ -1.65008545e-01,  -1.65069580e-01],
                        [ -2.69683838e-01,  -2.69744873e-01],
                        [ -3.25500488e-01,  -3.25500488e-01],
                        [ -3.16955566e-01,  -3.16894531e-01],
                        [ -2.61932373e-01,  -2.61932373e-01],
                        [ -1.97692871e-01,  -1.97692871e-01],
                        [ -1.51733398e-01,  -1.51733398e-01],
                        [ -1.23748779e-01,  -1.23779297e-01],
                        [ -9.35974121e-02,  -9.36584473e-02],
                        [ -4.76379395e-02,  -4.76074219e-02],
                        [  3.99780273e-03,   4.08935547e-03],
                        [  3.80554199e-02,   3.80859375e-02],
                        [  4.50439453e-02,   4.49523926e-02],
                        [  3.98559570e-02,   3.97949219e-02],
                        [  4.38232422e-02,   4.38842773e-02],
                        [  6.26525879e-02,   6.27441406e-02],
                        [  8.77075195e-02,   8.76770020e-02],
                        [  1.09405518e-01,   1.09344482e-01],
                        [  1.21734619e-01,   1.21734619e-01],
                        [  1.22711182e-01,   1.22711182e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.09497070e-01,   1.09527588e-01],
                        [  1.02874756e-01,   1.02935791e-01],
                        [  9.26513672e-02,   9.26208496e-02],
                        [  7.73010254e-02,   7.72094727e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  4.52880859e-02,   4.53796387e-02],
                        [  3.23791504e-02,   3.24401855e-02],
                        [  1.94702148e-02,   1.94091797e-02],
                        [  6.07299805e-03,   6.01196289e-03],
                        [ -3.50952148e-03,  -3.54003906e-03],
                        [ -3.66210938e-03,  -3.57055664e-03],
                        [  7.69042969e-03,   7.78198242e-03],
                        [  2.81372070e-02,   2.81066895e-02],
                        [  5.08728027e-02,   5.07812500e-02],
                        [  6.71081543e-02,   6.70776367e-02],
                        [  7.21740723e-02,   7.22351074e-02],
                        [  6.84509277e-02,   6.85424805e-02],
                        [  6.06689453e-02,   6.06994629e-02],
                        [  4.96215820e-02,   4.95300293e-02],
                        [  3.37219238e-02,   3.36303711e-02],
                        [  1.48315430e-02,   1.48620605e-02],
                        [ -1.80053711e-03,  -1.64794922e-03],
                        [ -1.24206543e-02,  -1.23596191e-02],
                        [ -1.75476074e-02,  -1.76696777e-02],
                        [ -1.99279785e-02,  -2.00500488e-02],
                        [ -2.09655762e-02,  -2.09045410e-02],
                        [ -2.01110840e-02,  -1.99890137e-02],
                        [ -1.59606934e-02,  -1.59301758e-02],
                        [ -7.23266602e-03,  -7.32421875e-03],
                        [  5.95092773e-03,   5.92041016e-03],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  4.03747559e-02,   4.04052734e-02],
                        [  5.39245605e-02,   5.39855957e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  5.25207520e-02,   5.24291992e-02],
                        [  4.25109863e-02,   4.24499512e-02],
                        [  3.43017578e-02,   3.43322754e-02],
                        [  2.89916992e-02,   2.90527344e-02],
                        [  2.28576660e-02,   2.28881836e-02],
                        [  1.30615234e-02,   1.30310059e-02],
                        [  1.06811523e-03,   1.00708008e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.64794922e-02,  -1.64184570e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -3.40881348e-02,  -3.41186523e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -3.66210938e-02,  -3.67126465e-02],
                        [ -3.38745117e-02,  -3.38439941e-02],
                        [ -3.57666016e-02,  -3.56140137e-02],
                        [ -3.97033691e-02,  -3.96728516e-02],
                        [ -3.75366211e-02,  -3.76892090e-02],
                        [ -2.47802734e-02,  -2.48718262e-02],
                        [ -7.50732422e-03,  -7.35473633e-03],
                        [  4.02832031e-03,   4.18090820e-03],
                        [  5.88989258e-03,   5.82885742e-03],
                        [  1.37329102e-03,   1.22070312e-03],
                        [ -4.33349609e-03,  -4.39453125e-03],
                        [ -8.48388672e-03,  -8.39233398e-03],
                        [ -1.16577148e-02,  -1.15356445e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -2.42919922e-02,  -2.44140625e-02],
                        [ -3.75366211e-02,  -3.75976562e-02],
                        [ -5.45043945e-02,  -5.44433594e-02],
                        [ -7.00683594e-02,  -6.99768066e-02],
                        [ -7.79113770e-02,  -7.78503418e-02],
                        [ -7.58056641e-02,  -7.58666992e-02],
                        [ -6.75048828e-02,  -6.76269531e-02],
                        [ -5.73730469e-02,  -5.74035645e-02],
                        [ -4.69665527e-02,  -4.67834473e-02],
                        [ -3.59497070e-02,  -3.58581543e-02],
                        [ -2.31933594e-02,  -2.33154297e-02],
                        [ -9.27734375e-03,  -9.39941406e-03],
                        [  2.71606445e-03,   2.74658203e-03],
                        [  1.29394531e-02,   1.30310059e-02],
                        [  2.45361328e-02,   2.45971680e-02],
                        [  3.65295410e-02,   3.64990234e-02],
                        [  4.44335938e-02,   4.43420410e-02],
                        [  4.57458496e-02,   4.57153320e-02],
                        [  4.02221680e-02,   4.02526855e-02],
                        [  2.84423828e-02,   2.84729004e-02],
                        [  1.35803223e-02,   1.36108398e-02],
                        [  7.01904297e-04,   6.71386719e-04],
                        [ -6.40869141e-03,  -6.46972656e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [  1.08947754e-02,   1.09863281e-02],
                        [  3.83911133e-02,   3.84216309e-02],
                        [  7.46459961e-02,   7.45239258e-02],
                        [  1.14562988e-01,   1.14532471e-01],
                        [  1.50634766e-01,   1.50726318e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.70867920e-01,   1.70806885e-01],
                        [  1.31927490e-01,   1.31988525e-01],
                        [  5.02624512e-02,   5.03540039e-02],
                        [ -6.31103516e-02,  -6.32019043e-02],
                        [ -1.81518555e-01,  -1.81579590e-01],
                        [ -2.74993896e-01,  -2.74932861e-01],
                        [ -3.20709229e-01,  -3.20648193e-01],
                        [ -3.12927246e-01,  -3.12927246e-01],
                        [ -2.70416260e-01,  -2.70446777e-01],
                        [ -2.22961426e-01,  -2.23022461e-01],
                        [ -1.85485840e-01,  -1.85485840e-01],
                        [ -1.51824951e-01,  -1.51763916e-01],
                        [ -1.09375000e-01,  -1.09344482e-01],
                        [ -5.52673340e-02,  -5.52978516e-02],
                        [ -1.22070312e-03,  -1.25122070e-03],
                        [  3.70483398e-02,   3.69873047e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  5.64575195e-02,   5.65795898e-02],
                        [  5.73120117e-02,   5.74035645e-02],
                        [  6.52160645e-02,   6.51245117e-02],
                        [  8.14819336e-02,   8.13293457e-02],
                        [  1.00677490e-01,   1.00708008e-01],
                        [  1.13983154e-01,   1.14135742e-01],
                        [  1.16149902e-01,   1.16180420e-01],
                        [  1.09008789e-01,   1.08856201e-01],
                        [  9.64050293e-02,   9.63439941e-02],
                        [  8.00476074e-02,   8.01086426e-02],
                        [  6.02722168e-02,   6.03637695e-02],
                        [  3.79943848e-02,   3.80249023e-02],
                        [  1.58386230e-02,   1.57775879e-02],
                        [ -2.01416016e-03,  -2.07519531e-03],
                        [ -1.22375488e-02,  -1.21765137e-02],
                        [ -1.29394531e-02,  -1.28784180e-02],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [  1.37023926e-02,   1.37329102e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  4.65698242e-02,   4.64782715e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  7.03735352e-02,   7.04650879e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  6.12182617e-02,   6.11267090e-02],
                        [  4.69360352e-02,   4.69360352e-02],
                        [  3.45153809e-02,   3.45458984e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.60522461e-02,   1.61132812e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  3.41796875e-03,   3.35693359e-03],
                        [  1.61743164e-03,   1.58691406e-03],
                        [  1.19018555e-03,   1.25122070e-03],
                        [ -1.55639648e-03,  -1.49536133e-03],
                        [ -6.56127930e-03,  -6.59179688e-03],
                        [ -1.16271973e-02,  -1.17187500e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.86157227e-02,  -1.85241699e-02],
                        [ -1.82495117e-02,  -1.82189941e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  2.62451172e-02,   2.62145996e-02],
                        [  4.29992676e-02,   4.29687500e-02],
                        [  4.98046875e-02,   4.98352051e-02],
                        [  4.74853516e-02,   4.75769043e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  4.19311523e-02,   4.18090820e-02],
                        [  4.19311523e-02,   4.18701172e-02],
                        [  3.73535156e-02,   3.74450684e-02],
                        [  2.65197754e-02,   2.66723633e-02],
                        [  1.31835938e-02,   1.31530762e-02],
                        [  3.38745117e-03,   3.20434570e-03],
                        [  2.19726562e-03,   2.16674805e-03],
                        [  9.55200195e-03,   9.67407227e-03],
                        [  1.81579590e-02,   1.82495117e-02],
                        [  1.96533203e-02,   1.95922852e-02],
                        [  1.07116699e-02,   1.06201172e-02],
                        [ -6.98852539e-03,  -7.01904297e-03],
                        [ -2.86560059e-02,  -2.86254883e-02],
                        [ -4.80957031e-02,  -4.80346680e-02],
                        [ -5.94482422e-02,  -5.93872070e-02],
                        [ -5.99975586e-02,  -6.00585938e-02],
                        [ -5.37109375e-02,  -5.38330078e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -4.51965332e-02,  -4.50134277e-02],
                        [ -4.23583984e-02,  -4.22668457e-02],
                        [ -3.74450684e-02,  -3.75671387e-02],
                        [ -3.17382812e-02,  -3.18298340e-02],
                        [ -2.54821777e-02,  -2.54211426e-02],
                        [ -1.70288086e-02,  -1.69372559e-02],
                        [ -7.08007812e-03,  -7.11059570e-03],
                        [  1.52587891e-03,   1.49536133e-03],
                        [  8.60595703e-03,   8.63647461e-03],
                        [  1.47399902e-02,   1.47094727e-02],
                        [  1.62048340e-02,   1.61132812e-02],
                        [  7.72094727e-03,   7.78198242e-03],
                        [ -1.01623535e-02,  -1.00402832e-02],
                        [ -2.95104980e-02,  -2.95715332e-02],
                        [ -4.22668457e-02,  -4.24499512e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -4.36401367e-02,  -4.34265137e-02],
                        [ -3.43933105e-02,  -3.43627930e-02],
                        [ -2.09960938e-02,  -2.11791992e-02],
                        [ -6.50024414e-03,  -6.53076172e-03],
                        [  7.62939453e-03,   7.75146484e-03],
                        [  2.09045410e-02,   2.09350586e-02],
                        [  3.13110352e-02,   3.12500000e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  3.32641602e-02,   3.33251953e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.92053223e-02,   2.91442871e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  2.67944336e-02,   2.69165039e-02],
                        [  3.00292969e-02,   3.00903320e-02],
                        [  3.79943848e-02,   3.78723145e-02],
                        [  4.83093262e-02,   4.82482910e-02],
                        [  6.03637695e-02,   6.04858398e-02],
                        [  7.69042969e-02,   7.69958496e-02],
                        [  9.88769531e-02,   9.88159180e-02],
                        [  1.21368408e-01,   1.21307373e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.30004883e-01,   1.30004883e-01],
                        [  9.63745117e-02,   9.64050293e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -1.74133301e-01,  -1.74133301e-01],
                        [ -2.71484375e-01,  -2.71545410e-01],
                        [ -3.34869385e-01,  -3.34899902e-01],
                        [ -3.48907471e-01,  -3.48815918e-01],
                        [ -3.17810059e-01,  -3.17749023e-01],
                        [ -2.64129639e-01,  -2.64221191e-01],
                        [ -2.11944580e-01,  -2.12066650e-01],
                        [ -1.67694092e-01,  -1.67663574e-01],
                        [ -1.19323730e-01,  -1.19171143e-01],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [  9.70458984e-03,   9.58251953e-03],
                        [  6.16149902e-02,   6.15539551e-02],
                        [  8.49304199e-02,   8.50219727e-02],
                        [  8.43505859e-02,   8.44116211e-02],
                        [  7.56225586e-02,   7.55615234e-02],
                        [  7.07702637e-02,   7.07092285e-02],
                        [  7.37304688e-02,   7.37304688e-02],
                        [  8.16955566e-02,   8.17260742e-02],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  6.22253418e-02,   6.22558594e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.49829102e-02,   4.49218750e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  2.95715332e-02,   2.96630859e-02],
                        [  2.70996094e-02,   2.71301270e-02],
                        [  2.91137695e-02,   2.90222168e-02],
                        [  3.15551758e-02,   3.14941406e-02],
                        [  3.14025879e-02,   3.14636230e-02],
                        [  3.01513672e-02,   3.01818848e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  2.99987793e-02,   2.99377441e-02],
                        [  3.06396484e-02,   3.05786133e-02],
                        [  3.21960449e-02,   3.22265625e-02],
                        [  3.34167480e-02,   3.34472656e-02],
                        [  3.16467285e-02,   3.16162109e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.53601074e-02,   2.53906250e-02],
                        [  2.46582031e-02,   2.45971680e-02],
                        [  2.14843750e-02,   2.14538574e-02],
                        [  1.44653320e-02,   1.45263672e-02],
                        [  7.08007812e-03,   7.14111328e-03],
                        [  2.41088867e-03,   2.31933594e-03],
                        [ -9.76562500e-04,  -1.06811523e-03],
                        [ -3.78417969e-03,  -3.75366211e-03],
                        [ -3.11279297e-03,  -2.99072266e-03],
                        [  1.80053711e-03,   1.77001953e-03],
                        [  6.53076172e-03,   6.46972656e-03],
                        [  8.66699219e-03,   8.69750977e-03],
                        [  1.16271973e-02,   1.16577148e-02],
                        [  1.73950195e-02,   1.73339844e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  1.73339844e-02,   1.74255371e-02],
                        [  1.21154785e-02,   1.20849609e-02],
                        [  1.09863281e-02,   1.08642578e-02],
                        [  1.28784180e-02,   1.28479004e-02],
                        [  1.45263672e-02,   1.46789551e-02],
                        [  1.64184570e-02,   1.65100098e-02],
                        [  1.85852051e-02,   1.84631348e-02],
                        [  1.73339844e-02,   1.71813965e-02],
                        [  1.15966797e-02,   1.16577148e-02],
                        [  5.98144531e-03,   6.13403320e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -6.40869141e-04,  -7.93457031e-04],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -1.25732422e-02,  -1.24816895e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.80969238e-02,  -1.81579590e-02],
                        [ -1.74865723e-02,  -1.74255371e-02],
                        [ -1.19628906e-02,  -1.19323730e-02],
                        [ -2.34985352e-03,  -2.47192383e-03],
                        [  6.04248047e-03,   5.98144531e-03],
                        [  9.76562500e-03,   9.88769531e-03],
                        [  9.94873047e-03,   1.00402832e-02],
                        [  7.23266602e-03,   7.14111328e-03],
                        [ -5.49316406e-04,  -6.71386719e-04],
                        [ -1.39160156e-02,  -1.38549805e-02],
                        [ -3.00292969e-02,  -2.99072266e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -5.85632324e-02,  -5.86547852e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -5.93872070e-02,  -5.93566895e-02],
                        [ -4.69970703e-02,  -4.70275879e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -1.04675293e-02,  -1.04370117e-02],
                        [  6.80541992e-03,   6.77490234e-03],
                        [  1.69677734e-02,   1.68762207e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  4.66918945e-03,   4.76074219e-03],
                        [ -9.82666016e-03,  -9.79614258e-03],
                        [ -2.12097168e-02,  -2.12402344e-02],
                        [ -2.67028809e-02,  -2.67639160e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -1.69982910e-02,  -1.69372559e-02],
                        [ -7.90405273e-03,  -7.87353516e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -2.22778320e-03,  -2.25830078e-03],
                        [ -2.96020508e-03,  -2.99072266e-03],
                        [ -3.08227539e-03,  -3.05175781e-03],
                        [ -2.53295898e-03,  -2.47192383e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  2.77709961e-03,   2.74658203e-03],
                        [  6.04248047e-03,   6.01196289e-03],
                        [  6.34765625e-03,   6.31713867e-03],
                        [  5.18798828e-03,   5.21850586e-03],
                        [  6.98852539e-03,   7.08007812e-03],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  2.45666504e-02,   2.44445801e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  5.54504395e-02,   5.55419922e-02],
                        [  7.58666992e-02,   7.58972168e-02],
                        [  9.86633301e-02,   9.86022949e-02],
                        [  1.20300293e-01,   1.20269775e-01],
                        [  1.34857178e-01,   1.34887695e-01],
                        [  1.34246826e-01,   1.34277344e-01],
                        [  1.08703613e-01,   1.08734131e-01],
                        [  5.09643555e-02,   5.09338379e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -1.49627686e-01,  -1.49597168e-01],
                        [ -2.55279541e-01,  -2.55340576e-01],
                        [ -3.25439453e-01,  -3.25469971e-01],
                        [ -3.43139648e-01,  -3.43048096e-01],
                        [ -3.15887451e-01,  -3.15856934e-01],
                        [ -2.67272949e-01,  -2.67333984e-01],
                        [ -2.17376709e-01,  -2.17407227e-01],
                        [ -1.71508789e-01,  -1.71478271e-01],
                        [ -1.23809814e-01,  -1.23748779e-01],
                        [ -6.77490234e-02,  -6.77185059e-02],
                        [ -6.13403320e-03,  -6.19506836e-03],
                        [  4.79736328e-02,   4.79431152e-02],
                        [  8.21228027e-02,   8.21838379e-02],
                        [  9.57946777e-02,   9.58251953e-02],
                        [  9.98535156e-02,   9.98840332e-02],
                        [  1.04248047e-01,   1.04217529e-01],
                        [  1.08520508e-01,   1.08489990e-01],
                        [  1.07757568e-01,   1.07788086e-01],
                        [  1.00158691e-01,   1.00189209e-01],
                        [  8.86535645e-02,   8.85925293e-02],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  6.68945312e-02,   6.69555664e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  3.92456055e-02,   3.91540527e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  1.35498047e-02,   1.36413574e-02],
                        [  1.26647949e-02,   1.26953125e-02],
                        [  1.99279785e-02,   1.98669434e-02],
                        [  2.82592773e-02,   2.81677246e-02],
                        [  3.23791504e-02,   3.24096680e-02],
                        [  3.37219238e-02,   3.38134766e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  4.46777344e-02,   4.46166992e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  5.83190918e-02,   5.83496094e-02],
                        [  5.99365234e-02,   5.99670410e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  2.76794434e-02,   2.76489258e-02],
                        [  1.39160156e-02,   1.38854980e-02],
                        [  4.79125977e-03,   4.82177734e-03],
                        [  1.34277344e-03,   1.43432617e-03],
                        [  1.64794922e-03,   1.61743164e-03],
                        [  1.43432617e-03,   1.37329102e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -6.40869141e-03,  -6.37817383e-03],
                        [ -8.02612305e-03,  -7.99560547e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  3.84521484e-03,   3.78417969e-03],
                        [  1.55944824e-02,   1.55639648e-02],
                        [  2.81066895e-02,   2.81677246e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.44543457e-02,   3.43933105e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  1.90124512e-02,   1.90429688e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  4.02832031e-03,   4.05883789e-03],
                        [  1.50451660e-02,   1.49841309e-02],
                        [  2.70080566e-02,   2.69775391e-02],
                        [  3.22265625e-02,   3.22875977e-02],
                        [  2.81982422e-02,   2.82287598e-02],
                        [  1.93786621e-02,   1.93176270e-02],
                        [  1.10778809e-02,   1.10168457e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -6.83593750e-03,  -6.77490234e-03],
                        [ -1.86767578e-02,  -1.86462402e-02],
                        [ -2.72521973e-02,  -2.72827148e-02],
                        [ -2.93884277e-02,  -2.94494629e-02],
                        [ -2.56652832e-02,  -2.56958008e-02],
                        [ -1.80053711e-02,  -1.79443359e-02],
                        [ -8.97216797e-03,  -8.88061523e-03],
                        [ -2.99072266e-03,  -3.05175781e-03],
                        [ -3.50952148e-03,  -3.66210938e-03],
                        [ -8.36181641e-03,  -8.33129883e-03],
                        [ -1.12915039e-02,  -1.11694336e-02],
                        [ -8.88061523e-03,  -8.85009766e-03],
                        [ -4.73022461e-03,  -4.79125977e-03],
                        [ -5.67626953e-03,  -5.73730469e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -2.44140625e-02,  -2.43225098e-02],
                        [ -3.46679688e-02,  -3.46069336e-02],
                        [ -4.24804688e-02,  -4.25720215e-02],
                        [ -4.59899902e-02,  -4.60510254e-02],
                        [ -4.41589355e-02,  -4.40979004e-02],
                        [ -3.85437012e-02,  -3.85131836e-02],
                        [ -3.20129395e-02,  -3.20434570e-02],
                        [ -2.66113281e-02,  -2.65808105e-02],
                        [ -2.23693848e-02,  -2.23999023e-02],
                        [ -1.76086426e-02,  -1.76391602e-02],
                        [ -1.11083984e-02,  -1.10778809e-02],
                        [ -3.50952148e-03,  -3.47900391e-03],
                        [  4.54711914e-03,   4.51660156e-03],
                        [  1.22070312e-02,   1.21765137e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  9.58251953e-03,   9.55200195e-03],
                        [  5.27954102e-03,   5.24902344e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  5.46264648e-03,   5.49316406e-03],
                        [  8.54492188e-03,   8.48388672e-03],
                        [  1.02539062e-02,   1.01928711e-02],
                        [  1.08947754e-02,   1.09863281e-02],
                        [  1.34887695e-02,   1.35803223e-02],
                        [  1.98059082e-02,   1.97143555e-02],
                        [  2.99987793e-02,   2.99072266e-02],
                        [  4.44030762e-02,   4.44641113e-02],
                        [  6.34460449e-02,   6.35375977e-02],
                        [  8.61511230e-02,   8.60900879e-02],
                        [  1.09039307e-01,   1.08947754e-01],
                        [  1.28814697e-01,   1.28875732e-01],
                        [  1.42120361e-01,   1.42181396e-01],
                        [  1.38244629e-01,   1.38214111e-01],
                        [  9.97009277e-02,   9.96398926e-02],
                        [  1.71508789e-02,   1.71813965e-02],
                        [ -9.73815918e-02,  -9.72900391e-02],
                        [ -2.14813232e-01,  -2.14843750e-01],
                        [ -3.03253174e-01,  -3.03405762e-01],
                        [ -3.40728760e-01,  -3.40698242e-01],
                        [ -3.25408936e-01,  -3.25225830e-01],
                        [ -2.78564453e-01,  -2.78594971e-01],
                        [ -2.29736328e-01,  -2.29949951e-01],
                        [ -1.94335938e-01,  -1.94305420e-01],
                        [ -1.65222168e-01,  -1.65069580e-01],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -6.88476562e-02,  -6.90002441e-02],
                        [ -4.21142578e-03,  -4.27246094e-03],
                        [  5.14831543e-02,   5.16052246e-02],
                        [  8.57238770e-02,   8.57543945e-02],
                        [  9.73815918e-02,   9.72900391e-02],
                        [  9.74121094e-02,   9.73815918e-02],
                        [  9.89685059e-02,   9.89990234e-02],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  9.55200195e-02,   9.55200195e-02],
                        [  8.00781250e-02,   8.00476074e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  4.08630371e-02,   4.08935547e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  1.22070312e-04,   9.15527344e-05],
                        [ -1.49230957e-02,  -1.48925781e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -4.91333008e-03,  -4.97436523e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  2.87475586e-02,   2.87780762e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  4.83703613e-02,   4.83398438e-02],
                        [  5.25207520e-02,   5.25512695e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  5.09338379e-02,   5.09033203e-02],
                        [  4.27856445e-02,   4.28161621e-02],
                        [  3.34472656e-02,   3.34777832e-02],
                        [  2.62756348e-02,   2.61840820e-02],
                        [  2.09655762e-02,   2.09045410e-02],
                        [  1.58081055e-02,   1.58996582e-02],
                        [  1.05895996e-02,   1.06201172e-02],
                        [  6.28662109e-03,   6.22558594e-03],
                        [  2.10571289e-03,   2.01416016e-03],
                        [ -3.14331055e-03,  -3.11279297e-03],
                        [ -8.17871094e-03,  -8.08715820e-03],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -2.06298828e-02,  -2.07214355e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.32543945e-02,  -2.31628418e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.34277344e-03,  -1.40380859e-03],
                        [  4.91333008e-03,   4.94384766e-03],
                        [  7.81250000e-03,   7.87353516e-03],
                        [  1.39465332e-02,   1.38854980e-02],
                        [  2.63671875e-02,   2.63366699e-02],
                        [  4.24804688e-02,   4.25415039e-02],
                        [  5.52673340e-02,   5.53283691e-02],
                        [  5.73730469e-02,   5.73425293e-02],
                        [  4.72106934e-02,   4.71191406e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  2.22473145e-02,   2.23388672e-02],
                        [  1.91345215e-02,   1.91040039e-02],
                        [  1.55639648e-02,   1.55029297e-02],
                        [  7.41577148e-03,   7.44628906e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -8.45336914e-03,  -8.48388672e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.20544434e-02,  -1.20239258e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.17797852e-02,  -1.18103027e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -1.47399902e-02,  -1.47094727e-02],
                        [ -1.56860352e-02,  -1.56555176e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -2.20336914e-02,  -2.20947266e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -3.30200195e-02,  -3.29589844e-02],
                        [ -3.30200195e-02,  -3.29895020e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -2.76794434e-02,  -2.77099609e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.93371582e-02,  -3.92761230e-02],
                        [ -4.31518555e-02,  -4.31213379e-02],
                        [ -3.78417969e-02,  -3.78723145e-02],
                        [ -2.60925293e-02,  -2.61535645e-02],
                        [ -1.45874023e-02,  -1.45568848e-02],
                        [ -6.77490234e-03,  -6.74438477e-03],
                        [ -1.89208984e-03,  -1.92260742e-03],
                        [  1.61743164e-03,   1.58691406e-03],
                        [  4.24194336e-03,   4.21142578e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  6.10351562e-05,   9.15527344e-05],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -2.09960938e-02,  -2.10266113e-02],
                        [ -2.71911621e-02,  -2.71606445e-02],
                        [ -2.60925293e-02,  -2.60620117e-02],
                        [ -2.09045410e-02,  -2.09350586e-02],
                        [ -1.62658691e-02,  -1.62963867e-02],
                        [ -1.39770508e-02,  -1.39465332e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  3.96728516e-04,   4.27246094e-04],
                        [  6.53076172e-03,   6.50024414e-03],
                        [  1.04675293e-02,   1.04370117e-02],
                        [  1.31835938e-02,   1.32141113e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  2.72521973e-02,   2.72216797e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  8.88977051e-02,   8.89282227e-02],
                        [  1.03973389e-01,   1.03942871e-01],
                        [  1.19293213e-01,   1.19232178e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  1.39007568e-01,   1.39038086e-01],
                        [  1.29180908e-01,   1.29180908e-01],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  2.39562988e-02,   2.39257812e-02],
                        [ -7.46765137e-02,  -7.47070312e-02],
                        [ -1.83959961e-01,  -1.83898926e-01],
                        [ -2.75604248e-01,  -2.75543213e-01],
                        [ -3.25592041e-01,  -3.25622559e-01],
                        [ -3.26995850e-01,  -3.27056885e-01],
                        [ -2.93548584e-01,  -2.93518066e-01],
                        [ -2.47375488e-01,  -2.47314453e-01],
                        [ -2.04315186e-01,  -2.04315186e-01],
                        [ -1.67205811e-01,  -1.67266846e-01],
                        [ -1.27258301e-01,  -1.27319336e-01],
                        [ -7.60803223e-02,  -7.60192871e-02],
                        [ -1.76086426e-02,  -1.75170898e-02],
                        [  3.37829590e-02,   3.37219238e-02],
                        [  6.53076172e-02,   6.52465820e-02],
                        [  7.71484375e-02,   7.72094727e-02],
                        [  8.07800293e-02,   8.08410645e-02],
                        [  8.66088867e-02,   8.65783691e-02],
                        [  9.59777832e-02,   9.59472656e-02],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  1.01196289e-01,   1.01226807e-01],
                        [  9.03930664e-02,   9.03930664e-02],
                        [  7.62329102e-02,   7.62023926e-02],
                        [  6.57043457e-02,   6.56738281e-02],
                        [  6.05163574e-02,   6.05468750e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  2.36511230e-02,   2.36206055e-02],
                        [  2.85339355e-02,   2.85949707e-02],
                        [  3.54919434e-02,   3.55224609e-02],
                        [  3.99780273e-02,   3.99169922e-02],
                        [  4.03442383e-02,   4.03442383e-02],
                        [  3.90319824e-02,   3.90625000e-02],
                        [  3.97338867e-02,   3.97033691e-02],
                        [  4.18090820e-02,   4.18395996e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  3.69873047e-02,   3.69262695e-02],
                        [  3.28979492e-02,   3.29284668e-02],
                        [  2.97241211e-02,   2.97546387e-02],
                        [  2.66113281e-02,   2.65502930e-02],
                        [  2.44140625e-02,   2.44445801e-02],
                        [  2.32238770e-02,   2.32849121e-02],
                        [  2.08740234e-02,   2.08129883e-02],
                        [  1.47705078e-02,   1.47399902e-02],
                        [  4.57763672e-03,   4.63867188e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -1.27868652e-02,  -1.28173828e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.05895996e-02,  -1.05590820e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  3.14636230e-02,   3.14331055e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.11889648e-02,   3.12500000e-02],
                        [  2.85034180e-02,   2.84729004e-02],
                        [  2.52380371e-02,   2.51770020e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.23388672e-02,   2.23999023e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  2.42919922e-02,   2.42309570e-02],
                        [  1.79443359e-02,   1.79138184e-02],
                        [  8.88061523e-03,   8.94165039e-03],
                        [  4.82177734e-03,   4.88281250e-03],
                        [  6.34765625e-03,   6.28662109e-03],
                        [  6.95800781e-03,   6.89697266e-03],
                        [  2.83813477e-03,   2.89916992e-03],
                        [ -4.79125977e-03,  -4.73022461e-03],
                        [ -1.35498047e-02,  -1.35803223e-02],
                        [ -2.12402344e-02,  -2.13012695e-02],
                        [ -2.58789062e-02,  -2.58178711e-02],
                        [ -2.58483887e-02,  -2.58178711e-02],
                        [ -2.14233398e-02,  -2.14843750e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -5.82885742e-03,  -5.76782227e-03],
                        [ -2.10571289e-03,  -2.13623047e-03],
                        [ -6.92749023e-03,  -7.01904297e-03],
                        [ -1.86157227e-02,  -1.85852051e-02],
                        [ -3.07006836e-02,  -3.06091309e-02],
                        [ -3.83911133e-02,  -3.84216309e-02],
                        [ -4.26330566e-02,  -4.27246094e-02],
                        [ -4.61120605e-02,  -4.60510254e-02],
                        [ -4.76379395e-02,  -4.75158691e-02],
                        [ -4.50439453e-02,  -4.50744629e-02],
                        [ -3.98254395e-02,  -3.99169922e-02],
                        [ -3.34777832e-02,  -3.35083008e-02],
                        [ -2.45056152e-02,  -2.43530273e-02],
                        [ -1.26342773e-02,  -1.25732422e-02],
                        [ -2.89916992e-03,  -3.02124023e-03],
                        [  6.10351562e-05,   0.00000000e+00],
                        [ -1.00708008e-03,  -8.85009766e-04],
                        [  1.22070312e-04,   1.83105469e-04],
                        [  4.39453125e-03,   4.27246094e-03],
                        [  7.47680664e-03,   7.41577148e-03],
                        [  6.68334961e-03,   6.77490234e-03],
                        [  3.35693359e-03,   3.38745117e-03],
                        [ -1.25122070e-03,  -1.31225586e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -8.88061523e-03,  -8.81958008e-03],
                        [ -5.98144531e-03,  -5.95092773e-03],
                        [ -1.52587891e-04,  -2.13623047e-04],
                        [  5.21850586e-03,   5.18798828e-03],
                        [  1.06811523e-02,   1.07421875e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  2.49023438e-02,   2.48413086e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.32336426e-02,   3.32641602e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  4.33959961e-02,   4.33654785e-02],
                        [  5.16357422e-02,   5.15747070e-02],
                        [  6.18591309e-02,   6.18896484e-02],
                        [  7.43408203e-02,   7.43713379e-02],
                        [  8.82263184e-02,   8.81958008e-02],
                        [  1.00982666e-01,   1.00952148e-01],
                        [  1.07482910e-01,   1.07482910e-01],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.07910156e-01,  -1.07971191e-01],
                        [ -2.15332031e-01,  -2.15362549e-01],
                        [ -2.94799805e-01,  -2.94738770e-01],
                        [ -3.24157715e-01,  -3.24127197e-01],
                        [ -3.06762695e-01,  -3.06823730e-01],
                        [ -2.67303467e-01,  -2.67333984e-01],
                        [ -2.31262207e-01,  -2.31231689e-01],
                        [ -2.05810547e-01,  -2.05810547e-01],
                        [ -1.79565430e-01,  -1.79595947e-01],
                        [ -1.37359619e-01,  -1.37359619e-01],
                        [ -7.51953125e-02,  -7.51953125e-02],
                        [ -3.81469727e-03,  -3.78417969e-03],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  1.00128174e-01,   1.00097656e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.31256104e-01,   1.31256104e-01],
                        [  1.30889893e-01,   1.30889893e-01],
                        [  1.26037598e-01,   1.26068115e-01],
                        [  1.16638184e-01,   1.16668701e-01],
                        [  1.04034424e-01,   1.04003906e-01],
                        [  8.80737305e-02,   8.80126953e-02],
                        [  6.82067871e-02,   6.82373047e-02],
                        [  4.60205078e-02,   4.61120605e-02],
                        [  2.36511230e-02,   2.36206055e-02],
                        [  3.63159180e-03,   3.50952148e-03],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -1.62048340e-02,  -1.61132812e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -2.74658203e-03,  -2.80761719e-03],
                        [  5.46264648e-03,   5.43212891e-03],
                        [  1.29699707e-02,   1.30004883e-02],
                        [  2.41088867e-02,   2.42004395e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  4.86450195e-02,   4.84924316e-02],
                        [  5.42907715e-02,   5.43212891e-02],
                        [  5.71899414e-02,   5.73120117e-02],
                        [  5.90209961e-02,   5.89904785e-02],
                        [  5.74645996e-02,   5.73730469e-02],
                        [  5.07812500e-02,   5.08117676e-02],
                        [  4.14428711e-02,   4.15039062e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  2.77709961e-02,   2.76794434e-02],
                        [  2.30407715e-02,   2.30712891e-02],
                        [  1.84326172e-02,   1.85241699e-02],
                        [  1.29089355e-02,   1.28784180e-02],
                        [  4.21142578e-03,   4.11987305e-03],
                        [ -6.59179688e-03,  -6.50024414e-03],
                        [ -1.46179199e-02,  -1.45263672e-02],
                        [ -1.71813965e-02,  -1.72424316e-02],
                        [ -1.67541504e-02,  -1.68457031e-02],
                        [ -1.55334473e-02,  -1.55029297e-02],
                        [ -1.00708008e-02,  -9.94873047e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.13220215e-02,   1.11999512e-02],
                        [  1.49230957e-02,   1.48620605e-02],
                        [  1.62658691e-02,   1.63879395e-02],
                        [  2.10266113e-02,   2.10876465e-02],
                        [  2.86865234e-02,   2.85644531e-02],
                        [  3.37829590e-02,   3.36914062e-02],
                        [  3.22570801e-02,   3.23486328e-02],
                        [  2.60314941e-02,   2.60925293e-02],
                        [  1.93176270e-02,   1.92565918e-02],
                        [  1.49230957e-02,   1.48925781e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.48010254e-02,   1.48315430e-02],
                        [  1.76696777e-02,   1.77307129e-02],
                        [  2.09350586e-02,   2.09655762e-02],
                        [  2.15454102e-02,   2.14538574e-02],
                        [  1.77001953e-02,   1.76696777e-02],
                        [  9.82666016e-03,   9.91821289e-03],
                        [ -1.06811523e-03,  -1.00708008e-03],
                        [ -1.41296387e-02,  -1.41906738e-02],
                        [ -2.84729004e-02,  -2.85644531e-02],
                        [ -4.01306152e-02,  -4.00695801e-02],
                        [ -4.34265137e-02,  -4.33044434e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -3.41796875e-02,  -3.42712402e-02],
                        [ -3.18603516e-02,  -3.18908691e-02],
                        [ -2.96325684e-02,  -2.95410156e-02],
                        [ -2.55432129e-02,  -2.55126953e-02],
                        [ -2.27355957e-02,  -2.28271484e-02],
                        [ -2.49023438e-02,  -2.49328613e-02],
                        [ -2.97851562e-02,  -2.97241211e-02],
                        [ -3.15551758e-02,  -3.15246582e-02],
                        [ -2.73437500e-02,  -2.74353027e-02],
                        [ -1.87377930e-02,  -1.87988281e-02],
                        [ -9.64355469e-03,  -9.58251953e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -2.65502930e-03,  -2.77709961e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -1.40380859e-03,  -1.31225586e-03],
                        [  1.86157227e-03,   1.83105469e-03],
                        [  4.57763672e-04,   3.66210938e-04],
                        [ -9.61303711e-03,  -9.55200195e-03],
                        [ -2.31628418e-02,  -2.30407715e-02],
                        [ -3.25012207e-02,  -3.24707031e-02],
                        [ -3.56140137e-02,  -3.56750488e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.20031738e-02,  -2.18505859e-02],
                        [ -1.95312500e-03,  -1.80053711e-03],
                        [  1.97143555e-02,   1.96838379e-02],
                        [  3.30810547e-02,   3.29895020e-02],
                        [  3.55224609e-02,   3.56750488e-02],
                        [  3.13110352e-02,   3.14636230e-02],
                        [  2.57568359e-02,   2.56652832e-02],
                        [  2.20947266e-02,   2.20031738e-02],
                        [  2.08435059e-02,   2.09045410e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  3.00598145e-02,   2.99682617e-02],
                        [  4.17785645e-02,   4.16870117e-02],
                        [  5.73730469e-02,   5.72814941e-02],
                        [  7.63549805e-02,   7.62939453e-02],
                        [  9.57641602e-02,   9.57031250e-02],
                        [  1.11022949e-01,   1.10900879e-01],
                        [  1.18835449e-01,   1.18713379e-01],
                        [  1.15936279e-01,   1.15936279e-01],
                        [  9.44824219e-02,   9.44519043e-02],
                        [  4.32434082e-02,   4.31518555e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -1.47857666e-01,  -1.47766113e-01],
                        [ -2.46765137e-01,  -2.46734619e-01],
                        [ -3.08654785e-01,  -3.08624268e-01],
                        [ -3.20007324e-01,  -3.19885254e-01],
                        [ -2.90710449e-01,  -2.90557861e-01],
                        [ -2.44720459e-01,  -2.44567871e-01],
                        [ -2.04101562e-01,  -2.03979492e-01],
                        [ -1.75018311e-01,  -1.74926758e-01],
                        [ -1.45477295e-01,  -1.45355225e-01],
                        [ -1.00219727e-01,  -1.00067139e-01],
                        [ -3.88793945e-02,  -3.87878418e-02],
                        [  2.23388672e-02,   2.22778320e-02],
                        [  6.59790039e-02,   6.59484863e-02],
                        [  8.81652832e-02,   8.81958008e-02],
                        [  9.69543457e-02,   9.68933105e-02],
                        [  1.01196289e-01,   1.00952148e-01],
                        [  1.04492188e-01,   1.04278564e-01],
                        [  1.06231689e-01,   1.06201172e-01],
                        [  1.03363037e-01,   1.03210449e-01],
                        [  9.24987793e-02,   9.21325684e-02],
                        [  7.39440918e-02,   7.37609863e-02],
                        [  5.41076660e-02,   5.41076660e-02],
                        [  4.00085449e-02,   3.98864746e-02],
                        [  3.10363770e-02,   3.08837891e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  1.11694336e-02,   1.12609863e-02],
                        [  7.29370117e-03,   7.41577148e-03],
                        [  1.07421875e-02,   1.08642578e-02],
                        [  1.82800293e-02,   1.84020996e-02],
                        [  2.85034180e-02,   2.87475586e-02],
                        [  3.96423340e-02,   3.99780273e-02],
                        [  4.88891602e-02,   4.90722656e-02],
                        [  5.61828613e-02,   5.63354492e-02],
                        [  6.34460449e-02,   6.37512207e-02],
                        [  6.87561035e-02,   6.89697266e-02],
                        [  6.71081543e-02,   6.71386719e-02],
                        [  5.77392578e-02,   5.77697754e-02],
                        [  4.44641113e-02,   4.45251465e-02],
                        [  3.10363770e-02,   3.09448242e-02],
                        [  1.97753906e-02,   1.95922852e-02],
                        [  1.04064941e-02,   1.02233887e-02],
                        [  1.43432617e-03,   1.15966797e-03],
                        [ -6.01196289e-03,  -6.34765625e-03],
                        [ -9.70458984e-03,  -9.97924805e-03],
                        [ -8.81958008e-03,  -9.12475586e-03],
                        [ -5.09643555e-03,  -5.43212891e-03],
                        [ -2.38037109e-03,  -2.62451172e-03],
                        [ -2.19726562e-03,  -2.31933594e-03],
                        [ -3.29589844e-03,  -3.41796875e-03],
                        [ -4.85229492e-03,  -4.97436523e-03],
                        [ -4.79125977e-03,  -4.76074219e-03],
                        [  8.85009766e-04,   1.09863281e-03],
                        [  1.43737793e-02,   1.46179199e-02],
                        [  3.16467285e-02,   3.18298340e-02],
                        [  4.41894531e-02,   4.44946289e-02],
                        [  4.84313965e-02,   4.89196777e-02],
                        [  4.71496582e-02,   4.75158691e-02],
                        [  4.22363281e-02,   4.24499512e-02],
                        [  3.50646973e-02,   3.54003906e-02],
                        [  2.85644531e-02,   2.89001465e-02],
                        [  2.36816406e-02,   2.38952637e-02],
                        [  1.73339844e-02,   1.73950195e-02],
                        [  6.13403320e-03,   6.07299805e-03],
                        [ -6.01196289e-03,  -6.07299805e-03],
                        [ -1.19018555e-02,  -1.20239258e-02],
                        [ -1.18408203e-02,  -1.22070312e-02],
                        [ -1.02539062e-02,  -1.06506348e-02],
                        [ -9.21630859e-03,  -9.49096680e-03],
                        [ -9.36889648e-03,  -9.79614258e-03],
                        [ -9.30786133e-03,  -9.79614258e-03],
                        [ -8.27026367e-03,  -8.57543945e-03],
                        [ -8.33129883e-03,  -8.63647461e-03],
                        [ -1.10168457e-02,  -1.13830566e-02],
                        [ -1.65100098e-02,  -1.66625977e-02],
                        [ -2.18505859e-02,  -2.18200684e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.16979980e-02,  -2.16369629e-02],
                        [ -2.37426758e-02,  -2.34680176e-02],
                        [ -2.73437500e-02,  -2.69470215e-02],
                        [ -2.84423828e-02,  -2.80151367e-02],
                        [ -2.63977051e-02,  -2.60620117e-02],
                        [ -2.27661133e-02,  -2.23693848e-02],
                        [ -1.82189941e-02,  -1.76696777e-02],
                        [ -1.34887695e-02,  -1.30615234e-02],
                        [ -1.15661621e-02,  -1.13525391e-02],
                        [ -1.26647949e-02,  -1.24206543e-02],
                        [ -1.14440918e-02,  -1.11389160e-02],
                        [ -5.67626953e-03,  -5.61523438e-03],
                        [ -4.27246094e-04,  -6.10351562e-04],
                        [ -4.88281250e-04,  -6.40869141e-04],
                        [ -5.00488281e-03,  -5.15747070e-03],
                        [ -9.58251953e-03,  -9.97924805e-03],
                        [ -1.20544434e-02,  -1.25732422e-02],
                        [ -1.22680664e-02,  -1.26953125e-02],
                        [ -8.57543945e-03,  -8.94165039e-03],
                        [ -8.23974609e-04,  -1.28173828e-03],
                        [  7.08007812e-03,   6.59179688e-03],
                        [  1.29089355e-02,   1.25732422e-02],
                        [  1.83410645e-02,   1.81274414e-02],
                        [  2.39257812e-02,   2.37731934e-02],
                        [  2.70385742e-02,   2.69470215e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  2.27661133e-02,   2.29187012e-02],
                        [  2.09350586e-02,   2.12402344e-02],
                        [  2.24304199e-02,   2.27661133e-02],
                        [  2.84423828e-02,   2.87475586e-02],
                        [  3.90319824e-02,   3.94287109e-02],
                        [  5.32836914e-02,   5.37719727e-02],
                        [  7.19299316e-02,   7.23876953e-02],
                        [  9.48791504e-02,   9.52453613e-02],
                        [  1.16882324e-01,   1.17187500e-01],
                        [  1.30554199e-01,   1.30828857e-01],
                        [  1.28234863e-01,   1.28448486e-01],
                        [  9.79309082e-02,   9.80834961e-02],
                        [  2.75573730e-02,   2.75878906e-02],
                        [ -7.98339844e-02,  -7.99255371e-02],
                        [ -1.97753906e-01,  -1.97906494e-01],
                        [ -2.89093018e-01,  -2.89245605e-01],
                        [ -3.28857422e-01,  -3.29071045e-01],
                        [ -3.16406250e-01,  -3.16741943e-01],
                        [ -2.73071289e-01,  -2.73406982e-01],
                        [ -2.26684570e-01,  -2.27020264e-01],
                        [ -1.90338135e-01,  -1.90643311e-01],
                        [ -1.56402588e-01,  -1.56646729e-01],
                        [ -1.11633301e-01,  -1.11968994e-01],
                        [ -5.30090332e-02,  -5.34057617e-02],
                        [  9.15527344e-03,   8.97216797e-03],
                        [  5.88073730e-02,   5.87463379e-02],
                        [  8.46862793e-02,   8.45031738e-02],
                        [  8.63342285e-02,   8.61206055e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  6.64062500e-02,   6.65283203e-02],
                        [  6.86645508e-02,   6.87561035e-02],
                        [  7.65991211e-02,   7.66296387e-02],
                        [  8.16040039e-02,   8.17565918e-02],
                        [  8.20312500e-02,   8.23364258e-02],
                        [  8.11767578e-02,   8.15124512e-02],
                        [  7.84912109e-02,   7.87658691e-02],
                        [  7.04956055e-02,   7.08312988e-02],
                        [  5.87463379e-02,   5.91430664e-02],
                        [  4.90417480e-02,   4.94384766e-02],
                        [  4.37316895e-02,   4.40979004e-02],
                        [  3.97949219e-02,   4.01916504e-02],
                        [  3.49426270e-02,   3.52783203e-02],
                        [  3.07006836e-02,   3.09448242e-02],
                        [  2.83203125e-02,   2.85644531e-02],
                        [  2.67944336e-02,   2.69470215e-02],
                        [  2.60009766e-02,   2.59704590e-02],
                        [  2.76184082e-02,   2.74963379e-02],
                        [  3.31420898e-02,   3.29284668e-02],
                        [  4.28161621e-02,   4.24499512e-02],
                        [  5.35583496e-02,   5.30700684e-02],
                        [  5.76782227e-02,   5.70983887e-02],
                        [  4.81872559e-02,   4.75158691e-02],
                        [  2.59704590e-02,   2.52380371e-02],
                        [  7.32421875e-04,  -6.10351562e-05],
                        [ -1.55639648e-02,  -1.62963867e-02],
                        [ -1.83715820e-02,  -1.89819336e-02],
                        [ -1.48010254e-02,  -1.54418945e-02],
                        [ -1.59606934e-02,  -1.64794922e-02],
                        [ -2.47802734e-02,  -2.49633789e-02],
                        [ -3.30200195e-02,  -3.29589844e-02],
                        [ -3.11584473e-02,  -3.10363770e-02],
                        [ -1.95922852e-02,  -1.92565918e-02],
                        [ -5.92041016e-03,  -5.24902344e-03],
                        [  4.30297852e-03,   5.24902344e-03],
                        [  8.97216797e-03,   1.00097656e-02],
                        [  1.02539062e-02,   1.13220215e-02],
                        [  1.50451660e-02,   1.62353516e-02],
                        [  2.66113281e-02,   2.79541016e-02],
                        [  3.86962891e-02,   3.98559570e-02],
                        [  4.23583984e-02,   4.32739258e-02],
                        [  3.69262695e-02,   3.77502441e-02],
                        [  3.03649902e-02,   3.09753418e-02],
                        [  2.88391113e-02,   2.90222168e-02],
                        [  3.10668945e-02,   3.09448242e-02],
                        [  3.17077637e-02,   3.12805176e-02],
                        [  2.75878906e-02,   2.67944336e-02],
                        [  2.13623047e-02,   2.02331543e-02],
                        [  1.77307129e-02,   1.63574219e-02],
                        [  1.73645020e-02,   1.58081055e-02],
                        [  1.66320801e-02,   1.49536133e-02],
                        [  1.16882324e-02,   9.94873047e-03],
                        [  3.60107422e-03,   1.95312500e-03],
                        [ -2.44140625e-03,  -3.81469727e-03],
                        [ -4.05883789e-03,  -5.24902344e-03],
                        [ -3.35693359e-03,  -4.24194336e-03],
                        [ -4.15039062e-03,  -4.57763672e-03],
                        [ -9.73510742e-03,  -9.70458984e-03],
                        [ -1.86462402e-02,  -1.81579590e-02],
                        [ -2.73132324e-02,  -2.63671875e-02],
                        [ -3.38439941e-02,  -3.25317383e-02],
                        [ -3.57971191e-02,  -3.41186523e-02],
                        [ -3.23181152e-02,  -3.03039551e-02],
                        [ -2.56347656e-02,  -2.35290527e-02],
                        [ -1.84020996e-02,  -1.62963867e-02],
                        [ -1.51062012e-02,  -1.30615234e-02],
                        [ -1.88903809e-02,  -1.69982910e-02],
                        [ -2.57568359e-02,  -2.42614746e-02],
                        [ -2.96936035e-02,  -2.86254883e-02],
                        [ -2.82287598e-02,  -2.76489258e-02],
                        [ -2.27966309e-02,  -2.27355957e-02],
                        [ -1.61132812e-02,  -1.65710449e-02],
                        [ -1.03149414e-02,  -1.13830566e-02],
                        [ -8.60595703e-03,  -1.02233887e-02],
                        [ -1.22985840e-02,  -1.41906738e-02],
                        [ -1.66015625e-02,  -1.87988281e-02],
                        [ -1.80664062e-02,  -2.05383301e-02],
                        [ -1.83105469e-02,  -2.08435059e-02],
                        [ -1.80969238e-02,  -2.04467773e-02],
                        [ -1.51062012e-02,  -1.71508789e-02],
                        [ -7.84301758e-03,  -9.61303711e-03],
                        [  3.96728516e-04,  -9.76562500e-04],
                        [  4.69970703e-03,   3.96728516e-03],
                        [  4.57763672e-03,   4.54711914e-03],
                        [  2.01416016e-03,   2.53295898e-03],
                        [ -1.80053711e-03,  -7.62939453e-04],
                        [ -4.82177734e-03,  -3.20434570e-03],
                        [ -4.54711914e-03,  -2.38037109e-03],
                        [ -7.01904297e-04,   1.73950195e-03],
                        [  4.33349609e-03,   6.89697266e-03],
                        [  8.45336914e-03,   1.11389160e-02],
                        [  1.34277344e-02,   1.59912109e-02],
                        [  2.14538574e-02,   2.37121582e-02],
                        [  3.10668945e-02,   3.29589844e-02],
                        [  4.06799316e-02,   4.21142578e-02],
                        [  5.18798828e-02,   5.26733398e-02],
                        [  6.71081543e-02,   6.72607422e-02],
                        [  8.73413086e-02,   8.68835449e-02],
                        [  1.11755371e-01,   1.10687256e-01],
                        [  1.35467529e-01,   1.33850098e-01],
                        [  1.48010254e-01,   1.45904541e-01],
                        [  1.37420654e-01,   1.34979248e-01],
                        [  9.47570801e-02,   9.21936035e-02],
                        [  1.55334473e-02,   1.29089355e-02],
                        [ -9.47570801e-02,  -9.72900391e-02],
                        [ -2.13378906e-01,  -2.15637207e-01],
                        [ -3.07098389e-01,  -3.08929443e-01],
                        [ -3.51348877e-01,  -3.52691650e-01],
                        [ -3.43200684e-01,  -3.43994141e-01],
                        [ -2.99072266e-01,  -2.99194336e-01],
                        [ -2.43927002e-01,  -2.43499756e-01],
                        [ -1.97814941e-01,  -1.96868896e-01],
                        [ -1.63116455e-01,  -1.61621094e-01],
                        [ -1.24969482e-01,  -1.22955322e-01],
                        [ -6.92749023e-02,  -6.70471191e-02],
                        [ -1.46484375e-03,   8.23974609e-04],
                        [  5.75866699e-02,   5.99365234e-02],
                        [  9.24682617e-02,   9.48181152e-02],
                        [  1.03668213e-01,   1.05712891e-01],
                        [  1.00433350e-01,   1.01989746e-01],
                        [  9.28649902e-02,   9.39941406e-02],
                        [  8.78295898e-02,   8.85925293e-02],
                        [  8.64562988e-02,   8.66699219e-02],
                        [  8.56628418e-02,   8.52050781e-02],
                        [  8.29162598e-02,   8.20007324e-02],
                        [  7.91625977e-02,   7.79418945e-02],
                        [  7.54394531e-02,   7.38830566e-02],
                        [  6.87561035e-02,   6.69250488e-02],
                        [  5.58166504e-02,   5.38635254e-02],
                        [  3.94287109e-02,   3.75061035e-02],
                        [  2.77099609e-02,   2.59399414e-02],
                        [  2.66113281e-02,   2.50549316e-02],
                        [  3.46374512e-02,   3.33557129e-02],
                        [  4.50744629e-02,   4.42199707e-02],
                        [  5.22460938e-02,   5.17578125e-02],
                        [  5.55725098e-02,   5.54504395e-02],
                        [  5.88378906e-02,   5.92041016e-02],
                        [  6.38427734e-02,   6.45751953e-02],
                        [  6.64672852e-02,   6.73217773e-02],
                        [  6.12487793e-02,   6.23474121e-02],
                        [  4.73022461e-02,   4.87060547e-02],
                        [  2.73132324e-02,   2.86865234e-02],
                        [  3.87573242e-03,   5.03540039e-03],
                        [ -1.97753906e-02,  -1.86462402e-02],
                        [ -3.73229980e-02,  -3.62854004e-02],
                        [ -4.30908203e-02,  -4.22668457e-02],
                        [ -3.93676758e-02,  -3.89099121e-02],
                        [ -3.46984863e-02,  -3.45153809e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.61938477e-02,  -3.62854004e-02],
                        [ -3.91235352e-02,  -3.95507812e-02],
                        [ -3.76586914e-02,  -3.83300781e-02],
                        [ -2.63977051e-02,  -2.69165039e-02],
                        [ -6.25610352e-03,  -6.74438477e-03],
                        [  1.44653320e-02,   1.37634277e-02],
                        [  2.79541016e-02,   2.73437500e-02],
                        [  3.44848633e-02,   3.41491699e-02],
                        [  4.03137207e-02,   4.00695801e-02],
                        [  4.80957031e-02,   4.78820801e-02],
                        [  5.48706055e-02,   5.47790527e-02],
                        [  5.88073730e-02,   5.88684082e-02],
                        [  6.06079102e-02,   6.07299805e-02],
                        [  6.01196289e-02,   6.02111816e-02],
                        [  5.69152832e-02,   5.70068359e-02],
                        [  5.21850586e-02,   5.23071289e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  3.92150879e-02,   3.90625000e-02],
                        [  2.67944336e-02,   2.66418457e-02],
                        [  1.40075684e-02,   1.38244629e-02],
                        [  6.40869141e-03,   6.01196289e-03],
                        [  2.44140625e-03,   2.01416016e-03],
                        [ -2.89916992e-03,  -3.23486328e-03],
                        [ -9.79614258e-03,  -1.00708008e-02],
                        [ -1.44653320e-02,  -1.47399902e-02],
                        [ -1.56250000e-02,  -1.58081055e-02],
                        [ -1.43432617e-02,  -1.43127441e-02],
                        [ -1.11083984e-02,  -1.08032227e-02],
                        [ -8.72802734e-03,  -8.30078125e-03],
                        [ -1.23291016e-02,  -1.18103027e-02],
                        [ -2.21252441e-02,  -2.13623047e-02],
                        [ -3.25317383e-02,  -3.15246582e-02],
                        [ -3.88793945e-02,  -3.78723145e-02],
                        [ -4.18090820e-02,  -4.08935547e-02],
                        [ -4.43115234e-02,  -4.33654785e-02],
                        [ -4.58679199e-02,  -4.49523926e-02],
                        [ -4.38232422e-02,  -4.32128906e-02],
                        [ -3.82995605e-02,  -3.79028320e-02],
                        [ -3.15551758e-02,  -3.14331055e-02],
                        [ -2.45666504e-02,  -2.48413086e-02],
                        [ -1.69677734e-02,  -1.75476074e-02],
                        [ -9.61303711e-03,  -1.04675293e-02],
                        [ -4.24194336e-03,  -5.40161133e-03],
                        [ -2.44140625e-04,  -1.64794922e-03],
                        [  2.99072266e-03,   1.46484375e-03],
                        [  3.93676758e-03,   2.34985352e-03],
                        [  1.86157227e-03,   3.66210938e-04],
                        [ -3.23486328e-03,  -4.57763672e-03],
                        [ -1.07727051e-02,  -1.19323730e-02],
                        [ -1.73645020e-02,  -1.81579590e-02],
                        [ -2.01721191e-02,  -2.05078125e-02],
                        [ -2.02941895e-02,  -2.02636719e-02],
                        [ -2.01110840e-02,  -1.96533203e-02],
                        [ -1.98974609e-02,  -1.89208984e-02],
                        [ -1.74255371e-02,  -1.61132812e-02],
                        [ -1.12609863e-02,  -9.67407227e-03],
                        [ -2.31933594e-03,  -4.27246094e-04],
                        [  8.48388672e-03,   1.04370117e-02],
                        [  1.91040039e-02,   2.10266113e-02],
                        [  2.59399414e-02,   2.77404785e-02],
                        [  2.75878906e-02,   2.91137695e-02],
                        [  2.67028809e-02,   2.78625488e-02],
                        [  2.73742676e-02,   2.81066895e-02],
                        [  3.15856934e-02,   3.17382812e-02],
                        [  3.72924805e-02,   3.69567871e-02],
                        [  4.17785645e-02,   4.10156250e-02],
                        [  4.59899902e-02,   4.47082520e-02],
                        [  5.35888672e-02,   5.18188477e-02],
                        [  6.50329590e-02,   6.30187988e-02],
                        [  7.68432617e-02,   7.47680664e-02],
                        [  8.72802734e-02,   8.51440430e-02],
                        [  9.72900391e-02,   9.52148438e-02],
                        [  1.02050781e-01,   1.00219727e-01],
                        [  8.65478516e-02,   8.51440430e-02],
                        [  3.42712402e-02,   3.33862305e-02],
                        [ -5.80139160e-02,  -5.84411621e-02],
                        [ -1.72546387e-01,  -1.72485352e-01],
                        [ -2.74871826e-01,  -2.74139404e-01],
                        [ -3.30047607e-01,  -3.28735352e-01],
                        [ -3.25622559e-01,  -3.23944092e-01],
                        [ -2.80761719e-01,  -2.78808594e-01],
                        [ -2.29858398e-01,  -2.27691650e-01],
                        [ -1.95037842e-01,  -1.92779541e-01],
                        [ -1.73095703e-01,  -1.70959473e-01],
                        [ -1.46270752e-01,  -1.44409180e-01],
                        [ -1.01470947e-01,  -1.00006104e-01],
                        [ -4.09851074e-02,  -3.99475098e-02],
                        [  1.98364258e-02,   2.02941895e-02],
                        [  6.48498535e-02,   6.46972656e-02],
                        [  8.95690918e-02,   8.88977051e-02],
                        [  1.01196289e-01,   9.99755859e-02],
                        [  1.10260010e-01,   1.08520508e-01],
                        [  1.21826172e-01,   1.19781494e-01],
                        [  1.31805420e-01,   1.29669189e-01],
                        [  1.33361816e-01,   1.31134033e-01],
                        [  1.23962402e-01,   1.21734619e-01],
                        [  1.05316162e-01,   1.03393555e-01],
                        [  8.16650391e-02,   8.02917480e-02],
                        [  5.78308105e-02,   5.69152832e-02],
                        [  3.69262695e-02,   3.64685059e-02],
                        [  2.02636719e-02,   2.04162598e-02],
                        [  9.49096680e-03,   1.03149414e-02],
                        [  6.25610352e-03,   7.69042969e-03],
                        [  8.75854492e-03,   1.05285645e-02],
                        [  1.31835938e-02,   1.52282715e-02],
                        [  2.05688477e-02,   2.28576660e-02],
                        [  3.39050293e-02,   3.62854004e-02],
                        [  5.04150391e-02,   5.25512695e-02],
                        [  6.42700195e-02,   6.60705566e-02],
                        [  7.11975098e-02,   7.26013184e-02],
                        [  6.82373047e-02,   6.91223145e-02],
                        [  5.49621582e-02,   5.52062988e-02],
                        [  3.46679688e-02,   3.42712402e-02],
                        [  1.34887695e-02,   1.24511719e-02],
                        [ -2.92968750e-03,  -4.51660156e-03],
                        [ -1.26647949e-02,  -1.47094727e-02],
                        [ -1.73645020e-02,  -1.97143555e-02],
                        [ -1.98059082e-02,  -2.22778320e-02],
                        [ -2.36206055e-02,  -2.60925293e-02],
                        [ -3.17687988e-02,  -3.40881348e-02],
                        [ -4.20227051e-02,  -4.39453125e-02],
                        [ -4.68444824e-02,  -4.81872559e-02],
                        [ -4.06494141e-02,  -4.14123535e-02],
                        [ -2.50854492e-02,  -2.52685547e-02],
                        [ -6.19506836e-03,  -5.64575195e-03],
                        [  1.08947754e-02,   1.22070312e-02],
                        [  2.34985352e-02,   2.54211426e-02],
                        [  3.15551758e-02,   3.38439941e-02],
                        [  3.72619629e-02,   3.98559570e-02],
                        [  4.31823730e-02,   4.59899902e-02],
                        [  4.94689941e-02,   5.22766113e-02],
                        [  5.36499023e-02,   5.61828613e-02],
                        [  5.21545410e-02,   5.41992188e-02],
                        [  4.42199707e-02,   4.57153320e-02],
                        [  3.43017578e-02,   3.52172852e-02],
                        [  2.80151367e-02,   2.81372070e-02],
                        [  2.69165039e-02,   2.62145996e-02],
                        [  2.91748047e-02,   2.77404785e-02],
                        [  3.17687988e-02,   2.97241211e-02],
                        [  3.10668945e-02,   2.84729004e-02],
                        [  2.49633789e-02,   2.19726562e-02],
                        [  1.55944824e-02,   1.24511719e-02],
                        [  6.53076172e-03,   3.47900391e-03],
                        [ -1.95312500e-03,  -4.76074219e-03],
                        [ -9.94873047e-03,  -1.23901367e-02],
                        [ -1.43737793e-02,  -1.61437988e-02],
                        [ -1.36718750e-02,  -1.46484375e-02],
                        [ -1.04980469e-02,  -1.07727051e-02],
                        [ -8.30078125e-03,  -7.75146484e-03],
                        [ -1.08642578e-02,  -9.36889648e-03],
                        [ -2.08740234e-02,  -1.86767578e-02],
                        [ -3.61022949e-02,  -3.34472656e-02],
                        [ -4.96826172e-02,  -4.65698242e-02],
                        [ -5.30090332e-02,  -4.95605469e-02],
                        [ -4.16564941e-02,  -3.82385254e-02],
                        [ -2.18505859e-02,  -1.87988281e-02],
                        [ -5.88989258e-03,  -3.26538086e-03],
                        [  7.32421875e-04,   2.83813477e-03],
                        [  1.70898438e-03,   3.08227539e-03],
                        [  7.93457031e-04,   1.12915039e-03],
                        [ -2.01416016e-03,  -2.53295898e-03],
                        [ -5.49316406e-03,  -6.74438477e-03],
                        [ -8.57543945e-03,  -1.05895996e-02],
                        [ -1.35498047e-02,  -1.63269043e-02],
                        [ -2.12707520e-02,  -2.45056152e-02],
                        [ -2.66723633e-02,  -3.00598145e-02],
                        [ -2.47192383e-02,  -2.81066895e-02],
                        [ -1.83105469e-02,  -2.16064453e-02],
                        [ -1.41296387e-02,  -1.70898438e-02],
                        [ -1.37634277e-02,  -1.59606934e-02],
                        [ -1.47094727e-02,  -1.61132812e-02],
                        [ -1.57470703e-02,  -1.64794922e-02],
                        [ -1.58996582e-02,  -1.57165527e-02],
                        [ -1.44042969e-02,  -1.32141113e-02],
                        [ -1.34277344e-02,  -1.15051270e-02],
                        [ -1.52587891e-02,  -1.27563477e-02],
                        [ -1.76086426e-02,  -1.44958496e-02],
                        [ -1.51672363e-02,  -1.17797852e-02],
                        [ -6.40869141e-03,  -3.05175781e-03],
                        [  4.27246094e-03,   7.53784180e-03],
                        [  1.35192871e-02,   1.64184570e-02],
                        [  2.13012695e-02,   2.35900879e-02],
                        [  2.70080566e-02,   2.85339355e-02],
                        [  2.96630859e-02,   3.03955078e-02],
                        [  3.16467285e-02,   3.15246582e-02],
                        [  3.76586914e-02,   3.67431641e-02],
                        [  5.06591797e-02,   4.89196777e-02],
                        [  6.83898926e-02,   6.59179688e-02],
                        [  8.67309570e-02,   8.38317871e-02],
                        [  1.05651855e-01,   1.02508545e-01],
                        [  1.25244141e-01,   1.21978760e-01],
                        [  1.37603760e-01,   1.34429932e-01],
                        [  1.29760742e-01,   1.26983643e-01],
                        [  9.28955078e-02,   9.07897949e-02],
                        [  2.39562988e-02,   2.25219727e-02],
                        [ -7.48596191e-02,  -7.55920410e-02],
                        [ -1.88873291e-01,  -1.88781738e-01],
                        [ -2.87994385e-01,  -2.86987305e-01],
                        [ -3.42010498e-01,  -3.40270996e-01],
                        [ -3.41918945e-01,  -3.39599609e-01],
                        [ -3.03161621e-01,  -3.00384521e-01],
                        [ -2.51342773e-01,  -2.48321533e-01],
                        [ -2.05291748e-01,  -2.02209473e-01],
                        [ -1.66931152e-01,  -1.64001465e-01],
                        [ -1.24694824e-01,  -1.22192383e-01],
                        [ -6.83593750e-02,  -6.64062500e-02],
                        [ -1.77001953e-03,  -4.57763672e-04],
                        [  5.75561523e-02,   5.80444336e-02],
                        [  9.29260254e-02,   9.25903320e-02],
                        [  1.03210449e-01,   1.02142334e-01],
                        [  9.98535156e-02,   9.80834961e-02],
                        [  9.40551758e-02,   9.16137695e-02],
                        [  9.14306641e-02,   8.86535645e-02],
                        [  9.28955078e-02,   8.99658203e-02],
                        [  9.46350098e-02,   9.16442871e-02],
                        [  9.04235840e-02,   8.75854492e-02],
                        [  7.76672363e-02,   7.53173828e-02],
                        [  6.06689453e-02,   5.89599609e-02],
                        [  4.53491211e-02,   4.43115234e-02],
                        [  3.30200195e-02,   3.27148438e-02],
                        [  2.21557617e-02,   2.26135254e-02],
                        [  1.41906738e-02,   1.55334473e-02],
                        [  1.43432617e-02,   1.64184570e-02],
                        [  2.36816406e-02,   2.62145996e-02],
                        [  3.62854004e-02,   3.91235352e-02],
                        [  4.83398438e-02,   5.14831543e-02],
                        [  6.25305176e-02,   6.56738281e-02],
                        [  7.83996582e-02,   8.11767578e-02],
                        [  8.83178711e-02,   9.06372070e-02],
                        [  8.52966309e-02,   8.70361328e-02],
                        [  6.90307617e-02,   7.00378418e-02],
                        [  4.41589355e-02,   4.43115234e-02],
                        [  1.67236328e-02,   1.60522461e-02],
                        [ -6.40869141e-03,  -7.87353516e-03],
                        [ -2.11486816e-02,  -2.33154297e-02],
                        [ -3.01513672e-02,  -3.28979492e-02],
                        [ -3.80554199e-02,  -4.11376953e-02],
                        [ -4.42810059e-02,  -4.75158691e-02],
                        [ -4.53796387e-02,  -4.86145020e-02],
                        [ -4.05273438e-02,  -4.35180664e-02],
                        [ -3.09753418e-02,  -3.34472656e-02],
                        [ -1.73034668e-02,  -1.91040039e-02],
                        [ -1.28173828e-03,  -2.34985352e-03],
                        [  1.25122070e-02,   1.22070312e-02],
                        [  2.10571289e-02,   2.16674805e-02],
                        [  2.64587402e-02,   2.79541016e-02],
                        [  3.17993164e-02,   3.39660645e-02],
                        [  3.60717773e-02,   3.87878418e-02],
                        [  3.58276367e-02,   3.89709473e-02],
                        [  3.20129395e-02,   3.54003906e-02],
                        [  3.01208496e-02,   3.35083008e-02],
                        [  3.19519043e-02,   3.50341797e-02],
                        [  3.26232910e-02,   3.52478027e-02],
                        [  2.88391113e-02,   3.09143066e-02],
                        [  2.45971680e-02,   2.60009766e-02],
                        [  2.61230469e-02,   2.66113281e-02],
                        [  3.29284668e-02,   3.25622559e-02],
                        [  3.87268066e-02,   3.75976562e-02],
                        [  4.01611328e-02,   3.82995605e-02],
                        [  3.83911133e-02,   3.58886719e-02],
                        [  3.37524414e-02,   3.08227539e-02],
                        [  2.58483887e-02,   2.26745605e-02],
                        [  1.59606934e-02,   1.27258301e-02],
                        [  5.24902344e-03,   2.13623047e-03],
                        [ -4.97436523e-03,  -7.72094727e-03],
                        [ -1.15661621e-02,  -1.37939453e-02],
                        [ -1.44042969e-02,  -1.59912109e-02],
                        [ -1.74255371e-02,  -1.82800293e-02],
                        [ -2.17895508e-02,  -2.18505859e-02],
                        [ -2.50854492e-02,  -2.43835449e-02],
                        [ -2.60620117e-02,  -2.47192383e-02],
                        [ -2.48718262e-02,  -2.29492188e-02],
                        [ -2.13317871e-02,  -1.89514160e-02],
                        [ -1.51367188e-02,  -1.24816895e-02],
                        [ -7.81250000e-03,  -5.03540039e-03],
                        [ -3.60107422e-03,  -8.85009766e-04],
                        [ -5.34057617e-03,  -2.89916992e-03],
                        [ -1.16882324e-02,  -9.61303711e-03],
                        [ -1.99890137e-02,  -1.83715820e-02],
                        [ -2.74963379e-02,  -2.64892578e-02],
                        [ -3.09448242e-02,  -3.05480957e-02],
                        [ -2.87170410e-02,  -2.88696289e-02],
                        [ -2.25830078e-02,  -2.33154297e-02],
                        [ -1.68457031e-02,  -1.80664062e-02],
                        [ -1.48925781e-02,  -1.64184570e-02],
                        [ -1.57470703e-02,  -1.75476074e-02],
                        [ -1.51062012e-02,  -1.70898438e-02],
                        [ -1.06201172e-02,  -1.24816895e-02],
                        [ -5.43212891e-03,  -7.11059570e-03],
                        [ -3.84521484e-03,  -5.34057617e-03],
                        [ -4.51660156e-03,  -5.73730469e-03],
                        [ -2.68554688e-03,  -3.47900391e-03],
                        [  3.29589844e-03,   2.89916992e-03],
                        [  1.09863281e-02,   1.09252930e-02],
                        [  1.60217285e-02,   1.62658691e-02],
                        [  1.51367188e-02,   1.56250000e-02],
                        [  9.49096680e-03,   1.01928711e-02],
                        [  4.18090820e-03,   4.97436523e-03],
                        [  2.16674805e-03,   2.86865234e-03],
                        [  7.01904297e-04,   1.37329102e-03],
                        [ -2.10571289e-03,  -1.55639648e-03],
                        [ -2.10571289e-03,  -1.70898438e-03],
                        [  4.48608398e-03,   4.60815430e-03],
                        [  1.40380859e-02,   1.40075684e-02],
                        [  2.18200684e-02,   2.16979980e-02],
                        [  2.90527344e-02,   2.88085938e-02],
                        [  3.97949219e-02,   3.95202637e-02],
                        [  5.58776855e-02,   5.56945801e-02],
                        [  7.63244629e-02,   7.62939453e-02],
                        [  9.84802246e-02,   9.86022949e-02],
                        [  1.18865967e-01,   1.19232178e-01],
                        [  1.33392334e-01,   1.34063721e-01],
                        [  1.33422852e-01,   1.34368896e-01],
                        [  1.04736328e-01,   1.05834961e-01],
                        [  3.68041992e-02,   3.80554199e-02],
                        [ -6.59484863e-02,  -6.45141602e-02],
                        [ -1.83135986e-01,  -1.81732178e-01],
                        [ -2.85888672e-01,  -2.84759521e-01],
                        [ -3.45672607e-01,  -3.44787598e-01],
                        [ -3.46405029e-01,  -3.45825195e-01],
                        [ -2.99713135e-01,  -2.99682617e-01],
                        [ -2.42950439e-01,  -2.43530273e-01],
                        [ -2.05749512e-01,  -2.06909180e-01],
                        [ -1.83105469e-01,  -1.84814453e-01],
                        [ -1.50817871e-01,  -1.53045654e-01],
                        [ -9.65576172e-02,  -9.93041992e-02],
                        [ -2.77709961e-02,  -3.08227539e-02],
                        [  3.78417969e-02,   3.47595215e-02],
                        [  8.22143555e-02,   7.91931152e-02],
                        [  9.88769531e-02,   9.60693359e-02],
                        [  9.98840332e-02,   9.75646973e-02],
                        [  1.02844238e-01,   1.01287842e-01],
                        [  1.12060547e-01,   1.11328125e-01],
                        [  1.19689941e-01,   1.19873047e-01],
                        [  1.19567871e-01,   1.20758057e-01],
                        [  1.11419678e-01,   1.13647461e-01],
                        [  9.70153809e-02,   1.00158691e-01],
                        [  7.87963867e-02,   8.27026367e-02],
                        [  5.97229004e-02,   6.42700195e-02],
                        [  4.11987305e-02,   4.60815430e-02],
                        [  2.33764648e-02,   2.82897949e-02],
                        [  8.81958008e-03,   1.35192871e-02],
                        [  3.32641602e-03,   7.50732422e-03],
                        [  1.01928711e-02,   1.35498047e-02],
                        [  2.57263184e-02,   2.79541016e-02],
                        [  4.30603027e-02,   4.40368652e-02],
                        [  5.86242676e-02,   5.82580566e-02],
                        [  7.02819824e-02,   6.84814453e-02],
                        [  7.28149414e-02,   6.96105957e-02],
                        [  6.06689453e-02,   5.62133789e-02],
                        [  3.50036621e-02,   2.95715332e-02],
                        [  5.40161133e-03,  -7.32421875e-04],
                        [ -1.70593262e-02,  -2.36206055e-02],
                        [ -2.70385742e-02,  -3.36303711e-02],
                        [ -2.73742676e-02,  -3.35388184e-02],
                        [ -2.57263184e-02,  -3.10974121e-02],
                        [ -2.70385742e-02,  -3.13110352e-02],
                        [ -2.94494629e-02,  -3.23486328e-02],
                        [ -2.94799805e-02,  -3.07312012e-02],
                        [ -2.74963379e-02,  -2.69775391e-02],
                        [ -2.48413086e-02,  -2.25830078e-02],
                        [ -2.02331543e-02,  -1.62963867e-02],
                        [ -1.30615234e-02,  -7.59887695e-03],
                        [ -6.10351562e-03,   5.18798828e-04],
                        [ -3.96728516e-04,   7.04956055e-03],
                        [  7.65991211e-03,   1.55639648e-02],
                        [  1.92260742e-02,   2.70385742e-02],
                        [  2.96936035e-02,   3.69873047e-02],
                        [  3.80554199e-02,   4.44335938e-02],
                        [  4.88281250e-02,   5.38635254e-02],
                        [  6.03027344e-02,   6.36596680e-02],
                        [  6.26220703e-02,   6.40869141e-02],
                        [  5.20324707e-02,   5.14831543e-02],
                        [  3.64685059e-02,   3.39355469e-02],
                        [  2.50549316e-02,   2.06909180e-02],
                        [  2.02331543e-02,   1.41906738e-02],
                        [  2.05078125e-02,   1.31530762e-02],
                        [  2.30102539e-02,   1.47705078e-02],
                        [  2.31323242e-02,   1.44653320e-02],
                        [  1.86767578e-02,   1.00708008e-02],
                        [  1.34887695e-02,   5.49316406e-03],
                        [  1.23901367e-02,   5.46264648e-03],
                        [  1.60827637e-02,   1.05895996e-02],
                        [  2.19421387e-02,   1.82189941e-02],
                        [  2.56652832e-02,   2.39868164e-02],
                        [  2.30407715e-02,   2.34985352e-02],
                        [  1.26037598e-02,   1.51062012e-02],
                        [ -3.63159180e-03,   8.23974609e-04],
                        [ -2.09350586e-02,  -1.47399902e-02],
                        [ -3.41796875e-02,  -2.66418457e-02],
                        [ -4.08935547e-02,  -3.24707031e-02],
                        [ -4.22363281e-02,  -3.34167480e-02],
                        [ -4.22363281e-02,  -3.34777832e-02],
                        [ -4.44946289e-02,  -3.63159180e-02],
                        [ -4.75158691e-02,  -4.04052734e-02],
                        [ -4.71191406e-02,  -4.14733887e-02],
                        [ -4.25415039e-02,  -3.86962891e-02],
                        [ -3.53088379e-02,  -3.34167480e-02],
                        [ -2.55432129e-02,  -2.57263184e-02],
                        [ -1.49841309e-02,  -1.72424316e-02],
                        [ -9.46044922e-03,  -1.36413574e-02],
                        [ -1.17187500e-02,  -1.75170898e-02],
                        [ -1.53198242e-02,  -2.23999023e-02],
                        [ -1.37939453e-02,  -2.17895508e-02],
                        [ -1.04370117e-02,  -1.88598633e-02],
                        [ -1.06506348e-02,  -1.89514160e-02],
                        [ -1.18103027e-02,  -1.95922852e-02],
                        [ -7.99560547e-03,  -1.48315430e-02],
                        [ -3.35693359e-04,  -5.79833984e-03],
                        [  3.78417969e-03,  -3.05175781e-05],
                        [  2.04467773e-03,   3.05175781e-05],
                        [  5.79833984e-04,   4.57763672e-04],
                        [  4.24194336e-03,   6.01196289e-03],
                        [  9.30786133e-03,   1.27868652e-02],
                        [  9.52148438e-03,   1.44653320e-02],
                        [  5.49316406e-03,   1.16577148e-02],
                        [  2.68554688e-03,   9.67407227e-03],
                        [  2.89916992e-03,   1.02233887e-02],
                        [  4.15039062e-03,   1.14746094e-02],
                        [  6.16455078e-03,   1.30615234e-02],
                        [  9.06372070e-03,   1.51367188e-02],
                        [  1.10778809e-02,   1.60217285e-02],
                        [  1.18408203e-02,   1.54418945e-02],
                        [  1.41296387e-02,   1.62353516e-02],
                        [  1.99584961e-02,   2.04467773e-02],
                        [  2.87170410e-02,   2.76184082e-02],
                        [  3.92456055e-02,   3.67431641e-02],
                        [  5.17578125e-02,   4.80041504e-02],
                        [  6.79016113e-02,   6.31103516e-02],
                        [  8.90502930e-02,   8.35876465e-02],
                        [  1.11968994e-01,   1.06170654e-01],
                        [  1.26770020e-01,   1.20880127e-01],
                        [  1.21856689e-01,   1.16241455e-01],
                        [  9.01794434e-02,   8.51440430e-02],
                        [  3.01208496e-02,   2.59399414e-02],
                        [ -5.57556152e-02,  -5.89599609e-02],
                        [ -1.57989502e-01,  -1.60095215e-01],
                        [ -2.55065918e-01,  -2.55981445e-01],
                        [ -3.18664551e-01,  -3.18420410e-01],
                        [ -3.31726074e-01,  -3.30383301e-01],
                        [ -3.00537109e-01,  -2.98248291e-01],
                        [ -2.49877930e-01,  -2.46795654e-01],
                        [ -2.05535889e-01,  -2.01873779e-01],
                        [ -1.76452637e-01,  -1.72424316e-01],
                        [ -1.50726318e-01,  -1.46606445e-01],
                        [ -1.10870361e-01,  -1.06842041e-01],
                        [ -5.30395508e-02,  -4.92553711e-02],
                        [  9.67407227e-03,   1.30004883e-02],
                        [  6.22863770e-02,   6.50329590e-02],
                        [  1.00189209e-01,   1.02264404e-01],
                        [  1.23901367e-01,   1.25274658e-01],
                        [  1.31805420e-01,   1.32446289e-01],
                        [  1.25549316e-01,   1.25488281e-01],
                        [  1.13830566e-01,   1.13128662e-01],
                        [  1.03393555e-01,   1.02142334e-01],
                        [  9.21325684e-02,   9.04235840e-02],
                        [  7.60498047e-02,   7.39746094e-02],
                        [  5.88989258e-02,   5.66101074e-02],
                        [  4.81567383e-02,   4.57458496e-02],
                        [  4.37011719e-02,   4.12597656e-02],
                        [  3.81774902e-02,   3.57666016e-02],
                        [  2.91442871e-02,   2.68554688e-02],
                        [  2.34069824e-02,   2.13317871e-02],
                        [  2.83813477e-02,   2.65808105e-02],
                        [  4.42810059e-02,   4.27551270e-02],
                        [  6.43615723e-02,   6.31408691e-02],
                        [  7.95593262e-02,   7.86743164e-02],
                        [  8.17565918e-02,   8.12072754e-02],
                        [  6.80541992e-02,   6.78710938e-02],
                        [  4.38232422e-02,   4.39758301e-02],
                        [  1.82495117e-02,   1.87377930e-02],
                        [ -2.59399414e-03,  -1.73950195e-03],
                        [ -1.54113770e-02,  -1.41601562e-02],
                        [ -1.77307129e-02,  -1.61437988e-02],
                        [ -1.22985840e-02,  -1.04675293e-02],
                        [ -8.60595703e-03,  -6.53076172e-03],
                        [ -1.33972168e-02,  -1.10778809e-02],
                        [ -2.31628418e-02,  -2.07519531e-02],
                        [ -3.00598145e-02,  -2.76489258e-02],
                        [ -3.08532715e-02,  -2.85034180e-02],
                        [ -2.63061523e-02,  -2.41394043e-02],
                        [ -1.74560547e-02,  -1.55639648e-02],
                        [ -6.34765625e-03,  -4.85229492e-03],
                        [  3.96728516e-03,   4.97436523e-03],
                        [  1.33361816e-02,   1.37329102e-02],
                        [  2.34069824e-02,   2.31628418e-02],
                        [  3.29895020e-02,   3.20739746e-02],
                        [  3.84826660e-02,   3.68652344e-02],
                        [  3.93371582e-02,   3.71093750e-02],
                        [  3.88183594e-02,   3.60412598e-02],
                        [  3.83300781e-02,   3.50952148e-02],
                        [  3.61938477e-02,   3.26843262e-02],
                        [  3.23791504e-02,   2.87780762e-02],
                        [  2.88696289e-02,   2.53295898e-02],
                        [  2.59094238e-02,   2.26440430e-02],
                        [  2.34680176e-02,   2.06909180e-02],
                        [  2.33459473e-02,   2.12707520e-02],
                        [  2.49633789e-02,   2.36511230e-02],
                        [  2.42919922e-02,   2.38647461e-02],
                        [  2.20642090e-02,   2.26440430e-02],
                        [  2.53601074e-02,   2.69165039e-02],
                        [  3.53698730e-02,   3.78417969e-02],
                        [  4.26940918e-02,   4.59899902e-02],
                        [  3.96423340e-02,   4.36401367e-02],
                        [  2.86254883e-02,   3.30505371e-02],
                        [  1.51977539e-02,   1.98059082e-02],
                        [  1.64794922e-03,   6.22558594e-03],
                        [ -1.06201172e-02,  -6.40869141e-03],
                        [ -1.91955566e-02,  -1.55944824e-02],
                        [ -2.27966309e-02,  -1.99890137e-02],
                        [ -2.42004395e-02,  -2.23999023e-02],
                        [ -2.79541016e-02,  -2.73437500e-02],
                        [ -3.35388184e-02,  -3.41186523e-02],
                        [ -3.54309082e-02,  -3.71704102e-02],
                        [ -3.32031250e-02,  -3.61022949e-02],
                        [ -3.23791504e-02,  -3.62854004e-02],
                        [ -3.33251953e-02,  -3.79638672e-02],
                        [ -2.99377441e-02,  -3.50646973e-02],
                        [ -2.17285156e-02,  -2.70690918e-02],
                        [ -1.55944824e-02,  -2.08129883e-02],
                        [ -1.43737793e-02,  -1.91345215e-02],
                        [ -1.34277344e-02,  -1.74255371e-02],
                        [ -1.04675293e-02,  -1.34887695e-02],
                        [ -8.33129883e-03,  -1.01318359e-02],
                        [ -7.41577148e-03,  -7.90405273e-03],
                        [ -5.73730469e-03,  -4.85229492e-03],
                        [ -5.40161133e-03,  -3.17382812e-03],
                        [ -9.27734375e-03,  -5.79833984e-03],
                        [ -1.44958496e-02,  -1.00097656e-02],
                        [ -1.58996582e-02,  -1.06811523e-02],
                        [ -1.27258301e-02,  -7.01904297e-03],
                        [ -7.50732422e-03,  -1.73950195e-03],
                        [ -1.25122070e-03,   4.27246094e-03],
                        [  6.74438477e-03,   1.16577148e-02],
                        [  1.41296387e-02,   1.81274414e-02],
                        [  1.72119141e-02,   2.00500488e-02],
                        [  1.71203613e-02,   1.85852051e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.20239258e-02,   1.05590820e-02],
                        [  3.63159180e-03,   7.62939453e-04],
                        [ -2.65502930e-03,  -6.74438477e-03],
                        [ -1.03759766e-03,  -6.13403320e-03],
                        [  4.97436523e-03,  -7.62939453e-04],
                        [  9.24682617e-03,   3.17382812e-03],
                        [  1.36718750e-02,   7.69042969e-03],
                        [  2.35595703e-02,   1.80053711e-02],
                        [  3.63769531e-02,   3.16162109e-02],
                        [  4.69970703e-02,   4.33044434e-02],
                        [  5.98449707e-02,   5.75256348e-02],
                        [  8.31298828e-02,   8.22753906e-02],
                        [  1.12854004e-01,   1.13525391e-01],
                        [  1.34216309e-01,   1.36444092e-01],
                        [  1.36505127e-01,   1.40106201e-01],
                        [  1.14624023e-01,   1.19354248e-01],
                        [  6.12487793e-02,   6.68640137e-02],
                        [ -2.81677246e-02,  -2.20336914e-02],
                        [ -1.42181396e-01,  -1.35894775e-01],
                        [ -2.51861572e-01,  -2.45849609e-01],
                        [ -3.23883057e-01,  -3.18481445e-01],
                        [ -3.37066650e-01,  -3.32672119e-01],
                        [ -2.96325684e-01,  -2.93182373e-01],
                        [ -2.34252930e-01,  -2.32574463e-01],
                        [ -1.90338135e-01,  -1.90216064e-01],
                        [ -1.77124023e-01,  -1.78588867e-01],
                        [ -1.70043945e-01,  -1.73004150e-01],
                        [ -1.38488770e-01,  -1.42761230e-01],
                        [ -7.96813965e-02,  -8.50219727e-02],
                        [ -1.37023926e-02,  -1.97753906e-02],
                        [  4.25720215e-02,   3.61633301e-02],
                        [  8.40148926e-02,   7.76672363e-02],
                        [  1.09436035e-01,   1.03546143e-01],
                        [  1.18347168e-01,   1.13281250e-01],
                        [  1.14898682e-01,   1.10961914e-01],
                        [  1.07696533e-01,   1.05133057e-01],
                        [  1.03240967e-01,   1.02233887e-01],
                        [  1.00616455e-01,   1.01196289e-01],
                        [  9.43298340e-02,   9.64965820e-02],
                        [  8.20617676e-02,   8.56628418e-02],
                        [  6.79626465e-02,   7.28149414e-02],
                        [  5.68847656e-02,   6.26220703e-02],
                        [  4.73937988e-02,   5.36804199e-02],
                        [  3.65295410e-02,   4.30297852e-02],
                        [  2.76489258e-02,   3.39355469e-02],
                        [  2.69470215e-02,   3.25927734e-02],
                        [  3.59497070e-02,   4.06494141e-02],
                        [  5.05676270e-02,   5.40771484e-02],
                        [  6.24084473e-02,   6.44226074e-02],
                        [  6.23168945e-02,   6.27746582e-02],
                        [  4.72717285e-02,   4.61425781e-02],
                        [  2.16064453e-02,   1.89514160e-02],
                        [ -6.89697266e-03,  -1.08947754e-02],
                        [ -2.87170410e-02,  -3.37829590e-02],
                        [ -3.60717773e-02,  -4.19311523e-02],
                        [ -2.98767090e-02,  -3.61938477e-02],
                        [ -1.92260742e-02,  -2.55737305e-02],
                        [ -1.29699707e-02,  -1.89819336e-02],
                        [ -1.43432617e-02,  -1.96838379e-02],
                        [ -2.17590332e-02,  -2.60925293e-02],
                        [ -3.04260254e-02,  -3.35083008e-02],
                        [ -3.26843262e-02,  -3.43322754e-02],
                        [ -2.19421387e-02,  -2.20947266e-02],
                        [  7.32421875e-04,   2.07519531e-03],
                        [  2.54211426e-02,   2.81677246e-02],
                        [  4.07409668e-02,   4.47387695e-02],
                        [  4.22668457e-02,   4.72412109e-02],
                        [  3.37829590e-02,   3.93981934e-02],
                        [  2.26135254e-02,   2.85644531e-02],
                        [  1.42822266e-02,   2.02331543e-02],
                        [  1.00097656e-02,   1.55639648e-02],
                        [  9.09423828e-03,   1.39770508e-02],
                        [  1.22070312e-02,   1.61743164e-02],
                        [  1.89819336e-02,   2.17590332e-02],
                        [  2.56958008e-02,   2.71606445e-02],
                        [  2.98461914e-02,   2.99682617e-02],
                        [  3.27758789e-02,   3.15551758e-02],
                        [  3.52478027e-02,   3.27758789e-02],
                        [  3.64990234e-02,   3.29589844e-02],
                        [  3.73840332e-02,   3.29895020e-02],
                        [  3.86352539e-02,   3.36608887e-02],
                        [  3.85742188e-02,   3.32946777e-02],
                        [  3.68347168e-02,   3.16162109e-02],
                        [  3.57666016e-02,   3.08227539e-02],
                        [  3.45764160e-02,   3.01818848e-02],
                        [  2.87170410e-02,   2.51464844e-02],
                        [  1.70898438e-02,   1.44958496e-02],
                        [  4.05883789e-03,   2.53295898e-03],
                        [ -6.83593750e-03,  -7.23266602e-03],
                        [ -1.55334473e-02,  -1.47705078e-02],
                        [ -2.28576660e-02,  -2.10876465e-02],
                        [ -2.98767090e-02,  -2.72216797e-02],
                        [ -3.68957520e-02,  -3.34777832e-02],
                        [ -4.26025391e-02,  -3.86657715e-02],
                        [ -4.65698242e-02,  -4.23889160e-02],
                        [ -4.86145020e-02,  -4.43420410e-02],
                        [ -4.60205078e-02,  -4.19006348e-02],
                        [ -3.82690430e-02,  -3.45458984e-02],
                        [ -3.02429199e-02,  -2.70690918e-02],
                        [ -2.49023438e-02,  -2.23693848e-02],
                        [ -2.05078125e-02,  -1.87683105e-02],
                        [ -1.67541504e-02,  -1.58691406e-02],
                        [ -1.50756836e-02,  -1.49536133e-02],
                        [ -1.40991211e-02,  -1.47705078e-02],
                        [ -1.13220215e-02,  -1.27563477e-02],
                        [ -7.59887695e-03,  -9.61303711e-03],
                        [ -5.03540039e-03,  -7.50732422e-03],
                        [ -3.35693359e-03,  -6.22558594e-03],
                        [ -2.10571289e-03,  -5.15747070e-03],
                        [ -4.15039062e-03,  -7.23266602e-03],
                        [ -1.22375488e-02,  -1.52587891e-02],
                        [ -2.24304199e-02,  -2.52380371e-02],
                        [ -2.56652832e-02,  -2.81372070e-02],
                        [ -1.82189941e-02,  -2.02941895e-02],
                        [ -5.64575195e-03,  -7.29370117e-03],
                        [  5.34057617e-03,   4.21142578e-03],
                        [  1.25732422e-02,   1.19628906e-02],
                        [  1.40075684e-02,   1.39160156e-02],
                        [  7.84301758e-03,   8.20922852e-03],
                        [ -1.09863281e-03,  -2.44140625e-04],
                        [ -4.69970703e-03,  -3.41796875e-03],
                        [ -2.38037109e-03,  -7.62939453e-04],
                        [  2.44140625e-04,   2.16674805e-03],
                        [  2.07519531e-03,   4.27246094e-03],
                        [  7.29370117e-03,   9.61303711e-03],
                        [  1.67541504e-02,   1.91955566e-02],
                        [  2.63366699e-02,   2.88085938e-02],
                        [  3.32641602e-02,   3.57055664e-02],
                        [  3.95202637e-02,   4.17785645e-02],
                        [  4.84924316e-02,   5.05676270e-02],
                        [  6.21032715e-02,   6.38732910e-02],
                        [  8.02917480e-02,   8.16650391e-02],
                        [  1.00921631e-01,   1.01867676e-01],
                        [  1.18286133e-01,   1.18713379e-01],
                        [  1.22131348e-01,   1.22039795e-01],
                        [  1.02233887e-01,   1.01531982e-01],
                        [  5.33447266e-02,   5.20629883e-02],
                        [ -2.56347656e-02,  -2.74963379e-02],
                        [ -1.30828857e-01,  -1.33178711e-01],
                        [ -2.42034912e-01,  -2.44873047e-01],
                        [ -3.21655273e-01,  -3.24798584e-01],
                        [ -3.40332031e-01,  -3.43719482e-01],
                        [ -3.04290771e-01,  -3.07708740e-01],
                        [ -2.48107910e-01,  -2.51464844e-01],
                        [ -2.01965332e-01,  -2.05047607e-01],
                        [ -1.72119141e-01,  -1.74774170e-01],
                        [ -1.48773193e-01,  -1.50848389e-01],
                        [ -1.20269775e-01,  -1.21643066e-01],
                        [ -8.01391602e-02,  -8.06579590e-02],
                        [ -3.03955078e-02,  -3.00292969e-02],
                        [  1.97753906e-02,   2.10571289e-02],
                        [  6.25000000e-02,   6.46972656e-02],
                        [  9.59167480e-02,   9.89379883e-02],
                        [  1.20208740e-01,   1.23962402e-01],
                        [  1.34307861e-01,   1.38580322e-01],
                        [  1.38061523e-01,   1.42669678e-01],
                        [  1.33666992e-01,   1.38366699e-01],
                        [  1.22772217e-01,   1.27349854e-01],
                        [  1.05743408e-01,   1.09924316e-01],
                        [  8.50830078e-02,   8.86230469e-02],
                        [  6.65893555e-02,   6.92443848e-02],
                        [  5.55419922e-02,   5.71899414e-02],
                        [  5.26428223e-02,   5.31616211e-02],
                        [  5.42297363e-02,   5.34973145e-02],
                        [  5.60913086e-02,   5.41687012e-02],
                        [  5.57250977e-02,   5.26428223e-02],
                        [  5.17883301e-02,   4.76989746e-02],
                        [  4.49829102e-02,   4.00695801e-02],
                        [  3.76281738e-02,   3.21960449e-02],
                        [  2.94799805e-02,   2.37731934e-02],
                        [  1.72729492e-02,   1.15966797e-02],
                        [  1.40380859e-03,  -3.90625000e-03],
                        [ -1.15661621e-02,  -1.62048340e-02],
                        [ -1.59606934e-02,  -1.96533203e-02],
                        [ -1.25732422e-02,  -1.51367188e-02],
                        [ -6.62231445e-03,  -7.84301758e-03],
                        [ -2.83813477e-03,  -2.62451172e-03],
                        [ -4.57763672e-03,  -2.96020508e-03],
                        [ -1.27868652e-02,  -9.82666016e-03],
                        [ -2.29797363e-02,  -1.87988281e-02],
                        [ -2.78015137e-02,  -2.26745605e-02],
                        [ -2.43835449e-02,  -1.85546875e-02],
                        [ -1.49536133e-02,  -8.69750977e-03],
                        [ -2.86865234e-03,   3.38745117e-03],
                        [  8.36181641e-03,   1.43127441e-02],
                        [  1.68151855e-02,   2.20947266e-02],
                        [  2.29797363e-02,   2.73437500e-02],
                        [  2.70996094e-02,   3.02429199e-02],
                        [  2.85339355e-02,   3.03039551e-02],
                        [  2.93884277e-02,   2.96630859e-02],
                        [  3.25317383e-02,   3.13110352e-02],
                        [  3.67736816e-02,   3.40881348e-02],
                        [  3.81164551e-02,   3.41796875e-02],
                        [  3.63464355e-02,   3.13720703e-02],
                        [  3.53393555e-02,   2.95410156e-02],
                        [  3.74450684e-02,   3.12194824e-02],
                        [  4.08630371e-02,   3.45764160e-02],
                        [  4.29992676e-02,   3.69567871e-02],
                        [  4.31213379e-02,   3.76892090e-02],
                        [  4.16870117e-02,   3.71398926e-02],
                        [  3.93981934e-02,   3.60412598e-02],
                        [  3.70178223e-02,   3.49731445e-02],
                        [  3.41796875e-02,   3.35693359e-02],
                        [  3.03039551e-02,   3.11584473e-02],
                        [  2.60620117e-02,   2.82897949e-02],
                        [  2.24609375e-02,   2.59399414e-02],
                        [  1.82189941e-02,   2.27355957e-02],
                        [  1.05285645e-02,   1.57775879e-02],
                        [ -3.35693359e-04,   5.34057617e-03],
                        [ -1.00402832e-02,  -4.24194336e-03],
                        [ -1.55639648e-02,  -9.97924805e-03],
                        [ -1.91040039e-02,  -1.40686035e-02],
                        [ -2.46276855e-02,  -2.03857422e-02],
                        [ -3.19519043e-02,  -2.87475586e-02],
                        [ -3.76586914e-02,  -3.56445312e-02],
                        [ -3.97949219e-02,  -3.90319824e-02],
                        [ -3.90014648e-02,  -3.95202637e-02],
                        [ -3.62243652e-02,  -3.79943848e-02],
                        [ -3.17687988e-02,  -3.45764160e-02],
                        [ -2.63671875e-02,  -3.00598145e-02],
                        [ -2.17895508e-02,  -2.61535645e-02],
                        [ -1.91650391e-02,  -2.38952637e-02],
                        [ -1.76391602e-02,  -2.24304199e-02],
                        [ -1.55334473e-02,  -2.01721191e-02],
                        [ -1.23291016e-02,  -1.65100098e-02],
                        [ -7.99560547e-03,  -1.15051270e-02],
                        [ -4.15039062e-03,  -6.80541992e-03],
                        [ -3.54003906e-03,  -5.24902344e-03],
                        [ -5.58471680e-03,  -6.28662109e-03],
                        [ -6.98852539e-03,  -6.65283203e-03],
                        [ -8.02612305e-03,  -6.80541992e-03],
                        [ -1.04370117e-02,  -8.36181641e-03],
                        [ -1.12915039e-02,  -8.51440430e-03],
                        [ -7.99560547e-03,  -4.82177734e-03],
                        [ -3.63159180e-03,  -1.83105469e-04],
                        [ -1.22070312e-03,   2.28881836e-03],
                        [  8.23974609e-04,   4.11987305e-03],
                        [  4.82177734e-03,   7.75146484e-03],
                        [  9.70458984e-03,   1.21459961e-02],
                        [  1.22985840e-02,   1.41296387e-02],
                        [  1.11999512e-02,   1.22985840e-02],
                        [  8.27026367e-03,   8.69750977e-03],
                        [  6.59179688e-03,   6.37817383e-03],
                        [  6.92749023e-03,   6.10351562e-03],
                        [  7.14111328e-03,   5.79833984e-03],
                        [  6.77490234e-03,   5.06591797e-03],
                        [  9.91821289e-03,   7.99560547e-03],
                        [  1.99890137e-02,   1.79748535e-02],
                        [  3.46679688e-02,   3.27148438e-02],
                        [  5.05676270e-02,   4.87976074e-02],
                        [  6.85119629e-02,   6.70166016e-02],
                        [  9.06066895e-02,   8.94470215e-02],
                        [  1.14868164e-01,   1.14135742e-01],
                        [  1.34429932e-01,   1.34094238e-01],
                        [  1.39892578e-01,   1.39892578e-01],
                        [  1.21826172e-01,   1.22131348e-01],
                        [  7.24182129e-02,   7.29675293e-02],
                        [ -1.16271973e-02,  -1.09558105e-02],
                        [ -1.22985840e-01,  -1.22253418e-01],
                        [ -2.37915039e-01,  -2.37182617e-01],
                        [ -3.20220947e-01,  -3.19641113e-01],
                        [ -3.41094971e-01,  -3.40698242e-01],
                        [ -3.02734375e-01,  -3.02520752e-01],
                        [ -2.40997314e-01,  -2.41027832e-01],
                        [ -1.96411133e-01,  -1.96655273e-01],
                        [ -1.79992676e-01,  -1.80419922e-01],
                        [ -1.70959473e-01,  -1.71478271e-01],
                        [ -1.44714355e-01,  -1.45263672e-01],
                        [ -9.68627930e-02,  -9.73815918e-02],
                        [ -4.01306152e-02,  -4.05273438e-02],
                        [  1.37329102e-02,   1.35192871e-02],
                        [  6.21643066e-02,   6.22253418e-02],
                        [  1.04309082e-01,   1.04644775e-01],
                        [  1.34399414e-01,   1.35040283e-01],
                        [  1.47064209e-01,   1.48040771e-01],
                        [  1.43585205e-01,   1.44836426e-01],
                        [  1.30798340e-01,   1.32202148e-01],
                        [  1.17187500e-01,   1.18713379e-01],
                        [  1.07330322e-01,   1.08856201e-01],
                        [  9.78088379e-02,   9.91821289e-02],
                        [  8.37402344e-02,   8.49304199e-02],
                        [  6.81152344e-02,   6.89392090e-02],
                        [  5.82275391e-02,   5.86242676e-02],
                        [  5.62438965e-02,   5.61523438e-02],
                        [  5.71289062e-02,   5.65490723e-02],
                        [  5.47180176e-02,   5.35583496e-02],
                        [  4.67529297e-02,   4.51354980e-02],
                        [  3.39965820e-02,   3.19519043e-02],
                        [  1.65405273e-02,   1.41906738e-02],
                        [ -4.60815430e-03,  -7.14111328e-03],
                        [ -2.36206055e-02,  -2.61535645e-02],
                        [ -3.14331055e-02,  -3.38439941e-02],
                        [ -2.41699219e-02,  -2.63366699e-02],
                        [ -9.09423828e-03,  -1.08032227e-02],
                        [  1.80053711e-03,   6.40869141e-04],
                        [  3.87573242e-03,   3.35693359e-03],
                        [  1.58691406e-03,   1.73950195e-03],
                        [ -1.22070312e-03,  -3.05175781e-04],
                        [ -5.58471680e-03,  -3.96728516e-03],
                        [ -1.15661621e-02,  -9.36889648e-03],
                        [ -1.40075684e-02,  -1.13220215e-02],
                        [ -8.39233398e-03,  -5.34057617e-03],
                        [  2.74658203e-03,   5.98144531e-03],
                        [  1.38549805e-02,   1.70898438e-02],
                        [  2.18505859e-02,   2.49023438e-02],
                        [  2.45056152e-02,   2.71911621e-02],
                        [  2.05383301e-02,   2.26745605e-02],
                        [  1.43737793e-02,   1.58386230e-02],
                        [  1.29699707e-02,   1.36718750e-02],
                        [  1.72729492e-02,   1.71508789e-02],
                        [  2.24304199e-02,   2.15454102e-02],
                        [  2.57568359e-02,   2.40783691e-02],
                        [  2.88696289e-02,   2.65197754e-02],
                        [  3.34777832e-02,   3.05786133e-02],
                        [  3.78723145e-02,   3.45764160e-02],
                        [  3.93371582e-02,   3.58276367e-02],
                        [  3.81469727e-02,   3.46679688e-02],
                        [  3.72009277e-02,   3.39355469e-02],
                        [  3.81164551e-02,   3.52172852e-02],
                        [  3.94592285e-02,   3.71093750e-02],
                        [  3.86352539e-02,   3.69873047e-02],
                        [  3.38745117e-02,   3.29589844e-02],
                        [  2.52990723e-02,   2.51770020e-02],
                        [  1.64184570e-02,   1.71203613e-02],
                        [  1.08337402e-02,   1.22985840e-02],
                        [  6.56127930e-03,   8.66699219e-03],
                        [ -3.66210938e-04,   2.31933594e-03],
                        [ -8.30078125e-03,  -5.24902344e-03],
                        [ -1.26342773e-02,  -9.36889648e-03],
                        [ -1.29089355e-02,  -9.64355469e-03],
                        [ -1.21765137e-02,  -9.00268555e-03],
                        [ -1.24206543e-02,  -9.61303711e-03],
                        [ -1.47705078e-02,  -1.24511719e-02],
                        [ -2.02026367e-02,  -1.84326172e-02],
                        [ -2.83203125e-02,  -2.71911621e-02],
                        [ -3.71093750e-02,  -3.67126465e-02],
                        [ -4.38842773e-02,  -4.41894531e-02],
                        [ -4.56237793e-02,  -4.65698242e-02],
                        [ -4.09545898e-02,  -4.25109863e-02],
                        [ -3.27758789e-02,  -3.48510742e-02],
                        [ -2.54516602e-02,  -2.78320312e-02],
                        [ -2.04467773e-02,  -2.30407715e-02],
                        [ -1.69372559e-02,  -1.96228027e-02],
                        [ -1.37329102e-02,  -1.63574219e-02],
                        [ -9.70458984e-03,  -1.21154785e-02],
                        [ -6.22558594e-03,  -8.33129883e-03],
                        [ -7.50732422e-03,  -9.18579102e-03],
                        [ -1.44653320e-02,  -1.56555176e-02],
                        [ -2.19421387e-02,  -2.26440430e-02],
                        [ -2.45971680e-02,  -2.48107910e-02],
                        [ -2.22167969e-02,  -2.19116211e-02],
                        [ -1.69677734e-02,  -1.62048340e-02],
                        [ -9.97924805e-03,  -8.85009766e-03],
                        [ -3.66210938e-03,  -2.22778320e-03],
                        [ -3.14331055e-03,  -1.49536133e-03],
                        [ -9.55200195e-03,  -7.78198242e-03],
                        [ -1.49841309e-02,  -1.31835938e-02],
                        [ -1.15661621e-02,  -9.79614258e-03],
                        [ -2.50244141e-03,  -8.85009766e-04],
                        [  3.08227539e-03,   4.54711914e-03],
                        [  3.78417969e-03,   5.03540039e-03],
                        [  5.21850586e-03,   6.19506836e-03],
                        [  8.30078125e-03,   9.00268555e-03],
                        [  9.06372070e-03,   9.49096680e-03],
                        [  7.99560547e-03,   8.17871094e-03],
                        [  9.15527344e-03,   9.09423828e-03],
                        [  1.32446289e-02,   1.29394531e-02],
                        [  2.02331543e-02,   1.97448730e-02],
                        [  3.18603516e-02,   3.12194824e-02],
                        [  4.78820801e-02,   4.70581055e-02],
                        [  6.73217773e-02,   6.63757324e-02],
                        [  9.24987793e-02,   9.14611816e-02],
                        [  1.22619629e-01,   1.21490479e-01],
                        [  1.46301270e-01,   1.45141602e-01],
                        [  1.48590088e-01,   1.47399902e-01],
                        [  1.21490479e-01,   1.20300293e-01],
                        [  6.25610352e-02,   6.13708496e-02],
                        [ -2.91442871e-02,  -3.02429199e-02],
                        [ -1.44195557e-01,  -1.45233154e-01],
                        [ -2.54211426e-01,  -2.55096436e-01],
                        [ -3.23364258e-01,  -3.24066162e-01],
                        [ -3.32794189e-01,  -3.33282471e-01],
                        [ -2.93212891e-01,  -2.93426514e-01],
                        [ -2.36328125e-01,  -2.36236572e-01],
                        [ -1.93023682e-01,  -1.92596436e-01],
                        [ -1.73095703e-01,  -1.72363281e-01],
                        [ -1.62017822e-01,  -1.60980225e-01],
                        [ -1.39099121e-01,  -1.37725830e-01],
                        [ -9.82360840e-02,  -9.65881348e-02],
                        [ -4.74548340e-02,  -4.56237793e-02],
                        [  6.31713867e-03,   8.30078125e-03],
                        [  5.95397949e-02,   6.15844727e-02],
                        [  1.03668213e-01,   1.05621338e-01],
                        [  1.28906250e-01,   1.30737305e-01],
                        [  1.35742188e-01,   1.37298584e-01],
                        [  1.33056641e-01,   1.34246826e-01],
                        [  1.28417969e-01,   1.29150391e-01],
                        [  1.23016357e-01,   1.23229980e-01],
                        [  1.12915039e-01,   1.12579346e-01],
                        [  9.59777832e-02,   9.50622559e-02],
                        [  7.99560547e-02,   7.84912109e-02],
                        [  7.63854980e-02,   7.44323730e-02],
                        [  8.33740234e-02,   8.09631348e-02],
                        [  8.55102539e-02,   8.27941895e-02],
                        [  7.40966797e-02,   7.12585449e-02],
                        [  5.42907715e-02,   5.14221191e-02],
                        [  3.20739746e-02,   2.93579102e-02],
                        [  8.14819336e-03,   5.73730469e-03],
                        [ -1.51672363e-02,  -1.71203613e-02],
                        [ -3.16772461e-02,  -3.30505371e-02],
                        [ -3.62854004e-02,  -3.69567871e-02],
                        [ -2.89001465e-02,  -2.88391113e-02],
                        [ -1.52893066e-02,  -1.44958496e-02],
                        [ -3.99780273e-03,  -2.44140625e-03],
                        [  3.05175781e-05,   2.28881836e-03],
                        [ -9.46044922e-04,   1.83105469e-03],
                        [ -1.22070312e-03,   2.01416016e-03],
                        [  3.35693359e-04,   3.81469727e-03],
                        [ -1.06811523e-03,   2.44140625e-03],
                        [ -6.28662109e-03,  -2.92968750e-03],
                        [ -7.50732422e-03,  -4.48608398e-03],
                        [  9.15527344e-04,   3.38745117e-03],
                        [  1.31530762e-02,   1.49536133e-02],
                        [  1.95312500e-02,   2.05078125e-02],
                        [  1.86767578e-02,   1.87988281e-02],
                        [  1.71203613e-02,   1.63269043e-02],
                        [  1.96838379e-02,   1.80358887e-02],
                        [  2.49023438e-02,   2.24609375e-02],
                        [  2.81677246e-02,   2.50854492e-02],
                        [  2.77099609e-02,   2.41394043e-02],
                        [  2.62451172e-02,   2.24304199e-02],
                        [  2.71301270e-02,   2.32238770e-02],
                        [  3.02734375e-02,   2.65502930e-02],
                        [  3.48205566e-02,   3.15246582e-02],
                        [  4.04052734e-02,   3.77197266e-02],
                        [  4.38842773e-02,   4.19311523e-02],
                        [  4.13208008e-02,   4.02526855e-02],
                        [  3.49731445e-02,   3.48815918e-02],
                        [  3.04565430e-02,   3.13110352e-02],
                        [  2.78320312e-02,   2.96325684e-02],
                        [  2.26135254e-02,   2.52075195e-02],
                        [  1.44653320e-02,   1.77307129e-02],
                        [  8.69750977e-03,   1.24206543e-02],
                        [  7.47680664e-03,   1.14746094e-02],
                        [  5.82885742e-03,   9.85717773e-03],
                        [  3.66210938e-04,   4.15039062e-03],
                        [ -4.91333008e-03,  -1.55639648e-03],
                        [ -6.28662109e-03,  -3.60107422e-03],
                        [ -5.73730469e-03,  -3.87573242e-03],
                        [ -4.42504883e-03,  -3.50952148e-03],
                        [ -1.49536133e-03,  -1.52587891e-03],
                        [ -5.79833984e-04,  -1.61743164e-03],
                        [ -6.95800781e-03,  -8.91113281e-03],
                        [ -1.75781250e-02,  -2.02941895e-02],
                        [ -2.49938965e-02,  -2.83508301e-02],
                        [ -2.81982422e-02,  -3.19824219e-02],
                        [ -2.94189453e-02,  -3.34167480e-02],
                        [ -2.81677246e-02,  -3.21044922e-02],
                        [ -2.62451172e-02,  -2.99072266e-02],
                        [ -2.83203125e-02,  -3.14941406e-02],
                        [ -3.32336426e-02,  -3.56750488e-02],
                        [ -3.50341797e-02,  -3.66516113e-02],
                        [ -3.34777832e-02,  -3.41491699e-02],
                        [ -3.18908691e-02,  -3.15856934e-02],
                        [ -2.90527344e-02,  -2.78015137e-02],
                        [ -2.31628418e-02,  -2.10266113e-02],
                        [ -1.68457031e-02,  -1.39770508e-02],
                        [ -1.13525391e-02,  -7.93457031e-03],
                        [ -4.15039062e-03,  -3.96728516e-04],
                        [  3.02124023e-03,   6.86645508e-03],
                        [  4.39453125e-03,   8.11767578e-03],
                        [  1.83105469e-04,   3.60107422e-03],
                        [ -3.99780273e-03,  -1.19018555e-03],
                        [ -6.43920898e-03,  -4.33349609e-03],
                        [ -9.09423828e-03,  -7.84301758e-03],
                        [ -1.19323730e-02,  -1.15966797e-02],
                        [ -1.27258301e-02,  -1.33666992e-02],
                        [ -9.97924805e-03,  -1.15051270e-02],
                        [ -4.27246094e-03,  -6.56127930e-03],
                        [  1.25122070e-03,  -1.70898438e-03],
                        [  3.29589844e-03,  -1.52587891e-04],
                        [  3.29589844e-03,  -3.66210938e-04],
                        [  6.16455078e-03,   2.47192383e-03],
                        [  1.19018555e-02,   8.39233398e-03],
                        [  1.54418945e-02,   1.23596191e-02],
                        [  1.55639648e-02,   1.31225586e-02],
                        [  1.55029297e-02,   1.37634277e-02],
                        [  1.68151855e-02,   1.58996582e-02],
                        [  2.17895508e-02,   2.18200684e-02],
                        [  3.56140137e-02,   3.65295410e-02],
                        [  5.99975586e-02,   6.17065430e-02],
                        [  9.10339355e-02,   9.34753418e-02],
                        [  1.22344971e-01,   1.25366211e-01],
                        [  1.45202637e-01,   1.48559570e-01],
                        [  1.49078369e-01,   1.52618408e-01],
                        [  1.24481201e-01,   1.27990723e-01],
                        [  6.41479492e-02,   6.73828125e-02],
                        [ -3.29589844e-02,  -3.02124023e-02],
                        [ -1.53259277e-01,  -1.51062012e-01],
                        [ -2.64892578e-01,  -2.63427734e-01],
                        [ -3.31146240e-01,  -3.30535889e-01],
                        [ -3.33892822e-01,  -3.34136963e-01],
                        [ -2.87231445e-01,  -2.88238525e-01],
                        [ -2.27264404e-01,  -2.29064941e-01],
                        [ -1.86096191e-01,  -1.88537598e-01],
                        [ -1.70837402e-01,  -1.73736572e-01],
                        [ -1.65771484e-01,  -1.69006348e-01],
                        [ -1.51428223e-01,  -1.54815674e-01],
                        [ -1.18499756e-01,  -1.21765137e-01],
                        [ -6.92749023e-02,  -7.22656250e-02],
                        [ -1.11083984e-02,  -1.37023926e-02],
                        [  5.07812500e-02,   4.87670898e-02],
                        [  1.10290527e-01,   1.09008789e-01],
                        [  1.52618408e-01,   1.52069092e-01],
                        [  1.64764404e-01,   1.64947510e-01],
                        [  1.53839111e-01,   1.54846191e-01],
                        [  1.38488770e-01,   1.40167236e-01],
                        [  1.25793457e-01,   1.28021240e-01],
                        [  1.12548828e-01,   1.15295410e-01],
                        [  1.01226807e-01,   1.04248047e-01],
                        [  9.73205566e-02,   1.00463867e-01],
                        [  9.85107422e-02,   1.01623535e-01],
                        [  9.73205566e-02,   1.00219727e-01],
                        [  8.84399414e-02,   9.09423828e-02],
                        [  6.79016113e-02,   6.98852539e-02],
                        [  3.48205566e-02,   3.62243652e-02],
                        [ -3.66210938e-03,  -2.92968750e-03],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -5.23376465e-02,  -5.30395508e-02],
                        [ -4.92858887e-02,  -5.05981445e-02],
                        [ -2.92358398e-02,  -3.11279297e-02],
                        [ -4.88281250e-03,  -7.23266602e-03],
                        [  9.15527344e-03,   6.46972656e-03],
                        [  1.04064941e-02,   7.53784180e-03],
                        [  7.90405273e-03,   4.97436523e-03],
                        [  6.80541992e-03,   3.99780273e-03],
                        [  4.54711914e-03,   2.01416016e-03],
                        [  5.49316406e-04,  -1.58691406e-03],
                        [ -1.06811523e-03,  -2.77709961e-03],
                        [  2.34985352e-03,   1.22070312e-03],
                        [  1.11999512e-02,   1.07116699e-02],
                        [  2.34069824e-02,   2.34985352e-02],
                        [  3.26232910e-02,   3.33557129e-02],
                        [  3.37219238e-02,   3.50036621e-02],
                        [  2.93884277e-02,   3.11889648e-02],
                        [  2.61230469e-02,   2.83203125e-02],
                        [  2.61840820e-02,   2.86865234e-02],
                        [  2.74047852e-02,   3.00903320e-02],
                        [  2.70996094e-02,   2.98156738e-02],
                        [  2.45361328e-02,   2.71606445e-02],
                        [  2.24609375e-02,   2.48718262e-02],
                        [  2.57263184e-02,   2.78625488e-02],
                        [  3.51562500e-02,   3.68652344e-02],
                        [  4.44335938e-02,   4.56542969e-02],
                        [  4.72412109e-02,   4.79125977e-02],
                        [  4.42504883e-02,   4.43725586e-02],
                        [  4.04357910e-02,   3.99475098e-02],
                        [  3.87573242e-02,   3.77197266e-02],
                        [  3.80859375e-02,   3.65600586e-02],
                        [  3.47900391e-02,   3.27758789e-02],
                        [  2.71606445e-02,   2.47802734e-02],
                        [  1.79138184e-02,   1.53198242e-02],
                        [  1.04064941e-02,   7.65991211e-03],
                        [  5.27954102e-03,   2.47192383e-03],
                        [  2.07519531e-03,  -5.79833984e-04],
                        [  5.49316406e-04,  -1.89208984e-03],
                        [ -1.40380859e-03,  -3.54003906e-03],
                        [ -6.22558594e-03,  -7.87353516e-03],
                        [ -1.42517090e-02,  -1.53198242e-02],
                        [ -2.48413086e-02,  -2.53601074e-02],
                        [ -3.60107422e-02,  -3.58886719e-02],
                        [ -4.27551270e-02,  -4.19616699e-02],
                        [ -4.15344238e-02,  -4.01000977e-02],
                        [ -3.43933105e-02,  -3.24096680e-02],
                        [ -2.55432129e-02,  -2.30712891e-02],
                        [ -1.74255371e-02,  -1.45263672e-02],
                        [ -1.15966797e-02,  -8.48388672e-03],
                        [ -9.03320312e-03,  -5.79833984e-03],
                        [ -9.46044922e-03,  -6.22558594e-03],
                        [ -1.30920410e-02,  -1.00708008e-02],
                        [ -1.99279785e-02,  -1.72729492e-02],
                        [ -2.67944336e-02,  -2.45971680e-02],
                        [ -2.92358398e-02,  -2.76489258e-02],
                        [ -2.69470215e-02,  -2.60925293e-02],
                        [ -2.33459473e-02,  -2.32543945e-02],
                        [ -2.02636719e-02,  -2.09350586e-02],
                        [ -1.77917480e-02,  -1.92871094e-02],
                        [ -1.67541504e-02,  -1.90124512e-02],
                        [ -1.60522461e-02,  -1.89208984e-02],
                        [ -1.31530762e-02,  -1.65100098e-02],
                        [ -9.27734375e-03,  -1.30310059e-02],
                        [ -7.23266602e-03,  -1.11694336e-02],
                        [ -5.67626953e-03,  -9.55200195e-03],
                        [ -3.63159180e-03,  -7.32421875e-03],
                        [ -4.69970703e-03,  -7.93457031e-03],
                        [ -9.67407227e-03,  -1.22985840e-02],
                        [ -1.28173828e-02,  -1.47094727e-02],
                        [ -1.01013184e-02,  -1.11389160e-02],
                        [ -4.33349609e-03,  -4.39453125e-03],
                        [  9.15527344e-05,   1.03759766e-03],
                        [  2.47192383e-03,   4.33349609e-03],
                        [  4.11987305e-03,   6.86645508e-03],
                        [  5.61523438e-03,   9.12475586e-03],
                        [  6.83593750e-03,   1.08947754e-02],
                        [  7.99560547e-03,   1.24511719e-02],
                        [  9.79614258e-03,   1.44042969e-02],
                        [  1.40075684e-02,   1.85241699e-02],
                        [  2.28271484e-02,   2.70080566e-02],
                        [  3.61022949e-02,   3.97033691e-02],
                        [  5.18188477e-02,   5.46569824e-02],
                        [  6.89086914e-02,   7.08007812e-02],
                        [  8.66699219e-02,   8.74938965e-02],
                        [  1.02752686e-01,   1.02447510e-01],
                        [  1.12518311e-01,   1.11114502e-01],
                        [  1.08673096e-01,   1.06201172e-01],
                        [  8.25195312e-02,   7.91015625e-02],
                        [  2.90222168e-02,   2.48107910e-02],
                        [ -4.97131348e-02,  -5.44433594e-02],
                        [ -1.43737793e-01,  -1.48803711e-01],
                        [ -2.34252930e-01,  -2.39379883e-01],
                        [ -2.94799805e-01,  -2.99652100e-01],
                        [ -3.04992676e-01,  -3.09356689e-01],
                        [ -2.70538330e-01,  -2.74169922e-01],
                        [ -2.22900391e-01,  -2.25555420e-01],
                        [ -1.90124512e-01,  -1.91680908e-01],
                        [ -1.73065186e-01,  -1.73431396e-01],
                        [ -1.54968262e-01,  -1.54083252e-01],
                        [ -1.25579834e-01,  -1.23504639e-01],
                        [ -8.84704590e-02,  -8.53271484e-02],
                        [ -4.96215820e-02,  -4.55627441e-02],
                        [ -7.65991211e-03,  -2.86865234e-03],
                        [  4.12292480e-02,   4.64477539e-02],
                        [  9.23767090e-02,   9.77783203e-02],
                        [  1.32934570e-01,   1.38183594e-01],
                        [  1.53076172e-01,   1.57897949e-01],
                        [  1.54296875e-01,   1.58477783e-01],
                        [  1.45507812e-01,   1.48773193e-01],
                        [  1.34338379e-01,   1.36535645e-01],
                        [  1.24206543e-01,   1.25183105e-01],
                        [  1.15875244e-01,   1.15600586e-01],
                        [  1.08489990e-01,   1.06964111e-01],
                        [  1.00769043e-01,   9.80834961e-02],
                        [  9.13085938e-02,   8.76159668e-02],
                        [  7.68737793e-02,   7.23876953e-02],
                        [  5.42297363e-02,   4.91943359e-02],
                        [  2.41088867e-02,   1.87988281e-02],
                        [ -8.88061523e-03,  -1.41906738e-02],
                        [ -3.74755859e-02,  -4.24804688e-02],
                        [ -5.39245605e-02,  -5.83801270e-02],
                        [ -5.50231934e-02,  -5.86547852e-02],
                        [ -4.28771973e-02,  -4.55017090e-02],
                        [ -2.25830078e-02,  -2.40783691e-02],
                        [ -3.20434570e-03,  -3.50952148e-03],
                        [  6.13403320e-03,   7.08007812e-03],
                        [  5.58471680e-03,   7.65991211e-03],
                        [  2.99072266e-03,   6.10351562e-03],
                        [  2.34985352e-03,   6.31713867e-03],
                        [  1.52587891e-03,   6.10351562e-03],
                        [  4.57763672e-04,   5.40161133e-03],
                        [  3.23486328e-03,   8.27026367e-03],
                        [  1.14135742e-02,   1.62963867e-02],
                        [  2.26135254e-02,   2.70385742e-02],
                        [  3.35083008e-02,   3.72619629e-02],
                        [  3.96118164e-02,   4.25109863e-02],
                        [  3.72619629e-02,   3.91540527e-02],
                        [  2.97851562e-02,   3.05480957e-02],
                        [  2.48107910e-02,   2.45056152e-02],
                        [  2.47497559e-02,   2.33459473e-02],
                        [  2.66418457e-02,   2.42614746e-02],
                        [  2.95715332e-02,   2.63366699e-02],
                        [  3.47290039e-02,   3.08532715e-02],
                        [  4.10156250e-02,   3.67126465e-02],
                        [  4.61120605e-02,   4.16259766e-02],
                        [  4.90112305e-02,   4.45861816e-02],
                        [  4.90417480e-02,   4.48913574e-02],
                        [  4.62036133e-02,   4.25720215e-02],
                        [  4.32128906e-02,   4.02526855e-02],
                        [  4.21447754e-02,   4.00390625e-02],
                        [  4.05578613e-02,   3.93371582e-02],
                        [  3.51562500e-02,   3.49121094e-02],
                        [  2.74963379e-02,   2.81982422e-02],
                        [  2.13928223e-02,   2.29797363e-02],
                        [  1.79748535e-02,   2.03552246e-02],
                        [  1.61132812e-02,   1.91345215e-02],
                        [  1.52282715e-02,   1.86767578e-02],
                        [  1.31225586e-02,   1.68457031e-02],
                        [  5.24902344e-03,   9.03320312e-03],
                        [ -8.97216797e-03,  -5.34057617e-03],
                        [ -2.31323242e-02,  -1.98059082e-02],
                        [ -3.13720703e-02,  -2.85339355e-02],
                        [ -3.42712402e-02,  -3.20434570e-02],
                        [ -3.46374512e-02,  -3.31420898e-02],
                        [ -3.28979492e-02,  -3.21655273e-02],
                        [ -2.80456543e-02,  -2.80761719e-02],
                        [ -2.08740234e-02,  -2.16979980e-02],
                        [ -1.36413574e-02,  -1.51062012e-02],
                        [ -8.27026367e-03,  -1.03149414e-02],
                        [ -6.71386719e-03,  -9.24682617e-03],
                        [ -9.76562500e-03,  -1.26342773e-02],
                        [ -1.50756836e-02,  -1.80664062e-02],
                        [ -1.90429688e-02,  -2.20642090e-02],
                        [ -2.00805664e-02,  -2.29492188e-02],
                        [ -1.87988281e-02,  -2.13623047e-02],
                        [ -1.74255371e-02,  -1.95922852e-02],
                        [ -1.81274414e-02,  -1.98059082e-02],
                        [ -1.98364258e-02,  -2.09350586e-02],
                        [ -1.92565918e-02,  -1.97753906e-02],
                        [ -1.51977539e-02,  -1.51367188e-02],
                        [ -9.85717773e-03,  -9.24682617e-03],
                        [ -6.95800781e-03,  -5.79833984e-03],
                        [ -7.44628906e-03,  -5.85937500e-03],
                        [ -7.50732422e-03,  -5.55419922e-03],
                        [ -2.86865234e-03,  -6.71386719e-04],
                        [  3.99780273e-03,   6.31713867e-03],
                        [  5.24902344e-03,   7.56835938e-03],
                        [ -1.64794922e-03,   5.79833984e-04],
                        [ -1.03454590e-02,  -8.30078125e-03],
                        [ -1.40075684e-02,  -1.22375488e-02],
                        [ -1.19018555e-02,  -1.04980469e-02],
                        [ -7.14111328e-03,  -6.16455078e-03],
                        [ -3.17382812e-03,  -2.62451172e-03],
                        [ -1.52587891e-04,  -6.10351562e-05],
                        [  5.31005859e-03,   4.94384766e-03],
                        [  1.30004883e-02,   1.22680664e-02],
                        [  1.76696777e-02,   1.65405273e-02],
                        [  1.90124512e-02,   1.75781250e-02],
                        [  2.37426758e-02,   2.21252441e-02],
                        [  3.42712402e-02,   3.24707031e-02],
                        [  4.44946289e-02,   4.26025391e-02],
                        [  5.02319336e-02,   4.84008789e-02],
                        [  5.63964844e-02,   5.46875000e-02],
                        [  7.00378418e-02,   6.84814453e-02],
                        [  9.07592773e-02,   8.94470215e-02],
                        [  1.10046387e-01,   1.09039307e-01],
                        [  1.14776611e-01,   1.14105225e-01],
                        [  9.20104980e-02,   9.16748047e-02],
                        [  3.62854004e-02,   3.63464355e-02],
                        [ -4.80346680e-02,  -4.76074219e-02],
                        [ -1.48132324e-01,  -1.47369385e-01],
                        [ -2.40875244e-01,  -2.39807129e-01],
                        [ -2.97271729e-01,  -2.95928955e-01],
                        [ -3.00415039e-01,  -2.98889160e-01],
                        [ -2.60101318e-01,  -2.58453369e-01],
                        [ -2.07244873e-01,  -2.05566406e-01],
                        [ -1.71325684e-01,  -1.69677734e-01],
                        [ -1.58966064e-01,  -1.57440186e-01],
                        [ -1.55334473e-01,  -1.54022217e-01],
                        [ -1.44165039e-01,  -1.43096924e-01],
                        [ -1.20239258e-01,  -1.19445801e-01],
                        [ -8.51440430e-02,  -8.47167969e-02],
                        [ -3.97033691e-02,  -3.96118164e-02],
                        [  1.68151855e-02,   1.65100098e-02],
                        [  8.00170898e-02,   7.93762207e-02],
                        [  1.36535645e-01,   1.35528564e-01],
                        [  1.70776367e-01,   1.69525146e-01],
                        [  1.77124023e-01,   1.75659180e-01],
                        [  1.62872314e-01,   1.61254883e-01],
                        [  1.41998291e-01,   1.40319824e-01],
                        [  1.26953125e-01,   1.25305176e-01],
                        [  1.21276855e-01,   1.19750977e-01],
                        [  1.18164062e-01,   1.16821289e-01],
                        [  1.08581543e-01,   1.07513428e-01],
                        [  9.01489258e-02,   8.94165039e-02],
                        [  6.50634766e-02,   6.46667480e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [ -4.54711914e-03,  -4.15039062e-03],
                        [ -4.07714844e-02,  -4.00085449e-02],
                        [ -6.18896484e-02,  -6.07910156e-02],
                        [ -6.12182617e-02,  -5.98754883e-02],
                        [ -4.40673828e-02,  -4.25109863e-02],
                        [ -2.07214355e-02,  -1.90734863e-02],
                        [  5.49316406e-04,   2.22778320e-03],
                        [  1.42517090e-02,   1.58691406e-02],
                        [  1.73034668e-02,   1.87377930e-02],
                        [  1.13220215e-02,   1.24816895e-02],
                        [  1.67846680e-03,   2.56347656e-03],
                        [ -7.23266602e-03,  -6.71386719e-03],
                        [ -1.29394531e-02,  -1.28479004e-02],
                        [ -1.13525391e-02,  -1.16271973e-02],
                        [  1.06811523e-03,   3.96728516e-04],
                        [  2.12097168e-02,   2.01721191e-02],
                        [  4.13208008e-02,   4.00085449e-02],
                        [  5.43212891e-02,   5.28259277e-02],
                        [  5.50537109e-02,   5.34362793e-02],
                        [  4.40063477e-02,   4.23278809e-02],
                        [  3.03344727e-02,   2.87170410e-02],
                        [  2.33459473e-02,   2.19421387e-02],
                        [  2.28576660e-02,   2.16674805e-02],
                        [  2.35900879e-02,   2.27050781e-02],
                        [  2.42309570e-02,   2.37426758e-02],
                        [  2.60620117e-02,   2.59704590e-02],
                        [  2.87780762e-02,   2.90527344e-02],
                        [  3.28674316e-02,   3.35693359e-02],
                        [  3.93676758e-02,   4.04052734e-02],
                        [  4.41589355e-02,   4.54711914e-02],
                        [  4.20227051e-02,   4.35485840e-02],
                        [  3.61328125e-02,   3.77807617e-02],
                        [  3.36303711e-02,   3.52783203e-02],
                        [  3.49731445e-02,   3.65295410e-02],
                        [  3.63464355e-02,   3.77197266e-02],
                        [  3.66821289e-02,   3.77807617e-02],
                        [  3.59191895e-02,   3.66821289e-02],
                        [  3.24096680e-02,   3.28063965e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.84631348e-02,   1.80664062e-02],
                        [  9.42993164e-03,   8.66699219e-03],
                        [ -3.35693359e-03,  -4.42504883e-03],
                        [ -1.75781250e-02,  -1.89208984e-02],
                        [ -2.75573730e-02,  -2.90832520e-02],
                        [ -3.13415527e-02,  -3.29284668e-02],
                        [ -3.10363770e-02,  -3.26232910e-02],
                        [ -2.82897949e-02,  -2.97546387e-02],
                        [ -2.49633789e-02,  -2.62145996e-02],
                        [ -2.41394043e-02,  -2.50854492e-02],
                        [ -2.56652832e-02,  -2.63061523e-02],
                        [ -2.55737305e-02,  -2.58483887e-02],
                        [ -2.32238770e-02,  -2.30712891e-02],
                        [ -2.31933594e-02,  -2.26745605e-02],
                        [ -2.60620117e-02,  -2.52075195e-02],
                        [ -2.63366699e-02,  -2.51770020e-02],
                        [ -2.32543945e-02,  -2.18811035e-02],
                        [ -2.20947266e-02,  -2.05993652e-02],
                        [ -2.26135254e-02,  -2.10571289e-02],
                        [ -2.05078125e-02,  -1.90124512e-02],
                        [ -1.77612305e-02,  -1.63879395e-02],
                        [ -1.70288086e-02,  -1.58996582e-02],
                        [ -1.34887695e-02,  -1.26647949e-02],
                        [ -4.88281250e-03,  -4.39453125e-03],
                        [  9.46044922e-04,   1.06811523e-03],
                        [ -2.41088867e-03,  -2.65502930e-03],
                        [ -1.10168457e-02,  -1.16271973e-02],
                        [ -1.73950195e-02,  -1.83410645e-02],
                        [ -1.73645020e-02,  -1.85546875e-02],
                        [ -1.22985840e-02,  -1.36718750e-02],
                        [ -9.42993164e-03,  -1.08947754e-02],
                        [ -1.33972168e-02,  -1.48620605e-02],
                        [ -1.79443359e-02,  -1.93481445e-02],
                        [ -1.42211914e-02,  -1.54418945e-02],
                        [ -4.60815430e-03,  -5.58471680e-03],
                        [  1.83105469e-03,   1.12915039e-03],
                        [  3.38745117e-03,   2.99072266e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  9.21630859e-03,   9.52148438e-03],
                        [  1.15661621e-02,   1.22070312e-02],
                        [  9.85717773e-03,   1.08032227e-02],
                        [  6.22558594e-03,   7.38525391e-03],
                        [  6.34765625e-03,   7.65991211e-03],
                        [  1.41906738e-02,   1.55639648e-02],
                        [  2.74353027e-02,   2.88085938e-02],
                        [  4.18701172e-02,   4.31518555e-02],
                        [  5.80444336e-02,   5.91430664e-02],
                        [  7.94372559e-02,   8.02917480e-02],
                        [  1.06109619e-01,   1.06689453e-01],
                        [  1.30340576e-01,   1.30615234e-01],
                        [  1.36749268e-01,   1.36718750e-01],
                        [  1.11083984e-01,   1.10748291e-01],
                        [  4.94689941e-02,   4.88281250e-02],
                        [ -4.20532227e-02,  -4.29077148e-02],
                        [ -1.49810791e-01,  -1.50848389e-01],
                        [ -2.49450684e-01,  -2.50640869e-01],
                        [ -3.10150146e-01,  -3.11370850e-01],
                        [ -3.13781738e-01,  -3.14971924e-01],
                        [ -2.71118164e-01,  -2.72247314e-01],
                        [ -2.14996338e-01,  -2.15942383e-01],
                        [ -1.74743652e-01,  -1.75476074e-01],
                        [ -1.57073975e-01,  -1.57562256e-01],
                        [ -1.48590088e-01,  -1.48834229e-01],
                        [ -1.34368896e-01,  -1.34338379e-01],
                        [ -1.12121582e-01,  -1.11846924e-01],
                        [ -8.59680176e-02,  -8.54492188e-02],
                        [ -5.27954102e-02,  -5.20629883e-02],
                        [ -4.57763672e-03,  -3.69262695e-03],
                        [  5.75256348e-02,   5.85021973e-02],
                        [  1.18499756e-01,   1.19506836e-01],
                        [  1.60461426e-01,   1.61468506e-01],
                        [  1.77093506e-01,   1.78009033e-01],
                        [  1.76422119e-01,   1.77215576e-01],
                        [  1.70318604e-01,   1.70928955e-01],
                        [  1.63024902e-01,   1.63452148e-01],
                        [  1.50360107e-01,   1.50604248e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  9.69543457e-02,   9.67712402e-02],
                        [  6.44531250e-02,   6.40869141e-02],
                        [  3.26538086e-02,   3.21350098e-02],
                        [  1.22070312e-03,   5.79833984e-04],
                        [ -2.73437500e-02,  -2.80761719e-02],
                        [ -4.66918945e-02,  -4.74548340e-02],
                        [ -5.00488281e-02,  -5.07812500e-02],
                        [ -3.74145508e-02,  -3.81164551e-02],
                        [ -1.97448730e-02,  -2.03857422e-02],
                        [ -9.55200195e-03,  -1.00402832e-02],
                        [ -7.04956055e-03,  -7.41577148e-03],
                        [ -4.39453125e-03,  -4.63867188e-03],
                        [ -5.79833984e-04,  -6.71386719e-04],
                        [ -1.03759766e-03,  -1.00708008e-03],
                        [ -4.97436523e-03,  -4.79125977e-03],
                        [ -4.91333008e-03,  -4.63867188e-03],
                        [  2.07519531e-03,   2.47192383e-03],
                        [  1.34277344e-02,   1.38854980e-02],
                        [  2.72521973e-02,   2.77099609e-02],
                        [  4.20532227e-02,   4.25415039e-02],
                        [  5.40161133e-02,   5.44738770e-02],
                        [  5.83496094e-02,   5.87768555e-02],
                        [  5.31616211e-02,   5.35278320e-02],
                        [  4.23583984e-02,   4.26940918e-02],
                        [  3.35693359e-02,   3.38134766e-02],
                        [  2.91442871e-02,   2.92968750e-02],
                        [  2.40173340e-02,   2.41088867e-02],
                        [  1.64489746e-02,   1.64794922e-02],
                        [  1.30004883e-02,   1.29394531e-02],
                        [  1.69372559e-02,   1.68151855e-02],
                        [  2.23999023e-02,   2.22473145e-02],
                        [  2.49938965e-02,   2.47802734e-02],
                        [  2.75268555e-02,   2.73132324e-02],
                        [  3.22570801e-02,   3.20434570e-02],
                        [  3.65600586e-02,   3.63159180e-02],
                        [  3.80554199e-02,   3.78112793e-02],
                        [  3.77197266e-02,   3.74755859e-02],
                        [  3.70788574e-02,   3.68347168e-02],
                        [  3.73229980e-02,   3.70788574e-02],
                        [  3.91845703e-02,   3.89709473e-02],
                        [  4.08630371e-02,   4.06799316e-02],
                        [  3.77197266e-02,   3.75366211e-02],
                        [  2.81677246e-02,   2.80151367e-02],
                        [  1.58691406e-02,   1.57775879e-02],
                        [  4.88281250e-03,   4.82177734e-03],
                        [ -2.38037109e-03,  -2.41088867e-03],
                        [ -5.00488281e-03,  -4.97436523e-03],
                        [ -6.34765625e-03,  -6.28662109e-03],
                        [ -1.11083984e-02,  -1.09863281e-02],
                        [ -1.86462402e-02,  -1.84631348e-02],
                        [ -2.61230469e-02,  -2.59094238e-02],
                        [ -3.42712402e-02,  -3.39965820e-02],
                        [ -4.28161621e-02,  -4.25109863e-02],
                        [ -4.71801758e-02,  -4.68750000e-02],
                        [ -4.49218750e-02,  -4.45861816e-02],
                        [ -3.96728516e-02,  -3.93676758e-02],
                        [ -3.38134766e-02,  -3.35083008e-02],
                        [ -2.57263184e-02,  -2.54821777e-02],
                        [ -1.85852051e-02,  -1.83715820e-02],
                        [ -1.94396973e-02,  -1.93176270e-02],
                        [ -2.65502930e-02,  -2.65197754e-02],
                        [ -3.06091309e-02,  -3.06396484e-02],
                        [ -2.92663574e-02,  -2.93884277e-02],
                        [ -2.68859863e-02,  -2.70690918e-02],
                        [ -2.30102539e-02,  -2.32849121e-02],
                        [ -1.39160156e-02,  -1.42517090e-02],
                        [ -2.34985352e-03,  -2.74658203e-03],
                        [  3.63159180e-03,   3.20434570e-03],
                        [  9.76562500e-04,   5.49316406e-04],
                        [ -5.21850586e-03,  -5.61523438e-03],
                        [ -9.06372070e-03,  -9.42993164e-03],
                        [ -1.00708008e-02,  -1.03759766e-02],
                        [ -1.16882324e-02,  -1.19323730e-02],
                        [ -1.59606934e-02,  -1.60827637e-02],
                        [ -1.98364258e-02,  -1.98669434e-02],
                        [ -1.85546875e-02,  -1.85241699e-02],
                        [ -1.26037598e-02,  -1.24206543e-02],
                        [ -7.47680664e-03,  -7.20214844e-03],
                        [ -6.86645508e-03,  -6.53076172e-03],
                        [ -8.72802734e-03,  -8.33129883e-03],
                        [ -8.39233398e-03,  -7.96508789e-03],
                        [ -4.11987305e-03,  -3.66210938e-03],
                        [  2.04467773e-03,   2.47192383e-03],
                        [  6.95800781e-03,   7.38525391e-03],
                        [  9.18579102e-03,   9.55200195e-03],
                        [  1.10778809e-02,   1.13525391e-02],
                        [  1.78833008e-02,   1.80969238e-02],
                        [  3.18298340e-02,   3.19213867e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  6.93054199e-02,   6.91833496e-02],
                        [  9.15832520e-02,   9.13696289e-02],
                        [  1.16577148e-01,   1.16271973e-01],
                        [  1.36138916e-01,   1.35772705e-01],
                        [  1.36535645e-01,   1.36138916e-01],
                        [  1.07879639e-01,   1.07452393e-01],
                        [  4.87060547e-02,   4.83093262e-02],
                        [ -3.72619629e-02,  -3.76586914e-02],
                        [ -1.41845703e-01,  -1.42181396e-01],
                        [ -2.44812012e-01,  -2.45086670e-01],
                        [ -3.14147949e-01,  -3.14361572e-01],
                        [ -3.25775146e-01,  -3.25866699e-01],
                        [ -2.85034180e-01,  -2.85034180e-01],
                        [ -2.23907471e-01,  -2.23846436e-01],
                        [ -1.75781250e-01,  -1.75598145e-01],
                        [ -1.52374268e-01,  -1.52130127e-01],
                        [ -1.42700195e-01,  -1.42425537e-01],
                        [ -1.30706787e-01,  -1.30401611e-01],
                        [ -1.10900879e-01,  -1.10565186e-01],
                        [ -8.54187012e-02,  -8.50830078e-02],
                        [ -5.27648926e-02,  -5.24597168e-02],
                        [ -7.08007812e-03,  -6.83593750e-03],
                        [  5.21240234e-02,   5.23376465e-02],
                        [  1.15112305e-01,   1.15264893e-01],
                        [  1.66442871e-01,   1.66534424e-01],
                        [  1.93969727e-01,   1.94000244e-01],
                        [  1.96868896e-01,   1.96807861e-01],
                        [  1.85577393e-01,   1.85455322e-01],
                        [  1.70349121e-01,   1.70166016e-01],
                        [  1.50695801e-01,   1.50482178e-01],
                        [  1.21093750e-01,   1.20880127e-01],
                        [  8.16345215e-02,   8.14208984e-02],
                        [  3.76892090e-02,   3.74755859e-02],
                        [ -4.42504883e-03,  -4.63867188e-03],
                        [ -3.62854004e-02,  -3.64379883e-02],
                        [ -4.94079590e-02,  -4.95300293e-02],
                        [ -4.40979004e-02,  -4.41894531e-02],
                        [ -3.21350098e-02,  -3.21960449e-02],
                        [ -2.52075195e-02,  -2.52380371e-02],
                        [ -2.34985352e-02,  -2.34680176e-02],
                        [ -2.03857422e-02,  -2.03247070e-02],
                        [ -1.37634277e-02,  -1.36718750e-02],
                        [ -6.22558594e-03,  -6.13403320e-03],
                        [  8.23974609e-04,   9.46044922e-04],
                        [  7.56835938e-03,   7.69042969e-03],
                        [  1.42211914e-02,   1.43127441e-02],
                        [  2.17285156e-02,   2.18200684e-02],
                        [  3.19213867e-02,   3.20129395e-02],
                        [  4.40368652e-02,   4.40979004e-02],
                        [  5.33142090e-02,   5.33447266e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  4.68750000e-02,   4.68444824e-02],
                        [  3.89099121e-02,   3.88793945e-02],
                        [  3.05175781e-02,   3.04870605e-02],
                        [  2.31018066e-02,   2.30712891e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  7.65991211e-03,   7.62939453e-03],
                        [  3.54003906e-03,   3.50952148e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  1.57470703e-02,   1.57775879e-02],
                        [  2.58483887e-02,   2.58789062e-02],
                        [  3.55834961e-02,   3.56445312e-02],
                        [  4.48608398e-02,   4.49218750e-02],
                        [  5.08728027e-02,   5.09033203e-02],
                        [  4.95910645e-02,   4.96215820e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  3.43017578e-02,   3.42712402e-02],
                        [  4.20837402e-02,   4.20227051e-02],
                        [  4.31823730e-02,   4.31213379e-02],
                        [  3.60107422e-02,   3.59191895e-02],
                        [  2.61230469e-02,   2.60314941e-02],
                        [  1.69982910e-02,   1.68762207e-02],
                        [  6.92749023e-03,   6.83593750e-03],
                        [ -3.72314453e-03,  -3.78417969e-03],
                        [ -1.12609863e-02,  -1.13220215e-02],
                        [ -1.50146484e-02,  -1.50451660e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.92260742e-02,  -1.91955566e-02],
                        [ -2.77709961e-02,  -2.76794434e-02],
                        [ -4.19616699e-02,  -4.18701172e-02],
                        [ -5.11169434e-02,  -5.09948730e-02],
                        [ -4.73327637e-02,  -4.72106934e-02],
                        [ -3.52172852e-02,  -3.50952148e-02],
                        [ -2.51464844e-02,  -2.49938965e-02],
                        [ -2.22167969e-02,  -2.20947266e-02],
                        [ -2.47802734e-02,  -2.46887207e-02],
                        [ -2.78015137e-02,  -2.77404785e-02],
                        [ -2.59399414e-02,  -2.59094238e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -5.15747070e-03,  -5.18798828e-03],
                        [  1.70898438e-03,   1.64794922e-03],
                        [ -2.41088867e-03,  -2.50244141e-03],
                        [ -1.39160156e-02,  -1.40380859e-02],
                        [ -2.16979980e-02,  -2.18200684e-02],
                        [ -1.92871094e-02,  -1.94396973e-02],
                        [ -1.17797852e-02,  -1.19323730e-02],
                        [ -7.87353516e-03,  -7.99560547e-03],
                        [ -8.54492188e-03,  -8.66699219e-03],
                        [ -9.09423828e-03,  -9.18579102e-03],
                        [ -8.05664062e-03,  -8.11767578e-03],
                        [ -8.36181641e-03,  -8.39233398e-03],
                        [ -1.12915039e-02,  -1.13220215e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.63269043e-02,  -1.62658691e-02],
                        [ -1.41601562e-02,  -1.40991211e-02],
                        [ -9.27734375e-03,  -9.18579102e-03],
                        [ -2.96020508e-03,  -2.83813477e-03],
                        [  4.54711914e-03,   4.66918945e-03],
                        [  1.15051270e-02,   1.16271973e-02],
                        [  1.40075684e-02,   1.41296387e-02],
                        [  1.01928711e-02,   1.02844238e-02],
                        [  4.69970703e-03,   4.79125977e-03],
                        [  5.18798828e-03,   5.24902344e-03],
                        [  1.35498047e-02,   1.36108398e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  5.97839355e-02,   5.97534180e-02],
                        [  8.93554688e-02,   8.92944336e-02],
                        [  1.21002197e-01,   1.20941162e-01],
                        [  1.42150879e-01,   1.42059326e-01],
                        [  1.40808105e-01,   1.40716553e-01],
                        [  1.09344482e-01,   1.09252930e-01],
                        [  4.52880859e-02,   4.51965332e-02],
                        [ -4.70275879e-02,  -4.70886230e-02],
                        [ -1.53503418e-01,  -1.53564453e-01],
                        [ -2.49786377e-01,  -2.49816895e-01],
                        [ -3.07495117e-01,  -3.07525635e-01],
                        [ -3.09722900e-01,  -3.09722900e-01],
                        [ -2.65014648e-01,  -2.65014648e-01],
                        [ -2.04681396e-01,  -2.04681396e-01],
                        [ -1.61376953e-01,  -1.61346436e-01],
                        [ -1.46575928e-01,  -1.46545410e-01],
                        [ -1.46209717e-01,  -1.46148682e-01],
                        [ -1.39465332e-01,  -1.39404297e-01],
                        [ -1.19201660e-01,  -1.19140625e-01],
                        [ -8.99658203e-02,  -8.99047852e-02],
                        [ -5.30700684e-02,  -5.30090332e-02],
                        [ -3.69262695e-03,  -3.66210938e-03],
                        [  5.89599609e-02,   5.89904785e-02],
                        [  1.25030518e-01,   1.25061035e-01],
                        [  1.78222656e-01,   1.78222656e-01],
                        [  2.05352783e-01,   2.05352783e-01],
                        [  2.05657959e-01,   2.05657959e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  1.70715332e-01,   1.70684814e-01],
                        [  1.44836426e-01,   1.44836426e-01],
                        [  1.04034424e-01,   1.04034424e-01],
                        [  4.73327637e-02,   4.73022461e-02],
                        [ -1.16577148e-02,  -1.16882324e-02],
                        [ -5.32531738e-02,  -5.32836914e-02],
                        [ -6.62536621e-02,  -6.62841797e-02],
                        [ -5.47790527e-02,  -5.48095703e-02],
                        [ -3.32641602e-02,  -3.32946777e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -8.05664062e-03,  -8.02612305e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  5.03540039e-02,   5.03540039e-02],
                        [  4.80957031e-02,   4.80957031e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  3.66210938e-02,   3.66210938e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  6.20117188e-02,   6.20117188e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  1.03332520e-01,   1.03332520e-01],
                        [  1.22192383e-01,   1.22192383e-01],
                        [  1.28051758e-01,   1.28051758e-01],
                        [  1.07116699e-01,   1.07116699e-01],
                        [  4.97741699e-02,   4.97741699e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -1.44409180e-01,  -1.44409180e-01],
                        [ -2.38464355e-01,  -2.38464355e-01],
                        [ -2.95654297e-01,  -2.95654297e-01],
                        [ -2.99468994e-01,  -2.99468994e-01],
                        [ -2.57690430e-01,  -2.57690430e-01],
                        [ -2.02087402e-01,  -2.02087402e-01],
                        [ -1.64031982e-01,  -1.64031982e-01],
                        [ -1.49658203e-01,  -1.49658203e-01],
                        [ -1.42791748e-01,  -1.42791748e-01],
                        [ -1.29608154e-01,  -1.29608154e-01],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -9.23767090e-02,  -9.23767090e-02],
                        [ -6.87866211e-02,  -6.87866211e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.90399170e-01,   1.90399170e-01],
                        [  2.29400635e-01,   2.29400635e-01],
                        [  2.29064941e-01,   2.29064941e-01],
                        [  2.02392578e-01,   2.02392578e-01],
                        [  1.64337158e-01,   1.64337158e-01],
                        [  1.20086670e-01,   1.20086670e-01],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  8.55407715e-02,   8.55407715e-02],
                        [  8.18481445e-02,   8.18481445e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  4.33349609e-03,   4.33349609e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  4.36401367e-02,   4.36401367e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  4.02526855e-02,   4.02526855e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  3.45764160e-02,   3.45458984e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  7.76062012e-02,   7.76062012e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  1.25366211e-01,   1.25366211e-01],
                        [  1.25915527e-01,   1.25915527e-01],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  4.70581055e-02,   4.70581055e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -1.33514404e-01,  -1.33514404e-01],
                        [ -2.27630615e-01,  -2.27630615e-01],
                        [ -2.89428711e-01,  -2.89428711e-01],
                        [ -2.96875000e-01,  -2.96875000e-01],
                        [ -2.55462646e-01,  -2.55493164e-01],
                        [ -1.98852539e-01,  -1.98852539e-01],
                        [ -1.61193848e-01,  -1.61193848e-01],
                        [ -1.51245117e-01,  -1.51245117e-01],
                        [ -1.54541016e-01,  -1.54541016e-01],
                        [ -1.53167725e-01,  -1.53167725e-01],
                        [ -1.38336182e-01,  -1.38336182e-01],
                        [ -1.10626221e-01,  -1.10626221e-01],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  2.18353271e-01,   2.18353271e-01],
                        [  2.33154297e-01,   2.33154297e-01],
                        [  2.15026855e-01,   2.15026855e-01],
                        [  1.69586182e-01,   1.69586182e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  3.40881348e-02,   3.40881348e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  8.01391602e-02,   8.01391602e-02],
                        [  9.32617188e-02,   9.32617188e-02],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  6.64978027e-02,   6.64978027e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  4.08935547e-03,   4.08935547e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  3.56140137e-02,   3.55834961e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  4.25720215e-02,   4.26025391e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -5.95092773e-03,  -5.92041016e-03],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.26342773e-02,  -1.26037598e-02],
                        [ -1.30004883e-02,  -1.29699707e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.73132324e-02,  -2.73437500e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  1.01959229e-01,   1.01959229e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.29516602e-01,   1.29516602e-01],
                        [  1.07513428e-01,   1.07513428e-01],
                        [  5.47485352e-02,   5.47485352e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -1.34216309e-01,  -1.34216309e-01],
                        [ -2.32910156e-01,  -2.32910156e-01],
                        [ -2.97088623e-01,  -2.97088623e-01],
                        [ -3.05236816e-01,  -3.05236816e-01],
                        [ -2.63031006e-01,  -2.63031006e-01],
                        [ -2.03948975e-01,  -2.03948975e-01],
                        [ -1.60614014e-01,  -1.60614014e-01],
                        [ -1.40014648e-01,  -1.40014648e-01],
                        [ -1.30859375e-01,  -1.30859375e-01],
                        [ -1.23413086e-01,  -1.23413086e-01],
                        [ -1.14807129e-01,  -1.14807129e-01],
                        [ -1.02050781e-01,  -1.02050781e-01],
                        [ -7.83081055e-02,  -7.83081055e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  1.06628418e-01,   1.06628418e-01],
                        [  1.76849365e-01,   1.76849365e-01],
                        [  2.19787598e-01,   2.19787598e-01],
                        [  2.25738525e-01,   2.25738525e-01],
                        [  1.96075439e-01,   1.96075439e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  7.01599121e-02,   7.01904297e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -3.28979492e-02,  -3.29284668e-02],
                        [ -4.53491211e-02,  -4.53186035e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  8.18481445e-02,   8.18481445e-02],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  9.49401855e-02,   9.49401855e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  7.58361816e-02,   7.58361816e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  2.42919922e-02,   2.43225098e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  9.88769531e-03,   9.91821289e-03],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.07519531e-02,   2.07214355e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  2.49938965e-02,   2.50244141e-02],
                        [  2.85034180e-02,   2.84729004e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  4.30603027e-02,   4.30297852e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.22167969e-02,  -2.22473145e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.66320801e-02,  -1.66625977e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -1.37939453e-02,  -1.38244629e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -1.57470703e-02,  -1.57165527e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.37329102e-03,  -1.40380859e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.14593506e-01,   1.14593506e-01],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -1.51092529e-01,  -1.51092529e-01],
                        [ -2.45208740e-01,  -2.45208740e-01],
                        [ -2.99621582e-01,  -2.99621582e-01],
                        [ -2.92877197e-01,  -2.92877197e-01],
                        [ -2.37640381e-01,  -2.37640381e-01],
                        [ -1.73583984e-01,  -1.73583984e-01],
                        [ -1.33789062e-01,  -1.33789062e-01],
                        [ -1.22436523e-01,  -1.22436523e-01],
                        [ -1.24328613e-01,  -1.24328613e-01],
                        [ -1.24664307e-01,  -1.24664307e-01],
                        [ -1.16973877e-01,  -1.16973877e-01],
                        [ -1.02203369e-01,  -1.02203369e-01],
                        [ -8.20922852e-02,  -8.20922852e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  7.40661621e-02,   7.40661621e-02],
                        [  1.54602051e-01,   1.54602051e-01],
                        [  2.13439941e-01,   2.13470459e-01],
                        [  2.27081299e-01,   2.27081299e-01],
                        [  1.88812256e-01,   1.88812256e-01],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  3.01818848e-02,   3.01818848e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.79443359e-02,   1.79138184e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  5.43823242e-02,   5.44128418e-02],
                        [  7.73620605e-02,   7.73620605e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.28369141e-02,   3.28063965e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.17895508e-02,   2.17590332e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.54516602e-02,  -2.54821777e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.23083496e-02,  -2.22778320e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.60009766e-02,  -2.60314941e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.84729004e-02,  -2.85034180e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.25122070e-03,  -1.28173828e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.17767334e-01,   1.17767334e-01],
                        [  1.20483398e-01,   1.20483398e-01],
                        [  1.01593018e-01,   1.01593018e-01],
                        [  5.42907715e-02,   5.42907715e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -2.35015869e-01,  -2.35015869e-01],
                        [ -3.00292969e-01,  -3.00292969e-01],
                        [ -2.98095703e-01,  -2.98095703e-01],
                        [ -2.39349365e-01,  -2.39349365e-01],
                        [ -1.66778564e-01,  -1.66809082e-01],
                        [ -1.18743896e-01,  -1.18743896e-01],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -1.04736328e-01,  -1.04736328e-01],
                        [ -1.04644775e-01,  -1.04644775e-01],
                        [ -9.73815918e-02,  -9.73815918e-02],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -7.07397461e-02,  -7.07397461e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.52130127e-01,   1.52130127e-01],
                        [  1.69067383e-01,   1.69067383e-01],
                        [  1.43218994e-01,   1.43218994e-01],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -1.86157227e-02,  -1.86157227e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  3.70178223e-02,   3.70483398e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  2.65502930e-02,   2.65808105e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  4.94995117e-02,   4.94689941e-02],
                        [  4.40368652e-02,   4.40673828e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.15454102e-02,   2.15759277e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.81164551e-02,   3.80859375e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  3.75061035e-02,   3.75366211e-02],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -1.22985840e-02,  -1.23291016e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.08337402e-02,  -1.08642578e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.95617676e-02,  -1.95312500e-02],
                        [ -2.97241211e-02,  -2.96936035e-02],
                        [ -3.83605957e-02,  -3.83911133e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.20837402e-02,  -4.20532227e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -3.38439941e-02,  -3.38745117e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.13220215e-02,  -1.12915039e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  8.28857422e-02,   8.28857422e-02],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  1.23260498e-01,   1.23229980e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  5.47485352e-02,   5.47485352e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.17462158e-01,  -1.17462158e-01],
                        [ -2.12310791e-01,  -2.12310791e-01],
                        [ -2.75970459e-01,  -2.75939941e-01],
                        [ -2.85644531e-01,  -2.85644531e-01],
                        [ -2.46765137e-01,  -2.46765137e-01],
                        [ -1.90704346e-01,  -1.90704346e-01],
                        [ -1.47216797e-01,  -1.47186279e-01],
                        [ -1.22283936e-01,  -1.22283936e-01],
                        [ -1.06384277e-01,  -1.06384277e-01],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -8.27941895e-02,  -8.27941895e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [  5.34057617e-03,   5.37109375e-03],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  8.44116211e-02,   8.43811035e-02],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  9.27429199e-02,   9.27734375e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  2.07214355e-02,   2.07519531e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  9.50927734e-02,   9.50927734e-02],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  1.04309082e-01,   1.04309082e-01],
                        [  9.21325684e-02,   9.21630859e-02],
                        [  7.57751465e-02,   7.57751465e-02],
                        [  6.39648438e-02,   6.39343262e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  5.08422852e-02,   5.08728027e-02],
                        [  3.79638672e-02,   3.79333496e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  1.34582520e-02,   1.34277344e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  2.85644531e-02,   2.85339355e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.74560547e-02,   1.74255371e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.98864746e-02,  -3.99169922e-02],
                        [ -4.29992676e-02,  -4.29687500e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.12597656e-02,  -4.12902832e-02],
                        [ -3.58276367e-02,  -3.57971191e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.68554688e-02,  -2.68859863e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -6.16455078e-03,  -6.19506836e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  6.70166016e-02,   6.70471191e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  9.74426270e-02,   9.74121094e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -1.27685547e-01,  -1.27685547e-01],
                        [ -2.26806641e-01,  -2.26806641e-01],
                        [ -2.86926270e-01,  -2.86926270e-01],
                        [ -2.90527344e-01,  -2.90527344e-01],
                        [ -2.47985840e-01,  -2.47985840e-01],
                        [ -1.87805176e-01,  -1.87805176e-01],
                        [ -1.38427734e-01,  -1.38427734e-01],
                        [ -1.10351562e-01,  -1.10351562e-01],
                        [ -9.45739746e-02,  -9.45739746e-02],
                        [ -7.99865723e-02,  -7.99560547e-02],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -5.82580566e-02,  -5.82885742e-02],
                        [ -5.60302734e-02,  -5.59997559e-02],
                        [ -5.02014160e-02,  -5.01708984e-02],
                        [ -3.07922363e-02,  -3.08227539e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  6.64367676e-02,   6.64062500e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.57775879e-02,   1.57470703e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  3.55529785e-02,   3.55224609e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  7.67211914e-02,   7.67211914e-02],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  2.72216797e-02,   2.72521973e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  1.93481445e-02,   1.93176270e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.00805664e-02,  -2.00500488e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -2.59704590e-02,  -2.59399414e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -4.29077148e-02,  -4.29382324e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.83496094e-02,  -5.83190918e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -3.68652344e-02,  -3.68957520e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.10363770e-02,  -3.10058594e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  2.76794434e-02,   2.76489258e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  5.16662598e-02,   5.16357422e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  8.51745605e-02,   8.52050781e-02],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  1.13861084e-01,   1.13861084e-01],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  9.12780762e-02,   9.13085938e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -1.27014160e-01,  -1.27014160e-01],
                        [ -2.19390869e-01,  -2.19390869e-01],
                        [ -2.77832031e-01,  -2.77832031e-01],
                        [ -2.82531738e-01,  -2.82531738e-01],
                        [ -2.37731934e-01,  -2.37731934e-01],
                        [ -1.74713135e-01,  -1.74713135e-01],
                        [ -1.29058838e-01,  -1.29058838e-01],
                        [ -1.09130859e-01,  -1.09100342e-01],
                        [ -9.57641602e-02,  -9.57641602e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  6.90917969e-02,   6.90612793e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  8.53881836e-02,   8.53881836e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  3.18908691e-02,   3.18908691e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  9.56115723e-02,   9.56115723e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  4.12902832e-02,   4.13208008e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  3.51867676e-02,   3.52172852e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  2.19421387e-02,   2.19116211e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  2.56347656e-02,   2.56042480e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.92968750e-03,   2.92968750e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.46887207e-02,  -2.46582031e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.55126953e-02,  -2.54821777e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.21447754e-02,  -4.21142578e-02],
                        [ -3.47290039e-02,  -3.47595215e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.11279297e-02,  -3.10974121e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.03552246e-02,  -2.03857422e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -1.45568848e-02,  -1.45874023e-02],
                        [ -1.60217285e-02,  -1.60522461e-02],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  1.40075684e-02,   1.39770508e-02],
                        [  1.69677734e-02,   1.69982910e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  6.82678223e-02,   6.82678223e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.28173828e-01,   1.28173828e-01],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  5.57556152e-02,   5.57556152e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -1.14227295e-01,  -1.14227295e-01],
                        [ -2.10937500e-01,  -2.10937500e-01],
                        [ -2.78015137e-01,  -2.78015137e-01],
                        [ -2.86773682e-01,  -2.86804199e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -1.69952393e-01,  -1.69921875e-01],
                        [ -1.16271973e-01,  -1.16302490e-01],
                        [ -8.96606445e-02,  -8.96911621e-02],
                        [ -7.69042969e-02,  -7.69042969e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -7.94982910e-02,  -7.94982910e-02],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -1.05712891e-01,  -1.05712891e-01],
                        [ -8.97521973e-02,  -8.97827148e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  7.11975098e-02,   7.11669922e-02],
                        [  1.07360840e-01,   1.07360840e-01],
                        [  1.10534668e-01,   1.10534668e-01],
                        [  9.28344727e-02,   9.28039551e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  1.07391357e-01,   1.07391357e-01],
                        [  1.21582031e-01,   1.21582031e-01],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  6.70166016e-02,   6.70166016e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  2.99682617e-02,   2.99377441e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  2.36206055e-02,   2.35900879e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.53808594e-02,   1.54113770e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  4.08935547e-03,   4.08935547e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.23291016e-02,  -1.22985840e-02],
                        [ -1.44958496e-02,  -1.45263672e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -4.48608398e-02,  -4.48303223e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.62145996e-02,  -2.61840820e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.02636719e-02,  -2.02331543e-02],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -6.50024414e-03,  -6.53076172e-03],
                        [ -1.52587891e-03,  -1.49536133e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  1.64794922e-03,   1.61743164e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  9.42993164e-03,   9.39941406e-03],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  9.77478027e-02,   9.77783203e-02],
                        [  1.21368408e-01,   1.21368408e-01],
                        [  1.36505127e-01,   1.36474609e-01],
                        [  1.35894775e-01,   1.35894775e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  4.95605469e-02,   4.95605469e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -1.35894775e-01,  -1.35864258e-01],
                        [ -2.20489502e-01,  -2.20489502e-01],
                        [ -2.69897461e-01,  -2.69897461e-01],
                        [ -2.69805908e-01,  -2.69805908e-01],
                        [ -2.24121094e-01,  -2.24121094e-01],
                        [ -1.60095215e-01,  -1.60095215e-01],
                        [ -1.10260010e-01,  -1.10260010e-01],
                        [ -8.46252441e-02,  -8.46252441e-02],
                        [ -6.95190430e-02,  -6.94885254e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -3.47290039e-02,  -3.47595215e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -4.47998047e-02,  -4.47692871e-02],
                        [ -7.51953125e-02,  -7.52258301e-02],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -1.38793945e-01,  -1.38763428e-01],
                        [ -1.44439697e-01,  -1.44439697e-01],
                        [ -1.19171143e-01,  -1.19171143e-01],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.19201660e-01,   1.19201660e-01],
                        [  1.08062744e-01,   1.08062744e-01],
                        [  9.75952148e-02,   9.75952148e-02],
                        [  9.08203125e-02,   9.08203125e-02],
                        [  8.01391602e-02,   8.01696777e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  4.71496582e-02,   4.71496582e-02],
                        [  4.77905273e-02,   4.77905273e-02],
                        [  5.04150391e-02,   5.04150391e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  8.11767578e-02,   8.11767578e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  1.05316162e-01,   1.05316162e-01],
                        [  1.02081299e-01,   1.02050781e-01],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  7.66601562e-02,   7.66906738e-02],
                        [  6.52160645e-02,   6.52160645e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -2.79541016e-02,  -2.79235840e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -5.78613281e-02,  -5.78918457e-02],
                        [ -6.16455078e-02,  -6.16455078e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -2.19726562e-02,  -2.20031738e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -3.05175781e-02,  -3.05480957e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.02026367e-02,  -2.02331543e-02],
                        [ -1.19323730e-02,  -1.19018555e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  5.06591797e-03,   5.09643555e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.44653320e-01,   1.44653320e-01],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  6.71997070e-02,   6.71997070e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -1.11450195e-01,  -1.11480713e-01],
                        [ -1.99829102e-01,  -1.99829102e-01],
                        [ -2.60253906e-01,  -2.60253906e-01],
                        [ -2.75299072e-01,  -2.75299072e-01],
                        [ -2.43194580e-01,  -2.43194580e-01],
                        [ -1.84875488e-01,  -1.84875488e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -8.69445801e-02,  -8.69445801e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -1.15661621e-01,  -1.15661621e-01],
                        [ -1.61437988e-01,  -1.61437988e-01],
                        [ -1.85119629e-01,  -1.85119629e-01],
                        [ -1.75933838e-01,  -1.75903320e-01],
                        [ -1.30920410e-01,  -1.30920410e-01],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  1.34399414e-01,   1.34368896e-01],
                        [  1.49780273e-01,   1.49780273e-01],
                        [  1.45019531e-01,   1.45019531e-01],
                        [  1.24542236e-01,   1.24542236e-01],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  4.42199707e-02,   4.42199707e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  7.58056641e-02,   7.58361816e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  1.08093262e-01,   1.08093262e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.30004883e-01,   1.30004883e-01],
                        [  1.20239258e-01,   1.20208740e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  5.06896973e-02,   5.06591797e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  4.57763672e-02,   4.58068848e-02],
                        [  5.73120117e-02,   5.72814941e-02],
                        [  6.86645508e-02,   6.86340332e-02],
                        [  7.26623535e-02,   7.26928711e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  5.67932129e-02,   5.68237305e-02],
                        [  4.30908203e-02,   4.31213379e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.07727051e-02,   1.08032227e-02],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  1.57165527e-02,   1.56860352e-02],
                        [  1.83715820e-02,   1.84020996e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  1.40991211e-02,   1.40686035e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  3.38745117e-03,   3.41796875e-03],
                        [  5.46264648e-03,   5.43212891e-03],
                        [  1.26037598e-02,   1.25732422e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  2.58789062e-02,   2.59094238e-02],
                        [  2.31933594e-02,   2.32238770e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -9.76562500e-03,  -9.79614258e-03],
                        [ -2.38037109e-03,  -2.34985352e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.46545410e-01,   1.46545410e-01],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  7.04650879e-02,   7.04650879e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.10626221e-01,  -1.10626221e-01],
                        [ -2.07519531e-01,  -2.07519531e-01],
                        [ -2.72918701e-01,  -2.72949219e-01],
                        [ -2.84973145e-01,  -2.84973145e-01],
                        [ -2.45361328e-01,  -2.45361328e-01],
                        [ -1.79565430e-01,  -1.79595947e-01],
                        [ -1.18469238e-01,  -1.18469238e-01],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -1.13098145e-01,  -1.13098145e-01],
                        [ -1.64672852e-01,  -1.64672852e-01],
                        [ -1.97814941e-01,  -1.97814941e-01],
                        [ -1.98974609e-01,  -1.98974609e-01],
                        [ -1.70349121e-01,  -1.70349121e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  1.28936768e-01,   1.28936768e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.33239746e-01,   1.33239746e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  7.83386230e-02,   7.83386230e-02],
                        [  6.52465820e-02,   6.52465820e-02],
                        [  6.57043457e-02,   6.57348633e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  1.28692627e-01,   1.28692627e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  9.47265625e-02,   9.46960449e-02],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  3.16467285e-02,   3.16467285e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  2.50244141e-02,   2.50549316e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  1.75781250e-02,   1.76086426e-02],
                        [  6.25610352e-03,   6.25610352e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -4.51660156e-03,  -4.48608398e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  1.19628906e-02,   1.19323730e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -2.15759277e-02,  -2.15454102e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -3.94897461e-02,  -3.95202637e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -4.40368652e-02,  -4.40063477e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.31005859e-02,  -5.31311035e-02],
                        [ -4.94079590e-02,  -4.93774414e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -1.77307129e-02,  -1.77001953e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -2.07519531e-03,  -2.10571289e-03],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  7.36083984e-02,   7.36083984e-02],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.40014648e-01,   1.40014648e-01],
                        [  1.52465820e-01,   1.52465820e-01],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  8.38012695e-02,   8.38317871e-02],
                        [  1.70898438e-03,   1.67846680e-03],
                        [ -1.00067139e-01,  -1.00067139e-01],
                        [ -2.01080322e-01,  -2.01080322e-01],
                        [ -2.70263672e-01,  -2.70263672e-01],
                        [ -2.81250000e-01,  -2.81250000e-01],
                        [ -2.34436035e-01,  -2.34436035e-01],
                        [ -1.59393311e-01,  -1.59393311e-01],
                        [ -9.27429199e-02,  -9.27429199e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -9.72595215e-02,  -9.72595215e-02],
                        [ -1.37939453e-01,  -1.37939453e-01],
                        [ -1.80358887e-01,  -1.80358887e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -1.99859619e-01,  -1.99859619e-01],
                        [ -1.63391113e-01,  -1.63391113e-01],
                        [ -1.15325928e-01,  -1.15325928e-01],
                        [ -7.15637207e-02,  -7.15637207e-02],
                        [ -3.19519043e-02,  -3.19824219e-02],
                        [  1.12609863e-02,   1.12915039e-02],
                        [  5.92346191e-02,   5.92346191e-02],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.33636475e-01,   1.33666992e-01],
                        [  1.38641357e-01,   1.38641357e-01],
                        [  1.21124268e-01,   1.21124268e-01],
                        [  9.81750488e-02,   9.81750488e-02],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  9.01184082e-02,   9.01184082e-02],
                        [  9.03320312e-02,   9.03320312e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  1.05346680e-01,   1.05316162e-01],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.35833740e-01,   1.35864258e-01],
                        [  1.40014648e-01,   1.40014648e-01],
                        [  1.34521484e-01,   1.34521484e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  1.01654053e-01,   1.01654053e-01],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  7.32727051e-02,   7.32421875e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  8.05664062e-03,   8.08715820e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  1.95312500e-03,   1.92260742e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -5.19714355e-02,  -5.19714355e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.14123535e-02,  -4.14428711e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.49926758e-02,  -5.50231934e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -5.29174805e-02,  -5.29174805e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -8.20922852e-03,  -8.17871094e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  5.36804199e-02,   5.36499023e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  1.52740479e-01,   1.52740479e-01],
                        [  1.57592773e-01,   1.57592773e-01],
                        [  1.37207031e-01,   1.37237549e-01],
                        [  9.08203125e-02,   9.08203125e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [ -8.63342285e-02,  -8.63342285e-02],
                        [ -1.92993164e-01,  -1.92993164e-01],
                        [ -2.69897461e-01,  -2.69897461e-01],
                        [ -2.89306641e-01,  -2.89306641e-01],
                        [ -2.48535156e-01,  -2.48535156e-01],
                        [ -1.72393799e-01,  -1.72393799e-01],
                        [ -9.78393555e-02,  -9.78393555e-02],
                        [ -5.01403809e-02,  -5.01098633e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -1.00616455e-01,  -1.00616455e-01],
                        [ -1.51184082e-01,  -1.51184082e-01],
                        [ -1.94061279e-01,  -1.94061279e-01],
                        [ -2.13256836e-01,  -2.13256836e-01],
                        [ -2.02606201e-01,  -2.02606201e-01],
                        [ -1.67114258e-01,  -1.67114258e-01],
                        [ -1.20025635e-01,  -1.20025635e-01],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  9.57031250e-02,   9.57031250e-02],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  1.36383057e-01,   1.36383057e-01],
                        [  1.47460938e-01,   1.47460938e-01],
                        [  1.47949219e-01,   1.47949219e-01],
                        [  1.36779785e-01,   1.36779785e-01],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  7.77282715e-02,   7.76977539e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  3.97644043e-02,   3.97949219e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  2.85949707e-02,   2.86254883e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  1.69067383e-02,   1.68762207e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -9.85717773e-03,  -9.82666016e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  6.05163574e-02,   6.05163574e-02],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  1.33941650e-01,   1.33941650e-01],
                        [  1.48468018e-01,   1.48468018e-01],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  5.91430664e-02,   5.91430664e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -9.51232910e-02,  -9.51232910e-02],
                        [ -1.81152344e-01,  -1.81152344e-01],
                        [ -2.43530273e-01,  -2.43530273e-01],
                        [ -2.56195068e-01,  -2.56195068e-01],
                        [ -2.15270996e-01,  -2.15270996e-01],
                        [ -1.47888184e-01,  -1.47888184e-01],
                        [ -9.25598145e-02,  -9.25598145e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -7.46459961e-02,  -7.46459961e-02],
                        [ -8.99047852e-02,  -8.99047852e-02],
                        [ -1.10534668e-01,  -1.10534668e-01],
                        [ -1.39129639e-01,  -1.39129639e-01],
                        [ -1.70135498e-01,  -1.70135498e-01],
                        [ -1.88140869e-01,  -1.88140869e-01],
                        [ -1.83990479e-01,  -1.83990479e-01],
                        [ -1.63848877e-01,  -1.63848877e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -1.12152100e-01,  -1.12182617e-01],
                        [ -8.27331543e-02,  -8.27331543e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  8.20617676e-02,   8.20617676e-02],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.34948730e-01,   1.34948730e-01],
                        [  1.35040283e-01,   1.35040283e-01],
                        [  1.21887207e-01,   1.21887207e-01],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  9.46960449e-02,   9.46655273e-02],
                        [  9.36584473e-02,   9.36584473e-02],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  1.06262207e-01,   1.06262207e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.43707275e-01,   1.43707275e-01],
                        [  1.44378662e-01,   1.44378662e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.12670898e-01,   1.12670898e-01],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  7.70263672e-02,   7.70568848e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -4.10766602e-02,  -4.10766602e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -3.56445312e-02,  -3.56140137e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.56982422e-01,   1.56982422e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  7.23571777e-02,   7.23571777e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -1.01745605e-01,  -1.01745605e-01],
                        [ -1.92291260e-01,  -1.92291260e-01],
                        [ -2.48413086e-01,  -2.48413086e-01],
                        [ -2.48748779e-01,  -2.48748779e-01],
                        [ -1.97753906e-01,  -1.97753906e-01],
                        [ -1.25732422e-01,  -1.25732422e-01],
                        [ -7.07702637e-02,  -7.07702637e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -7.65991211e-02,  -7.65991211e-02],
                        [ -1.16333008e-01,  -1.16333008e-01],
                        [ -1.56402588e-01,  -1.56402588e-01],
                        [ -1.84997559e-01,  -1.84997559e-01],
                        [ -1.95007324e-01,  -1.95007324e-01],
                        [ -1.84936523e-01,  -1.84936523e-01],
                        [ -1.61499023e-01,  -1.61499023e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -1.15142822e-01,  -1.15142822e-01],
                        [ -9.85107422e-02,  -9.85107422e-02],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  1.43554688e-01,   1.43554688e-01],
                        [  1.52587891e-01,   1.52587891e-01],
                        [  1.37115479e-01,   1.37115479e-01],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  9.81750488e-02,   9.81750488e-02],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.49871826e-01,   1.49841309e-01],
                        [  1.65802002e-01,   1.65802002e-01],
                        [  1.67236328e-01,   1.67236328e-01],
                        [  1.52465820e-01,   1.52465820e-01],
                        [  1.26190186e-01,   1.26190186e-01],
                        [  9.84802246e-02,   9.84802246e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  3.73840332e-02,   3.73840332e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -6.63452148e-02,  -6.63452148e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.43280029e-01,   1.43280029e-01],
                        [  1.44714355e-01,   1.44714355e-01],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -8.69445801e-02,  -8.69445801e-02],
                        [ -1.72454834e-01,  -1.72454834e-01],
                        [ -2.29125977e-01,  -2.29125977e-01],
                        [ -2.34283447e-01,  -2.34283447e-01],
                        [ -1.90277100e-01,  -1.90277100e-01],
                        [ -1.28387451e-01,  -1.28387451e-01],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -8.88061523e-02,  -8.88061523e-02],
                        [ -1.19171143e-01,  -1.19171143e-01],
                        [ -1.54937744e-01,  -1.54937744e-01],
                        [ -1.80511475e-01,  -1.80511475e-01],
                        [ -1.91894531e-01,  -1.91894531e-01],
                        [ -1.88140869e-01,  -1.88140869e-01],
                        [ -1.70745850e-01,  -1.70745850e-01],
                        [ -1.46972656e-01,  -1.46972656e-01],
                        [ -1.25885010e-01,  -1.25885010e-01],
                        [ -1.11206055e-01,  -1.11206055e-01],
                        [ -9.93347168e-02,  -9.93347168e-02],
                        [ -8.31298828e-02,  -8.31298828e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.44134521e-01,   1.44134521e-01],
                        [  1.63452148e-01,   1.63452148e-01],
                        [  1.55731201e-01,   1.55731201e-01],
                        [  1.31927490e-01,   1.31927490e-01],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  9.92431641e-02,   9.92431641e-02],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.47918701e-01,   1.47918701e-01],
                        [  1.60552979e-01,   1.60552979e-01],
                        [  1.65283203e-01,   1.65283203e-01],
                        [  1.60369873e-01,   1.60369873e-01],
                        [  1.47644043e-01,   1.47644043e-01],
                        [  1.30187988e-01,   1.30187988e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  7.87658691e-02,   7.87658691e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -6.20117188e-02,  -6.20117188e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -7.41577148e-02,  -7.41577148e-02],
                        [ -7.08618164e-02,  -7.08618164e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  1.31622314e-01,   1.31622314e-01],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.51947021e-01,   1.51947021e-01],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  7.19299316e-02,   7.19299316e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -1.79809570e-01,  -1.79809570e-01],
                        [ -2.25860596e-01,  -2.25860596e-01],
                        [ -2.20092773e-01,  -2.20092773e-01],
                        [ -1.73248291e-01,  -1.73248291e-01],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -9.75036621e-02,  -9.75036621e-02],
                        [ -1.12487793e-01,  -1.12487793e-01],
                        [ -1.50054932e-01,  -1.50054932e-01],
                        [ -1.85455322e-01,  -1.85455322e-01],
                        [ -2.00988770e-01,  -2.00988770e-01],
                        [ -1.92565918e-01,  -1.92565918e-01],
                        [ -1.67907715e-01,  -1.67907715e-01],
                        [ -1.39221191e-01,  -1.39221191e-01],
                        [ -1.16271973e-01,  -1.16271973e-01],
                        [ -1.02722168e-01,  -1.02722168e-01],
                        [ -9.61914062e-02,  -9.61914062e-02],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -8.43811035e-02,  -8.43811035e-02],
                        [ -7.03735352e-02,  -7.03735352e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.62597656e-01,   1.62597656e-01],
                        [  1.62658691e-01,   1.62658691e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.23504639e-01,   1.23504639e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  1.21124268e-01,   1.21124268e-01],
                        [  1.39007568e-01,   1.39007568e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.71569824e-01,   1.71569824e-01],
                        [  1.76849365e-01,   1.76849365e-01],
                        [  1.67633057e-01,   1.67633057e-01],
                        [  1.47552490e-01,   1.47552490e-01],
                        [  1.26770020e-01,   1.26770020e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  6.19812012e-02,   6.19812012e-02],
                        [  5.48400879e-02,   5.48400879e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.97741699e-02,  -4.97741699e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  1.09985352e-01,   1.09985352e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.48223877e-01,   1.48223877e-01],
                        [  1.47094727e-01,   1.47094727e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  6.54907227e-02,   6.54907227e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.02905273e-01,  -1.02905273e-01],
                        [ -1.80206299e-01,  -1.80206299e-01],
                        [ -2.24609375e-01,  -2.24609375e-01],
                        [ -2.22534180e-01,  -2.22534180e-01],
                        [ -1.81518555e-01,  -1.81518555e-01],
                        [ -1.37145996e-01,  -1.37145996e-01],
                        [ -1.28692627e-01,  -1.28692627e-01],
                        [ -1.62139893e-01,  -1.62139893e-01],
                        [ -2.07214355e-01,  -2.07214355e-01],
                        [ -2.31140137e-01,  -2.31140137e-01],
                        [ -2.25189209e-01,  -2.25189209e-01],
                        [ -2.00958252e-01,  -2.00958252e-01],
                        [ -1.71783447e-01,  -1.71783447e-01],
                        [ -1.42974854e-01,  -1.42974854e-01],
                        [ -1.14715576e-01,  -1.14715576e-01],
                        [ -8.68225098e-02,  -8.68225098e-02],
                        [ -6.06689453e-02,  -6.06689453e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.58447266e-01,   1.58447266e-01],
                        [  1.50207520e-01,   1.50207520e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.11480713e-01,   1.11480713e-01],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.43249512e-01,   1.43249512e-01],
                        [  1.71295166e-01,   1.71295166e-01],
                        [  1.92687988e-01,   1.92687988e-01],
                        [  1.99737549e-01,   1.99737549e-01],
                        [  1.89392090e-01,   1.89392090e-01],
                        [  1.63909912e-01,   1.63909912e-01],
                        [  1.30523682e-01,   1.30523682e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  7.01599121e-02,   7.01599121e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  4.11682129e-02,   4.11682129e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  8.61511230e-02,   8.61511230e-02],
                        [  1.18713379e-01,   1.18713379e-01],
                        [  1.48406982e-01,   1.48406982e-01],
                        [  1.60919189e-01,   1.60919189e-01],
                        [  1.47399902e-01,   1.47399902e-01],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  4.01611328e-02,   4.01611328e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -1.28356934e-01,  -1.28356934e-01],
                        [ -1.97753906e-01,  -1.97753906e-01],
                        [ -2.29553223e-01,  -2.29553223e-01],
                        [ -2.25494385e-01,  -2.25494385e-01],
                        [ -2.12615967e-01,  -2.12615967e-01],
                        [ -2.14691162e-01,  -2.14691162e-01],
                        [ -2.28881836e-01,  -2.28881836e-01],
                        [ -2.35137939e-01,  -2.35137939e-01],
                        [ -2.19696045e-01,  -2.19696045e-01],
                        [ -1.86004639e-01,  -1.86004639e-01],
                        [ -1.49078369e-01,  -1.49078369e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -1.12518311e-01,  -1.12518311e-01],
                        [ -1.05255127e-01,  -1.05255127e-01],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  1.20941162e-01,   1.20941162e-01],
                        [  1.45294189e-01,   1.45294189e-01],
                        [  1.50024414e-01,   1.50024414e-01],
                        [  1.42364502e-01,   1.42364502e-01],
                        [  1.36505127e-01,   1.36505127e-01],
                        [  1.44409180e-01,   1.44409180e-01],
                        [  1.67968750e-01,   1.67968750e-01],
                        [  1.95983887e-01,   1.95983887e-01],
                        [  2.11853027e-01,   2.11853027e-01],
                        [  2.07611084e-01,   2.07611084e-01],
                        [  1.88385010e-01,   1.88385010e-01],
                        [  1.63391113e-01,   1.63391113e-01],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  9.80834961e-02,   9.80834961e-02],
                        [  8.06274414e-02,   8.06274414e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  5.31921387e-02,   5.31921387e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  8.85009766e-03,   8.85009766e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  1.49505615e-01,   1.49505615e-01],
                        [  1.76818848e-01,   1.76818848e-01],
                        [  1.80328369e-01,   1.80328369e-01],
                        [  1.58081055e-01,   1.58081055e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  4.20532227e-02,   4.20532227e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -2.09472656e-01,  -2.09472656e-01],
                        [ -2.50610352e-01,  -2.50610352e-01],
                        [ -2.64434814e-01,  -2.64434814e-01],
                        [ -2.61718750e-01,  -2.61718750e-01],
                        [ -2.53845215e-01,  -2.53845215e-01],
                        [ -2.46398926e-01,  -2.46398926e-01],
                        [ -2.33856201e-01,  -2.33856201e-01],
                        [ -2.05566406e-01,  -2.05566406e-01],
                        [ -1.63391113e-01,  -1.63391113e-01],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -1.05102539e-01,  -1.05102539e-01],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -7.82165527e-02,  -7.82165527e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.43096924e-01,   1.43096924e-01],
                        [  1.57440186e-01,   1.57440186e-01],
                        [  1.62109375e-01,   1.62109375e-01],
                        [  1.66961670e-01,   1.66961670e-01],
                        [  1.80572510e-01,   1.80572510e-01],
                        [  1.97784424e-01,   1.97784424e-01],
                        [  2.04803467e-01,   2.04803467e-01],
                        [  1.95861816e-01,   1.95861816e-01],
                        [  1.77185059e-01,   1.77185059e-01],
                        [  1.55914307e-01,   1.55914307e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  8.25805664e-02,   8.25805664e-02],
                        [  6.47583008e-02,   6.47583008e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  3.05175781e-03,   3.05175781e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -6.37207031e-02,  -6.37207031e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  1.25335693e-01,   1.25335693e-01],
                        [  1.60583496e-01,   1.60583496e-01],
                        [  1.85302734e-01,   1.85302734e-01],
                        [  1.86859131e-01,   1.86859131e-01],
                        [  1.54785156e-01,   1.54785156e-01],
                        [  8.56628418e-02,   8.56628418e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.26281738e-01,  -1.26281738e-01],
                        [ -2.30926514e-01,  -2.30926514e-01],
                        [ -3.03497314e-01,  -3.03497314e-01],
                        [ -3.29284668e-01,  -3.29284668e-01],
                        [ -3.13537598e-01,  -3.13537598e-01],
                        [ -2.77740479e-01,  -2.77740479e-01],
                        [ -2.41455078e-01,  -2.41455078e-01],
                        [ -2.10174561e-01,  -2.10174561e-01],
                        [ -1.79840088e-01,  -1.79840088e-01],
                        [ -1.48864746e-01,  -1.48864746e-01],
                        [ -1.22680664e-01,  -1.22680664e-01],
                        [ -1.05895996e-01,  -1.05895996e-01],
                        [ -9.42382812e-02,  -9.42382812e-02],
                        [ -7.96813965e-02,  -7.96813965e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  1.03485107e-01,   1.03485107e-01],
                        [  1.49993896e-01,   1.49993896e-01],
                        [  1.82403564e-01,   1.82403564e-01],
                        [  1.97753906e-01,   1.97753906e-01],
                        [  2.03826904e-01,   2.03826904e-01],
                        [  2.09167480e-01,   2.09167480e-01],
                        [  2.14080811e-01,   2.14080811e-01],
                        [  2.11212158e-01,   2.11212158e-01],
                        [  1.96228027e-01,   1.96228027e-01],
                        [  1.75720215e-01,   1.75720215e-01],
                        [  1.60156250e-01,   1.60156250e-01],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.38031006e-01,   1.38031006e-01],
                        [  1.18133545e-01,   1.18133545e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  7.18383789e-02,   7.18383789e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  7.34252930e-02,   7.34252930e-02],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  1.36474609e-01,   1.36474609e-01],
                        [  1.75964355e-01,   1.75964355e-01],
                        [  2.03369141e-01,   2.03369141e-01],
                        [  2.04559326e-01,   2.04559326e-01],
                        [  1.71386719e-01,   1.71386719e-01],
                        [  9.93957520e-02,   9.93957520e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -2.75146484e-01,  -2.75146484e-01],
                        [ -3.66912842e-01,  -3.66912842e-01],
                        [ -3.93157959e-01,  -3.93157959e-01],
                        [ -3.57055664e-01,  -3.57055664e-01],
                        [ -2.91137695e-01,  -2.91137695e-01],
                        [ -2.30377197e-01,  -2.30377197e-01],
                        [ -1.88476562e-01,  -1.88476562e-01],
                        [ -1.60919189e-01,  -1.60919189e-01],
                        [ -1.39617920e-01,  -1.39617920e-01],
                        [ -1.18804932e-01,  -1.18804932e-01],
                        [ -9.72595215e-02,  -9.72595215e-02],
                        [ -7.99560547e-02,  -7.99560547e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  1.73248291e-01,   1.73248291e-01],
                        [  2.13775635e-01,   2.13775635e-01],
                        [  2.38708496e-01,   2.38708496e-01],
                        [  2.46398926e-01,   2.46398926e-01],
                        [  2.39959717e-01,   2.39959717e-01],
                        [  2.26623535e-01,   2.26623535e-01],
                        [  2.10662842e-01,   2.10662842e-01],
                        [  1.92596436e-01,   1.92596436e-01],
                        [  1.73492432e-01,   1.73492432e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.14318848e-01,   1.14318848e-01],
                        [  9.34143066e-02,   9.34143066e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  6.06079102e-02,   6.06079102e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  4.21142578e-03,   4.21142578e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -7.09838867e-02,  -7.09838867e-02],
                        [ -7.37304688e-02,  -7.37304688e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  1.07879639e-01,   1.07879639e-01],
                        [  1.31286621e-01,   1.31286621e-01],
                        [  1.58935547e-01,   1.58935547e-01],
                        [  1.82739258e-01,   1.82739258e-01],
                        [  1.87896729e-01,   1.87896729e-01],
                        [  1.57958984e-01,   1.57958984e-01],
                        [  8.32519531e-02,   8.32519531e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -1.78588867e-01,  -1.78588867e-01],
                        [ -3.14727783e-01,  -3.14727783e-01],
                        [ -3.99566650e-01,  -3.99566650e-01],
                        [ -4.07684326e-01,  -4.07684326e-01],
                        [ -3.51318359e-01,  -3.51318359e-01],
                        [ -2.69927979e-01,  -2.69927979e-01],
                        [ -2.00683594e-01,  -2.00683594e-01],
                        [ -1.59149170e-01,  -1.59149170e-01],
                        [ -1.38732910e-01,  -1.38732910e-01],
                        [ -1.22039795e-01,  -1.22039795e-01],
                        [ -9.71984863e-02,  -9.71984863e-02],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  1.66442871e-01,   1.66442871e-01],
                        [  2.29736328e-01,   2.29736328e-01],
                        [  2.66479492e-01,   2.66479492e-01],
                        [  2.73132324e-01,   2.73132324e-01],
                        [  2.63000488e-01,   2.63000488e-01],
                        [  2.49023438e-01,   2.49023438e-01],
                        [  2.30926514e-01,   2.30926514e-01],
                        [  2.04711914e-01,   2.04711914e-01],
                        [  1.74468994e-01,   1.74468994e-01],
                        [  1.46423340e-01,   1.46423340e-01],
                        [  1.21276855e-01,   1.21276855e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  7.89184570e-02,   7.89184570e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -7.20825195e-02,  -7.20825195e-02],
                        [ -7.14111328e-02,  -7.14111328e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -7.48901367e-02,  -7.48901367e-02],
                        [ -6.94580078e-02,  -6.94580078e-02],
                        [ -6.16455078e-02,  -6.16455078e-02],
                        [ -5.50537109e-02,  -5.50537109e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  1.27105713e-01,   1.27105713e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.74865723e-01,   1.74865723e-01],
                        [  1.78314209e-01,   1.78314209e-01],
                        [  1.56066895e-01,   1.56066895e-01],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  6.83593750e-03,   6.83593750e-03],
                        [ -1.16516113e-01,  -1.16516113e-01],
                        [ -2.53204346e-01,  -2.53204346e-01],
                        [ -3.68041992e-01,  -3.68041992e-01],
                        [ -4.18548584e-01,  -4.18548584e-01],
                        [ -3.88580322e-01,  -3.88580322e-01],
                        [ -3.07464600e-01,  -3.07464600e-01],
                        [ -2.26226807e-01,  -2.26226807e-01],
                        [ -1.75476074e-01,  -1.75476074e-01],
                        [ -1.50299072e-01,  -1.50299072e-01],
                        [ -1.29425049e-01,  -1.29425049e-01],
                        [ -1.01928711e-01,  -1.01928711e-01],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -6.16455078e-02,  -6.16455078e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -4.10766602e-02,  -4.10766602e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  1.81823730e-01,   1.81823730e-01],
                        [  2.49694824e-01,   2.49694824e-01],
                        [  2.89978027e-01,   2.89978027e-01],
                        [  2.95959473e-01,   2.95959473e-01],
                        [  2.75329590e-01,   2.75329590e-01],
                        [  2.43072510e-01,   2.43072510e-01],
                        [  2.11517334e-01,   2.11517334e-01],
                        [  1.85058594e-01,   1.85058594e-01],
                        [  1.61956787e-01,   1.61956787e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.18743896e-01,   1.18743896e-01],
                        [  9.97924805e-02,   9.97924805e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -7.39440918e-02,  -7.39440918e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  7.05566406e-02,   7.05566406e-02],
                        [  8.61206055e-02,   8.61206055e-02],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  1.33972168e-01,   1.33972168e-01],
                        [  1.60675049e-01,   1.60675049e-01],
                        [  1.80694580e-01,   1.80694580e-01],
                        [  1.77581787e-01,   1.77581787e-01],
                        [  1.41204834e-01,   1.41204834e-01],
                        [  6.92749023e-02,   6.92749023e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -1.71386719e-01,  -1.71386719e-01],
                        [ -3.00537109e-01,  -3.00537109e-01],
                        [ -3.82934570e-01,  -3.82934570e-01],
                        [ -3.93157959e-01,  -3.93157959e-01],
                        [ -3.41369629e-01,  -3.41369629e-01],
                        [ -2.63946533e-01,  -2.63946533e-01],
                        [ -1.97509766e-01,  -1.97509766e-01],
                        [ -1.57745361e-01,  -1.57745361e-01],
                        [ -1.37664795e-01,  -1.37664795e-01],
                        [ -1.23046875e-01,  -1.23046875e-01],
                        [ -1.07513428e-01,  -1.07513428e-01],
                        [ -9.38415527e-02,  -9.38415527e-02],
                        [ -8.42590332e-02,  -8.42590332e-02],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.96136475e-01,   1.96136475e-01],
                        [  2.65014648e-01,   2.65014648e-01],
                        [  3.02612305e-01,   3.02612305e-01],
                        [  3.01269531e-01,   3.01269531e-01],
                        [  2.70202637e-01,   2.70202637e-01],
                        [  2.29827881e-01,   2.29827881e-01],
                        [  1.97662354e-01,   1.97662354e-01],
                        [  1.77764893e-01,   1.77764893e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.50787354e-01,   1.50787354e-01],
                        [  1.36108398e-01,   1.36108398e-01],
                        [  1.19079590e-01,   1.19079590e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -8.40759277e-02,  -8.40759277e-02],
                        [ -8.09631348e-02,  -8.09631348e-02],
                        [ -7.09228516e-02,  -7.09228516e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  7.30590820e-02,   7.30590820e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  1.08489990e-01,   1.08489990e-01],
                        [  1.27899170e-01,   1.27899170e-01],
                        [  1.53472900e-01,   1.53472900e-01],
                        [  1.73400879e-01,   1.73400879e-01],
                        [  1.71661377e-01,   1.71661377e-01],
                        [  1.36047363e-01,   1.36047363e-01],
                        [  6.11877441e-02,   6.11877441e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -1.82891846e-01,  -1.82891846e-01],
                        [ -3.04565430e-01,  -3.04565430e-01],
                        [ -3.78112793e-01,  -3.78112793e-01],
                        [ -3.83605957e-01,  -3.83605957e-01],
                        [ -3.32000732e-01,  -3.32000732e-01],
                        [ -2.57476807e-01,  -2.57476807e-01],
                        [ -1.94458008e-01,  -1.94458008e-01],
                        [ -1.57409668e-01,  -1.57409668e-01],
                        [ -1.38244629e-01,  -1.38244629e-01],
                        [ -1.22009277e-01,  -1.22009277e-01],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -8.38928223e-02,  -8.38928223e-02],
                        [ -6.91833496e-02,  -6.91833496e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  1.84753418e-01,   1.84753418e-01],
                        [  2.63610840e-01,   2.63610840e-01],
                        [  3.13110352e-01,   3.13110352e-01],
                        [  3.20495605e-01,   3.20495605e-01],
                        [  2.91381836e-01,   2.91381836e-01],
                        [  2.45880127e-01,   2.45880127e-01],
                        [  2.04986572e-01,   2.04986572e-01],
                        [  1.77154541e-01,   1.77154541e-01],
                        [  1.56982422e-01,   1.56982422e-01],
                        [  1.37451172e-01,   1.37451172e-01],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  7.00378418e-02,   7.00378418e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  3.37829590e-02,   3.37829590e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -5.66711426e-02,  -5.66711426e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -6.82678223e-02,  -6.82678223e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -6.37207031e-02,  -6.37207031e-02],
                        [ -6.25000000e-02,  -6.25000000e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -5.91735840e-02,  -5.91735840e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  1.06445312e-01,   1.06445312e-01],
                        [  1.33453369e-01,   1.33453369e-01],
                        [  1.60949707e-01,   1.60949707e-01],
                        [  1.76971436e-01,   1.76971436e-01],
                        [  1.69097900e-01,   1.69097900e-01],
                        [  1.33087158e-01,   1.33087158e-01],
                        [  7.17163086e-02,   7.17163086e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -1.04461670e-01,  -1.04461670e-01],
                        [ -2.04040527e-01,  -2.04040527e-01],
                        [ -2.92358398e-01,  -2.92358398e-01],
                        [ -3.47564697e-01,  -3.47564697e-01],
                        [ -3.54797363e-01,  -3.54797363e-01],
                        [ -3.18115234e-01,  -3.18115234e-01],
                        [ -2.57904053e-01,  -2.57904053e-01],
                        [ -1.98974609e-01,  -1.98974609e-01],
                        [ -1.57379150e-01,  -1.57379150e-01],
                        [ -1.31164551e-01,  -1.31164551e-01],
                        [ -1.07055664e-01,  -1.07055664e-01],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  1.85455322e-01,   1.85455322e-01],
                        [  2.56835938e-01,   2.56835938e-01],
                        [  2.98736572e-01,   2.98736572e-01],
                        [  3.03741455e-01,   3.03741455e-01],
                        [  2.79602051e-01,   2.79602051e-01],
                        [  2.42492676e-01,   2.42492676e-01],
                        [  2.05078125e-01,   2.05078125e-01],
                        [  1.72485352e-01,   1.72485352e-01],
                        [  1.46179199e-01,   1.46179199e-01],
                        [  1.26770020e-01,   1.26770020e-01],
                        [  1.12487793e-01,   1.12487793e-01],
                        [  1.00372314e-01,   1.00372314e-01],
                        [  8.86535645e-02,   8.86535645e-02],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -7.65686035e-02,  -7.65686035e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -6.38732910e-02,  -6.38732910e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  9.98840332e-02,   9.98840332e-02],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  1.43585205e-01,   1.43585205e-01],
                        [  1.60614014e-01,   1.60614014e-01],
                        [  1.61102295e-01,   1.61102295e-01],
                        [  1.35833740e-01,   1.35833740e-01],
                        [  8.56933594e-02,   8.56933594e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -1.51367188e-01,  -1.51367188e-01],
                        [ -2.36511230e-01,  -2.36511230e-01],
                        [ -3.07159424e-01,  -3.07159424e-01],
                        [ -3.46923828e-01,  -3.46923828e-01],
                        [ -3.41613770e-01,  -3.41613770e-01],
                        [ -2.93731689e-01,  -2.93731689e-01],
                        [ -2.26745605e-01,  -2.26745605e-01],
                        [ -1.69677734e-01,  -1.69677734e-01],
                        [ -1.36444092e-01,  -1.36444092e-01],
                        [ -1.18438721e-01,  -1.18438721e-01],
                        [ -9.95788574e-02,  -9.95788574e-02],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -5.19714355e-02,  -5.19714355e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  1.08520508e-01,   1.08520508e-01],
                        [  1.86859131e-01,   1.86859131e-01],
                        [  2.55706787e-01,   2.55706787e-01],
                        [  2.98370361e-01,   2.98370361e-01],
                        [  3.07769775e-01,   3.07769775e-01],
                        [  2.86743164e-01,   2.86743164e-01],
                        [  2.45544434e-01,   2.45544434e-01],
                        [  1.99340820e-01,   1.99340820e-01],
                        [  1.61285400e-01,   1.61285400e-01],
                        [  1.36444092e-01,   1.36444092e-01],
                        [  1.22558594e-01,   1.22558594e-01],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -6.43920898e-02,  -6.43920898e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.75354004e-02,  -6.75354004e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  9.11254883e-02,   9.11254883e-02],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.45019531e-01,   1.45019531e-01],
                        [  1.44134521e-01,   1.44134521e-01],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  8.82568359e-02,   8.82568359e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -9.02709961e-02,  -9.02709961e-02],
                        [ -1.54785156e-01,  -1.54785156e-01],
                        [ -2.20916748e-01,  -2.20916748e-01],
                        [ -2.85675049e-01,  -2.85675049e-01],
                        [ -3.32336426e-01,  -3.32336426e-01],
                        [ -3.38012695e-01,  -3.38012695e-01],
                        [ -2.96386719e-01,  -2.96386719e-01],
                        [ -2.29522705e-01,  -2.29522705e-01],
                        [ -1.70654297e-01,  -1.70654297e-01],
                        [ -1.34613037e-01,  -1.34613037e-01],
                        [ -1.11206055e-01,  -1.11206055e-01],
                        [ -8.65173340e-02,  -8.65173340e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  3.05175781e-03,   3.05175781e-03],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  1.48437500e-01,   1.48437500e-01],
                        [  2.14233398e-01,   2.14233398e-01],
                        [  2.66204834e-01,   2.66204834e-01],
                        [  2.92510986e-01,   2.92510986e-01],
                        [  2.88269043e-01,   2.88269043e-01],
                        [  2.58239746e-01,   2.58239746e-01],
                        [  2.17315674e-01,   2.17315674e-01],
                        [  1.81396484e-01,   1.81396484e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -5.95092773e-02,  -5.95092773e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  6.85119629e-02,   6.85119629e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  1.20513916e-01,   1.20513916e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  1.23779297e-01,   1.23779297e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  6.95495605e-02,   6.95495605e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -1.93359375e-01,  -1.93359375e-01],
                        [ -2.75909424e-01,  -2.75909424e-01],
                        [ -3.33923340e-01,  -3.33923340e-01],
                        [ -3.32427979e-01,  -3.32427979e-01],
                        [ -2.75177002e-01,  -2.75177002e-01],
                        [ -1.99310303e-01,  -1.99310303e-01],
                        [ -1.41967773e-01,  -1.41967773e-01],
                        [ -1.14013672e-01,  -1.14013672e-01],
                        [ -9.98229980e-02,  -9.98229980e-02],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  6.93054199e-02,   6.93054199e-02],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.74499512e-01,   1.74499512e-01],
                        [  2.20489502e-01,   2.20489502e-01],
                        [  2.56835938e-01,   2.56835938e-01],
                        [  2.79388428e-01,   2.79388428e-01],
                        [  2.80883789e-01,   2.80883789e-01],
                        [  2.57537842e-01,   2.57537842e-01],
                        [  2.17803955e-01,   2.17803955e-01],
                        [  1.76940918e-01,   1.76940918e-01],
                        [  1.44500732e-01,   1.44500732e-01],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  9.32617188e-02,   9.32617188e-02],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -9.18579102e-03,  -9.18579102e-03],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -5.74340820e-02,  -5.74340820e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  7.95898438e-02,   7.95898438e-02],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  1.16424561e-01,   1.16424561e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -1.03302002e-01,  -1.03302002e-01],
                        [ -1.86065674e-01,  -1.86065674e-01],
                        [ -2.72979736e-01,  -2.72979736e-01],
                        [ -3.23852539e-01,  -3.23852539e-01],
                        [ -3.15155029e-01,  -3.15155029e-01],
                        [ -2.59399414e-01,  -2.59399414e-01],
                        [ -1.93481445e-01,  -1.93481445e-01],
                        [ -1.45782471e-01,  -1.45782471e-01],
                        [ -1.17156982e-01,  -1.17156982e-01],
                        [ -9.29870605e-02,  -9.29870605e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  1.11358643e-01,   1.11358643e-01],
                        [  1.50268555e-01,   1.50268555e-01],
                        [  1.87591553e-01,   1.87591553e-01],
                        [  2.22381592e-01,   2.22381592e-01],
                        [  2.55004883e-01,   2.55004883e-01],
                        [  2.77008057e-01,   2.77008057e-01],
                        [  2.73071289e-01,   2.73071289e-01],
                        [  2.39532471e-01,   2.39532471e-01],
                        [  1.92504883e-01,   1.92504883e-01],
                        [  1.51611328e-01,   1.51611328e-01],
                        [  1.23565674e-01,   1.23565674e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  7.93151855e-02,   7.93151855e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -7.01599121e-02,  -7.01599121e-02],
                        [ -7.36694336e-02,  -7.36694336e-02],
                        [ -8.00781250e-02,  -8.00781250e-02],
                        [ -8.11767578e-02,  -8.11767578e-02],
                        [ -7.11975098e-02,  -7.11975098e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  9.82971191e-02,   9.82971191e-02],
                        [  1.10534668e-01,   1.10534668e-01],
                        [  1.15356445e-01,   1.15356445e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -9.58557129e-02,  -9.58557129e-02],
                        [ -1.84600830e-01,  -1.84600830e-01],
                        [ -2.70355225e-01,  -2.70355225e-01],
                        [ -3.14208984e-01,  -3.14208984e-01],
                        [ -3.00018311e-01,  -3.00018311e-01],
                        [ -2.43957520e-01,  -2.43957520e-01],
                        [ -1.79626465e-01,  -1.79626465e-01],
                        [ -1.33209229e-01,  -1.33209229e-01],
                        [ -1.08520508e-01,  -1.08520508e-01],
                        [ -9.05761719e-02,  -9.05761719e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  1.34307861e-01,   1.34307861e-01],
                        [  1.56768799e-01,   1.56768799e-01],
                        [  1.86706543e-01,   1.86706543e-01],
                        [  2.21160889e-01,   2.21160889e-01],
                        [  2.48077393e-01,   2.48077393e-01],
                        [  2.55004883e-01,   2.55004883e-01],
                        [  2.40936279e-01,   2.40936279e-01],
                        [  2.15728760e-01,   2.15728760e-01],
                        [  1.87683105e-01,   1.87683105e-01],
                        [  1.59118652e-01,   1.59118652e-01],
                        [  1.31835938e-01,   1.31835938e-01],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  8.45336914e-02,   8.45336914e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -6.78710938e-02,  -6.78710938e-02],
                        [ -6.84204102e-02,  -6.84204102e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -6.35681152e-02,  -6.35681152e-02],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -7.64160156e-02,  -7.64160156e-02],
                        [ -7.42187500e-02,  -7.42187500e-02],
                        [ -6.38732910e-02,  -6.38732910e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  9.92736816e-02,   9.92736816e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -1.60675049e-01,  -1.60675049e-01],
                        [ -2.43713379e-01,  -2.43713379e-01],
                        [ -2.93029785e-01,  -2.93029785e-01],
                        [ -2.88787842e-01,  -2.88787842e-01],
                        [ -2.39044189e-01,  -2.39044189e-01],
                        [ -1.73583984e-01,  -1.73583984e-01],
                        [ -1.19293213e-01,  -1.19293213e-01],
                        [ -8.48388672e-02,  -8.48388672e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  9.15527344e-04,   9.15527344e-04],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  8.77380371e-02,   8.77380371e-02],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  1.08489990e-01,   1.08489990e-01],
                        [  1.12762451e-01,   1.12762451e-01],
                        [  1.34765625e-01,   1.34765625e-01],
                        [  1.75506592e-01,   1.75506592e-01],
                        [  2.19848633e-01,   2.19848633e-01],
                        [  2.44995117e-01,   2.44995117e-01],
                        [  2.38677979e-01,   2.38677979e-01],
                        [  2.08099365e-01,   2.08099365e-01],
                        [  1.70745850e-01,   1.70745850e-01],
                        [  1.41784668e-01,   1.41784668e-01],
                        [  1.26434326e-01,   1.26434326e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.61218262e-02,  -5.61218262e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -6.74743652e-02,  -6.74743652e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -7.38220215e-02,  -7.38220215e-02],
                        [ -7.66296387e-02,  -7.66296387e-02],
                        [ -7.20520020e-02,  -7.20520020e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -8.39233398e-02,  -8.39233398e-02],
                        [ -9.32006836e-02,  -9.32006836e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -1.41693115e-01,  -1.41693115e-01],
                        [ -2.18475342e-01,  -2.18475342e-01],
                        [ -2.68157959e-01,  -2.68157959e-01],
                        [ -2.69348145e-01,  -2.69348145e-01],
                        [ -2.27233887e-01,  -2.27233887e-01],
                        [ -1.69219971e-01,  -1.69219971e-01],
                        [ -1.21002197e-01,  -1.21002197e-01],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  1.01379395e-01,   1.01379395e-01],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  1.11633301e-01,   1.11633301e-01],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.47918701e-01,   1.47918701e-01],
                        [  1.87438965e-01,   1.87438965e-01],
                        [  2.20489502e-01,   2.20489502e-01],
                        [  2.34375000e-01,   2.34375000e-01],
                        [  2.26593018e-01,   2.26593018e-01],
                        [  2.01263428e-01,   2.01263428e-01],
                        [  1.68548584e-01,   1.68548584e-01],
                        [  1.40411377e-01,   1.40411377e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.00097656e-01,   1.00097656e-01],
                        [  8.01696777e-02,   8.02001953e-02],
                        [  6.53076172e-02,   6.53076172e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -7.82165527e-02,  -7.82165527e-02],
                        [ -8.08105469e-02,  -8.08105469e-02],
                        [ -8.16650391e-02,  -8.16650391e-02],
                        [ -8.00476074e-02,  -8.00476074e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -2.12402344e-02,  -2.12707520e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  1.02172852e-01,   1.02172852e-01],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  9.06066895e-02,   9.06372070e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -6.15234375e-02,  -6.15234375e-02],
                        [ -9.98535156e-02,  -9.98229980e-02],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -8.93554688e-02,  -8.93554688e-02],
                        [ -1.78710938e-01,  -1.78710938e-01],
                        [ -2.57629395e-01,  -2.57629395e-01],
                        [ -2.93518066e-01,  -2.93518066e-01],
                        [ -2.73315430e-01,  -2.73315430e-01],
                        [ -2.14416504e-01,  -2.14416504e-01],
                        [ -1.49688721e-01,  -1.49688721e-01],
                        [ -1.04766846e-01,  -1.04766846e-01],
                        [ -8.50219727e-02,  -8.50219727e-02],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  2.34069824e-02,   2.33764648e-02],
                        [  2.32238770e-02,   2.32543945e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  1.56372070e-01,   1.56372070e-01],
                        [  2.04193115e-01,   2.04193115e-01],
                        [  2.39807129e-01,   2.39807129e-01],
                        [  2.48168945e-01,   2.48168945e-01],
                        [  2.29370117e-01,   2.29370117e-01],
                        [  1.97601318e-01,   1.97601318e-01],
                        [  1.66656494e-01,   1.66656494e-01],
                        [  1.41326904e-01,   1.41326904e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  7.42797852e-02,   7.42797852e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.80957031e-02,   4.80957031e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  3.87878418e-02,   3.88183594e-02],
                        [  3.87878418e-02,   3.87573242e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -2.01110840e-02,  -2.01416016e-02],
                        [ -3.23486328e-02,  -3.23181152e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.53796387e-02,  -4.53796387e-02],
                        [ -4.97741699e-02,  -4.97741699e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -4.59289551e-02,  -4.58984375e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.61328125e-02,  -3.61022949e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -6.71997070e-02,  -6.71997070e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -7.95593262e-02,  -7.95593262e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.84118652e-02,  -2.84423828e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  7.72399902e-02,   7.72399902e-02],
                        [  8.33129883e-02,   8.33129883e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  2.32849121e-02,   2.33154297e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -7.16247559e-02,  -7.16247559e-02],
                        [ -1.02905273e-01,  -1.02874756e-01],
                        [ -9.86022949e-02,  -9.86022949e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  2.05383301e-02,   2.05688477e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -9.90600586e-02,  -9.90905762e-02],
                        [ -1.76361084e-01,  -1.76361084e-01],
                        [ -2.37701416e-01,  -2.37670898e-01],
                        [ -2.59521484e-01,  -2.59521484e-01],
                        [ -2.36572266e-01,  -2.36572266e-01],
                        [ -1.86096191e-01,  -1.86096191e-01],
                        [ -1.34033203e-01,  -1.34033203e-01],
                        [ -9.76562500e-02,  -9.76562500e-02],
                        [ -7.82775879e-02,  -7.82470703e-02],
                        [ -6.60400391e-02,  -6.60400391e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -3.43322754e-02,  -3.43017578e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  7.28759766e-02,   7.28759766e-02],
                        [  9.16748047e-02,   9.17053223e-02],
                        [  1.01684570e-01,   1.01684570e-01],
                        [  9.88159180e-02,   9.87854004e-02],
                        [  8.66699219e-02,   8.66699219e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  9.82666016e-02,   9.82666016e-02],
                        [  1.36901855e-01,   1.36932373e-01],
                        [  1.82189941e-01,   1.82220459e-01],
                        [  2.18017578e-01,   2.18017578e-01],
                        [  2.31109619e-01,   2.31109619e-01],
                        [  2.19238281e-01,   2.19238281e-01],
                        [  1.90979004e-01,   1.90979004e-01],
                        [  1.58782959e-01,   1.58782959e-01],
                        [  1.32476807e-01,   1.32476807e-01],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  9.98535156e-02,   9.98535156e-02],
                        [  8.15124512e-02,   8.15124512e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  5.54809570e-02,   5.54504395e-02],
                        [  5.00183105e-02,   5.00183105e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  2.98767090e-02,   2.98461914e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -3.89099121e-02,  -3.88793945e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -6.96411133e-02,  -6.96411133e-02],
                        [ -7.25097656e-02,  -7.25097656e-02],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -6.46362305e-02,  -6.46362305e-02],
                        [ -5.82580566e-02,  -5.82885742e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -4.36401367e-02,  -4.36706543e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -2.95715332e-02,  -2.95410156e-02],
                        [ -2.28576660e-02,  -2.28881836e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  5.00183105e-02,   5.00183105e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -1.00463867e-01,  -1.00463867e-01],
                        [ -1.18957520e-01,  -1.18957520e-01],
                        [ -1.00677490e-01,  -1.00677490e-01],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  6.31713867e-03,   6.31713867e-03],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -1.34948730e-01,  -1.34948730e-01],
                        [ -2.15118408e-01,  -2.15118408e-01],
                        [ -2.64312744e-01,  -2.64282227e-01],
                        [ -2.63946533e-01,  -2.63946533e-01],
                        [ -2.18933105e-01,  -2.18933105e-01],
                        [ -1.53045654e-01,  -1.53015137e-01],
                        [ -9.42993164e-02,  -9.43298340e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -3.35388184e-02,  -3.35083008e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  1.01898193e-01,   1.01928711e-01],
                        [  1.27777100e-01,   1.27777100e-01],
                        [  1.33270264e-01,   1.33239746e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  9.01184082e-02,   9.01184082e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  6.61315918e-02,   6.61621094e-02],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.49505615e-01,   1.49505615e-01],
                        [  1.92321777e-01,   1.92321777e-01],
                        [  2.20520020e-01,   2.20520020e-01],
                        [  2.27600098e-01,   2.27630615e-01],
                        [  2.10876465e-01,   2.10876465e-01],
                        [  1.78771973e-01,   1.78771973e-01],
                        [  1.48254395e-01,   1.48254395e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  8.66394043e-02,   8.66699219e-02],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  8.17565918e-02,   8.17260742e-02],
                        [  8.67614746e-02,   8.67614746e-02],
                        [  8.20007324e-02,   8.20007324e-02],
                        [  6.65283203e-02,   6.65283203e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  2.13623047e-03,   2.10571289e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.89208984e-03,   1.92260742e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  7.44628906e-03,   7.47680664e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [ -8.30078125e-03,  -8.27026367e-03],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -6.51855469e-02,  -6.51550293e-02],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -6.58569336e-02,  -6.58569336e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.92041016e-02,  -5.92041016e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -4.62646484e-02,  -4.62951660e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -4.05273438e-02,  -4.04968262e-02],
                        [ -3.48510742e-02,  -3.48815918e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  9.53063965e-02,   9.53063965e-02],
                        [  8.16955566e-02,   8.16955566e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -1.39770508e-01,  -1.39770508e-01],
                        [ -1.44927979e-01,  -1.44927979e-01],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  4.45556641e-02,   4.45861816e-02],
                        [  5.94177246e-02,   5.94177246e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  1.55639648e-03,   1.55639648e-03],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -1.64520264e-01,  -1.64520264e-01],
                        [ -2.40875244e-01,  -2.40875244e-01],
                        [ -2.74505615e-01,  -2.74505615e-01],
                        [ -2.52593994e-01,  -2.52593994e-01],
                        [ -1.92626953e-01,  -1.92626953e-01],
                        [ -1.31530762e-01,  -1.31500244e-01],
                        [ -9.55505371e-02,  -9.55505371e-02],
                        [ -8.23974609e-02,  -8.23974609e-02],
                        [ -7.34252930e-02,  -7.34252930e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -3.98559570e-02,  -3.98864746e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.34375000e-02,   2.34069824e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  1.44958496e-02,   1.44653320e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  1.26251221e-01,   1.26251221e-01],
                        [  1.34826660e-01,   1.34826660e-01],
                        [  1.21246338e-01,   1.21246338e-01],
                        [  9.49401855e-02,   9.49401855e-02],
                        [  7.14416504e-02,   7.14416504e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  1.46057129e-01,   1.46057129e-01],
                        [  1.87835693e-01,   1.87835693e-01],
                        [  2.15454102e-01,   2.15454102e-01],
                        [  2.21374512e-01,   2.21374512e-01],
                        [  2.04925537e-01,   2.04925537e-01],
                        [  1.72515869e-01,   1.72485352e-01],
                        [  1.37054443e-01,   1.37054443e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  9.72900391e-02,   9.72900391e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  8.25195312e-02,   8.25195312e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  6.87866211e-02,   6.87561035e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  5.38024902e-02,   5.37719727e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  2.54821777e-02,   2.54516602e-02],
                        [  1.81274414e-02,   1.80969238e-02],
                        [  7.75146484e-03,   7.78198242e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  1.98364258e-03,   1.95312500e-03],
                        [  7.62939453e-03,   7.65991211e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -9.36889648e-03,  -9.39941406e-03],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.51354980e-02,  -4.51660156e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -6.17065430e-02,  -6.16760254e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -6.84204102e-02,  -6.84204102e-02],
                        [ -6.67724609e-02,  -6.67724609e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -6.25000000e-02,  -6.25000000e-02],
                        [ -6.21032715e-02,  -6.21337891e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -6.10351562e-02,  -6.10046387e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.36608887e-02,  -3.36914062e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -1.29394531e-02,  -1.29089355e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.33056641e-02,  -1.32751465e-02],
                        [ -4.88281250e-04,  -5.18798828e-04],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  5.70983887e-02,   5.70678711e-02],
                        [  6.80847168e-02,   6.80847168e-02],
                        [  7.21740723e-02,   7.22045898e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -7.94982910e-02,  -7.94982910e-02],
                        [ -1.23718262e-01,  -1.23748779e-01],
                        [ -1.35681152e-01,  -1.35681152e-01],
                        [ -1.08123779e-01,  -1.08123779e-01],
                        [ -5.28259277e-02,  -5.28564453e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -1.22375488e-01,  -1.22375488e-01],
                        [ -2.13317871e-01,  -2.13317871e-01],
                        [ -2.68798828e-01,  -2.68798828e-01],
                        [ -2.69287109e-01,  -2.69287109e-01],
                        [ -2.23358154e-01,  -2.23358154e-01],
                        [ -1.61376953e-01,  -1.61376953e-01],
                        [ -1.12640381e-01,  -1.12640381e-01],
                        [ -8.59069824e-02,  -8.59069824e-02],
                        [ -7.25402832e-02,  -7.25402832e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -1.48010254e-02,  -1.47705078e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  2.75878906e-02,   2.75573730e-02],
                        [  3.88793945e-02,   3.89099121e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  3.11279297e-02,   3.10974121e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  7.08923340e-02,   7.09228516e-02],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.21673584e-01,   1.21673584e-01],
                        [  1.09771729e-01,   1.09802246e-01],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  6.39038086e-02,   6.39343262e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.39434814e-01,   1.39434814e-01],
                        [  1.75781250e-01,   1.75781250e-01],
                        [  2.06268311e-01,   2.06268311e-01],
                        [  2.20764160e-01,   2.20764160e-01],
                        [  2.12493896e-01,   2.12493896e-01],
                        [  1.84783936e-01,   1.84783936e-01],
                        [  1.49566650e-01,   1.49566650e-01],
                        [  1.17340088e-01,   1.17340088e-01],
                        [  9.13391113e-02,   9.13696289e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  6.64978027e-02,   6.64978027e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  5.51147461e-02,   5.51452637e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [ -3.23486328e-03,  -3.26538086e-03],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.91333008e-02,  -4.91638184e-02],
                        [ -4.74853516e-02,  -4.74853516e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -5.26123047e-02,  -5.26428223e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -4.74548340e-02,  -4.74853516e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.01306152e-02,  -4.01000977e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -5.82885742e-02,  -5.82580566e-02],
                        [ -6.74743652e-02,  -6.74743652e-02],
                        [ -7.23266602e-02,  -7.23571777e-02],
                        [ -7.52868652e-02,  -7.52563477e-02],
                        [ -7.50122070e-02,  -7.50122070e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -6.43005371e-02,  -6.42700195e-02],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -6.78710938e-02,  -6.79016113e-02],
                        [ -6.14318848e-02,  -6.14013672e-02],
                        [ -5.50842285e-02,  -5.50842285e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  3.00598145e-02,   3.00292969e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  5.13000488e-02,   5.12695312e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -6.87866211e-02,  -6.87866211e-02],
                        [ -1.31561279e-01,  -1.31561279e-01],
                        [ -1.66046143e-01,  -1.66046143e-01],
                        [ -1.56982422e-01,  -1.56982422e-01],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [  1.28173828e-02,   1.28479004e-02],
                        [  5.14526367e-02,   5.14526367e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  7.19299316e-02,   7.19604492e-02],
                        [  4.06494141e-02,   4.06188965e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -1.25122070e-01,  -1.25091553e-01],
                        [ -2.14935303e-01,  -2.14935303e-01],
                        [ -2.64587402e-01,  -2.64617920e-01],
                        [ -2.57507324e-01,  -2.57507324e-01],
                        [ -2.05444336e-01,  -2.05444336e-01],
                        [ -1.41967773e-01,  -1.41998291e-01],
                        [ -9.69543457e-02,  -9.69543457e-02],
                        [ -7.54089355e-02,  -7.53784180e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -5.94482422e-02,  -5.94787598e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -1.98059082e-02,  -1.97753906e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  1.17156982e-01,   1.17156982e-01],
                        [  1.38000488e-01,   1.37969971e-01],
                        [  1.35620117e-01,   1.35620117e-01],
                        [  1.14471436e-01,   1.14501953e-01],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  7.14111328e-02,   7.13806152e-02],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.59301758e-01,   1.59301758e-01],
                        [  2.03796387e-01,   2.03796387e-01],
                        [  2.25830078e-01,   2.25799561e-01],
                        [  2.20336914e-01,   2.20367432e-01],
                        [  1.95465088e-01,   1.95495605e-01],
                        [  1.62933350e-01,   1.62933350e-01],
                        [  1.31072998e-01,   1.31072998e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  8.44726562e-02,   8.44726562e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  5.37719727e-02,   5.37414551e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  4.97131348e-02,   4.97436523e-02],
                        [  4.69360352e-02,   4.69360352e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -6.71386719e-03,  -6.74438477e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -9.15527344e-03,  -9.18579102e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -2.66113281e-02,  -2.66418457e-02],
                        [ -3.29895020e-02,  -3.29589844e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.86657715e-02,  -3.86962891e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -5.06591797e-02,  -5.06286621e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -5.16052246e-02,  -5.16357422e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -6.34765625e-02,  -6.35070801e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -5.61828613e-02,  -5.62133789e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -6.09130859e-02,  -6.08825684e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -7.45544434e-02,  -7.45239258e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -5.16967773e-02,  -5.17272949e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -1.98059082e-02,  -1.98364258e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.04870605e-02,  -3.05175781e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  6.99462891e-02,   6.99462891e-02],
                        [  7.22656250e-02,   7.22656250e-02],
                        [  5.42297363e-02,   5.42602539e-02],
                        [  5.79833984e-03,   5.76782227e-03],
                        [ -6.44836426e-02,  -6.45141602e-02],
                        [ -1.28448486e-01,  -1.28417969e-01],
                        [ -1.58050537e-01,  -1.58050537e-01],
                        [ -1.45416260e-01,  -1.45416260e-01],
                        [ -1.03668213e-01,  -1.03637695e-01],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -1.24206543e-02,  -1.24511719e-02],
                        [  1.72729492e-02,   1.73034668e-02],
                        [  3.97338867e-02,   3.97644043e-02],
                        [  5.47180176e-02,   5.46875000e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  1.31835938e-02,   1.32141113e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -1.55700684e-01,  -1.55731201e-01],
                        [ -2.31811523e-01,  -2.31811523e-01],
                        [ -2.58880615e-01,  -2.58880615e-01],
                        [ -2.35229492e-01,  -2.35260010e-01],
                        [ -1.82922363e-01,  -1.82922363e-01],
                        [ -1.26983643e-01,  -1.26953125e-01],
                        [ -8.59985352e-02,  -8.60290527e-02],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -6.21032715e-02,  -6.20727539e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.70080566e-02,   2.70385742e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  1.79443359e-02,   1.79748535e-02],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  5.99060059e-02,   5.99365234e-02],
                        [  9.61914062e-02,   9.61914062e-02],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.49200439e-01,   1.49230957e-01],
                        [  1.50299072e-01,   1.50299072e-01],
                        [  1.30218506e-01,   1.30187988e-01],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  1.89788818e-01,   1.89788818e-01],
                        [  2.14813232e-01,   2.14813232e-01],
                        [  2.16674805e-01,   2.16674805e-01],
                        [  1.95617676e-01,   1.95617676e-01],
                        [  1.62445068e-01,   1.62445068e-01],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  1.14959717e-01,   1.14959717e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  6.06994629e-02,   6.06994629e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  4.11987305e-02,   4.12292480e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.60620117e-02,   2.60925293e-02],
                        [  2.53906250e-02,   2.53601074e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.01623535e-02,   1.01928711e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.80053711e-02,  -1.80358887e-02],
                        [ -3.08837891e-02,  -3.08532715e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -3.88793945e-02,  -3.89099121e-02],
                        [ -3.65295410e-02,  -3.64990234e-02],
                        [ -3.49731445e-02,  -3.49426270e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -3.33862305e-02,  -3.33557129e-02],
                        [ -3.45458984e-02,  -3.45764160e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.34570312e-02,  -4.34875488e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.93469238e-02,  -4.93164062e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -7.29675293e-02,  -7.29675293e-02],
                        [ -7.78808594e-02,  -7.79113770e-02],
                        [ -7.83081055e-02,  -7.83386230e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -6.39648438e-02,  -6.39953613e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.69763184e-02,  -5.69458008e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -6.49108887e-02,  -6.49108887e-02],
                        [ -6.73522949e-02,  -6.73522949e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -4.45861816e-02,  -4.45556641e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  8.31298828e-02,   8.31298828e-02],
                        [  9.38720703e-02,   9.38720703e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  3.65600586e-02,   3.65295410e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -1.15661621e-01,  -1.15661621e-01],
                        [ -1.69433594e-01,  -1.69433594e-01],
                        [ -1.77978516e-01,  -1.77978516e-01],
                        [ -1.44287109e-01,  -1.44287109e-01],
                        [ -8.79211426e-02,  -8.79211426e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.13464355e-01,  -1.13464355e-01],
                        [ -2.01446533e-01,  -2.01446533e-01],
                        [ -2.60986328e-01,  -2.60986328e-01],
                        [ -2.71728516e-01,  -2.71728516e-01],
                        [ -2.33032227e-01,  -2.33032227e-01],
                        [ -1.67785645e-01,  -1.67816162e-01],
                        [ -1.08428955e-01,  -1.08428955e-01],
                        [ -7.46154785e-02,  -7.45849609e-02],
                        [ -6.38122559e-02,  -6.38427734e-02],
                        [ -6.16149902e-02,  -6.16455078e-02],
                        [ -5.76477051e-02,  -5.76171875e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -4.62951660e-02,  -4.63256836e-02],
                        [ -3.62243652e-02,  -3.61938477e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [  1.27258301e-02,   1.26953125e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  5.07507324e-02,   5.07812500e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  4.01000977e-02,   4.00695801e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  1.44439697e-01,   1.44439697e-01],
                        [  1.61071777e-01,   1.61071777e-01],
                        [  1.49719238e-01,   1.49719238e-01],
                        [  1.16027832e-01,   1.16027832e-01],
                        [  7.68737793e-02,   7.68737793e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.60247803e-01,   1.60247803e-01],
                        [  2.00897217e-01,   2.00897217e-01],
                        [  2.21527100e-01,   2.21527100e-01],
                        [  2.16674805e-01,   2.16674805e-01],
                        [  1.91528320e-01,   1.91497803e-01],
                        [  1.58172607e-01,   1.58172607e-01],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  1.04492188e-01,   1.04461670e-01],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  5.46875000e-02,   5.46569824e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  3.80249023e-02,   3.80554199e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  1.91650391e-02,   1.91345215e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  3.05175781e-04,   2.74658203e-04],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -4.60815430e-02,  -4.60510254e-02],
                        [ -4.40673828e-02,  -4.40979004e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -5.47485352e-02,  -5.47790527e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -5.23986816e-02,  -5.23681641e-02],
                        [ -4.95300293e-02,  -4.95605469e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -5.59692383e-02,  -5.59387207e-02],
                        [ -6.39648438e-02,  -6.39648438e-02],
                        [ -7.12890625e-02,  -7.13195801e-02],
                        [ -7.41271973e-02,  -7.40966797e-02],
                        [ -7.07092285e-02,  -7.06787109e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.45446777e-02,  -6.45141602e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -6.93359375e-02,  -6.93054199e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -5.63659668e-02,  -5.63964844e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.15356445e-02,  -1.15051270e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [  4.36401367e-03,   4.33349609e-03],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  3.33557129e-02,   3.33862305e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  7.39440918e-02,   7.39135742e-02],
                        [  8.39843750e-02,   8.39843750e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -9.47570801e-02,  -9.47570801e-02],
                        [ -1.55517578e-01,  -1.55487061e-01],
                        [ -1.81762695e-01,  -1.81793213e-01],
                        [ -1.62384033e-01,  -1.62384033e-01],
                        [ -1.06262207e-01,  -1.06231689e-01],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  6.95495605e-02,   6.95495605e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  7.40966797e-02,   7.41271973e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -1.42303467e-01,  -1.42303467e-01],
                        [ -2.27630615e-01,  -2.27600098e-01],
                        [ -2.68493652e-01,  -2.68493652e-01],
                        [ -2.56134033e-01,  -2.56164551e-01],
                        [ -2.06542969e-01,  -2.06542969e-01],
                        [ -1.46911621e-01,  -1.46881104e-01],
                        [ -1.00860596e-01,  -1.00860596e-01],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -6.89697266e-02,  -6.89392090e-02],
                        [ -6.15539551e-02,  -6.15844727e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  2.90527344e-02,   2.90222168e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  7.52868652e-02,   7.53173828e-02],
                        [  1.08245850e-01,   1.08245850e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.30798340e-01,   1.30828857e-01],
                        [  1.16058350e-01,   1.16088867e-01],
                        [  9.35974121e-02,   9.35668945e-02],
                        [  7.14111328e-02,   7.14111328e-02],
                        [  5.47485352e-02,   5.47790527e-02],
                        [  4.48913574e-02,   4.48913574e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  1.47705078e-01,   1.47705078e-01],
                        [  1.99798584e-01,   1.99829102e-01],
                        [  2.34069824e-01,   2.34069824e-01],
                        [  2.37243652e-01,   2.37243652e-01],
                        [  2.10815430e-01,   2.10845947e-01],
                        [  1.71661377e-01,   1.71691895e-01],
                        [  1.37634277e-01,   1.37634277e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  5.39855957e-02,   5.39550781e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  2.05383301e-02,   2.05688477e-02],
                        [  7.75146484e-03,   7.72094727e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  4.42504883e-03,   4.45556641e-03],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  1.04064941e-02,   1.03759766e-02],
                        [  1.04064941e-02,   1.04370117e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.13830566e-02,   1.13525391e-02],
                        [  7.44628906e-03,   7.47680664e-03],
                        [ -1.28173828e-03,  -1.25122070e-03],
                        [ -1.43127441e-02,  -1.43432617e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -3.74145508e-02,  -3.73840332e-02],
                        [ -4.22058105e-02,  -4.22363281e-02],
                        [ -4.80651855e-02,  -4.80957031e-02],
                        [ -5.37719727e-02,  -5.37414551e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.25207520e-02,  -5.25512695e-02],
                        [ -5.32531738e-02,  -5.32226562e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -5.90515137e-02,  -5.90820312e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -6.02722168e-02,  -6.02416992e-02],
                        [ -5.93261719e-02,  -5.93566895e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.89599609e-02,  -5.89294434e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.31823730e-02,  -4.31518555e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -5.05371094e-02,  -5.05676270e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -6.01806641e-02,  -6.01501465e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.62438965e-02,  -5.62133789e-02],
                        [ -5.74035645e-02,  -5.74340820e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  3.85437012e-02,   3.85131836e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  6.99768066e-02,   6.99768066e-02],
                        [  7.41271973e-02,   7.40966797e-02],
                        [  6.79931641e-02,   6.79626465e-02],
                        [  4.56237793e-02,   4.56542969e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [ -6.44836426e-02,  -6.45141602e-02],
                        [ -1.27563477e-01,  -1.27532959e-01],
                        [ -1.65344238e-01,  -1.65344238e-01],
                        [ -1.64733887e-01,  -1.64733887e-01],
                        [ -1.28509521e-01,  -1.28509521e-01],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  1.23901367e-02,   1.23901367e-02],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -1.34918213e-01,  -1.34918213e-01],
                        [ -2.03918457e-01,  -2.03948975e-01],
                        [ -2.36511230e-01,  -2.36511230e-01],
                        [ -2.21069336e-01,  -2.21069336e-01],
                        [ -1.71020508e-01,  -1.71020508e-01],
                        [ -1.17218018e-01,  -1.17218018e-01],
                        [ -8.43200684e-02,  -8.43200684e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -6.82373047e-02,  -6.82373047e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -2.79235840e-02,  -2.79541016e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [  8.36181641e-03,   8.33129883e-03],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  4.55017090e-02,   4.55322266e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.51354980e-02,   4.51049805e-02],
                        [  5.55725098e-02,   5.55725098e-02],
                        [  7.73315430e-02,   7.73620605e-02],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  1.22711182e-01,   1.22711182e-01],
                        [  1.29180908e-01,   1.29180908e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.09588623e-01,   1.09558105e-01],
                        [  8.93249512e-02,   8.93249512e-02],
                        [  7.14721680e-02,   7.15026855e-02],
                        [  5.96923828e-02,   5.96618652e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  5.47485352e-02,   5.47790527e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  1.12152100e-01,   1.12121582e-01],
                        [  1.61834717e-01,   1.61865234e-01],
                        [  2.07153320e-01,   2.07153320e-01],
                        [  2.30377197e-01,   2.30346680e-01],
                        [  2.23205566e-01,   2.23205566e-01],
                        [  1.92687988e-01,   1.92718506e-01],
                        [  1.52923584e-01,   1.52893066e-01],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  7.40966797e-02,   7.40966797e-02],
                        [  7.17773438e-02,   7.17468262e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  7.45544434e-02,   7.45544434e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.94091797e-02,  -1.94396973e-02],
                        [ -2.70385742e-02,  -2.70080566e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -5.82580566e-02,  -5.82885742e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -4.31823730e-02,  -4.31518555e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -4.60510254e-02,  -4.60815430e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -3.68652344e-02,  -3.68347168e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -2.74047852e-02,  -2.74353027e-02],
                        [ -1.78833008e-02,  -1.78527832e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [  4.79125977e-03,   4.76074219e-03],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  3.93066406e-02,   3.93371582e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  3.91845703e-02,   3.91540527e-02],
                        [ -3.02124023e-03,  -3.05175781e-03],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -1.21643066e-01,  -1.21643066e-01],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.48956299e-01,  -1.48925781e-01],
                        [ -1.16363525e-01,  -1.16363525e-01],
                        [ -7.64160156e-02,  -7.64465332e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  6.85119629e-02,   6.85119629e-02],
                        [  8.56018066e-02,   8.55712891e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  2.56042480e-02,   2.56347656e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -1.48864746e-01,  -1.48864746e-01],
                        [ -2.18475342e-01,  -2.18444824e-01],
                        [ -2.41088867e-01,  -2.41088867e-01],
                        [ -2.13897705e-01,  -2.13897705e-01],
                        [ -1.57135010e-01,  -1.57104492e-01],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -6.57958984e-02,  -6.57653809e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -4.51660156e-02,  -4.51354980e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  4.42810059e-02,   4.43115234e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  9.03930664e-02,   9.03625488e-02],
                        [  1.26007080e-01,   1.26007080e-01],
                        [  1.41906738e-01,   1.41937256e-01],
                        [  1.39984131e-01,   1.39984131e-01],
                        [  1.26831055e-01,   1.26800537e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  6.64672852e-02,   6.64367676e-02],
                        [  5.37414551e-02,   5.37719727e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.90948486e-01,   1.90948486e-01],
                        [  2.07885742e-01,   2.07885742e-01],
                        [  1.99615479e-01,   1.99615479e-01],
                        [  1.72363281e-01,   1.72363281e-01],
                        [  1.41967773e-01,   1.41967773e-01],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  1.06597900e-01,   1.06597900e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  7.69653320e-02,   7.69348145e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  3.18908691e-02,   3.19213867e-02],
                        [  2.65808105e-02,   2.65502930e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -9.21630859e-03,  -9.24682617e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.46484375e-02,  -1.46179199e-02],
                        [ -1.49841309e-02,  -1.50146484e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -2.14843750e-02,  -2.14538574e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -3.19824219e-02,  -3.20129395e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -5.09643555e-02,  -5.09948730e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.97229004e-02,  -5.97534180e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -5.24291992e-02,  -5.24597168e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.36706543e-02,  -4.36401367e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -2.37426758e-02,  -2.37121582e-02],
                        [ -4.51660156e-03,  -4.54711914e-03],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -1.25915527e-01,  -1.25915527e-01],
                        [ -1.78344727e-01,  -1.78344727e-01],
                        [ -1.91711426e-01,  -1.91711426e-01],
                        [ -1.63146973e-01,  -1.63146973e-01],
                        [ -1.11602783e-01,  -1.11602783e-01],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  2.69470215e-02,   2.69775391e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  8.13598633e-02,   8.13293457e-02],
                        [  8.98132324e-02,   8.98437500e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -1.45568848e-01,  -1.45568848e-01],
                        [ -2.11334229e-01,  -2.11334229e-01],
                        [ -2.35900879e-01,  -2.35900879e-01],
                        [ -2.16186523e-01,  -2.16186523e-01],
                        [ -1.70867920e-01,  -1.70867920e-01],
                        [ -1.26617432e-01,  -1.26617432e-01],
                        [ -9.75646973e-02,  -9.75646973e-02],
                        [ -7.92846680e-02,  -7.92846680e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -4.57763672e-04,  -4.27246094e-04],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  4.11376953e-02,   4.11071777e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.14843750e-02,   2.15148926e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  3.14636230e-02,   3.14941406e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  1.34063721e-01,   1.34094238e-01],
                        [  1.54266357e-01,   1.54266357e-01],
                        [  1.55487061e-01,   1.55487061e-01],
                        [  1.37237549e-01,   1.37268066e-01],
                        [  1.05987549e-01,   1.06018066e-01],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  4.56237793e-02,   4.55932617e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  1.29913330e-01,   1.29913330e-01],
                        [  1.73522949e-01,   1.73522949e-01],
                        [  2.03491211e-01,   2.03521729e-01],
                        [  2.11822510e-01,   2.11822510e-01],
                        [  1.93878174e-01,   1.93878174e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  9.28955078e-02,   9.28649902e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  8.23059082e-02,   8.23364258e-02],
                        [  7.79113770e-02,   7.78808594e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  5.66711426e-02,   5.67016602e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -3.19519043e-02,  -3.19213867e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -4.82177734e-02,  -4.82482910e-02],
                        [ -5.21850586e-02,  -5.21545410e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.28259277e-02,  -5.28259277e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -6.27441406e-02,  -6.27746582e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -5.24902344e-02,  -5.24597168e-02],
                        [ -5.65490723e-02,  -5.65795898e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -5.96923828e-02,  -5.96618652e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -5.05371094e-02,  -5.05065918e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.57055664e-02,  -3.57360840e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -1.91040039e-02,  -1.90734863e-02],
                        [ -1.61437988e-02,  -1.61743164e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  6.28356934e-02,   6.28051758e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -1.06231689e-01,  -1.06231689e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -2.02331543e-01,  -2.02331543e-01],
                        [ -1.86950684e-01,  -1.86950684e-01],
                        [ -1.34552002e-01,  -1.34552002e-01],
                        [ -7.56225586e-02,  -7.55920410e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  7.01599121e-02,   7.01293945e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -1.46972656e-01,  -1.46972656e-01],
                        [ -2.12066650e-01,  -2.12066650e-01],
                        [ -2.36236572e-01,  -2.36236572e-01],
                        [ -2.14447021e-01,  -2.14447021e-01],
                        [ -1.65985107e-01,  -1.65985107e-01],
                        [ -1.19171143e-01,  -1.19171143e-01],
                        [ -8.87756348e-02,  -8.87756348e-02],
                        [ -7.08007812e-02,  -7.08007812e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  2.77099609e-02,   2.76794434e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  4.00695801e-02,   4.01000977e-02],
                        [  5.19714355e-02,   5.19714355e-02],
                        [  7.18994141e-02,   7.18688965e-02],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  1.31011963e-01,   1.31011963e-01],
                        [  1.47521973e-01,   1.47521973e-01],
                        [  1.44775391e-01,   1.44775391e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.08367920e-01,   1.08367920e-01],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  7.06787109e-02,   7.06787109e-02],
                        [  5.30700684e-02,   5.30700684e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  1.39770508e-01,   1.39770508e-01],
                        [  1.78131104e-01,   1.78131104e-01],
                        [  1.97387695e-01,   1.97387695e-01],
                        [  1.90765381e-01,   1.90765381e-01],
                        [  1.65588379e-01,   1.65618896e-01],
                        [  1.37237549e-01,   1.37207031e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  9.14916992e-02,   9.14916992e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.98059082e-02,  -1.98364258e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -5.18493652e-02,  -5.18188477e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -7.02209473e-02,  -7.01904297e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -6.53076172e-02,  -6.53381348e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  5.73120117e-02,   5.73425293e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  7.65991211e-03,   7.69042969e-03],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -1.22619629e-01,  -1.22619629e-01],
                        [ -1.82098389e-01,  -1.82098389e-01],
                        [ -2.06420898e-01,  -2.06420898e-01],
                        [ -1.90582275e-01,  -1.90582275e-01],
                        [ -1.48376465e-01,  -1.48376465e-01],
                        [ -9.94873047e-02,  -9.94567871e-02],
                        [ -5.84411621e-02,  -5.84411621e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  9.54284668e-02,   9.54284668e-02],
                        [  1.02752686e-01,   1.02752686e-01],
                        [  8.67614746e-02,   8.67614746e-02],
                        [  4.16564941e-02,   4.16870117e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -1.20330811e-01,  -1.20330811e-01],
                        [ -1.97631836e-01,  -1.97631836e-01],
                        [ -2.35565186e-01,  -2.35565186e-01],
                        [ -2.24151611e-01,  -2.24151611e-01],
                        [ -1.78466797e-01,  -1.78436279e-01],
                        [ -1.25793457e-01,  -1.25793457e-01],
                        [ -8.72192383e-02,  -8.72497559e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -4.67529297e-02,  -4.67834473e-02],
                        [ -3.09753418e-02,  -3.09448242e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -8.72802734e-03,  -8.75854492e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.29089355e-01,   1.29089355e-01],
                        [  1.35986328e-01,   1.35986328e-01],
                        [  1.31622314e-01,   1.31622314e-01],
                        [  1.21490479e-01,   1.21490479e-01],
                        [  1.10809326e-01,   1.10809326e-01],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  7.12280273e-02,   7.12280273e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.07922363e-02,   3.08227539e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  1.42761230e-01,   1.42761230e-01],
                        [  1.79168701e-01,   1.79168701e-01],
                        [  1.94702148e-01,   1.94702148e-01],
                        [  1.82556152e-01,   1.82556152e-01],
                        [  1.52893066e-01,   1.52893066e-01],
                        [  1.26129150e-01,   1.26129150e-01],
                        [  1.10748291e-01,   1.10717773e-01],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  7.44628906e-02,   7.44628906e-02],
                        [  6.68334961e-02,   6.68640137e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -1.36352539e-01,  -1.36352539e-01],
                        [ -1.96594238e-01,  -1.96594238e-01],
                        [ -2.14019775e-01,  -2.14019775e-01],
                        [ -1.88049316e-01,  -1.88049316e-01],
                        [ -1.40838623e-01,  -1.40838623e-01],
                        [ -9.72290039e-02,  -9.72290039e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -1.35589600e-01,  -1.35589600e-01],
                        [ -2.07366943e-01,  -2.07366943e-01],
                        [ -2.33154297e-01,  -2.33154297e-01],
                        [ -2.10815430e-01,  -2.10815430e-01],
                        [ -1.61254883e-01,  -1.61254883e-01],
                        [ -1.14501953e-01,  -1.14501953e-01],
                        [ -8.82873535e-02,  -8.82873535e-02],
                        [ -7.77893066e-02,  -7.77893066e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.36230469e-01,   1.36230469e-01],
                        [  1.31317139e-01,   1.31317139e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  8.88671875e-02,   8.88671875e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  1.54937744e-01,   1.54937744e-01],
                        [  1.83624268e-01,   1.83624268e-01],
                        [  1.91345215e-01,   1.91345215e-01],
                        [  1.72668457e-01,   1.72668457e-01],
                        [  1.38946533e-01,   1.38946533e-01],
                        [  1.08825684e-01,   1.08825684e-01],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  7.73925781e-02,   7.73925781e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -5.38330078e-02,  -5.38635254e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -7.06787109e-02,  -7.06787109e-02],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -9.75646973e-02,  -9.75646973e-02],
                        [ -1.57287598e-01,  -1.57287598e-01],
                        [ -1.88385010e-01,  -1.88385010e-01],
                        [ -1.87530518e-01,  -1.87530518e-01],
                        [ -1.63757324e-01,  -1.63757324e-01],
                        [ -1.28723145e-01,  -1.28723145e-01],
                        [ -9.28039551e-02,  -9.28039551e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  1.09252930e-01,   1.09252930e-01],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  5.48095703e-02,   5.48095703e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -1.28051758e-01,  -1.28051758e-01],
                        [ -2.07183838e-01,  -2.07183838e-01],
                        [ -2.39471436e-01,  -2.39471436e-01],
                        [ -2.20611572e-01,  -2.20611572e-01],
                        [ -1.70349121e-01,  -1.70349121e-01],
                        [ -1.19201660e-01,  -1.19201660e-01],
                        [ -8.70361328e-02,  -8.70361328e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.27148438e-02,   3.27453613e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.40258789e-01,   1.40258789e-01],
                        [  1.42120361e-01,   1.42120361e-01],
                        [  1.26525879e-01,   1.26525879e-01],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  8.30078125e-02,   8.30078125e-02],
                        [  8.00781250e-02,   8.00781250e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  1.35650635e-01,   1.35650635e-01],
                        [  1.69311523e-01,   1.69311523e-01],
                        [  1.80603027e-01,   1.80603027e-01],
                        [  1.67633057e-01,   1.67633057e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  7.47375488e-02,   7.47375488e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  4.37011719e-02,   4.37011719e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -7.35778809e-02,  -7.35778809e-02],
                        [ -8.07189941e-02,  -8.07189941e-02],
                        [ -8.31298828e-02,  -8.31298828e-02],
                        [ -8.27026367e-02,  -8.27026367e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  3.16467285e-02,   3.16467285e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -1.09191895e-01,  -1.09191895e-01],
                        [ -1.63330078e-01,  -1.63330078e-01],
                        [ -1.94976807e-01,  -1.94976807e-01],
                        [ -1.96899414e-01,  -1.96899414e-01],
                        [ -1.70684814e-01,  -1.70684814e-01],
                        [ -1.31469727e-01,  -1.31469727e-01],
                        [ -9.69543457e-02,  -9.69543457e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  9.59472656e-02,   9.59472656e-02],
                        [  1.22283936e-01,   1.22283936e-01],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -9.72290039e-02,  -9.72290039e-02],
                        [ -1.92779541e-01,  -1.92779541e-01],
                        [ -2.47131348e-01,  -2.47131348e-01],
                        [ -2.44079590e-01,  -2.44079590e-01],
                        [ -1.94549561e-01,  -1.94549561e-01],
                        [ -1.30493164e-01,  -1.30493164e-01],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  1.24328613e-01,   1.24328613e-01],
                        [  1.43249512e-01,   1.43249512e-01],
                        [  1.44897461e-01,   1.44897461e-01],
                        [  1.34918213e-01,   1.34918213e-01],
                        [  1.21704102e-01,   1.21704102e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  8.80737305e-02,   8.80737305e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  1.24816895e-01,   1.24816895e-01],
                        [  1.57379150e-01,   1.57379150e-01],
                        [  1.73217773e-01,   1.73217773e-01],
                        [  1.67968750e-01,   1.67968750e-01],
                        [  1.46728516e-01,   1.46728516e-01],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.19714355e-02,  -5.19714355e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  4.71496582e-02,   4.71496582e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -9.09423828e-02,  -9.09423828e-02],
                        [ -1.66076660e-01,  -1.66076660e-01],
                        [ -2.18658447e-01,  -2.18658447e-01],
                        [ -2.28820801e-01,  -2.28820801e-01],
                        [ -1.94793701e-01,  -1.94793701e-01],
                        [ -1.39923096e-01,  -1.39923096e-01],
                        [ -9.45434570e-02,  -9.45434570e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -5.68237305e-02,  -5.68237305e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  6.86950684e-02,   6.86950684e-02],
                        [  1.03118896e-01,   1.03118896e-01],
                        [  1.29974365e-01,   1.29974365e-01],
                        [  1.33666992e-01,   1.33666992e-01],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  4.03442383e-02,   4.03442383e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -1.42395020e-01,  -1.42395020e-01],
                        [ -2.14141846e-01,  -2.14141846e-01],
                        [ -2.40936279e-01,  -2.40936279e-01],
                        [ -2.17895508e-01,  -2.17895508e-01],
                        [ -1.63848877e-01,  -1.63848877e-01],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -7.53173828e-02,  -7.53173828e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  6.20117188e-02,   6.20117188e-02],
                        [  9.88159180e-02,   9.88159180e-02],
                        [  1.32507324e-01,   1.32507324e-01],
                        [  1.51672363e-01,   1.51672363e-01],
                        [  1.50665283e-01,   1.50665283e-01],
                        [  1.33392334e-01,   1.33392334e-01],
                        [  1.11267090e-01,   1.11267090e-01],
                        [  9.69238281e-02,   9.69238281e-02],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  1.46240234e-01,   1.46240234e-01],
                        [  1.84051514e-01,   1.84051514e-01],
                        [  1.94763184e-01,   1.94763184e-01],
                        [  1.76330566e-01,   1.76330566e-01],
                        [  1.39984131e-01,   1.39984131e-01],
                        [  1.03851318e-01,   1.03851318e-01],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  5.57250977e-02,   5.57250977e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -6.46362305e-02,  -6.46362305e-02],
                        [ -1.36657715e-01,  -1.36657715e-01],
                        [ -1.97326660e-01,  -1.97326660e-01],
                        [ -2.23968506e-01,  -2.23968506e-01],
                        [ -2.08648682e-01,  -2.08648682e-01],
                        [ -1.67175293e-01,  -1.67175293e-01],
                        [ -1.25305176e-01,  -1.25305176e-01],
                        [ -9.68322754e-02,  -9.68322754e-02],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -6.67724609e-02,  -6.67724609e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  1.31286621e-01,   1.31286621e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  4.59289551e-02,   4.59289551e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -1.42456055e-01,  -1.42456055e-01],
                        [ -2.15606689e-01,  -2.15606689e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -2.12371826e-01,  -2.12371826e-01],
                        [ -1.58050537e-01,  -1.58050537e-01],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  9.46044922e-02,   9.46044922e-02],
                        [  1.21887207e-01,   1.21887207e-01],
                        [  1.38580322e-01,   1.38580322e-01],
                        [  1.38366699e-01,   1.38366699e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  1.02813721e-01,   1.02813721e-01],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  6.02416992e-02,   6.02416992e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.70654297e-01,   1.70654297e-01],
                        [  1.71325684e-01,   1.71325684e-01],
                        [  1.49963379e-01,   1.49963379e-01],
                        [  1.19934082e-01,   1.19934082e-01],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -7.65075684e-02,  -7.65075684e-02],
                        [ -8.68835449e-02,  -8.68835449e-02],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -7.10144043e-02,  -7.10144043e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -1.45843506e-01,  -1.45843506e-01],
                        [ -2.09411621e-01,  -2.09411621e-01],
                        [ -2.36236572e-01,  -2.36236572e-01],
                        [ -2.21801758e-01,  -2.21801758e-01],
                        [ -1.78253174e-01,  -1.78253174e-01],
                        [ -1.27136230e-01,  -1.27136230e-01],
                        [ -8.81958008e-02,  -8.81958008e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  1.29638672e-01,   1.29638672e-01],
                        [  1.52770996e-01,   1.52770996e-01],
                        [  1.53137207e-01,   1.53137207e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  4.83093262e-02,   4.83093262e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -1.48193359e-01,  -1.48193359e-01],
                        [ -2.22961426e-01,  -2.22961426e-01],
                        [ -2.49542236e-01,  -2.49542236e-01],
                        [ -2.23083496e-01,  -2.23083496e-01],
                        [ -1.66229248e-01,  -1.66229248e-01],
                        [ -1.12396240e-01,  -1.12396240e-01],
                        [ -7.87048340e-02,  -7.87048340e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  1.40686035e-01,   1.40686035e-01],
                        [  1.46362305e-01,   1.46362305e-01],
                        [  1.36962891e-01,   1.36962891e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.06628418e-01,   1.06628418e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  9.61303711e-02,   9.61303711e-02],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  6.99768066e-02,   6.99768066e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.45416260e-01,   1.45416260e-01],
                        [  1.42150879e-01,   1.42150879e-01],
                        [  1.24176025e-01,   1.24176025e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  7.28759766e-02,   7.28759766e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -6.45751953e-02,  -6.45751953e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -6.41479492e-02,  -6.41479492e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -8.74633789e-02,  -8.74633789e-02],
                        [ -1.62384033e-01,  -1.62384033e-01],
                        [ -2.23999023e-01,  -2.23999023e-01],
                        [ -2.49786377e-01,  -2.49786377e-01],
                        [ -2.29003906e-01,  -2.29003906e-01],
                        [ -1.77062988e-01,  -1.77062988e-01],
                        [ -1.25213623e-01,  -1.25213623e-01],
                        [ -9.20104980e-02,  -9.20104980e-02],
                        [ -7.16857910e-02,  -7.16857910e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.41326904e-01,   1.41326904e-01],
                        [  1.26892090e-01,   1.26892090e-01],
                        [  8.00781250e-02,   8.00781250e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -1.84204102e-01,  -1.84204102e-01],
                        [ -2.38800049e-01,  -2.38800049e-01],
                        [ -2.39044189e-01,  -2.39044189e-01],
                        [ -1.95037842e-01,  -1.95037842e-01],
                        [ -1.38519287e-01,  -1.38519287e-01],
                        [ -9.64050293e-02,  -9.64050293e-02],
                        [ -7.11364746e-02,  -7.11364746e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  1.04614258e-01,   1.04614258e-01],
                        [  1.31744385e-01,   1.31744385e-01],
                        [  1.48498535e-01,   1.48498535e-01],
                        [  1.48925781e-01,   1.48925781e-01],
                        [  1.40533447e-01,   1.40533447e-01],
                        [  1.32598877e-01,   1.32598877e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  1.30310059e-01,   1.30310059e-01],
                        [  1.56402588e-01,   1.56402588e-01],
                        [  1.59027100e-01,   1.59027100e-01],
                        [  1.41296387e-01,   1.41296387e-01],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  9.68017578e-02,   9.68017578e-02],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -1.28448486e-01,  -1.28448486e-01],
                        [ -1.97235107e-01,  -1.97235107e-01],
                        [ -2.36480713e-01,  -2.36480713e-01],
                        [ -2.30987549e-01,  -2.30987549e-01],
                        [ -1.90795898e-01,  -1.90795898e-01],
                        [ -1.43035889e-01,  -1.43035889e-01],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -8.72192383e-02,  -8.72192383e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  1.09161377e-01,   1.09161377e-01],
                        [  1.39099121e-01,   1.39099121e-01],
                        [  1.50634766e-01,   1.50634766e-01],
                        [  1.35650635e-01,   1.35650635e-01],
                        [  8.66088867e-02,   8.66088867e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -9.89990234e-02,  -9.89990234e-02],
                        [ -1.87377930e-01,  -1.87377930e-01],
                        [ -2.34008789e-01,  -2.34008789e-01],
                        [ -2.29553223e-01,  -2.29553223e-01],
                        [ -1.84448242e-01,  -1.84448242e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  1.34307861e-01,   1.34307861e-01],
                        [  1.42883301e-01,   1.42883301e-01],
                        [  1.36932373e-01,   1.36932373e-01],
                        [  1.28875732e-01,   1.28875732e-01],
                        [  1.25915527e-01,   1.25915527e-01],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.01135254e-01,   1.01135254e-01],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  7.34558105e-02,   7.34558105e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  1.27746582e-01,   1.27746582e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.68334961e-01,   1.68334961e-01],
                        [  1.49719238e-01,   1.49719238e-01],
                        [  1.22253418e-01,   1.22253418e-01],
                        [  9.82971191e-02,   9.82971191e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  5.21545410e-02,   5.21545410e-02],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -1.17553711e-01,  -1.17553711e-01],
                        [ -1.82373047e-01,  -1.82373047e-01],
                        [ -2.20184326e-01,  -2.20184326e-01],
                        [ -2.17102051e-01,  -2.17102051e-01],
                        [ -1.78100586e-01,  -1.78100586e-01],
                        [ -1.27044678e-01,  -1.27044678e-01],
                        [ -8.94165039e-02,  -8.94165039e-02],
                        [ -7.23571777e-02,  -7.23571777e-02],
                        [ -6.59179688e-02,  -6.59179688e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -4.74853516e-02,  -4.74853516e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.28936768e-01,   1.28936768e-01],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  1.23229980e-01,   1.23229980e-01],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -1.50329590e-01,  -1.50329590e-01],
                        [ -2.13500977e-01,  -2.13500977e-01],
                        [ -2.25555420e-01,  -2.25555420e-01],
                        [ -1.88201904e-01,  -1.88201904e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.37908936e-01,   1.37908936e-01],
                        [  1.40716553e-01,   1.40716553e-01],
                        [  1.29913330e-01,   1.29913330e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  1.35986328e-01,   1.35986328e-01],
                        [  1.55761719e-01,   1.55761719e-01],
                        [  1.49200439e-01,   1.49200439e-01],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -1.14349365e-01,  -1.14349365e-01],
                        [ -1.81457520e-01,  -1.81457520e-01],
                        [ -2.23876953e-01,  -2.23876953e-01],
                        [ -2.25280762e-01,  -2.25280762e-01],
                        [ -1.87042236e-01,  -1.87042236e-01],
                        [ -1.29364014e-01,  -1.29364014e-01],
                        [ -8.17871094e-02,  -8.17871094e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  5.21850586e-02,   5.21850586e-02],
                        [  8.56933594e-02,   8.56933594e-02],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -1.19781494e-01,  -1.19781494e-01],
                        [ -1.87225342e-01,  -1.87225342e-01],
                        [ -2.12738037e-01,  -2.12738037e-01],
                        [ -1.90826416e-01,  -1.90826416e-01],
                        [ -1.40594482e-01,  -1.40594482e-01],
                        [ -9.22241211e-02,  -9.22241211e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  1.56463623e-01,   1.56463623e-01],
                        [  1.65740967e-01,   1.65740967e-01],
                        [  1.52374268e-01,   1.52374268e-01],
                        [  1.30737305e-01,   1.30737305e-01],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  1.09497070e-01,   1.09497070e-01],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  8.57849121e-02,   8.57849121e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.43096924e-01,   1.43096924e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  7.84301758e-03,   7.84301758e-03],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  5.60913086e-02,   5.60913086e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -1.17767334e-01,  -1.17767334e-01],
                        [ -1.89666748e-01,  -1.89666748e-01],
                        [ -2.33734131e-01,  -2.33734131e-01],
                        [ -2.36022949e-01,  -2.36022949e-01],
                        [ -2.01324463e-01,  -2.01324463e-01],
                        [ -1.48223877e-01,  -1.48223877e-01],
                        [ -1.00555420e-01,  -1.00555420e-01],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.28265381e-01,   1.28265381e-01],
                        [  7.57446289e-02,   7.57446289e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -1.06048584e-01,  -1.06048584e-01],
                        [ -1.87347412e-01,  -1.87347412e-01],
                        [ -2.27874756e-01,  -2.27874756e-01],
                        [ -2.18566895e-01,  -2.18566895e-01],
                        [ -1.73980713e-01,  -1.73980713e-01],
                        [ -1.21276855e-01,  -1.21276855e-01],
                        [ -7.97424316e-02,  -7.97424316e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  8.35266113e-02,   8.35266113e-02],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  1.48895264e-01,   1.48895264e-01],
                        [  1.58050537e-01,   1.58050537e-01],
                        [  1.52862549e-01,   1.52862549e-01],
                        [  1.39190674e-01,   1.39190674e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  1.12335205e-01,   1.12335205e-01],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  7.90405273e-02,   7.90405273e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  1.33392334e-01,   1.33392334e-01],
                        [  1.40014648e-01,   1.40014648e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  7.08312988e-02,   7.08312988e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  7.47375488e-02,   7.47375488e-02],
                        [  6.82373047e-02,   6.82373047e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -1.40563965e-01,  -1.40563965e-01],
                        [ -2.03399658e-01,  -2.03399658e-01],
                        [ -2.34252930e-01,  -2.34252930e-01],
                        [ -2.24578857e-01,  -2.24578857e-01],
                        [ -1.84753418e-01,  -1.84753418e-01],
                        [ -1.37481689e-01,  -1.37481689e-01],
                        [ -1.02844238e-01,  -1.02844238e-01],
                        [ -8.50524902e-02,  -8.50524902e-02],
                        [ -7.33337402e-02,  -7.33337402e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  5.54199219e-02,   5.54199219e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.44897461e-01,   1.44897461e-01],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  5.86242676e-02,   5.86242676e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -1.21765137e-01,  -1.21765137e-01],
                        [ -1.98760986e-01,  -1.98760986e-01],
                        [ -2.32910156e-01,  -2.32910156e-01],
                        [ -2.14965820e-01,  -2.14965820e-01],
                        [ -1.62292480e-01,  -1.62292480e-01],
                        [ -1.08306885e-01,  -1.08306885e-01],
                        [ -7.49511719e-02,  -7.49511719e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.74194336e-01,   1.74194336e-01],
                        [  1.72424316e-01,   1.72424316e-01],
                        [  1.60491943e-01,   1.60491943e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.02203369e-01,   1.02203369e-01],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  6.05163574e-02,   6.05163574e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.66839600e-01,   1.66839600e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.24420166e-01,   1.24420166e-01],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  5.17883301e-02,   5.17883301e-02],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -8.05053711e-02,  -8.05053711e-02],
                        [ -8.64562988e-02,  -8.64562988e-02],
                        [ -8.38012695e-02,  -8.38012695e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  4.37316895e-02,   4.37316895e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  5.91430664e-02,   5.91430664e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -1.28021240e-01,  -1.28021240e-01],
                        [ -1.96197510e-01,  -1.96197510e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -2.40783691e-01,  -2.40783691e-01],
                        [ -2.04437256e-01,  -2.04437256e-01],
                        [ -1.53076172e-01,  -1.53076172e-01],
                        [ -1.10046387e-01,  -1.10046387e-01],
                        [ -8.32519531e-02,  -8.32519531e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  7.29370117e-02,   7.29370117e-02],
                        [  1.01654053e-01,   1.01654053e-01],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.29089355e-01,   1.29089355e-01],
                        [  1.15631104e-01,   1.15631104e-01],
                        [  7.03735352e-02,   7.03735352e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.09893799e-01,  -1.09893799e-01],
                        [ -1.93481445e-01,  -1.93481445e-01],
                        [ -2.31353760e-01,  -2.31353760e-01],
                        [ -2.15972900e-01,  -2.15972900e-01],
                        [ -1.62414551e-01,  -1.62414551e-01],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  1.06750488e-01,   1.06750488e-01],
                        [  1.41357422e-01,   1.41357422e-01],
                        [  1.61010742e-01,   1.61010742e-01],
                        [  1.60552979e-01,   1.60552979e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.18713379e-01,   1.18713379e-01],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  8.80737305e-02,   8.80737305e-02],
                        [  7.08923340e-02,   7.08923340e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  1.45782471e-01,   1.45782471e-01],
                        [  1.71203613e-01,   1.71203613e-01],
                        [  1.65191650e-01,   1.65191650e-01],
                        [  1.36718750e-01,   1.36718750e-01],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.86157227e-02,  -1.86157227e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -1.04949951e-01,  -1.04949951e-01],
                        [ -1.76300049e-01,  -1.76300049e-01],
                        [ -2.18597412e-01,  -2.18597412e-01],
                        [ -2.16125488e-01,  -2.16125488e-01],
                        [ -1.78710938e-01,  -1.78710938e-01],
                        [ -1.33941650e-01,  -1.33941650e-01],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -8.92944336e-02,  -8.92944336e-02],
                        [ -8.26721191e-02,  -8.26721191e-02],
                        [ -7.65686035e-02,  -7.65686035e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  6.99462891e-02,   6.99462891e-02],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  1.40533447e-01,   1.40533447e-01],
                        [  1.55395508e-01,   1.55395508e-01],
                        [  1.44989014e-01,   1.44989014e-01],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [ -8.63952637e-02,  -8.63952637e-02],
                        [ -1.73675537e-01,  -1.73675537e-01],
                        [ -2.22564697e-01,  -2.22564697e-01],
                        [ -2.21893311e-01,  -2.21893311e-01],
                        [ -1.79504395e-01,  -1.79504395e-01],
                        [ -1.21612549e-01,  -1.21612549e-01],
                        [ -7.69653320e-02,  -7.69653320e-02],
                        [ -5.50842285e-02,  -5.50842285e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  9.05761719e-02,   9.05761719e-02],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  1.41235352e-01,   1.41235352e-01],
                        [  1.43157959e-01,   1.43157959e-01],
                        [  1.31591797e-01,   1.31591797e-01],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  1.19171143e-01,   1.19171143e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  1.01806641e-01,   1.01806641e-01],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  1.37207031e-01,   1.37207031e-01],
                        [  1.44409180e-01,   1.44409180e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -1.14807129e-01,  -1.14807129e-01],
                        [ -1.93664551e-01,  -1.93664551e-01],
                        [ -2.40417480e-01,  -2.40417480e-01],
                        [ -2.40692139e-01,  -2.40692139e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -1.61102295e-01,  -1.61102295e-01],
                        [ -1.24176025e-01,  -1.24176025e-01],
                        [ -1.00585938e-01,  -1.00585938e-01],
                        [ -8.45031738e-02,  -8.45031738e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  1.35284424e-01,   1.35284424e-01],
                        [  1.47766113e-01,   1.47766113e-01],
                        [  1.41021729e-01,   1.41021729e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  3.50036621e-02,   3.50036621e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -1.58843994e-01,  -1.58843994e-01],
                        [ -2.17468262e-01,  -2.17468262e-01],
                        [ -2.24151611e-01,  -2.24151611e-01],
                        [ -1.87561035e-01,  -1.87561035e-01],
                        [ -1.31469727e-01,  -1.31469727e-01],
                        [ -8.07189941e-02,  -8.07189941e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  5.69152832e-02,   5.69152832e-02],
                        [  5.08117676e-02,   5.08117676e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  3.28979492e-02,   3.28979492e-02],
                        [  7.81250000e-02,   7.81250000e-02],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.62994385e-01,   1.62994385e-01],
                        [  1.81884766e-01,   1.81884766e-01],
                        [  1.80358887e-01,   1.80358887e-01],
                        [  1.64978027e-01,   1.64978027e-01],
                        [  1.46606445e-01,   1.46606445e-01],
                        [  1.32476807e-01,   1.32476807e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  7.57751465e-02,   7.57751465e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  6.39648438e-02,   6.39648438e-02],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.44226074e-01,   1.44226074e-01],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.33544922e-01,   1.33544922e-01],
                        [  1.06140137e-01,   1.06140137e-01],
                        [  7.76062012e-02,   7.76062012e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  4.95300293e-02,   4.95300293e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -8.74633789e-02,  -8.74633789e-02],
                        [ -1.63208008e-01,  -1.63208008e-01],
                        [ -2.19696045e-01,  -2.19696045e-01],
                        [ -2.38098145e-01,  -2.38098145e-01],
                        [ -2.14630127e-01,  -2.14630127e-01],
                        [ -1.66809082e-01,  -1.66809082e-01],
                        [ -1.22100830e-01,  -1.22100830e-01],
                        [ -9.56420898e-02,  -9.56420898e-02],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -7.88879395e-02,  -7.88879395e-02],
                        [ -7.07092285e-02,  -7.07092285e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.38702393e-01,   1.38702393e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  8.38317871e-02,   8.38317871e-02],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -1.14685059e-01,  -1.14685059e-01],
                        [ -2.04345703e-01,  -2.04345703e-01],
                        [ -2.38464355e-01,  -2.38464355e-01],
                        [ -2.13500977e-01,  -2.13500977e-01],
                        [ -1.51733398e-01,  -1.51733398e-01],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  5.50231934e-02,   5.50231934e-02],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.54235840e-01,   1.54235840e-01],
                        [  1.59973145e-01,   1.59973145e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  1.37298584e-01,   1.37298584e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  9.29565430e-02,   9.29565430e-02],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  1.19750977e-01,   1.19750977e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  8.74023438e-02,   8.74023438e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.28259277e-02,  -5.28259277e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -7.01904297e-02,  -7.01904297e-02],
                        [ -1.44439697e-01,  -1.44439697e-01],
                        [ -2.02850342e-01,  -2.02850342e-01],
                        [ -2.26654053e-01,  -2.26654053e-01],
                        [ -2.11700439e-01,  -2.11700439e-01],
                        [ -1.74163818e-01,  -1.74163818e-01],
                        [ -1.38946533e-01,  -1.38946533e-01],
                        [ -1.18988037e-01,  -1.18988037e-01],
                        [ -1.08489990e-01,  -1.08489990e-01],
                        [ -9.50927734e-02,  -9.50927734e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  1.15509033e-01,   1.15509033e-01],
                        [  1.30432129e-01,   1.30432129e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [ -8.00476074e-02,  -8.00476074e-02],
                        [ -1.72729492e-01,  -1.72729492e-01],
                        [ -2.22961426e-01,  -2.22961426e-01],
                        [ -2.15728760e-01,  -2.15728760e-01],
                        [ -1.69952393e-01,  -1.69952393e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  4.37011719e-02,   4.37011719e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  1.10717773e-01,   1.10717773e-01],
                        [  1.51672363e-01,   1.51672363e-01],
                        [  1.72698975e-01,   1.72698975e-01],
                        [  1.72760010e-01,   1.72760010e-01],
                        [  1.63299561e-01,   1.63299561e-01],
                        [  1.55639648e-01,   1.55639648e-01],
                        [  1.50909424e-01,   1.50909424e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  6.85729980e-02,   6.85729980e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  1.44775391e-01,   1.44775391e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  7.00378418e-02,   7.00378418e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.66101074e-02,  -5.66101074e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  8.01391602e-02,   8.01391602e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -1.87194824e-01,  -1.87194824e-01],
                        [ -2.35046387e-01,  -2.35046387e-01],
                        [ -2.38586426e-01,  -2.38586426e-01],
                        [ -2.06939697e-01,  -2.06939697e-01],
                        [ -1.63360596e-01,  -1.63360596e-01],
                        [ -1.28692627e-01,  -1.28692627e-01],
                        [ -1.08276367e-01,  -1.08276367e-01],
                        [ -9.46044922e-02,  -9.46044922e-02],
                        [ -8.08105469e-02,  -8.08105469e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  1.21185303e-01,   1.21185303e-01],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  1.44836426e-01,   1.44836426e-01],
                        [  1.32659912e-01,   1.32659912e-01],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -1.01867676e-01,  -1.01867676e-01],
                        [ -1.94915771e-01,  -1.94915771e-01],
                        [ -2.39074707e-01,  -2.39074707e-01],
                        [ -2.23724365e-01,  -2.23724365e-01],
                        [ -1.68365479e-01,  -1.68365479e-01],
                        [ -1.07391357e-01,  -1.07391357e-01],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  1.30126953e-01,   1.30126953e-01],
                        [  1.70318604e-01,   1.70318604e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  1.89697266e-01,   1.89697266e-01],
                        [  1.75231934e-01,   1.75231934e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  1.42669678e-01,   1.42669678e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.08825684e-01,   1.08825684e-01],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  5.55114746e-02,   5.55114746e-02],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  1.35986328e-01,   1.35986328e-01],
                        [  1.44042969e-01,   1.44042969e-01],
                        [  1.28326416e-01,   1.28326416e-01],
                        [  1.00616455e-01,   1.00616455e-01],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  6.13098145e-02,   6.13098145e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -8.74328613e-02,  -8.74328613e-02],
                        [ -1.78649902e-01,  -1.78649902e-01],
                        [ -2.45483398e-01,  -2.45483398e-01],
                        [ -2.64770508e-01,  -2.64770508e-01],
                        [ -2.36968994e-01,  -2.36968994e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -1.43249512e-01,  -1.43249512e-01],
                        [ -1.19049072e-01,  -1.19049072e-01],
                        [ -1.04522705e-01,  -1.04522705e-01],
                        [ -8.48999023e-02,  -8.48999023e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.32965088e-01,   1.32965088e-01],
                        [  1.34002686e-01,   1.34002686e-01],
                        [  1.15325928e-01,   1.15325928e-01],
                        [  6.79016113e-02,   6.79016113e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.15997314e-01,  -1.15997314e-01],
                        [ -2.02239990e-01,  -2.02239990e-01],
                        [ -2.34436035e-01,  -2.34436035e-01],
                        [ -2.06024170e-01,  -2.06024170e-01],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -8.36181641e-02,  -8.36181641e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.78192139e-01,   1.78192139e-01],
                        [  1.86218262e-01,   1.86218262e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.50054932e-01,   1.50054932e-01],
                        [  1.29302979e-01,   1.29302979e-01],
                        [  1.14593506e-01,   1.14593506e-01],
                        [  1.02691650e-01,   1.02691650e-01],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  1.42272949e-01,   1.42272949e-01],
                        [  1.33697510e-01,   1.33697510e-01],
                        [  1.06475830e-01,   1.06475830e-01],
                        [  7.40966797e-02,   7.40966797e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -1.19750977e-01,  -1.19750977e-01],
                        [ -1.98913574e-01,  -1.98913574e-01],
                        [ -2.48962402e-01,  -2.48962402e-01],
                        [ -2.50183105e-01,  -2.50183105e-01],
                        [ -2.10784912e-01,  -2.10784912e-01],
                        [ -1.60675049e-01,  -1.60675049e-01],
                        [ -1.24725342e-01,  -1.24725342e-01],
                        [ -1.05438232e-01,  -1.05438232e-01],
                        [ -9.14611816e-02,  -9.14611816e-02],
                        [ -7.69958496e-02,  -7.69958496e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.43402100e-01,   1.43402100e-01],
                        [  1.40716553e-01,   1.40716553e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  4.24499512e-02,   4.24499512e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -1.59301758e-01,  -1.59301758e-01],
                        [ -2.25952148e-01,  -2.25952148e-01],
                        [ -2.33551025e-01,  -2.33551025e-01],
                        [ -1.89605713e-01,  -1.89605713e-01],
                        [ -1.26708984e-01,  -1.26708984e-01],
                        [ -7.80639648e-02,  -7.80639648e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  1.31744385e-01,   1.31744385e-01],
                        [  1.63269043e-01,   1.63269043e-01],
                        [  1.77551270e-01,   1.77551270e-01],
                        [  1.72790527e-01,   1.72790527e-01],
                        [  1.57653809e-01,   1.57653809e-01],
                        [  1.43463135e-01,   1.43463135e-01],
                        [  1.34246826e-01,   1.34246826e-01],
                        [  1.24450684e-01,   1.24450684e-01],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.24176025e-01,   1.24176025e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  5.17883301e-02,   5.17883301e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -6.78100586e-02,  -6.78100586e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -4.89807129e-02,  -4.89807129e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -1.57287598e-01,  -1.57287598e-01],
                        [ -2.28240967e-01,  -2.28240967e-01],
                        [ -2.59521484e-01,  -2.59521484e-01],
                        [ -2.41577148e-01,  -2.41577148e-01],
                        [ -1.90765381e-01,  -1.90765381e-01],
                        [ -1.38488770e-01,  -1.38488770e-01],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -9.40551758e-02,  -9.40551758e-02],
                        [ -8.65783691e-02,  -8.65783691e-02],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -5.84411621e-02,  -5.84411621e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  1.11663818e-01,   1.11663818e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.38916016e-01,   1.38916016e-01],
                        [  1.33087158e-01,   1.33087158e-01],
                        [  1.07238770e-01,   1.07238770e-01],
                        [  5.27343750e-02,   5.27343750e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -1.33575439e-01,  -1.33575439e-01],
                        [ -2.09197998e-01,  -2.09197998e-01],
                        [ -2.27661133e-01,  -2.27661133e-01],
                        [ -1.89636230e-01,  -1.89636230e-01],
                        [ -1.28295898e-01,  -1.28295898e-01],
                        [ -8.01391602e-02,  -8.01391602e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  5.25512695e-02,   5.25512695e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  4.77905273e-02,   4.77905273e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  1.26525879e-01,   1.26525879e-01],
                        [  1.67907715e-01,   1.67907715e-01],
                        [  1.91253662e-01,   1.91253662e-01],
                        [  1.88873291e-01,   1.88873291e-01],
                        [  1.69952393e-01,   1.69952393e-01],
                        [  1.51153564e-01,   1.51153564e-01],
                        [  1.40533447e-01,   1.40533447e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  1.32598877e-01,   1.32598877e-01],
                        [  1.43066406e-01,   1.43066406e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  8.37707520e-02,   8.37707520e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  6.02416992e-02,   6.02416992e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -1.48986816e-01,  -1.48986816e-01],
                        [ -2.23968506e-01,  -2.23968506e-01],
                        [ -2.68066406e-01,  -2.68066406e-01],
                        [ -2.67517090e-01,  -2.67517090e-01],
                        [ -2.25799561e-01,  -2.25799561e-01],
                        [ -1.68395996e-01,  -1.68395996e-01],
                        [ -1.25396729e-01,  -1.25396729e-01],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -8.76770020e-02,  -8.76770020e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -6.06689453e-02,  -6.06689453e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.16424561e-01,   1.16424561e-01],
                        [  1.31042480e-01,   1.31042480e-01],
                        [  1.34094238e-01,   1.34094238e-01],
                        [  1.20300293e-01,   1.20300293e-01],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -1.31134033e-01,  -1.31134033e-01],
                        [ -1.92871094e-01,  -1.92871094e-01],
                        [ -2.05200195e-01,  -2.05200195e-01],
                        [ -1.68914795e-01,  -1.68914795e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -7.33337402e-02,  -7.33337402e-02],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  9.34143066e-02,   9.34143066e-02],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.77795410e-01,   1.77795410e-01],
                        [  1.93328857e-01,   1.93328857e-01],
                        [  1.79534912e-01,   1.79534912e-01],
                        [  1.52313232e-01,   1.52313232e-01],
                        [  1.31439209e-01,   1.31439209e-01],
                        [  1.21032715e-01,   1.21032715e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  7.66296387e-02,   7.66296387e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.31072998e-01,   1.31072998e-01],
                        [  1.30462646e-01,   1.30462646e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  5.92651367e-02,   5.92651367e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  3.50646973e-02,   3.50646973e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -1.22955322e-01,  -1.22955322e-01],
                        [ -1.99401855e-01,  -1.99401855e-01],
                        [ -2.51739502e-01,  -2.51739502e-01],
                        [ -2.61047363e-01,  -2.61047363e-01],
                        [ -2.27691650e-01,  -2.27691650e-01],
                        [ -1.73797607e-01,  -1.73797607e-01],
                        [ -1.27075195e-01,  -1.27075195e-01],
                        [ -1.00677490e-01,  -1.00677490e-01],
                        [ -8.89587402e-02,  -8.89587402e-02],
                        [ -8.03527832e-02,  -8.03527832e-02],
                        [ -7.08618164e-02,  -7.08618164e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  8.30688477e-02,   8.30688477e-02],
                        [  1.09558105e-01,   1.09558105e-01],
                        [  1.31683350e-01,   1.31683350e-01],
                        [  1.41632080e-01,   1.41632080e-01],
                        [  1.32446289e-01,   1.32446289e-01],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -1.35650635e-01,  -1.35650635e-01],
                        [ -1.97570801e-01,  -1.97570801e-01],
                        [ -2.10693359e-01,  -2.10693359e-01],
                        [ -1.74468994e-01,  -1.74468994e-01],
                        [ -1.14471436e-01,  -1.14471436e-01],
                        [ -6.35681152e-02,  -6.35681152e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  4.30908203e-02,   4.30908203e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  1.43646240e-01,   1.43646240e-01],
                        [  1.77337646e-01,   1.77337646e-01],
                        [  1.91955566e-01,   1.91955566e-01],
                        [  1.86950684e-01,   1.86950684e-01],
                        [  1.71508789e-01,   1.71508789e-01],
                        [  1.56036377e-01,   1.56036377e-01],
                        [  1.43920898e-01,   1.43920898e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  8.04748535e-02,   8.04748535e-02],
                        [  6.82678223e-02,   6.82678223e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  7.83386230e-02,   7.83386230e-02],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  1.46820068e-01,   1.46820068e-01],
                        [  1.34552002e-01,   1.34552002e-01],
                        [  1.02600098e-01,   1.02600098e-01],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -7.61718750e-02,  -7.61718750e-02],
                        [ -1.60461426e-01,  -1.60461426e-01],
                        [ -2.29736328e-01,  -2.29736328e-01],
                        [ -2.62512207e-01,  -2.62512207e-01],
                        [ -2.51068115e-01,  -2.51068115e-01],
                        [ -2.06634521e-01,  -2.06634521e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.18743896e-01,  -1.18743896e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -9.89990234e-02,  -9.89990234e-02],
                        [ -8.37097168e-02,  -8.37097168e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  9.10339355e-02,   9.10339355e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -1.39648438e-01,  -1.39648438e-01],
                        [ -1.96075439e-01,  -1.96075439e-01],
                        [ -1.98364258e-01,  -1.98364258e-01],
                        [ -1.52770996e-01,  -1.52770996e-01],
                        [ -9.48181152e-02,  -9.48181152e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  1.30767822e-01,   1.30767822e-01],
                        [  1.65374756e-01,   1.65374756e-01],
                        [  1.81915283e-01,   1.81915283e-01],
                        [  1.79138184e-01,   1.79138184e-01],
                        [  1.66534424e-01,   1.66534424e-01],
                        [  1.54602051e-01,   1.54602051e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.39984131e-01,   1.39984131e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  5.24902344e-03,   5.24902344e-03],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  1.14624023e-01,   1.14624023e-01],
                        [  1.40838623e-01,   1.40838623e-01],
                        [  1.36260986e-01,   1.36260986e-01],
                        [  1.09771729e-01,   1.09771729e-01],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -1.44561768e-01,  -1.44561768e-01],
                        [ -2.18933105e-01,  -2.18933105e-01],
                        [ -2.55676270e-01,  -2.55676270e-01],
                        [ -2.45056152e-01,  -2.45056152e-01],
                        [ -2.01934814e-01,  -2.01934814e-01],
                        [ -1.52465820e-01,  -1.52465820e-01],
                        [ -1.17553711e-01,  -1.17553711e-01],
                        [ -1.01867676e-01,  -1.01867676e-01],
                        [ -9.52758789e-02,  -9.52758789e-02],
                        [ -8.67919922e-02,  -8.67919922e-02],
                        [ -7.47985840e-02,  -7.47985840e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.09191895e-01,   1.09191895e-01],
                        [  7.64465332e-02,   7.64465332e-02],
                        [  4.69970703e-03,   4.69970703e-03],
                        [ -9.02709961e-02,  -9.02709961e-02],
                        [ -1.71844482e-01,  -1.71844482e-01],
                        [ -2.07946777e-01,  -2.07946777e-01],
                        [ -1.92382812e-01,  -1.92382812e-01],
                        [ -1.44805908e-01,  -1.44805908e-01],
                        [ -9.21936035e-02,  -9.21936035e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  3.28369141e-02,   3.28369141e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  1.27624512e-01,   1.27624512e-01],
                        [  1.61499023e-01,   1.61499023e-01],
                        [  1.76269531e-01,   1.76269531e-01],
                        [  1.73950195e-01,   1.73950195e-01],
                        [  1.62109375e-01,   1.62109375e-01],
                        [  1.48223877e-01,   1.48223877e-01],
                        [  1.37329102e-01,   1.37329102e-01],
                        [  1.30432129e-01,   1.30432129e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.14379883e-01,   1.14379883e-01],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  9.04541016e-02,   9.04541016e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  4.57458496e-02,   4.57458496e-02],
                        [  8.76159668e-02,   8.76159668e-02],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -5.76782227e-02,  -5.76782227e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -1.12701416e-01,  -1.12701416e-01],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -2.41882324e-01,  -2.41882324e-01],
                        [ -2.58239746e-01,  -2.58239746e-01],
                        [ -2.33734131e-01,  -2.33734131e-01],
                        [ -1.86706543e-01,  -1.86706543e-01],
                        [ -1.43920898e-01,  -1.43920898e-01],
                        [ -1.17431641e-01,  -1.17431641e-01],
                        [ -1.01165771e-01,  -1.01165771e-01],
                        [ -8.69140625e-02,  -8.69140625e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  4.14733887e-02,   4.14733887e-02],
                        [  6.39953613e-02,   6.39953613e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  1.27166748e-01,   1.27166748e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  6.94274902e-02,   6.94274902e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -9.89379883e-02,  -9.89379883e-02],
                        [ -1.80206299e-01,  -1.80206299e-01],
                        [ -2.15454102e-01,  -2.15454102e-01],
                        [ -1.94274902e-01,  -1.94274902e-01],
                        [ -1.36871338e-01,  -1.36871338e-01],
                        [ -7.95898438e-02,  -7.95898438e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  9.72290039e-02,   9.72290039e-02],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  1.80297852e-01,   1.80297852e-01],
                        [  1.90917969e-01,   1.90917969e-01],
                        [  1.80633545e-01,   1.80633545e-01],
                        [  1.58935547e-01,   1.58935547e-01],
                        [  1.39343262e-01,   1.39343262e-01],
                        [  1.29730225e-01,   1.29730225e-01],
                        [  1.25823975e-01,   1.25823975e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  5.60913086e-02,   5.60913086e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  4.03442383e-02,   4.03442383e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -1.53686523e-01,  -1.53686523e-01],
                        [ -2.33001709e-01,  -2.33001709e-01],
                        [ -2.75482178e-01,  -2.75482178e-01],
                        [ -2.71179199e-01,  -2.71179199e-01],
                        [ -2.29980469e-01,  -2.29980469e-01],
                        [ -1.74346924e-01,  -1.74346924e-01],
                        [ -1.28906250e-01,  -1.28906250e-01],
                        [ -1.04614258e-01,  -1.04614258e-01],
                        [ -9.15832520e-02,  -9.15832520e-02],
                        [ -7.48596191e-02,  -7.48596191e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  8.26721191e-02,   8.26721191e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  9.75036621e-02,   9.75036621e-02],
                        [  1.04217529e-01,   1.04217529e-01],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [ -7.07702637e-02,  -7.07702637e-02],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -2.01110840e-01,  -2.01110840e-01],
                        [ -1.97845459e-01,  -1.97845459e-01],
                        [ -1.56494141e-01,  -1.56494141e-01],
                        [ -1.05560303e-01,  -1.05560303e-01],
                        [ -6.68945312e-02,  -6.68945312e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  4.53796387e-02,   4.53796387e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.57318115e-01,   1.57318115e-01],
                        [  1.76757812e-01,   1.76757812e-01],
                        [  1.78680420e-01,   1.78680420e-01],
                        [  1.67602539e-01,   1.67602539e-01],
                        [  1.53259277e-01,   1.53259277e-01],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  1.15325928e-01,   1.15325928e-01],
                        [  1.08856201e-01,   1.08856201e-01],
                        [  1.02539062e-01,   1.02539062e-01],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  7.81250000e-02,   7.81250000e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  4.63867188e-03,   4.63867188e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  9.20715332e-02,   9.20715332e-02],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -1.63970947e-01,  -1.63970947e-01],
                        [ -2.33703613e-01,  -2.33703613e-01],
                        [ -2.63214111e-01,  -2.63214111e-01],
                        [ -2.42370605e-01,  -2.42370605e-01],
                        [ -1.90155029e-01,  -1.90155029e-01],
                        [ -1.40380859e-01,  -1.40380859e-01],
                        [ -1.13677979e-01,  -1.13677979e-01],
                        [ -1.06109619e-01,  -1.06109619e-01],
                        [ -1.02233887e-01,  -1.02233887e-01],
                        [ -9.22241211e-02,  -9.22241211e-02],
                        [ -7.79724121e-02,  -7.79724121e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  9.27124023e-02,   9.27124023e-02],
                        [  1.01684570e-01,   1.01684570e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  9.85107422e-02,   9.85107422e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -8.74328613e-02,  -8.74328613e-02],
                        [ -1.56677246e-01,  -1.56677246e-01],
                        [ -1.87774658e-01,  -1.87774658e-01],
                        [ -1.72821045e-01,  -1.72821045e-01],
                        [ -1.29974365e-01,  -1.29974365e-01],
                        [ -8.80432129e-02,  -8.80432129e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.50909424e-01,   1.50909424e-01],
                        [  1.74896240e-01,   1.74896240e-01],
                        [  1.77581787e-01,   1.77581787e-01],
                        [  1.65863037e-01,   1.65863037e-01],
                        [  1.49993896e-01,   1.49993896e-01],
                        [  1.37145996e-01,   1.37145996e-01],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  1.19842529e-01,   1.19842529e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.08612061e-01,   1.08612061e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.19750977e-01,   1.19750977e-01],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  8.62731934e-02,   8.62731934e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  4.62646484e-02,   4.62646484e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -7.74536133e-02,  -7.74536133e-02],
                        [ -1.52221680e-01,  -1.52221680e-01],
                        [ -2.18475342e-01,  -2.18475342e-01],
                        [ -2.55187988e-01,  -2.55187988e-01],
                        [ -2.47039795e-01,  -2.47039795e-01],
                        [ -2.01873779e-01,  -2.01873779e-01],
                        [ -1.51062012e-01,  -1.51062012e-01],
                        [ -1.21215820e-01,  -1.21215820e-01],
                        [ -1.10443115e-01,  -1.10443115e-01],
                        [ -1.00585938e-01,  -1.00585938e-01],
                        [ -8.41674805e-02,  -8.41674805e-02],
                        [ -6.85729980e-02,  -6.85729980e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  6.22863770e-02,   6.22863770e-02],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.32171631e-01,   1.32171631e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  7.07702637e-02,   7.07702637e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -2.15179443e-01,  -2.15179443e-01],
                        [ -1.87103271e-01,  -1.87103271e-01],
                        [ -1.28082275e-01,  -1.28082275e-01],
                        [ -7.47680664e-02,  -7.47680664e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  1.04034424e-01,   1.04034424e-01],
                        [  1.40289307e-01,   1.40289307e-01],
                        [  1.63635254e-01,   1.63635254e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.52465820e-01,   1.52465820e-01],
                        [  1.36657715e-01,   1.36657715e-01],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.29150391e-01,   1.29150391e-01],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.28723145e-01,   1.28692627e-01],
                        [  1.25854492e-01,   1.25854492e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.27716064e-01,   1.27716064e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  5.76171875e-02,   5.76171875e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -1.59423828e-01,  -1.59423828e-01],
                        [ -2.28454590e-01,  -2.28454590e-01],
                        [ -2.60681152e-01,  -2.60681152e-01],
                        [ -2.45208740e-01,  -2.45208740e-01],
                        [ -1.95739746e-01,  -1.95739746e-01],
                        [ -1.44836426e-01,  -1.44836426e-01],
                        [ -1.18103027e-01,  -1.18103027e-01],
                        [ -1.14074707e-01,  -1.14074707e-01],
                        [ -1.13677979e-01,  -1.13677979e-01],
                        [ -1.04278564e-01,  -1.04278564e-01],
                        [ -8.75549316e-02,  -8.75549316e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -3.47290039e-02,  -3.46984863e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  1.10351562e-01,   1.10382080e-01],
                        [  1.20788574e-01,   1.20788574e-01],
                        [  1.07513428e-01,   1.07513428e-01],
                        [  5.82275391e-02,   5.82275391e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -1.67083740e-01,  -1.67083740e-01],
                        [ -1.83258057e-01,  -1.83258057e-01],
                        [ -1.57592773e-01,  -1.57562256e-01],
                        [ -1.13830566e-01,  -1.13830566e-01],
                        [ -7.90710449e-02,  -7.90710449e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -1.77001953e-02,  -1.76696777e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  1.08062744e-01,   1.08062744e-01],
                        [  1.46331787e-01,   1.46331787e-01],
                        [  1.68945312e-01,   1.68945312e-01],
                        [  1.69799805e-01,   1.69799805e-01],
                        [  1.54693604e-01,   1.54693604e-01],
                        [  1.36566162e-01,   1.36566162e-01],
                        [  1.25579834e-01,   1.25579834e-01],
                        [  1.21887207e-01,   1.21887207e-01],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  1.15295410e-01,   1.15295410e-01],
                        [  1.10321045e-01,   1.10321045e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  9.41772461e-02,   9.41772461e-02],
                        [  8.90808105e-02,   8.91113281e-02],
                        [  7.74536133e-02,   7.74536133e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -1.68151855e-02,  -1.67846680e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -1.37512207e-01,  -1.37512207e-01],
                        [ -2.26745605e-01,  -2.26745605e-01],
                        [ -2.83020020e-01,  -2.83020020e-01],
                        [ -2.85522461e-01,  -2.85522461e-01],
                        [ -2.42523193e-01,  -2.42523193e-01],
                        [ -1.83898926e-01,  -1.83898926e-01],
                        [ -1.36169434e-01,  -1.36169434e-01],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -8.70361328e-02,  -8.70361328e-02],
                        [ -7.24792480e-02,  -7.24792480e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -4.54711914e-03,  -4.51660156e-03],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  7.36083984e-02,   7.36083984e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -1.28051758e-01,  -1.28051758e-01],
                        [ -1.71447754e-01,  -1.71447754e-01],
                        [ -1.66900635e-01,  -1.66900635e-01],
                        [ -1.27960205e-01,  -1.27960205e-01],
                        [ -8.37707520e-02,  -8.37707520e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -2.88696289e-02,  -2.88696289e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  1.23962402e-01,   1.23962402e-01],
                        [  1.59912109e-01,   1.59912109e-01],
                        [  1.83868408e-01,   1.83868408e-01],
                        [  1.88995361e-01,   1.88995361e-01],
                        [  1.73034668e-01,   1.73034668e-01],
                        [  1.43951416e-01,   1.43951416e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  9.50927734e-02,   9.50927734e-02],
                        [  9.60388184e-02,   9.60388184e-02],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  8.38623047e-02,   8.38623047e-02],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  1.61743164e-02,   1.61437988e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  8.69750977e-03,   8.72802734e-03],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -1.12152100e-01,  -1.12121582e-01],
                        [ -1.94641113e-01,  -1.94641113e-01],
                        [ -2.55310059e-01,  -2.55310059e-01],
                        [ -2.73925781e-01,  -2.73925781e-01],
                        [ -2.49023438e-01,  -2.49023438e-01],
                        [ -1.98242188e-01,  -1.98242188e-01],
                        [ -1.47155762e-01,  -1.47155762e-01],
                        [ -1.14410400e-01,  -1.14410400e-01],
                        [ -1.01379395e-01,  -1.01379395e-01],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -8.70666504e-02,  -8.70666504e-02],
                        [ -7.62023926e-02,  -7.62023926e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  2.17285156e-02,   2.16979980e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  6.27746582e-02,   6.28051758e-02],
                        [  8.57849121e-02,   8.57849121e-02],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.16821289e-01,   1.16821289e-01],
                        [  1.11877441e-01,   1.11877441e-01],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -1.00463867e-01,  -1.00463867e-01],
                        [ -1.48803711e-01,  -1.48803711e-01],
                        [ -1.61376953e-01,  -1.61376953e-01],
                        [ -1.38305664e-01,  -1.38305664e-01],
                        [ -9.56115723e-02,  -9.56115723e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  1.30889893e-01,   1.30889893e-01],
                        [  1.55242920e-01,   1.55242920e-01],
                        [  1.59912109e-01,   1.59912109e-01],
                        [  1.46942139e-01,   1.46942139e-01],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.06353760e-01,   1.06353760e-01],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.10534668e-01,   1.10534668e-01],
                        [  1.19537354e-01,   1.19537354e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  7.44628906e-02,   7.44323730e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.58691406e-02,  -1.58386230e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.46472168e-02,  -4.46166992e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  1.00189209e-01,   1.00189209e-01],
                        [  1.12915039e-01,   1.12915039e-01],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [ -4.27246094e-04,  -3.96728516e-04],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -7.32421875e-04,  -7.62939453e-04],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.72827148e-02,  -2.72521973e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -2.82592773e-02,  -2.82287598e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  4.99572754e-02,   4.99572754e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  4.41894531e-02,   4.42199707e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -1.32904053e-01,  -1.32904053e-01],
                        [ -2.04986572e-01,  -2.04986572e-01],
                        [ -2.53173828e-01,  -2.53173828e-01],
                        [ -2.62542725e-01,  -2.62542725e-01],
                        [ -2.33947754e-01,  -2.33947754e-01],
                        [ -1.85150146e-01,  -1.85150146e-01],
                        [ -1.38488770e-01,  -1.38488770e-01],
                        [ -1.08123779e-01,  -1.08123779e-01],
                        [ -9.55200195e-02,  -9.55200195e-02],
                        [ -9.29260254e-02,  -9.29260254e-02],
                        [ -9.03015137e-02,  -9.03015137e-02],
                        [ -8.14208984e-02,  -8.14208984e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -3.45458984e-02,  -3.45153809e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  6.80541992e-02,   6.80236816e-02],
                        [  8.97216797e-02,   8.97216797e-02],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.35650635e-01,   1.35620117e-01],
                        [  1.39465332e-01,   1.39465332e-01],
                        [  1.14868164e-01,   1.14868164e-01],
                        [  5.42907715e-02,   5.42907715e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -1.23596191e-01,  -1.23596191e-01],
                        [ -1.79779053e-01,  -1.79779053e-01],
                        [ -1.85577393e-01,  -1.85577393e-01],
                        [ -1.50726318e-01,  -1.50726318e-01],
                        [ -1.02355957e-01,  -1.02355957e-01],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -4.03442383e-02,  -4.03137207e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  1.77124023e-01,   1.77124023e-01],
                        [  2.04406738e-01,   2.04406738e-01],
                        [  1.99798584e-01,   1.99798584e-01],
                        [  1.68701172e-01,   1.68701172e-01],
                        [  1.30432129e-01,   1.30432129e-01],
                        [  1.01684570e-01,   1.01684570e-01],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  9.32617188e-02,   9.32617188e-02],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  8.25195312e-02,   8.25195312e-02],
                        [  5.94177246e-02,   5.94177246e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  2.14843750e-02,   2.15148926e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  1.19415283e-01,   1.19384766e-01],
                        [  1.23748779e-01,   1.23748779e-01],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  4.78820801e-02,   4.78515625e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  3.57055664e-03,   3.54003906e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  7.38525391e-03,   7.35473633e-03],
                        [ -1.08032227e-02,  -1.08337402e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.53796387e-02,  -4.53796387e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.76281738e-02,  -3.75976562e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -7.59887695e-03,  -7.62939453e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -1.25732422e-02,  -1.25427246e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -4.91638184e-02,  -4.91333008e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -7.41577148e-03,  -7.44628906e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -1.37237549e-01,  -1.37268066e-01],
                        [ -2.13806152e-01,  -2.13806152e-01],
                        [ -2.59704590e-01,  -2.59704590e-01],
                        [ -2.60986328e-01,  -2.60986328e-01],
                        [ -2.26928711e-01,  -2.26928711e-01],
                        [ -1.83013916e-01,  -1.83013916e-01],
                        [ -1.47766113e-01,  -1.47796631e-01],
                        [ -1.22100830e-01,  -1.22100830e-01],
                        [ -1.00311279e-01,  -1.00311279e-01],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -7.15637207e-02,  -7.15637207e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.29760742e-01,   1.29760742e-01],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.18408203e-01,   1.18408203e-01],
                        [  7.44323730e-02,   7.44323730e-02],
                        [  1.64794922e-03,   1.67846680e-03],
                        [ -8.53576660e-02,  -8.53576660e-02],
                        [ -1.57104492e-01,  -1.57104492e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -1.70837402e-01,  -1.70806885e-01],
                        [ -1.30432129e-01,  -1.30432129e-01],
                        [ -9.15222168e-02,  -9.15222168e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  1.73217773e-01,   1.73217773e-01],
                        [  2.01202393e-01,   2.01202393e-01],
                        [  2.01293945e-01,   2.01293945e-01],
                        [  1.81091309e-01,   1.81091309e-01],
                        [  1.52435303e-01,   1.52435303e-01],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  9.55200195e-02,   9.55200195e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  7.86743164e-02,   7.86743164e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -2.47192383e-02,  -2.47497559e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  6.57653809e-02,   6.57653809e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  4.34570312e-02,   4.34265137e-02],
                        [  3.17993164e-02,   3.18298340e-02],
                        [  2.52075195e-02,   2.52380371e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  1.62963867e-02,   1.63269043e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.23901367e-02,   1.23901367e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.17175293e-02,  -4.16870117e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  4.91333008e-03,   4.91333008e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -3.67736816e-02,  -3.67431641e-02],
                        [ -1.94396973e-02,  -1.94702148e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  5.02929688e-02,   5.02624512e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  2.15759277e-02,   2.16064453e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -9.88464355e-02,  -9.88769531e-02],
                        [ -1.76757812e-01,  -1.76757812e-01],
                        [ -2.33306885e-01,  -2.33306885e-01],
                        [ -2.48748779e-01,  -2.48748779e-01],
                        [ -2.26226807e-01,  -2.26226807e-01],
                        [ -1.87500000e-01,  -1.87469482e-01],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.32080078e-01,  -1.32080078e-01],
                        [ -1.16058350e-01,  -1.16058350e-01],
                        [ -9.83276367e-02,  -9.83276367e-02],
                        [ -7.85522461e-02,  -7.85827637e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  9.46044922e-02,   9.46044922e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  1.08154297e-01,   1.08154297e-01],
                        [  1.12365723e-01,   1.12396240e-01],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -1.48498535e-01,  -1.48498535e-01],
                        [ -1.90734863e-01,  -1.90734863e-01],
                        [ -1.83959961e-01,  -1.83959961e-01],
                        [ -1.45172119e-01,  -1.45141602e-01],
                        [ -1.02905273e-01,  -1.02905273e-01],
                        [ -7.26623535e-02,  -7.26928711e-02],
                        [ -5.30395508e-02,  -5.30090332e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.42407227e-02,  -3.42712402e-02],
                        [ -3.68347168e-02,  -3.68652344e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [  4.54406738e-02,   4.54711914e-02],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  1.50695801e-01,   1.50695801e-01],
                        [  1.76513672e-01,   1.76513672e-01],
                        [  1.76086426e-01,   1.76086426e-01],
                        [  1.55731201e-01,   1.55700684e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.00921631e-01,   1.00952148e-01],
                        [  8.59375000e-02,   8.59069824e-02],
                        [  8.51135254e-02,   8.51135254e-02],
                        [  9.41162109e-02,   9.41162109e-02],
                        [  1.04064941e-01,   1.04064941e-01],
                        [  1.08062744e-01,   1.08062744e-01],
                        [  1.03851318e-01,   1.03851318e-01],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  6.12792969e-02,   6.13098145e-02],
                        [  5.90820312e-02,   5.90515137e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  2.73742676e-02,   2.73437500e-02],
                        [  1.25732422e-02,   1.25427246e-02],
                        [ -6.10351562e-05,  -3.05175781e-05],
                        [ -1.42211914e-02,  -1.42517090e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  1.07849121e-01,   1.07879639e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  5.04150391e-02,   5.04150391e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  5.31005859e-03,   5.31005859e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -3.60107422e-03,  -3.63159180e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.29699707e-02,  -1.29394531e-02],
                        [ -2.12097168e-02,  -2.12402344e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.57055664e-02,  -3.56750488e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -4.03747559e-02,  -4.03442383e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.68139648e-02,  -4.68444824e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -3.71398926e-02,  -3.71093750e-02],
                        [ -2.49023438e-02,  -2.49328613e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -1.21734619e-01,  -1.21765137e-01],
                        [ -2.00439453e-01,  -2.00439453e-01],
                        [ -2.53509521e-01,  -2.53509521e-01],
                        [ -2.65716553e-01,  -2.65716553e-01],
                        [ -2.42828369e-01,  -2.42828369e-01],
                        [ -2.04681396e-01,  -2.04681396e-01],
                        [ -1.67297363e-01,  -1.67327881e-01],
                        [ -1.35742188e-01,  -1.35742188e-01],
                        [ -1.10168457e-01,  -1.10168457e-01],
                        [ -9.17968750e-02,  -9.17968750e-02],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -7.69348145e-02,  -7.69348145e-02],
                        [ -6.97631836e-02,  -6.97326660e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.59912109e-02,   1.59606934e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  1.27899170e-01,   1.27899170e-01],
                        [  1.37664795e-01,   1.37664795e-01],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -1.52343750e-01,  -1.52343750e-01],
                        [ -1.91680908e-01,  -1.91680908e-01],
                        [ -1.80908203e-01,  -1.80908203e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -8.73718262e-02,  -8.73718262e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  7.97119141e-02,   7.97119141e-02],
                        [  1.36901855e-01,   1.36901855e-01],
                        [  1.74163818e-01,   1.74163818e-01],
                        [  1.86096191e-01,   1.86096191e-01],
                        [  1.76696777e-01,   1.76696777e-01],
                        [  1.55914307e-01,   1.55883789e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  8.97827148e-02,   8.97827148e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  9.32617188e-02,   9.32617188e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  8.97216797e-02,   8.97216797e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -1.13220215e-02,  -1.12915039e-02],
                        [ -2.22167969e-02,  -2.21862793e-02],
                        [ -3.42712402e-02,  -3.43017578e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  1.19293213e-01,   1.19323730e-01],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.58081055e-02,   1.57775879e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  8.72802734e-03,   8.69750977e-03],
                        [ -1.52587891e-04,  -1.83105469e-04],
                        [ -1.06506348e-02,  -1.06201172e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.89306641e-02,  -2.89611816e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.23583984e-02,  -4.23278809e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  3.92456055e-02,   3.92456055e-02],
                        [  5.93872070e-02,   5.93872070e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  4.05578613e-02,   4.05273438e-02],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -1.59027100e-01,  -1.59027100e-01],
                        [ -2.35015869e-01,  -2.35015869e-01],
                        [ -2.76519775e-01,  -2.76519775e-01],
                        [ -2.72338867e-01,  -2.72338867e-01],
                        [ -2.33245850e-01,  -2.33245850e-01],
                        [ -1.83654785e-01,  -1.83654785e-01],
                        [ -1.44287109e-01,  -1.44287109e-01],
                        [ -1.20819092e-01,  -1.20819092e-01],
                        [ -1.06201172e-01,  -1.06201172e-01],
                        [ -9.03625488e-02,  -9.03625488e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -2.13623047e-03,  -2.16674805e-03],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  9.88464355e-02,   9.88159180e-02],
                        [  1.17828369e-01,   1.17828369e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.25183105e-01,   1.25183105e-01],
                        [  9.54895020e-02,   9.54895020e-02],
                        [  3.66210938e-02,   3.66210938e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -1.17340088e-01,  -1.17340088e-01],
                        [ -1.63269043e-01,  -1.63269043e-01],
                        [ -1.68945312e-01,  -1.68945312e-01],
                        [ -1.44958496e-01,  -1.44958496e-01],
                        [ -1.13159180e-01,  -1.13159180e-01],
                        [ -8.89282227e-02,  -8.89282227e-02],
                        [ -7.39135742e-02,  -7.39135742e-02],
                        [ -6.43615723e-02,  -6.43615723e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -4.66003418e-02,  -4.65698242e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  1.55731201e-01,   1.55731201e-01],
                        [  1.72821045e-01,   1.72821045e-01],
                        [  1.71356201e-01,   1.71356201e-01],
                        [  1.58416748e-01,   1.58416748e-01],
                        [  1.42761230e-01,   1.42761230e-01],
                        [  1.29150391e-01,   1.29150391e-01],
                        [  1.16455078e-01,   1.16485596e-01],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  8.03833008e-02,   8.03833008e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  7.40661621e-02,   7.40661621e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  2.68249512e-02,   2.68249512e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  2.36816406e-02,   2.36511230e-02],
                        [  2.27661133e-02,   2.27966309e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -5.18493652e-02,  -5.18798828e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  1.06597900e-01,   1.06597900e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  9.50927734e-02,   9.51232910e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.35083008e-02,  -3.35388184e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  1.22985840e-02,   1.22680664e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  5.88073730e-02,   5.88073730e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -1.06719971e-01,  -1.06719971e-01],
                        [ -1.83898926e-01,  -1.83898926e-01],
                        [ -2.41241455e-01,  -2.41271973e-01],
                        [ -2.61779785e-01,  -2.61779785e-01],
                        [ -2.46978760e-01,  -2.46978760e-01],
                        [ -2.12890625e-01,  -2.12890625e-01],
                        [ -1.76544189e-01,  -1.76544189e-01],
                        [ -1.46301270e-01,  -1.46301270e-01],
                        [ -1.21887207e-01,  -1.21887207e-01],
                        [ -1.00555420e-01,  -1.00555420e-01],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -4.33654785e-02,  -4.33959961e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -1.01928711e-02,  -1.01623535e-02],
                        [  1.12915039e-02,   1.12609863e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  3.88793945e-02,   3.89099121e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  5.37719727e-02,   5.37414551e-02],
                        [  7.08618164e-02,   7.08923340e-02],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.42425537e-01,   1.42425537e-01],
                        [  1.33819580e-01,   1.33819580e-01],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [ -7.95593262e-02,  -7.95593262e-02],
                        [ -1.62750244e-01,  -1.62750244e-01],
                        [ -2.05474854e-01,  -2.05474854e-01],
                        [ -1.95983887e-01,  -1.95983887e-01],
                        [ -1.52465820e-01,  -1.52465820e-01],
                        [ -1.06933594e-01,  -1.06933594e-01],
                        [ -7.90405273e-02,  -7.90405273e-02],
                        [ -6.70166016e-02,  -6.70166016e-02],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -3.19213867e-02,  -3.19519043e-02],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  1.52648926e-01,   1.52679443e-01],
                        [  1.71142578e-01,   1.71142578e-01],
                        [  1.71600342e-01,   1.71600342e-01],
                        [  1.57531738e-01,   1.57531738e-01],
                        [  1.38946533e-01,   1.38946533e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  9.43298340e-02,   9.43603516e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  5.59692383e-02,   5.59387207e-02],
                        [  5.80444336e-02,   5.80749512e-02],
                        [  6.17675781e-02,   6.17370605e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  6.28051758e-02,   6.28356934e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  3.47595215e-02,   3.47900391e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  8.17871094e-03,   8.14819336e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  5.78308105e-02,   5.78308105e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -2.97546387e-02,  -2.97851562e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.22070312e-02,  -1.22375488e-02],
                        [ -1.01928711e-02,  -1.02233887e-02],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.66723633e-02,  -2.66418457e-02],
                        [ -2.06298828e-02,  -2.06604004e-02],
                        [ -1.08032227e-02,  -1.08337402e-02],
                        [  5.73730469e-03,   5.76782227e-03],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  6.99768066e-02,   6.99768066e-02],
                        [  3.67736816e-02,   3.67431641e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -1.88659668e-01,  -1.88659668e-01],
                        [ -2.54516602e-01,  -2.54516602e-01],
                        [ -2.82653809e-01,  -2.82653809e-01],
                        [ -2.64099121e-01,  -2.64099121e-01],
                        [ -2.11853027e-01,  -2.11883545e-01],
                        [ -1.57684326e-01,  -1.57714844e-01],
                        [ -1.27441406e-01,  -1.27441406e-01],
                        [ -1.19018555e-01,  -1.19018555e-01],
                        [ -1.11663818e-01,  -1.11663818e-01],
                        [ -9.46350098e-02,  -9.46350098e-02],
                        [ -7.51953125e-02,  -7.51953125e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -2.70385742e-02,  -2.70080566e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  1.31072998e-01,   1.31042480e-01],
                        [  1.32781982e-01,   1.32781982e-01],
                        [  1.07513428e-01,   1.07513428e-01],
                        [  5.12390137e-02,   5.12390137e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -1.05377197e-01,  -1.05346680e-01],
                        [ -1.59088135e-01,  -1.59088135e-01],
                        [ -1.74865723e-01,  -1.74865723e-01],
                        [ -1.57989502e-01,  -1.57989502e-01],
                        [ -1.28875732e-01,  -1.28875732e-01],
                        [ -1.08703613e-01,  -1.08703613e-01],
                        [ -1.02691650e-01,  -1.02691650e-01],
                        [ -9.80834961e-02,  -9.80834961e-02],
                        [ -8.00781250e-02,  -8.00781250e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  1.10473633e-01,   1.10504150e-01],
                        [  1.49627686e-01,   1.49627686e-01],
                        [  1.62536621e-01,   1.62536621e-01],
                        [  1.53747559e-01,   1.53747559e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.26281738e-01,   1.26281738e-01],
                        [  1.14593506e-01,   1.14593506e-01],
                        [  1.01837158e-01,   1.01837158e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  8.68225098e-02,   8.68225098e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  7.45849609e-02,   7.46154785e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  4.09545898e-02,   4.09851074e-02],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.91345215e-02,  -1.91650391e-02],
                        [ -3.23181152e-02,  -3.23486328e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  8.92944336e-02,   8.92944336e-02],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  9.17358398e-02,   9.17663574e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.83715820e-02,   1.84020996e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  2.70690918e-02,   2.70996094e-02],
                        [  2.18811035e-02,   2.19116211e-02],
                        [  1.71813965e-02,   1.71508789e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -3.36303711e-02,  -3.36608887e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -3.40576172e-02,  -3.40881348e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -3.27453613e-02,  -3.27148438e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -1.14227295e-01,  -1.14227295e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -2.74291992e-01,  -2.74291992e-01],
                        [ -2.94647217e-01,  -2.94647217e-01],
                        [ -2.63763428e-01,  -2.63763428e-01],
                        [ -2.05780029e-01,  -2.05780029e-01],
                        [ -1.55090332e-01,  -1.55090332e-01],
                        [ -1.29913330e-01,  -1.29913330e-01],
                        [ -1.22467041e-01,  -1.22467041e-01],
                        [ -1.12701416e-01,  -1.12701416e-01],
                        [ -8.94470215e-02,  -8.94470215e-02],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  2.85644531e-02,   2.85949707e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  1.40167236e-01,   1.40167236e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  7.37915039e-02,   7.37915039e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.18469238e-01,  -1.18499756e-01],
                        [ -1.88323975e-01,  -1.88293457e-01],
                        [ -2.10540771e-01,  -2.10540771e-01],
                        [ -1.89636230e-01,  -1.89666748e-01],
                        [ -1.47674561e-01,  -1.47674561e-01],
                        [ -1.10229492e-01,  -1.10229492e-01],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -5.28259277e-02,  -5.28259277e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  9.11865234e-02,   9.11865234e-02],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.50451660e-01,   1.50451660e-01],
                        [  1.52343750e-01,   1.52343750e-01],
                        [  1.41754150e-01,   1.41754150e-01],
                        [  1.26953125e-01,   1.26953125e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.01898193e-01,   1.01867676e-01],
                        [  9.10949707e-02,   9.10949707e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  7.34863281e-02,   7.34863281e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  5.14526367e-02,   5.14526367e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  4.52880859e-02,   4.52575684e-02],
                        [  3.11584473e-02,   3.11279297e-02],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -2.76184082e-02,  -2.76489258e-02],
                        [  5.21850586e-03,   5.18798828e-03],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  7.77587891e-02,   7.77587891e-02],
                        [  9.04235840e-02,   9.04235840e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.56958008e-02,   2.57263184e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -4.88281250e-03,  -4.85229492e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.27758789e-02,  -3.28063965e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -3.21350098e-02,  -3.21044922e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.99682617e-02,  -2.99377441e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  7.01599121e-02,   7.01599121e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  3.19824219e-02,   3.19519043e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -1.25183105e-01,  -1.25183105e-01],
                        [ -2.13836670e-01,  -2.13836670e-01],
                        [ -2.72430420e-01,  -2.72430420e-01],
                        [ -2.84637451e-01,  -2.84637451e-01],
                        [ -2.54119873e-01,  -2.54150391e-01],
                        [ -2.01446533e-01,  -2.01446533e-01],
                        [ -1.50909424e-01,  -1.50909424e-01],
                        [ -1.16241455e-01,  -1.16241455e-01],
                        [ -9.73510742e-02,  -9.73510742e-02],
                        [ -8.86230469e-02,  -8.86230469e-02],
                        [ -8.41979980e-02,  -8.41979980e-02],
                        [ -7.74841309e-02,  -7.74841309e-02],
                        [ -6.39648438e-02,  -6.39343262e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -1.42822266e-02,  -1.42517090e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  3.00292969e-02,   3.00598145e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  4.29077148e-02,   4.28771973e-02],
                        [  5.55114746e-02,   5.55114746e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  1.50268555e-01,   1.50268555e-01],
                        [  1.47430420e-01,   1.47430420e-01],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  4.11682129e-02,   4.11682129e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -1.52526855e-01,  -1.52526855e-01],
                        [ -2.12951660e-01,  -2.12951660e-01],
                        [ -2.20855713e-01,  -2.20855713e-01],
                        [ -1.84448242e-01,  -1.84478760e-01],
                        [ -1.29913330e-01,  -1.29913330e-01],
                        [ -7.97729492e-02,  -7.97729492e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  1.03057861e-01,   1.03057861e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.24969482e-01,   1.24969482e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  9.32617188e-02,   9.32617188e-02],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  9.41162109e-02,   9.41162109e-02],
                        [  9.24377441e-02,   9.24377441e-02],
                        [  8.65478516e-02,   8.65478516e-02],
                        [  7.84912109e-02,   7.84912109e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  5.76171875e-02,   5.76171875e-02],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  5.62133789e-02,   5.62438965e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  5.65185547e-02,   5.65490723e-02],
                        [  5.69152832e-02,   5.69152832e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  5.11474609e-02,   5.11474609e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  1.94396973e-02,   1.94091797e-02],
                        [  9.39941406e-03,   9.42993164e-03],
                        [  5.21850586e-03,   5.24902344e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -1.44653320e-02,  -1.44958496e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  5.37414551e-02,   5.37414551e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  3.64379883e-02,   3.64074707e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -1.33789062e-01,  -1.33789062e-01],
                        [ -1.96594238e-01,  -1.96624756e-01],
                        [ -2.35900879e-01,  -2.35900879e-01],
                        [ -2.41760254e-01,  -2.41729736e-01],
                        [ -2.16094971e-01,  -2.16094971e-01],
                        [ -1.76879883e-01,  -1.76879883e-01],
                        [ -1.46881104e-01,  -1.46850586e-01],
                        [ -1.34033203e-01,  -1.34033203e-01],
                        [ -1.28997803e-01,  -1.28997803e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -1.04156494e-01,  -1.04156494e-01],
                        [ -8.30993652e-02,  -8.30993652e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -5.34057617e-03,  -5.31005859e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  8.45336914e-02,   8.45336914e-02],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  1.34582520e-01,   1.34582520e-01],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [ -7.82165527e-02,  -7.82470703e-02],
                        [ -1.67816162e-01,  -1.67816162e-01],
                        [ -2.11303711e-01,  -2.11303711e-01],
                        [ -1.91894531e-01,  -1.91925049e-01],
                        [ -1.27532959e-01,  -1.27532959e-01],
                        [ -5.77697754e-02,  -5.77697754e-02],
                        [ -1.08642578e-02,  -1.08947754e-02],
                        [  1.44042969e-02,   1.43737793e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  7.49511719e-02,   7.49511719e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  9.27429199e-02,   9.27429199e-02],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  8.43200684e-02,   8.43200684e-02],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  8.35266113e-02,   8.35266113e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  1.76086426e-02,   1.76391602e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  3.66210938e-04,   3.35693359e-04],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -8.85009766e-03,  -8.85009766e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.82189941e-02,   1.82495117e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -4.07409668e-02,  -4.07714844e-02],
                        [ -7.95898438e-02,  -7.95898438e-02],
                        [ -1.19140625e-01,  -1.19140625e-01],
                        [ -1.54815674e-01,  -1.54846191e-01],
                        [ -1.81640625e-01,  -1.81640625e-01],
                        [ -1.93206787e-01,  -1.93206787e-01],
                        [ -1.87072754e-01,  -1.87072754e-01],
                        [ -1.68701172e-01,  -1.68701172e-01],
                        [ -1.47766113e-01,  -1.47766113e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -1.20483398e-01,  -1.20483398e-01],
                        [ -1.10473633e-01,  -1.10473633e-01],
                        [ -9.87854004e-02,  -9.87854004e-02],
                        [ -8.61511230e-02,  -8.61511230e-02],
                        [ -7.40661621e-02,  -7.40661621e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [  5.55419922e-03,   5.58471680e-03],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  9.15222168e-02,   9.14916992e-02],
                        [  1.13311768e-01,   1.13311768e-01],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.23748779e-01,   1.23748779e-01],
                        [  9.82666016e-02,   9.82360840e-02],
                        [  4.81872559e-02,   4.82177734e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -9.97924805e-02,  -9.97924805e-02],
                        [ -1.57745361e-01,  -1.57745361e-01],
                        [ -1.71447754e-01,  -1.71447754e-01],
                        [ -1.36169434e-01,  -1.36199951e-01],
                        [ -7.58972168e-02,  -7.58972168e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  4.77294922e-02,   4.77600098e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  3.34777832e-02,   3.34472656e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  1.16943359e-01,   1.16943359e-01],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  5.92346191e-02,   5.92346191e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [ -2.22778320e-03,  -2.25830078e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -1.82189941e-02,  -1.82495117e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.07922363e-02,  -3.07617188e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.28479004e-02,  -1.28784180e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -1.18774414e-01,  -1.18774414e-01],
                        [ -1.61132812e-01,  -1.61132812e-01],
                        [ -1.92810059e-01,  -1.92810059e-01],
                        [ -2.05566406e-01,  -2.05566406e-01],
                        [ -1.99279785e-01,  -1.99279785e-01],
                        [ -1.83715820e-01,  -1.83685303e-01],
                        [ -1.66931152e-01,  -1.66931152e-01],
                        [ -1.49078369e-01,  -1.49078369e-01],
                        [ -1.27532959e-01,  -1.27532959e-01],
                        [ -1.04064941e-01,  -1.04064941e-01],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -7.62329102e-02,  -7.62329102e-02],
                        [ -7.33642578e-02,  -7.33642578e-02],
                        [ -6.70471191e-02,  -6.70166016e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  1.02844238e-02,   1.02539062e-02],
                        [  8.94165039e-03,   8.97216797e-03],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.57775879e-02,   1.58081055e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  8.51440430e-02,   8.51440430e-02],
                        [  1.09985352e-01,   1.09985352e-01],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.35040283e-01,   1.35040283e-01],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [ -6.64367676e-02,  -6.64672852e-02],
                        [ -1.26190186e-01,  -1.26159668e-01],
                        [ -1.46850586e-01,  -1.46850586e-01],
                        [ -1.17828369e-01,  -1.17828369e-01],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  4.77294922e-02,   4.77294922e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  6.42089844e-02,   6.42089844e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  7.12280273e-02,   7.12280273e-02],
                        [  6.06079102e-02,   6.05773926e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  4.51660156e-02,   4.51965332e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  9.47570801e-02,   9.47875977e-02],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  9.60083008e-02,   9.60083008e-02],
                        [  7.42492676e-02,   7.42797852e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  8.14819336e-03,   8.11767578e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.03247070e-02,  -2.02941895e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  8.88671875e-02,   8.88671875e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  2.17895508e-02,   2.17895508e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -1.32904053e-01,  -1.32904053e-01],
                        [ -2.10845947e-01,  -2.10845947e-01],
                        [ -2.64648438e-01,  -2.64648438e-01],
                        [ -2.80456543e-01,  -2.80456543e-01],
                        [ -2.56927490e-01,  -2.56927490e-01],
                        [ -2.09930420e-01,  -2.09930420e-01],
                        [ -1.63757324e-01,  -1.63757324e-01],
                        [ -1.33911133e-01,  -1.33941650e-01],
                        [ -1.19384766e-01,  -1.19384766e-01],
                        [ -1.09069824e-01,  -1.09069824e-01],
                        [ -9.53369141e-02,  -9.53369141e-02],
                        [ -7.95898438e-02,  -7.95898438e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -3.62854004e-02,  -3.63159180e-02],
                        [ -2.71911621e-02,  -2.71606445e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  1.87377930e-02,   1.87072754e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -4.54711914e-03,  -4.57763672e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  8.96606445e-02,   8.96911621e-02],
                        [  1.08947754e-01,   1.08947754e-01],
                        [  1.21643066e-01,   1.21612549e-01],
                        [  1.22467041e-01,   1.22497559e-01],
                        [  1.10961914e-01,   1.10961914e-01],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -1.08093262e-01,  -1.08093262e-01],
                        [ -9.43298340e-02,  -9.43298340e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  4.06799316e-02,   4.06494141e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  5.39550781e-02,   5.39245605e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  4.29687500e-02,   4.29382324e-02],
                        [  4.63256836e-02,   4.62951660e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  4.44335938e-02,   4.44335938e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -5.31616211e-02,  -5.31311035e-02],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [ -5.51452637e-02,  -5.51757812e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  1.32110596e-01,   1.32141113e-01],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.01196289e-01,   1.01165771e-01],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  4.35485840e-02,   4.35791016e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  3.20434570e-03,   3.20434570e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  6.46972656e-03,   6.43920898e-03],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  2.48107910e-02,   2.48413086e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [ -3.66210938e-03,  -3.69262695e-03],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  4.08020020e-02,   4.07714844e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  7.17163086e-02,   7.17468262e-02],
                        [  7.94982910e-02,   7.94677734e-02],
                        [  6.95800781e-02,   6.95800781e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -1.18133545e-01,  -1.18164062e-01],
                        [ -1.94396973e-01,  -1.94396973e-01],
                        [ -2.46551514e-01,  -2.46551514e-01],
                        [ -2.64770508e-01,  -2.64801025e-01],
                        [ -2.50274658e-01,  -2.50274658e-01],
                        [ -2.14874268e-01,  -2.14874268e-01],
                        [ -1.74316406e-01,  -1.74316406e-01],
                        [ -1.40075684e-01,  -1.40106201e-01],
                        [ -1.16027832e-01,  -1.16027832e-01],
                        [ -9.85717773e-02,  -9.85717773e-02],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -4.61730957e-02,  -4.62036133e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -2.37121582e-02,  -2.36816406e-02],
                        [ -6.98852539e-03,  -7.01904297e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  2.53906250e-02,   2.54211426e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  2.91748047e-02,   2.92053223e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  7.54089355e-02,   7.53784180e-02],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  1.17370605e-01,   1.17401123e-01],
                        [  1.35406494e-01,   1.35406494e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  3.41491699e-02,   3.41186523e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -9.27734375e-02,  -9.27734375e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -1.60827637e-02,  -1.60522461e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  4.62646484e-02,   4.62341309e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -3.80554199e-02,  -3.80249023e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.05529785e-01,   1.05529785e-01],
                        [  7.42187500e-02,   7.41882324e-02],
                        [  4.67834473e-02,   4.67529297e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.93481445e-02,   1.93176270e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  1.76086426e-02,   1.76391602e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  4.05578613e-02,   4.05273438e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -3.93981934e-02,  -3.93676758e-02],
                        [ -9.96093750e-02,  -9.96093750e-02],
                        [ -1.68060303e-01,  -1.68060303e-01],
                        [ -2.26776123e-01,  -2.26776123e-01],
                        [ -2.53204346e-01,  -2.53204346e-01],
                        [ -2.40997314e-01,  -2.40997314e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -1.70562744e-01,  -1.70562744e-01],
                        [ -1.44805908e-01,  -1.44805908e-01],
                        [ -1.27471924e-01,  -1.27471924e-01],
                        [ -1.11694336e-01,  -1.11694336e-01],
                        [ -9.26208496e-02,  -9.26208496e-02],
                        [ -7.16857910e-02,  -7.16857910e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.15039062e-02,  -4.15344238e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.83911133e-02,  -3.83605957e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -1.71508789e-02,  -1.71813965e-02],
                        [ -1.89208984e-03,  -1.86157227e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  1.65405273e-02,   1.65100098e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -3.66210938e-04,  -3.96728516e-04],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.27258301e-02,   1.27563477e-02],
                        [  3.01818848e-02,   3.02124023e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  9.97924805e-02,   9.97924805e-02],
                        [  1.22283936e-01,   1.22283936e-01],
                        [  1.41784668e-01,   1.41815186e-01],
                        [  1.53045654e-01,   1.53045654e-01],
                        [  1.47949219e-01,   1.47949219e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  6.43615723e-02,   6.43615723e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -8.12988281e-02,  -8.12988281e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  6.53076172e-03,   6.50024414e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  2.96020508e-03,   2.92968750e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [ -2.74658203e-04,  -2.44140625e-04],
                        [  1.43737793e-02,   1.43432617e-02],
                        [  3.34167480e-02,   3.33862305e-02],
                        [  4.90722656e-02,   4.91027832e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  6.38427734e-02,   6.38122559e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  5.67016602e-02,   5.67321777e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  9.79614258e-03,   9.76562500e-03],
                        [  1.62353516e-02,   1.62658691e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.22985840e-02,   1.22680664e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -3.22875977e-02,  -3.23181152e-02],
                        [ -4.84313965e-02,  -4.84619141e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -5.92346191e-02,  -5.92041016e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -5.18798828e-04,  -5.49316406e-04],
                        [  5.40771484e-02,   5.40466309e-02],
                        [  1.06475830e-01,   1.06506348e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.30310059e-01,   1.30279541e-01],
                        [  9.55200195e-02,   9.55200195e-02],
                        [  5.58166504e-02,   5.58471680e-02],
                        [  3.26232910e-02,   3.26538086e-02],
                        [  2.83813477e-02,   2.83508301e-02],
                        [  2.99377441e-02,   2.99072266e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  1.34277344e-02,   1.34582520e-02],
                        [  2.01416016e-03,   1.98364258e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  3.60107422e-03,   3.63159180e-03],
                        [  6.92749023e-03,   6.95800781e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -1.27258301e-02,  -1.26953125e-02],
                        [ -8.94165039e-03,  -8.91113281e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -3.99780273e-03,  -4.02832031e-03],
                        [ -5.67626953e-03,  -5.64575195e-03],
                        [ -5.55419922e-03,  -5.52368164e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  1.95312500e-03,   1.92260742e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  1.74865723e-02,   1.75170898e-02],
                        [  2.42004395e-02,   2.42309570e-02],
                        [  2.99682617e-02,   2.99377441e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  5.71594238e-02,   5.71899414e-02],
                        [  7.35473633e-02,   7.35473633e-02],
                        [  7.81860352e-02,   7.81250000e-02],
                        [  6.60095215e-02,   6.60400391e-02],
                        [  3.79943848e-02,   3.80554199e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -6.23168945e-02,  -6.23779297e-02],
                        [ -1.26007080e-01,  -1.25976562e-01],
                        [ -1.84387207e-01,  -1.84326172e-01],
                        [ -2.26287842e-01,  -2.26318359e-01],
                        [ -2.43408203e-01,  -2.43469238e-01],
                        [ -2.33306885e-01,  -2.33306885e-01],
                        [ -2.04101562e-01,  -2.04010010e-01],
                        [ -1.71325684e-01,  -1.71325684e-01],
                        [ -1.46118164e-01,  -1.46209717e-01],
                        [ -1.27349854e-01,  -1.27349854e-01],
                        [ -1.07238770e-01,  -1.07177734e-01],
                        [ -8.33740234e-02,  -8.33435059e-02],
                        [ -6.23474121e-02,  -6.24084473e-02],
                        [ -5.21545410e-02,  -5.21850586e-02],
                        [ -5.23071289e-02,  -5.22766113e-02],
                        [ -5.26733398e-02,  -5.26123047e-02],
                        [ -4.38842773e-02,  -4.39147949e-02],
                        [ -2.76794434e-02,  -2.77404785e-02],
                        [ -1.21154785e-02,  -1.20849609e-02],
                        [ -1.49536133e-03,  -1.43432617e-03],
                        [  4.91333008e-03,   4.88281250e-03],
                        [  1.01623535e-02,   1.01013184e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.49938965e-02,   2.50244141e-02],
                        [  2.73132324e-02,   2.72827148e-02],
                        [  2.16979980e-02,   2.16674805e-02],
                        [  1.37023926e-02,   1.37329102e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  9.73510742e-03,   9.70458984e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  5.95092773e-03,   5.98144531e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  2.04772949e-02,   2.04467773e-02],
                        [  3.73840332e-02,   3.74145508e-02],
                        [  6.01501465e-02,   6.01806641e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  1.80023193e-01,   1.79992676e-01],
                        [  2.17773438e-01,   2.17773438e-01],
                        [  2.27478027e-01,   2.27478027e-01],
                        [  1.92993164e-01,   1.92993164e-01],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  1.22375488e-02,   1.22375488e-02],
                        [ -7.18383789e-02,  -7.18688965e-02],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -9.32617188e-02,  -9.32312012e-02],
                        [ -5.44433594e-02,  -5.44128418e-02],
                        [ -2.44140625e-02,  -2.44445801e-02],
                        [ -1.75170898e-02,  -1.75476074e-02],
                        [ -2.34985352e-02,  -2.34680176e-02],
                        [ -2.45056152e-02,  -2.44750977e-02],
                        [ -1.52587891e-02,  -1.52893066e-02],
                        [ -4.57763672e-03,  -4.63867188e-03],
                        [  2.44140625e-04,   2.13623047e-04],
                        [  3.29589844e-03,   3.32641602e-03],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  2.34375000e-02,   2.34069824e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  3.76892090e-02,   3.77197266e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  5.57556152e-02,   5.56945801e-02],
                        [  4.88891602e-02,   4.88281250e-02],
                        [  3.37219238e-02,   3.37524414e-02],
                        [  2.09350586e-02,   2.10266113e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  1.30310059e-02,   1.29394531e-02],
                        [  9.79614258e-03,   9.76562500e-03],
                        [  8.51440430e-03,   8.63647461e-03],
                        [  9.15527344e-03,   9.21630859e-03],
                        [  3.75366211e-03,   3.66210938e-03],
                        [ -1.15356445e-02,  -1.15966797e-02],
                        [ -2.82592773e-02,  -2.82287598e-02],
                        [ -3.74145508e-02,  -3.73535156e-02],
                        [ -4.07714844e-02,  -4.08020020e-02],
                        [ -4.42810059e-02,  -4.43420410e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.56140137e-02,  -3.55834961e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  1.14929199e-01,   1.14898682e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  9.58862305e-02,   9.59167480e-02],
                        [  6.90307617e-02,   6.90307617e-02],
                        [  5.20324707e-02,   5.20019531e-02],
                        [  4.59594727e-02,   4.59289551e-02],
                        [  4.23583984e-02,   4.23889160e-02],
                        [  3.56445312e-02,   3.56750488e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  1.90429688e-02,   1.90124512e-02],
                        [  1.28173828e-02,   1.28479004e-02],
                        [  7.14111328e-03,   7.17163086e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [ -7.04956055e-03,  -7.08007812e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.29797363e-02,  -2.30102539e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.89208984e-03,  -1.86157227e-03],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  2.50549316e-02,   2.50854492e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  1.66320801e-02,   1.66015625e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  7.93457031e-02,   7.93151855e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  1.02081299e-01,   1.02111816e-01],
                        [  8.85009766e-02,   8.85314941e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [ -2.39257812e-02,  -2.39868164e-02],
                        [ -1.08154297e-01,  -1.08154297e-01],
                        [ -1.89971924e-01,  -1.89910889e-01],
                        [ -2.50823975e-01,  -2.50823975e-01],
                        [ -2.73986816e-01,  -2.74047852e-01],
                        [ -2.54730225e-01,  -2.54760742e-01],
                        [ -2.09838867e-01,  -2.09808350e-01],
                        [ -1.68090820e-01,  -1.68029785e-01],
                        [ -1.45172119e-01,  -1.45202637e-01],
                        [ -1.34246826e-01,  -1.34277344e-01],
                        [ -1.22772217e-01,  -1.22772217e-01],
                        [ -1.08856201e-01,  -1.08856201e-01],
                        [ -9.63439941e-02,  -9.63134766e-02],
                        [ -8.54187012e-02,  -8.54187012e-02],
                        [ -7.50427246e-02,  -7.50732422e-02],
                        [ -6.60095215e-02,  -6.60400391e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -4.52880859e-02,  -4.52270508e-02],
                        [ -2.74963379e-02,  -2.74353027e-02],
                        [ -6.83593750e-03,  -6.89697266e-03],
                        [  1.16882324e-02,   1.16271973e-02],
                        [  2.52380371e-02,   2.52990723e-02],
                        [  3.21350098e-02,   3.22265625e-02],
                        [  3.07006836e-02,   3.06701660e-02],
                        [  2.31628418e-02,   2.31018066e-02],
                        [  1.69982910e-02,   1.70288086e-02],
                        [  1.54418945e-02,   1.55029297e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.55639648e-03,   1.52587891e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -2.16369629e-02,  -2.16064453e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [  3.26538086e-03,   3.23486328e-03],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  9.74426270e-02,   9.74731445e-02],
                        [  1.42822266e-01,   1.42822266e-01],
                        [  1.97967529e-01,   1.97906494e-01],
                        [  2.46887207e-01,   2.46917725e-01],
                        [  2.69256592e-01,   2.69317627e-01],
                        [  2.47161865e-01,   2.47131348e-01],
                        [  1.72119141e-01,   1.72058105e-01],
                        [  5.95092773e-02,   5.95397949e-02],
                        [ -5.05371094e-02,  -5.04760742e-02],
                        [ -1.18469238e-01,  -1.18499756e-01],
                        [ -1.31866455e-01,  -1.31927490e-01],
                        [ -1.06689453e-01,  -1.06658936e-01],
                        [ -6.90307617e-02,  -6.90002441e-02],
                        [ -3.82995605e-02,  -3.83605957e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.24206543e-02,  -1.23596191e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.68457031e-02,  -1.69372559e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -4.58984375e-02,  -4.58068848e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -2.01110840e-02,  -2.02026367e-02],
                        [  7.65991211e-03,   7.62939453e-03],
                        [  2.85949707e-02,   2.86865234e-02],
                        [  4.25109863e-02,   4.25720215e-02],
                        [  5.45959473e-02,   5.45043945e-02],
                        [  6.41479492e-02,   6.40869141e-02],
                        [  6.55822754e-02,   6.56433105e-02],
                        [  5.67932129e-02,   5.68847656e-02],
                        [  4.15954590e-02,   4.15649414e-02],
                        [  2.50549316e-02,   2.49938965e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [ -3.05175781e-03,  -3.02124023e-03],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.78222656e-02,  -1.78527832e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.50451660e-02,  -1.50146484e-02],
                        [ -1.72119141e-02,  -1.71813965e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -3.13110352e-02,  -3.13415527e-02],
                        [ -3.79943848e-02,  -3.80249023e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -1.66625977e-02,  -1.66015625e-02],
                        [  2.35290527e-02,   2.35595703e-02],
                        [  7.19909668e-02,   7.19299316e-02],
                        [  1.06231689e-01,   1.06170654e-01],
                        [  1.13220215e-01,   1.13311768e-01],
                        [  9.86633301e-02,   9.87548828e-02],
                        [  7.72094727e-02,   7.71484375e-02],
                        [  5.95703125e-02,   5.94787598e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  3.37219238e-02,   3.38134766e-02],
                        [  1.87072754e-02,   1.87377930e-02],
                        [  6.77490234e-03,   6.71386719e-03],
                        [  4.24194336e-03,   4.21142578e-03],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  2.09655762e-02,   2.10266113e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  6.95800781e-03,   6.92749023e-03],
                        [ -1.49841309e-02,  -1.50146484e-02],
                        [ -3.18603516e-02,  -3.18298340e-02],
                        [ -3.54003906e-02,  -3.53698730e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  2.82287598e-02,   2.82592773e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  5.99670410e-02,   5.99365234e-02],
                        [  7.72094727e-02,   7.71789551e-02],
                        [  9.54589844e-02,   9.55200195e-02],
                        [  1.11480713e-01,   1.11511230e-01],
                        [  1.14959717e-01,   1.14898682e-01],
                        [  9.66491699e-02,   9.66186523e-02],
                        [  5.63354492e-02,   5.63964844e-02],
                        [ -3.08227539e-03,  -3.05175781e-03],
                        [ -8.23364258e-02,  -8.23669434e-02],
                        [ -1.74591064e-01,  -1.74621582e-01],
                        [ -2.53662109e-01,  -2.53631592e-01],
                        [ -2.88604736e-01,  -2.88604736e-01],
                        [ -2.71759033e-01,  -2.71820068e-01],
                        [ -2.23785400e-01,  -2.23785400e-01],
                        [ -1.74346924e-01,  -1.74285889e-01],
                        [ -1.42944336e-01,  -1.42974854e-01],
                        [ -1.30889893e-01,  -1.30920410e-01],
                        [ -1.24725342e-01,  -1.24694824e-01],
                        [ -1.11907959e-01,  -1.11907959e-01],
                        [ -9.29260254e-02,  -9.29565430e-02],
                        [ -7.54699707e-02,  -7.54394531e-02],
                        [ -6.32934570e-02,  -6.32629395e-02],
                        [ -5.48400879e-02,  -5.48706055e-02],
                        [ -4.73022461e-02,  -4.73327637e-02],
                        [ -3.86962891e-02,  -3.86657715e-02],
                        [ -2.96936035e-02,  -2.96630859e-02],
                        [ -2.27050781e-02,  -2.27661133e-02],
                        [ -1.62048340e-02,  -1.62658691e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  9.70458984e-03,   9.73510742e-03],
                        [  2.32238770e-02,   2.32543945e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  3.28979492e-02,   3.28674316e-02],
                        [  2.54516602e-02,   2.53906250e-02],
                        [  1.08642578e-02,   1.09252930e-02],
                        [ -2.47192383e-03,  -2.38037109e-03],
                        [ -8.60595703e-03,  -8.66699219e-03],
                        [ -9.88769531e-03,  -1.00097656e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -8.14819336e-03,  -8.02612305e-03],
                        [ -3.08227539e-03,  -3.05175781e-03],
                        [  6.50024414e-03,   6.43920898e-03],
                        [  2.74353027e-02,   2.73742676e-02],
                        [  7.02514648e-02,   7.02819824e-02],
                        [  1.36535645e-01,   1.36566162e-01],
                        [  2.11181641e-01,   2.11181641e-01],
                        [  2.72094727e-01,   2.72094727e-01],
                        [  3.04626465e-01,   3.04595947e-01],
                        [  3.02520752e-01,   3.02490234e-01],
                        [  2.60009766e-01,   2.60040283e-01],
                        [  1.73980713e-01,   1.74072266e-01],
                        [  5.57556152e-02,   5.57250977e-02],
                        [ -6.39648438e-02,  -6.40563965e-02],
                        [ -1.45812988e-01,  -1.45812988e-01],
                        [ -1.65344238e-01,  -1.65252686e-01],
                        [ -1.32446289e-01,  -1.32415771e-01],
                        [ -8.40759277e-02,  -8.41979980e-02],
                        [ -5.27038574e-02,  -5.27648926e-02],
                        [ -4.26635742e-02,  -4.26025391e-02],
                        [ -3.85131836e-02,  -3.84521484e-02],
                        [ -3.05786133e-02,  -3.06091309e-02],
                        [ -2.44140625e-02,  -2.44445801e-02],
                        [ -2.71606445e-02,  -2.71911621e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -2.80761719e-02,  -2.80151367e-02],
                        [ -4.36401367e-03,  -4.33349609e-03],
                        [  2.67944336e-02,   2.67639160e-02],
                        [  4.83703613e-02,   4.83093262e-02],
                        [  5.57556152e-02,   5.57861328e-02],
                        [  5.56945801e-02,   5.57250977e-02],
                        [  5.17578125e-02,   5.17272949e-02],
                        [  4.14733887e-02,   4.14428711e-02],
                        [  2.51770020e-02,   2.52075195e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -6.04248047e-03,  -6.01196289e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -5.06591797e-03,  -5.09643555e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -1.28173828e-03,  -1.25122070e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.72729492e-02,  -1.73339844e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -3.22875977e-02,  -3.22265625e-02],
                        [ -3.58581543e-02,  -3.58886719e-02],
                        [ -3.95812988e-02,  -3.96423340e-02],
                        [ -3.88488770e-02,  -3.88183594e-02],
                        [ -2.46582031e-02,  -2.45971680e-02],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  5.62744141e-02,   5.61828613e-02],
                        [  1.02081299e-01,   1.02111816e-01],
                        [  1.27319336e-01,   1.27380371e-01],
                        [  1.24359131e-01,   1.24359131e-01],
                        [  1.00982666e-01,   1.00921631e-01],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  5.05371094e-02,   5.05676270e-02],
                        [  3.85742188e-02,   3.85437012e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  2.78320312e-02,   2.78625488e-02],
                        [  2.24609375e-02,   2.24304199e-02],
                        [  1.04064941e-02,   1.03759766e-02],
                        [ -8.23974609e-03,  -8.20922852e-03],
                        [ -2.78015137e-02,  -2.77404785e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -4.08325195e-02,  -4.08630371e-02],
                        [ -2.58483887e-02,  -2.58789062e-02],
                        [ -3.11279297e-03,  -3.08227539e-03],
                        [  1.41601562e-02,   1.42517090e-02],
                        [  1.91650391e-02,   1.91345215e-02],
                        [  1.70898438e-02,   1.69677734e-02],
                        [  1.84631348e-02,   1.84326172e-02],
                        [  2.85034180e-02,   2.86254883e-02],
                        [  4.28161621e-02,   4.29077148e-02],
                        [  5.31616211e-02,   5.30395508e-02],
                        [  5.85021973e-02,   5.84106445e-02],
                        [  6.80236816e-02,   6.81152344e-02],
                        [  8.74328613e-02,   8.75549316e-02],
                        [  1.06750488e-01,   1.06719971e-01],
                        [  1.08856201e-01,   1.08734131e-01],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  4.91333008e-02,   4.91943359e-02],
                        [  2.44140625e-04,   2.74658203e-04],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -1.42608643e-01,  -1.42608643e-01],
                        [ -2.29980469e-01,  -2.30041504e-01],
                        [ -2.91717529e-01,  -2.91717529e-01],
                        [ -2.96691895e-01,  -2.96630859e-01],
                        [ -2.46063232e-01,  -2.46032715e-01],
                        [ -1.75933838e-01,  -1.75964355e-01],
                        [ -1.26831055e-01,  -1.26861572e-01],
                        [ -1.13525391e-01,  -1.13525391e-01],
                        [ -1.21398926e-01,  -1.21368408e-01],
                        [ -1.25579834e-01,  -1.25488281e-01],
                        [ -1.12945557e-01,  -1.12915039e-01],
                        [ -9.05761719e-02,  -9.06982422e-02],
                        [ -7.30285645e-02,  -7.31201172e-02],
                        [ -6.31408691e-02,  -6.30187988e-02],
                        [ -4.98657227e-02,  -4.97131348e-02],
                        [ -2.52685547e-02,  -2.53906250e-02],
                        [  3.26538086e-03,   3.08227539e-03],
                        [  2.21862793e-02,   2.22473145e-02],
                        [  2.72216797e-02,   2.74047852e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.25732422e-02,   1.24206543e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -1.28173828e-02,  -1.26953125e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -1.69677734e-02,  -1.70593262e-02],
                        [ -2.02331543e-02,  -2.02026367e-02],
                        [ -2.77099609e-02,  -2.76794434e-02],
                        [ -3.40881348e-02,  -3.41186523e-02],
                        [ -3.50646973e-02,  -3.51257324e-02],
                        [ -3.08837891e-02,  -3.08227539e-02],
                        [ -2.14538574e-02,  -2.13928223e-02],
                        [ -5.27954102e-03,  -5.37109375e-03],
                        [  1.76696777e-02,   1.76086426e-02],
                        [  4.94384766e-02,   4.95300293e-02],
                        [  9.63439941e-02,   9.64050293e-02],
                        [  1.60614014e-01,   1.60522461e-01],
                        [  2.31231689e-01,   2.31170654e-01],
                        [  2.88391113e-01,   2.88452148e-01],
                        [  3.16802979e-01,   3.16833496e-01],
                        [  3.12042236e-01,   3.11981201e-01],
                        [  2.75329590e-01,   2.75299072e-01],
                        [  2.07275391e-01,   2.07305908e-01],
                        [  1.10473633e-01,   1.10504150e-01],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -1.06231689e-01,  -1.06262207e-01],
                        [ -1.73065186e-01,  -1.73095703e-01],
                        [ -1.84295654e-01,  -1.84265137e-01],
                        [ -1.43402100e-01,  -1.43310547e-01],
                        [ -7.99865723e-02,  -7.99865723e-02],
                        [ -3.28674316e-02,  -3.29895020e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.88696289e-02,  -2.87475586e-02],
                        [ -3.96423340e-02,  -3.95812988e-02],
                        [ -4.54711914e-02,  -4.56237793e-02],
                        [ -4.98657227e-02,  -4.99572754e-02],
                        [ -5.23376465e-02,  -5.22460938e-02],
                        [ -4.60205078e-02,  -4.59289551e-02],
                        [ -2.60009766e-02,  -2.60620117e-02],
                        [  5.79833984e-03,   5.67626953e-03],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  6.65588379e-02,   6.66198730e-02],
                        [  7.22351074e-02,   7.22656250e-02],
                        [  5.96618652e-02,   5.96313477e-02],
                        [  3.99780273e-02,   3.99169922e-02],
                        [  2.19726562e-02,   2.19421387e-02],
                        [  7.50732422e-03,   7.53784180e-03],
                        [ -2.59399414e-03,  -2.53295898e-03],
                        [ -6.10351562e-03,  -6.07299805e-03],
                        [ -5.43212891e-03,  -5.49316406e-03],
                        [ -7.84301758e-03,  -7.93457031e-03],
                        [ -1.43737793e-02,  -1.43127441e-02],
                        [ -1.80358887e-02,  -1.79138184e-02],
                        [ -1.73339844e-02,  -1.73645020e-02],
                        [ -2.10876465e-02,  -2.12097168e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -5.40771484e-02,  -5.39550781e-02],
                        [ -6.52770996e-02,  -6.52465820e-02],
                        [ -5.99670410e-02,  -6.00585938e-02],
                        [ -3.52478027e-02,  -3.53088379e-02],
                        [  5.76782227e-03,   5.79833984e-03],
                        [  5.32226562e-02,   5.32531738e-02],
                        [  9.44213867e-02,   9.44519043e-02],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  1.25579834e-01,   1.25518799e-01],
                        [  1.10321045e-01,   1.10321045e-01],
                        [  8.18481445e-02,   8.19091797e-02],
                        [  5.39855957e-02,   5.40466309e-02],
                        [  3.57666016e-02,   3.57360840e-02],
                        [  2.50549316e-02,   2.49938965e-02],
                        [  1.67236328e-02,   1.67541504e-02],
                        [  1.09558105e-02,   1.09863281e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  7.93457031e-03,   7.90405273e-03],
                        [  4.48608398e-03,   4.42504883e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -1.15966797e-02,  -1.15356445e-02],
                        [ -2.05078125e-02,  -2.04772949e-02],
                        [ -2.62451172e-02,  -2.63366699e-02],
                        [ -2.88391113e-02,  -2.89001465e-02],
                        [ -2.83203125e-02,  -2.82592773e-02],
                        [ -2.16979980e-02,  -2.16064453e-02],
                        [ -7.99560547e-03,  -8.08715820e-03],
                        [  8.78906250e-03,   8.69750977e-03],
                        [  2.57263184e-02,   2.57873535e-02],
                        [  4.25415039e-02,   4.26330566e-02],
                        [  5.72814941e-02,   5.72509766e-02],
                        [  6.90002441e-02,   6.89086914e-02],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  9.67102051e-02,   9.67712402e-02],
                        [  1.10961914e-01,   1.10992432e-01],
                        [  1.18377686e-01,   1.18408203e-01],
                        [  1.11145020e-01,   1.11083984e-01],
                        [  7.84606934e-02,   7.83386230e-02],
                        [  1.55334473e-02,   1.55639648e-02],
                        [ -6.97326660e-02,  -6.95495605e-02],
                        [ -1.62078857e-01,  -1.62048340e-01],
                        [ -2.44506836e-01,  -2.44750977e-01],
                        [ -2.97637939e-01,  -2.97760010e-01],
                        [ -3.04046631e-01,  -3.03833008e-01],
                        [ -2.64099121e-01,  -2.63885498e-01],
                        [ -2.05017090e-01,  -2.05169678e-01],
                        [ -1.60919189e-01,  -1.61193848e-01],
                        [ -1.41784668e-01,  -1.41723633e-01],
                        [ -1.31164551e-01,  -1.30828857e-01],
                        [ -1.12304688e-01,  -1.12274170e-01],
                        [ -8.64868164e-02,  -8.67614746e-02],
                        [ -6.57348633e-02,  -6.58874512e-02],
                        [ -5.58471680e-02,  -5.56335449e-02],
                        [ -5.10253906e-02,  -5.08422852e-02],
                        [ -4.34875488e-02,  -4.35791016e-02],
                        [ -3.06396484e-02,  -3.07922363e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [  1.49536133e-03,   1.55639648e-03],
                        [  9.61303711e-03,   9.67407227e-03],
                        [  9.70458984e-03,   9.73510742e-03],
                        [  6.16455078e-03,   6.10351562e-03],
                        [  8.54492188e-04,   7.32421875e-04],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -2.07214355e-02,  -2.05383301e-02],
                        [ -3.18298340e-02,  -3.17687988e-02],
                        [ -3.94897461e-02,  -3.96423340e-02],
                        [ -4.52270508e-02,  -4.53491211e-02],
                        [ -4.80651855e-02,  -4.79431152e-02],
                        [ -4.40063477e-02,  -4.38232422e-02],
                        [ -3.35693359e-02,  -3.36303711e-02],
                        [ -2.13317871e-02,  -2.14843750e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  2.25830078e-02,   2.27050781e-02],
                        [  6.86950684e-02,   6.87255859e-02],
                        [  1.28265381e-01,   1.28204346e-01],
                        [  1.90307617e-01,   1.90246582e-01],
                        [  2.41485596e-01,   2.41516113e-01],
                        [  2.70141602e-01,   2.70141602e-01],
                        [  2.72644043e-01,   2.72674561e-01],
                        [  2.57324219e-01,   2.57385254e-01],
                        [  2.37091064e-01,   2.37060547e-01],
                        [  2.14721680e-01,   2.14630127e-01],
                        [  1.77734375e-01,   1.77734375e-01],
                        [  1.12121582e-01,   1.12213135e-01],
                        [  2.10266113e-02,   2.10266113e-02],
                        [ -7.25097656e-02,  -7.26013184e-02],
                        [ -1.38458252e-01,  -1.38458252e-01],
                        [ -1.58630371e-01,  -1.58569336e-01],
                        [ -1.41265869e-01,  -1.41296387e-01],
                        [ -1.13647461e-01,  -1.13708496e-01],
                        [ -9.54589844e-02,  -9.53979492e-02],
                        [ -8.60900879e-02,  -8.60290527e-02],
                        [ -7.79113770e-02,  -7.80029297e-02],
                        [ -6.88171387e-02,  -6.88781738e-02],
                        [ -5.82885742e-02,  -5.81359863e-02],
                        [ -4.30297852e-02,  -4.29382324e-02],
                        [ -2.35900879e-02,  -2.37426758e-02],
                        [ -6.71386719e-03,  -6.86645508e-03],
                        [  4.42504883e-03,   4.60815430e-03],
                        [  1.46484375e-02,   1.48315430e-02],
                        [  2.59399414e-02,   2.57568359e-02],
                        [  3.41796875e-02,   3.39355469e-02],
                        [  3.86047363e-02,   3.87573242e-02],
                        [  4.22973633e-02,   4.25415039e-02],
                        [  4.18701172e-02,   4.17480469e-02],
                        [  2.97546387e-02,   2.94799805e-02],
                        [  8.45336914e-03,   8.54492188e-03],
                        [ -8.36181641e-03,  -8.08715820e-03],
                        [ -1.31530762e-02,  -1.31835938e-02],
                        [ -1.22070312e-02,  -1.25122070e-02],
                        [ -1.15661621e-02,  -1.15356445e-02],
                        [ -9.46044922e-03,  -9.15527344e-03],
                        [ -8.72802734e-03,  -8.69750977e-03],
                        [ -1.90734863e-02,  -1.93481445e-02],
                        [ -3.94897461e-02,  -3.95507812e-02],
                        [ -5.37719727e-02,  -5.34973145e-02],
                        [ -5.13000488e-02,  -5.12390137e-02],
                        [ -4.00695801e-02,  -4.03137207e-02],
                        [ -3.02124023e-02,  -3.03039551e-02],
                        [ -1.58996582e-02,  -1.56555176e-02],
                        [  1.46179199e-02,   1.46789551e-02],
                        [  5.70983887e-02,   5.68847656e-02],
                        [  9.34448242e-02,   9.33837891e-02],
                        [  1.11511230e-01,   1.11724854e-01],
                        [  1.11816406e-01,   1.11846924e-01],
                        [  9.88464355e-02,   9.86328125e-02],
                        [  7.88574219e-02,   7.88269043e-02],
                        [  6.11267090e-02,   6.13403320e-02],
                        [  4.92553711e-02,   4.92858887e-02],
                        [  3.65600586e-02,   3.63159180e-02],
                        [  1.87683105e-02,   1.87377930e-02],
                        [  2.92968750e-03,   3.17382812e-03],
                        [ -3.47900391e-03,  -3.41796875e-03],
                        [ -3.54003906e-03,  -3.72314453e-03],
                        [ -4.57763672e-03,  -4.63867188e-03],
                        [ -8.63647461e-03,  -8.48388672e-03],
                        [ -1.47399902e-02,  -1.46484375e-02],
                        [ -2.32238770e-02,  -2.33459473e-02],
                        [ -3.05175781e-02,  -3.05786133e-02],
                        [ -2.71911621e-02,  -2.70996094e-02],
                        [ -9.61303711e-03,  -9.58251953e-03],
                        [  1.19018555e-02,   1.18103027e-02],
                        [  2.32849121e-02,   2.32238770e-02],
                        [  2.31323242e-02,   2.32238770e-02],
                        [  2.56347656e-02,   2.56958008e-02],
                        [  4.42504883e-02,   4.41589355e-02],
                        [  7.57751465e-02,   7.56530762e-02],
                        [  1.06262207e-01,   1.06384277e-01],
                        [  1.27685547e-01,   1.27868652e-01],
                        [  1.40258789e-01,   1.40197754e-01],
                        [  1.43188477e-01,   1.43005371e-01],
                        [  1.29455566e-01,   1.29516602e-01],
                        [  8.85925293e-02,   8.87756348e-02],
                        [  1.39160156e-02,   1.39465332e-02],
                        [ -8.81042480e-02,  -8.82568359e-02],
                        [ -1.93695068e-01,  -1.93756104e-01],
                        [ -2.70629883e-01,  -2.70507812e-01],
                        [ -2.97393799e-01,  -2.97332764e-01],
                        [ -2.76092529e-01,  -2.76153564e-01],
                        [ -2.27752686e-01,  -2.27813721e-01],
                        [ -1.78314209e-01,  -1.78314209e-01],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -1.24725342e-01,  -1.24664307e-01],
                        [ -1.09039307e-01,  -1.08947754e-01],
                        [ -9.09729004e-02,  -9.10034180e-02],
                        [ -7.65380859e-02,  -7.66601562e-02],
                        [ -7.35168457e-02,  -7.35168457e-02],
                        [ -7.62939453e-02,  -7.61413574e-02],
                        [ -6.93969727e-02,  -6.93359375e-02],
                        [ -4.71191406e-02,  -4.72717285e-02],
                        [ -2.02941895e-02,  -2.03552246e-02],
                        [ -2.80761719e-03,  -2.68554688e-03],
                        [  1.09863281e-03,   1.15966797e-03],
                        [ -2.04467773e-03,  -2.13623047e-03],
                        [ -2.10571289e-03,  -2.16674805e-03],
                        [  3.57055664e-03,   3.60107422e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  1.15966797e-03,   1.12915039e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -2.06298828e-02,  -2.05993652e-02],
                        [ -2.81066895e-02,  -2.81372070e-02],
                        [ -3.69567871e-02,  -3.70178223e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -4.82788086e-02,  -4.82177734e-02],
                        [ -3.90930176e-02,  -3.90625000e-02],
                        [ -1.86767578e-02,  -1.87377930e-02],
                        [  1.31225586e-02,   1.30920410e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  1.24755859e-01,   1.24786377e-01],
                        [  1.92199707e-01,   1.92230225e-01],
                        [  2.41424561e-01,   2.41394043e-01],
                        [  2.57843018e-01,   2.57781982e-01],
                        [  2.46032715e-01,   2.46002197e-01],
                        [  2.26776123e-01,   2.26837158e-01],
                        [  2.18475342e-01,   2.18566895e-01],
                        [  2.20458984e-01,   2.20458984e-01],
                        [  2.16613770e-01,   2.16522217e-01],
                        [  1.90826416e-01,   1.90765381e-01],
                        [  1.36962891e-01,   1.37084961e-01],
                        [  6.00585938e-02,   6.01806641e-02],
                        [ -2.67639160e-02,  -2.68249512e-02],
                        [ -1.05224609e-01,  -1.05407715e-01],
                        [ -1.54968262e-01,  -1.54998779e-01],
                        [ -1.62994385e-01,  -1.62811279e-01],
                        [ -1.36688232e-01,  -1.36596680e-01],
                        [ -1.03485107e-01,  -1.03637695e-01],
                        [ -8.77685547e-02,  -8.79211426e-02],
                        [ -8.76464844e-02,  -8.75549316e-02],
                        [ -8.23974609e-02,  -8.22448730e-02],
                        [ -6.13708496e-02,  -6.13403320e-02],
                        [ -3.34777832e-02,  -3.35998535e-02],
                        [ -1.23291016e-02,  -1.23901367e-02],
                        [ -2.77709961e-03,  -2.71606445e-03],
                        [ -4.88281250e-04,  -3.66210938e-04],
                        [  2.19726562e-03,   2.22778320e-03],
                        [  8.69750977e-03,   8.57543945e-03],
                        [  1.65710449e-02,   1.64794922e-02],
                        [  2.33459473e-02,   2.34375000e-02],
                        [  2.95410156e-02,   2.96325684e-02],
                        [  3.58276367e-02,   3.57360840e-02],
                        [  4.14123535e-02,   4.13513184e-02],
                        [  4.38232422e-02,   4.38842773e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  1.68151855e-02,   1.67846680e-02],
                        [ -1.22375488e-02,  -1.21765137e-02],
                        [ -3.72619629e-02,  -3.72314453e-02],
                        [ -5.05065918e-02,  -5.06286621e-02],
                        [ -5.31921387e-02,  -5.32836914e-02],
                        [ -4.98657227e-02,  -4.97436523e-02],
                        [ -4.43115234e-02,  -4.41589355e-02],
                        [ -3.82080078e-02,  -3.83300781e-02],
                        [ -3.11889648e-02,  -3.13415527e-02],
                        [ -2.19726562e-02,  -2.19116211e-02],
                        [ -8.66699219e-03,  -8.48388672e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  3.70483398e-02,   3.68652344e-02],
                        [  6.72302246e-02,   6.71997070e-02],
                        [  9.59167480e-02,   9.60693359e-02],
                        [  1.13006592e-01,   1.13067627e-01],
                        [  1.09436035e-01,   1.09313965e-01],
                        [  8.81042480e-02,   8.79821777e-02],
                        [  6.36291504e-02,   6.36901855e-02],
                        [  4.87670898e-02,   4.88891602e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  3.65905762e-02,   3.64685059e-02],
                        [  2.27966309e-02,   2.27355957e-02],
                        [  6.25610352e-03,   6.34765625e-03],
                        [ -3.47900391e-03,  -3.38745117e-03],
                        [ -5.18798828e-03,  -5.24902344e-03],
                        [ -7.50732422e-03,  -7.59887695e-03],
                        [ -1.57165527e-02,  -1.56555176e-02],
                        [ -2.49023438e-02,  -2.48107910e-02],
                        [ -2.75573730e-02,  -2.76184082e-02],
                        [ -2.09655762e-02,  -2.10266113e-02],
                        [ -6.62231445e-03,  -6.56127930e-03],
                        [  1.07116699e-02,   1.07421875e-02],
                        [  2.39868164e-02,   2.38952637e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  2.85339355e-02,   2.86865234e-02],
                        [  3.17993164e-02,   3.17687988e-02],
                        [  4.26330566e-02,   4.23889160e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  9.30786133e-02,   9.33532715e-02],
                        [  1.35131836e-01,   1.35192871e-01],
                        [  1.67510986e-01,   1.67205811e-01],
                        [  1.65191650e-01,   1.65100098e-01],
                        [  1.23870850e-01,   1.24114990e-01],
                        [  5.66406250e-02,   5.67932129e-02],
                        [ -2.64282227e-02,  -2.65808105e-02],
                        [ -1.20635986e-01,  -1.20788574e-01],
                        [ -2.13562012e-01,  -2.13500977e-01],
                        [ -2.82012939e-01,  -2.81921387e-01],
                        [ -3.04229736e-01,  -3.04229736e-01],
                        [ -2.75238037e-01,  -2.75268555e-01],
                        [ -2.15087891e-01,  -2.15148926e-01],
                        [ -1.59057617e-01,  -1.59118652e-01],
                        [ -1.30065918e-01,  -1.30004883e-01],
                        [ -1.22772217e-01,  -1.22650146e-01],
                        [ -1.18164062e-01,  -1.18164062e-01],
                        [ -1.05133057e-01,  -1.05255127e-01],
                        [ -8.55102539e-02,  -8.55712891e-02],
                        [ -6.76269531e-02,  -6.75659180e-02],
                        [ -5.72814941e-02,  -5.71899414e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -4.32128906e-02,  -4.33044434e-02],
                        [ -3.01208496e-02,  -3.02429199e-02],
                        [ -1.59301758e-02,  -1.58691406e-02],
                        [ -2.86865234e-03,  -2.68554688e-03],
                        [  7.26318359e-03,   7.32421875e-03],
                        [  8.23974609e-03,   8.02612305e-03],
                        [ -5.37109375e-03,  -5.52368164e-03],
                        [ -2.71301270e-02,  -2.69470215e-02],
                        [ -4.19616699e-02,  -4.17175293e-02],
                        [ -4.27856445e-02,  -4.28771973e-02],
                        [ -3.76281738e-02,  -3.79028320e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -3.78417969e-02,  -3.75671387e-02],
                        [ -3.21044922e-02,  -3.20129395e-02],
                        [ -1.71508789e-02,  -1.73339844e-02],
                        [  3.75366211e-03,   3.63159180e-03],
                        [  2.99682617e-02,   3.00598145e-02],
                        [  6.29882812e-02,   6.30798340e-02],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  1.47247314e-01,   1.47186279e-01],
                        [  1.90124512e-01,   1.90124512e-01],
                        [  2.18933105e-01,   2.18933105e-01],
                        [  2.24182129e-01,   2.24182129e-01],
                        [  2.11578369e-01,   2.11608887e-01],
                        [  2.00012207e-01,   2.00042725e-01],
                        [  2.03613281e-01,   2.03552246e-01],
                        [  2.17407227e-01,   2.17376709e-01],
                        [  2.22351074e-01,   2.22412109e-01],
                        [  2.01416016e-01,   2.01446533e-01],
                        [  1.49627686e-01,   1.49597168e-01],
                        [  7.24792480e-02,   7.24487305e-02],
                        [ -1.84936523e-02,  -1.85241699e-02],
                        [ -1.06048584e-01,  -1.06048584e-01],
                        [ -1.69342041e-01,  -1.69342041e-01],
                        [ -1.93267822e-01,  -1.93237305e-01],
                        [ -1.77856445e-01,  -1.77795410e-01],
                        [ -1.40258789e-01,  -1.40319824e-01],
                        [ -1.05621338e-01,  -1.05682373e-01],
                        [ -8.64868164e-02,  -8.64562988e-02],
                        [ -7.39746094e-02,  -7.38525391e-02],
                        [ -5.43518066e-02,  -5.43823242e-02],
                        [ -2.76794434e-02,  -2.78320312e-02],
                        [ -3.93676758e-03,  -3.96728516e-03],
                        [  1.07421875e-02,   1.08947754e-02],
                        [  1.77612305e-02,   1.78222656e-02],
                        [  1.96838379e-02,   1.95312500e-02],
                        [  1.73950195e-02,   1.73034668e-02],
                        [  1.37023926e-02,   1.37939453e-02],
                        [  1.24511719e-02,   1.25427246e-02],
                        [  1.28173828e-02,   1.27563477e-02],
                        [  1.09558105e-02,   1.08947754e-02],
                        [  6.74438477e-03,   6.80541992e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -8.14819336e-03,  -8.20922852e-03],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -3.38134766e-02,  -3.37524414e-02],
                        [ -3.29895020e-02,  -3.30200195e-02],
                        [ -2.47802734e-02,  -2.48413086e-02],
                        [ -2.16064453e-02,  -2.15759277e-02],
                        [ -2.81982422e-02,  -2.81677246e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -4.23583984e-02,  -4.23889160e-02],
                        [ -4.06188965e-02,  -4.05883789e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -2.56958008e-02,  -2.57568359e-02],
                        [ -5.03540039e-03,  -5.00488281e-03],
                        [  3.07312012e-02,   3.07922363e-02],
                        [  7.51953125e-02,   7.51647949e-02],
                        [  1.11114502e-01,   1.11053467e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  1.10809326e-01,   1.10870361e-01],
                        [  8.93859863e-02,   8.94165039e-02],
                        [  7.14721680e-02,   7.14111328e-02],
                        [  5.76477051e-02,   5.75866699e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  1.76086426e-02,   1.77001953e-02],
                        [ -4.27246094e-03,  -4.24194336e-03],
                        [ -1.63269043e-02,  -1.63879395e-02],
                        [ -1.62353516e-02,  -1.63269043e-02],
                        [ -7.90405273e-03,  -7.87353516e-03],
                        [  1.52587891e-03,   1.67846680e-03],
                        [  4.60815430e-03,   4.63867188e-03],
                        [ -2.28881836e-03,  -2.47192383e-03],
                        [ -1.41906738e-02,  -1.42517090e-02],
                        [ -1.91345215e-02,  -1.89514160e-02],
                        [ -1.00708008e-02,  -9.91821289e-03],
                        [  5.67626953e-03,   5.52368164e-03],
                        [  1.65710449e-02,   1.64184570e-02],
                        [  2.41394043e-02,   2.42614746e-02],
                        [  3.83300781e-02,   3.85131836e-02],
                        [  5.95703125e-02,   5.95092773e-02],
                        [  7.89184570e-02,   7.87353516e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.10504150e-01,   1.10656738e-01],
                        [  1.31195068e-01,   1.31286621e-01],
                        [  1.45141602e-01,   1.45050049e-01],
                        [  1.34613037e-01,   1.34429932e-01],
                        [  8.88366699e-02,   8.88061523e-02],
                        [  1.41601562e-02,   1.43737793e-02],
                        [ -7.28759766e-02,  -7.27844238e-02],
                        [ -1.61712646e-01,  -1.61956787e-01],
                        [ -2.44628906e-01,  -2.44842529e-01],
                        [ -3.00872803e-01,  -3.00659180e-01],
                        [ -3.04748535e-01,  -3.04382324e-01],
                        [ -2.58209229e-01,  -2.58331299e-01],
                        [ -1.98394775e-01,  -1.98760986e-01],
                        [ -1.60156250e-01,  -1.60125732e-01],
                        [ -1.42822266e-01,  -1.42425537e-01],
                        [ -1.25793457e-01,  -1.25701904e-01],
                        [ -1.01806641e-01,  -1.02142334e-01],
                        [ -7.87353516e-02,  -7.89184570e-02],
                        [ -6.13098145e-02,  -6.11267090e-02],
                        [ -4.88586426e-02,  -4.87365723e-02],
                        [ -4.21447754e-02,  -4.23278809e-02],
                        [ -4.01000977e-02,  -4.03137207e-02],
                        [ -3.51257324e-02,  -3.50952148e-02],
                        [ -2.17590332e-02,  -2.16064453e-02],
                        [ -6.89697266e-03,  -6.83593750e-03],
                        [ -2.99072266e-03,  -2.96020508e-03],
                        [ -1.18713379e-02,  -1.18103027e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.86865234e-02,  -2.87170410e-02],
                        [ -2.67944336e-02,  -2.67333984e-02],
                        [ -2.13317871e-02,  -2.12097168e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.52380371e-02,  -2.53601074e-02],
                        [ -4.20227051e-02,  -4.20837402e-02],
                        [ -5.61828613e-02,  -5.61523438e-02],
                        [ -5.19104004e-02,  -5.19409180e-02],
                        [ -2.52075195e-02,  -2.53601074e-02],
                        [  1.56555176e-02,   1.54113770e-02],
                        [  6.15234375e-02,   6.13708496e-02],
                        [  1.09893799e-01,   1.09924316e-01],
                        [  1.60186768e-01,   1.60400391e-01],
                        [  2.03918457e-01,   2.04040527e-01],
                        [  2.24609375e-01,   2.24578857e-01],
                        [  2.14813232e-01,   2.14935303e-01],
                        [  1.89086914e-01,   1.89453125e-01],
                        [  1.71142578e-01,   1.71447754e-01],
                        [  1.70745850e-01,   1.70745850e-01],
                        [  1.79473877e-01,   1.79412842e-01],
                        [  1.86035156e-01,   1.86187744e-01],
                        [  1.85546875e-01,   1.85791016e-01],
                        [  1.74163818e-01,   1.74163818e-01],
                        [  1.43432617e-01,   1.43127441e-01],
                        [  8.40148926e-02,   8.35876465e-02],
                        [ -3.66210938e-03,  -3.90625000e-03],
                        [ -1.00555420e-01,  -1.00646973e-01],
                        [ -1.75994873e-01,  -1.76116943e-01],
                        [ -2.07824707e-01,  -2.08007812e-01],
                        [ -1.94793701e-01,  -1.94885254e-01],
                        [ -1.52923584e-01,  -1.52893066e-01],
                        [ -1.04858398e-01,  -1.04797363e-01],
                        [ -6.74133301e-02,  -6.73828125e-02],
                        [ -4.37927246e-02,  -4.36706543e-02],
                        [ -2.72216797e-02,  -2.69470215e-02],
                        [ -1.31530762e-02,  -1.27868652e-02],
                        [ -5.18798828e-03,  -4.88281250e-03],
                        [ -8.20922852e-03,  -7.96508789e-03],
                        [ -1.81579590e-02,  -1.79748535e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.93786621e-02,  -1.96228027e-02],
                        [ -6.71386719e-03,  -7.04956055e-03],
                        [  8.57543945e-03,   8.27026367e-03],
                        [  2.15759277e-02,   2.11486816e-02],
                        [  2.46276855e-02,   2.40173340e-02],
                        [  1.19628906e-02,   1.14746094e-02],
                        [ -9.00268555e-03,  -9.06372070e-03],
                        [ -2.23999023e-02,  -2.23083496e-02],
                        [ -2.41699219e-02,  -2.42614746e-02],
                        [ -2.45361328e-02,  -2.45666504e-02],
                        [ -2.93579102e-02,  -2.90527344e-02],
                        [ -3.27148438e-02,  -3.21044922e-02],
                        [ -2.84423828e-02,  -2.78625488e-02],
                        [ -1.97143555e-02,  -1.92260742e-02],
                        [ -1.44653320e-02,  -1.38854980e-02],
                        [ -1.63269043e-02,  -1.57470703e-02],
                        [ -2.39562988e-02,  -2.36816406e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.71093750e-02,  -3.71398926e-02],
                        [ -2.08129883e-02,  -2.08435059e-02],
                        [  2.07824707e-02,   2.05688477e-02],
                        [  7.44628906e-02,   7.40356445e-02],
                        [  1.15631104e-01,   1.15173340e-01],
                        [  1.26922607e-01,   1.26556396e-01],
                        [  1.09558105e-01,   1.09191895e-01],
                        [  8.02612305e-02,   7.98034668e-02],
                        [  5.74645996e-02,   5.70373535e-02],
                        [  4.68444824e-02,   4.65393066e-02],
                        [  3.95202637e-02,   3.93371582e-02],
                        [  2.61230469e-02,   2.59094238e-02],
                        [  8.05664062e-03,   7.75146484e-03],
                        [ -6.07299805e-03,  -6.22558594e-03],
                        [ -1.01928711e-02,  -9.88769531e-03],
                        [ -6.01196289e-03,  -5.46264648e-03],
                        [ -1.86157227e-03,  -1.40380859e-03],
                        [ -3.29589844e-03,  -2.80761719e-03],
                        [ -4.11987305e-03,  -3.38745117e-03],
                        [  6.07299805e-03,   6.68334961e-03],
                        [  2.36511230e-02,   2.36816406e-02],
                        [  3.20739746e-02,   3.17687988e-02],
                        [  2.62145996e-02,   2.61535645e-02],
                        [  2.05383301e-02,   2.05688477e-02],
                        [  2.60314941e-02,   2.57568359e-02],
                        [  3.78723145e-02,   3.75061035e-02],
                        [  5.20019531e-02,   5.19714355e-02],
                        [  7.36389160e-02,   7.36694336e-02],
                        [  1.04064941e-01,   1.03820801e-01],
                        [  1.34338379e-01,   1.34124756e-01],
                        [  1.53137207e-01,   1.53137207e-01],
                        [  1.48834229e-01,   1.48773193e-01],
                        [  1.08673096e-01,   1.08459473e-01],
                        [  2.91137695e-02,   2.92053223e-02],
                        [ -7.46154785e-02,  -7.41882324e-02],
                        [ -1.79016113e-01,  -1.78863525e-01],
                        [ -2.64404297e-01,  -2.64495850e-01],
                        [ -3.09936523e-01,  -3.09753418e-01],
                        [ -2.98980713e-01,  -2.98645020e-01],
                        [ -2.44415283e-01,  -2.44445801e-01],
                        [ -1.87225342e-01,  -1.87469482e-01],
                        [ -1.55456543e-01,  -1.55151367e-01],
                        [ -1.39282227e-01,  -1.38549805e-01],
                        [ -1.15997314e-01,  -1.15844727e-01],
                        [ -8.50524902e-02,  -8.57849121e-02],
                        [ -6.45141602e-02,  -6.53076172e-02],
                        [ -6.10961914e-02,  -6.13708496e-02],
                        [ -6.21032715e-02,  -6.22253418e-02],
                        [ -5.55114746e-02,  -5.57250977e-02],
                        [ -4.08020020e-02,  -4.08630371e-02],
                        [ -2.16369629e-02,  -2.15454102e-02],
                        [ -3.63159180e-03,  -3.87573242e-03],
                        [  4.51660156e-03,   3.90625000e-03],
                        [  3.05175781e-04,  -6.10351562e-05],
                        [ -9.00268555e-03,  -8.69750977e-03],
                        [ -1.77307129e-02,  -1.69067383e-02],
                        [ -2.74047852e-02,  -2.63671875e-02],
                        [ -3.90014648e-02,  -3.80249023e-02],
                        [ -5.02624512e-02,  -4.95605469e-02],
                        [ -5.85327148e-02,  -5.84106445e-02],
                        [ -6.07299805e-02,  -6.12487793e-02],
                        [ -5.46875000e-02,  -5.56335449e-02],
                        [ -4.06494141e-02,  -4.16870117e-02],
                        [ -1.84020996e-02,  -1.92871094e-02],
                        [  1.31530762e-02,   1.23596191e-02],
                        [  5.13916016e-02,   5.07812500e-02],
                        [  9.28039551e-02,   9.27429199e-02],
                        [  1.36779785e-01,   1.37237549e-01],
                        [  1.77978516e-01,   1.78497314e-01],
                        [  2.01293945e-01,   2.01629639e-01],
                        [  1.96289062e-01,   1.96746826e-01],
                        [  1.73095703e-01,   1.73919678e-01],
                        [  1.53167725e-01,   1.54357910e-01],
                        [  1.47003174e-01,   1.48376465e-01],
                        [  1.49139404e-01,   1.50390625e-01],
                        [  1.49841309e-01,   1.50421143e-01],
                        [  1.45935059e-01,   1.45629883e-01],
                        [  1.43707275e-01,   1.42761230e-01],
                        [  1.48864746e-01,   1.47613525e-01],
                        [  1.52618408e-01,   1.51184082e-01],
                        [  1.35070801e-01,   1.33819580e-01],
                        [  8.35876465e-02,   8.29162598e-02],
                        [  2.19726562e-03,   1.98364258e-03],
                        [ -9.13696289e-02,  -9.15222168e-02],
                        [ -1.69769287e-01,  -1.69952393e-01],
                        [ -2.04437256e-01,  -2.04376221e-01],
                        [ -1.83166504e-01,  -1.82891846e-01],
                        [ -1.26098633e-01,  -1.25823975e-01],
                        [ -7.41882324e-02,  -7.37609863e-02],
                        [ -5.16357422e-02,  -5.07202148e-02],
                        [ -4.78515625e-02,  -4.66308594e-02],
                        [ -4.38842773e-02,  -4.30297852e-02],
                        [ -4.04052734e-02,  -4.00390625e-02],
                        [ -4.70886230e-02,  -4.68139648e-02],
                        [ -5.91430664e-02,  -5.88684082e-02],
                        [ -6.04553223e-02,  -6.05773926e-02],
                        [ -4.37316895e-02,  -4.43420410e-02],
                        [ -1.61437988e-02,  -1.70898438e-02],
                        [  1.01928711e-02,   9.00268555e-03],
                        [  2.69470215e-02,   2.51770020e-02],
                        [  3.14025879e-02,   2.89611816e-02],
                        [  2.50854492e-02,   2.27050781e-02],
                        [  1.17797852e-02,   1.04064941e-02],
                        [ -3.96728516e-03,  -3.87573242e-03],
                        [ -1.77612305e-02,  -1.65405273e-02],
                        [ -2.73437500e-02,  -2.55126953e-02],
                        [ -3.23791504e-02,  -3.00292969e-02],
                        [ -3.14636230e-02,  -2.85034180e-02],
                        [ -2.23388672e-02,  -1.93176270e-02],
                        [ -8.36181641e-03,  -6.01196289e-03],
                        [ -2.74658203e-04,   1.12915039e-03],
                        [ -6.40869141e-03,  -5.67626953e-03],
                        [ -2.31933594e-02,  -2.30102539e-02],
                        [ -3.98254395e-02,  -4.03747559e-02],
                        [ -4.71801758e-02,  -4.84008789e-02],
                        [ -3.74145508e-02,  -3.90930176e-02],
                        [ -4.30297852e-03,  -6.37817383e-03],
                        [  4.69360352e-02,   4.43115234e-02],
                        [  9.42077637e-02,   9.13391113e-02],
                        [  1.13952637e-01,   1.11663818e-01],
                        [  1.02294922e-01,   1.01348877e-01],
                        [  7.49816895e-02,   7.53173828e-02],
                        [  4.83703613e-02,   4.95605469e-02],
                        [  2.89611816e-02,   3.04565430e-02],
                        [  1.82189941e-02,   1.95922852e-02],
                        [  1.73034668e-02,   1.81579590e-02],
                        [  2.40478516e-02,   2.44445801e-02],
                        [  3.13110352e-02,   3.16772461e-02],
                        [  3.37219238e-02,   3.42712402e-02],
                        [  3.23181152e-02,   3.27148438e-02],
                        [  2.79541016e-02,   2.78320312e-02],
                        [  1.78527832e-02,   1.74560547e-02],
                        [  4.36401367e-03,   4.15039062e-03],
                        [ -4.51660156e-03,  -4.57763672e-03],
                        [ -6.10351562e-03,  -6.25610352e-03],
                        [ -2.89916992e-03,  -3.20434570e-03],
                        [  6.34765625e-03,   5.85937500e-03],
                        [  2.39562988e-02,   2.31933594e-02],
                        [  4.57763672e-02,   4.50744629e-02],
                        [  6.67724609e-02,   6.67419434e-02],
                        [  8.84704590e-02,   8.92333984e-02],
                        [  1.12243652e-01,   1.13067627e-01],
                        [  1.30615234e-01,   1.31042480e-01],
                        [  1.36230469e-01,   1.36413574e-01],
                        [  1.30645752e-01,   1.30859375e-01],
                        [  1.12792969e-01,   1.13128662e-01],
                        [  6.86950684e-02,   6.94885254e-02],
                        [ -1.29089355e-02,  -1.13830566e-02],
                        [ -1.20666504e-01,  -1.18988037e-01],
                        [ -2.24822998e-01,  -2.24090576e-01],
                        [ -2.94738770e-01,  -2.95227051e-01],
                        [ -3.10546875e-01,  -3.11614990e-01],
                        [ -2.71759033e-01,  -2.72949219e-01],
                        [ -2.03918457e-01,  -2.05322266e-01],
                        [ -1.45019531e-01,  -1.46606445e-01],
                        [ -1.15356445e-01,  -1.16638184e-01],
                        [ -1.05499268e-01,  -1.06018066e-01],
                        [ -9.61303711e-02,  -9.59167480e-02],
                        [ -8.14514160e-02,  -8.08715820e-02],
                        [ -6.98242188e-02,  -6.91223145e-02],
                        [ -6.74438477e-02,  -6.67724609e-02],
                        [ -6.76879883e-02,  -6.72912598e-02],
                        [ -5.85632324e-02,  -5.87158203e-02],
                        [ -3.79333496e-02,  -3.87268066e-02],
                        [ -1.58996582e-02,  -1.68762207e-02],
                        [ -1.12915039e-03,  -1.77001953e-03],
                        [  7.32421875e-03,   7.08007812e-03],
                        [  1.17797852e-02,   1.16577148e-02],
                        [  8.60595703e-03,   8.66699219e-03],
                        [ -4.88281250e-03,  -4.39453125e-03],
                        [ -2.43530273e-02,  -2.34069824e-02],
                        [ -4.32739258e-02,  -4.20227051e-02],
                        [ -5.88378906e-02,  -5.74951172e-02],
                        [ -7.13195801e-02,  -7.00988770e-02],
                        [ -7.98950195e-02,  -7.89489746e-02],
                        [ -7.83691406e-02,  -7.78198242e-02],
                        [ -5.78613281e-02,  -5.78002930e-02],
                        [ -1.47705078e-02,  -1.54418945e-02],
                        [  4.53491211e-02,   4.38537598e-02],
                        [  1.11358643e-01,   1.09436035e-01],
                        [  1.71264648e-01,   1.69586182e-01],
                        [  2.13470459e-01,   2.12371826e-01],
                        [  2.27752686e-01,   2.27142334e-01],
                        [  2.11853027e-01,   2.11364746e-01],
                        [  1.76544189e-01,   1.76147461e-01],
                        [  1.39892578e-01,   1.39739990e-01],
                        [  1.14746094e-01,   1.15081787e-01],
                        [  1.03240967e-01,   1.04492188e-01],
                        [  1.01928711e-01,   1.04309082e-01],
                        [  1.08398438e-01,   1.11419678e-01],
                        [  1.20300293e-01,   1.22924805e-01],
                        [  1.32446289e-01,   1.33850098e-01],
                        [  1.41601562e-01,   1.41723633e-01],
                        [  1.49108887e-01,   1.48284912e-01],
                        [  1.50177002e-01,   1.48834229e-01],
                        [  1.26708984e-01,   1.25427246e-01],
                        [  6.17065430e-02,   6.10656738e-02],
                        [ -3.83605957e-02,  -3.81774902e-02],
                        [ -1.39099121e-01,  -1.38519287e-01],
                        [ -1.99584961e-01,  -1.99279785e-01],
                        [ -2.00866699e-01,  -2.01446533e-01],
                        [ -1.57531738e-01,  -1.59332275e-01],
                        [ -1.03759766e-01,  -1.07025146e-01],
                        [ -6.86645508e-02,  -7.31201172e-02],
                        [ -5.97229004e-02,  -6.40869141e-02],
                        [ -6.33850098e-02,  -6.57958984e-02],
                        [ -5.98754883e-02,  -5.91735840e-02],
                        [ -4.27246094e-02,  -3.93676758e-02],
                        [ -2.55432129e-02,  -2.11486816e-02],
                        [ -2.39868164e-02,  -2.01110840e-02],
                        [ -3.47290039e-02,  -3.22875977e-02],
                        [ -4.13818359e-02,  -4.04663086e-02],
                        [ -3.49731445e-02,  -3.48510742e-02],
                        [ -1.91040039e-02,  -1.88903809e-02],
                        [ -1.28173828e-03,  -7.32421875e-04],
                        [  1.15051270e-02,   1.19018555e-02],
                        [  1.40686035e-02,   1.39160156e-02],
                        [  6.46972656e-03,   5.76782227e-03],
                        [ -5.67626953e-03,  -6.74438477e-03],
                        [ -1.61132812e-02,  -1.72729492e-02],
                        [ -2.10571289e-02,  -2.20031738e-02],
                        [ -1.96228027e-02,  -2.02331543e-02],
                        [ -1.53198242e-02,  -1.56555176e-02],
                        [ -1.42822266e-02,  -1.42517090e-02],
                        [ -1.96228027e-02,  -1.88293457e-02],
                        [ -2.95715332e-02,  -2.78015137e-02],
                        [ -4.03137207e-02,  -3.81164551e-02],
                        [ -4.82177734e-02,  -4.64477539e-02],
                        [ -4.82788086e-02,  -4.75158691e-02],
                        [ -3.34167480e-02,  -3.38439941e-02],
                        [  0.00000000e+00,  -1.37329102e-03],
                        [  4.49523926e-02,   4.31518555e-02],
                        [  8.55407715e-02,   8.40148926e-02],
                        [  1.07269287e-01,   1.06231689e-01],
                        [  1.05010986e-01,   1.04217529e-01],
                        [  8.52050781e-02,   8.45031738e-02],
                        [  6.12792969e-02,   6.07604980e-02],
                        [  4.33349609e-02,   4.30297852e-02],
                        [  3.19824219e-02,   3.17077637e-02],
                        [  2.38342285e-02,   2.33764648e-02],
                        [  1.86157227e-02,   1.77917480e-02],
                        [  1.69372559e-02,   1.57165527e-02],
                        [  1.66320801e-02,   1.53808594e-02],
                        [  1.72119141e-02,   1.66931152e-02],
                        [  2.17285156e-02,   2.23083496e-02],
                        [  2.78320312e-02,   2.93579102e-02],
                        [  2.63977051e-02,   2.85339355e-02],
                        [  1.43432617e-02,   1.67846680e-02],
                        [  1.19018555e-03,   3.57055664e-03],
                        [ -6.10351562e-04,   9.46044922e-04],
                        [  1.19018555e-02,   1.22375488e-02],
                        [  3.25622559e-02,   3.19519043e-02],
                        [  5.67932129e-02,   5.57556152e-02],
                        [  8.48999023e-02,   8.35266113e-02],
                        [  1.11877441e-01,   1.10076904e-01],
                        [  1.27288818e-01,   1.25335693e-01],
                        [  1.30096436e-01,   1.28326416e-01],
                        [  1.28662109e-01,   1.27349854e-01],
                        [  1.21124268e-01,   1.20941162e-01],
                        [  9.03625488e-02,   9.21936035e-02],
                        [  2.35290527e-02,   2.77099609e-02],
                        [ -7.25708008e-02,  -6.69555664e-02],
                        [ -1.76116943e-01,  -1.70654297e-01],
                        [ -2.60040283e-01,  -2.56134033e-01],
                        [ -2.98736572e-01,  -2.97210693e-01],
                        [ -2.80731201e-01,  -2.81494141e-01],
                        [ -2.22656250e-01,  -2.24792480e-01],
                        [ -1.61956787e-01,  -1.64489746e-01],
                        [ -1.26617432e-01,  -1.29333496e-01],
                        [ -1.14471436e-01,  -1.17828369e-01],
                        [ -1.05438232e-01,  -1.09924316e-01],
                        [ -8.85314941e-02,  -9.39941406e-02],
                        [ -6.87561035e-02,  -7.45239258e-02],
                        [ -5.38635254e-02,  -5.89599609e-02],
                        [ -4.51354980e-02,  -4.87365723e-02],
                        [ -4.02221680e-02,  -4.19311523e-02],
                        [ -3.64990234e-02,  -3.64074707e-02],
                        [ -3.12500000e-02,  -2.96325684e-02],
                        [ -2.42004395e-02,  -2.12707520e-02],
                        [ -1.84020996e-02,  -1.42211914e-02],
                        [ -1.48315430e-02,  -9.61303711e-03],
                        [ -1.14440918e-02,  -5.70678711e-03],
                        [ -1.07116699e-02,  -5.12695312e-03],
                        [ -1.96533203e-02,  -1.44348145e-02],
                        [ -3.81164551e-02,  -3.31115723e-02],
                        [ -5.67932129e-02,  -5.23986816e-02],
                        [ -6.93054199e-02,  -6.66198730e-02],
                        [ -7.62634277e-02,  -7.64465332e-02],
                        [ -7.51342773e-02,  -7.85522461e-02],
                        [ -5.63354492e-02,  -6.23779297e-02],
                        [ -1.48620605e-02,  -2.19726562e-02],
                        [  4.12292480e-02,   3.50952148e-02],
                        [  1.00860596e-01,   9.68627930e-02],
                        [  1.58447266e-01,   1.55944824e-01],
                        [  2.05169678e-01,   2.02636719e-01],
                        [  2.25708008e-01,   2.22534180e-01],
                        [  2.14019775e-01,   2.10998535e-01],
                        [  1.81640625e-01,   1.80236816e-01],
                        [  1.45263672e-01,   1.47003174e-01],
                        [  1.15264893e-01,   1.20849609e-01],
                        [  9.66491699e-02,   1.05285645e-01],
                        [  9.10339355e-02,   1.00372314e-01],
                        [  9.56726074e-02,   1.03149414e-01],
                        [  1.05987549e-01,   1.10229492e-01],
                        [  1.20056152e-01,   1.20941162e-01],
                        [  1.36199951e-01,   1.34185791e-01],
                        [  1.48986816e-01,   1.45080566e-01],
                        [  1.53045654e-01,   1.48437500e-01],
                        [  1.44836426e-01,   1.40655518e-01],
                        [  1.16943359e-01,   1.13677979e-01],
                        [  5.87463379e-02,   5.64575195e-02],
                        [ -2.88696289e-02,  -3.07312012e-02],
                        [ -1.23046875e-01,  -1.25518799e-01],
                        [ -1.89331055e-01,  -1.93145752e-01],
                        [ -2.05871582e-01,  -2.10540771e-01],
                        [ -1.76971436e-01,  -1.81030273e-01],
                        [ -1.25885010e-01,  -1.28082275e-01],
                        [ -7.92846680e-02,  -7.91931152e-02],
                        [ -5.45959473e-02,  -5.24597168e-02],
                        [ -5.22766113e-02,  -4.87670898e-02],
                        [ -5.80749512e-02,  -5.39550781e-02],
                        [ -5.67016602e-02,  -5.24902344e-02],
                        [ -4.53796387e-02,  -4.11987305e-02],
                        [ -3.35998535e-02,  -2.92968750e-02],
                        [ -3.02734375e-02,  -2.57873535e-02],
                        [ -3.27453613e-02,  -2.84423828e-02],
                        [ -3.10363770e-02,  -2.76794434e-02],
                        [ -2.13012695e-02,  -1.95617676e-02],
                        [ -9.36889648e-03,  -9.39941406e-03],
                        [ -1.03759766e-03,  -2.53295898e-03],
                        [  2.71606445e-03,  -3.05175781e-05],
                        [  8.54492188e-04,  -2.71606445e-03],
                        [ -6.10351562e-03,  -9.79614258e-03],
                        [ -1.10778809e-02,  -1.44958496e-02],
                        [ -8.30078125e-03,  -1.19323730e-02],
                        [ -4.30297852e-03,  -8.63647461e-03],
                        [ -1.12304688e-02,  -1.56250000e-02],
                        [ -3.04260254e-02,  -3.33862305e-02],
                        [ -4.97131348e-02,  -4.98962402e-02],
                        [ -5.85937500e-02,  -5.52978516e-02],
                        [ -5.88378906e-02,  -5.23986816e-02],
                        [ -5.52062988e-02,  -4.73327637e-02],
                        [ -4.35791016e-02,  -3.72619629e-02],
                        [ -1.69067383e-02,  -1.46179199e-02],
                        [  2.42004395e-02,   2.21252441e-02],
                        [  7.00988770e-02,   6.53381348e-02],
                        [  1.05224609e-01,   1.00128174e-01],
                        [  1.15386963e-01,   1.11755371e-01],
                        [  1.00646973e-01,   9.89990234e-02],
                        [  7.83996582e-02,   7.80639648e-02],
                        [  6.66198730e-02,   6.64672852e-02],
                        [  6.62231445e-02,   6.54602051e-02],
                        [  6.52770996e-02,   6.38732910e-02],
                        [  5.61523438e-02,   5.44433594e-02],
                        [  4.03137207e-02,   3.88488770e-02],
                        [  2.20336914e-02,   2.16979980e-02],
                        [  5.76782227e-03,   7.38525391e-03],
                        [ -3.72314453e-03,   1.52587891e-04],
                        [ -4.88281250e-03,   3.66210938e-04],
                        [ -1.19018555e-03,   3.69262695e-03],
                        [  2.68554688e-03,   5.37109375e-03],
                        [  4.54711914e-03,   4.05883789e-03],
                        [  4.88281250e-03,   1.83105469e-03],
                        [  6.71386719e-03,   3.41796875e-03],
                        [  1.63879395e-02,   1.53198242e-02],
                        [  4.08935547e-02,   4.28161621e-02],
                        [  7.93457031e-02,   8.26416016e-02],
                        [  1.19415283e-01,   1.21276855e-01],
                        [  1.47735596e-01,   1.46209717e-01],
                        [  1.61346436e-01,   1.56524658e-01],
                        [  1.61682129e-01,   1.55548096e-01],
                        [  1.42089844e-01,   1.37512207e-01],
                        [  9.34143066e-02,   9.26208496e-02],
                        [  1.78833008e-02,   2.13317871e-02],
                        [ -7.36694336e-02,  -6.72302246e-02],
                        [ -1.70898438e-01,  -1.63208008e-01],
                        [ -2.58544922e-01,  -2.50885010e-01],
                        [ -3.09509277e-01,  -3.02795410e-01],
                        [ -2.99804688e-01,  -2.95318604e-01],
                        [ -2.35870361e-01,  -2.34893799e-01],
                        [ -1.58081055e-01,  -1.61010742e-01],
                        [ -1.07421875e-01,  -1.13433838e-01],
                        [ -9.12780762e-02,  -9.91821289e-02],
                        [ -9.00878906e-02,  -9.89990234e-02],
                        [ -8.87145996e-02,  -9.81750488e-02],
                        [ -8.76464844e-02,  -9.74426270e-02],
                        [ -8.88061523e-02,  -9.86022949e-02],
                        [ -8.65173340e-02,  -9.51843262e-02],
                        [ -7.45849609e-02,  -8.00781250e-02],
                        [ -5.45654297e-02,  -5.47180176e-02],
                        [ -3.30200195e-02,  -2.71606445e-02],
                        [ -1.43432617e-02,  -3.72314453e-03],
                        [  1.83105469e-04,   1.31225586e-02],
                        [  7.32421875e-03,   2.05688477e-02],
                        [  2.86865234e-03,   1.54418945e-02],
                        [ -1.12609863e-02,   1.22070312e-04],
                        [ -2.78930664e-02,  -1.84326172e-02],
                        [ -4.48608398e-02,  -3.85742188e-02],
                        [ -6.48498535e-02,  -6.31713867e-02],
                        [ -8.32214355e-02,  -8.70361328e-02],
                        [ -8.80432129e-02,  -9.70764160e-02],
                        [ -7.31506348e-02,  -8.56628418e-02],
                        [ -4.08935547e-02,  -5.43212891e-02],
                        [  5.00488281e-03,  -7.01904297e-03],
                        [  6.06079102e-02,   5.13610840e-02],
                        [  1.17950439e-01,   1.11785889e-01],
                        [  1.66503906e-01,   1.63055420e-01],
                        [  1.96594238e-01,   1.95434570e-01],
                        [  2.02117920e-01,   2.03155518e-01],
                        [  1.85638428e-01,   1.89147949e-01],
                        [  1.59576416e-01,   1.65954590e-01],
                        [  1.35955811e-01,   1.45416260e-01],
                        [  1.17370605e-01,   1.29547119e-01],
                        [  1.01867676e-01,   1.15539551e-01],
                        [  9.04846191e-02,   1.03393555e-01],
                        [  8.57543945e-02,   9.52453613e-02],
                        [  8.93859863e-02,   9.34448242e-02],
                        [  1.00952148e-01,   9.90600586e-02],
                        [  1.14288330e-01,   1.07513428e-01],
                        [  1.20513916e-01,   1.10565186e-01],
                        [  1.19018555e-01,   1.07147217e-01],
                        [  1.17767334e-01,   1.04370117e-01],
                        [  1.17736816e-01,   1.03302002e-01],
                        [  1.05072021e-01,   9.10644531e-02],
                        [  6.46057129e-02,   5.33142090e-02],
                        [ -2.86865234e-03,  -9.12475586e-03],
                        [ -8.12683105e-02,  -8.12377930e-02],
                        [ -1.50634766e-01,  -1.44805908e-01],
                        [ -1.92565918e-01,  -1.82891846e-01],
                        [ -1.94732666e-01,  -1.83624268e-01],
                        [ -1.61560059e-01,  -1.50695801e-01],
                        [ -1.16607666e-01,  -1.06262207e-01],
                        [ -8.34350586e-02,  -7.33642578e-02],
                        [ -6.61621094e-02,  -5.69458008e-02],
                        [ -5.49011230e-02,  -4.80651855e-02],
                        [ -4.32128906e-02,  -4.01611328e-02],
                        [ -3.24707031e-02,  -3.36303711e-02],
                        [ -2.59094238e-02,  -3.07922363e-02],
                        [ -2.56042480e-02,  -3.32641602e-02],
                        [ -3.16162109e-02,  -4.08325195e-02],
                        [ -3.95812988e-02,  -4.87365723e-02],
                        [ -4.10766602e-02,  -4.84313965e-02],
                        [ -3.12500000e-02,  -3.50952148e-02],
                        [ -1.52893066e-02,  -1.44958496e-02],
                        [ -3.11279297e-03,   2.10571289e-03],
                        [  1.95312500e-03,   9.36889648e-03],
                        [  3.35693359e-03,   9.36889648e-03],
                        [  2.44140625e-03,   4.27246094e-03],
                        [ -4.15039062e-03,  -6.59179688e-03],
                        [ -1.87683105e-02,  -2.27966309e-02],
                        [ -3.73840332e-02,  -3.96423340e-02],
                        [ -5.16052246e-02,  -5.02624512e-02],
                        [ -5.74035645e-02,  -5.34057617e-02],
                        [ -5.96313477e-02,  -5.58166504e-02],
                        [ -6.29272461e-02,  -6.21948242e-02],
                        [ -6.28967285e-02,  -6.63452148e-02],
                        [ -4.98657227e-02,  -5.62133789e-02],
                        [ -1.73034668e-02,  -2.39257812e-02],
                        [  3.33862305e-02,   2.86254883e-02],
                        [  8.89892578e-02,   8.68835449e-02],
                        [  1.27410889e-01,   1.27685547e-01],
                        [  1.33697510e-01,   1.35528564e-01],
                        [  1.13250732e-01,   1.15661621e-01],
                        [  8.42285156e-02,   8.61511230e-02],
                        [  5.99365234e-02,   6.08520508e-02],
                        [  4.28466797e-02,   4.29992676e-02],
                        [  3.04565430e-02,   3.09143066e-02],
                        [  2.26135254e-02,   2.48107910e-02],
                        [  2.19421387e-02,   2.68859863e-02],
                        [  2.83508301e-02,   3.53088379e-02],
                        [  3.55834961e-02,   4.19616699e-02],
                        [  3.53393555e-02,   3.79333496e-02],
                        [  2.51159668e-02,   2.19726562e-02],
                        [  1.22680664e-02,   3.87573242e-03],
                        [  7.08007812e-03,  -3.75366211e-03],
                        [  1.08642578e-02,   1.49536133e-03],
                        [  1.75170898e-02,   1.27868652e-02],
                        [  2.64892578e-02,   2.71606445e-02],
                        [  4.40368652e-02,   4.84313965e-02],
                        [  7.12585449e-02,   7.71179199e-02],
                        [  1.01928711e-01,   1.07788086e-01],
                        [  1.30767822e-01,   1.36291504e-01],
                        [  1.53961182e-01,   1.59179688e-01],
                        [  1.62322998e-01,   1.67388916e-01],
                        [  1.45233154e-01,   1.50177002e-01],
                        [  1.00524902e-01,   1.04736328e-01],
                        [  3.17382812e-02,   3.41796875e-02],
                        [ -5.85632324e-02,  -5.86853027e-02],
                        [ -1.61499023e-01,  -1.64276123e-01],
                        [ -2.52563477e-01,  -2.57446289e-01],
                        [ -2.99774170e-01,  -3.05999756e-01],
                        [ -2.85705566e-01,  -2.92510986e-01],
                        [ -2.24182129e-01,  -2.30895996e-01],
                        [ -1.54846191e-01,  -1.61224365e-01],
                        [ -1.12396240e-01,  -1.18652344e-01],
                        [ -9.89990234e-02,  -1.05194092e-01],
                        [ -9.25903320e-02,  -9.81445312e-02],
                        [ -8.02001953e-02,  -8.37097168e-02],
                        [ -7.00378418e-02,  -7.00988770e-02],
                        [ -7.14721680e-02,  -6.77185059e-02],
                        [ -7.85827637e-02,  -7.21740723e-02],
                        [ -7.87048340e-02,  -7.16247559e-02],
                        [ -6.57043457e-02,  -5.97229004e-02],
                        [ -4.17175293e-02,  -3.74755859e-02],
                        [ -1.39770508e-02,  -1.08337402e-02],
                        [  7.26318359e-03,   1.07727051e-02],
                        [  1.33666992e-02,   1.84936523e-02],
                        [  2.41088867e-03,   9.30786133e-03],
                        [ -2.04467773e-02,  -1.28784180e-02],
                        [ -4.55017090e-02,  -3.90319824e-02],
                        [ -6.25610352e-02,  -5.91735840e-02],
                        [ -6.72607422e-02,  -6.87255859e-02],
                        [ -6.35681152e-02,  -7.08923340e-02],
                        [ -5.68237305e-02,  -6.94274902e-02],
                        [ -4.57153320e-02,  -6.11877441e-02],
                        [ -2.34069824e-02,  -3.79943848e-02],
                        [  1.55944824e-02,   5.64575195e-03],
                        [  7.01904297e-02,   6.70166016e-02],
                        [  1.31072998e-01,   1.33819580e-01],
                        [  1.82708740e-01,   1.88262939e-01],
                        [  2.09381104e-01,   2.14630127e-01],
                        [  2.02972412e-01,   2.07153320e-01],
                        [  1.70379639e-01,   1.75048828e-01],
                        [  1.32019043e-01,   1.39373779e-01],
                        [  1.08337402e-01,   1.19110107e-01],
                        [  1.04675293e-01,   1.17309570e-01],
                        [  1.09954834e-01,   1.21063232e-01],
                        [  1.08673096e-01,   1.14898682e-01],
                        [  9.54895020e-02,   9.55810547e-02],
                        [  7.87048340e-02,   7.37915039e-02],
                        [  6.92443848e-02,   6.13708496e-02],
                        [  6.88781738e-02,   5.96008301e-02],
                        [  7.11364746e-02,   6.11267090e-02],
                        [  7.15942383e-02,   6.11267090e-02],
                        [  7.38220215e-02,   6.33239746e-02],
                        [  8.46862793e-02,   7.48596191e-02],
                        [  1.04431152e-01,   9.62524414e-02],
                        [  1.19842529e-01,   1.14074707e-01],
                        [  1.09222412e-01,   1.06231689e-01],
                        [  5.94177246e-02,   5.93872070e-02],
                        [ -2.23999023e-02,  -1.91040039e-02],
                        [ -1.12854004e-01,  -1.05957031e-01],
                        [ -1.82952881e-01,  -1.72973633e-01],
                        [ -2.08099365e-01,  -1.96594238e-01],
                        [ -1.84020996e-01,  -1.73126221e-01],
                        [ -1.36566162e-01,  -1.27716064e-01],
                        [ -1.00921631e-01,  -9.41772461e-02],
                        [ -8.71582031e-02,  -8.15734863e-02],
                        [ -7.84606934e-02,  -7.33032227e-02],
                        [ -6.25915527e-02,  -5.83496094e-02],
                        [ -4.64782715e-02,  -4.48913574e-02],
                        [ -3.75976562e-02,  -4.06494141e-02],
                        [ -3.27148438e-02,  -4.08935547e-02],
                        [ -2.92968750e-02,  -4.08935547e-02],
                        [ -3.04565430e-02,  -4.21447754e-02],
                        [ -3.43017578e-02,  -4.29382324e-02],
                        [ -3.36608887e-02,  -3.77197266e-02],
                        [ -2.69775391e-02,  -2.67333984e-02],
                        [ -1.75476074e-02,  -1.45568848e-02],
                        [ -5.82885742e-03,  -1.80053711e-03],
                        [  6.50024414e-03,   1.04980469e-02],
                        [  1.03149414e-02,   1.40075684e-02],
                        [ -7.32421875e-04,   2.65502930e-03],
                        [ -1.97753906e-02,  -1.72119141e-02],
                        [ -3.61938477e-02,  -3.52172852e-02],
                        [ -4.76684570e-02,  -4.87365723e-02],
                        [ -5.71594238e-02,  -6.03332520e-02],
                        [ -6.60400391e-02,  -7.09838867e-02],
                        [ -7.29064941e-02,  -7.87048340e-02],
                        [ -7.11059570e-02,  -7.63854980e-02],
                        [ -5.01403809e-02,  -5.36193848e-02],
                        [ -8.30078125e-03,  -9.30786133e-03],
                        [  4.01000977e-02,   4.13513184e-02],
                        [  7.74841309e-02,   8.01086426e-02],
                        [  9.73205566e-02,   1.00158691e-01],
                        [  1.01928711e-01,   1.04064941e-01],
                        [  9.57031250e-02,   9.68933105e-02],
                        [  8.42285156e-02,   8.48693848e-02],
                        [  7.14721680e-02,   7.22045898e-02],
                        [  5.68542480e-02,   5.79833984e-02],
                        [  4.01000977e-02,   4.16259766e-02],
                        [  2.68859863e-02,   2.89306641e-02],
                        [  2.41699219e-02,   2.69470215e-02],
                        [  3.05175781e-02,   3.42102051e-02],
                        [  3.75366211e-02,   4.17480469e-02],
                        [  4.08630371e-02,   4.44335938e-02],
                        [  4.32739258e-02,   4.45251465e-02],
                        [  4.44030762e-02,   4.23889160e-02],
                        [  3.85131836e-02,   3.37524414e-02],
                        [  2.74353027e-02,   2.18200684e-02],
                        [  2.59399414e-02,   2.14843750e-02],
                        [  4.52270508e-02,   4.29992676e-02],
                        [  7.94982910e-02,   7.93151855e-02],
                        [  1.14990234e-01,   1.16027832e-01],
                        [  1.44012451e-01,   1.45721436e-01],
                        [  1.62841797e-01,   1.65161133e-01],
                        [  1.64916992e-01,   1.67877197e-01],
                        [  1.43615723e-01,   1.46728516e-01],
                        [  9.51232910e-02,   9.72290039e-02],
                        [  1.77612305e-02,   1.80053711e-02],
                        [ -8.18786621e-02,  -8.30993652e-02],
                        [ -1.83410645e-01,  -1.84814453e-01],
                        [ -2.60681152e-01,  -2.61230469e-01],
                        [ -2.92877197e-01,  -2.93243408e-01],
                        [ -2.73162842e-01,  -2.75604248e-01],
                        [ -2.16491699e-01,  -2.23358154e-01],
                        [ -1.55548096e-01,  -1.66961670e-01],
                        [ -1.16577148e-01,  -1.29455566e-01],
                        [ -1.01043701e-01,  -1.10382080e-01],
                        [ -9.52758789e-02,  -9.69848633e-02],
                        [ -9.06982422e-02,  -8.40148926e-02],
                        [ -8.88366699e-02,  -7.64465332e-02],
                        [ -9.01794434e-02,  -7.67211914e-02],
                        [ -8.65783691e-02,  -7.62023926e-02],
                        [ -6.89392090e-02,  -6.35070801e-02],
                        [ -3.96423340e-02,  -3.85131836e-02],
                        [ -1.10473633e-02,  -1.21765137e-02],
                        [  7.81250000e-03,   6.50024414e-03],
                        [  1.68762207e-02,   1.67541504e-02],
                        [  1.72729492e-02,   1.90429688e-02],
                        [  6.28662109e-03,   9.82666016e-03],
                        [ -1.65405273e-02,  -1.22070312e-02],
                        [ -4.28161621e-02,  -3.97644043e-02],
                        [ -6.14929199e-02,  -6.18591309e-02],
                        [ -6.84204102e-02,  -7.33337402e-02],
                        [ -6.56433105e-02,  -7.41882324e-02],
                        [ -5.45959473e-02,  -6.42089844e-02],
                        [ -3.33557129e-02,  -4.11987305e-02],
                        [  2.89916992e-03,  -1.46484375e-03],
                        [  5.75256348e-02,   5.64575195e-02],
                        [  1.22955322e-01,   1.23687744e-01],
                        [  1.79473877e-01,   1.80603027e-01],
                        [  2.08282471e-01,   2.09564209e-01],
                        [  2.05291748e-01,   2.07611084e-01],
                        [  1.81732178e-01,   1.85852051e-01],
                        [  1.52496338e-01,   1.58325195e-01],
                        [  1.26220703e-01,   1.32507324e-01],
                        [  1.05682373e-01,   1.10839844e-01],
                        [  9.17053223e-02,   9.44519043e-02],
                        [  8.22143555e-02,   8.22753906e-02],
                        [  7.46765137e-02,   7.24792480e-02],
                        [  7.10754395e-02,   6.73217773e-02],
                        [  7.38830566e-02,   6.93054199e-02],
                        [  7.75756836e-02,   7.27539062e-02],
                        [  7.34558105e-02,   6.90612793e-02],
                        [  6.18896484e-02,   5.85327148e-02],
                        [  5.19714355e-02,   4.99572754e-02],
                        [  5.03234863e-02,   4.96826172e-02],
                        [  5.68847656e-02,   5.74951172e-02],
                        [  6.91833496e-02,   7.08618164e-02],
                        [  8.27026367e-02,   8.52355957e-02],
                        [  8.77685547e-02,   9.07897949e-02],
                        [  7.37304688e-02,   7.64770508e-02],
                        [  3.66821289e-02,   3.79943848e-02],
                        [ -1.86462402e-02,  -1.95922852e-02],
                        [ -7.96203613e-02,  -8.26416016e-02],
                        [ -1.26922607e-01,  -1.30584717e-01],
                        [ -1.43371582e-01,  -1.45782471e-01],
                        [ -1.28479004e-01,  -1.28448486e-01],
                        [ -1.00402832e-01,  -9.77783203e-02],
                        [ -7.93151855e-02,  -7.47375488e-02],
                        [ -7.09838867e-02,  -6.51550293e-02],
                        [ -6.70776367e-02,  -6.06079102e-02],
                        [ -5.92346191e-02,  -5.30395508e-02],
                        [ -4.91638184e-02,  -4.47998047e-02],
                        [ -4.30908203e-02,  -4.21752930e-02],
                        [ -4.15954590e-02,  -4.47082520e-02],
                        [ -3.88488770e-02,  -4.49829102e-02],
                        [ -2.92968750e-02,  -3.59802246e-02],
                        [ -1.31225586e-02,  -1.77917480e-02],
                        [  2.22778320e-03,   6.10351562e-04],
                        [  7.59887695e-03,   7.65991211e-03],
                        [  1.00708008e-03,   3.35693359e-04],
                        [ -1.09558105e-02,  -1.37023926e-02],
                        [ -2.08740234e-02,  -2.48107910e-02],
                        [ -2.60925293e-02,  -2.89306641e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.70690918e-02,  -2.42309570e-02],
                        [ -3.12805176e-02,  -2.74353027e-02],
                        [ -4.48913574e-02,  -4.20837402e-02],
                        [ -6.34765625e-02,  -6.24389648e-02],
                        [ -7.47375488e-02,  -7.44934082e-02],
                        [ -7.18994141e-02,  -7.11669922e-02],
                        [ -5.75866699e-02,  -5.60302734e-02],
                        [ -3.25317383e-02,  -3.11279297e-02],
                        [  6.86645508e-03,   6.98852539e-03],
                        [  5.46264648e-02,   5.31616211e-02],
                        [  9.14001465e-02,   8.90808105e-02],
                        [  1.02447510e-01,   1.00067139e-01],
                        [  9.20715332e-02,   8.94165039e-02],
                        [  7.47680664e-02,   7.05871582e-02],
                        [  5.90515137e-02,   5.23376465e-02],
                        [  4.46472168e-02,   3.62854004e-02],
                        [  3.03955078e-02,   2.34985352e-02],
                        [  2.01110840e-02,   1.84631348e-02],
                        [  1.94091797e-02,   2.52380371e-02],
                        [  2.78015137e-02,   4.01916504e-02],
                        [  3.72009277e-02,   5.29174805e-02],
                        [  4.15344238e-02,   5.68237305e-02],
                        [  4.28161621e-02,   5.53588867e-02],
                        [  4.50134277e-02,   5.42907715e-02],
                        [  4.73632812e-02,   5.38024902e-02],
                        [  4.83093262e-02,   5.20019531e-02],
                        [  5.14526367e-02,   5.15136719e-02],
                        [  6.25305176e-02,   5.77697754e-02],
                        [  8.28247070e-02,   7.28149414e-02],
                        [  1.07604980e-01,   9.32312012e-02],
                        [  1.30828857e-01,   1.13800049e-01],
                        [  1.48162842e-01,   1.30432129e-01],
                        [  1.52862549e-01,   1.36474609e-01],
                        [  1.31805420e-01,   1.19049072e-01],
                        [  7.39440918e-02,   6.71691895e-02],
                        [ -1.69982910e-02,  -1.61437988e-02],
                        [ -1.22741699e-01,  -1.14257812e-01],
                        [ -2.18902588e-01,  -2.04986572e-01],
                        [ -2.80517578e-01,  -2.64923096e-01],
                        [ -2.90557861e-01,  -2.77069092e-01],
                        [ -2.54333496e-01,  -2.45086670e-01],
                        [ -1.99615479e-01,  -1.94458008e-01],
                        [ -1.53411865e-01,  -1.50848389e-01],
                        [ -1.22314453e-01,  -1.21002197e-01],
                        [ -9.83276367e-02,  -9.81750488e-02],
                        [ -7.66601562e-02,  -7.85217285e-02],
                        [ -6.02416992e-02,  -6.47277832e-02],
                        [ -5.18493652e-02,  -5.84411621e-02],
                        [ -4.84619141e-02,  -5.57250977e-02],
                        [ -4.34875488e-02,  -4.98657227e-02],
                        [ -3.29589844e-02,  -3.74450684e-02],
                        [ -1.90429688e-02,  -2.15454102e-02],
                        [ -7.50732422e-03,  -8.60595703e-03],
                        [ -3.20434570e-03,  -3.54003906e-03],
                        [ -7.08007812e-03,  -6.83593750e-03],
                        [ -1.62658691e-02,  -1.50756836e-02],
                        [ -2.77404785e-02,  -2.48107910e-02],
                        [ -4.26940918e-02,  -3.70178223e-02],
                        [ -6.30187988e-02,  -5.41381836e-02],
                        [ -8.23974609e-02,  -7.09838867e-02],
                        [ -8.67309570e-02,  -7.51342773e-02],
                        [ -6.82678223e-02,  -6.00585938e-02],
                        [ -3.18603516e-02,  -2.99987793e-02],
                        [  1.64184570e-02,   1.11389160e-02],
                        [  7.54699707e-02,   6.49719238e-02],
                        [  1.38092041e-01,   1.26037598e-01],
                        [  1.86279297e-01,   1.76025391e-01],
                        [  2.05902100e-01,   1.98791504e-01],
                        [  1.97052002e-01,   1.92230225e-01],
                        [  1.68701172e-01,   1.64642334e-01],
                        [  1.33636475e-01,   1.29730225e-01],
                        [  1.06872559e-01,   1.04064941e-01],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  9.10034180e-02,   9.50927734e-02],
                        [  8.12683105e-02,   8.92639160e-02],
                        [  6.81457520e-02,   7.84606934e-02],
                        [  6.18896484e-02,   7.24182129e-02],
                        [  6.39343262e-02,   7.25402832e-02],
                        [  6.47888184e-02,   6.95190430e-02],
                        [  5.76782227e-02,   5.70373535e-02],
                        [  4.63562012e-02,   3.99169922e-02],
                        [  3.94287109e-02,   2.85949707e-02],
                        [  4.16870117e-02,   2.99072266e-02],
                        [  5.20019531e-02,   4.34875488e-02],
                        [  6.59484863e-02,   6.34460449e-02],
                        [  7.99865723e-02,   8.30993652e-02],
                        [  9.30480957e-02,   9.85412598e-02],
                        [  1.03912354e-01,   1.07940674e-01],
                        [  1.07025146e-01,   1.07666016e-01],
                        [  9.07287598e-02,   8.93859863e-02],
                        [  4.26025391e-02,   4.25720215e-02],
                        [ -3.72314453e-02,  -3.34472656e-02],
                        [ -1.25061035e-01,  -1.17858887e-01],
                        [ -1.84082031e-01,  -1.76666260e-01],
                        [ -1.93969727e-01,  -1.89819336e-01],
                        [ -1.67297363e-01,  -1.67907715e-01],
                        [ -1.34338379e-01,  -1.38244629e-01],
                        [ -1.13342285e-01,  -1.17645264e-01],
                        [ -1.01074219e-01,  -1.03454590e-01],
                        [ -8.76159668e-02,  -8.78601074e-02],
                        [ -6.94274902e-02,  -6.91528320e-02],
                        [ -4.67529297e-02,  -4.78210449e-02],
                        [ -2.18505859e-02,  -2.47192383e-02],
                        [ -3.35693359e-03,  -6.98852539e-03],
                        [ -3.66210938e-04,  -3.14331055e-03],
                        [ -9.55200195e-03,  -1.05895996e-02],
                        [ -1.88598633e-02,  -1.82189941e-02],
                        [ -2.25219727e-02,  -2.09655762e-02],
                        [ -2.40783691e-02,  -2.22167969e-02],
                        [ -2.65197754e-02,  -2.45971680e-02],
                        [ -2.79846191e-02,  -2.59704590e-02],
                        [ -2.57568359e-02,  -2.36816406e-02],
                        [ -2.06298828e-02,  -1.85241699e-02],
                        [ -1.71813965e-02,  -1.49841309e-02],
                        [ -2.17285156e-02,  -1.90734863e-02],
                        [ -3.72924805e-02,  -3.41186523e-02],
                        [ -5.88989258e-02,  -5.59387207e-02],
                        [ -7.47680664e-02,  -7.36999512e-02],
                        [ -7.48596191e-02,  -7.74841309e-02],
                        [ -5.74035645e-02,  -6.45751953e-02],
                        [ -2.60620117e-02,  -3.70178223e-02],
                        [  1.51672363e-02,   2.74658203e-03],
                        [  6.02722168e-02,   4.92858887e-02],
                        [  9.81750488e-02,   9.07592773e-02],
                        [  1.17767334e-01,   1.14746094e-01],
                        [  1.16729736e-01,   1.17614746e-01],
                        [  1.02050781e-01,   1.05743408e-01],
                        [  8.35571289e-02,   8.88366699e-02],
                        [  6.85729980e-02,   7.47070312e-02],
                        [  5.88684082e-02,   6.55212402e-02],
                        [  4.92248535e-02,   5.66406250e-02],
                        [  3.50341797e-02,   4.35791016e-02],
                        [  2.22167969e-02,   3.19824219e-02],
                        [  2.12097168e-02,   3.16772461e-02],
                        [  3.11279297e-02,   4.11071777e-02],
                        [  4.11376953e-02,   4.93469238e-02],
                        [  4.55627441e-02,   5.11474609e-02],
                        [  4.68750000e-02,   4.96215820e-02],
                        [  4.82482910e-02,   4.81872559e-02],
                        [  5.39855957e-02,   5.08422852e-02],
                        [  7.15942383e-02,   6.45446777e-02],
                        [  1.01684570e-01,   9.00573730e-02],
                        [  1.32324219e-01,   1.16607666e-01],
                        [  1.51153564e-01,   1.33483887e-01],
                        [  1.54693604e-01,   1.38214111e-01],
                        [  1.39495850e-01,   1.26770020e-01],
                        [  9.63134766e-02,   8.83789062e-02],
                        [  2.13928223e-02,   1.76696777e-02],
                        [ -7.55004883e-02,  -7.59582520e-02],
                        [ -1.75201416e-01,  -1.72546387e-01],
                        [ -2.51861572e-01,  -2.45269775e-01],
                        [ -2.79296875e-01,  -2.68066406e-01],
                        [ -2.51373291e-01,  -2.36114502e-01],
                        [ -1.93725586e-01,  -1.76818848e-01],
                        [ -1.43280029e-01,  -1.27929688e-01],
                        [ -1.17706299e-01,  -1.06658936e-01],
                        [ -1.09161377e-01,  -1.03668213e-01],
                        [ -1.02416992e-01,  -1.02539062e-01],
                        [ -9.22851562e-02,  -9.75341797e-02],
                        [ -8.20617676e-02,  -9.17053223e-02],
                        [ -7.23571777e-02,  -8.51440430e-02],
                        [ -5.94482422e-02,  -7.31506348e-02],
                        [ -4.28466797e-02,  -5.45043945e-02],
                        [ -2.57873535e-02,  -3.30810547e-02],
                        [ -9.85717773e-03,  -1.22985840e-02],
                        [  3.87573242e-03,   4.66918945e-03],
                        [  1.16882324e-02,   1.35192871e-02],
                        [  1.09558105e-02,   1.28173828e-02],
                        [  1.49536133e-03,   4.69970703e-03],
                        [ -1.84631348e-02,  -1.14440918e-02],
                        [ -4.88281250e-02,  -3.65600586e-02],
                        [ -7.83996582e-02,  -6.24389648e-02],
                        [ -9.01489258e-02,  -7.46459961e-02],
                        [ -7.80944824e-02,  -6.75964355e-02],
                        [ -4.88891602e-02,  -4.58068848e-02],
                        [ -6.74438477e-03,  -1.01318359e-02],
                        [  5.07507324e-02,   4.38232422e-02],
                        [  1.19934082e-01,   1.12182617e-01],
                        [  1.84387207e-01,   1.76513672e-01],
                        [  2.23846436e-01,   2.14691162e-01],
                        [  2.27020264e-01,   2.15393066e-01],
                        [  1.98974609e-01,   1.85211182e-01],
                        [  1.57836914e-01,   1.44287109e-01],
                        [  1.21978760e-01,   1.11907959e-01],
                        [  9.90295410e-02,   9.48486328e-02],
                        [  8.60595703e-02,   8.85009766e-02],
                        [  7.68432617e-02,   8.48388672e-02],
                        [  6.72607422e-02,   7.86743164e-02],
                        [  5.67932129e-02,   6.91833496e-02],
                        [  4.66308594e-02,   5.76171875e-02],
                        [  3.71398926e-02,   4.49218750e-02],
                        [  2.78015137e-02,   3.15856934e-02],
                        [  1.85852051e-02,   1.89514160e-02],
                        [  1.14135742e-02,   9.91821289e-03],
                        [  1.11999512e-02,   9.55200195e-03],
                        [  2.30712891e-02,   2.19421387e-02],
                        [  4.58679199e-02,   4.44946289e-02],
                        [  7.23571777e-02,   6.92443848e-02],
                        [  9.66796875e-02,   9.09423828e-02],
                        [  1.16638184e-01,   1.09069824e-01],
                        [  1.28875732e-01,   1.21948242e-01],
                        [  1.28112793e-01,   1.24603271e-01],
                        [  1.09313965e-01,   1.10931396e-01],
                        [  6.62536621e-02,   7.28149414e-02],
                        [ -6.46972656e-03,   3.20434570e-03],
                        [ -9.98535156e-02,  -8.97216797e-02],
                        [ -1.82830811e-01,  -1.74652100e-01],
                        [ -2.20306396e-01,  -2.15606689e-01],
                        [ -2.02423096e-01,  -2.01660156e-01],
                        [ -1.51123047e-01,  -1.53625488e-01],
                        [ -9.86022949e-02,  -1.03149414e-01],
                        [ -6.46362305e-02,  -7.01293945e-02],
                        [ -5.07812500e-02,  -5.68542480e-02],
                        [ -4.76379395e-02,  -5.45349121e-02],
                        [ -4.63256836e-02,  -5.42907715e-02],
                        [ -4.69360352e-02,  -5.51452637e-02],
                        [ -5.32531738e-02,  -5.94787598e-02],
                        [ -5.99670410e-02,  -6.15844727e-02],
                        [ -5.54504395e-02,  -5.11169434e-02],
                        [ -3.75061035e-02,  -2.83813477e-02],
                        [ -1.61132812e-02,  -5.55419922e-03],
                        [ -8.85009766e-04,   7.35473633e-03],
                        [  4.60815430e-03,   8.81958008e-03],
                        [  4.27246094e-04,   1.67846680e-03],
                        [ -9.73510742e-03,  -8.60595703e-03],
                        [ -1.98059082e-02,  -1.66320801e-02],
                        [ -2.77099609e-02,  -2.24609375e-02],
                        [ -3.61022949e-02,  -3.10974121e-02],
                        [ -4.80651855e-02,  -4.63562012e-02],
                        [ -6.43920898e-02,  -6.79321289e-02],
                        [ -8.05053711e-02,  -8.95080566e-02],
                        [ -8.53576660e-02,  -9.84497070e-02],
                        [ -6.96716309e-02,  -8.46557617e-02],
                        [ -3.56140137e-02,  -5.01403809e-02],
                        [  7.11059570e-03,  -4.57763672e-03],
                        [  5.05065918e-02,   4.37316895e-02],
                        [  8.88671875e-02,   8.80737305e-02],
                        [  1.14837646e-01,   1.19476318e-01],
                        [  1.20483398e-01,   1.28479004e-01],
                        [  1.04431152e-01,   1.13281250e-01],
                        [  7.73315430e-02,   8.57849121e-02],
                        [  5.50537109e-02,   6.38427734e-02],
                        [  4.33959961e-02,   5.41687012e-02],
                        [  3.60717773e-02,   4.97131348e-02],
                        [  3.11584473e-02,   4.61120605e-02],
                        [  3.63464355e-02,   4.91333008e-02],
                        [  5.34057617e-02,   6.04248047e-02],
                        [  6.97021484e-02,   6.97631836e-02],
                        [  7.40661621e-02,   6.86950684e-02],
                        [  7.05566406e-02,   6.28967285e-02],
                        [  7.01599121e-02,   6.24389648e-02],
                        [  7.56835938e-02,   6.79321289e-02],
                        [  8.24890137e-02,   7.31201172e-02],
                        [  9.00573730e-02,   7.78198242e-02],
                        [  1.03820801e-01,   8.94775391e-02],
                        [  1.24511719e-01,   1.10717773e-01],
                        [  1.40777588e-01,   1.30767822e-01],
                        [  1.35131836e-01,   1.30767822e-01],
                        [  9.48486328e-02,   9.59472656e-02],
                        [  1.88598633e-02,   2.38952637e-02],
                        [ -8.12988281e-02,  -7.40661621e-02],
                        [ -1.84265137e-01,  -1.76055908e-01],
                        [ -2.62542725e-01,  -2.54150391e-01],
                        [ -2.91534424e-01,  -2.83721924e-01],
                        [ -2.65563965e-01,  -2.59033203e-01],
                        [ -2.05780029e-01,  -2.00836182e-01],
                        [ -1.45111084e-01,  -1.41235352e-01],
                        [ -1.04309082e-01,  -1.00708008e-01],
                        [ -8.50830078e-02,  -8.16650391e-02],
                        [ -7.96203613e-02,  -7.75146484e-02],
                        [ -7.87353516e-02,  -7.99560547e-02],
                        [ -7.71484375e-02,  -8.29162598e-02],
                        [ -7.52563477e-02,  -8.48083496e-02],
                        [ -7.30895996e-02,  -8.36486816e-02],
                        [ -6.47277832e-02,  -7.27539062e-02],
                        [ -4.62341309e-02,  -4.94079590e-02],
                        [ -2.38952637e-02,  -2.21862793e-02],
                        [ -5.58471680e-03,  -9.15527344e-04],
                        [  8.75854492e-03,   1.38549805e-02],
                        [  1.87988281e-02,   2.26135254e-02],
                        [  1.51367188e-02,   1.73339844e-02],
                        [ -9.06372070e-03,  -7.72094727e-03],
                        [ -4.44641113e-02,  -4.29077148e-02],
                        [ -7.23571777e-02,  -6.98242188e-02],
                        [ -8.12072754e-02,  -7.77587891e-02],
                        [ -7.05261230e-02,  -6.68945312e-02],
                        [ -4.14428711e-02,  -3.89099121e-02],
                        [  8.23974609e-03,   8.51440430e-03],
                        [  7.62023926e-02,   7.39746094e-02],
                        [  1.46301270e-01,   1.42395020e-01],
                        [  1.94488525e-01,   1.90429688e-01],
                        [  2.06512451e-01,   2.03643799e-01],
                        [  1.87927246e-01,   1.86492920e-01],
                        [  1.57196045e-01,   1.56341553e-01],
                        [  1.31835938e-01,   1.30523682e-01],
                        [  1.17553711e-01,   1.15570068e-01],
                        [  1.07360840e-01,   1.05468750e-01],
                        [  9.35058594e-02,   9.25598145e-02],
                        [  7.84912109e-02,   7.83691406e-02],
                        [  6.79321289e-02,   6.73217773e-02],
                        [  5.77697754e-02,   5.51147461e-02],
                        [  4.07104492e-02,   3.58886719e-02],
                        [  2.09045410e-02,   1.58386230e-02],
                        [  7.20214844e-03,   4.82177734e-03],
                        [ -1.83105469e-03,   4.27246094e-04],
                        [ -1.01318359e-02,  -3.84521484e-03],
                        [ -9.30786133e-03,  -1.73950195e-03],
                        [  9.36889648e-03,   1.53198242e-02],
                        [  3.56750488e-02,   3.89709473e-02],
                        [  5.17578125e-02,   5.35888672e-02],
                        [  5.66101074e-02,   5.91430664e-02],
                        [  6.36901855e-02,   6.80236816e-02],
                        [  8.06274414e-02,   8.57849121e-02],
                        [  1.04431152e-01,   1.08215332e-01],
                        [  1.27563477e-01,   1.28234863e-01],
                        [  1.34826660e-01,   1.32324219e-01],
                        [  1.03912354e-01,   9.95788574e-02],
                        [  2.58178711e-02,   2.10266113e-02],
                        [ -7.85827637e-02,  -8.32824707e-02],
                        [ -1.70379639e-01,  -1.75476074e-01],
                        [ -2.18231201e-01,  -2.24090576e-01],
                        [ -2.12951660e-01,  -2.19085693e-01],
                        [ -1.69555664e-01,  -1.74865723e-01],
                        [ -1.17675781e-01,  -1.21246338e-01],
                        [ -8.16040039e-02,  -8.34045410e-02],
                        [ -6.65283203e-02,  -6.69860840e-02],
                        [ -6.48498535e-02,  -6.37512207e-02],
                        [ -6.95800781e-02,  -6.55822754e-02],
                        [ -7.73010254e-02,  -6.87866211e-02],
                        [ -8.36181641e-02,  -7.05566406e-02],
                        [ -8.35571289e-02,  -6.86645508e-02],
                        [ -7.58972168e-02,  -6.39953613e-02],
                        [ -6.15234375e-02,  -5.70678711e-02],
                        [ -3.98559570e-02,  -4.42199707e-02],
                        [ -1.36718750e-02,  -2.42919922e-02],
                        [  5.61523438e-03,  -6.25610352e-03],
                        [  7.78198242e-03,  -8.54492188e-04],
                        [ -3.81469727e-03,  -7.50732422e-03],
                        [ -1.78833008e-02,  -1.79748535e-02],
                        [ -2.87780762e-02,  -2.81372070e-02],
                        [ -3.75366211e-02,  -3.84826660e-02],
                        [ -4.66613770e-02,  -4.96826172e-02],
                        [ -5.87158203e-02,  -6.28356934e-02],
                        [ -7.46765137e-02,  -7.82165527e-02],
                        [ -8.68530273e-02,  -8.85620117e-02],
                        [ -7.97424316e-02,  -7.91320801e-02],
                        [ -4.47692871e-02,  -4.21142578e-02],
                        [  8.14819336e-03,   1.17492676e-02],
                        [  5.99060059e-02,   6.30187988e-02],
                        [  9.83581543e-02,   9.97314453e-02],
                        [  1.18286133e-01,   1.17523193e-01],
                        [  1.15875244e-01,   1.13952637e-01],
                        [  9.61914062e-02,   9.50927734e-02],
                        [  7.67822266e-02,   7.82775879e-02],
                        [  6.91223145e-02,   7.36083984e-02],
                        [  6.59179688e-02,   7.20825195e-02],
                        [  5.83801270e-02,   6.39953613e-02],
                        [  5.34667969e-02,   5.68542480e-02],
                        [  5.99670410e-02,   6.10961914e-02],
                        [  6.96716309e-02,   7.00988770e-02],
                        [  6.86035156e-02,   7.04345703e-02],
                        [  5.89599609e-02,   6.34155273e-02],
                        [  5.44128418e-02,   6.08825684e-02],
                        [  5.99365234e-02,   6.61621094e-02],
                        [  7.10449219e-02,   7.38220215e-02],
                        [  8.74633789e-02,   8.40759277e-02],
                        [  1.13098145e-01,   1.02600098e-01],
                        [  1.42303467e-01,   1.26312256e-01],
                        [  1.57897949e-01,   1.40228271e-01],
                        [  1.45233154e-01,   1.30432129e-01],
                        [  1.00402832e-01,   9.18273926e-02],
                        [  2.49633789e-02,   2.32849121e-02],
                        [ -7.63244629e-02,  -7.31506348e-02],
                        [ -1.87072754e-01,  -1.82434082e-01],
                        [ -2.76214600e-01,  -2.72552490e-01],
                        [ -3.12377930e-01,  -3.09875488e-01],
                        [ -2.86468506e-01,  -2.83325195e-01],
                        [ -2.21252441e-01,  -2.15301514e-01],
                        [ -1.55212402e-01,  -1.45782471e-01],
                        [ -1.13525391e-01,  -1.02111816e-01],
                        [ -9.63439941e-02,  -8.59069824e-02],
                        [ -9.10949707e-02,  -8.44726562e-02],
                        [ -8.58459473e-02,  -8.45336914e-02],
                        [ -7.37609863e-02,  -7.75756836e-02],
                        [ -5.64270020e-02,  -6.38122559e-02],
                        [ -4.23278809e-02,  -5.10253906e-02],
                        [ -3.65600586e-02,  -4.40368652e-02],
                        [ -3.38745117e-02,  -3.79638672e-02],
                        [ -2.58789062e-02,  -2.53906250e-02],
                        [ -1.17187500e-02,  -7.23266602e-03],
                        [  2.13623047e-04,   6.34765625e-03],
                        [  1.49536133e-03,   6.10351562e-03],
                        [ -8.97216797e-03,  -8.08715820e-03],
                        [ -2.72827148e-02,  -3.00598145e-02],
                        [ -4.76379395e-02,  -5.19409180e-02],
                        [ -5.97229004e-02,  -6.28967285e-02],
                        [ -5.32226562e-02,  -5.40161133e-02],
                        [ -2.79846191e-02,  -2.74353027e-02],
                        [  1.00097656e-02,   9.67407227e-03],
                        [  6.10046387e-02,   5.84411621e-02],
                        [  1.24053955e-01,   1.20086670e-01],
                        [  1.81060791e-01,   1.78161621e-01],
                        [  2.07550049e-01,   2.07977295e-01],
                        [  1.99127197e-01,   2.03186035e-01],
                        [  1.71966553e-01,   1.77825928e-01],
                        [  1.40930176e-01,   1.46087646e-01],
                        [  1.11724854e-01,   1.14959717e-01],
                        [  8.89892578e-02,   9.07897949e-02],
                        [  7.57751465e-02,   7.73315430e-02],
                        [  6.83288574e-02,   6.99768066e-02],
                        [  6.22558594e-02,   6.27441406e-02],
                        [  5.94787598e-02,   5.67626953e-02],
                        [  6.10961914e-02,   5.42602539e-02],
                        [  5.99975586e-02,   5.01708984e-02],
                        [  4.71801758e-02,   3.72009277e-02],
                        [  2.38952637e-02,   1.66625977e-02],
                        [  1.98364258e-03,  -1.12915039e-03],
                        [ -7.50732422e-03,  -6.86645508e-03],
                        [ -2.92968750e-03,   6.10351562e-05],
                        [  1.08947754e-02,   1.51062012e-02],
                        [  2.90832520e-02,   3.39660645e-02],
                        [  4.66003418e-02,   5.20935059e-02],
                        [  5.82275391e-02,   6.42395020e-02],
                        [  6.31103516e-02,   6.92749023e-02],
                        [  6.61926270e-02,   7.22351074e-02],
                        [  7.29370117e-02,   7.86743164e-02],
                        [  8.35876465e-02,   8.88366699e-02],
                        [  9.24987793e-02,   9.66491699e-02],
                        [  8.94775391e-02,   9.14001465e-02],
                        [  6.33544922e-02,   6.18591309e-02],
                        [  8.94165039e-03,   3.26538086e-03],
                        [ -6.63146973e-02,  -7.58972168e-02],
                        [ -1.40838623e-01,  -1.53167725e-01],
                        [ -1.87286377e-01,  -2.00592041e-01],
                        [ -1.89331055e-01,  -2.01507568e-01],
                        [ -1.55090332e-01,  -1.63818359e-01],
                        [ -1.10778809e-01,  -1.13769531e-01],
                        [ -7.83996582e-02,  -7.40051270e-02],
                        [ -6.21032715e-02,  -5.02014160e-02],
                        [ -5.62438965e-02,  -3.87573242e-02],
                        [ -5.71594238e-02,  -3.77502441e-02],
                        [ -6.27746582e-02,  -4.55627441e-02],
                        [ -6.84204102e-02,  -5.67321777e-02],
                        [ -6.97021484e-02,  -6.51550293e-02],
                        [ -6.63146973e-02,  -6.88781738e-02],
                        [ -5.93261719e-02,  -6.79321289e-02],
                        [ -4.74853516e-02,  -6.04248047e-02],
                        [ -2.89306641e-02,  -4.41284180e-02],
                        [ -6.25610352e-03,  -2.14843750e-02],
                        [  1.17187500e-02,  -1.61743164e-03],
                        [  1.55944824e-02,   5.09643555e-03],
                        [  3.11279297e-03,  -4.63867188e-03],
                        [ -1.96838379e-02,  -2.51159668e-02],
                        [ -4.55322266e-02,  -4.85534668e-02],
                        [ -7.11364746e-02,  -7.05566406e-02],
                        [ -9.37194824e-02,  -8.79211426e-02],
                        [ -1.06170654e-01,  -9.47265625e-02],
                        [ -9.96093750e-02,  -8.44116211e-02],
                        [ -6.96716309e-02,  -5.44738770e-02],
                        [ -2.01110840e-02,  -8.60595703e-03],
                        [  3.77197266e-02,   4.39758301e-02],
                        [  8.84399414e-02,   9.07287598e-02],
                        [  1.18408203e-01,   1.19476318e-01],
                        [  1.21856689e-01,   1.23718262e-01],
                        [  1.04461670e-01,   1.06842041e-01],
                        [  8.06579590e-02,   8.14208984e-02],
                        [  6.37817383e-02,   6.08520508e-02],
                        [  5.78002930e-02,   5.08728027e-02],
                        [  5.86547852e-02,   4.94384766e-02],
                        [  6.09130859e-02,   5.17883301e-02],
                        [  6.20727539e-02,   5.46264648e-02],
                        [  6.29882812e-02,   5.76171875e-02],
                        [  6.52465820e-02,   6.19201660e-02],
                        [  6.83288574e-02,   6.77185059e-02],
                        [  7.06787109e-02,   7.40661621e-02],
                        [  7.30895996e-02,   8.12683105e-02],
                        [  7.91015625e-02,   9.09118652e-02],
                        [  9.19799805e-02,   1.04125977e-01],
                        [  1.11419678e-01,   1.19964600e-01],
                        [  1.31988525e-01,   1.34399414e-01],
                        [  1.44500732e-01,   1.40686035e-01],
                        [  1.38610840e-01,   1.30340576e-01],
                        [  1.02813721e-01,   9.22241211e-02],
                        [  2.82897949e-02,   1.67541504e-02],
                        [ -7.97424316e-02,  -9.14916992e-02],
                        [ -1.95007324e-01,  -2.06024170e-01],
                        [ -2.81402588e-01,  -2.89947510e-01],
                        [ -3.13354492e-01,  -3.17565918e-01],
                        [ -2.88726807e-01,  -2.87841797e-01],
                        [ -2.28271484e-01,  -2.23297119e-01],
                        [ -1.64123535e-01,  -1.57165527e-01],
                        [ -1.19964600e-01,  -1.12640381e-01],
                        [ -9.87854004e-02,  -9.12780762e-02],
                        [ -9.09729004e-02,  -8.24890137e-02],
                        [ -8.86840820e-02,  -7.87353516e-02],
                        [ -8.64562988e-02,  -7.61108398e-02],
                        [ -7.69653320e-02,  -6.86340332e-02],
                        [ -5.53283691e-02,  -5.12084961e-02],
                        [ -2.42309570e-02,  -2.48718262e-02],
                        [  6.83593750e-03,   2.89916992e-03],
                        [  2.62756348e-02,   2.14843750e-02],
                        [  2.82592773e-02,   2.44750977e-02],
                        [  1.58386230e-02,   1.37634277e-02],
                        [ -7.53784180e-03,  -8.39233398e-03],
                        [ -4.26635742e-02,  -4.31213379e-02],
                        [ -8.21228027e-02,  -8.29467773e-02],
                        [ -1.05499268e-01,  -1.07482910e-01],
                        [ -9.75341797e-02,  -1.01531982e-01],
                        [ -6.25610352e-02,  -6.91223145e-02],
                        [ -1.33056641e-02,  -2.19116211e-02],
                        [  4.45861816e-02,   3.58276367e-02],
                        [  1.08825684e-01,   1.02630615e-01],
                        [  1.68060303e-01,   1.66687012e-01],
                        [  2.04650879e-01,   2.08648682e-01],
                        [  2.10906982e-01,   2.18841553e-01],
                        [  1.94488525e-01,   2.03826904e-01],
                        [  1.69036865e-01,   1.77398682e-01],
                        [  1.44348145e-01,   1.50451660e-01],
                        [  1.23870850e-01,   1.27410889e-01],
                        [  1.05255127e-01,   1.06597900e-01],
                        [  8.47473145e-02,   8.42895508e-02],
                        [  6.32019043e-02,   6.11267090e-02],
                        [  4.66308594e-02,   4.29992676e-02],
                        [  3.91235352e-02,   3.39050293e-02],
                        [  3.59497070e-02,   2.92968750e-02],
                        [  2.72216797e-02,   1.95617676e-02],
                        [  9.88769531e-03,   2.50244141e-03],
                        [ -6.89697266e-03,  -1.19628906e-02],
                        [ -1.22985840e-02,  -1.27868652e-02],
                        [ -6.34765625e-03,  -1.03759766e-03],
                        [  1.70898438e-03,   1.19628906e-02],
                        [  6.19506836e-03,   1.83715820e-02],
                        [  1.02539062e-02,   2.03857422e-02],
                        [  1.86767578e-02,   2.37426758e-02],
                        [  3.25622559e-02,   3.19213867e-02],
                        [  5.24597168e-02,   4.77905273e-02],
                        [  7.69653320e-02,   7.08312988e-02],
                        [  9.72290039e-02,   9.17663574e-02],
                        [  1.04919434e-01,   1.00891113e-01],
                        [  1.04003906e-01,   1.01440430e-01],
                        [  1.03149414e-01,   1.01837158e-01],
                        [  9.72290039e-02,   9.71679688e-02],
                        [  6.72912598e-02,   6.82373047e-02],
                        [  3.05175781e-05,   1.06811523e-03],
                        [ -9.39025879e-02,  -9.40856934e-02],
                        [ -1.80694580e-01,  -1.82708740e-01],
                        [ -2.25463867e-01,  -2.28332520e-01],
                        [ -2.17803955e-01,  -2.19085693e-01],
                        [ -1.76574707e-01,  -1.73767090e-01],
                        [ -1.32446289e-01,  -1.24816895e-01],
                        [ -1.05346680e-01,  -9.46350098e-02],
                        [ -9.44824219e-02,  -8.38928223e-02],
                        [ -8.72802734e-02,  -7.96508789e-02],
                        [ -7.65686035e-02,  -7.29675293e-02],
                        [ -6.47888184e-02,  -6.46667480e-02],
                        [ -5.56945801e-02,  -5.81359863e-02],
                        [ -4.90112305e-02,  -5.38940430e-02],
                        [ -4.31518555e-02,  -5.10864258e-02],
                        [ -3.66210938e-02,  -4.76684570e-02],
                        [ -2.65808105e-02,  -3.95507812e-02],
                        [ -1.16882324e-02,  -2.41088867e-02],
                        [  2.80761719e-03,  -6.86645508e-03],
                        [  6.92749023e-03,   8.85009766e-04],
                        [ -3.99780273e-03,  -7.08007812e-03],
                        [ -2.63366699e-02,  -2.74963379e-02],
                        [ -5.47790527e-02,  -5.41381836e-02],
                        [ -8.48083496e-02,  -8.14819336e-02],
                        [ -1.09222412e-01,  -1.02355957e-01],
                        [ -1.18560791e-01,  -1.08581543e-01],
                        [ -1.06903076e-01,  -9.58251953e-02],
                        [ -7.42187500e-02,  -6.45751953e-02],
                        [ -2.55432129e-02,  -1.88903809e-02],
                        [  3.06396484e-02,   3.44543457e-02],
                        [  8.42895508e-02,   8.64868164e-02],
                        [  1.24938965e-01,   1.26464844e-01],
                        [  1.43188477e-01,   1.44042969e-01],
                        [  1.35284424e-01,   1.34948730e-01],
                        [  1.07727051e-01,   1.06292725e-01],
                        [  7.59277344e-02,   7.46459961e-02],
                        [  5.49621582e-02,   5.56945801e-02],
                        [  4.97131348e-02,   5.33752441e-02],
                        [  5.34667969e-02,   5.89904785e-02],
                        [  5.71594238e-02,   6.16760254e-02],
                        [  5.88073730e-02,   5.89599609e-02],
                        [  6.32019043e-02,   5.71289062e-02],
                        [  7.45849609e-02,   6.31103516e-02],
                        [  9.08203125e-02,   7.69958496e-02],
                        [  1.04888916e-01,   9.27734375e-02],
                        [  1.12274170e-01,   1.05041504e-01],
                        [  1.14837646e-01,   1.13464355e-01],
                        [  1.17767334e-01,   1.20880127e-01],
                        [  1.23840332e-01,   1.28540039e-01],
                        [  1.27655029e-01,   1.31134033e-01],
                        [  1.13494873e-01,   1.14440918e-01],
                        [  6.40869141e-02,   6.33239746e-02],
                        [ -2.42919922e-02,  -2.44445801e-02],
                        [ -1.34765625e-01,  -1.32232666e-01],
                        [ -2.35412598e-01,  -2.29827881e-01],
                        [ -2.91992188e-01,  -2.85308838e-01],
                        [ -2.87139893e-01,  -2.82653809e-01],
                        [ -2.36450195e-01,  -2.36938477e-01],
                        [ -1.79656982e-01,  -1.85607910e-01],
                        [ -1.46087646e-01,  -1.55364990e-01],
                        [ -1.32171631e-01,  -1.41052246e-01],
                        [ -1.17370605e-01,  -1.22406006e-01],
                        [ -9.33227539e-02,  -9.27734375e-02],
                        [ -6.79016113e-02,  -6.21032715e-02],
                        [ -4.91027832e-02,  -4.00390625e-02],
                        [ -3.77502441e-02,  -2.79541016e-02],
                        [ -3.10974121e-02,  -2.27966309e-02],
                        [ -2.50549316e-02,  -1.95312500e-02],
                        [ -1.62353516e-02,  -1.36413574e-02],
                        [ -7.14111328e-03,  -6.65283203e-03],
                        [ -5.00488281e-03,  -5.21850586e-03],
                        [ -1.33056641e-02,  -1.30310059e-02],
                        [ -2.93884277e-02,  -2.84729004e-02],
                        [ -4.84313965e-02,  -4.79736328e-02],
                        [ -6.39953613e-02,  -6.56433105e-02],
                        [ -6.64672852e-02,  -7.13500977e-02],
                        [ -4.94689941e-02,  -5.71594238e-02],
                        [ -1.53198242e-02,  -2.40478516e-02],
                        [  3.18298340e-02,   2.42004395e-02],
                        [  9.19189453e-02,   8.65478516e-02],
                        [  1.57104492e-01,   1.53778076e-01],
                        [  2.03277588e-01,   2.00958252e-01],
                        [  2.08679199e-01,   2.06817627e-01],
                        [  1.79748535e-01,   1.78985596e-01],
                        [  1.45751953e-01,   1.47583008e-01],
                        [  1.27716064e-01,   1.33178711e-01],
                        [  1.20971680e-01,   1.29760742e-01],
                        [  1.09893799e-01,   1.20208740e-01],
                        [  9.06372070e-02,   1.00128174e-01],
                        [  7.37609863e-02,   8.06884766e-02],
                        [  6.73522949e-02,   7.08007812e-02],
                        [  6.53991699e-02,   6.50939941e-02],
                        [  5.56945801e-02,   5.16052246e-02],
                        [  3.47595215e-02,   2.71301270e-02],
                        [  1.12304688e-02,   1.06811523e-03],
                        [ -3.90625000e-03,  -1.44653320e-02],
                        [ -7.41577148e-03,  -1.57470703e-02],
                        [ -4.36401367e-03,  -8.54492188e-03],
                        [ -1.22070312e-04,   1.22070312e-04],
                        [  5.27954102e-03,   8.75854492e-03],
                        [  1.28173828e-02,   1.79138184e-02],
                        [  1.94702148e-02,   2.52075195e-02],
                        [  2.16674805e-02,   2.78625488e-02],
                        [  2.09960938e-02,   2.74963379e-02],
                        [  2.27355957e-02,   2.85644531e-02],
                        [  3.16467285e-02,   3.49731445e-02],
                        [  4.90417480e-02,   4.81567383e-02],
                        [  7.08923340e-02,   6.57348633e-02],
                        [  9.05151367e-02,   8.29467773e-02],
                        [  1.02935791e-01,   9.59167480e-02],
                        [  1.04553223e-01,   1.00433350e-01],
                        [  8.91723633e-02,   8.86230469e-02],
                        [  4.79431152e-02,   4.99572754e-02],
                        [ -2.37426758e-02,  -2.07519531e-02],
                        [ -1.14135742e-01,  -1.11114502e-01],
                        [ -1.91192627e-01,  -1.88079834e-01],
                        [ -2.22259521e-01,  -2.18444824e-01],
                        [ -2.02514648e-01,  -1.97601318e-01],
                        [ -1.57653809e-01,  -1.51916504e-01],
                        [ -1.17980957e-01,  -1.12243652e-01],
                        [ -9.55200195e-02,  -9.09118652e-02],
                        [ -8.41979980e-02,  -8.17565918e-02],
                        [ -7.36694336e-02,  -7.42797852e-02],
                        [ -6.04553223e-02,  -6.46057129e-02],
                        [ -4.94079590e-02,  -5.69152832e-02],
                        [ -4.66308594e-02,  -5.65185547e-02],
                        [ -5.04150391e-02,  -6.09436035e-02],
                        [ -5.09948730e-02,  -6.03332520e-02],
                        [ -4.23889160e-02,  -4.91027832e-02],
                        [ -3.03039551e-02,  -3.39050293e-02],
                        [ -2.38342285e-02,  -2.47192383e-02],
                        [ -2.37426758e-02,  -2.29187012e-02],
                        [ -2.58178711e-02,  -2.42919922e-02],
                        [ -2.99377441e-02,  -2.85949707e-02],
                        [ -3.96423340e-02,  -3.86962891e-02],
                        [ -5.52368164e-02,  -5.43823242e-02],
                        [ -7.35168457e-02,  -7.18383789e-02],
                        [ -9.03015137e-02,  -8.68835449e-02],
                        [ -9.92126465e-02,  -9.34753418e-02],
                        [ -8.99658203e-02,  -8.24279785e-02],
                        [ -5.40466309e-02,  -4.62036133e-02],
                        [  5.85937500e-03,   1.21459961e-02],
                        [  7.17773438e-02,   7.51953125e-02],
                        [  1.18621826e-01,   1.18957520e-01],
                        [  1.31256104e-01,   1.29486084e-01],
                        [  1.14807129e-01,   1.12365723e-01],
                        [  8.71582031e-02,   8.52661133e-02],
                        [  6.52465820e-02,   6.46362305e-02],
                        [  5.77087402e-02,   5.88684082e-02],
                        [  6.22863770e-02,   6.53991699e-02],
                        [  6.77795410e-02,   7.26318359e-02],
                        [  6.68640137e-02,   7.22656250e-02],
                        [  6.64062500e-02,   7.01599121e-02],
                        [  7.73925781e-02,   7.72094727e-02],
                        [  9.70764160e-02,   9.17968750e-02],
                        [  1.11114502e-01,   1.01837158e-01],
                        [  1.12976074e-01,   1.02600098e-01],
                        [  1.11877441e-01,   1.03424072e-01],
                        [  1.20697021e-01,   1.15386963e-01],
                        [  1.40655518e-01,   1.37237549e-01],
                        [  1.55853271e-01,   1.51885986e-01],
                        [  1.42547607e-01,   1.36657715e-01],
                        [  8.77990723e-02,   8.10852051e-02],
                        [ -8.54492188e-04,  -5.31005859e-03],
                        [ -1.05468750e-01,  -1.04644775e-01],
                        [ -2.05780029e-01,  -1.98913574e-01],
                        [ -2.75238037e-01,  -2.64465332e-01],
                        [ -2.89001465e-01,  -2.77893066e-01],
                        [ -2.48168945e-01,  -2.39746094e-01],
                        [ -1.85058594e-01,  -1.80389404e-01],
                        [ -1.36077881e-01,  -1.34552002e-01],
                        [ -1.15600586e-01,  -1.15966797e-01],
                        [ -1.14349365e-01,  -1.15722656e-01],
                        [ -1.14044189e-01,  -1.15997314e-01],
                        [ -1.03424072e-01,  -1.05499268e-01],
                        [ -8.40454102e-02,  -8.54492188e-02],
                        [ -6.28356934e-02,  -6.27746582e-02],
                        [ -4.33349609e-02,  -4.16870117e-02],
                        [ -2.76184082e-02,  -2.49328613e-02],
                        [ -2.02941895e-02,  -1.73034668e-02],
                        [ -2.35900879e-02,  -2.07214355e-02],
                        [ -3.21960449e-02,  -2.93884277e-02],
                        [ -3.92761230e-02,  -3.66210938e-02],
                        [ -4.51660156e-02,  -4.34265137e-02],
                        [ -5.31616211e-02,  -5.37719727e-02],
                        [ -5.90820312e-02,  -6.29272461e-02],
                        [ -5.24291992e-02,  -5.89904785e-02],
                        [ -2.86865234e-02,  -3.57971191e-02],
                        [  7.20214844e-03,   2.16674805e-03],
                        [  5.01708984e-02,   4.85534668e-02],
                        [  1.00372314e-01,   1.01379395e-01],
                        [  1.54144287e-01,   1.55395508e-01],
                        [  1.94213867e-01,   1.93450928e-01],
                        [  2.00897217e-01,   1.97448730e-01],
                        [  1.75201416e-01,   1.70379639e-01],
                        [  1.41662598e-01,   1.37634277e-01],
                        [  1.23138428e-01,   1.21704102e-01],
                        [  1.20544434e-01,   1.22192383e-01],
                        [  1.19293213e-01,   1.23291016e-01],
                        [  1.08001709e-01,   1.13067627e-01],
                        [  8.81652832e-02,   9.29870605e-02],
                        [  6.93969727e-02,   7.30895996e-02],
                        [  5.66406250e-02,   5.88378906e-02],
                        [  4.48608398e-02,   4.58374023e-02],
                        [  2.95104980e-02,   3.01513672e-02],
                        [  1.35192871e-02,   1.48315430e-02],
                        [ -4.88281250e-04,   2.04467773e-03],
                        [ -1.28479004e-02,  -9.76562500e-03],
                        [ -1.91345215e-02,  -1.72729492e-02],
                        [ -1.37329102e-02,  -1.49230957e-02],
                        [ -1.55639648e-03,  -6.50024414e-03],
                        [  8.05664062e-03,   5.49316406e-04],
                        [  1.51062012e-02,   7.59887695e-03],
                        [  2.29187012e-02,   1.80053711e-02],
                        [  2.53601074e-02,   2.42004395e-02],
                        [  1.57775879e-02,   1.76086426e-02],
                        [  2.96020508e-03,   5.95092773e-03],
                        [  3.60107422e-03,   6.04248047e-03],
                        [  2.23693848e-02,   2.36511230e-02],
                        [  5.00183105e-02,   5.06286621e-02],
                        [  7.64770508e-02,   7.73925781e-02],
                        [  9.64355469e-02,   9.85412598e-02],
                        [  1.05773926e-01,   1.09283447e-01],
                        [  9.84191895e-02,   1.02996826e-01],
                        [  6.44836426e-02,   6.92443848e-02],
                        [ -4.60815430e-03,  -8.54492188e-04],
                        [ -9.89685059e-02,  -9.74426270e-02],
                        [ -1.82800293e-01,  -1.84143066e-01],
                        [ -2.18811035e-01,  -2.22534180e-01],
                        [ -2.00927734e-01,  -2.05352783e-01],
                        [ -1.55395508e-01,  -1.58538818e-01],
                        [ -1.14074707e-01,  -1.14746094e-01],
                        [ -9.27734375e-02,  -9.16137695e-02],
                        [ -8.79821777e-02,  -8.70666504e-02],
                        [ -8.46557617e-02,  -8.61206055e-02],
                        [ -7.13195801e-02,  -7.58361816e-02],
                        [ -5.22460938e-02,  -5.85632324e-02],
                        [ -4.09545898e-02,  -4.67834473e-02],
                        [ -4.16564941e-02,  -4.50744629e-02],
                        [ -4.56848145e-02,  -4.62036133e-02],
                        [ -4.66308594e-02,  -4.51049805e-02],
                        [ -4.77600098e-02,  -4.54406738e-02],
                        [ -5.14526367e-02,  -4.90417480e-02],
                        [ -5.27343750e-02,  -5.02929688e-02],
                        [ -4.88891602e-02,  -4.63562012e-02],
                        [ -4.58374023e-02,  -4.35485840e-02],
                        [ -5.02319336e-02,  -4.88586426e-02],
                        [ -6.23168945e-02,  -6.22863770e-02],
                        [ -7.86132812e-02,  -7.97729492e-02],
                        [ -9.37500000e-02,  -9.54589844e-02],
                        [ -9.88159180e-02,  -1.00433350e-01],
                        [ -8.44726562e-02,  -8.56018066e-02],
                        [ -4.82177734e-02,  -4.84924316e-02],
                        [  2.86865234e-03,   4.15039062e-03],
                        [  5.53894043e-02,   5.92041016e-02],
                        [  9.49401855e-02,   1.01745605e-01],
                        [  1.12548828e-01,   1.21490479e-01],
                        [  1.10137939e-01,   1.18804932e-01],
                        [  9.94262695e-02,   1.04888916e-01],
                        [  9.26513672e-02,   9.33227539e-02],
                        [  9.39025879e-02,   9.03930664e-02],
                        [  9.85412598e-02,   9.32617188e-02],
                        [  9.98229980e-02,   9.51843262e-02],
                        [  9.68933105e-02,   9.38110352e-02],
                        [  9.70153809e-02,   9.43603516e-02],
                        [  1.06323242e-01,   1.02233887e-01],
                        [  1.20178223e-01,   1.13708496e-01],
                        [  1.27807617e-01,   1.19873047e-01],
                        [  1.26312256e-01,   1.19232178e-01],
                        [  1.23596191e-01,   1.19567871e-01],
                        [  1.26312256e-01,   1.26159668e-01],
                        [  1.27807617e-01,   1.30615234e-01],
                        [  1.10015869e-01,   1.14044189e-01],
                        [  6.11572266e-02,   6.47583008e-02],
                        [ -1.13525391e-02,  -9.03320312e-03],
                        [ -9.09118652e-02,  -9.00573730e-02],
                        [ -1.67785645e-01,  -1.68212891e-01],
                        [ -2.33886719e-01,  -2.35290527e-01],
                        [ -2.69470215e-01,  -2.71240234e-01],
                        [ -2.55279541e-01,  -2.56561279e-01],
                        [ -2.02087402e-01,  -2.01812744e-01],
                        [ -1.49383545e-01,  -1.46942139e-01],
                        [ -1.25701904e-01,  -1.21246338e-01],
                        [ -1.22619629e-01,  -1.17095947e-01],
                        [ -1.16760254e-01,  -1.11480713e-01],
                        [ -1.02050781e-01,  -9.80529785e-02],
                        [ -8.79211426e-02,  -8.55407715e-02],
                        [ -7.88879395e-02,  -7.77587891e-02],
                        [ -6.91223145e-02,  -6.85119629e-02],
                        [ -5.26123047e-02,  -5.19714355e-02],
                        [ -3.13110352e-02,  -3.03955078e-02],
                        [ -1.39770508e-02,  -1.29699707e-02],
                        [ -8.69750977e-03,  -8.11767578e-03],
                        [ -1.53808594e-02,  -1.59912109e-02],
                        [ -2.65197754e-02,  -2.89306641e-02],
                        [ -3.45764160e-02,  -3.90319824e-02],
                        [ -3.56750488e-02,  -4.18701172e-02],
                        [ -2.71301270e-02,  -3.40576172e-02],
                        [ -5.70678711e-03,  -1.21459961e-02],
                        [  3.00598145e-02,   2.51770020e-02],
                        [  7.87353516e-02,   7.60498047e-02],
                        [  1.34368896e-01,   1.33941650e-01],
                        [  1.83898926e-01,   1.85455322e-01],
                        [  2.10906982e-01,   2.13836670e-01],
                        [  2.06298828e-01,   2.09930420e-01],
                        [  1.76422119e-01,   1.80053711e-01],
                        [  1.40228271e-01,   1.43280029e-01],
                        [  1.15783691e-01,   1.18164062e-01],
                        [  1.06536865e-01,   1.08459473e-01],
                        [  1.01806641e-01,   1.03698730e-01],
                        [  9.21936035e-02,   9.40246582e-02],
                        [  7.92846680e-02,   8.05053711e-02],
                        [  6.94580078e-02,   6.91528320e-02],
                        [  6.27746582e-02,   6.02722168e-02],
                        [  5.28869629e-02,   4.86450195e-02],
                        [  3.58581543e-02,   3.13415527e-02],
                        [  1.38854980e-02,   1.08032227e-02],
                        [ -8.81958008e-03,  -9.33837891e-03],
                        [ -2.81066895e-02,  -2.61535645e-02],
                        [ -3.91540527e-02,  -3.57055664e-02],
                        [ -3.87573242e-02,  -3.49731445e-02],
                        [ -2.80456543e-02,  -2.44750977e-02],
                        [ -1.11694336e-02,  -7.87353516e-03],
                        [  6.04248047e-03,   8.97216797e-03],
                        [  1.85546875e-02,   2.05383301e-02],
                        [  2.55126953e-02,   2.56347656e-02],
                        [  2.87475586e-02,   2.63671875e-02],
                        [  2.96630859e-02,   2.49938965e-02],
                        [  3.07312012e-02,   2.48107910e-02],
                        [  3.52783203e-02,   2.96325684e-02],
                        [  4.37316895e-02,   3.94897461e-02],
                        [  5.41687012e-02,   5.19104004e-02],
                        [  6.75354004e-02,   6.73828125e-02],
                        [  8.55102539e-02,   8.73718262e-02],
                        [  1.02722168e-01,   1.06475830e-01],
                        [  1.04309082e-01,   1.09436035e-01],
                        [  7.31201172e-02,   7.86437988e-02],
                        [  2.80761719e-03,   7.47680664e-03],
                        [ -9.07897949e-02,  -8.78906250e-02],
                        [ -1.71630859e-01,  -1.70654297e-01],
                        [ -2.05139160e-01,  -2.05566406e-01],
                        [ -1.85760498e-01,  -1.86737061e-01],
                        [ -1.41571045e-01,  -1.42791748e-01],
                        [ -1.07971191e-01,  -1.09680176e-01],
                        [ -9.70764160e-02,  -9.98229980e-02],
                        [ -9.47570801e-02,  -9.86633301e-02],
                        [ -8.32214355e-02,  -8.76770020e-02],
                        [ -6.24389648e-02,  -6.63146973e-02],
                        [ -4.73022461e-02,  -4.97436523e-02],
                        [ -4.65393066e-02,  -4.73632812e-02],
                        [ -5.29174805e-02,  -5.26733398e-02],
                        [ -5.59387207e-02,  -5.54809570e-02],
                        [ -5.30700684e-02,  -5.29174805e-02],
                        [ -4.64477539e-02,  -4.65393066e-02],
                        [ -4.01000977e-02,  -3.98559570e-02],
                        [ -3.99780273e-02,  -3.87268066e-02],
                        [ -4.77600098e-02,  -4.51049805e-02],
                        [ -5.86853027e-02,  -5.46875000e-02],
                        [ -7.08923340e-02,  -6.62536621e-02],
                        [ -8.64257812e-02,  -8.21228027e-02],
                        [ -9.91516113e-02,  -9.64355469e-02],
                        [ -9.63745117e-02,  -9.61303711e-02],
                        [ -7.39440918e-02,  -7.62939453e-02],
                        [ -3.77197266e-02,  -4.18090820e-02],
                        [  8.88061523e-03,   4.60815430e-03],
                        [  6.43005371e-02,   6.15844727e-02],
                        [  1.16302490e-01,   1.16088867e-01],
                        [  1.44226074e-01,   1.46240234e-01],
                        [  1.39556885e-01,   1.42547607e-01],
                        [  1.15997314e-01,   1.18499756e-01],
                        [  9.33227539e-02,   9.44519043e-02],
                        [  7.94677734e-02,   7.94067383e-02],
                        [  7.35168457e-02,   7.31811523e-02],
                        [  7.48901367e-02,   7.53173828e-02],
                        [  8.23364258e-02,   8.38317871e-02],
                        [  9.10644531e-02,   9.30786133e-02],
                        [  9.85412598e-02,   9.98535156e-02],
                        [  1.08306885e-01,   1.07696533e-01],
                        [  1.24755859e-01,   1.21673584e-01],
                        [  1.45263672e-01,   1.40167236e-01],
                        [  1.60858154e-01,   1.55059814e-01],
                        [  1.64276123e-01,   1.59484863e-01],
                        [  1.53564453e-01,   1.51031494e-01],
                        [  1.25762939e-01,   1.25793457e-01],
                        [  7.36389160e-02,   7.54699707e-02],
                        [ -6.34765625e-03,  -4.08935547e-03],
                        [ -1.05224609e-01,  -1.03759766e-01],
                        [ -2.03460693e-01,  -2.03186035e-01],
                        [ -2.77221680e-01,  -2.77740479e-01],
                        [ -3.04351807e-01,  -3.04931641e-01],
                        [ -2.77404785e-01,  -2.77526855e-01],
                        [ -2.17376709e-01,  -2.17041016e-01],
                        [ -1.62109375e-01,  -1.61529541e-01],
                        [ -1.31195068e-01,  -1.30340576e-01],
                        [ -1.14715576e-01,  -1.13250732e-01],
                        [ -1.00036621e-01,  -9.74731445e-02],
                        [ -8.99963379e-02,  -8.63342285e-02],
                        [ -8.83789062e-02,  -8.41674805e-02],
                        [ -8.68835449e-02,  -8.31298828e-02],
                        [ -7.71179199e-02,  -7.45544434e-02],
                        [ -6.12792969e-02,  -6.00280762e-02],
                        [ -4.43420410e-02,  -4.40979004e-02],
                        [ -2.68554688e-02,  -2.72827148e-02],
                        [ -1.07727051e-02,  -1.19018555e-02],
                        [ -2.89916992e-03,  -5.09643555e-03],
                        [ -6.71386719e-03,  -1.01928711e-02],
                        [ -1.69677734e-02,  -2.14233398e-02],
                        [ -2.43225098e-02,  -2.89611816e-02],
                        [ -1.90734863e-02,  -2.29797363e-02],
                        [  6.83593750e-03,   4.02832031e-03],
                        [  5.32531738e-02,   5.15441895e-02],
                        [  1.09344482e-01,   1.08489990e-01],
                        [  1.60583496e-01,   1.60644531e-01],
                        [  1.94305420e-01,   1.95526123e-01],
                        [  2.01385498e-01,   2.03979492e-01],
                        [  1.84631348e-01,   1.88201904e-01],
                        [  1.61682129e-01,   1.65283203e-01],
                        [  1.45904541e-01,   1.48468018e-01],
                        [  1.30554199e-01,   1.31469727e-01],
                        [  1.05865479e-01,   1.05468750e-01],
                        [  8.04443359e-02,   7.95288086e-02],
                        [  6.75354004e-02,   6.68640137e-02],
                        [  6.35986328e-02,   6.35375977e-02],
                        [  5.76782227e-02,   5.80139160e-02],
                        [  4.80957031e-02,   4.84008789e-02],
                        [  3.79638672e-02,   3.79333496e-02],
                        [  2.60620117e-02,   2.56347656e-02],
                        [  1.07727051e-02,   9.97924805e-03],
                        [ -5.00488281e-03,  -6.25610352e-03],
                        [ -1.64489746e-02,  -1.81579590e-02],
                        [ -2.10571289e-02,  -2.29187012e-02],
                        [ -1.97753906e-02,  -2.12097168e-02],
                        [ -1.39770508e-02,  -1.41601562e-02],
                        [ -3.47900391e-03,  -1.95312500e-03],
                        [  8.17871094e-03,   1.11999512e-02],
                        [  1.34582520e-02,   1.70898438e-02],
                        [  1.22070312e-02,   1.52282715e-02],
                        [  1.47094727e-02,   1.62658691e-02],
                        [  2.53295898e-02,   2.51770020e-02],
                        [  3.41491699e-02,   3.27148438e-02],
                        [  3.40576172e-02,   3.19519043e-02],
                        [  3.32946777e-02,   3.11279297e-02],
                        [  4.21447754e-02,   4.02526855e-02],
                        [  5.84716797e-02,   5.70373535e-02],
                        [  7.40661621e-02,   7.30590820e-02],
                        [  8.42285156e-02,   8.36486816e-02],
                        [  8.61206055e-02,   8.59985352e-02],
                        [  7.43713379e-02,   7.47375488e-02],
                        [  4.07714844e-02,   4.17480469e-02],
                        [ -2.04772949e-02,  -1.88293457e-02],
                        [ -1.00616455e-01,  -9.83581543e-02],
                        [ -1.70806885e-01,  -1.68334961e-01],
                        [ -1.99188232e-01,  -1.97082520e-01],
                        [ -1.77124023e-01,  -1.76086426e-01],
                        [ -1.27258301e-01,  -1.27624512e-01],
                        [ -8.54492188e-02,  -8.70361328e-02],
                        [ -7.13806152e-02,  -7.36083984e-02],
                        [ -7.47070312e-02,  -7.68737793e-02],
                        [ -7.39440918e-02,  -7.55920410e-02],
                        [ -6.57043457e-02,  -6.67114258e-02],
                        [ -6.43615723e-02,  -6.48498535e-02],
                        [ -7.66601562e-02,  -7.68737793e-02],
                        [ -9.29870605e-02,  -9.31091309e-02],
                        [ -1.02844238e-01,  -1.03057861e-01],
                        [ -1.02874756e-01,  -1.03393555e-01],
                        [ -9.01489258e-02,  -9.10339355e-02],
                        [ -6.60400391e-02,  -6.71691895e-02],
                        [ -4.51354980e-02,  -4.60510254e-02],
                        [ -4.23889160e-02,  -4.25415039e-02],
                        [ -5.44738770e-02,  -5.34973145e-02],
                        [ -6.69860840e-02,  -6.50634766e-02],
                        [ -7.30895996e-02,  -7.07397461e-02],
                        [ -7.24182129e-02,  -7.01599121e-02],
                        [ -6.12487793e-02,  -5.93261719e-02],
                        [ -3.52783203e-02,  -3.35998535e-02],
                        [  2.04467773e-03,   3.66210938e-03],
                        [  4.15039062e-02,   4.30297852e-02],
                        [  7.62329102e-02,   7.73315430e-02],
                        [  1.02813721e-01,   1.03027344e-01],
                        [  1.16394043e-01,   1.15478516e-01],
                        [  1.12060547e-01,   1.10260010e-01],
                        [  9.41772461e-02,   9.18579102e-02],
                        [  7.74536133e-02,   7.50122070e-02],
                        [  7.46154785e-02,   7.22351074e-02],
                        [  8.50524902e-02,   8.28857422e-02],
                        [  9.88159180e-02,   9.71374512e-02],
                        [  1.08001709e-01,   1.07238770e-01],
                        [  1.13128662e-01,   1.13616943e-01],
                        [  1.21368408e-01,   1.23046875e-01],
                        [  1.39984131e-01,   1.42364502e-01],
                        [  1.67755127e-01,   1.70074463e-01],
                        [  1.91345215e-01,   1.92932129e-01],
                        [  1.94396973e-01,   1.95068359e-01],
                        [  1.70410156e-01,   1.70288086e-01],
                        [  1.22467041e-01,   1.21856689e-01],
                        [  5.28259277e-02,   5.18188477e-02],
                        [ -3.98254395e-02,  -4.11987305e-02],
                        [ -1.49047852e-01,  -1.50726318e-01],
                        [ -2.51556396e-01,  -2.53234863e-01],
                        [ -3.15551758e-01,  -3.16802979e-01],
                        [ -3.22265625e-01,  -3.22784424e-01],
                        [ -2.79266357e-01,  -2.79113770e-01],
                        [ -2.15087891e-01,  -2.14660645e-01],
                        [ -1.59973145e-01,  -1.59637451e-01],
                        [ -1.26190186e-01,  -1.26007080e-01],
                        [ -1.04858398e-01,  -1.04461670e-01],
                        [ -8.37402344e-02,  -8.26721191e-02],
                        [ -6.39038086e-02,  -6.19812012e-02],
                        [ -5.37414551e-02,  -5.12084961e-02],
                        [ -5.30700684e-02,  -5.05676270e-02],
                        [ -5.33142090e-02,  -5.14526367e-02],
                        [ -4.91943359e-02,  -4.82482910e-02],
                        [ -4.24194336e-02,  -4.23278809e-02],
                        [ -3.63159180e-02,  -3.68041992e-02],
                        [ -3.27453613e-02,  -3.35998535e-02],
                        [ -3.32336426e-02,  -3.44543457e-02],
                        [ -3.69567871e-02,  -3.86047363e-02],
                        [ -3.65600586e-02,  -3.86047363e-02],
                        [ -1.92565918e-02,  -2.15759277e-02],
                        [  2.29797363e-02,   2.06909180e-02],
                        [  8.34045410e-02,   8.14819336e-02],
                        [  1.43432617e-01,   1.42150879e-01],
                        [  1.87438965e-01,   1.87072754e-01],
                        [  2.10754395e-01,   2.11425781e-01],
                        [  2.13592529e-01,   2.15270996e-01],
                        [  1.97296143e-01,   1.99768066e-01],
                        [  1.69097900e-01,   1.71844482e-01],
                        [  1.42181396e-01,   1.44622803e-01],
                        [  1.25213623e-01,   1.26861572e-01],
                        [  1.15295410e-01,   1.15905762e-01],
                        [  1.03759766e-01,   1.03363037e-01],
                        [  8.70361328e-02,   8.58764648e-02],
                        [  6.96105957e-02,   6.80236816e-02],
                        [  5.57861328e-02,   5.40466309e-02],
                        [  4.31518555e-02,   4.15344238e-02],
                        [  2.93884277e-02,   2.81677246e-02],
                        [  1.95922852e-02,   1.88903809e-02],
                        [  1.75170898e-02,   1.73034668e-02],
                        [  1.60522461e-02,   1.62963867e-02],
                        [  7.72094727e-03,   8.20922852e-03],
                        [ -3.75366211e-03,  -3.11279297e-03],
                        [ -1.19018555e-02,  -1.11999512e-02],
                        [ -1.80664062e-02,  -1.73339844e-02],
                        [ -2.36206055e-02,  -2.29187012e-02],
                        [ -2.38342285e-02,  -2.31323242e-02],
                        [ -1.65405273e-02,  -1.58996582e-02],
                        [ -7.90405273e-03,  -7.35473633e-03],
                        [ -3.87573242e-03,  -3.38745117e-03],
                        [ -2.07519531e-03,  -1.73950195e-03],
                        [  3.38745117e-03,   3.44848633e-03],
                        [  1.35498047e-02,   1.32141113e-02],
                        [  2.52685547e-02,   2.44750977e-02],
                        [  3.81774902e-02,   3.71093750e-02],
                        [  5.54504395e-02,   5.44128418e-02],
                        [  7.59582520e-02,   7.52563477e-02],
                        [  9.25598145e-02,   9.22851562e-02],
                        [  1.01196289e-01,   1.01257324e-01],
                        [  1.05224609e-01,   1.05377197e-01],
                        [  1.04980469e-01,   1.05133057e-01],
                        [  8.88977051e-02,   8.90808105e-02],
                        [  4.22973633e-02,   4.26025391e-02],
                        [ -3.46069336e-02,  -3.40881348e-02],
                        [ -1.20635986e-01,  -1.20086670e-01],
                        [ -1.85028076e-01,  -1.84661865e-01],
                        [ -2.05169678e-01,  -2.05139160e-01],
                        [ -1.80694580e-01,  -1.80938721e-01],
                        [ -1.34155273e-01,  -1.34490967e-01],
                        [ -9.52453613e-02,  -9.54895020e-02],
                        [ -7.89184570e-02,  -7.89489746e-02],
                        [ -7.74230957e-02,  -7.73925781e-02],
                        [ -7.51953125e-02,  -7.52563477e-02],
                        [ -6.95190430e-02,  -6.97937012e-02],
                        [ -7.06176758e-02,  -7.09838867e-02],
                        [ -8.31604004e-02,  -8.33740234e-02],
                        [ -9.83886719e-02,  -9.83276367e-02],
                        [ -1.04339600e-01,  -1.03973389e-01],
                        [ -9.54284668e-02,  -9.49707031e-02],
                        [ -7.51037598e-02,  -7.47680664e-02],
                        [ -5.51147461e-02,  -5.50842285e-02],
                        [ -4.76989746e-02,  -4.80041504e-02],
                        [ -5.34973145e-02,  -5.40466309e-02],
                        [ -6.13098145e-02,  -6.19506836e-02],
                        [ -6.14929199e-02,  -6.20422363e-02],
                        [ -5.51452637e-02,  -5.54199219e-02],
                        [ -4.71496582e-02,  -4.70581055e-02],
                        [ -3.46679688e-02,  -3.42102051e-02],
                        [ -9.42993164e-03,  -8.69750977e-03],
                        [  2.88696289e-02,   2.96325684e-02],
                        [  6.89697266e-02,   6.96105957e-02],
                        [  9.94873047e-02,   9.98840332e-02],
                        [  1.16729736e-01,   1.16943359e-01],
                        [  1.21063232e-01,   1.21215820e-01],
                        [  1.13677979e-01,   1.13891602e-01],
                        [  1.00158691e-01,   1.00433350e-01],
                        [  9.02709961e-02,   9.04846191e-02],
                        [  9.00573730e-02,   8.99353027e-02],
                        [  9.72290039e-02,   9.67102051e-02],
                        [  1.06445312e-01,   1.05560303e-01],
                        [  1.15905762e-01,   1.14898682e-01],
                        [  1.28814697e-01,   1.27899170e-01],
                        [  1.49047852e-01,   1.48468018e-01],
                        [  1.73522949e-01,   1.73339844e-01],
                        [  1.90002441e-01,   1.90155029e-01],
                        [  1.85852051e-01,   1.86187744e-01],
                        [  1.55090332e-01,   1.55426025e-01],
                        [  9.40246582e-02,   9.42382812e-02],
                        [  1.43432617e-03,   1.52587891e-03],
                        [ -1.11450195e-01,  -1.11419678e-01],
                        [ -2.19024658e-01,  -2.18963623e-01],
                        [ -2.93792725e-01,  -2.93609619e-01],
                        [ -3.15643311e-01,  -3.15368652e-01],
                        [ -2.78564453e-01,  -2.78259277e-01],
                        [ -2.04223633e-01,  -2.04040527e-01],
                        [ -1.39038086e-01,  -1.38977051e-01],
                        [ -1.14654541e-01,  -1.14685059e-01],
                        [ -1.17065430e-01,  -1.17156982e-01],
                        [ -1.13159180e-01,  -1.13189697e-01],
                        [ -9.52758789e-02,  -9.52148438e-02],
                        [ -7.93762207e-02,  -7.92236328e-02],
                        [ -7.42797852e-02,  -7.41271973e-02],
                        [ -7.35168457e-02,  -7.34252930e-02],
                        [ -6.79016113e-02,  -6.78710938e-02],
                        [ -5.27038574e-02,  -5.27648926e-02],
                        [ -3.08227539e-02,  -3.09448242e-02],
                        [ -1.37329102e-02,  -1.38854980e-02],
                        [ -1.16577148e-02,  -1.17492676e-02],
                        [ -2.01110840e-02,  -2.01416016e-02],
                        [ -2.24609375e-02,  -2.24304199e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  2.96325684e-02,   2.95104980e-02],
                        [  7.79724121e-02,   7.76977539e-02],
                        [  1.30523682e-01,   1.30157471e-01],
                        [  1.76361084e-01,   1.76025391e-01],
                        [  2.01324463e-01,   2.01202393e-01],
                        [  1.95373535e-01,   1.95526123e-01],
                        [  1.64886475e-01,   1.65222168e-01],
                        [  1.32537842e-01,   1.32965088e-01],
                        [  1.16241455e-01,   1.16607666e-01],
                        [  1.12915039e-01,   1.13159180e-01],
                        [  1.09741211e-01,   1.09832764e-01],
                        [  1.01776123e-01,   1.01806641e-01],
                        [  9.11254883e-02,   9.11254883e-02],
                        [  7.91931152e-02,   7.91625977e-02],
                        [  6.70776367e-02,   6.69860840e-02],
                        [  5.51452637e-02,   5.50231934e-02],
                        [  4.05273438e-02,   4.03747559e-02],
                        [  2.16064453e-02,   2.14843750e-02],
                        [  4.05883789e-03,   3.96728516e-03],
                        [ -5.03540039e-03,  -5.12695312e-03],
                        [ -6.98852539e-03,  -7.08007812e-03],
                        [ -9.21630859e-03,  -9.30786133e-03],
                        [ -1.58081055e-02,  -1.58386230e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.40576172e-02,  -3.39965820e-02],
                        [ -3.54309082e-02,  -3.53393555e-02],
                        [ -2.57873535e-02,  -2.56958008e-02],
                        [ -1.11694336e-02,  -1.11389160e-02],
                        [ -1.70898438e-03,  -1.67846680e-03],
                        [  3.66210938e-04,   3.96728516e-04],
                        [  2.44140625e-04,   3.35693359e-04],
                        [  2.96020508e-03,   3.05175781e-03],
                        [  8.57543945e-03,   8.66699219e-03],
                        [  1.28173828e-02,   1.28479004e-02],
                        [  1.48315430e-02,   1.48010254e-02],
                        [  2.26745605e-02,   2.26135254e-02],
                        [  4.19311523e-02,   4.18701172e-02],
                        [  6.43615723e-02,   6.43310547e-02],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  8.93249512e-02,   8.93249512e-02],
                        [  9.48181152e-02,   9.48181152e-02],
                        [  8.67309570e-02,   8.67004395e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -7.70263672e-02,  -7.70263672e-02],
                        [ -1.47033691e-01,  -1.47064209e-01],
                        [ -1.90917969e-01,  -1.90948486e-01],
                        [ -1.94763184e-01,  -1.94793701e-01],
                        [ -1.68334961e-01,  -1.68365479e-01],
                        [ -1.36444092e-01,  -1.36474609e-01],
                        [ -1.15051270e-01,  -1.15051270e-01],
                        [ -1.03332520e-01,  -1.03302002e-01],
                        [ -9.46350098e-02,  -9.46044922e-02],
                        [ -8.58459473e-02,  -8.58154297e-02],
                        [ -7.80944824e-02,  -7.80639648e-02],
                        [ -7.51953125e-02,  -7.51953125e-02],
                        [ -7.83081055e-02,  -7.82775879e-02],
                        [ -7.97424316e-02,  -7.97119141e-02],
                        [ -7.05871582e-02,  -7.05566406e-02],
                        [ -5.44738770e-02,  -5.44433594e-02],
                        [ -4.44946289e-02,  -4.44641113e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -5.40466309e-02,  -5.40771484e-02],
                        [ -6.05163574e-02,  -6.05468750e-02],
                        [ -6.47277832e-02,  -6.47583008e-02],
                        [ -6.80847168e-02,  -6.81152344e-02],
                        [ -6.89392090e-02,  -6.89697266e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [  3.81469727e-03,   3.84521484e-03],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  1.10351562e-01,   1.10382080e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.27227783e-01,   1.27258301e-01],
                        [  1.28601074e-01,   1.28631592e-01],
                        [  1.21704102e-01,   1.21734619e-01],
                        [  1.13311768e-01,   1.13311768e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  1.21185303e-01,   1.21185303e-01],
                        [  1.42456055e-01,   1.42425537e-01],
                        [  1.65008545e-01,   1.65008545e-01],
                        [  1.76361084e-01,   1.76361084e-01],
                        [  1.69250488e-01,   1.69250488e-01],
                        [  1.37451172e-01,   1.37451172e-01],
                        [  7.23571777e-02,   7.23571777e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -1.43432617e-01,  -1.43432617e-01],
                        [ -2.48779297e-01,  -2.48779297e-01],
                        [ -3.10760498e-01,  -3.10760498e-01],
                        [ -3.07678223e-01,  -3.07678223e-01],
                        [ -2.47955322e-01,  -2.47955322e-01],
                        [ -1.73492432e-01,  -1.73492432e-01],
                        [ -1.27593994e-01,  -1.27593994e-01],
                        [ -1.18194580e-01,  -1.18194580e-01],
                        [ -1.21398926e-01,  -1.21398926e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -1.01867676e-01,  -1.01867676e-01],
                        [ -8.71276855e-02,  -8.71276855e-02],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.52343750e-01,   1.52343750e-01],
                        [  1.99554443e-01,   1.99554443e-01],
                        [  2.18292236e-01,   2.18292236e-01],
                        [  2.11059570e-01,   2.11059570e-01],
                        [  1.91467285e-01,   1.91467285e-01],
                        [  1.67999268e-01,   1.67999268e-01],
                        [  1.42456055e-01,   1.42456055e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  7.67822266e-02,   7.67822266e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  7.26318359e-03,   7.29370117e-03],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  3.90625000e-03,   3.90625000e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  9.30480957e-02,   9.30786133e-02],
                        [  1.06048584e-01,   1.06048584e-01],
                        [  1.09619141e-01,   1.09619141e-01],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -1.36016846e-01,  -1.36016846e-01],
                        [ -1.96075439e-01,  -1.96075439e-01],
                        [ -2.13714600e-01,  -2.13714600e-01],
                        [ -1.93237305e-01,  -1.93237305e-01],
                        [ -1.55303955e-01,  -1.55303955e-01],
                        [ -1.21032715e-01,  -1.21032715e-01],
                        [ -9.83886719e-02,  -9.83886719e-02],
                        [ -8.37097168e-02,  -8.37097168e-02],
                        [ -7.26013184e-02,  -7.26318359e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -7.01293945e-02,  -7.01293945e-02],
                        [ -7.52258301e-02,  -7.52258301e-02],
                        [ -7.67211914e-02,  -7.67211914e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -7.27539062e-02,  -7.27539062e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -7.19909668e-02,  -7.20214844e-02],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  1.05468750e-01,   1.05468750e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.21490479e-01,   1.21490479e-01],
                        [  1.25061035e-01,   1.25061035e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.48681641e-01,   1.48681641e-01],
                        [  1.67022705e-01,   1.67022705e-01],
                        [  1.81701660e-01,   1.81701660e-01],
                        [  1.87530518e-01,   1.87530518e-01],
                        [  1.78283691e-01,   1.78283691e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  6.69555664e-02,   6.69555664e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -1.56158447e-01,  -1.56158447e-01],
                        [ -2.53997803e-01,  -2.53997803e-01],
                        [ -3.11676025e-01,  -3.11676025e-01],
                        [ -3.14605713e-01,  -3.14605713e-01],
                        [ -2.65563965e-01,  -2.65563965e-01],
                        [ -1.92565918e-01,  -1.92565918e-01],
                        [ -1.32476807e-01,  -1.32476807e-01],
                        [ -1.02935791e-01,  -1.02935791e-01],
                        [ -9.49401855e-02,  -9.49401855e-02],
                        [ -9.11560059e-02,  -9.11560059e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -7.84301758e-02,  -7.84301758e-02],
                        [ -7.51037598e-02,  -7.51037598e-02],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -7.39746094e-02,  -7.39746094e-02],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -8.33129883e-02,  -8.33129883e-02],
                        [ -7.67517090e-02,  -7.67517090e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  7.61413574e-02,   7.61413574e-02],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  1.76147461e-01,   1.76147461e-01],
                        [  2.01599121e-01,   2.01599121e-01],
                        [  1.98577881e-01,   1.98577881e-01],
                        [  1.74011230e-01,   1.74011230e-01],
                        [  1.47705078e-01,   1.47705078e-01],
                        [  1.31500244e-01,   1.31500244e-01],
                        [  1.21459961e-01,   1.21429443e-01],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.05590820e-01,   1.05590820e-01],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  5.64575195e-03,   5.67626953e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  8.17565918e-02,   8.17260742e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -1.08245850e-01,  -1.08215332e-01],
                        [ -1.64733887e-01,  -1.64703369e-01],
                        [ -1.85882568e-01,  -1.85882568e-01],
                        [ -1.69464111e-01,  -1.69464111e-01],
                        [ -1.32598877e-01,  -1.32598877e-01],
                        [ -1.01989746e-01,  -1.01989746e-01],
                        [ -9.17663574e-02,  -9.17663574e-02],
                        [ -9.47265625e-02,  -9.47265625e-02],
                        [ -9.66796875e-02,  -9.66796875e-02],
                        [ -9.16137695e-02,  -9.16442871e-02],
                        [ -8.41674805e-02,  -8.41674805e-02],
                        [ -8.34960938e-02,  -8.34960938e-02],
                        [ -9.14001465e-02,  -9.14001465e-02],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -8.60900879e-02,  -8.60900879e-02],
                        [ -6.87255859e-02,  -6.87255859e-02],
                        [ -5.80749512e-02,  -5.81054688e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -5.42602539e-02,  -5.42907715e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  5.60913086e-02,   5.61218262e-02],
                        [  8.66088867e-02,   8.66394043e-02],
                        [  1.07177734e-01,   1.07147217e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  1.06018066e-01,   1.06018066e-01],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  1.02172852e-01,   1.02172852e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.18713379e-01,   1.18713379e-01],
                        [  1.30004883e-01,   1.29974365e-01],
                        [  1.46636963e-01,   1.46636963e-01],
                        [  1.67175293e-01,   1.67175293e-01],
                        [  1.84265137e-01,   1.84265137e-01],
                        [  1.91925049e-01,   1.91925049e-01],
                        [  1.87194824e-01,   1.87194824e-01],
                        [  1.62902832e-01,   1.62902832e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  2.23693848e-02,   2.23693848e-02],
                        [ -8.62426758e-02,  -8.62121582e-02],
                        [ -1.97723389e-01,  -1.97723389e-01],
                        [ -2.83935547e-01,  -2.83935547e-01],
                        [ -3.16009521e-01,  -3.16009521e-01],
                        [ -2.86529541e-01,  -2.86560059e-01],
                        [ -2.19757080e-01,  -2.19757080e-01],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -1.12213135e-01,  -1.12213135e-01],
                        [ -9.56115723e-02,  -9.56115723e-02],
                        [ -8.79821777e-02,  -8.79821777e-02],
                        [ -7.69042969e-02,  -7.69042969e-02],
                        [ -6.49108887e-02,  -6.49108887e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -4.25720215e-02,  -4.26025391e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  1.05834961e-01,   1.05804443e-01],
                        [  1.57867432e-01,   1.57867432e-01],
                        [  1.89941406e-01,   1.89941406e-01],
                        [  1.93389893e-01,   1.93389893e-01],
                        [  1.76422119e-01,   1.76422119e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.37878418e-01,   1.37878418e-01],
                        [  1.25061035e-01,   1.25030518e-01],
                        [  1.13891602e-01,   1.13922119e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  9.95178223e-02,   9.94873047e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  9.40551758e-02,   9.40856934e-02],
                        [  8.62426758e-02,   8.62121582e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -7.69042969e-03,  -7.72094727e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -8.39233398e-03,  -8.42285156e-03],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.43432617e-03,  -1.40380859e-03],
                        [  4.27246094e-03,   4.24194336e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.31835938e-02,   1.31530762e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -1.47033691e-01,  -1.47033691e-01],
                        [ -1.79809570e-01,  -1.79779053e-01],
                        [ -1.74865723e-01,  -1.74865723e-01],
                        [ -1.49627686e-01,  -1.49658203e-01],
                        [ -1.25244141e-01,  -1.25244141e-01],
                        [ -1.11846924e-01,  -1.11846924e-01],
                        [ -1.11511230e-01,  -1.11541748e-01],
                        [ -1.18774414e-01,  -1.18774414e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -1.09222412e-01,  -1.09222412e-01],
                        [ -9.73205566e-02,  -9.73205566e-02],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -1.03698730e-01,  -1.03698730e-01],
                        [ -9.94262695e-02,  -9.94567871e-02],
                        [ -7.99560547e-02,  -7.99255371e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.07006836e-02,  -3.07312012e-02],
                        [ -2.92053223e-02,  -2.91748047e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.21862793e-02,  -2.21557617e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  5.24291992e-02,   5.23986816e-02],
                        [  8.65478516e-02,   8.65478516e-02],
                        [  1.00891113e-01,   1.00921631e-01],
                        [  1.03546143e-01,   1.03546143e-01],
                        [  1.03759766e-01,   1.03729248e-01],
                        [  1.02203369e-01,   1.02233887e-01],
                        [  1.01837158e-01,   1.01837158e-01],
                        [  1.10382080e-01,   1.10351562e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  1.49047852e-01,   1.49078369e-01],
                        [  1.71356201e-01,   1.71325684e-01],
                        [  1.97204590e-01,   1.97204590e-01],
                        [  2.19818115e-01,   2.19848633e-01],
                        [  2.22625732e-01,   2.22625732e-01],
                        [  1.90917969e-01,   1.90917969e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  2.58178711e-02,   2.58178711e-02],
                        [ -8.36486816e-02,  -8.36791992e-02],
                        [ -1.93298340e-01,  -1.93298340e-01],
                        [ -2.85125732e-01,  -2.85125732e-01],
                        [ -3.31054688e-01,  -3.31054688e-01],
                        [ -3.10882568e-01,  -3.10913086e-01],
                        [ -2.41119385e-01,  -2.41119385e-01],
                        [ -1.68853760e-01,  -1.68823242e-01],
                        [ -1.28204346e-01,  -1.28204346e-01],
                        [ -1.14990234e-01,  -1.14990234e-01],
                        [ -1.07116699e-01,  -1.07086182e-01],
                        [ -9.38415527e-02,  -9.38415527e-02],
                        [ -7.99560547e-02,  -7.99865723e-02],
                        [ -7.37915039e-02,  -7.37915039e-02],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -8.48693848e-02,  -8.48693848e-02],
                        [ -8.67004395e-02,  -8.67004395e-02],
                        [ -7.98645020e-02,  -7.98339844e-02],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [  2.47497559e-02,   2.47802734e-02],
                        [  7.68127441e-02,   7.67822266e-02],
                        [  1.31256104e-01,   1.31256104e-01],
                        [  1.79260254e-01,   1.79290771e-01],
                        [  2.08282471e-01,   2.08282471e-01],
                        [  2.08343506e-01,   2.08312988e-01],
                        [  1.84906006e-01,   1.84936523e-01],
                        [  1.56951904e-01,   1.56951904e-01],
                        [  1.38977051e-01,   1.38977051e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.22406006e-01,   1.22436523e-01],
                        [  1.07757568e-01,   1.07727051e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  8.01696777e-02,   8.02001953e-02],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  5.99670410e-02,   5.99975586e-02],
                        [  4.28466797e-02,   4.28771973e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  6.56127930e-03,   6.59179688e-03],
                        [ -1.37329102e-03,  -1.40380859e-03],
                        [ -1.23291016e-02,  -1.23596191e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.83508301e-02,  -2.83813477e-02],
                        [ -2.10266113e-02,  -2.09960938e-02],
                        [ -1.40075684e-02,  -1.39770508e-02],
                        [ -7.56835938e-03,  -7.59887695e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -1.12915039e-03,  -1.09863281e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -1.43432617e-02,  -1.43737793e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.79235840e-02,  -2.79541016e-02],
                        [ -1.50451660e-02,  -1.50756836e-02],
                        [ -1.52587891e-03,  -1.49536133e-03],
                        [  9.46044922e-03,   9.42993164e-03],
                        [  1.92565918e-02,   1.92260742e-02],
                        [  2.74658203e-02,   2.74963379e-02],
                        [  3.68957520e-02,   3.69262695e-02],
                        [  5.57556152e-02,   5.57250977e-02],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  1.05682373e-01,   1.05712891e-01],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.10290527e-01,   1.10260010e-01],
                        [  9.26818848e-02,   9.27124023e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [ -2.56347656e-02,  -2.56652832e-02],
                        [ -1.11541748e-01,  -1.11541748e-01],
                        [ -1.83380127e-01,  -1.83380127e-01],
                        [ -2.20642090e-01,  -2.20672607e-01],
                        [ -2.16247559e-01,  -2.16247559e-01],
                        [ -1.81457520e-01,  -1.81457520e-01],
                        [ -1.40167236e-01,  -1.40167236e-01],
                        [ -1.11206055e-01,  -1.11236572e-01],
                        [ -9.74121094e-02,  -9.73815918e-02],
                        [ -9.32312012e-02,  -9.32312012e-02],
                        [ -9.62829590e-02,  -9.63134766e-02],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -1.15234375e-01,  -1.15203857e-01],
                        [ -1.19873047e-01,  -1.19873047e-01],
                        [ -1.15173340e-01,  -1.15203857e-01],
                        [ -9.87548828e-02,  -9.87243652e-02],
                        [ -7.18688965e-02,  -7.18383789e-02],
                        [ -4.06799316e-02,  -4.07104492e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.96533203e-02,  -1.96228027e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  1.07238770e-01,   1.07269287e-01],
                        [  1.09680176e-01,   1.09649658e-01],
                        [  1.06353760e-01,   1.06353760e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.15905762e-01,   1.15875244e-01],
                        [  1.36749268e-01,   1.36749268e-01],
                        [  1.65252686e-01,   1.65252686e-01],
                        [  1.91833496e-01,   1.91802979e-01],
                        [  2.10906982e-01,   2.10906982e-01],
                        [  2.20397949e-01,   2.20397949e-01],
                        [  2.12585449e-01,   2.12554932e-01],
                        [  1.77032471e-01,   1.77032471e-01],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  2.05993652e-02,   2.05993652e-02],
                        [ -8.94470215e-02,  -8.94775391e-02],
                        [ -2.04040527e-01,  -2.04010010e-01],
                        [ -2.92083740e-01,  -2.92083740e-01],
                        [ -3.21685791e-01,  -3.21685791e-01],
                        [ -2.86987305e-01,  -2.86987305e-01],
                        [ -2.16674805e-01,  -2.16644287e-01],
                        [ -1.53167725e-01,  -1.53167725e-01],
                        [ -1.21276855e-01,  -1.21307373e-01],
                        [ -1.15264893e-01,  -1.15234375e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -1.14685059e-01,  -1.14685059e-01],
                        [ -1.12915039e-01,  -1.12915039e-01],
                        [ -1.10473633e-01,  -1.10443115e-01],
                        [ -1.02264404e-01,  -1.02294922e-01],
                        [ -8.79821777e-02,  -8.79821777e-02],
                        [ -7.38830566e-02,  -7.38525391e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -5.21545410e-02,  -5.21850586e-02],
                        [ -2.94799805e-02,  -2.94494629e-02],
                        [  1.06201172e-02,   1.06506348e-02],
                        [  6.64672852e-02,   6.64367676e-02],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.85852051e-01,   1.85882568e-01],
                        [  2.21130371e-01,   2.21130371e-01],
                        [  2.26898193e-01,   2.26867676e-01],
                        [  2.06176758e-01,   2.06207275e-01],
                        [  1.71173096e-01,   1.71173096e-01],
                        [  1.38183594e-01,   1.38153076e-01],
                        [  1.19842529e-01,   1.19842529e-01],
                        [  1.15600586e-01,   1.15631104e-01],
                        [  1.12670898e-01,   1.12640381e-01],
                        [  1.02081299e-01,   1.02050781e-01],
                        [  8.95690918e-02,   8.95996094e-02],
                        [  8.46557617e-02,   8.46862793e-02],
                        [  8.56018066e-02,   8.55712891e-02],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  7.55310059e-02,   7.55615234e-02],
                        [  5.93872070e-02,   5.93566895e-02],
                        [  3.39965820e-02,   3.39660645e-02],
                        [  6.50024414e-03,   6.53076172e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.07421875e-02,  -1.07727051e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.35192871e-02,  -1.35498047e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.91955566e-02,  -1.91650391e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.73229980e-02,  -3.73535156e-02],
                        [ -3.36608887e-02,  -3.36303711e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.38342285e-02,  -2.38647461e-02],
                        [ -2.25524902e-02,  -2.25219727e-02],
                        [ -1.66320801e-02,  -1.66015625e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -8.08715820e-03,  -8.05664062e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -5.15747070e-03,  -5.18798828e-03],
                        [  1.25122070e-03,   1.28173828e-03],
                        [  1.01928711e-02,   1.02233887e-02],
                        [  2.67639160e-02,   2.67333984e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  8.06274414e-02,   8.06579590e-02],
                        [  1.00616455e-01,   1.00585938e-01],
                        [  1.10290527e-01,   1.10260010e-01],
                        [  1.10656738e-01,   1.10687256e-01],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  6.07299805e-02,   6.06994629e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -7.43713379e-02,  -7.43408203e-02],
                        [ -1.45568848e-01,  -1.45599365e-01],
                        [ -1.93634033e-01,  -1.93664551e-01],
                        [ -2.05444336e-01,  -2.05413818e-01],
                        [ -1.84143066e-01,  -1.84143066e-01],
                        [ -1.49688721e-01,  -1.49719238e-01],
                        [ -1.23931885e-01,  -1.23901367e-01],
                        [ -1.14410400e-01,  -1.14379883e-01],
                        [ -1.13708496e-01,  -1.13708496e-01],
                        [ -1.13311768e-01,  -1.13342285e-01],
                        [ -1.12487793e-01,  -1.12457275e-01],
                        [ -1.11938477e-01,  -1.11968994e-01],
                        [ -1.06994629e-01,  -1.07025146e-01],
                        [ -9.20715332e-02,  -9.20410156e-02],
                        [ -6.97326660e-02,  -6.97021484e-02],
                        [ -5.10253906e-02,  -5.10559082e-02],
                        [ -4.40673828e-02,  -4.40979004e-02],
                        [ -4.58679199e-02,  -4.58374023e-02],
                        [ -4.86450195e-02,  -4.86755371e-02],
                        [ -4.75158691e-02,  -4.75463867e-02],
                        [ -3.81164551e-02,  -3.80859375e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [  2.19726562e-02,   2.19421387e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  9.70153809e-02,   9.70458984e-02],
                        [  1.09344482e-01,   1.09313965e-01],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  9.34143066e-02,   9.34448242e-02],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  9.93652344e-02,   9.93347168e-02],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  1.38946533e-01,   1.38977051e-01],
                        [  1.58325195e-01,   1.58294678e-01],
                        [  1.80816650e-01,   1.80816650e-01],
                        [  2.09869385e-01,   2.09899902e-01],
                        [  2.33520508e-01,   2.33520508e-01],
                        [  2.28057861e-01,   2.28027344e-01],
                        [  1.81793213e-01,   1.81823730e-01],
                        [  1.05102539e-01,   1.05133057e-01],
                        [  1.26342773e-02,   1.26037598e-02],
                        [ -8.99658203e-02,  -8.99658203e-02],
                        [ -1.93969727e-01,  -1.93939209e-01],
                        [ -2.75024414e-01,  -2.75054932e-01],
                        [ -3.04473877e-01,  -3.04504395e-01],
                        [ -2.74780273e-01,  -2.74749756e-01],
                        [ -2.11547852e-01,  -2.11547852e-01],
                        [ -1.55883789e-01,  -1.55914307e-01],
                        [ -1.29333496e-01,  -1.29333496e-01],
                        [ -1.21551514e-01,  -1.21520996e-01],
                        [ -1.15112305e-01,  -1.15142822e-01],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.05438232e-01,  -1.05407715e-01],
                        [ -1.04248047e-01,  -1.04248047e-01],
                        [ -9.99755859e-02,  -1.00006104e-01],
                        [ -9.25292969e-02,  -9.24987793e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -7.33032227e-02,  -7.33337402e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -2.14538574e-02,  -2.14233398e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  7.96203613e-02,   7.95898438e-02],
                        [  1.41601562e-01,   1.41632080e-01],
                        [  2.03674316e-01,   2.03704834e-01],
                        [  2.42706299e-01,   2.42675781e-01],
                        [  2.37030029e-01,   2.37030029e-01],
                        [  1.95800781e-01,   1.95831299e-01],
                        [  1.52282715e-01,   1.52252197e-01],
                        [  1.27502441e-01,   1.27502441e-01],
                        [  1.16851807e-01,   1.16912842e-01],
                        [  1.10107422e-01,   1.10137939e-01],
                        [  1.06353760e-01,   1.06323242e-01],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  1.02416992e-01,   1.02447510e-01],
                        [  9.28039551e-02,   9.27734375e-02],
                        [  8.16040039e-02,   8.15734863e-02],
                        [  7.07092285e-02,   7.07702637e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  3.82080078e-02,   3.81774902e-02],
                        [  2.37426758e-02,   2.37731934e-02],
                        [  1.31835938e-02,   1.32141113e-02],
                        [  1.37329102e-03,   1.34277344e-03],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.52282715e-02,  -1.51977539e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [  2.74658203e-04,   2.44140625e-04],
                        [  1.43432617e-03,   1.46484375e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.87268066e-02,  -3.86962891e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.44335938e-02,  -4.44641113e-02],
                        [ -4.24194336e-02,  -4.23889160e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  2.55432129e-02,   2.55126953e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  4.40979004e-02,   4.41284180e-02],
                        [  5.79528809e-02,   5.79223633e-02],
                        [  7.22045898e-02,   7.21740723e-02],
                        [  8.56323242e-02,   8.56628418e-02],
                        [  9.79003906e-02,   9.79309082e-02],
                        [  1.00372314e-01,   1.00341797e-01],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  2.62451172e-02,   2.62756348e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -1.17187500e-01,  -1.17218018e-01],
                        [ -1.76239014e-01,  -1.76208496e-01],
                        [ -2.04010010e-01,  -2.04010010e-01],
                        [ -1.94946289e-01,  -1.94976807e-01],
                        [ -1.66198730e-01,  -1.66168213e-01],
                        [ -1.41479492e-01,  -1.41448975e-01],
                        [ -1.26892090e-01,  -1.26922607e-01],
                        [ -1.13555908e-01,  -1.13586426e-01],
                        [ -9.78393555e-02,  -9.77783203e-02],
                        [ -8.70666504e-02,  -8.70666504e-02],
                        [ -8.72192383e-02,  -8.72497559e-02],
                        [ -9.33837891e-02,  -9.33532715e-02],
                        [ -9.63745117e-02,  -9.63439941e-02],
                        [ -9.28649902e-02,  -9.28955078e-02],
                        [ -8.59069824e-02,  -8.59069824e-02],
                        [ -7.95593262e-02,  -7.94982910e-02],
                        [ -7.59277344e-02,  -7.59582520e-02],
                        [ -7.52563477e-02,  -7.53173828e-02],
                        [ -7.37304688e-02,  -7.36999512e-02],
                        [ -6.04858398e-02,  -6.04553223e-02],
                        [ -2.45971680e-02,  -2.46582031e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  8.62121582e-02,   8.62731934e-02],
                        [  1.22833252e-01,   1.22802734e-01],
                        [  1.34582520e-01,   1.34521484e-01],
                        [  1.27380371e-01,   1.27441406e-01],
                        [  1.10900879e-01,   1.10900879e-01],
                        [  9.59167480e-02,   9.58557129e-02],
                        [  9.50927734e-02,   9.51232910e-02],
                        [  1.13098145e-01,   1.13159180e-01],
                        [  1.38763428e-01,   1.38732910e-01],
                        [  1.59881592e-01,   1.59851074e-01],
                        [  1.80358887e-01,   1.80419922e-01],
                        [  2.07366943e-01,   2.07366943e-01],
                        [  2.29003906e-01,   2.28942871e-01],
                        [  2.22717285e-01,   2.22717285e-01],
                        [  1.80206299e-01,   1.80267334e-01],
                        [  1.07208252e-01,   1.07177734e-01],
                        [  6.98852539e-03,   6.98852539e-03],
                        [ -1.14532471e-01,  -1.14471436e-01],
                        [ -2.33154297e-01,  -2.33154297e-01],
                        [ -3.13018799e-01,  -3.13079834e-01],
                        [ -3.29315186e-01,  -3.29284668e-01],
                        [ -2.84729004e-01,  -2.84698486e-01],
                        [ -2.11425781e-01,  -2.11486816e-01],
                        [ -1.51306152e-01,  -1.51306152e-01],
                        [ -1.23107910e-01,  -1.23077393e-01],
                        [ -1.13433838e-01,  -1.13433838e-01],
                        [ -1.03607178e-01,  -1.03637695e-01],
                        [ -9.41467285e-02,  -9.41162109e-02],
                        [ -9.33532715e-02,  -9.33227539e-02],
                        [ -9.79309082e-02,  -9.79614258e-02],
                        [ -9.89379883e-02,  -9.89379883e-02],
                        [ -9.49707031e-02,  -9.49401855e-02],
                        [ -8.72802734e-02,  -8.72802734e-02],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -4.21752930e-02,  -4.21447754e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  5.26733398e-02,   5.26428223e-02],
                        [  1.14959717e-01,   1.14990234e-01],
                        [  1.76116943e-01,   1.76116943e-01],
                        [  2.16369629e-01,   2.16308594e-01],
                        [  2.23022461e-01,   2.23022461e-01],
                        [  2.02178955e-01,   2.02209473e-01],
                        [  1.70379639e-01,   1.70379639e-01],
                        [  1.41723633e-01,   1.41693115e-01],
                        [  1.23474121e-01,   1.23504639e-01],
                        [  1.15722656e-01,   1.15722656e-01],
                        [  1.11846924e-01,   1.11816406e-01],
                        [  1.04522705e-01,   1.04553223e-01],
                        [  9.38415527e-02,   9.39025879e-02],
                        [  8.44726562e-02,   8.44421387e-02],
                        [  7.70874023e-02,   7.70874023e-02],
                        [  6.97631836e-02,   6.97937012e-02],
                        [  6.17370605e-02,   6.17675781e-02],
                        [  4.97131348e-02,   4.96826172e-02],
                        [  2.96325684e-02,   2.96630859e-02],
                        [  6.74438477e-03,   6.80541992e-03],
                        [ -7.17163086e-03,  -7.20214844e-03],
                        [ -8.66699219e-03,  -8.69750977e-03],
                        [ -6.56127930e-03,  -6.50024414e-03],
                        [ -8.45336914e-03,  -8.48388672e-03],
                        [ -1.08337402e-02,  -1.08947754e-02],
                        [ -7.78198242e-03,  -7.75146484e-03],
                        [ -2.92968750e-03,  -2.89916992e-03],
                        [ -3.75366211e-03,  -3.81469727e-03],
                        [ -1.08947754e-02,  -1.09252930e-02],
                        [ -2.08740234e-02,  -2.08129883e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -4.27246094e-02,  -4.27856445e-02],
                        [ -4.43115234e-02,  -4.42810059e-02],
                        [ -3.46679688e-02,  -3.46374512e-02],
                        [ -2.11181641e-02,  -2.11486816e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -2.01416016e-03,  -1.95312500e-03],
                        [  4.08935547e-03,   4.05883789e-03],
                        [  7.69042969e-03,   7.62939453e-03],
                        [  1.24816895e-02,   1.25427246e-02],
                        [  2.11791992e-02,   2.12097168e-02],
                        [  2.87475586e-02,   2.86865234e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  3.02734375e-02,   3.03344727e-02],
                        [  4.04357910e-02,   4.04052734e-02],
                        [  6.28051758e-02,   6.27746582e-02],
                        [  8.66088867e-02,   8.66699219e-02],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  9.60388184e-02,   9.59777832e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  3.64074707e-02,   3.64379883e-02],
                        [ -3.42407227e-02,  -3.42712402e-02],
                        [ -1.23016357e-01,  -1.23016357e-01],
                        [ -1.94335938e-01,  -1.94274902e-01],
                        [ -2.17498779e-01,  -2.17498779e-01],
                        [ -1.93786621e-01,  -1.93817139e-01],
                        [ -1.51062012e-01,  -1.51000977e-01],
                        [ -1.18530273e-01,  -1.18530273e-01],
                        [ -1.08367920e-01,  -1.08398438e-01],
                        [ -1.13159180e-01,  -1.13159180e-01],
                        [ -1.16485596e-01,  -1.16455078e-01],
                        [ -1.07910156e-01,  -1.07940674e-01],
                        [ -9.14306641e-02,  -9.14611816e-02],
                        [ -7.82470703e-02,  -7.82165527e-02],
                        [ -7.38220215e-02,  -7.38220215e-02],
                        [ -7.71789551e-02,  -7.72399902e-02],
                        [ -8.59069824e-02,  -8.58764648e-02],
                        [ -9.40856934e-02,  -9.40551758e-02],
                        [ -9.23767090e-02,  -9.24377441e-02],
                        [ -7.72705078e-02,  -7.73010254e-02],
                        [ -5.33752441e-02,  -5.33142090e-02],
                        [ -2.35595703e-02,  -2.35900879e-02],
                        [  1.41601562e-02,   1.41296387e-02],
                        [  5.62744141e-02,   5.63049316e-02],
                        [  9.01489258e-02,   9.01489258e-02],
                        [  1.06994629e-01,   1.06933594e-01],
                        [  1.08520508e-01,   1.08551025e-01],
                        [  1.01409912e-01,   1.01440430e-01],
                        [  9.58251953e-02,   9.57641602e-02],
                        [  1.04797363e-01,   1.04766846e-01],
                        [  1.31927490e-01,   1.31988525e-01],
                        [  1.63604736e-01,   1.63574219e-01],
                        [  1.81884766e-01,   1.81823730e-01],
                        [  1.84448242e-01,   1.84478760e-01],
                        [  1.84478760e-01,   1.84509277e-01],
                        [  1.91223145e-01,   1.91162109e-01],
                        [  1.96197510e-01,   1.96166992e-01],
                        [  1.79199219e-01,   1.79260254e-01],
                        [  1.24298096e-01,   1.24267578e-01],
                        [  3.17382812e-02,   3.17077637e-02],
                        [ -8.15124512e-02,  -8.14819336e-02],
                        [ -1.91802979e-01,  -1.91772461e-01],
                        [ -2.76428223e-01,  -2.76489258e-01],
                        [ -3.15582275e-01,  -3.15582275e-01],
                        [ -2.98126221e-01,  -2.98065186e-01],
                        [ -2.35473633e-01,  -2.35504150e-01],
                        [ -1.64123535e-01,  -1.64154053e-01],
                        [ -1.19812012e-01,  -1.19750977e-01],
                        [ -1.07421875e-01,  -1.07391357e-01],
                        [ -1.06994629e-01,  -1.07055664e-01],
                        [ -1.03942871e-01,  -1.03912354e-01],
                        [ -9.94262695e-02,  -9.93652344e-02],
                        [ -9.81140137e-02,  -9.81750488e-02],
                        [ -9.89990234e-02,  -9.90295410e-02],
                        [ -9.64660645e-02,  -9.64050293e-02],
                        [ -8.49304199e-02,  -8.49304199e-02],
                        [ -6.27136230e-02,  -6.27746582e-02],
                        [ -3.19213867e-02,  -3.18603516e-02],
                        [  7.84301758e-03,   7.90405273e-03],
                        [  6.12487793e-02,   6.12182617e-02],
                        [  1.26403809e-01,   1.26373291e-01],
                        [  1.85577393e-01,   1.85638428e-01],
                        [  2.15850830e-01,   2.15850830e-01],
                        [  2.08312988e-01,   2.08251953e-01],
                        [  1.73950195e-01,   1.73980713e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  1.07788086e-01,   1.07727051e-01],
                        [  1.02355957e-01,   1.02386475e-01],
                        [  1.12854004e-01,   1.12915039e-01],
                        [  1.24084473e-01,   1.24053955e-01],
                        [  1.24908447e-01,   1.24877930e-01],
                        [  1.19567871e-01,   1.19628906e-01],
                        [  1.16241455e-01,   1.16241455e-01],
                        [  1.09405518e-01,   1.09375000e-01],
                        [  8.77075195e-02,   8.77380371e-02],
                        [  5.37414551e-02,   5.37719727e-02],
                        [  2.31018066e-02,   2.30712891e-02],
                        [  6.25610352e-03,   6.22558594e-03],
                        [  7.62939453e-04,   7.93457031e-04],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  4.57763672e-04,   4.27246094e-04],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -6.56127930e-03,  -6.59179688e-03],
                        [ -1.13220215e-02,  -1.13525391e-02],
                        [ -1.11389160e-02,  -1.11083984e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -3.47900391e-03,  -3.50952148e-03],
                        [ -7.41577148e-03,  -7.38525391e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.46887207e-02,  -2.47192383e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.64990234e-02,  -3.64685059e-02],
                        [ -3.64379883e-02,  -3.64685059e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -1.32141113e-02,  -1.31835938e-02],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  2.86865234e-03,   2.80761719e-03],
                        [ -1.00708008e-03,  -9.76562500e-04],
                        [  1.25122070e-03,   1.28173828e-03],
                        [  1.69982910e-02,   1.69372559e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.62341309e-02,   4.62951660e-02],
                        [  4.45556641e-02,   4.45251465e-02],
                        [  4.25720215e-02,   4.25415039e-02],
                        [  4.98046875e-02,   4.98352051e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  8.93859863e-02,   8.93554688e-02],
                        [  9.97314453e-02,   9.97619629e-02],
                        [  8.05664062e-02,   8.06274414e-02],
                        [  2.48413086e-02,   2.48107910e-02],
                        [ -5.64270020e-02,  -5.64575195e-02],
                        [ -1.38854980e-01,  -1.38824463e-01],
                        [ -1.93420410e-01,  -1.93420410e-01],
                        [ -2.01354980e-01,  -2.01416016e-01],
                        [ -1.70288086e-01,  -1.70257568e-01],
                        [ -1.29516602e-01,  -1.29486084e-01],
                        [ -1.05804443e-01,  -1.05834961e-01],
                        [ -1.05438232e-01,  -1.05438232e-01],
                        [ -1.16180420e-01,  -1.16119385e-01],
                        [ -1.21093750e-01,  -1.21093750e-01],
                        [ -1.13555908e-01,  -1.13616943e-01],
                        [ -1.01806641e-01,  -1.01776123e-01],
                        [ -9.77172852e-02,  -9.77172852e-02],
                        [ -1.00769043e-01,  -1.00830078e-01],
                        [ -9.88769531e-02,  -9.88769531e-02],
                        [ -8.74023438e-02,  -8.73413086e-02],
                        [ -7.49816895e-02,  -7.50122070e-02],
                        [ -6.58874512e-02,  -6.59484863e-02],
                        [ -5.09643555e-02,  -5.09338379e-02],
                        [ -2.29797363e-02,  -2.29492188e-02],
                        [  1.12915039e-02,   1.12609863e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  6.58874512e-02,   6.59484863e-02],
                        [  8.48083496e-02,   8.47778320e-02],
                        [  9.48486328e-02,   9.48181152e-02],
                        [  9.55200195e-02,   9.55810547e-02],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  1.03790283e-01,   1.03729248e-01],
                        [  1.20727539e-01,   1.20758057e-01],
                        [  1.37359619e-01,   1.37420654e-01],
                        [  1.49719238e-01,   1.49688721e-01],
                        [  1.64184570e-01,   1.64154053e-01],
                        [  1.84326172e-01,   1.84387207e-01],
                        [  2.02087402e-01,   2.02087402e-01],
                        [  2.07305908e-01,   2.07244873e-01],
                        [  1.93450928e-01,   1.93481445e-01],
                        [  1.52191162e-01,   1.52252197e-01],
                        [  7.57446289e-02,   7.56835938e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -1.51336670e-01,  -1.51275635e-01],
                        [ -2.55889893e-01,  -2.55920410e-01],
                        [ -3.16101074e-01,  -3.16162109e-01],
                        [ -3.12286377e-01,  -3.12255859e-01],
                        [ -2.53631592e-01,  -2.53631592e-01],
                        [ -1.80328369e-01,  -1.80389404e-01],
                        [ -1.33575439e-01,  -1.33544922e-01],
                        [ -1.22802734e-01,  -1.22741699e-01],
                        [ -1.27502441e-01,  -1.27532959e-01],
                        [ -1.27258301e-01,  -1.27288818e-01],
                        [ -1.21215820e-01,  -1.21154785e-01],
                        [ -1.16485596e-01,  -1.16485596e-01],
                        [ -1.11785889e-01,  -1.11816406e-01],
                        [ -1.02386475e-01,  -1.02355957e-01],
                        [ -8.76159668e-02,  -8.75854492e-02],
                        [ -6.46667480e-02,  -6.47277832e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [  2.54211426e-02,   2.54821777e-02],
                        [  8.29772949e-02,   8.29467773e-02],
                        [  1.36383057e-01,   1.36352539e-01],
                        [  1.80297852e-01,   1.80328369e-01],
                        [  2.06451416e-01,   2.06451416e-01],
                        [  2.04956055e-01,   2.04895020e-01],
                        [  1.76940918e-01,   1.76971436e-01],
                        [  1.39282227e-01,   1.39312744e-01],
                        [  1.13372803e-01,   1.13311768e-01],
                        [  1.08947754e-01,   1.08947754e-01],
                        [  1.17279053e-01,   1.17340088e-01],
                        [  1.22711182e-01,   1.22680664e-01],
                        [  1.19842529e-01,   1.19781494e-01],
                        [  1.13372803e-01,   1.13433838e-01],
                        [  1.06079102e-01,   1.06109619e-01],
                        [  9.60388184e-02,   9.59777832e-02],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  5.97839355e-02,   5.98449707e-02],
                        [  3.36608887e-02,   3.36303711e-02],
                        [  1.23291016e-02,   1.22680664e-02],
                        [  6.74438477e-03,   6.80541992e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.85852051e-02,   1.85241699e-02],
                        [  1.38549805e-02,   1.38854980e-02],
                        [  7.93457031e-03,   7.96508789e-03],
                        [  5.03540039e-03,   4.97436523e-03],
                        [ -2.10571289e-03,  -2.13623047e-03],
                        [ -1.59606934e-02,  -1.58996582e-02],
                        [ -2.62451172e-02,  -2.62756348e-02],
                        [ -2.74047852e-02,  -2.74658203e-02],
                        [ -2.79541016e-02,  -2.78930664e-02],
                        [ -3.35083008e-02,  -3.34777832e-02],
                        [ -3.70788574e-02,  -3.71398926e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.88696289e-02,  -2.88085938e-02],
                        [ -2.21252441e-02,  -2.21557617e-02],
                        [ -1.22375488e-02,  -1.22985840e-02],
                        [ -3.93676758e-03,  -3.87573242e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -3.11279297e-03,  -3.17382812e-03],
                        [  1.98364258e-03,   2.01416016e-03],
                        [  9.94873047e-03,   9.97924805e-03],
                        [  1.13220215e-02,   1.12915039e-02],
                        [  7.11059570e-03,   7.08007812e-03],
                        [  1.01928711e-02,   1.02233887e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  5.13610840e-02,   5.13305664e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  7.19299316e-02,   7.19909668e-02],
                        [  7.75146484e-02,   7.74841309e-02],
                        [  9.09729004e-02,   9.09423828e-02],
                        [  1.00433350e-01,   1.00494385e-01],
                        [  8.07495117e-02,   8.07800293e-02],
                        [  1.69982910e-02,   1.69372559e-02],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -1.68609619e-01,  -1.68579102e-01],
                        [ -2.20245361e-01,  -2.20275879e-01],
                        [ -2.19146729e-01,  -2.19177246e-01],
                        [ -1.82800293e-01,  -1.82739258e-01],
                        [ -1.44561768e-01,  -1.44561768e-01],
                        [ -1.23229980e-01,  -1.23291016e-01],
                        [ -1.14074707e-01,  -1.14044189e-01],
                        [ -1.06781006e-01,  -1.06750488e-01],
                        [ -9.87243652e-02,  -9.87854004e-02],
                        [ -9.40551758e-02,  -9.40856934e-02],
                        [ -9.89685059e-02,  -9.89074707e-02],
                        [ -1.12640381e-01,  -1.12670898e-01],
                        [ -1.22039795e-01,  -1.22100830e-01],
                        [ -1.15264893e-01,  -1.15203857e-01],
                        [ -9.71679688e-02,  -9.71374512e-02],
                        [ -7.93457031e-02,  -7.94067383e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -2.99987793e-02,  -2.99377441e-02],
                        [  1.30004883e-02,   1.29699707e-02],
                        [  6.10351562e-02,   6.10046387e-02],
                        [  1.04187012e-01,   1.04217529e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.27532959e-01,   1.27502441e-01],
                        [  1.04705811e-01,   1.04736328e-01],
                        [  8.10241699e-02,   8.10852051e-02],
                        [  7.22961426e-02,   7.22656250e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  1.01562500e-01,   1.01623535e-01],
                        [  1.25793457e-01,   1.25793457e-01],
                        [  1.49169922e-01,   1.49139404e-01],
                        [  1.75048828e-01,   1.75079346e-01],
                        [  2.06634521e-01,   2.06665039e-01],
                        [  2.31994629e-01,   2.31933594e-01],
                        [  2.29400635e-01,   2.29400635e-01],
                        [  1.88140869e-01,   1.88201904e-01],
                        [  1.12213135e-01,   1.12182617e-01],
                        [  8.63647461e-03,   8.63647461e-03],
                        [ -1.14379883e-01,  -1.14318848e-01],
                        [ -2.38311768e-01,  -2.38311768e-01],
                        [ -3.29406738e-01,  -3.29467773e-01],
                        [ -3.52935791e-01,  -3.52935791e-01],
                        [ -3.02886963e-01,  -3.02856445e-01],
                        [ -2.16613770e-01,  -2.16674805e-01],
                        [ -1.47857666e-01,  -1.47857666e-01],
                        [ -1.21337891e-01,  -1.21276855e-01],
                        [ -1.21887207e-01,  -1.21917725e-01],
                        [ -1.24938965e-01,  -1.25000000e-01],
                        [ -1.22253418e-01,  -1.22192383e-01],
                        [ -1.17553711e-01,  -1.17523193e-01],
                        [ -1.14715576e-01,  -1.14776611e-01],
                        [ -1.14379883e-01,  -1.14379883e-01],
                        [ -1.11755371e-01,  -1.11694336e-01],
                        [ -9.41772461e-02,  -9.42077637e-02],
                        [ -4.86755371e-02,  -4.87060547e-02],
                        [  2.27966309e-02,   2.28576660e-02],
                        [  1.02050781e-01,   1.02081299e-01],
                        [  1.70959473e-01,   1.70898438e-01],
                        [  2.20245361e-01,   2.20275879e-01],
                        [  2.42706299e-01,   2.42736816e-01],
                        [  2.33154297e-01,   2.33123779e-01],
                        [  1.98669434e-01,   1.98638916e-01],
                        [  1.57470703e-01,   1.57531738e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.07574463e-01,   1.07513428e-01],
                        [  9.93652344e-02,   9.93957520e-02],
                        [  9.38110352e-02,   9.38415527e-02],
                        [  8.74023438e-02,   8.73413086e-02],
                        [  8.29772949e-02,   8.29772949e-02],
                        [  8.19396973e-02,   8.20007324e-02],
                        [  7.65075684e-02,   7.64770508e-02],
                        [  6.07604980e-02,   6.06994629e-02],
                        [  4.33654785e-02,   4.33959961e-02],
                        [  3.61022949e-02,   3.61328125e-02],
                        [  3.74145508e-02,   3.73840332e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  3.42712402e-02,   3.43322754e-02],
                        [  2.75573730e-02,   2.75268555e-02],
                        [  1.75476074e-02,   1.75170898e-02],
                        [  3.99780273e-03,   4.02832031e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.87683105e-02,  -1.87988281e-02],
                        [ -1.86767578e-02,  -1.86462402e-02],
                        [ -1.00097656e-02,  -9.97924805e-03],
                        [ -1.55639648e-03,  -1.58691406e-03],
                        [ -3.72314453e-03,  -3.75366211e-03],
                        [ -1.69067383e-02,  -1.68762207e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -4.29382324e-02,  -4.29687500e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -3.93981934e-02,  -3.93676758e-02],
                        [ -3.03649902e-02,  -3.03955078e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -4.79125977e-03,  -4.76074219e-03],
                        [  7.29370117e-03,   7.26318359e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.04370117e-02,   1.04675293e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  8.08715820e-03,   8.05664062e-03],
                        [  8.23974609e-03,   8.27026367e-03],
                        [  1.53198242e-02,   1.53503418e-02],
                        [  3.27758789e-02,   3.27148438e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  7.23571777e-02,   7.23876953e-02],
                        [  8.97827148e-02,   8.97521973e-02],
                        [  1.04980469e-01,   1.04949951e-01],
                        [  1.06933594e-01,   1.06964111e-01],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  2.84118652e-02,   2.83508301e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -1.25183105e-01,  -1.25122070e-01],
                        [ -1.87683105e-01,  -1.87713623e-01],
                        [ -2.18017578e-01,  -2.18048096e-01],
                        [ -2.12097168e-01,  -2.12036133e-01],
                        [ -1.83959961e-01,  -1.83959961e-01],
                        [ -1.56311035e-01,  -1.56372070e-01],
                        [ -1.38977051e-01,  -1.38977051e-01],
                        [ -1.24359131e-01,  -1.24328613e-01],
                        [ -1.06597900e-01,  -1.06628418e-01],
                        [ -9.11254883e-02,  -9.11254883e-02],
                        [ -8.30078125e-02,  -8.29467773e-02],
                        [ -8.03222656e-02,  -8.03222656e-02],
                        [ -8.01696777e-02,  -8.02307129e-02],
                        [ -8.13903809e-02,  -8.13598633e-02],
                        [ -8.30078125e-02,  -8.29467773e-02],
                        [ -8.34045410e-02,  -8.34350586e-02],
                        [ -7.79724121e-02,  -7.80029297e-02],
                        [ -5.89599609e-02,  -5.89294434e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [  3.16162109e-02,   3.15551758e-02],
                        [  8.47473145e-02,   8.47778320e-02],
                        [  1.20727539e-01,   1.20758057e-01],
                        [  1.31347656e-01,   1.31286621e-01],
                        [  1.23352051e-01,   1.23352051e-01],
                        [  1.09954834e-01,   1.10015869e-01],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  9.26818848e-02,   9.26208496e-02],
                        [  9.38720703e-02,   9.39025879e-02],
                        [  1.05346680e-01,   1.05377197e-01],
                        [  1.29913330e-01,   1.29882812e-01],
                        [  1.69250488e-01,   1.69219971e-01],
                        [  2.14569092e-01,   2.14630127e-01],
                        [  2.43438721e-01,   2.43408203e-01],
                        [  2.32910156e-01,   2.32879639e-01],
                        [  1.74011230e-01,   1.74041748e-01],
                        [  7.39746094e-02,   7.40051270e-02],
                        [ -4.82788086e-02,  -4.83093262e-02],
                        [ -1.68579102e-01,  -1.68579102e-01],
                        [ -2.62908936e-01,  -2.62878418e-01],
                        [ -3.08898926e-01,  -3.08929443e-01],
                        [ -2.92785645e-01,  -2.92816162e-01],
                        [ -2.28363037e-01,  -2.28363037e-01],
                        [ -1.61193848e-01,  -1.61193848e-01],
                        [ -1.31591797e-01,  -1.31622314e-01],
                        [ -1.36840820e-01,  -1.36810303e-01],
                        [ -1.46514893e-01,  -1.46484375e-01],
                        [ -1.43859863e-01,  -1.43859863e-01],
                        [ -1.34826660e-01,  -1.34857178e-01],
                        [ -1.29516602e-01,  -1.29486084e-01],
                        [ -1.29486084e-01,  -1.29486084e-01],
                        [ -1.26800537e-01,  -1.26831055e-01],
                        [ -1.08093262e-01,  -1.08062744e-01],
                        [ -6.37207031e-02,  -6.37207031e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  1.55242920e-01,   1.55273438e-01],
                        [  2.05169678e-01,   2.05169678e-01],
                        [  2.27355957e-01,   2.27325439e-01],
                        [  2.23815918e-01,   2.23846436e-01],
                        [  1.99951172e-01,   1.99951172e-01],
                        [  1.66534424e-01,   1.66534424e-01],
                        [  1.38549805e-01,   1.38580322e-01],
                        [  1.20819092e-01,   1.20849609e-01],
                        [  1.06079102e-01,   1.06048584e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  8.87145996e-02,   8.87451172e-02],
                        [  9.21630859e-02,   9.21325684e-02],
                        [  9.42077637e-02,   9.41772461e-02],
                        [  9.20715332e-02,   9.21020508e-02],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  7.41577148e-02,   7.41271973e-02],
                        [  5.17883301e-02,   5.18188477e-02],
                        [  2.72216797e-02,   2.72521973e-02],
                        [  9.24682617e-03,   9.21630859e-03],
                        [  8.23974609e-04,   7.93457031e-04],
                        [  2.47192383e-03,   2.53295898e-03],
                        [  1.07421875e-02,   1.07727051e-02],
                        [  1.66320801e-02,   1.65710449e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  8.81958008e-03,   8.88061523e-03],
                        [  3.26538086e-03,   3.23486328e-03],
                        [  1.86157227e-03,   1.83105469e-03],
                        [  4.30297852e-03,   4.33349609e-03],
                        [  2.83813477e-03,   2.86865234e-03],
                        [ -1.02233887e-02,  -1.02539062e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -4.41284180e-02,  -4.40979004e-02],
                        [ -4.42504883e-02,  -4.43115234e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -3.05786133e-02,  -3.05480957e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.49938965e-02,  -2.50244141e-02],
                        [ -1.58996582e-02,  -1.58691406e-02],
                        [ -9.91821289e-03,  -9.88769531e-03],
                        [ -1.22680664e-02,  -1.23291016e-02],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -9.79614258e-03,  -9.76562500e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  2.07214355e-02,   2.06604004e-02],
                        [  4.09240723e-02,   4.09545898e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  6.01196289e-02,   6.00585938e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  8.75549316e-02,   8.75854492e-02],
                        [  1.02783203e-01,   1.02752686e-01],
                        [  1.02966309e-01,   1.02935791e-01],
                        [  8.62731934e-02,   8.63342285e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [ -1.26342773e-02,  -1.26647949e-02],
                        [ -9.80224609e-02,  -9.79919434e-02],
                        [ -1.79992676e-01,  -1.79992676e-01],
                        [ -2.26989746e-01,  -2.27020264e-01],
                        [ -2.26593018e-01,  -2.26562500e-01],
                        [ -1.94061279e-01,  -1.94030762e-01],
                        [ -1.57287598e-01,  -1.57318115e-01],
                        [ -1.33666992e-01,  -1.33697510e-01],
                        [ -1.21124268e-01,  -1.21093750e-01],
                        [ -1.07727051e-01,  -1.07727051e-01],
                        [ -8.71276855e-02,  -8.71582031e-02],
                        [ -6.68640137e-02,  -6.68334961e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -7.46765137e-02,  -7.47070312e-02],
                        [ -9.41467285e-02,  -9.41162109e-02],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -9.53979492e-02,  -9.54284668e-02],
                        [ -7.86743164e-02,  -7.86743164e-02],
                        [ -5.35583496e-02,  -5.35278320e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [  3.08532715e-02,   3.08227539e-02],
                        [  7.84606934e-02,   7.84912109e-02],
                        [  1.16149902e-01,   1.16180420e-01],
                        [  1.33972168e-01,   1.33941650e-01],
                        [  1.28540039e-01,   1.28540039e-01],
                        [  1.09771729e-01,   1.09832764e-01],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  8.91418457e-02,   8.91113281e-02],
                        [  9.93652344e-02,   9.93957520e-02],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.57897949e-01,   1.57867432e-01],
                        [  1.92169189e-01,   1.92169189e-01],
                        [  2.16308594e-01,   2.16369629e-01],
                        [  2.19085693e-01,   2.19055176e-01],
                        [  1.87133789e-01,   1.87103271e-01],
                        [  1.14013672e-01,   1.14074707e-01],
                        [  8.30078125e-03,   8.30078125e-03],
                        [ -1.11694336e-01,  -1.11755371e-01],
                        [ -2.22869873e-01,  -2.22869873e-01],
                        [ -2.97363281e-01,  -2.97302246e-01],
                        [ -3.12347412e-01,  -3.12377930e-01],
                        [ -2.70050049e-01,  -2.70080566e-01],
                        [ -2.03247070e-01,  -2.03186035e-01],
                        [ -1.51885986e-01,  -1.51916504e-01],
                        [ -1.32659912e-01,  -1.32690430e-01],
                        [ -1.33758545e-01,  -1.33728027e-01],
                        [ -1.36444092e-01,  -1.36413574e-01],
                        [ -1.34918213e-01,  -1.34979248e-01],
                        [ -1.35437012e-01,  -1.35437012e-01],
                        [ -1.39251709e-01,  -1.39190674e-01],
                        [ -1.35284424e-01,  -1.35314941e-01],
                        [ -1.11480713e-01,  -1.11511230e-01],
                        [ -6.46057129e-02,  -6.45751953e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  7.89184570e-02,   7.88879395e-02],
                        [  1.54174805e-01,   1.54205322e-01],
                        [  2.10601807e-01,   2.10632324e-01],
                        [  2.32910156e-01,   2.32879639e-01],
                        [  2.16552734e-01,   2.16552734e-01],
                        [  1.75048828e-01,   1.75109863e-01],
                        [  1.34216309e-01,   1.34216309e-01],
                        [  1.13342285e-01,   1.13311768e-01],
                        [  1.12426758e-01,   1.12457275e-01],
                        [  1.19720459e-01,   1.19750977e-01],
                        [  1.26251221e-01,   1.26190186e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.24816895e-01,   1.24877930e-01],
                        [  1.11419678e-01,   1.11389160e-01],
                        [  8.86840820e-02,   8.86230469e-02],
                        [  6.26525879e-02,   6.27136230e-02],
                        [  4.20837402e-02,   4.21142578e-02],
                        [  3.05175781e-02,   3.04565430e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.96228027e-02,   1.96838379e-02],
                        [  1.46484375e-02,   1.46179199e-02],
                        [  1.12304688e-02,   1.11999512e-02],
                        [  9.79614258e-03,   9.85717773e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  4.39453125e-03,   4.33349609e-03],
                        [ -3.66210938e-03,  -3.63159180e-03],
                        [ -1.46484375e-02,  -1.45874023e-02],
                        [ -2.45056152e-02,  -2.45971680e-02],
                        [ -3.15551758e-02,  -3.15856934e-02],
                        [ -3.67736816e-02,  -3.66821289e-02],
                        [ -3.82385254e-02,  -3.82690430e-02],
                        [ -3.37829590e-02,  -3.38439941e-02],
                        [ -2.65808105e-02,  -2.65197754e-02],
                        [ -1.94702148e-02,  -1.94396973e-02],
                        [ -1.09863281e-02,  -1.10778809e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -5.03540039e-03,  -4.94384766e-03],
                        [ -1.35192871e-02,  -1.35498047e-02],
                        [ -1.87072754e-02,  -1.87683105e-02],
                        [ -1.67236328e-02,  -1.66320801e-02],
                        [ -1.32446289e-02,  -1.32141113e-02],
                        [ -1.13220215e-02,  -1.14135742e-02],
                        [ -9.39941406e-03,  -9.36889648e-03],
                        [ -7.11059570e-03,  -7.04956055e-03],
                        [ -2.80761719e-03,  -2.83813477e-03],
                        [  9.00268555e-03,   8.97216797e-03],
                        [  3.08227539e-02,   3.08837891e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  7.96813965e-02,   7.96203613e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.00646973e-01,   1.00677490e-01],
                        [  9.75341797e-02,   9.75036621e-02],
                        [  8.06884766e-02,   8.06579590e-02],
                        [  5.05981445e-02,   5.06286621e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [ -5.31005859e-02,  -5.31311035e-02],
                        [ -1.25030518e-01,  -1.25000000e-01],
                        [ -1.85363770e-01,  -1.85333252e-01],
                        [ -2.10296631e-01,  -2.10327148e-01],
                        [ -1.97723389e-01,  -1.97723389e-01],
                        [ -1.66381836e-01,  -1.66320801e-01],
                        [ -1.37603760e-01,  -1.37603760e-01],
                        [ -1.21917725e-01,  -1.21948242e-01],
                        [ -1.17065430e-01,  -1.17034912e-01],
                        [ -1.14227295e-01,  -1.14196777e-01],
                        [ -1.07727051e-01,  -1.07757568e-01],
                        [ -9.97314453e-02,  -9.97314453e-02],
                        [ -9.62219238e-02,  -9.61914062e-02],
                        [ -9.91821289e-02,  -9.91821289e-02],
                        [ -1.02172852e-01,  -1.02172852e-01],
                        [ -9.62219238e-02,  -9.61914062e-02],
                        [ -7.99255371e-02,  -7.99255371e-02],
                        [ -5.61218262e-02,  -5.61523438e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [  2.38342285e-02,   2.38647461e-02],
                        [  7.73620605e-02,   7.73315430e-02],
                        [  1.21704102e-01,   1.21704102e-01],
                        [  1.40502930e-01,   1.40533447e-01],
                        [  1.29730225e-01,   1.29699707e-01],
                        [  1.03454590e-01,   1.03424072e-01],
                        [  8.43505859e-02,   8.43811035e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  1.59149170e-01,   1.59179688e-01],
                        [  1.95770264e-01,   1.95739746e-01],
                        [  2.19390869e-01,   2.19360352e-01],
                        [  2.19818115e-01,   2.19848633e-01],
                        [  1.89880371e-01,   1.89880371e-01],
                        [  1.18957520e-01,   1.18927002e-01],
                        [  5.79833984e-03,   5.82885742e-03],
                        [ -1.28082275e-01,  -1.28051758e-01],
                        [ -2.47100830e-01,  -2.47161865e-01],
                        [ -3.18328857e-01,  -3.18328857e-01],
                        [ -3.23577881e-01,  -3.23547363e-01],
                        [ -2.71911621e-01,  -2.71911621e-01],
                        [ -2.01416016e-01,  -2.01477051e-01],
                        [ -1.52893066e-01,  -1.52862549e-01],
                        [ -1.36871338e-01,  -1.36840820e-01],
                        [ -1.36260986e-01,  -1.36322021e-01],
                        [ -1.36322021e-01,  -1.36352539e-01],
                        [ -1.37786865e-01,  -1.37725830e-01],
                        [ -1.41906738e-01,  -1.41906738e-01],
                        [ -1.39526367e-01,  -1.39556885e-01],
                        [ -1.21795654e-01,  -1.21765137e-01],
                        [ -8.94165039e-02,  -8.93859863e-02],
                        [ -4.26025391e-02,  -4.26635742e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.04522705e-01,   1.04583740e-01],
                        [  1.76574707e-01,   1.76513672e-01],
                        [  2.17193604e-01,   2.17163086e-01],
                        [  2.21740723e-01,   2.21801758e-01],
                        [  2.02026367e-01,   2.02026367e-01],
                        [  1.73370361e-01,   1.73309326e-01],
                        [  1.46301270e-01,   1.46331787e-01],
                        [  1.26037598e-01,   1.26098633e-01],
                        [  1.13708496e-01,   1.13647461e-01],
                        [  1.07116699e-01,   1.07116699e-01],
                        [  1.03820801e-01,   1.03851318e-01],
                        [  1.03027344e-01,   1.02996826e-01],
                        [  1.04278564e-01,   1.04217529e-01],
                        [  1.04248047e-01,   1.04278564e-01],
                        [  9.56420898e-02,   9.56726074e-02],
                        [  7.26318359e-02,   7.26013184e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  1.52587891e-02,   1.52893066e-02],
                        [  9.33837891e-03,   9.30786133e-03],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  2.38952637e-02,   2.39257812e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  8.91113281e-03,   8.88061523e-03],
                        [  4.30297852e-03,   4.33349609e-03],
                        [  8.72802734e-03,   8.75854492e-03],
                        [  1.25427246e-02,   1.25122070e-02],
                        [  4.24194336e-03,   4.27246094e-03],
                        [ -1.35192871e-02,  -1.34887695e-02],
                        [ -2.92968750e-02,  -2.93273926e-02],
                        [ -3.89099121e-02,  -3.89404297e-02],
                        [ -4.40673828e-02,  -4.40368652e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.57775879e-02,  -1.57470703e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -2.10266113e-02,  -2.09960938e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -7.41577148e-03,  -7.44628906e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.23999023e-02,   2.23693848e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  2.19726562e-02,   2.20031738e-02],
                        [  2.60925293e-02,   2.60620117e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  3.07006836e-02,   3.07312012e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  5.13000488e-02,   5.12695312e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  6.28967285e-02,   6.29272461e-02],
                        [  6.58874512e-02,   6.58569336e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  4.26635742e-02,   4.26940918e-02],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -6.64367676e-02,  -6.64672852e-02],
                        [ -1.43402100e-01,  -1.43371582e-01],
                        [ -2.02636719e-01,  -2.02606201e-01],
                        [ -2.20153809e-01,  -2.20184326e-01],
                        [ -1.99554443e-01,  -1.99554443e-01],
                        [ -1.64855957e-01,  -1.64825439e-01],
                        [ -1.37634277e-01,  -1.37634277e-01],
                        [ -1.24969482e-01,  -1.25030518e-01],
                        [ -1.19720459e-01,  -1.19689941e-01],
                        [ -1.11053467e-01,  -1.11022949e-01],
                        [ -9.85107422e-02,  -9.85412598e-02],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -8.84094238e-02,  -8.83789062e-02],
                        [ -8.65783691e-02,  -8.66088867e-02],
                        [ -8.08715820e-02,  -8.09020996e-02],
                        [ -7.26013184e-02,  -7.25708008e-02],
                        [ -5.99975586e-02,  -5.99670410e-02],
                        [ -3.79333496e-02,  -3.79943848e-02],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  3.70178223e-02,   3.70483398e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  1.14288330e-01,   1.14257812e-01],
                        [  1.27105713e-01,   1.27136230e-01],
                        [  1.23718262e-01,   1.23748779e-01],
                        [  1.18713379e-01,   1.18682861e-01],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.36505127e-01,   1.36535645e-01],
                        [  1.56127930e-01,   1.56097412e-01],
                        [  1.78710938e-01,   1.78710938e-01],
                        [  2.01049805e-01,   2.01080322e-01],
                        [  2.15270996e-01,   2.15270996e-01],
                        [  2.08831787e-01,   2.08801270e-01],
                        [  1.69006348e-01,   1.69036865e-01],
                        [  9.04846191e-02,   9.04846191e-02],
                        [ -1.99584961e-02,  -1.99890137e-02],
                        [ -1.43859863e-01,  -1.43829346e-01],
                        [ -2.53326416e-01,  -2.53326416e-01],
                        [ -3.18115234e-01,  -3.18145752e-01],
                        [ -3.19274902e-01,  -3.19274902e-01],
                        [ -2.63702393e-01,  -2.63671875e-01],
                        [ -1.87591553e-01,  -1.87622070e-01],
                        [ -1.35040283e-01,  -1.35070801e-01],
                        [ -1.22650146e-01,  -1.22650146e-01],
                        [ -1.32934570e-01,  -1.32934570e-01],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -1.50787354e-01,  -1.50787354e-01],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -1.38153076e-01,  -1.38153076e-01],
                        [ -1.10351562e-01,  -1.10351562e-01],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  5.97534180e-02,   5.97229004e-02],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.85089111e-01,   1.85089111e-01],
                        [  2.20642090e-01,   2.20642090e-01],
                        [  2.22442627e-01,   2.22412109e-01],
                        [  1.94305420e-01,   1.94305420e-01],
                        [  1.58691406e-01,   1.58691406e-01],
                        [  1.33239746e-01,   1.33209229e-01],
                        [  1.18011475e-01,   1.17980957e-01],
                        [  1.07543945e-01,   1.07574463e-01],
                        [  1.01135254e-01,   1.01104736e-01],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.01745605e-01,   1.01776123e-01],
                        [  1.02416992e-01,   1.02447510e-01],
                        [  9.68322754e-02,   9.68017578e-02],
                        [  8.26721191e-02,   8.26721191e-02],
                        [  6.28051758e-02,   6.28662109e-02],
                        [  4.40368652e-02,   4.40063477e-02],
                        [  3.13110352e-02,   3.12805176e-02],
                        [  2.50854492e-02,   2.51464844e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.75573730e-02,   2.75268555e-02],
                        [  3.25622559e-02,   3.25927734e-02],
                        [  3.22265625e-02,   3.22570801e-02],
                        [  2.39562988e-02,   2.38952637e-02],
                        [  1.55639648e-02,   1.55334473e-02],
                        [  1.21459961e-02,   1.22070312e-02],
                        [  4.82177734e-03,   4.79125977e-03],
                        [ -1.38244629e-02,  -1.38549805e-02],
                        [ -3.26538086e-02,  -3.26232910e-02],
                        [ -3.70178223e-02,  -3.69873047e-02],
                        [ -3.12194824e-02,  -3.12805176e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -3.68041992e-02,  -3.67431641e-02],
                        [ -3.94592285e-02,  -3.94897461e-02],
                        [ -3.60107422e-02,  -3.60717773e-02],
                        [ -3.24096680e-02,  -3.23791504e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -1.77917480e-02,  -1.78527832e-02],
                        [ -6.28662109e-03,  -6.25610352e-03],
                        [  1.15966797e-03,   1.19018555e-03],
                        [  7.29370117e-03,   7.23266602e-03],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  2.23083496e-02,   2.23693848e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.93884277e-02,   2.93273926e-02],
                        [  3.46679688e-02,   3.47290039e-02],
                        [  3.67736816e-02,   3.68041992e-02],
                        [  3.54919434e-02,   3.54309082e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  4.60205078e-02,   4.60815430e-02],
                        [  6.07299805e-02,   6.06994629e-02],
                        [  7.40356445e-02,   7.40051270e-02],
                        [  7.75146484e-02,   7.75756836e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  4.94689941e-02,   4.94384766e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [ -2.74047852e-02,  -2.73742676e-02],
                        [ -9.29870605e-02,  -9.30175781e-02],
                        [ -1.63024902e-01,  -1.63024902e-01],
                        [ -2.15179443e-01,  -2.15148926e-01],
                        [ -2.32116699e-01,  -2.32116699e-01],
                        [ -2.11486816e-01,  -2.11517334e-01],
                        [ -1.69738770e-01,  -1.69708252e-01],
                        [ -1.32324219e-01,  -1.32324219e-01],
                        [ -1.13647461e-01,  -1.13677979e-01],
                        [ -1.08154297e-01,  -1.08123779e-01],
                        [ -1.02447510e-01,  -1.02416992e-01],
                        [ -9.24682617e-02,  -9.24987793e-02],
                        [ -8.61206055e-02,  -8.61511230e-02],
                        [ -8.84094238e-02,  -8.83483887e-02],
                        [ -9.10949707e-02,  -9.10949707e-02],
                        [ -8.37402344e-02,  -8.37707520e-02],
                        [ -6.57348633e-02,  -6.57043457e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -6.07299805e-03,  -6.10351562e-03],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  8.44116211e-02,   8.44421387e-02],
                        [  1.21612549e-01,   1.21582031e-01],
                        [  1.39221191e-01,   1.39190674e-01],
                        [  1.39495850e-01,   1.39526367e-01],
                        [  1.33911133e-01,   1.33911133e-01],
                        [  1.30981445e-01,   1.30950928e-01],
                        [  1.33697510e-01,   1.33697510e-01],
                        [  1.46240234e-01,   1.46270752e-01],
                        [  1.71264648e-01,   1.71234131e-01],
                        [  1.99707031e-01,   1.99707031e-01],
                        [  2.15057373e-01,   2.15087891e-01],
                        [  2.06237793e-01,   2.06237793e-01],
                        [  1.67327881e-01,   1.67297363e-01],
                        [  9.17968750e-02,   9.17968750e-02],
                        [ -2.01110840e-02,  -2.00805664e-02],
                        [ -1.50756836e-01,  -1.50787354e-01],
                        [ -2.66448975e-01,  -2.66448975e-01],
                        [ -3.29803467e-01,  -3.29772949e-01],
                        [ -3.20526123e-01,  -3.20526123e-01],
                        [ -2.54028320e-01,  -2.54058838e-01],
                        [ -1.77490234e-01,  -1.77459717e-01],
                        [ -1.33850098e-01,  -1.33819580e-01],
                        [ -1.27655029e-01,  -1.27685547e-01],
                        [ -1.33728027e-01,  -1.33728027e-01],
                        [ -1.33636475e-01,  -1.33575439e-01],
                        [ -1.29486084e-01,  -1.29516602e-01],
                        [ -1.27868652e-01,  -1.27929688e-01],
                        [ -1.23046875e-01,  -1.23016357e-01],
                        [ -9.90905762e-02,  -9.90905762e-02],
                        [ -4.65698242e-02,  -4.66003418e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  9.93652344e-02,   9.94262695e-02],
                        [  1.63116455e-01,   1.63085938e-01],
                        [  2.11395264e-01,   2.11364746e-01],
                        [  2.32147217e-01,   2.32177734e-01],
                        [  2.14508057e-01,   2.14508057e-01],
                        [  1.70166016e-01,   1.70104980e-01],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  1.03698730e-01,   1.03729248e-01],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  8.46557617e-02,   8.46252441e-02],
                        [  8.20617676e-02,   8.20922852e-02],
                        [  8.52661133e-02,   8.52661133e-02],
                        [  9.08813477e-02,   9.08203125e-02],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  9.69848633e-02,   9.70458984e-02],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  6.95800781e-02,   6.95495605e-02],
                        [  5.06591797e-02,   5.06896973e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  3.89404297e-02,   3.89099121e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  3.44543457e-02,   3.44848633e-02],
                        [  2.80456543e-02,   2.80151367e-02],
                        [  1.89819336e-02,   1.89514160e-02],
                        [  9.30786133e-03,   9.33837891e-03],
                        [  2.53295898e-03,   2.56347656e-03],
                        [  2.13623047e-04,   1.52587891e-04],
                        [ -2.53295898e-03,  -2.50244141e-03],
                        [ -1.29394531e-02,  -1.29089355e-02],
                        [ -2.93273926e-02,  -2.93579102e-02],
                        [ -4.07714844e-02,  -4.08020020e-02],
                        [ -4.20837402e-02,  -4.20532227e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -3.88183594e-02,  -3.88488770e-02],
                        [ -3.66821289e-02,  -3.66516113e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -1.62353516e-02,  -1.62963867e-02],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [  6.53076172e-03,   6.59179688e-03],
                        [  2.59399414e-03,   2.56347656e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -9.76562500e-03,  -9.73510742e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  5.37109375e-03,   5.31005859e-03],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.69677734e-02,   1.69982910e-02],
                        [  2.48413086e-02,   2.48107910e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  3.07617188e-02,   3.07922363e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  5.49621582e-02,   5.49926758e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  5.94787598e-02,   5.94482422e-02],
                        [  5.65185547e-02,   5.65490723e-02],
                        [  5.08728027e-02,   5.09033203e-02],
                        [  3.59191895e-02,   3.58886719e-02],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -5.33142090e-02,  -5.32836914e-02],
                        [ -1.24786377e-01,  -1.24816895e-01],
                        [ -1.91314697e-01,  -1.91345215e-01],
                        [ -2.29553223e-01,  -2.29553223e-01],
                        [ -2.27447510e-01,  -2.27447510e-01],
                        [ -1.92169189e-01,  -1.92199707e-01],
                        [ -1.46240234e-01,  -1.46240234e-01],
                        [ -1.12091064e-01,  -1.12060547e-01],
                        [ -9.76257324e-02,  -9.76562500e-02],
                        [ -9.59167480e-02,  -9.59167480e-02],
                        [ -9.66491699e-02,  -9.66491699e-02],
                        [ -9.64660645e-02,  -9.64660645e-02],
                        [ -9.63745117e-02,  -9.64050293e-02],
                        [ -9.41162109e-02,  -9.41162109e-02],
                        [ -8.47473145e-02,  -8.47167969e-02],
                        [ -6.53381348e-02,  -6.53686523e-02],
                        [ -3.46374512e-02,  -3.46679688e-02],
                        [  6.83593750e-03,   6.86645508e-03],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  9.64660645e-02,   9.64355469e-02],
                        [  1.26342773e-01,   1.26373291e-01],
                        [  1.39556885e-01,   1.39587402e-01],
                        [  1.39221191e-01,   1.39190674e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.30279541e-01,   1.30310059e-01],
                        [  1.37420654e-01,   1.37390137e-01],
                        [  1.57287598e-01,   1.57257080e-01],
                        [  1.84478760e-01,   1.84509277e-01],
                        [  2.05535889e-01,   2.05566406e-01],
                        [  2.06359863e-01,   2.06329346e-01],
                        [  1.78009033e-01,   1.78009033e-01],
                        [  1.14837646e-01,   1.14898682e-01],
                        [  1.46179199e-02,   1.45874023e-02],
                        [ -1.12457275e-01,  -1.12457275e-01],
                        [ -2.36816406e-01,  -2.36785889e-01],
                        [ -3.18481445e-01,  -3.18450928e-01],
                        [ -3.28735352e-01,  -3.28796387e-01],
                        [ -2.72827148e-01,  -2.72796631e-01],
                        [ -1.91253662e-01,  -1.91223145e-01],
                        [ -1.31195068e-01,  -1.31225586e-01],
                        [ -1.11114502e-01,  -1.11145020e-01],
                        [ -1.16271973e-01,  -1.16241455e-01],
                        [ -1.23901367e-01,  -1.23870850e-01],
                        [ -1.23992920e-01,  -1.24023438e-01],
                        [ -1.17492676e-01,  -1.17462158e-01],
                        [ -1.06567383e-01,  -1.06567383e-01],
                        [ -8.89892578e-02,  -8.90197754e-02],
                        [ -5.63659668e-02,  -5.63964844e-02],
                        [  3.66210938e-04,   3.96728516e-04],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  1.64306641e-01,   1.64276123e-01],
                        [  2.24548340e-01,   2.24578857e-01],
                        [  2.38830566e-01,   2.38830566e-01],
                        [  2.09838867e-01,   2.09808350e-01],
                        [  1.62933350e-01,   1.62933350e-01],
                        [  1.24206543e-01,   1.24237061e-01],
                        [  1.02142334e-01,   1.02142334e-01],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  8.38928223e-02,   8.39233398e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  8.60900879e-02,   8.60595703e-02],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  6.36901855e-02,   6.37207031e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  6.07299805e-02,   6.06994629e-02],
                        [  5.98754883e-02,   5.99060059e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  4.21447754e-02,   4.21142578e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  1.81579590e-02,   1.81884766e-02],
                        [  1.13830566e-02,   1.13525391e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.55639648e-03,   1.58691406e-03],
                        [ -3.87573242e-03,  -3.90625000e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.74255371e-02,  -1.73950195e-02],
                        [ -2.58789062e-02,  -2.58483887e-02],
                        [ -3.22875977e-02,  -3.23181152e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.92150879e-02,  -3.92456055e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  1.11389160e-02,   1.11694336e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -2.77709961e-03,  -2.74658203e-03],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  3.37829590e-02,   3.37524414e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.55432129e-02,   2.55737305e-02],
                        [  1.75476074e-02,   1.75170898e-02],
                        [  1.71203613e-02,   1.70898438e-02],
                        [  2.93273926e-02,   2.93579102e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.43725586e-02,   4.44030762e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [ -1.63574219e-02,  -1.63879395e-02],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -1.43341064e-01,  -1.43310547e-01],
                        [ -1.96044922e-01,  -1.96075439e-01],
                        [ -2.12219238e-01,  -2.12219238e-01],
                        [ -1.89392090e-01,  -1.89361572e-01],
                        [ -1.49963379e-01,  -1.49932861e-01],
                        [ -1.19903564e-01,  -1.19934082e-01],
                        [ -1.05468750e-01,  -1.05468750e-01],
                        [ -9.86328125e-02,  -9.86022949e-02],
                        [ -9.49401855e-02,  -9.49707031e-02],
                        [ -9.53674316e-02,  -9.53979492e-02],
                        [ -9.83886719e-02,  -9.83581543e-02],
                        [ -9.92431641e-02,  -9.92431641e-02],
                        [ -9.33837891e-02,  -9.33837891e-02],
                        [ -7.65991211e-02,  -7.65991211e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -3.96728516e-04,  -4.27246094e-04],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  1.46820068e-01,   1.46820068e-01],
                        [  1.60186768e-01,   1.60186768e-01],
                        [  1.48376465e-01,   1.48376465e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.40686035e-01,   1.40686035e-01],
                        [  1.70410156e-01,   1.70410156e-01],
                        [  1.99249268e-01,   1.99249268e-01],
                        [  2.08892822e-01,   2.08892822e-01],
                        [  1.99859619e-01,   1.99859619e-01],
                        [  1.72363281e-01,   1.72393799e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  1.94396973e-02,   1.94396973e-02],
                        [ -9.99450684e-02,  -9.99145508e-02],
                        [ -2.17132568e-01,  -2.17132568e-01],
                        [ -3.02185059e-01,  -3.02185059e-01],
                        [ -3.27331543e-01,  -3.27331543e-01],
                        [ -2.84454346e-01,  -2.84454346e-01],
                        [ -2.03887939e-01,  -2.03887939e-01],
                        [ -1.37359619e-01,  -1.37329102e-01],
                        [ -1.12243652e-01,  -1.12213135e-01],
                        [ -1.14959717e-01,  -1.14990234e-01],
                        [ -1.21704102e-01,  -1.21704102e-01],
                        [ -1.24847412e-01,  -1.24847412e-01],
                        [ -1.24359131e-01,  -1.24359131e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -3.41796875e-02,  -3.41491699e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  1.16363525e-01,   1.16333008e-01],
                        [  1.83898926e-01,   1.83898926e-01],
                        [  2.14660645e-01,   2.14660645e-01],
                        [  2.06726074e-01,   2.06726074e-01],
                        [  1.78436279e-01,   1.78436279e-01],
                        [  1.45874023e-01,   1.45904541e-01],
                        [  1.14685059e-01,   1.14685059e-01],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  7.82470703e-02,   7.82470703e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  7.73315430e-02,   7.73010254e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  8.25500488e-02,   8.25805664e-02],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  8.36791992e-02,   8.36486816e-02],
                        [  7.97119141e-02,   7.97424316e-02],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  6.05163574e-02,   6.05163574e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -2.73742676e-02,  -2.74047852e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.59399414e-02,  -2.59094238e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [  6.92749023e-03,   6.95800781e-03],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  6.10351562e-03,   6.13403320e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  6.09741211e-02,   6.09436035e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  2.43835449e-02,   2.44140625e-02],
                        [ -2.50244141e-02,  -2.50549316e-02],
                        [ -9.25903320e-02,  -9.26208496e-02],
                        [ -1.61865234e-01,  -1.61834717e-01],
                        [ -2.07946777e-01,  -2.07946777e-01],
                        [ -2.15148926e-01,  -2.15179443e-01],
                        [ -1.90765381e-01,  -1.90765381e-01],
                        [ -1.58477783e-01,  -1.58447266e-01],
                        [ -1.36993408e-01,  -1.36993408e-01],
                        [ -1.26617432e-01,  -1.26617432e-01],
                        [ -1.16149902e-01,  -1.16149902e-01],
                        [ -9.92126465e-02,  -9.92126465e-02],
                        [ -8.14819336e-02,  -8.15124512e-02],
                        [ -7.24792480e-02,  -7.24487305e-02],
                        [ -7.12585449e-02,  -7.12280273e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  1.30981445e-01,   1.30981445e-01],
                        [  1.49444580e-01,   1.49444580e-01],
                        [  1.63482666e-01,   1.63482666e-01],
                        [  1.78527832e-01,   1.78527832e-01],
                        [  1.90643311e-01,   1.90643311e-01],
                        [  1.95709229e-01,   1.95678711e-01],
                        [  1.95739746e-01,   1.95739746e-01],
                        [  1.89910889e-01,   1.89941406e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.10046387e-01,   1.10046387e-01],
                        [  1.82495117e-02,   1.82495117e-02],
                        [ -9.57031250e-02,  -9.57031250e-02],
                        [ -2.06939697e-01,  -2.06939697e-01],
                        [ -2.86468506e-01,  -2.86468506e-01],
                        [ -3.12591553e-01,  -3.12561035e-01],
                        [ -2.84637451e-01,  -2.84637451e-01],
                        [ -2.26593018e-01,  -2.26623535e-01],
                        [ -1.73522949e-01,  -1.73522949e-01],
                        [ -1.48895264e-01,  -1.48864746e-01],
                        [ -1.49566650e-01,  -1.49566650e-01],
                        [ -1.53930664e-01,  -1.53930664e-01],
                        [ -1.46911621e-01,  -1.46911621e-01],
                        [ -1.31256104e-01,  -1.31256104e-01],
                        [ -1.12548828e-01,  -1.12579346e-01],
                        [ -8.32519531e-02,  -8.32519531e-02],
                        [ -2.98767090e-02,  -2.98461914e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  1.34613037e-01,   1.34613037e-01],
                        [  2.02392578e-01,   2.02392578e-01],
                        [  2.30926514e-01,   2.30926514e-01],
                        [  2.15820312e-01,   2.15820312e-01],
                        [  1.73828125e-01,   1.73828125e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  9.03930664e-02,   9.03930664e-02],
                        [  7.87963867e-02,   7.87963867e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  7.21435547e-02,   7.21435547e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  6.44836426e-02,   6.44836426e-02],
                        [  6.17370605e-02,   6.17675781e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  6.59484863e-02,   6.59179688e-02],
                        [  7.08312988e-02,   7.08618164e-02],
                        [  6.79626465e-02,   6.79626465e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  3.93676758e-03,   3.96728516e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.04260254e-02,  -3.04565430e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.61230469e-02,  -2.60925293e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.84631348e-02,   1.84326172e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  2.07824707e-02,   2.07519531e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [  2.28881836e-03,   2.31933594e-03],
                        [  1.38854980e-02,   1.39160156e-02],
                        [  2.79541016e-02,   2.79235840e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -1.06689453e-01,  -1.06689453e-01],
                        [ -1.71051025e-01,  -1.71051025e-01],
                        [ -2.04101562e-01,  -2.04101562e-01],
                        [ -1.95495605e-01,  -1.95495605e-01],
                        [ -1.59698486e-01,  -1.59698486e-01],
                        [ -1.25549316e-01,  -1.25518799e-01],
                        [ -1.09405518e-01,  -1.09405518e-01],
                        [ -1.03393555e-01,  -1.03424072e-01],
                        [ -9.45434570e-02,  -9.45129395e-02],
                        [ -8.34350586e-02,  -8.34350586e-02],
                        [ -7.77587891e-02,  -7.77587891e-02],
                        [ -7.89794922e-02,  -7.89794922e-02],
                        [ -8.09020996e-02,  -8.09020996e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [  3.87573242e-02,   3.87268066e-02],
                        [  8.61511230e-02,   8.61511230e-02],
                        [  1.24084473e-01,   1.24114990e-01],
                        [  1.48101807e-01,   1.48101807e-01],
                        [  1.61041260e-01,   1.61010742e-01],
                        [  1.71844482e-01,   1.71844482e-01],
                        [  1.89086914e-01,   1.89086914e-01],
                        [  2.13226318e-01,   2.13226318e-01],
                        [  2.33001709e-01,   2.33001709e-01],
                        [  2.28942871e-01,   2.28973389e-01],
                        [  1.83807373e-01,   1.83807373e-01],
                        [  9.40856934e-02,   9.40551758e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -1.59362793e-01,  -1.59332275e-01],
                        [ -2.72003174e-01,  -2.72003174e-01],
                        [ -3.35205078e-01,  -3.35205078e-01],
                        [ -3.30535889e-01,  -3.30505371e-01],
                        [ -2.70202637e-01,  -2.70202637e-01],
                        [ -1.97113037e-01,  -1.97113037e-01],
                        [ -1.53503418e-01,  -1.53503418e-01],
                        [ -1.47125244e-01,  -1.47094727e-01],
                        [ -1.53961182e-01,  -1.53961182e-01],
                        [ -1.52709961e-01,  -1.52709961e-01],
                        [ -1.42852783e-01,  -1.42822266e-01],
                        [ -1.28601074e-01,  -1.28601074e-01],
                        [ -1.02264404e-01,  -1.02264404e-01],
                        [ -5.17272949e-02,  -5.16967773e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.12731934e-01,   1.12731934e-01],
                        [  1.88751221e-01,   1.88751221e-01],
                        [  2.29461670e-01,   2.29461670e-01],
                        [  2.29888916e-01,   2.29888916e-01],
                        [  2.04559326e-01,   2.04559326e-01],
                        [  1.70074463e-01,   1.70074463e-01],
                        [  1.32568359e-01,   1.32598877e-01],
                        [  9.42077637e-02,   9.42077637e-02],
                        [  6.37817383e-02,   6.37512207e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  7.88574219e-02,   7.88269043e-02],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  8.58459473e-02,   8.58459473e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.42712402e-02,   3.42407227e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -6.04248047e-03,  -6.07299805e-03],
                        [ -1.64794922e-02,  -1.65100098e-02],
                        [ -2.76794434e-02,  -2.76489258e-02],
                        [ -3.81774902e-02,  -3.81469727e-02],
                        [ -4.35485840e-02,  -4.35791016e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -3.92456055e-02,  -3.92150879e-02],
                        [ -3.61022949e-02,  -3.61328125e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  9.85717773e-03,   9.82666016e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -9.45739746e-02,  -9.45739746e-02],
                        [ -1.52313232e-01,  -1.52343750e-01],
                        [ -1.88598633e-01,  -1.88598633e-01],
                        [ -1.88018799e-01,  -1.88018799e-01],
                        [ -1.62506104e-01,  -1.62506104e-01],
                        [ -1.34826660e-01,  -1.34826660e-01],
                        [ -1.14318848e-01,  -1.14318848e-01],
                        [ -9.72900391e-02,  -9.72900391e-02],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -7.20214844e-02,  -7.20520020e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [  4.88281250e-04,   4.88281250e-04],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  1.19384766e-01,   1.19354248e-01],
                        [  1.67114258e-01,   1.67114258e-01],
                        [  1.94885254e-01,   1.94885254e-01],
                        [  2.10144043e-01,   2.10144043e-01],
                        [  2.21862793e-01,   2.21862793e-01],
                        [  2.30377197e-01,   2.30377197e-01],
                        [  2.26104736e-01,   2.26104736e-01],
                        [  1.95098877e-01,   1.95098877e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  2.56958008e-02,   2.57263184e-02],
                        [ -9.67712402e-02,  -9.67712402e-02],
                        [ -2.18536377e-01,  -2.18536377e-01],
                        [ -3.12469482e-01,  -3.12438965e-01],
                        [ -3.47351074e-01,  -3.47351074e-01],
                        [ -3.09967041e-01,  -3.09967041e-01],
                        [ -2.30804443e-01,  -2.30773926e-01],
                        [ -1.66992188e-01,  -1.66961670e-01],
                        [ -1.48559570e-01,  -1.48559570e-01],
                        [ -1.57196045e-01,  -1.57196045e-01],
                        [ -1.60919189e-01,  -1.60919189e-01],
                        [ -1.49078369e-01,  -1.49078369e-01],
                        [ -1.26708984e-01,  -1.26739502e-01],
                        [ -9.50012207e-02,  -9.49707031e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [  1.82495117e-02,   1.82189941e-02],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  1.73980713e-01,   1.73980713e-01],
                        [  2.16735840e-01,   2.16735840e-01],
                        [  2.14263916e-01,   2.14263916e-01],
                        [  1.81762695e-01,   1.81762695e-01],
                        [  1.48986816e-01,   1.48986816e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  7.14111328e-02,   7.14111328e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -4.45251465e-02,  -4.45556641e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.80151367e-02,   2.80456543e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  4.33959961e-02,   4.33654785e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -8.48083496e-02,  -8.48083496e-02],
                        [ -1.44317627e-01,  -1.44317627e-01],
                        [ -1.87072754e-01,  -1.87072754e-01],
                        [ -1.98547363e-01,  -1.98547363e-01],
                        [ -1.76879883e-01,  -1.76879883e-01],
                        [ -1.37054443e-01,  -1.37054443e-01],
                        [ -1.00250244e-01,  -1.00250244e-01],
                        [ -7.98645020e-02,  -7.98645020e-02],
                        [ -7.63244629e-02,  -7.63549805e-02],
                        [ -8.09020996e-02,  -8.09020996e-02],
                        [ -8.29467773e-02,  -8.29467773e-02],
                        [ -7.70874023e-02,  -7.70874023e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -4.46472168e-02,  -4.46166992e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  1.70532227e-01,   1.70532227e-01],
                        [  1.98211670e-01,   1.98211670e-01],
                        [  2.17956543e-01,   2.17987061e-01],
                        [  2.26165771e-01,   2.26165771e-01],
                        [  2.22045898e-01,   2.22045898e-01],
                        [  2.02484131e-01,   2.02514648e-01],
                        [  1.55700684e-01,   1.55700684e-01],
                        [  7.15942383e-02,   7.15637207e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -1.67480469e-01,  -1.67449951e-01],
                        [ -2.70874023e-01,  -2.70904541e-01],
                        [ -3.27972412e-01,  -3.28002930e-01],
                        [ -3.25958252e-01,  -3.25927734e-01],
                        [ -2.74505615e-01,  -2.74505615e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -1.58203125e-01,  -1.58172607e-01],
                        [ -1.44104004e-01,  -1.44104004e-01],
                        [ -1.45629883e-01,  -1.45660400e-01],
                        [ -1.37390137e-01,  -1.37390137e-01],
                        [ -1.13494873e-01,  -1.13464355e-01],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  7.70874023e-02,   7.71179199e-02],
                        [  1.46850586e-01,   1.46850586e-01],
                        [  1.96807861e-01,   1.96807861e-01],
                        [  2.12097168e-01,   2.12097168e-01],
                        [  1.93756104e-01,   1.93756104e-01],
                        [  1.60186768e-01,   1.60156250e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  8.26721191e-02,   8.26416016e-02],
                        [  6.86950684e-02,   6.87255859e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  7.40966797e-02,   7.41271973e-02],
                        [  6.94885254e-02,   6.94580078e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  5.05065918e-02,   5.04760742e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  3.79028320e-02,   3.79333496e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  2.89001465e-02,   2.88696289e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  1.42517090e-02,   1.42822266e-02],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -2.08435059e-02,  -2.08740234e-02],
                        [ -3.43017578e-02,  -3.42712402e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.22265625e-02,  -3.21960449e-02],
                        [ -3.32641602e-02,  -3.32946777e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.27966309e-02,  -2.27661133e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  1.69372559e-02,   1.69677734e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.74560547e-02,   1.74255371e-02],
                        [  1.39160156e-02,   1.39465332e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.98059082e-02,  -1.97753906e-02],
                        [ -2.27050781e-02,  -2.27355957e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [  3.05175781e-03,   3.08227539e-03],
                        [  9.03320312e-03,   9.00268555e-03],
                        [  9.79614258e-03,   9.82666016e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [ -1.46484375e-03,  -1.49536133e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  9.42993164e-03,   9.39941406e-03],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -1.67419434e-01,  -1.67419434e-01],
                        [ -1.93267822e-01,  -1.93298340e-01],
                        [ -1.81030273e-01,  -1.81030273e-01],
                        [ -1.44500732e-01,  -1.44500732e-01],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -9.62219238e-02,  -9.62219238e-02],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -8.83178711e-02,  -8.83178711e-02],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -8.02307129e-02,  -8.02307129e-02],
                        [ -6.33850098e-02,  -6.34155273e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  1.53686523e-01,   1.53686523e-01],
                        [  1.91192627e-01,   1.91192627e-01],
                        [  2.14447021e-01,   2.14447021e-01],
                        [  2.30377197e-01,   2.30377197e-01],
                        [  2.39105225e-01,   2.39105225e-01],
                        [  2.30926514e-01,   2.30957031e-01],
                        [  1.93359375e-01,   1.93359375e-01],
                        [  1.20239258e-01,   1.20239258e-01],
                        [  1.58081055e-02,   1.58386230e-02],
                        [ -1.05651855e-01,  -1.05651855e-01],
                        [ -2.21710205e-01,  -2.21710205e-01],
                        [ -3.05480957e-01,  -3.05480957e-01],
                        [ -3.34899902e-01,  -3.34899902e-01],
                        [ -3.07678223e-01,  -3.07708740e-01],
                        [ -2.49206543e-01,  -2.49206543e-01],
                        [ -1.96289062e-01,  -1.96289062e-01],
                        [ -1.68090820e-01,  -1.68090820e-01],
                        [ -1.56066895e-01,  -1.56066895e-01],
                        [ -1.41540527e-01,  -1.41540527e-01],
                        [ -1.17187500e-01,  -1.17187500e-01],
                        [ -8.76159668e-02,  -8.76159668e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  1.26251221e-01,   1.26251221e-01],
                        [  1.86492920e-01,   1.86492920e-01],
                        [  2.16766357e-01,   2.16766357e-01],
                        [  2.13928223e-01,   2.13928223e-01],
                        [  1.85913086e-01,   1.85913086e-01],
                        [  1.45416260e-01,   1.45416260e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  8.03222656e-02,   8.03222656e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  6.01196289e-02,   6.01196289e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  4.72106934e-02,   4.71801758e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  7.84301758e-02,   7.83996582e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  7.05566406e-02,   7.05871582e-02],
                        [  6.34765625e-02,   6.34765625e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  1.83410645e-02,   1.83715820e-02],
                        [  7.93457031e-03,   7.90405273e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -9.09423828e-03,  -9.06372070e-03],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -3.09448242e-02,  -3.09753418e-02],
                        [ -3.32031250e-02,  -3.31726074e-02],
                        [ -3.07312012e-02,  -3.07006836e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.30310059e-02,   1.30615234e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  1.95922852e-02,   1.95617676e-02],
                        [  2.05383301e-02,   2.05688477e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  5.06591797e-03,   5.03540039e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  6.59179688e-03,   6.56127930e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -1.84631348e-02,  -1.84326172e-02],
                        [ -2.22778320e-02,  -2.22473145e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  1.11083984e-02,   1.11389160e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  4.15039062e-02,   4.14733887e-02],
                        [  5.24291992e-02,   5.24291992e-02],
                        [  4.35180664e-02,   4.35485840e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -1.13952637e-01,  -1.13922119e-01],
                        [ -1.71295166e-01,  -1.71295166e-01],
                        [ -1.95617676e-01,  -1.95648193e-01],
                        [ -1.82098389e-01,  -1.82067871e-01],
                        [ -1.48956299e-01,  -1.48956299e-01],
                        [ -1.20971680e-01,  -1.20971680e-01],
                        [ -1.09405518e-01,  -1.09405518e-01],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -9.43603516e-02,  -9.43908691e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  1.09771729e-01,   1.09771729e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.98822021e-01,   1.98791504e-01],
                        [  2.20642090e-01,   2.20642090e-01],
                        [  2.33642578e-01,   2.33642578e-01],
                        [  2.36358643e-01,   2.36358643e-01],
                        [  2.15667725e-01,   2.15667725e-01],
                        [  1.56341553e-01,   1.56372070e-01],
                        [  5.62133789e-02,   5.62133789e-02],
                        [ -6.98242188e-02,  -6.98242188e-02],
                        [ -1.97265625e-01,  -1.97235107e-01],
                        [ -2.97454834e-01,  -2.97454834e-01],
                        [ -3.42010498e-01,  -3.42041016e-01],
                        [ -3.20983887e-01,  -3.20983887e-01],
                        [ -2.58636475e-01,  -2.58636475e-01],
                        [ -1.97692871e-01,  -1.97692871e-01],
                        [ -1.64154053e-01,  -1.64184570e-01],
                        [ -1.53656006e-01,  -1.53625488e-01],
                        [ -1.47155762e-01,  -1.47155762e-01],
                        [ -1.30889893e-01,  -1.30889893e-01],
                        [ -1.01501465e-01,  -1.01501465e-01],
                        [ -6.06994629e-02,  -6.06689453e-02],
                        [ -9.27734375e-03,  -9.30786133e-03],
                        [  5.21850586e-02,   5.21850586e-02],
                        [  1.17858887e-01,   1.17889404e-01],
                        [  1.73797607e-01,   1.73797607e-01],
                        [  2.04101562e-01,   2.04101562e-01],
                        [  2.01782227e-01,   2.01782227e-01],
                        [  1.75048828e-01,   1.75048828e-01],
                        [  1.40045166e-01,   1.40045166e-01],
                        [  1.08520508e-01,   1.08551025e-01],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  7.58666992e-02,   7.58666992e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  7.36389160e-02,   7.36389160e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  5.71289062e-02,   5.70983887e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  8.63037109e-02,   8.63037109e-02],
                        [  8.92028809e-02,   8.92028809e-02],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  7.78198242e-03,   7.75146484e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [ -1.83105469e-04,  -1.52587891e-04],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [  3.75366211e-03,   3.72314453e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.63574219e-02,  -1.63879395e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -7.93457031e-03,  -7.90405273e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [  4.76074219e-03,   4.73022461e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -1.19750977e-01,  -1.19750977e-01],
                        [ -1.73400879e-01,  -1.73431396e-01],
                        [ -1.97113037e-01,  -1.97113037e-01],
                        [ -1.87133789e-01,  -1.87103271e-01],
                        [ -1.57226562e-01,  -1.57226562e-01],
                        [ -1.26861572e-01,  -1.26861572e-01],
                        [ -1.06719971e-01,  -1.06689453e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.83807373e-01,   1.83837891e-01],
                        [  2.25006104e-01,   2.25006104e-01],
                        [  2.40783691e-01,   2.40783691e-01],
                        [  2.31597900e-01,   2.31597900e-01],
                        [  2.00744629e-01,   2.00775146e-01],
                        [  1.43615723e-01,   1.43615723e-01],
                        [  5.22155762e-02,   5.22155762e-02],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [ -1.95678711e-01,  -1.95648193e-01],
                        [ -2.93548584e-01,  -2.93579102e-01],
                        [ -3.35266113e-01,  -3.35266113e-01],
                        [ -3.15948486e-01,  -3.15948486e-01],
                        [ -2.58422852e-01,  -2.58453369e-01],
                        [ -2.01538086e-01,  -2.01538086e-01],
                        [ -1.71600342e-01,  -1.71569824e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.46057129e-01,  -1.46057129e-01],
                        [ -1.12701416e-01,  -1.12701416e-01],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.89025879e-01,   1.89025879e-01],
                        [  1.97937012e-01,   1.97937012e-01],
                        [  1.82891846e-01,   1.82891846e-01],
                        [  1.56250000e-01,   1.56280518e-01],
                        [  1.27624512e-01,   1.27624512e-01],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  6.14013672e-02,   6.13708496e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.42602539e-02,   5.42602539e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  4.10461426e-02,   4.10156250e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  8.73718262e-02,   8.74023438e-02],
                        [  7.76977539e-02,   7.76977539e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  2.56347656e-02,   2.56042480e-02],
                        [  8.33129883e-03,   8.30078125e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -2.80761719e-03,  -2.83813477e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -1.70593262e-02,  -1.70898438e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -2.96630859e-02,  -2.96325684e-02],
                        [ -2.48718262e-02,  -2.49023438e-02],
                        [ -1.49536133e-02,  -1.49841309e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  1.66931152e-02,   1.67236328e-02],
                        [  1.79748535e-02,   1.79443359e-02],
                        [  2.04162598e-02,   2.03857422e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -5.89904785e-02,  -5.89599609e-02],
                        [ -1.09985352e-01,  -1.10015869e-01],
                        [ -1.51977539e-01,  -1.51977539e-01],
                        [ -1.62780762e-01,  -1.62750244e-01],
                        [ -1.42669678e-01,  -1.42669678e-01],
                        [ -1.13525391e-01,  -1.13525391e-01],
                        [ -9.53369141e-02,  -9.53369141e-02],
                        [ -8.96606445e-02,  -8.96606445e-02],
                        [ -8.51745605e-02,  -8.51745605e-02],
                        [ -7.38830566e-02,  -7.38830566e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  5.65185547e-02,   5.65185547e-02],
                        [  1.12121582e-01,   1.12121582e-01],
                        [  1.65924072e-01,   1.65924072e-01],
                        [  2.10632324e-01,   2.10632324e-01],
                        [  2.38311768e-01,   2.38311768e-01],
                        [  2.38220215e-01,   2.38220215e-01],
                        [  2.02819824e-01,   2.02819824e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  2.68249512e-02,   2.68249512e-02],
                        [ -1.03576660e-01,  -1.03576660e-01],
                        [ -2.34863281e-01,  -2.34863281e-01],
                        [ -3.26477051e-01,  -3.26477051e-01],
                        [ -3.48510742e-01,  -3.48510742e-01],
                        [ -3.06304932e-01,  -3.06304932e-01],
                        [ -2.37121582e-01,  -2.37121582e-01],
                        [ -1.83288574e-01,  -1.83288574e-01],
                        [ -1.64093018e-01,  -1.64093018e-01],
                        [ -1.65252686e-01,  -1.65252686e-01],
                        [ -1.56433105e-01,  -1.56433105e-01],
                        [ -1.20910645e-01,  -1.20910645e-01],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  1.28723145e-01,   1.28753662e-01],
                        [  1.81762695e-01,   1.81762695e-01],
                        [  2.08526611e-01,   2.08526611e-01],
                        [  2.06115723e-01,   2.06115723e-01],
                        [  1.84692383e-01,   1.84692383e-01],
                        [  1.57135010e-01,   1.57135010e-01],
                        [  1.28387451e-01,   1.28417969e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  5.15747070e-02,   5.16052246e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  3.51867676e-02,   3.52172852e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  6.05773926e-02,   6.05773926e-02],
                        [  6.58874512e-02,   6.58874512e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  6.67114258e-02,   6.67114258e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -2.11181641e-02,  -2.11486816e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -5.15747070e-03,  -5.18798828e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  8.39233398e-03,   8.42285156e-03],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  1.66015625e-02,   1.66320801e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [ -5.49316406e-04,  -5.79833984e-04],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.49536133e-03,   1.52587891e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -3.10363770e-02,  -3.10668945e-02],
                        [ -3.25622559e-02,  -3.25317383e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -6.10351562e-04,  -5.79833984e-04],
                        [  8.23974609e-03,   8.20922852e-03],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  2.63061523e-02,   2.63366699e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -8.43811035e-02,  -8.43811035e-02],
                        [ -1.30401611e-01,  -1.30432129e-01],
                        [ -1.53594971e-01,  -1.53594971e-01],
                        [ -1.49841309e-01,  -1.49841309e-01],
                        [ -1.29333496e-01,  -1.29333496e-01],
                        [ -1.05529785e-01,  -1.05560303e-01],
                        [ -8.60900879e-02,  -8.61206055e-02],
                        [ -7.30285645e-02,  -7.30285645e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  1.07238770e-01,   1.07238770e-01],
                        [  1.69525146e-01,   1.69494629e-01],
                        [  2.21099854e-01,   2.21099854e-01],
                        [  2.40692139e-01,   2.40692139e-01],
                        [  2.20092773e-01,   2.20092773e-01],
                        [  1.61102295e-01,   1.61102295e-01],
                        [  6.71997070e-02,   6.71997070e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -1.83013916e-01,  -1.83013916e-01],
                        [ -2.86315918e-01,  -2.86315918e-01],
                        [ -3.33709717e-01,  -3.33709717e-01],
                        [ -3.17504883e-01,  -3.17504883e-01],
                        [ -2.61352539e-01,  -2.61352539e-01],
                        [ -2.05230713e-01,  -2.05230713e-01],
                        [ -1.74804688e-01,  -1.74804688e-01],
                        [ -1.64672852e-01,  -1.64672852e-01],
                        [ -1.52008057e-01,  -1.52008057e-01],
                        [ -1.21978760e-01,  -1.21978760e-01],
                        [ -7.67211914e-02,  -7.67211914e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  1.44073486e-01,   1.44073486e-01],
                        [  1.83410645e-01,   1.83410645e-01],
                        [  1.97753906e-01,   1.97753906e-01],
                        [  1.89880371e-01,   1.89880371e-01],
                        [  1.70257568e-01,   1.70257568e-01],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  1.21063232e-01,   1.21063232e-01],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  5.34973145e-02,   5.35278320e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  5.74645996e-02,   5.74340820e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  5.56640625e-02,   5.56640625e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  6.28051758e-02,   6.28356934e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  4.46777344e-02,   4.46472168e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.12915039e-03,   1.09863281e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  8.97216797e-03,   8.97216797e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.20239258e-02,  -1.20544434e-02],
                        [ -1.44042969e-02,  -1.43737793e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -1.34277344e-02,  -1.33972168e-02],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  1.97143555e-02,   1.96838379e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -1.09039307e-01,  -1.09069824e-01],
                        [ -1.43005371e-01,  -1.43005371e-01],
                        [ -1.51275635e-01,  -1.51275635e-01],
                        [ -1.34338379e-01,  -1.34338379e-01],
                        [ -1.02752686e-01,  -1.02752686e-01],
                        [ -7.16247559e-02,  -7.16247559e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -2.62756348e-02,  -2.62451172e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  9.27124023e-02,   9.27124023e-02],
                        [  1.50543213e-01,   1.50543213e-01],
                        [  2.01873779e-01,   2.01873779e-01],
                        [  2.21923828e-01,   2.21923828e-01],
                        [  1.95312500e-01,   1.95312500e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  2.30712891e-02,   2.31018066e-02],
                        [ -9.60693359e-02,  -9.60693359e-02],
                        [ -2.15240479e-01,  -2.15240479e-01],
                        [ -3.06579590e-01,  -3.06579590e-01],
                        [ -3.41949463e-01,  -3.41949463e-01],
                        [ -3.16375732e-01,  -3.16375732e-01],
                        [ -2.57720947e-01,  -2.57720947e-01],
                        [ -2.04589844e-01,  -2.04559326e-01],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -1.49017334e-01,  -1.49017334e-01],
                        [ -1.17523193e-01,  -1.17523193e-01],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -3.60717773e-02,  -3.61022949e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.56585693e-01,   1.56585693e-01],
                        [  1.75842285e-01,   1.75872803e-01],
                        [  1.75048828e-01,   1.75048828e-01],
                        [  1.67388916e-01,   1.67388916e-01],
                        [  1.58477783e-01,   1.58477783e-01],
                        [  1.43768311e-01,   1.43768311e-01],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  7.70874023e-02,   7.70874023e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  5.51452637e-02,   5.51452637e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  5.84411621e-02,   5.84411621e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  5.02929688e-02,   5.03234863e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  1.95312500e-03,   1.92260742e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [  6.10351562e-04,   6.40869141e-04],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -8.19396973e-02,  -8.19396973e-02],
                        [ -1.28509521e-01,  -1.28509521e-01],
                        [ -1.51641846e-01,  -1.51641846e-01],
                        [ -1.45599365e-01,  -1.45599365e-01],
                        [ -1.17248535e-01,  -1.17248535e-01],
                        [ -7.92236328e-02,  -7.92236328e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  1.27716064e-01,   1.27716064e-01],
                        [  1.92993164e-01,   1.92993164e-01],
                        [  2.33154297e-01,   2.33154297e-01],
                        [  2.28576660e-01,   2.28576660e-01],
                        [  1.77795410e-01,   1.77795410e-01],
                        [  8.97216797e-02,   8.97216797e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.56860352e-01,  -1.56860352e-01],
                        [ -2.77435303e-01,  -2.77435303e-01],
                        [ -3.51043701e-01,  -3.51043701e-01],
                        [ -3.54064941e-01,  -3.54064941e-01],
                        [ -3.01269531e-01,  -3.01269531e-01],
                        [ -2.37518311e-01,  -2.37518311e-01],
                        [ -1.99157715e-01,  -1.99157715e-01],
                        [ -1.85821533e-01,  -1.85821533e-01],
                        [ -1.70715332e-01,  -1.70715332e-01],
                        [ -1.34094238e-01,  -1.34094238e-01],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [  4.64782715e-02,   4.65087891e-02],
                        [  1.12548828e-01,   1.12548828e-01],
                        [  1.67816162e-01,   1.67816162e-01],
                        [  1.98699951e-01,   1.98699951e-01],
                        [  2.03918457e-01,   2.03918457e-01],
                        [  1.93572998e-01,   1.93572998e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  5.13916016e-02,   5.13610840e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  8.97827148e-02,   8.97827148e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.59912109e-02,   1.59606934e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  4.97436523e-03,   4.94384766e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -1.05407715e-01,  -1.05407715e-01],
                        [ -1.31591797e-01,  -1.31591797e-01],
                        [ -1.33789062e-01,  -1.33789062e-01],
                        [ -1.17218018e-01,  -1.17218018e-01],
                        [ -9.36889648e-02,  -9.36889648e-02],
                        [ -7.40356445e-02,  -7.40356445e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  6.75659180e-02,   6.75659180e-02],
                        [  1.29241943e-01,   1.29272461e-01],
                        [  1.90032959e-01,   1.90032959e-01],
                        [  2.38555908e-01,   2.38555908e-01],
                        [  2.51983643e-01,   2.51983643e-01],
                        [  2.13745117e-01,   2.13745117e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -1.27319336e-01,  -1.27319336e-01],
                        [ -2.60589600e-01,  -2.60589600e-01],
                        [ -3.51989746e-01,  -3.51989746e-01],
                        [ -3.73107910e-01,  -3.73107910e-01],
                        [ -3.33526611e-01,  -3.33526611e-01],
                        [ -2.73468018e-01,  -2.73468018e-01],
                        [ -2.25708008e-01,  -2.25708008e-01],
                        [ -1.93695068e-01,  -1.93695068e-01],
                        [ -1.65222168e-01,  -1.65222168e-01],
                        [ -1.31072998e-01,  -1.31072998e-01],
                        [ -8.49609375e-02,  -8.49609375e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  1.72302246e-01,   1.72302246e-01],
                        [  1.94458008e-01,   1.94458008e-01],
                        [  1.95587158e-01,   1.95587158e-01],
                        [  1.82189941e-01,   1.82189941e-01],
                        [  1.60583496e-01,   1.60583496e-01],
                        [  1.36901855e-01,   1.36901855e-01],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  7.42797852e-02,   7.42797852e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  8.58764648e-02,   8.58764648e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  6.75048828e-02,   6.75048828e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.88391113e-02,  -2.88085938e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -1.11389160e-01,  -1.11389160e-01],
                        [ -1.39251709e-01,  -1.39251709e-01],
                        [ -1.36566162e-01,  -1.36566162e-01],
                        [ -1.10748291e-01,  -1.10748291e-01],
                        [ -8.37707520e-02,  -8.37707520e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  7.84912109e-02,   7.84912109e-02],
                        [  1.34887695e-01,   1.34887695e-01],
                        [  1.94030762e-01,   1.94030762e-01],
                        [  2.30438232e-01,   2.30438232e-01],
                        [  2.22290039e-01,   2.22290039e-01],
                        [  1.62872314e-01,   1.62872314e-01],
                        [  5.89294434e-02,   5.89294434e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -2.06115723e-01,  -2.06115723e-01],
                        [ -3.11004639e-01,  -3.11004639e-01],
                        [ -3.60321045e-01,  -3.60321045e-01],
                        [ -3.47320557e-01,  -3.47320557e-01],
                        [ -2.93792725e-01,  -2.93792725e-01],
                        [ -2.35778809e-01,  -2.35778809e-01],
                        [ -1.96807861e-01,  -1.96807861e-01],
                        [ -1.73431396e-01,  -1.73431396e-01],
                        [ -1.45019531e-01,  -1.45019531e-01],
                        [ -9.69238281e-02,  -9.69238281e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  9.71984863e-02,   9.71984863e-02],
                        [  1.47125244e-01,   1.47125244e-01],
                        [  1.76574707e-01,   1.76574707e-01],
                        [  1.83929443e-01,   1.83929443e-01],
                        [  1.79046631e-01,   1.79016113e-01],
                        [  1.72149658e-01,   1.72149658e-01],
                        [  1.62017822e-01,   1.62017822e-01],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -1.00189209e-01,  -1.00189209e-01],
                        [ -1.33850098e-01,  -1.33850098e-01],
                        [ -1.36108398e-01,  -1.36108398e-01],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -6.67724609e-02,  -6.67724609e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  8.54492188e-02,   8.54492188e-02],
                        [  1.46148682e-01,   1.46148682e-01],
                        [  2.02056885e-01,   2.02056885e-01],
                        [  2.36785889e-01,   2.36785889e-01],
                        [  2.33276367e-01,   2.33276367e-01],
                        [  1.83105469e-01,   1.83105469e-01],
                        [  8.85620117e-02,   8.85620117e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -1.77642822e-01,  -1.77642822e-01],
                        [ -2.93945312e-01,  -2.93945312e-01],
                        [ -3.54980469e-01,  -3.54980469e-01],
                        [ -3.49700928e-01,  -3.49700928e-01],
                        [ -2.98889160e-01,  -2.98889160e-01],
                        [ -2.40661621e-01,  -2.40661621e-01],
                        [ -2.02514648e-01,  -2.02514648e-01],
                        [ -1.82739258e-01,  -1.82739258e-01],
                        [ -1.58416748e-01,  -1.58416748e-01],
                        [ -1.11206055e-01,  -1.11206055e-01],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  1.44195557e-01,   1.44226074e-01],
                        [  1.67083740e-01,   1.67083740e-01],
                        [  1.67083740e-01,   1.67083740e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  1.54632568e-01,   1.54632568e-01],
                        [  1.56951904e-01,   1.56951904e-01],
                        [  1.49566650e-01,   1.49566650e-01],
                        [  1.25885010e-01,   1.25885010e-01],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  7.77587891e-02,   7.77587891e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  1.95617676e-02,   1.95922852e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  4.42199707e-02,   4.42199707e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  8.78295898e-02,   8.78295898e-02],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  4.36401367e-02,   4.36401367e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -9.18579102e-03,  -9.18579102e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  2.26135254e-02,   2.25830078e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -9.61914062e-02,  -9.61914062e-02],
                        [ -1.31195068e-01,  -1.31195068e-01],
                        [ -1.38031006e-01,  -1.38000488e-01],
                        [ -1.14227295e-01,  -1.14227295e-01],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.82434082e-01,   1.82434082e-01],
                        [  2.19177246e-01,   2.19177246e-01],
                        [  2.22442627e-01,   2.22442627e-01],
                        [  1.74163818e-01,   1.74163818e-01],
                        [  7.38525391e-02,   7.38525391e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -1.98120117e-01,  -1.98120117e-01],
                        [ -3.09997559e-01,  -3.09997559e-01],
                        [ -3.65386963e-01,  -3.65386963e-01],
                        [ -3.50463867e-01,  -3.50463867e-01],
                        [ -2.85461426e-01,  -2.85461426e-01],
                        [ -2.17132568e-01,  -2.17132568e-01],
                        [ -1.79779053e-01,  -1.79779053e-01],
                        [ -1.66809082e-01,  -1.66839600e-01],
                        [ -1.47033691e-01,  -1.47033691e-01],
                        [ -1.00982666e-01,  -1.00982666e-01],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.43096924e-01,   1.43096924e-01],
                        [  1.58081055e-01,   1.58081055e-01],
                        [  1.57867432e-01,   1.57867432e-01],
                        [  1.57684326e-01,   1.57684326e-01],
                        [  1.61315918e-01,   1.61315918e-01],
                        [  1.59362793e-01,   1.59362793e-01],
                        [  1.42730713e-01,   1.42730713e-01],
                        [  1.13403320e-01,   1.13433838e-01],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  4.91333008e-02,   4.91333008e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -6.10351562e-05,  -9.15527344e-05],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.75061035e-02,  -3.75366211e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.56250000e-02,  -1.55944824e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -1.40319824e-01,  -1.40319824e-01],
                        [ -1.45721436e-01,  -1.45721436e-01],
                        [ -1.24114990e-01,  -1.24114990e-01],
                        [ -8.87756348e-02,  -8.87756348e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  1.44500732e-01,   1.44500732e-01],
                        [  1.85272217e-01,   1.85272217e-01],
                        [  2.03338623e-01,   2.03338623e-01],
                        [  1.88415527e-01,   1.88415527e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  2.03247070e-02,   2.03247070e-02],
                        [ -1.12915039e-01,  -1.12915039e-01],
                        [ -2.40295410e-01,  -2.40295410e-01],
                        [ -3.29589844e-01,  -3.29589844e-01],
                        [ -3.56719971e-01,  -3.56719971e-01],
                        [ -3.21319580e-01,  -3.21319580e-01],
                        [ -2.54394531e-01,  -2.54394531e-01],
                        [ -1.98242188e-01,  -1.98242188e-01],
                        [ -1.72210693e-01,  -1.72210693e-01],
                        [ -1.59454346e-01,  -1.59454346e-01],
                        [ -1.29394531e-01,  -1.29394531e-01],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.43524170e-01,   1.43524170e-01],
                        [  1.40899658e-01,   1.40899658e-01],
                        [  1.44042969e-01,   1.44042969e-01],
                        [  1.44989014e-01,   1.44989014e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.20727539e-01,   1.20727539e-01],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  7.57751465e-02,   7.57751465e-02],
                        [  7.83386230e-02,   7.83386230e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -1.29760742e-01,  -1.29760742e-01],
                        [ -1.34185791e-01,  -1.34185791e-01],
                        [ -1.11145020e-01,  -1.11145020e-01],
                        [ -7.25402832e-02,  -7.25402832e-02],
                        [ -3.68652344e-02,  -3.68652344e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  6.58874512e-02,   6.58874512e-02],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.50756836e-01,   1.50756836e-01],
                        [  1.82678223e-01,   1.82678223e-01],
                        [  1.89086914e-01,   1.89086914e-01],
                        [  1.51092529e-01,   1.51092529e-01],
                        [  6.53381348e-02,   6.53381348e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -1.81518555e-01,  -1.81518555e-01],
                        [ -2.91534424e-01,  -2.91534424e-01],
                        [ -3.52600098e-01,  -3.52600098e-01],
                        [ -3.49517822e-01,  -3.49517822e-01],
                        [ -2.97698975e-01,  -2.97698975e-01],
                        [ -2.32696533e-01,  -2.32696533e-01],
                        [ -1.83380127e-01,  -1.83380127e-01],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -1.25793457e-01,  -1.25793457e-01],
                        [ -8.21838379e-02,  -8.21838379e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  8.78601074e-02,   8.78601074e-02],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  1.33331299e-01,   1.33331299e-01],
                        [  1.40136719e-01,   1.40136719e-01],
                        [  1.45568848e-01,   1.45568848e-01],
                        [  1.49322510e-01,   1.49322510e-01],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.26708984e-01,   1.26708984e-01],
                        [  1.08520508e-01,   1.08520508e-01],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  8.78295898e-02,   8.78295898e-02],
                        [  8.82568359e-02,   8.82568359e-02],
                        [  8.02307129e-02,   8.02307129e-02],
                        [  6.62231445e-02,   6.62231445e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  4.29992676e-02,   4.29992676e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -9.57946777e-02,  -9.57946777e-02],
                        [ -1.22589111e-01,  -1.22589111e-01],
                        [ -1.21429443e-01,  -1.21429443e-01],
                        [ -9.88464355e-02,  -9.88464355e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  1.63482666e-01,   1.63482666e-01],
                        [  1.91711426e-01,   1.91711426e-01],
                        [  1.85943604e-01,   1.85943604e-01],
                        [  1.38549805e-01,   1.38549805e-01],
                        [  4.91333008e-02,   4.91333008e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -2.05841064e-01,  -2.05841064e-01],
                        [ -3.13262939e-01,  -3.13262939e-01],
                        [ -3.67462158e-01,  -3.67462158e-01],
                        [ -3.59802246e-01,  -3.59802246e-01],
                        [ -3.08044434e-01,  -3.08044434e-01],
                        [ -2.48352051e-01,  -2.48352051e-01],
                        [ -2.07336426e-01,  -2.07336426e-01],
                        [ -1.78588867e-01,  -1.78588867e-01],
                        [ -1.35620117e-01,  -1.35620117e-01],
                        [ -6.43920898e-02,  -6.43920898e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  1.38549805e-01,   1.38549805e-01],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.29913330e-01,   1.29913330e-01],
                        [  1.24450684e-01,   1.24450684e-01],
                        [  1.28021240e-01,   1.28021240e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  9.68017578e-02,   9.68017578e-02],
                        [  8.05664062e-02,   8.05664062e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  1.00128174e-01,   1.00128174e-01],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -8.39233398e-03,  -8.36181641e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  6.22558594e-03,   6.22558594e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -7.04650879e-02,  -7.04650879e-02],
                        [ -1.13250732e-01,  -1.13250732e-01],
                        [ -1.30401611e-01,  -1.30401611e-01],
                        [ -1.17553711e-01,  -1.17553711e-01],
                        [ -8.31298828e-02,  -8.31298828e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  7.92236328e-02,   7.92236328e-02],
                        [  1.29852295e-01,   1.29852295e-01],
                        [  1.67541504e-01,   1.67541504e-01],
                        [  1.74041748e-01,   1.74041748e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  5.72204590e-02,   5.72204590e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -1.89086914e-01,  -1.89086914e-01],
                        [ -2.99499512e-01,  -2.99499512e-01],
                        [ -3.58581543e-01,  -3.58581543e-01],
                        [ -3.53027344e-01,  -3.53027344e-01],
                        [ -2.98583984e-01,  -2.98583984e-01],
                        [ -2.31964111e-01,  -2.31964111e-01],
                        [ -1.84844971e-01,  -1.84844971e-01],
                        [ -1.59393311e-01,  -1.59393311e-01],
                        [ -1.30340576e-01,  -1.30340576e-01],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  1.16241455e-01,   1.16241455e-01],
                        [  1.33178711e-01,   1.33178711e-01],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.48864746e-01,   1.48864746e-01],
                        [  1.61132812e-01,   1.61132812e-01],
                        [  1.64550781e-01,   1.64550781e-01],
                        [  1.49230957e-01,   1.49230957e-01],
                        [  1.19201660e-01,   1.19201660e-01],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  9.01489258e-02,   9.01489258e-02],
                        [  9.80834961e-02,   9.80834961e-02],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  9.13085938e-02,   9.13085938e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  6.36596680e-02,   6.36596680e-02],
                        [  4.62646484e-02,   4.62646484e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.86767578e-02,  -1.87072754e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -7.98645020e-02,  -7.98645020e-02],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.59179688e-01,   1.59179688e-01],
                        [  1.62994385e-01,   1.62994385e-01],
                        [  1.24755859e-01,   1.24755859e-01],
                        [  3.94287109e-02,   3.94287109e-02],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -2.10266113e-01,  -2.10266113e-01],
                        [ -3.09020996e-01,  -3.09020996e-01],
                        [ -3.51867676e-01,  -3.51867676e-01],
                        [ -3.36059570e-01,  -3.36059570e-01],
                        [ -2.81768799e-01,  -2.81768799e-01],
                        [ -2.21099854e-01,  -2.21099854e-01],
                        [ -1.77215576e-01,  -1.77215576e-01],
                        [ -1.48162842e-01,  -1.48162842e-01],
                        [ -1.14166260e-01,  -1.14166260e-01],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  6.06079102e-02,   6.06079102e-02],
                        [  9.36279297e-02,   9.36279297e-02],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.21063232e-01,   1.21063232e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.57531738e-01,   1.57531738e-01],
                        [  1.68182373e-01,   1.68182373e-01],
                        [  1.62902832e-01,   1.62902832e-01],
                        [  1.40777588e-01,   1.40777588e-01],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  4.18701172e-02,   4.18701172e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  1.42913818e-01,   1.42913818e-01],
                        [  1.67907715e-01,   1.67907715e-01],
                        [  1.57409668e-01,   1.57409668e-01],
                        [  9.82666016e-02,   9.82666016e-02],
                        [ -5.27954102e-03,  -5.31005859e-03],
                        [ -1.33300781e-01,  -1.33300781e-01],
                        [ -2.57690430e-01,  -2.57690430e-01],
                        [ -3.48846436e-01,  -3.48846436e-01],
                        [ -3.85406494e-01,  -3.85406494e-01],
                        [ -3.66607666e-01,  -3.66607666e-01],
                        [ -3.12835693e-01,  -3.12835693e-01],
                        [ -2.49603271e-01,  -2.49603271e-01],
                        [ -1.90856934e-01,  -1.90856934e-01],
                        [ -1.35131836e-01,  -1.35131836e-01],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  1.30096436e-01,   1.30096436e-01],
                        [  1.52587891e-01,   1.52587891e-01],
                        [  1.48101807e-01,   1.48101807e-01],
                        [  1.34704590e-01,   1.34704590e-01],
                        [  1.29211426e-01,   1.29211426e-01],
                        [  1.34033203e-01,   1.34033203e-01],
                        [  1.37329102e-01,   1.37329102e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  8.27636719e-02,   8.27636719e-02],
                        [  7.60498047e-02,   7.60498047e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  4.95300293e-02,   4.95300293e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  3.50952148e-03,   3.50952148e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  5.21850586e-03,   5.21850586e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.62231445e-02,  -6.62231445e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  1.54174805e-01,   1.54174805e-01],
                        [  1.44592285e-01,   1.44592285e-01],
                        [  9.20104980e-02,   9.20104980e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -1.36230469e-01,  -1.36230469e-01],
                        [ -2.66937256e-01,  -2.66937256e-01],
                        [ -3.56170654e-01,  -3.56170654e-01],
                        [ -3.81042480e-01,  -3.81042480e-01],
                        [ -3.47442627e-01,  -3.47442627e-01],
                        [ -2.82501221e-01,  -2.82501221e-01],
                        [ -2.18414307e-01,  -2.18414307e-01],
                        [ -1.71203613e-01,  -1.71203613e-01],
                        [ -1.30279541e-01,  -1.30279541e-01],
                        [ -7.43103027e-02,  -7.43103027e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  1.32843018e-01,   1.32843018e-01],
                        [  1.26892090e-01,   1.26892090e-01],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  1.27105713e-01,   1.27105713e-01],
                        [  1.31011963e-01,   1.31011963e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  6.14624023e-02,   6.14624023e-02],
                        [  7.47985840e-02,   7.47985840e-02],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  6.22863770e-02,   6.22863770e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  6.80541992e-03,   6.80541992e-03],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -8.09631348e-02,  -8.09631348e-02],
                        [ -9.86938477e-02,  -9.86938477e-02],
                        [ -8.87756348e-02,  -8.87756348e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  1.03790283e-01,   1.03790283e-01],
                        [  1.43585205e-01,   1.43585205e-01],
                        [  1.68823242e-01,   1.68823242e-01],
                        [  1.68914795e-01,   1.68914795e-01],
                        [  1.31378174e-01,   1.31378174e-01],
                        [  4.52880859e-02,   4.52880859e-02],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -2.29827881e-01,  -2.29827881e-01],
                        [ -3.46527100e-01,  -3.46527100e-01],
                        [ -3.99261475e-01,  -3.99261475e-01],
                        [ -3.80981445e-01,  -3.80981445e-01],
                        [ -3.15704346e-01,  -3.15704346e-01],
                        [ -2.41088867e-01,  -2.41088867e-01],
                        [ -1.82189941e-01,  -1.82189941e-01],
                        [ -1.35772705e-01,  -1.35772705e-01],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  1.05773926e-01,   1.05773926e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  1.18652344e-01,   1.18652344e-01],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  1.03912354e-01,   1.03912354e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  9.52758789e-02,   9.52758789e-02],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.13739014e-01,   1.13739014e-01],
                        [  1.05773926e-01,   1.05773926e-01],
                        [  8.86535645e-02,   8.86535645e-02],
                        [  6.34765625e-02,   6.34765625e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  1.09863281e-03,   1.09863281e-03],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  2.28881836e-03,   2.28881836e-03],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.31988525e-01,   1.31988525e-01],
                        [  1.37298584e-01,   1.37298584e-01],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  4.56237793e-02,   4.56237793e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -2.04895020e-01,  -2.04895020e-01],
                        [ -3.18786621e-01,  -3.18786621e-01],
                        [ -3.66180420e-01,  -3.66180420e-01],
                        [ -3.41339111e-01,  -3.41339111e-01],
                        [ -2.74963379e-01,  -2.74963379e-01],
                        [ -2.06085205e-01,  -2.06085205e-01],
                        [ -1.57196045e-01,  -1.57196045e-01],
                        [ -1.24755859e-01,  -1.24755859e-01],
                        [ -8.83178711e-02,  -8.83178711e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  7.05261230e-02,   7.05261230e-02],
                        [  8.50524902e-02,   8.50524902e-02],
                        [  7.98339844e-02,   7.98339844e-02],
                        [  7.61413574e-02,   7.61413574e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  1.04949951e-01,   1.04949951e-01],
                        [  1.14349365e-01,   1.14349365e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  9.57031250e-02,   9.57031250e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  7.05261230e-02,   7.05261230e-02],
                        [  8.57238770e-02,   8.57238770e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  1.23596191e-01,   1.23596191e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  9.93957520e-02,   9.93957520e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  6.79321289e-02,   6.79321289e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -7.06787109e-02,  -7.06787109e-02],
                        [ -7.49206543e-02,  -7.49206543e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  7.68737793e-02,   7.68737793e-02],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.58142090e-01,   1.58142090e-01],
                        [  1.81945801e-01,   1.81945801e-01],
                        [  1.84417725e-01,   1.84417725e-01],
                        [  1.51092529e-01,   1.51092529e-01],
                        [  6.64672852e-02,   6.64672852e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -2.33764648e-01,  -2.33764648e-01],
                        [ -3.74725342e-01,  -3.74725342e-01],
                        [ -4.48150635e-01,  -4.48150635e-01],
                        [ -4.38568115e-01,  -4.38568115e-01],
                        [ -3.69171143e-01,  -3.69171143e-01],
                        [ -2.84088135e-01,  -2.84088135e-01],
                        [ -2.15728760e-01,  -2.15728760e-01],
                        [ -1.63574219e-01,  -1.63574219e-01],
                        [ -1.04125977e-01,  -1.04125977e-01],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  1.42608643e-01,   1.42608643e-01],
                        [  1.36779785e-01,   1.36779785e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.26129150e-01,   1.26129150e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.27136230e-01,   1.27136230e-01],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [  4.88281250e-04,   4.88281250e-04],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  8.77990723e-02,   8.77990723e-02],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  1.41296387e-01,   1.41296387e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  2.88391113e-02,   2.88391113e-02],
                        [ -1.04705811e-01,  -1.04705811e-01],
                        [ -2.53570557e-01,  -2.53570557e-01],
                        [ -3.67950439e-01,  -3.67950439e-01],
                        [ -4.13330078e-01,  -4.13330078e-01],
                        [ -3.85742188e-01,  -3.85742188e-01],
                        [ -3.10119629e-01,  -3.10119629e-01],
                        [ -2.26593018e-01,  -2.26593018e-01],
                        [ -1.63116455e-01,  -1.63116455e-01],
                        [ -1.15295410e-01,  -1.15295410e-01],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  6.05773926e-02,   6.05773926e-02],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  8.92944336e-02,   8.92944336e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.15509033e-01,   1.15509033e-01],
                        [  1.18133545e-01,   1.18133545e-01],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.03607178e-01,   1.03607178e-01],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  6.34765625e-02,   6.34765625e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -4.53796387e-02,  -4.53796387e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -2.88696289e-02,  -2.88696289e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  7.58361816e-02,   7.58361816e-02],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -1.07696533e-01,  -1.07696533e-01],
                        [ -2.25097656e-01,  -2.25097656e-01],
                        [ -3.14666748e-01,  -3.14666748e-01],
                        [ -3.44451904e-01,  -3.44451904e-01],
                        [ -3.13201904e-01,  -3.13201904e-01],
                        [ -2.49145508e-01,  -2.49145508e-01],
                        [ -1.87713623e-01,  -1.87713623e-01],
                        [ -1.45233154e-01,  -1.45233154e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  4.65698242e-02,   4.65698242e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  1.20910645e-01,   1.20910645e-01],
                        [  1.23413086e-01,   1.23413086e-01],
                        [  1.19537354e-01,   1.19537354e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  4.37316895e-02,   4.37316895e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  6.70166016e-02,   6.70166016e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  4.46472168e-02,   4.46472168e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [ -1.05590820e-01,  -1.05590820e-01],
                        [ -2.28515625e-01,  -2.28515625e-01],
                        [ -3.17199707e-01,  -3.17199707e-01],
                        [ -3.40179443e-01,  -3.40179443e-01],
                        [ -3.02337646e-01,  -3.02337646e-01],
                        [ -2.36267090e-01,  -2.36267090e-01],
                        [ -1.75781250e-01,  -1.75781250e-01],
                        [ -1.35192871e-01,  -1.35192871e-01],
                        [ -1.06719971e-01,  -1.06719971e-01],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  1.04339600e-01,   1.04339600e-01],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.24816895e-01,   1.24816895e-01],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  5.56640625e-02,   5.56640625e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  5.79223633e-02,   5.79223633e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  7.87963867e-02,   7.87963867e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  5.30395508e-02,   5.30395508e-02],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.33575439e-01,   1.33575439e-01],
                        [  1.39068604e-01,   1.39068604e-01],
                        [  1.27441406e-01,   1.27441406e-01],
                        [  9.45129395e-02,   9.45129395e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -1.74621582e-01,  -1.74621582e-01],
                        [ -2.78472900e-01,  -2.78472900e-01],
                        [ -3.37677002e-01,  -3.37677002e-01],
                        [ -3.36181641e-01,  -3.36181641e-01],
                        [ -2.87384033e-01,  -2.87384033e-01],
                        [ -2.21862793e-01,  -2.21862793e-01],
                        [ -1.63574219e-01,  -1.63574219e-01],
                        [ -1.15356445e-01,  -1.15356445e-01],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  7.44323730e-02,   7.44323730e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  7.93151855e-02,   7.93151855e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  5.48400879e-02,   5.48400879e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.46679688e-02,   3.46679688e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  1.46301270e-01,   1.46301270e-01],
                        [  1.70135498e-01,   1.70135498e-01],
                        [  1.82250977e-01,   1.82250977e-01],
                        [  1.72485352e-01,   1.72485352e-01],
                        [  1.27838135e-01,   1.27838135e-01],
                        [  4.04968262e-02,   4.04968262e-02],
                        [ -8.17565918e-02,  -8.17565918e-02],
                        [ -2.14599609e-01,  -2.14599609e-01],
                        [ -3.25531006e-01,  -3.25531006e-01],
                        [ -3.85253906e-01,  -3.85253906e-01],
                        [ -3.81866455e-01,  -3.81866455e-01],
                        [ -3.30902100e-01,  -3.30902100e-01],
                        [ -2.64434814e-01,  -2.64434814e-01],
                        [ -2.03674316e-01,  -2.03674316e-01],
                        [ -1.46514893e-01,  -1.46514893e-01],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  9.61914062e-02,   9.61914062e-02],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  8.92333984e-02,   8.92333984e-02],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  7.33642578e-02,   7.33642578e-02],
                        [  6.13708496e-02,   6.13708496e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  4.93164062e-02,   4.93164062e-02],
                        [  4.68750000e-02,   4.68750000e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -6.79931641e-02,  -6.79931641e-02],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  4.08935547e-03,   4.08935547e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.26220703e-01,   1.26220703e-01],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -9.66796875e-02,  -9.66796875e-02],
                        [ -2.06481934e-01,  -2.06481934e-01],
                        [ -2.99987793e-01,  -2.99987793e-01],
                        [ -3.53424072e-01,  -3.53424072e-01],
                        [ -3.54766846e-01,  -3.54766846e-01],
                        [ -3.11798096e-01,  -3.11798096e-01],
                        [ -2.48382568e-01,  -2.48382568e-01],
                        [ -1.87530518e-01,  -1.87530518e-01],
                        [ -1.35162354e-01,  -1.35162354e-01],
                        [ -8.12988281e-02,  -8.12988281e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  6.28356934e-02,   6.28356934e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  5.88073730e-02,   5.88073730e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -5.25207520e-02,  -5.25207520e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  5.58471680e-03,   5.58471680e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  9.45129395e-02,   9.45129395e-02],
                        [  1.29302979e-01,   1.29302979e-01],
                        [  1.51672363e-01,   1.51672363e-01],
                        [  1.53320312e-01,   1.53320312e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  7.21130371e-02,   7.21130371e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.33728027e-01,  -1.33728027e-01],
                        [ -2.46704102e-01,  -2.46704102e-01],
                        [ -3.24554443e-01,  -3.24554443e-01],
                        [ -3.49670410e-01,  -3.49670410e-01],
                        [ -3.29193115e-01,  -3.29193115e-01],
                        [ -2.85278320e-01,  -2.85278320e-01],
                        [ -2.37518311e-01,  -2.37518311e-01],
                        [ -1.91802979e-01,  -1.91802979e-01],
                        [ -1.42639160e-01,  -1.42639160e-01],
                        [ -8.24890137e-02,  -8.24890137e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  1.19812012e-01,   1.19812012e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.42425537e-01,   1.42425537e-01],
                        [  1.43646240e-01,   1.43615723e-01],
                        [  1.30920410e-01,   1.30920410e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  7.39746094e-02,   7.39440918e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  6.30493164e-02,   6.30493164e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  7.05566406e-02,   7.05566406e-02],
                        [  7.29980469e-02,   7.29980469e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [  2.04467773e-03,   2.07519531e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -2.07824707e-02,  -2.07519531e-02],
                        [ -2.32543945e-02,  -2.32238770e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -3.05175781e-04,  -2.74658203e-04],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -2.99987793e-02,  -2.99682617e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -5.26123047e-02,  -5.25817871e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -4.74853516e-02,  -4.74548340e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.98364258e-03,  -1.95312500e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  6.83593750e-03,   6.86645508e-03],
                        [  1.15051270e-02,   1.15356445e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  1.91345215e-02,   1.91650391e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [ -2.10571289e-03,  -2.07519531e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -4.24194336e-03,  -4.21142578e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  7.08312988e-02,   7.08312988e-02],
                        [  9.59472656e-02,   9.59777832e-02],
                        [  1.17584229e-01,   1.17614746e-01],
                        [  1.33148193e-01,   1.33178711e-01],
                        [  1.42395020e-01,   1.42395020e-01],
                        [  1.39190674e-01,   1.39190674e-01],
                        [  1.07330322e-01,   1.07330322e-01],
                        [  3.24096680e-02,   3.24096680e-02],
                        [ -8.06884766e-02,  -8.06884766e-02],
                        [ -2.04040527e-01,  -2.04040527e-01],
                        [ -3.00750732e-01,  -3.00750732e-01],
                        [ -3.44635010e-01,  -3.44635010e-01],
                        [ -3.33404541e-01,  -3.33404541e-01],
                        [ -2.87872314e-01,  -2.87872314e-01],
                        [ -2.36083984e-01,  -2.36053467e-01],
                        [ -1.93450928e-01,  -1.93420410e-01],
                        [ -1.56951904e-01,  -1.56951904e-01],
                        [ -1.15203857e-01,  -1.15203857e-01],
                        [ -6.27746582e-02,  -6.27746582e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  7.31811523e-02,   7.32116699e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  9.50317383e-02,   9.50317383e-02],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.06353760e-01,   1.06353760e-01],
                        [  9.50927734e-02,   9.50927734e-02],
                        [  8.34350586e-02,   8.34350586e-02],
                        [  7.08618164e-02,   7.08312988e-02],
                        [  5.35278320e-02,   5.34973145e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -1.76696777e-02,  -1.77001953e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -5.46264648e-03,  -5.49316406e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  3.32641602e-02,   3.32336426e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.02624512e-02,   5.02319336e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  2.68859863e-02,   2.68554688e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  1.44958496e-02,   1.44653320e-02],
                        [  8.33129883e-03,   8.30078125e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -5.85937500e-03,  -5.88989258e-03],
                        [ -6.46972656e-03,  -6.50024414e-03],
                        [ -5.06591797e-03,  -5.09643555e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  5.73730469e-03,   5.70678711e-03],
                        [  1.40991211e-02,   1.40686035e-02],
                        [  1.73645020e-02,   1.73339844e-02],
                        [  1.28479004e-02,   1.28173828e-02],
                        [  6.01196289e-03,   5.98144531e-03],
                        [  3.99780273e-03,   3.96728516e-03],
                        [  8.48388672e-03,   8.45336914e-03],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  1.96838379e-02,   1.96533203e-02],
                        [  1.70898438e-02,   1.70593262e-02],
                        [  8.33129883e-03,   8.30078125e-03],
                        [  0.00000000e+00,  -3.05175781e-05],
                        [ -4.27246094e-04,  -4.57763672e-04],
                        [  6.37817383e-03,   6.34765625e-03],
                        [  1.20544434e-02,   1.20239258e-02],
                        [  1.18103027e-02,   1.17797852e-02],
                        [  9.91821289e-03,   9.88769531e-03],
                        [  1.21154785e-02,   1.20544434e-02],
                        [  1.83105469e-02,   1.82800293e-02],
                        [  2.39868164e-02,   2.39562988e-02],
                        [  2.35595703e-02,   2.35290527e-02],
                        [  1.49230957e-02,   1.48925781e-02],
                        [  2.19726562e-03,   2.16674805e-03],
                        [ -8.94165039e-03,  -8.97216797e-03],
                        [ -1.68457031e-02,  -1.68762207e-02],
                        [ -2.30102539e-02,  -2.30407715e-02],
                        [ -2.80761719e-02,  -2.81066895e-02],
                        [ -3.06396484e-02,  -3.06701660e-02],
                        [ -3.03344727e-02,  -3.03649902e-02],
                        [ -2.95104980e-02,  -2.95410156e-02],
                        [ -3.14025879e-02,  -3.14331055e-02],
                        [ -3.74755859e-02,  -3.75366211e-02],
                        [ -4.59289551e-02,  -4.59594727e-02],
                        [ -5.14831543e-02,  -5.15136719e-02],
                        [ -4.88281250e-02,  -4.88586426e-02],
                        [ -3.79028320e-02,  -3.79333496e-02],
                        [ -2.55737305e-02,  -2.56042480e-02],
                        [ -1.87683105e-02,  -1.87988281e-02],
                        [ -1.67541504e-02,  -1.67846680e-02],
                        [ -1.40991211e-02,  -1.41296387e-02],
                        [ -8.91113281e-03,  -8.94165039e-03],
                        [ -5.24902344e-03,  -5.27954102e-03],
                        [ -6.80541992e-03,  -6.83593750e-03],
                        [ -1.27868652e-02,  -1.28173828e-02],
                        [ -2.09350586e-02,  -2.09655762e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.33557129e-02,  -3.33862305e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -4.97436523e-03,  -5.00488281e-03],
                        [  6.50024414e-03,   6.46972656e-03],
                        [  1.34277344e-02,   1.33972168e-02],
                        [  1.51977539e-02,   1.51672363e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.28173828e-03,   1.25122070e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  7.37304688e-02,   7.37304688e-02],
                        [  9.33227539e-02,   9.33532715e-02],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.45751953e-01,   1.45751953e-01],
                        [  1.47033691e-01,   1.47064209e-01],
                        [  1.30554199e-01,   1.30584717e-01],
                        [  8.86840820e-02,   8.87145996e-02],
                        [  1.58691406e-02,   1.58996582e-02],
                        [ -8.35571289e-02,  -8.35571289e-02],
                        [ -1.89514160e-01,  -1.89483643e-01],
                        [ -2.73101807e-01,  -2.73101807e-01],
                        [ -3.14270020e-01,  -3.14239502e-01],
                        [ -3.11859131e-01,  -3.11828613e-01],
                        [ -2.80853271e-01,  -2.80822754e-01],
                        [ -2.42156982e-01,  -2.42126465e-01],
                        [ -2.10662842e-01,  -2.10632324e-01],
                        [ -1.86126709e-01,  -1.86096191e-01],
                        [ -1.54296875e-01,  -1.54266357e-01],
                        [ -1.00830078e-01,  -1.00769043e-01],
                        [ -2.80456543e-02,  -2.79846191e-02],
                        [  4.33349609e-02,   4.33654785e-02],
                        [  9.16137695e-02,   9.16442871e-02],
                        [  1.11816406e-01,   1.11846924e-01],
                        [  1.16424561e-01,   1.16485596e-01],
                        [  1.20697021e-01,   1.20758057e-01],
                        [  1.28326416e-01,   1.28387451e-01],
                        [  1.30798340e-01,   1.30859375e-01],
                        [  1.18377686e-01,   1.18408203e-01],
                        [  9.10034180e-02,   9.10644531e-02],
                        [  5.94482422e-02,   5.95092773e-02],
                        [  3.54003906e-02,   3.54614258e-02],
                        [  2.13928223e-02,   2.14538574e-02],
                        [  9.76562500e-03,   9.82666016e-03],
                        [ -5.85937500e-03,  -5.79833984e-03],
                        [ -2.02636719e-02,  -2.02026367e-02],
                        [ -2.35900879e-02,  -2.35290527e-02],
                        [ -1.37023926e-02,  -1.36413574e-02],
                        [  3.60107422e-03,   3.66210938e-03],
                        [  2.17895508e-02,   2.18505859e-02],
                        [  3.78417969e-02,   3.79028320e-02],
                        [  5.14221191e-02,   5.14831543e-02],
                        [  6.35375977e-02,   6.36291504e-02],
                        [  7.55920410e-02,   7.56530762e-02],
                        [  8.50219727e-02,   8.50830078e-02],
                        [  8.68835449e-02,   8.69445801e-02],
                        [  8.09936523e-02,   8.10546875e-02],
                        [  7.05566406e-02,   7.06481934e-02],
                        [  5.66406250e-02,   5.67321777e-02],
                        [  3.96423340e-02,   3.97033691e-02],
                        [  2.23999023e-02,   2.24609375e-02],
                        [  9.49096680e-03,   9.55200195e-03],
                        [  2.13623047e-03,   2.19726562e-03],
                        [ -3.02124023e-03,  -2.96020508e-03],
                        [ -8.11767578e-03,  -8.05664062e-03],
                        [ -1.22070312e-02,  -1.21459961e-02],
                        [ -1.44958496e-02,  -1.44348145e-02],
                        [ -1.48925781e-02,  -1.48315430e-02],
                        [ -1.25427246e-02,  -1.24511719e-02],
                        [ -5.31005859e-03,  -5.24902344e-03],
                        [  6.50024414e-03,   6.56127930e-03],
                        [  1.79748535e-02,   1.80358887e-02],
                        [  2.46887207e-02,   2.47497559e-02],
                        [  2.72521973e-02,   2.73132324e-02],
                        [  2.82897949e-02,   2.83508301e-02],
                        [  2.83508301e-02,   2.84118652e-02],
                        [  2.52685547e-02,   2.52990723e-02],
                        [  1.72729492e-02,   1.73339844e-02],
                        [  6.74438477e-03,   6.77490234e-03],
                        [  2.13623047e-04,   2.74658203e-04],
                        [  3.32641602e-03,   3.35693359e-03],
                        [  1.29394531e-02,   1.30004883e-02],
                        [  2.16369629e-02,   2.16674805e-02],
                        [  2.81677246e-02,   2.81982422e-02],
                        [  3.45764160e-02,   3.46069336e-02],
                        [  3.82995605e-02,   3.83300781e-02],
                        [  3.49731445e-02,   3.50036621e-02],
                        [  2.45056152e-02,   2.45361328e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -4.15954590e-02,  -4.15649414e-02],
                        [ -4.72412109e-02,  -4.72106934e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.12500000e-02,  -3.12194824e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.17187500e-02,  -1.17492676e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -3.53698730e-02,  -3.54003906e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.58776855e-02,  -5.59082031e-02],
                        [ -5.64880371e-02,  -5.65185547e-02],
                        [ -4.84924316e-02,  -4.85229492e-02],
                        [ -3.50952148e-02,  -3.51257324e-02],
                        [ -2.36816406e-02,  -2.37121582e-02],
                        [ -1.66625977e-02,  -1.67236328e-02],
                        [ -1.11999512e-02,  -1.12304688e-02],
                        [ -5.49316406e-03,  -5.55419922e-03],
                        [ -3.66210938e-04,  -4.27246094e-04],
                        [  4.76074219e-03,   4.69970703e-03],
                        [  1.04064941e-02,   1.03454590e-02],
                        [  1.38549805e-02,   1.37939453e-02],
                        [  1.32446289e-02,   1.31835938e-02],
                        [  1.18103027e-02,   1.17492676e-02],
                        [  1.41296387e-02,   1.40380859e-02],
                        [  1.97143555e-02,   1.96533203e-02],
                        [  2.32238770e-02,   2.31323242e-02],
                        [  2.16369629e-02,   2.15454102e-02],
                        [  1.69677734e-02,   1.68762207e-02],
                        [  1.22985840e-02,   1.22070312e-02],
                        [  1.01928711e-02,   1.01013184e-02],
                        [  1.20239258e-02,   1.19323730e-02],
                        [  1.70898438e-02,   1.69982910e-02],
                        [  2.44750977e-02,   2.43835449e-02],
                        [  3.39050293e-02,   3.38134766e-02],
                        [  4.58679199e-02,   4.57763672e-02],
                        [  6.18896484e-02,   6.17980957e-02],
                        [  8.18176270e-02,   8.17260742e-02],
                        [  1.02203369e-01,   1.02081299e-01],
                        [  1.16973877e-01,   1.16851807e-01],
                        [  1.16577148e-01,   1.16485596e-01],
                        [  8.72802734e-02,   8.71887207e-02],
                        [  1.79138184e-02,   1.78222656e-02],
                        [ -8.68530273e-02,  -8.69445801e-02],
                        [ -2.00195312e-01,  -2.00317383e-01],
                        [ -2.85552979e-01,  -2.85675049e-01],
                        [ -3.20037842e-01,  -3.20159912e-01],
                        [ -3.08319092e-01,  -3.08441162e-01],
                        [ -2.74963379e-01,  -2.75054932e-01],
                        [ -2.42645264e-01,  -2.42767334e-01],
                        [ -2.17132568e-01,  -2.17254639e-01],
                        [ -1.88568115e-01,  -1.88659668e-01],
                        [ -1.43585205e-01,  -1.43676758e-01],
                        [ -7.90405273e-02,  -7.91320801e-02],
                        [ -6.13403320e-03,  -6.25610352e-03],
                        [  5.78308105e-02,   5.77087402e-02],
                        [  1.01562500e-01,   1.01440430e-01],
                        [  1.24511719e-01,   1.24420166e-01],
                        [  1.32629395e-01,   1.32537842e-01],
                        [  1.32415771e-01,   1.32293701e-01],
                        [  1.29638672e-01,   1.29547119e-01],
                        [  1.28204346e-01,   1.28112793e-01],
                        [  1.27227783e-01,   1.27136230e-01],
                        [  1.21490479e-01,   1.21398926e-01],
                        [  1.05773926e-01,   1.05682373e-01],
                        [  8.02307129e-02,   8.01391602e-02],
                        [  5.07812500e-02,   5.06896973e-02],
                        [  2.35595703e-02,   2.34680176e-02],
                        [  1.52587891e-03,   1.43432617e-03],
                        [ -1.42822266e-02,  -1.43737793e-02],
                        [ -2.27661133e-02,  -2.28271484e-02],
                        [ -2.25830078e-02,  -2.26745605e-02],
                        [ -1.46484375e-02,  -1.47399902e-02],
                        [ -2.25830078e-03,  -2.31933594e-03],
                        [  1.22680664e-02,   1.22070312e-02],
                        [  2.77709961e-02,   2.77099609e-02],
                        [  4.15039062e-02,   4.14428711e-02],
                        [  4.86145020e-02,   4.85534668e-02],
                        [  4.74853516e-02,   4.74243164e-02],
                        [  4.32434082e-02,   4.31823730e-02],
                        [  4.10156250e-02,   4.09851074e-02],
                        [  3.87878418e-02,   3.87573242e-02],
                        [  3.27148438e-02,   3.26843262e-02],
                        [  2.49938965e-02,   2.49633789e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  2.02636719e-02,   2.02331543e-02],
                        [  2.22473145e-02,   2.22167969e-02],
                        [  2.53295898e-02,   2.52990723e-02],
                        [  2.71911621e-02,   2.71606445e-02],
                        [  2.52380371e-02,   2.52075195e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  1.23901367e-02,   1.24206543e-02],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.46484375e-03,   1.49536133e-03],
                        [ -1.09863281e-03,  -1.06811523e-03],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [  8.23974609e-04,   8.54492188e-04],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [ -3.23486328e-03,  -3.20434570e-03],
                        [ -1.67846680e-03,  -1.61743164e-03],
                        [  7.41577148e-03,   7.47680664e-03],
                        [  2.06604004e-02,   2.07214355e-02],
                        [  3.06091309e-02,   3.06701660e-02],
                        [  3.27453613e-02,   3.28063965e-02],
                        [  2.82287598e-02,   2.82897949e-02],
                        [  2.21252441e-02,   2.21862793e-02],
                        [  1.92260742e-02,   1.93176270e-02],
                        [  2.11791992e-02,   2.12707520e-02],
                        [  2.58483887e-02,   2.59399414e-02],
                        [  2.87780762e-02,   2.88696289e-02],
                        [  2.73742676e-02,   2.74658203e-02],
                        [  2.17590332e-02,   2.18505859e-02],
                        [  1.23901367e-02,   1.24816895e-02],
                        [  3.96728516e-04,   4.88281250e-04],
                        [ -1.23291016e-02,  -1.22375488e-02],
                        [ -2.35900879e-02,  -2.34680176e-02],
                        [ -3.00903320e-02,  -2.99987793e-02],
                        [ -3.07312012e-02,  -3.06091309e-02],
                        [ -2.94189453e-02,  -2.92968750e-02],
                        [ -3.17993164e-02,  -3.16772461e-02],
                        [ -3.86352539e-02,  -3.85131836e-02],
                        [ -4.49829102e-02,  -4.48608398e-02],
                        [ -4.66003418e-02,  -4.64477539e-02],
                        [ -4.47082520e-02,  -4.45861816e-02],
                        [ -4.38232422e-02,  -4.37011719e-02],
                        [ -4.61120605e-02,  -4.59594727e-02],
                        [ -4.87670898e-02,  -4.86450195e-02],
                        [ -4.71496582e-02,  -4.69970703e-02],
                        [ -3.83911133e-02,  -3.82385254e-02],
                        [ -2.31018066e-02,  -2.29492188e-02],
                        [ -7.44628906e-03,  -7.29370117e-03],
                        [  7.62939453e-04,   9.15527344e-04],
                        [  9.15527344e-04,   1.03759766e-03],
                        [ -3.05175781e-05,   1.22070312e-04],
                        [  3.81469727e-03,   3.96728516e-03],
                        [  8.27026367e-03,   8.42285156e-03],
                        [  4.94384766e-03,   5.09643555e-03],
                        [ -4.48608398e-03,  -4.33349609e-03],
                        [ -1.17492676e-02,  -1.15966797e-02],
                        [ -1.48620605e-02,  -1.47399902e-02],
                        [ -1.63574219e-02,  -1.62048340e-02],
                        [ -1.56860352e-02,  -1.55334473e-02],
                        [ -9.67407227e-03,  -9.52148438e-03],
                        [  1.52587891e-03,   1.67846680e-03],
                        [  1.26342773e-02,   1.27563477e-02],
                        [  1.91040039e-02,   1.92260742e-02],
                        [  2.01721191e-02,   2.02941895e-02],
                        [  1.79443359e-02,   1.80664062e-02],
                        [  1.68762207e-02,   1.69982910e-02],
                        [  2.07824707e-02,   2.09350586e-02],
                        [  3.13720703e-02,   3.15246582e-02],
                        [  4.84619141e-02,   4.85839844e-02],
                        [  6.95190430e-02,   6.96411133e-02],
                        [  9.20410156e-02,   9.21630859e-02],
                        [  1.13311768e-01,   1.13403320e-01],
                        [  1.28723145e-01,   1.28845215e-01],
                        [  1.35101318e-01,   1.35192871e-01],
                        [  1.31164551e-01,   1.31286621e-01],
                        [  1.14288330e-01,   1.14379883e-01],
                        [  7.76367188e-02,   7.77282715e-02],
                        [  1.25122070e-02,   1.26037598e-02],
                        [ -8.18786621e-02,  -8.17871094e-02],
                        [ -1.90185547e-01,  -1.90093994e-01],
                        [ -2.83996582e-01,  -2.83905029e-01],
                        [ -3.36425781e-01,  -3.36334229e-01],
                        [ -3.39874268e-01,  -3.39813232e-01],
                        [ -3.08685303e-01,  -3.08624268e-01],
                        [ -2.65838623e-01,  -2.65777588e-01],
                        [ -2.28820801e-01,  -2.28759766e-01],
                        [ -1.98394775e-01,  -1.98333740e-01],
                        [ -1.59057617e-01,  -1.58996582e-01],
                        [ -9.73205566e-02,  -9.72900391e-02],
                        [ -1.90429688e-02,  -1.90124512e-02],
                        [  5.29479980e-02,   5.29785156e-02],
                        [  9.96093750e-02,   9.96398926e-02],
                        [  1.20483398e-01,   1.20483398e-01],
                        [  1.26342773e-01,   1.26373291e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.27166748e-01,   1.27166748e-01],
                        [  1.23443604e-01,   1.23413086e-01],
                        [  1.12701416e-01,   1.12670898e-01],
                        [  9.61608887e-02,   9.61303711e-02],
                        [  7.89489746e-02,   7.89184570e-02],
                        [  6.25915527e-02,   6.25610352e-02],
                        [  4.31213379e-02,   4.30603027e-02],
                        [  1.83410645e-02,   1.82800293e-02],
                        [ -5.70678711e-03,  -5.76782227e-03],
                        [ -1.97448730e-02,  -1.97753906e-02],
                        [ -2.14843750e-02,  -2.15454102e-02],
                        [ -1.43432617e-02,  -1.44042969e-02],
                        [ -1.49536133e-03,  -1.58691406e-03],
                        [  1.21154785e-02,   1.20239258e-02],
                        [  2.26440430e-02,   2.25524902e-02],
                        [  3.15246582e-02,   3.14331055e-02],
                        [  4.10156250e-02,   4.09240723e-02],
                        [  5.02624512e-02,   5.01708984e-02],
                        [  5.64575195e-02,   5.63659668e-02],
                        [  5.88989258e-02,   5.87768555e-02],
                        [  6.02416992e-02,   6.01196289e-02],
                        [  6.13403320e-02,   6.12182617e-02],
                        [  5.95397949e-02,   5.94177246e-02],
                        [  5.15747070e-02,   5.14526367e-02],
                        [  3.74145508e-02,   3.72924805e-02],
                        [  2.13623047e-02,   2.12402344e-02],
                        [  6.89697266e-03,   6.74438477e-03],
                        [ -4.85229492e-03,  -5.00488281e-03],
                        [ -1.14440918e-02,  -1.15966797e-02],
                        [ -1.27868652e-02,  -1.29394531e-02],
                        [ -1.28173828e-02,  -1.30004883e-02],
                        [ -1.51062012e-02,  -1.52893066e-02],
                        [ -2.03247070e-02,  -2.04772949e-02],
                        [ -2.41699219e-02,  -2.43225098e-02],
                        [ -2.01416016e-02,  -2.03247070e-02],
                        [ -6.19506836e-03,  -6.37817383e-03],
                        [  1.40075684e-02,   1.38244629e-02],
                        [  3.30810547e-02,   3.29284668e-02],
                        [  4.57763672e-02,   4.56237793e-02],
                        [  5.12084961e-02,   5.10253906e-02],
                        [  4.93164062e-02,   4.91333008e-02],
                        [  4.29992676e-02,   4.28466797e-02],
                        [  3.78417969e-02,   3.76892090e-02],
                        [  3.49121094e-02,   3.47290039e-02],
                        [  2.99987793e-02,   2.98156738e-02],
                        [  2.00195312e-02,   1.98364258e-02],
                        [  7.96508789e-03,   7.78198242e-03],
                        [ -1.70898438e-03,  -1.86157227e-03],
                        [ -1.06506348e-02,  -1.08337402e-02],
                        [ -1.92260742e-02,  -1.94091797e-02],
                        [ -2.16979980e-02,  -2.18811035e-02],
                        [ -1.58081055e-02,  -1.59912109e-02],
                        [ -5.09643555e-03,  -5.27954102e-03],
                        [  3.63159180e-03,   3.44848633e-03],
                        [  3.81469727e-03,   3.63159180e-03],
                        [ -5.18798828e-03,  -5.34057617e-03],
                        [ -1.94702148e-02,  -1.96228027e-02],
                        [ -3.26232910e-02,  -3.28063965e-02],
                        [ -3.82995605e-02,  -3.84826660e-02],
                        [ -3.84826660e-02,  -3.86352539e-02],
                        [ -3.86352539e-02,  -3.87878418e-02],
                        [ -3.65905762e-02,  -3.67431641e-02],
                        [ -2.86254883e-02,  -2.87780762e-02],
                        [ -1.78833008e-02,  -1.80053711e-02],
                        [ -1.03454590e-02,  -1.04980469e-02],
                        [ -8.27026367e-03,  -8.39233398e-03],
                        [ -1.05590820e-02,  -1.07116699e-02],
                        [ -1.67846680e-02,  -1.69067383e-02],
                        [ -2.24609375e-02,  -2.25830078e-02],
                        [ -1.90429688e-02,  -1.91650391e-02],
                        [ -6.50024414e-03,  -6.62231445e-03],
                        [  4.39453125e-03,   4.30297852e-03],
                        [  5.43212891e-03,   5.31005859e-03],
                        [ -7.62939453e-04,  -8.54492188e-04],
                        [ -6.16455078e-03,  -6.25610352e-03],
                        [ -7.53784180e-03,  -7.62939453e-03],
                        [ -6.37817383e-03,  -6.43920898e-03],
                        [ -4.05883789e-03,  -4.11987305e-03],
                        [ -3.84521484e-03,  -3.90625000e-03],
                        [ -8.20922852e-03,  -8.27026367e-03],
                        [ -1.19934082e-02,  -1.20544434e-02],
                        [ -7.59887695e-03,  -7.62939453e-03],
                        [  4.76074219e-03,   4.73022461e-03],
                        [  1.75170898e-02,   1.74560547e-02],
                        [  2.51770020e-02,   2.51464844e-02],
                        [  2.90222168e-02,   2.89916992e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  7.15332031e-02,   7.15637207e-02],
                        [  8.57238770e-02,   8.57543945e-02],
                        [  1.02966309e-01,   1.02996826e-01],
                        [  1.20452881e-01,   1.20483398e-01],
                        [  1.33148193e-01,   1.33178711e-01],
                        [  1.35040283e-01,   1.35070801e-01],
                        [  1.12915039e-01,   1.12945557e-01],
                        [  4.88891602e-02,   4.89501953e-02],
                        [ -5.84411621e-02,  -5.83801270e-02],
                        [ -1.82006836e-01,  -1.81915283e-01],
                        [ -2.82501221e-01,  -2.82440186e-01],
                        [ -3.32550049e-01,  -3.32458496e-01],
                        [ -3.28369141e-01,  -3.28277588e-01],
                        [ -2.90405273e-01,  -2.90313721e-01],
                        [ -2.48901367e-01,  -2.48809814e-01],
                        [ -2.18475342e-01,  -2.18383789e-01],
                        [ -1.89880371e-01,  -1.89788818e-01],
                        [ -1.47521973e-01,  -1.47399902e-01],
                        [ -8.79821777e-02,  -8.78601074e-02],
                        [ -2.17590332e-02,  -2.16369629e-02],
                        [  3.56750488e-02,   3.58276367e-02],
                        [  7.31506348e-02,   7.33032227e-02],
                        [  8.97827148e-02,   8.99353027e-02],
                        [  9.56420898e-02,   9.57946777e-02],
                        [  1.02142334e-01,   1.02294922e-01],
                        [  1.10137939e-01,   1.10321045e-01],
                        [  1.12243652e-01,   1.12396240e-01],
                        [  1.05590820e-01,   1.05773926e-01],
                        [  9.51843262e-02,   9.53674316e-02],
                        [  8.48388672e-02,   8.50219727e-02],
                        [  7.27539062e-02,   7.29370117e-02],
                        [  5.77087402e-02,   5.78918457e-02],
                        [  4.37316895e-02,   4.39147949e-02],
                        [  3.58581543e-02,   3.60412598e-02],
                        [  3.40881348e-02,   3.42712402e-02],
                        [  3.44543457e-02,   3.46374512e-02],
                        [  3.50036621e-02,   3.51867676e-02],
                        [  3.71398926e-02,   3.73535156e-02],
                        [  4.20227051e-02,   4.22363281e-02],
                        [  4.97741699e-02,   4.99572754e-02],
                        [  5.80749512e-02,   5.82885742e-02],
                        [  6.10961914e-02,   6.13098145e-02],
                        [  5.66101074e-02,   5.68237305e-02],
                        [  5.03234863e-02,   5.05371094e-02],
                        [  4.63867188e-02,   4.66003418e-02],
                        [  3.88488770e-02,   3.90625000e-02],
                        [  1.93481445e-02,   1.95617676e-02],
                        [ -9.73510742e-03,  -9.52148438e-03],
                        [ -3.46679688e-02,  -3.44848633e-02],
                        [ -4.27856445e-02,  -4.26025391e-02],
                        [ -3.33862305e-02,  -3.31726074e-02],
                        [ -1.89819336e-02,  -1.87988281e-02],
                        [ -1.42517090e-02,  -1.40380859e-02],
                        [ -2.05688477e-02,  -2.03857422e-02],
                        [ -2.56958008e-02,  -2.55126953e-02],
                        [ -1.98669434e-02,  -1.96838379e-02],
                        [ -7.29370117e-03,  -7.08007812e-03],
                        [  1.95312500e-03,   2.13623047e-03],
                        [  3.84521484e-03,   4.02832031e-03],
                        [  1.09863281e-03,   1.28173828e-03],
                        [  2.13623047e-04,   3.96728516e-04],
                        [  8.39233398e-03,   8.57543945e-03],
                        [  2.47192383e-02,   2.48718262e-02],
                        [  3.86047363e-02,   3.87878418e-02],
                        [  4.27551270e-02,   4.29077148e-02],
                        [  4.04357910e-02,   4.05578613e-02],
                        [  3.93676758e-02,   3.95202637e-02],
                        [  4.31823730e-02,   4.33349609e-02],
                        [  4.89807129e-02,   4.91027832e-02],
                        [  5.06286621e-02,   5.07812500e-02],
                        [  4.48303223e-02,   4.49523926e-02],
                        [  3.52172852e-02,   3.53088379e-02],
                        [  2.90222168e-02,   2.91137695e-02],
                        [  2.76184082e-02,   2.77099609e-02],
                        [  2.40478516e-02,   2.41394043e-02],
                        [  1.18713379e-02,   1.19628906e-02],
                        [ -6.16455078e-03,  -6.07299805e-03],
                        [ -2.09655762e-02,  -2.08740234e-02],
                        [ -2.64587402e-02,  -2.63977051e-02],
                        [ -2.28881836e-02,  -2.28271484e-02],
                        [ -1.50146484e-02,  -1.49841309e-02],
                        [ -9.76562500e-03,  -9.70458984e-03],
                        [ -1.03759766e-02,  -1.03454590e-02],
                        [ -1.50756836e-02,  -1.50451660e-02],
                        [ -2.17590332e-02,  -2.17285156e-02],
                        [ -2.82592773e-02,  -2.82287598e-02],
                        [ -3.13720703e-02,  -3.13415527e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -3.50341797e-02,  -3.50646973e-02],
                        [ -4.27856445e-02,  -4.28161621e-02],
                        [ -4.30603027e-02,  -4.31213379e-02],
                        [ -3.57971191e-02,  -3.58276367e-02],
                        [ -2.54821777e-02,  -2.55432129e-02],
                        [ -1.44348145e-02,  -1.44958496e-02],
                        [ -2.89916992e-03,  -2.96020508e-03],
                        [  5.21850586e-03,   5.15747070e-03],
                        [  6.68334961e-03,   6.62231445e-03],
                        [  5.37109375e-03,   5.27954102e-03],
                        [  4.21142578e-03,   4.11987305e-03],
                        [ -4.27246094e-04,  -5.18798828e-04],
                        [ -9.97924805e-03,  -1.01013184e-02],
                        [ -1.93481445e-02,  -1.94702148e-02],
                        [ -2.38952637e-02,  -2.39868164e-02],
                        [ -2.50854492e-02,  -2.52075195e-02],
                        [ -2.46887207e-02,  -2.48107910e-02],
                        [ -1.96533203e-02,  -1.98059082e-02],
                        [ -1.01623535e-02,  -1.02844238e-02],
                        [ -2.19726562e-03,  -2.34985352e-03],
                        [  1.95312500e-03,   1.80053711e-03],
                        [  5.27954102e-03,   5.09643555e-03],
                        [  8.45336914e-03,   8.27026367e-03],
                        [  9.61303711e-03,   9.42993164e-03],
                        [  9.70458984e-03,   9.52148438e-03],
                        [  1.30615234e-02,   1.28784180e-02],
                        [  2.16979980e-02,   2.15148926e-02],
                        [  3.24401855e-02,   3.22570801e-02],
                        [  4.25720215e-02,   4.23889160e-02],
                        [  5.37109375e-02,   5.34973145e-02],
                        [  6.86645508e-02,   6.84814453e-02],
                        [  8.82873535e-02,   8.81042480e-02],
                        [  1.11419678e-01,   1.11206055e-01],
                        [  1.33728027e-01,   1.33514404e-01],
                        [  1.45568848e-01,   1.45355225e-01],
                        [  1.35528564e-01,   1.35314941e-01],
                        [  9.50012207e-02,   9.47875977e-02],
                        [  1.86767578e-02,   1.84631348e-02],
                        [ -8.87145996e-02,  -8.89587402e-02],
                        [ -2.04986572e-01,  -2.05200195e-01],
                        [ -2.97912598e-01,  -2.98126221e-01],
                        [ -3.43536377e-01,  -3.43750000e-01],
                        [ -3.38043213e-01,  -3.38256836e-01],
                        [ -2.95928955e-01,  -2.96142578e-01],
                        [ -2.40020752e-01,  -2.40234375e-01],
                        [ -1.90765381e-01,  -1.90979004e-01],
                        [ -1.53900146e-01,  -1.54144287e-01],
                        [ -1.16088867e-01,  -1.16333008e-01],
                        [ -6.23474121e-02,  -6.25610352e-02],
                        [  2.38037109e-03,   2.16674805e-03],
                        [  5.69152832e-02,   5.67016602e-02],
                        [  8.71276855e-02,   8.69140625e-02],
                        [  9.66491699e-02,   9.64355469e-02],
                        [  9.48791504e-02,   9.46655273e-02],
                        [  8.84399414e-02,   8.82263184e-02],
                        [  8.37097168e-02,   8.35266113e-02],
                        [  8.30688477e-02,   8.28857422e-02],
                        [  8.09326172e-02,   8.07495117e-02],
                        [  7.27844238e-02,   7.26013184e-02],
                        [  6.22863770e-02,   6.21032715e-02],
                        [  5.47180176e-02,   5.45349121e-02],
                        [  4.85839844e-02,   4.84008789e-02],
                        [  3.89404297e-02,   3.87573242e-02],
                        [  2.64892578e-02,   2.63366699e-02],
                        [  1.81884766e-02,   1.80358887e-02],
                        [  2.00805664e-02,   1.99279785e-02],
                        [  3.20434570e-02,   3.18908691e-02],
                        [  4.78210449e-02,   4.76989746e-02],
                        [  6.12792969e-02,   6.11572266e-02],
                        [  7.13195801e-02,   7.11975098e-02],
                        [  7.94067383e-02,   7.92846680e-02],
                        [  8.47778320e-02,   8.46862793e-02],
                        [  8.34350586e-02,   8.33129883e-02],
                        [  7.24487305e-02,   7.23571777e-02],
                        [  5.36804199e-02,   5.35888672e-02],
                        [  3.02429199e-02,   3.01513672e-02],
                        [  4.88281250e-03,   4.79125977e-03],
                        [ -1.74255371e-02,  -1.75170898e-02],
                        [ -3.09143066e-02,  -3.09753418e-02],
                        [ -3.42407227e-02,  -3.43017578e-02],
                        [ -3.22875977e-02,  -3.23181152e-02],
                        [ -3.18603516e-02,  -3.19213867e-02],
                        [ -3.45764160e-02,  -3.46374512e-02],
                        [ -3.68347168e-02,  -3.68652344e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.89208984e-03,  -1.86157227e-03],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  2.09045410e-02,   2.09350586e-02],
                        [  2.58789062e-02,   2.59094238e-02],
                        [  3.34472656e-02,   3.34777832e-02],
                        [  4.40979004e-02,   4.41284180e-02],
                        [  5.20019531e-02,   5.20324707e-02],
                        [  5.36499023e-02,   5.37109375e-02],
                        [  5.07812500e-02,   5.08728027e-02],
                        [  4.50744629e-02,   4.51354980e-02],
                        [  3.79028320e-02,   3.79638672e-02],
                        [  3.27758789e-02,   3.28674316e-02],
                        [  3.13415527e-02,   3.14331055e-02],
                        [  3.08227539e-02,   3.09143066e-02],
                        [  2.84729004e-02,   2.85949707e-02],
                        [  2.60314941e-02,   2.61230469e-02],
                        [  2.59094238e-02,   2.60314941e-02],
                        [  2.49938965e-02,   2.51159668e-02],
                        [  1.74865723e-02,   1.76086426e-02],
                        [  3.87573242e-03,   4.02832031e-03],
                        [ -9.67407227e-03,  -9.55200195e-03],
                        [ -1.98669434e-02,  -1.97143555e-02],
                        [ -2.79235840e-02,  -2.77709961e-02],
                        [ -3.41186523e-02,  -3.39660645e-02],
                        [ -3.64379883e-02,  -3.62548828e-02],
                        [ -3.56140137e-02,  -3.54614258e-02],
                        [ -3.39965820e-02,  -3.38134766e-02],
                        [ -3.05786133e-02,  -3.03955078e-02],
                        [ -2.44750977e-02,  -2.42919922e-02],
                        [ -1.93481445e-02,  -1.91650391e-02],
                        [ -1.86157227e-02,  -1.84326172e-02],
                        [ -2.00500488e-02,  -1.98364258e-02],
                        [ -1.98974609e-02,  -1.97143555e-02],
                        [ -1.96838379e-02,  -1.94702148e-02],
                        [ -2.26745605e-02,  -2.24609375e-02],
                        [ -2.74353027e-02,  -2.71911621e-02],
                        [ -2.97546387e-02,  -2.95410156e-02],
                        [ -2.82592773e-02,  -2.80456543e-02],
                        [ -2.42309570e-02,  -2.40173340e-02],
                        [ -1.91650391e-02,  -1.89514160e-02],
                        [ -1.46179199e-02,  -1.43737793e-02],
                        [ -1.20239258e-02,  -1.18103027e-02],
                        [ -1.01318359e-02,  -9.88769531e-03],
                        [ -5.76782227e-03,  -5.55419922e-03],
                        [  1.31225586e-03,   1.52587891e-03],
                        [  8.27026367e-03,   8.48388672e-03],
                        [  1.16882324e-02,   1.19018555e-02],
                        [  8.66699219e-03,   8.91113281e-03],
                        [ -1.06811523e-03,  -8.54492188e-04],
                        [ -1.40991211e-02,  -1.38854980e-02],
                        [ -2.57263184e-02,  -2.54821777e-02],
                        [ -3.25622559e-02,  -3.23486328e-02],
                        [ -3.27148438e-02,  -3.25012207e-02],
                        [ -2.47192383e-02,  -2.45056152e-02],
                        [ -9.36889648e-03,  -9.15527344e-03],
                        [  8.85009766e-03,   9.06372070e-03],
                        [  2.48718262e-02,   2.50854492e-02],
                        [  3.66210938e-02,   3.68347168e-02],
                        [  4.51354980e-02,   4.53491211e-02],
                        [  5.24291992e-02,   5.26123047e-02],
                        [  5.89294434e-02,   5.91430664e-02],
                        [  6.39038086e-02,   6.40869141e-02],
                        [  6.69250488e-02,   6.71081543e-02],
                        [  6.80236816e-02,   6.82067871e-02],
                        [  6.86340332e-02,   6.88171387e-02],
                        [  7.16247559e-02,   7.17773438e-02],
                        [  7.85522461e-02,   7.87048340e-02],
                        [  8.72192383e-02,   8.73718262e-02],
                        [  8.96911621e-02,   8.98437500e-02],
                        [  7.12585449e-02,   7.14111328e-02],
                        [  1.65710449e-02,   1.67236328e-02],
                        [ -7.74230957e-02,  -7.72705078e-02],
                        [ -1.92413330e-01,  -1.92291260e-01],
                        [ -2.94067383e-01,  -2.93945312e-01],
                        [ -3.48876953e-01,  -3.48785400e-01],
                        [ -3.43963623e-01,  -3.43872070e-01],
                        [ -2.96417236e-01,  -2.96325684e-01],
                        [ -2.39044189e-01,  -2.38952637e-01],
                        [ -1.94274902e-01,  -1.94183350e-01],
                        [ -1.61376953e-01,  -1.61285400e-01],
                        [ -1.25549316e-01,  -1.25457764e-01],
                        [ -7.53784180e-02,  -7.53173828e-02],
                        [ -1.28479004e-02,  -1.27868652e-02],
                        [  4.83703613e-02,   4.84313965e-02],
                        [  9.18273926e-02,   9.18884277e-02],
                        [  1.11358643e-01,   1.11389160e-01],
                        [  1.15356445e-01,   1.15386963e-01],
                        [  1.17309570e-01,   1.17340088e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.30432129e-01,   1.30432129e-01],
                        [  1.27746582e-01,   1.27716064e-01],
                        [  1.13586426e-01,   1.13555908e-01],
                        [  9.22851562e-02,   9.22546387e-02],
                        [  6.89392090e-02,   6.88781738e-02],
                        [  4.80346680e-02,   4.80041504e-02],
                        [  3.14025879e-02,   3.13415527e-02],
                        [  1.82800293e-02,   1.82495117e-02],
                        [  9.06372070e-03,   9.00268555e-03],
                        [  5.55419922e-03,   5.46264648e-03],
                        [  8.66699219e-03,   8.57543945e-03],
                        [  1.63574219e-02,   1.62658691e-02],
                        [  2.63366699e-02,   2.62451172e-02],
                        [  3.80859375e-02,   3.79638672e-02],
                        [  4.92553711e-02,   4.91333008e-02],
                        [  5.73425293e-02,   5.72204590e-02],
                        [  6.21948242e-02,   6.20727539e-02],
                        [  6.10046387e-02,   6.08825684e-02],
                        [  4.97131348e-02,   4.95910645e-02],
                        [  2.98767090e-02,   2.97241211e-02],
                        [  7.96508789e-03,   7.81250000e-03],
                        [ -9.49096680e-03,  -9.64355469e-03],
                        [ -1.95617676e-02,  -1.97448730e-02],
                        [ -2.31933594e-02,  -2.33459473e-02],
                        [ -2.28881836e-02,  -2.30712891e-02],
                        [ -2.34680176e-02,  -2.36511230e-02],
                        [ -2.88696289e-02,  -2.90527344e-02],
                        [ -3.66821289e-02,  -3.68652344e-02],
                        [ -3.99780273e-02,  -4.01611328e-02],
                        [ -3.28979492e-02,  -3.31115723e-02],
                        [ -1.53808594e-02,  -1.55944824e-02],
                        [  6.62231445e-03,   6.40869141e-03],
                        [  2.63366699e-02,   2.61230469e-02],
                        [  3.87878418e-02,   3.85742188e-02],
                        [  4.24804688e-02,   4.22668457e-02],
                        [  4.26025391e-02,   4.23889160e-02],
                        [  4.63562012e-02,   4.61425781e-02],
                        [  5.45959473e-02,   5.43518066e-02],
                        [  6.04248047e-02,   6.02111816e-02],
                        [  5.60913086e-02,   5.58776855e-02],
                        [  4.26940918e-02,   4.24499512e-02],
                        [  2.98767090e-02,   2.96325684e-02],
                        [  2.42614746e-02,   2.40478516e-02],
                        [  2.41394043e-02,   2.38952637e-02],
                        [  2.54516602e-02,   2.52380371e-02],
                        [  2.68249512e-02,   2.65808105e-02],
                        [  2.64587402e-02,   2.62145996e-02],
                        [  2.14843750e-02,   2.12707520e-02],
                        [  1.30004883e-02,   1.27868652e-02],
                        [  4.88281250e-03,   4.66918945e-03],
                        [ -2.65502930e-03,  -2.89916992e-03],
                        [ -1.08337402e-02,  -1.10778809e-02],
                        [ -1.78527832e-02,  -1.80664062e-02],
                        [ -2.20031738e-02,  -2.22167969e-02],
                        [ -2.42004395e-02,  -2.44140625e-02],
                        [ -2.60314941e-02,  -2.62451172e-02],
                        [ -2.85949707e-02,  -2.88085938e-02],
                        [ -3.17993164e-02,  -3.20129395e-02],
                        [ -3.41491699e-02,  -3.43322754e-02],
                        [ -3.39660645e-02,  -3.41491699e-02],
                        [ -2.88085938e-02,  -2.89916992e-02],
                        [ -1.64489746e-02,  -1.66625977e-02],
                        [ -1.15966797e-03,  -1.34277344e-03],
                        [  8.20922852e-03,   8.02612305e-03],
                        [  8.78906250e-03,   8.60595703e-03],
                        [  3.78417969e-03,   3.60107422e-03],
                        [ -4.97436523e-03,  -5.12695312e-03],
                        [ -1.62048340e-02,  -1.63574219e-02],
                        [ -2.55432129e-02,  -2.56958008e-02],
                        [ -2.85949707e-02,  -2.87475586e-02],
                        [ -2.68249512e-02,  -2.69470215e-02],
                        [ -2.52685547e-02,  -2.53906250e-02],
                        [ -2.49633789e-02,  -2.51159668e-02],
                        [ -2.43835449e-02,  -2.45056152e-02],
                        [ -2.41394043e-02,  -2.42309570e-02],
                        [ -2.39868164e-02,  -2.41088867e-02],
                        [ -2.12097168e-02,  -2.13012695e-02],
                        [ -1.45568848e-02,  -1.46484375e-02],
                        [ -5.52368164e-03,  -5.61523438e-03],
                        [  3.50952148e-03,   3.41796875e-03],
                        [  8.42285156e-03,   8.36181641e-03],
                        [  5.09643555e-03,   5.03540039e-03],
                        [ -4.45556641e-03,  -4.51660156e-03],
                        [ -1.16882324e-02,  -1.17492676e-02],
                        [ -1.07727051e-02,  -1.08032227e-02],
                        [ -3.41796875e-03,  -3.44848633e-03],
                        [  5.76782227e-03,   5.73730469e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.89819336e-02,   1.90124512e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  1.95922852e-02,   1.96228027e-02],
                        [  2.75573730e-02,   2.75878906e-02],
                        [  4.04052734e-02,   4.04357910e-02],
                        [  5.72204590e-02,   5.72509766e-02],
                        [  7.69958496e-02,   7.70263672e-02],
                        [  9.95483398e-02,   9.96093750e-02],
                        [  1.24328613e-01,   1.24389648e-01],
                        [  1.42639160e-01,   1.42700195e-01],
                        [  1.39160156e-01,   1.39221191e-01],
                        [  1.03179932e-01,   1.03271484e-01],
                        [  3.37524414e-02,   3.38439941e-02],
                        [ -6.38427734e-02,  -6.37512207e-02],
                        [ -1.76849365e-01,  -1.76727295e-01],
                        [ -2.78228760e-01,  -2.78106689e-01],
                        [ -3.35784912e-01,  -3.35662842e-01],
                        [ -3.37432861e-01,  -3.37310791e-01],
                        [ -3.00323486e-01,  -3.00170898e-01],
                        [ -2.53265381e-01,  -2.53112793e-01],
                        [ -2.14447021e-01,  -2.14294434e-01],
                        [ -1.81701660e-01,  -1.81549072e-01],
                        [ -1.40930176e-01,  -1.40777588e-01],
                        [ -8.23669434e-02,  -8.22143555e-02],
                        [ -1.17492676e-02,  -1.15966797e-02],
                        [  5.14221191e-02,   5.15747070e-02],
                        [  9.00573730e-02,   9.02404785e-02],
                        [  1.04431152e-01,   1.04614258e-01],
                        [  1.06506348e-01,   1.06719971e-01],
                        [  1.06140137e-01,   1.06323242e-01],
                        [  1.07391357e-01,   1.07604980e-01],
                        [  1.10473633e-01,   1.10656738e-01],
                        [  1.11022949e-01,   1.11236572e-01],
                        [  1.02508545e-01,   1.02722168e-01],
                        [  8.26721191e-02,   8.28857422e-02],
                        [  5.70068359e-02,   5.72509766e-02],
                        [  3.39355469e-02,   3.41491699e-02],
                        [  1.69677734e-02,   1.72119141e-02],
                        [  4.11987305e-03,   4.33349609e-03],
                        [ -4.39453125e-03,  -4.15039062e-03],
                        [ -2.80761719e-03,  -2.59399414e-03],
                        [  1.08947754e-02,   1.11389160e-02],
                        [  2.99377441e-02,   3.01818848e-02],
                        [  4.79125977e-02,   4.81262207e-02],
                        [  6.47277832e-02,   6.49414062e-02],
                        [  7.93762207e-02,   7.95898438e-02],
                        [  8.57543945e-02,   8.59985352e-02],
                        [  7.99560547e-02,   8.02001953e-02],
                        [  6.45751953e-02,   6.47888184e-02],
                        [  4.42810059e-02,   4.45251465e-02],
                        [  2.27050781e-02,   2.29492188e-02],
                        [  3.75366211e-03,   3.96728516e-03],
                        [ -9.85717773e-03,  -9.61303711e-03],
                        [ -1.95617676e-02,  -1.93176270e-02],
                        [ -2.84118652e-02,  -2.81677246e-02],
                        [ -3.59191895e-02,  -3.57055664e-02],
                        [ -3.99475098e-02,  -3.97338867e-02],
                        [ -3.87878418e-02,  -3.86047363e-02],
                        [ -3.02734375e-02,  -3.00598145e-02],
                        [ -1.46179199e-02,  -1.44348145e-02],
                        [  3.23486328e-03,   3.44848633e-03],
                        [  1.87683105e-02,   1.89819336e-02],
                        [  3.02734375e-02,   3.04565430e-02],
                        [  3.69873047e-02,   3.71704102e-02],
                        [  3.81164551e-02,   3.82995605e-02],
                        [  3.33862305e-02,   3.35693359e-02],
                        [  2.45666504e-02,   2.47192383e-02],
                        [  1.46789551e-02,   1.48315430e-02],
                        [  7.41577148e-03,   7.56835938e-03],
                        [  6.98852539e-03,   7.14111328e-03],
                        [  1.24206543e-02,   1.25427246e-02],
                        [  1.77612305e-02,   1.78833008e-02],
                        [  2.25219727e-02,   2.26440430e-02],
                        [  3.10668945e-02,   3.11889648e-02],
                        [  4.17175293e-02,   4.18395996e-02],
                        [  4.68444824e-02,   4.69360352e-02],
                        [  4.33959961e-02,   4.34875488e-02],
                        [  3.58581543e-02,   3.59497070e-02],
                        [  2.86560059e-02,   2.87475586e-02],
                        [  2.28271484e-02,   2.28881836e-02],
                        [  1.82800293e-02,   1.83410645e-02],
                        [  1.37634277e-02,   1.38244629e-02],
                        [  8.97216797e-03,   9.03320312e-03],
                        [  6.59179688e-03,   6.65283203e-03],
                        [  5.95092773e-03,   5.98144531e-03],
                        [  2.28881836e-03,   2.31933594e-03],
                        [ -4.51660156e-03,  -4.48608398e-03],
                        [ -1.08947754e-02,  -1.08642578e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.70898438e-02,  -1.71203613e-02],
                        [ -2.00195312e-02,  -2.00805664e-02],
                        [ -2.71911621e-02,  -2.72521973e-02],
                        [ -3.57055664e-02,  -3.57666016e-02],
                        [ -4.21752930e-02,  -4.22363281e-02],
                        [ -4.37316895e-02,  -4.38232422e-02],
                        [ -3.93371582e-02,  -3.94287109e-02],
                        [ -3.08227539e-02,  -3.09143066e-02],
                        [ -2.21862793e-02,  -2.22778320e-02],
                        [ -1.70593262e-02,  -1.71508789e-02],
                        [ -1.48010254e-02,  -1.48925781e-02],
                        [ -1.04675293e-02,  -1.05895996e-02],
                        [ -3.05175781e-03,  -3.17382812e-03],
                        [  1.80053711e-03,   1.64794922e-03],
                        [  1.06811523e-03,   9.15527344e-04],
                        [ -1.19018555e-03,  -1.34277344e-03],
                        [ -9.15527344e-05,  -2.13623047e-04],
                        [  5.55419922e-03,   5.40161133e-03],
                        [  1.41906738e-02,   1.40075684e-02],
                        [  2.19421387e-02,   2.17590332e-02],
                        [  2.31018066e-02,   2.29187012e-02],
                        [  1.54113770e-02,   1.52282715e-02],
                        [  4.82177734e-03,   4.63867188e-03],
                        [ -1.37329102e-03,  -1.55639648e-03],
                        [ -3.41796875e-03,  -3.60107422e-03],
                        [ -4.82177734e-03,  -5.00488281e-03],
                        [ -3.23486328e-03,  -3.44848633e-03],
                        [  5.27954102e-03,   5.06591797e-03],
                        [  1.76391602e-02,   1.74560547e-02],
                        [  2.78930664e-02,   2.76794434e-02],
                        [  3.56750488e-02,   3.54614258e-02],
                        [  4.47387695e-02,   4.45251465e-02],
                        [  5.76171875e-02,   5.74035645e-02],
                        [  7.47070312e-02,   7.44934082e-02],
                        [  9.49096680e-02,   9.46960449e-02],
                        [  1.15722656e-01,   1.15509033e-01],
                        [  1.31988525e-01,   1.31744385e-01],
                        [  1.33758545e-01,   1.33514404e-01],
                        [  1.08276367e-01,   1.08062744e-01],
                        [  4.66613770e-02,   4.64172363e-02],
                        [ -4.90112305e-02,  -4.92248535e-02],
                        [ -1.62902832e-01,  -1.63116455e-01],
                        [ -2.68829346e-01,  -2.69042969e-01],
                        [ -3.37249756e-01,  -3.37463379e-01],
                        [ -3.48541260e-01,  -3.48785400e-01],
                        [ -3.10394287e-01,  -3.10638428e-01],
                        [ -2.57263184e-01,  -2.57476807e-01],
                        [ -2.18872070e-01,  -2.19085693e-01],
                        [ -1.92230225e-01,  -1.92443848e-01],
                        [ -1.55395508e-01,  -1.55609131e-01],
                        [ -9.85412598e-02,  -9.87548828e-02],
                        [ -2.98461914e-02,  -3.00598145e-02],
                        [  3.47900391e-02,   3.46069336e-02],
                        [  7.97119141e-02,   7.95288086e-02],
                        [  9.97619629e-02,   9.95483398e-02],
                        [  1.04858398e-01,   1.04675293e-01],
                        [  1.08459473e-01,   1.08276367e-01],
                        [  1.13403320e-01,   1.13220215e-01],
                        [  1.14166260e-01,   1.13983154e-01],
                        [  1.08489990e-01,   1.08306885e-01],
                        [  9.87854004e-02,   9.86022949e-02],
                        [  8.58459473e-02,   8.56628418e-02],
                        [  6.98852539e-02,   6.97326660e-02],
                        [  5.28259277e-02,   5.26733398e-02],
                        [  3.54614258e-02,   3.53088379e-02],
                        [  1.84326172e-02,   1.82800293e-02],
                        [  6.68334961e-03,   6.56127930e-03],
                        [  8.27026367e-03,   8.14819336e-03],
                        [  2.56347656e-02,   2.55126953e-02],
                        [  5.09643555e-02,   5.08422852e-02],
                        [  7.34558105e-02,   7.33642578e-02],
                        [  8.76770020e-02,   8.75854492e-02],
                        [  9.32006836e-02,   9.31091309e-02],
                        [  9.00268555e-02,   8.99353027e-02],
                        [  7.51953125e-02,   7.51037598e-02],
                        [  4.72106934e-02,   4.71191406e-02],
                        [  1.23291016e-02,   1.22680664e-02],
                        [ -1.84936523e-02,  -1.85546875e-02],
                        [ -3.84216309e-02,  -3.84826660e-02],
                        [ -4.84619141e-02,  -4.84924316e-02],
                        [ -5.43823242e-02,  -5.44128418e-02],
                        [ -6.05163574e-02,  -6.05468750e-02],
                        [ -6.59179688e-02,  -6.59484863e-02],
                        [ -6.60705566e-02,  -6.61010742e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -4.77905273e-02,  -4.77600098e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  1.96533203e-02,   1.96838379e-02],
                        [  3.77502441e-02,   3.77807617e-02],
                        [  4.82482910e-02,   4.82788086e-02],
                        [  5.54504395e-02,   5.55114746e-02],
                        [  5.89294434e-02,   5.89599609e-02],
                        [  5.68542480e-02,   5.69458008e-02],
                        [  5.34057617e-02,   5.34667969e-02],
                        [  5.20324707e-02,   5.20935059e-02],
                        [  4.84313965e-02,   4.85229492e-02],
                        [  3.93371582e-02,   3.94287109e-02],
                        [  2.94494629e-02,   2.95410156e-02],
                        [  2.39257812e-02,   2.40173340e-02],
                        [  2.23388672e-02,   2.24304199e-02],
                        [  2.16674805e-02,   2.17895508e-02],
                        [  1.95617676e-02,   1.96838379e-02],
                        [  1.48315430e-02,   1.49536133e-02],
                        [  8.63647461e-03,   8.78906250e-03],
                        [  4.66918945e-03,   4.82177734e-03],
                        [  4.82177734e-03,   5.00488281e-03],
                        [  7.38525391e-03,   7.53784180e-03],
                        [  1.00708008e-02,   1.02233887e-02],
                        [  1.16271973e-02,   1.18103027e-02],
                        [  1.14135742e-02,   1.15966797e-02],
                        [  7.84301758e-03,   8.02612305e-03],
                        [ -9.76562500e-04,  -7.93457031e-04],
                        [ -1.23901367e-02,  -1.21765137e-02],
                        [ -2.06298828e-02,  -2.04162598e-02],
                        [ -2.39868164e-02,  -2.37731934e-02],
                        [ -2.45056152e-02,  -2.43225098e-02],
                        [ -2.59094238e-02,  -2.56958008e-02],
                        [ -3.09753418e-02,  -3.07617188e-02],
                        [ -3.73229980e-02,  -3.71093750e-02],
                        [ -4.04968262e-02,  -4.02832031e-02],
                        [ -3.97949219e-02,  -3.95812988e-02],
                        [ -3.62243652e-02,  -3.60107422e-02],
                        [ -2.97546387e-02,  -2.95104980e-02],
                        [ -2.26135254e-02,  -2.23693848e-02],
                        [ -2.01721191e-02,  -1.99584961e-02],
                        [ -2.31018066e-02,  -2.28576660e-02],
                        [ -2.32849121e-02,  -2.30712891e-02],
                        [ -1.60522461e-02,  -1.58081055e-02],
                        [ -8.57543945e-03,  -8.36181641e-03],
                        [ -8.42285156e-03,  -8.20922852e-03],
                        [ -1.22375488e-02,  -1.19934082e-02],
                        [ -1.19323730e-02,  -1.16882324e-02],
                        [ -6.40869141e-03,  -6.19506836e-03],
                        [ -1.28173828e-03,  -1.06811523e-03],
                        [  1.09863281e-03,   1.31225586e-03],
                        [  4.69970703e-03,   4.94384766e-03],
                        [  1.12915039e-02,   1.15051270e-02],
                        [  1.56250000e-02,   1.58386230e-02],
                        [  1.23596191e-02,   1.25732422e-02],
                        [  3.35693359e-03,   3.57055664e-03],
                        [ -5.03540039e-03,  -4.85229492e-03],
                        [ -8.85009766e-03,  -8.63647461e-03],
                        [ -8.27026367e-03,  -8.08715820e-03],
                        [ -4.45556641e-03,  -4.24194336e-03],
                        [  2.62451172e-03,   2.80761719e-03],
                        [  1.09252930e-02,   1.11083984e-02],
                        [  1.64794922e-02,   1.66625977e-02],
                        [  1.95617676e-02,   1.97448730e-02],
                        [  2.42309570e-02,   2.44140625e-02],
                        [  3.21655273e-02,   3.23486328e-02],
                        [  4.37622070e-02,   4.39453125e-02],
                        [  6.12792969e-02,   6.14318848e-02],
                        [  8.54187012e-02,   8.55712891e-02],
                        [  1.11755371e-01,   1.11907959e-01],
                        [  1.32171631e-01,   1.32324219e-01],
                        [  1.38824463e-01,   1.38946533e-01],
                        [  1.23870850e-01,   1.23992920e-01],
                        [  8.12377930e-02,   8.13598633e-02],
                        [  1.14440918e-02,   1.15661621e-02],
                        [ -7.95288086e-02,  -7.94372559e-02],
                        [ -1.81793213e-01,  -1.81701660e-01],
                        [ -2.74841309e-01,  -2.74749756e-01],
                        [ -3.31909180e-01,  -3.31817627e-01],
                        [ -3.38500977e-01,  -3.38439941e-01],
                        [ -3.02581787e-01,  -3.02520752e-01],
                        [ -2.47772217e-01,  -2.47711182e-01],
                        [ -1.98028564e-01,  -1.97967529e-01],
                        [ -1.62811279e-01,  -1.62780762e-01],
                        [ -1.31744385e-01,  -1.31713867e-01],
                        [ -8.75854492e-02,  -8.75854492e-02],
                        [ -2.86254883e-02,  -2.85949707e-02],
                        [  2.99377441e-02,   2.99682617e-02],
                        [  7.53784180e-02,   7.54089355e-02],
                        [  1.05529785e-01,   1.05499268e-01],
                        [  1.21459961e-01,   1.21429443e-01],
                        [  1.24542236e-01,   1.24572754e-01],
                        [  1.20178223e-01,   1.20147705e-01],
                        [  1.15295410e-01,   1.15234375e-01],
                        [  1.09893799e-01,   1.09832764e-01],
                        [  9.60998535e-02,   9.60693359e-02],
                        [  7.10449219e-02,   7.09838867e-02],
                        [  4.41894531e-02,   4.41284180e-02],
                        [  2.85339355e-02,   2.84423828e-02],
                        [  2.72216797e-02,   2.71606445e-02],
                        [  3.19519043e-02,   3.18603516e-02],
                        [  3.38439941e-02,   3.37524414e-02],
                        [  3.20434570e-02,   3.19824219e-02],
                        [  3.14636230e-02,   3.13720703e-02],
                        [  3.67126465e-02,   3.65905762e-02],
                        [  4.78210449e-02,   4.76989746e-02],
                        [  5.93261719e-02,   5.92346191e-02],
                        [  6.41784668e-02,   6.40258789e-02],
                        [  5.78308105e-02,   5.76782227e-02],
                        [  4.22668457e-02,   4.21142578e-02],
                        [  2.49023438e-02,   2.47497559e-02],
                        [  1.16577148e-02,   1.14746094e-02],
                        [  4.76074219e-03,   4.57763672e-03],
                        [  5.52368164e-03,   5.34057617e-03],
                        [  1.05285645e-02,   1.03454590e-02],
                        [  9.97924805e-03,   9.79614258e-03],
                        [ -1.92260742e-03,  -2.10571289e-03],
                        [ -1.92565918e-02,  -1.94396973e-02],
                        [ -3.18908691e-02,  -3.20739746e-02],
                        [ -3.56140137e-02,  -3.58276367e-02],
                        [ -3.19824219e-02,  -3.21960449e-02],
                        [ -2.36206055e-02,  -2.38342285e-02],
                        [ -1.39465332e-02,  -1.41601562e-02],
                        [ -6.13403320e-03,  -6.31713867e-03],
                        [  1.70898438e-03,   1.49536133e-03],
                        [  1.34582520e-02,   1.32141113e-02],
                        [  2.68859863e-02,   2.66723633e-02],
                        [  3.66210938e-02,   3.64074707e-02],
                        [  4.27246094e-02,   4.25109863e-02],
                        [  4.83398438e-02,   4.81262207e-02],
                        [  5.26123047e-02,   5.23986816e-02],
                        [  5.25207520e-02,   5.23071289e-02],
                        [  4.78210449e-02,   4.75769043e-02],
                        [  3.92150879e-02,   3.89709473e-02],
                        [  2.75573730e-02,   2.73437500e-02],
                        [  1.71508789e-02,   1.69372559e-02],
                        [  1.34277344e-02,   1.32141113e-02],
                        [  1.58386230e-02,   1.55944824e-02],
                        [  1.88598633e-02,   1.86462402e-02],
                        [  2.07519531e-02,   2.05383301e-02],
                        [  2.52075195e-02,   2.49938965e-02],
                        [  3.35083008e-02,   3.32946777e-02],
                        [  4.08020020e-02,   4.05883789e-02],
                        [  4.21447754e-02,   4.19616699e-02],
                        [  3.64990234e-02,   3.63159180e-02],
                        [  2.52685547e-02,   2.50854492e-02],
                        [  1.12915039e-02,   1.10778809e-02],
                        [ -3.11279297e-03,  -3.32641602e-03],
                        [ -1.58386230e-02,  -1.60217285e-02],
                        [ -2.41088867e-02,  -2.42919922e-02],
                        [ -2.95104980e-02,  -2.96936035e-02],
                        [ -3.72619629e-02,  -3.74755859e-02],
                        [ -4.68444824e-02,  -4.70275879e-02],
                        [ -5.19409180e-02,  -5.20935059e-02],
                        [ -5.09948730e-02,  -5.11474609e-02],
                        [ -4.86145020e-02,  -4.88281250e-02],
                        [ -4.55017090e-02,  -4.56848145e-02],
                        [ -3.67431641e-02,  -3.68652344e-02],
                        [ -2.47802734e-02,  -2.49023438e-02],
                        [ -1.89208984e-02,  -1.90734863e-02],
                        [ -1.89819336e-02,  -1.91040039e-02],
                        [ -1.64184570e-02,  -1.65405273e-02],
                        [ -9.52148438e-03,  -9.64355469e-03],
                        [ -3.35693359e-03,  -3.47900391e-03],
                        [  8.23974609e-04,   7.32421875e-04],
                        [  5.70678711e-03,   5.61523438e-03],
                        [  9.49096680e-03,   9.36889648e-03],
                        [  7.59887695e-03,   7.50732422e-03],
                        [  1.77001953e-03,   1.73950195e-03],
                        [ -2.04467773e-03,  -2.10571289e-03],
                        [ -1.00708008e-03,  -1.09863281e-03],
                        [  6.07299805e-03,   6.04248047e-03],
                        [  1.84326172e-02,   1.84020996e-02],
                        [  2.99377441e-02,   2.99072266e-02],
                        [  3.19213867e-02,   3.18603516e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  4.30297852e-03,   4.30297852e-03],
                        [ -8.88061523e-03,  -8.91113281e-03],
                        [ -1.85546875e-02,  -1.85852051e-02],
                        [ -2.72521973e-02,  -2.71911621e-02],
                        [ -2.98767090e-02,  -2.98461914e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -6.37817383e-03,  -6.34765625e-03],
                        [  6.07299805e-03,   6.16455078e-03],
                        [  1.62048340e-02,   1.62963867e-02],
                        [  2.94189453e-02,   2.94494629e-02],
                        [  4.40368652e-02,   4.40979004e-02],
                        [  5.57556152e-02,   5.58471680e-02],
                        [  6.89392090e-02,   6.90307617e-02],
                        [  9.06982422e-02,   9.07592773e-02],
                        [  1.17218018e-01,   1.17279053e-01],
                        [  1.36535645e-01,   1.36657715e-01],
                        [  1.39190674e-01,   1.39312744e-01],
                        [  1.17736816e-01,   1.17858887e-01],
                        [  6.39038086e-02,   6.39648438e-02],
                        [ -2.45971680e-02,  -2.44750977e-02],
                        [ -1.35253906e-01,  -1.35070801e-01],
                        [ -2.41546631e-01,  -2.41363525e-01],
                        [ -3.13385010e-01,  -3.13293457e-01],
                        [ -3.31787109e-01,  -3.31695557e-01],
                        [ -3.00598145e-01,  -3.00384521e-01],
                        [ -2.48809814e-01,  -2.48596191e-01],
                        [ -2.11090088e-01,  -2.10937500e-01],
                        [ -1.96838379e-01,  -1.96746826e-01],
                        [ -1.84020996e-01,  -1.83837891e-01],
                        [ -1.46759033e-01,  -1.46545410e-01],
                        [ -8.33435059e-02,  -8.31298828e-02],
                        [ -1.25732422e-02,  -1.24511719e-02],
                        [  4.94995117e-02,   4.96520996e-02],
                        [  9.78698730e-02,   9.80834961e-02],
                        [  1.29547119e-01,   1.29760742e-01],
                        [  1.41784668e-01,   1.41967773e-01],
                        [  1.36932373e-01,   1.37145996e-01],
                        [  1.23748779e-01,   1.23931885e-01],
                        [  1.11755371e-01,   1.11938477e-01],
                        [  1.02630615e-01,   1.02844238e-01],
                        [  9.17053223e-02,   9.19494629e-02],
                        [  7.70263672e-02,   7.72399902e-02],
                        [  6.14929199e-02,   6.16455078e-02],
                        [  4.78210449e-02,   4.80041504e-02],
                        [  3.56445312e-02,   3.58886719e-02],
                        [  2.51159668e-02,   2.53601074e-02],
                        [  2.07214355e-02,   2.09045410e-02],
                        [  2.60620117e-02,   2.62451172e-02],
                        [  4.06799316e-02,   4.09240723e-02],
                        [  6.06994629e-02,   6.09436035e-02],
                        [  7.60803223e-02,   7.62939453e-02],
                        [  7.54089355e-02,   7.55920410e-02],
                        [  5.56335449e-02,   5.58166504e-02],
                        [  2.33764648e-02,   2.35595703e-02],
                        [ -9.24682617e-03,  -9.00268555e-03],
                        [ -3.04565430e-02,  -3.02124023e-02],
                        [ -3.50036621e-02,  -3.48510742e-02],
                        [ -2.72521973e-02,  -2.70996094e-02],
                        [ -1.88598633e-02,  -1.86157227e-02],
                        [ -1.77307129e-02,  -1.74865723e-02],
                        [ -2.26135254e-02,  -2.24304199e-02],
                        [ -3.08227539e-02,  -3.07006836e-02],
                        [ -4.05273438e-02,  -4.03442383e-02],
                        [ -4.52880859e-02,  -4.50744629e-02],
                        [ -3.63769531e-02,  -3.61938477e-02],
                        [ -1.15051270e-02,  -1.13525391e-02],
                        [  1.98059082e-02,   1.99890137e-02],
                        [  4.26940918e-02,   4.28466797e-02],
                        [  4.94079590e-02,   4.95605469e-02],
                        [  4.30908203e-02,   4.32434082e-02],
                        [  3.28063965e-02,   3.29589844e-02],
                        [  2.62756348e-02,   2.63977051e-02],
                        [  2.33764648e-02,   2.34680176e-02],
                        [  2.02941895e-02,   2.04467773e-02],
                        [  1.68762207e-02,   1.70288086e-02],
                        [  1.63269043e-02,   1.64184570e-02],
                        [  2.01416016e-02,   2.02331543e-02],
                        [  2.59704590e-02,   2.60620117e-02],
                        [  3.13110352e-02,   3.14025879e-02],
                        [  3.65600586e-02,   3.66210938e-02],
                        [  4.24804688e-02,   4.26025391e-02],
                        [  4.79736328e-02,   4.80651855e-02],
                        [  4.96826172e-02,   4.97131348e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  3.48205566e-02,   3.49121094e-02],
                        [  2.60314941e-02,   2.61230469e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  3.87573242e-03,   3.93676758e-03],
                        [ -4.15039062e-03,  -4.11987305e-03],
                        [ -1.09558105e-02,  -1.09863281e-02],
                        [ -1.73034668e-02,  -1.73645020e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -3.28063965e-02,  -3.27758789e-02],
                        [ -4.14733887e-02,  -4.15039062e-02],
                        [ -4.58068848e-02,  -4.58374023e-02],
                        [ -4.37316895e-02,  -4.37927246e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -2.98156738e-02,  -2.98461914e-02],
                        [ -2.18811035e-02,  -2.19726562e-02],
                        [ -1.73950195e-02,  -1.74865723e-02],
                        [ -1.67236328e-02,  -1.67846680e-02],
                        [ -1.71508789e-02,  -1.72119141e-02],
                        [ -1.77612305e-02,  -1.78833008e-02],
                        [ -1.96838379e-02,  -1.98059082e-02],
                        [ -2.12707520e-02,  -2.13317871e-02],
                        [ -1.88903809e-02,  -1.89514160e-02],
                        [ -1.36718750e-02,  -1.38244629e-02],
                        [ -1.08337402e-02,  -1.09863281e-02],
                        [ -1.14440918e-02,  -1.15356445e-02],
                        [ -1.33666992e-02,  -1.34582520e-02],
                        [ -1.68762207e-02,  -1.70288086e-02],
                        [ -2.21557617e-02,  -2.23388672e-02],
                        [ -2.44140625e-02,  -2.45361328e-02],
                        [ -1.78833008e-02,  -1.79748535e-02],
                        [ -3.75366211e-03,  -3.93676758e-03],
                        [  1.00402832e-02,   9.85717773e-03],
                        [  1.85546875e-02,   1.84020996e-02],
                        [  2.27966309e-02,   2.26745605e-02],
                        [  2.30407715e-02,   2.28271484e-02],
                        [  1.77917480e-02,   1.75781250e-02],
                        [  9.42993164e-03,   9.30786133e-03],
                        [  2.65502930e-03,   2.53295898e-03],
                        [ -1.46484375e-03,  -1.70898438e-03],
                        [ -5.64575195e-03,  -5.88989258e-03],
                        [ -1.03759766e-02,  -1.04980469e-02],
                        [ -1.17187500e-02,  -1.18408203e-02],
                        [ -7.72094727e-03,  -7.96508789e-03],
                        [ -1.92260742e-03,  -2.16674805e-03],
                        [  4.27246094e-03,   4.15039062e-03],
                        [  1.53808594e-02,   1.52282715e-02],
                        [  3.48510742e-02,   3.46069336e-02],
                        [  6.14624023e-02,   6.12182617e-02],
                        [  9.16748047e-02,   9.15527344e-02],
                        [  1.21063232e-01,   1.20941162e-01],
                        [  1.43127441e-01,   1.42913818e-01],
                        [  1.48712158e-01,   1.48468018e-01],
                        [  1.28723145e-01,   1.28540039e-01],
                        [  7.76367188e-02,   7.74536133e-02],
                        [ -6.71386719e-03,  -6.92749023e-03],
                        [ -1.19262695e-01,  -1.19445801e-01],
                        [ -2.37335205e-01,  -2.37487793e-01],
                        [ -3.23425293e-01,  -3.23638916e-01],
                        [ -3.49700928e-01,  -3.49945068e-01],
                        [ -3.20312500e-01,  -3.20495605e-01],
                        [ -2.65380859e-01,  -2.65502930e-01],
                        [ -2.15301514e-01,  -2.15454102e-01],
                        [ -1.81396484e-01,  -1.81640625e-01],
                        [ -1.55700684e-01,  -1.55914307e-01],
                        [ -1.23809814e-01,  -1.23901367e-01],
                        [ -7.81250000e-02,  -7.82165527e-02],
                        [ -2.26135254e-02,  -2.28576660e-02],
                        [  3.31115723e-02,   3.28369141e-02],
                        [  8.14514160e-02,   8.13293457e-02],
                        [  1.17950439e-01,   1.17919922e-01],
                        [  1.38549805e-01,   1.38427734e-01],
                        [  1.40960693e-01,   1.40747070e-01],
                        [  1.29608154e-01,   1.29394531e-01],
                        [  1.14440918e-01,   1.14379883e-01],
                        [  1.02783203e-01,   1.02752686e-01],
                        [  9.32312012e-02,   9.30480957e-02],
                        [  8.06274414e-02,   8.04138184e-02],
                        [  6.60400391e-02,   6.59484863e-02],
                        [  5.56945801e-02,   5.56640625e-02],
                        [  5.10253906e-02,   5.09338379e-02],
                        [  4.78515625e-02,   4.77294922e-02],
                        [  4.47082520e-02,   4.46166992e-02],
                        [  4.30297852e-02,   4.29687500e-02],
                        [  4.29077148e-02,   4.28161621e-02],
                        [  4.33654785e-02,   4.33044434e-02],
                        [  4.14123535e-02,   4.13818359e-02],
                        [  3.21044922e-02,   3.20434570e-02],
                        [  1.55334473e-02,   1.54418945e-02],
                        [ -9.15527344e-04,  -9.76562500e-04],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -2.16674805e-03,  -2.22778320e-03],
                        [  3.99780273e-03,   3.90625000e-03],
                        [  6.04248047e-03,   6.01196289e-03],
                        [  1.64794922e-03,   1.73950195e-03],
                        [ -7.53784180e-03,  -7.50732422e-03],
                        [ -1.70593262e-02,  -1.71508789e-02],
                        [ -2.26440430e-02,  -2.27050781e-02],
                        [ -2.21862793e-02,  -2.20947266e-02],
                        [ -1.68151855e-02,  -1.66931152e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  1.43432617e-03,   1.40380859e-03],
                        [  1.31530762e-02,   1.32141113e-02],
                        [  2.51770020e-02,   2.53295898e-02],
                        [  3.41491699e-02,   3.42102051e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  3.65600586e-02,   3.66210938e-02],
                        [  3.88793945e-02,   3.90014648e-02],
                        [  4.38842773e-02,   4.39758301e-02],
                        [  4.72106934e-02,   4.72717285e-02],
                        [  4.62036133e-02,   4.62951660e-02],
                        [  4.16259766e-02,   4.17480469e-02],
                        [  3.53088379e-02,   3.53698730e-02],
                        [  2.81677246e-02,   2.82897949e-02],
                        [  2.16674805e-02,   2.17895508e-02],
                        [  1.76391602e-02,   1.77612305e-02],
                        [  1.69067383e-02,   1.69677734e-02],
                        [  1.90734863e-02,   1.92260742e-02],
                        [  2.27355957e-02,   2.29187012e-02],
                        [  2.64892578e-02,   2.66113281e-02],
                        [  3.06091309e-02,   3.07006836e-02],
                        [  3.54614258e-02,   3.56445312e-02],
                        [  3.91845703e-02,   3.93676758e-02],
                        [  3.78112793e-02,   3.79028320e-02],
                        [  2.89916992e-02,   2.90832520e-02],
                        [  1.52587891e-02,   1.54113770e-02],
                        [  8.23974609e-04,   1.00708008e-03],
                        [ -1.23291016e-02,  -1.21765137e-02],
                        [ -2.46582031e-02,  -2.45361328e-02],
                        [ -3.62854004e-02,  -3.61633301e-02],
                        [ -4.50439453e-02,  -4.48913574e-02],
                        [ -4.93469238e-02,  -4.91638184e-02],
                        [ -5.01098633e-02,  -4.99267578e-02],
                        [ -4.81567383e-02,  -4.80041504e-02],
                        [ -4.35180664e-02,  -4.33959961e-02],
                        [ -3.55529785e-02,  -3.53698730e-02],
                        [ -2.37121582e-02,  -2.34985352e-02],
                        [ -1.15966797e-02,  -1.14135742e-02],
                        [ -4.42504883e-03,  -4.30297852e-03],
                        [ -2.89916992e-03,  -2.77709961e-03],
                        [ -4.02832031e-03,  -3.84521484e-03],
                        [ -4.60815430e-03,  -4.39453125e-03],
                        [ -3.75366211e-03,  -3.60107422e-03],
                        [ -3.66210938e-03,  -3.54003906e-03],
                        [ -6.37817383e-03,  -6.22558594e-03],
                        [ -1.11999512e-02,  -1.09863281e-02],
                        [ -1.54724121e-02,  -1.52893066e-02],
                        [ -1.79443359e-02,  -1.78222656e-02],
                        [ -1.87988281e-02,  -1.86767578e-02],
                        [ -1.63574219e-02,  -1.62353516e-02],
                        [ -9.94873047e-03,  -9.79614258e-03],
                        [ -3.08227539e-03,  -2.89916992e-03],
                        [  1.95312500e-03,   2.10571289e-03],
                        [  6.37817383e-03,   6.46972656e-03],
                        [  1.07421875e-02,   1.08337402e-02],
                        [  1.43737793e-02,   1.45568848e-02],
                        [  1.66931152e-02,   1.68762207e-02],
                        [  1.67846680e-02,   1.68762207e-02],
                        [  1.37634277e-02,   1.38244629e-02],
                        [  7.99560547e-03,   8.14819336e-03],
                        [  1.61743164e-03,   1.77001953e-03],
                        [ -3.90625000e-03,  -3.84521484e-03],
                        [ -6.62231445e-03,  -6.53076172e-03],
                        [ -1.28173828e-03,  -1.15966797e-03],
                        [  1.40380859e-02,   1.41296387e-02],
                        [  3.33862305e-02,   3.34472656e-02],
                        [  5.09643555e-02,   5.10559082e-02],
                        [  6.72302246e-02,   6.73217773e-02],
                        [  8.55102539e-02,   8.56018066e-02],
                        [  1.06201172e-01,   1.06262207e-01],
                        [  1.24511719e-01,   1.24603271e-01],
                        [  1.31591797e-01,   1.31652832e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  6.89697266e-02,   6.90307617e-02],
                        [ -1.33361816e-02,  -1.32141113e-02],
                        [ -1.22619629e-01,  -1.22589111e-01],
                        [ -2.35748291e-01,  -2.35809326e-01],
                        [ -3.16558838e-01,  -3.16558838e-01],
                        [ -3.35937500e-01,  -3.35815430e-01],
                        [ -2.96875000e-01,  -2.96813965e-01],
                        [ -2.35809326e-01,  -2.35870361e-01],
                        [ -1.91802979e-01,  -1.91864014e-01],
                        [ -1.74285889e-01,  -1.74194336e-01],
                        [ -1.64123535e-01,  -1.64031982e-01],
                        [ -1.40197754e-01,  -1.40228271e-01],
                        [ -9.76562500e-02,  -9.77783203e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [  1.24816895e-02,   1.25732422e-02],
                        [  6.70471191e-02,   6.70471191e-02],
                        [  1.12457275e-01,   1.12365723e-01],
                        [  1.41479492e-01,   1.41418457e-01],
                        [  1.52221680e-01,   1.52191162e-01],
                        [  1.48468018e-01,   1.48468018e-01],
                        [  1.36016846e-01,   1.35986328e-01],
                        [  1.19506836e-01,   1.19445801e-01],
                        [  1.02416992e-01,   1.02355957e-01],
                        [  8.56323242e-02,   8.56018066e-02],
                        [  6.79626465e-02,   6.79016113e-02],
                        [  5.14831543e-02,   5.14221191e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  4.09240723e-02,   4.08630371e-02],
                        [  4.37927246e-02,   4.36401367e-02],
                        [  4.50744629e-02,   4.49523926e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  3.69262695e-02,   3.68957520e-02],
                        [  2.53295898e-02,   2.51464844e-02],
                        [  8.54492188e-03,   8.36181641e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -1.37634277e-02,  -1.37329102e-02],
                        [ -8.60595703e-03,  -8.72802734e-03],
                        [  2.80761719e-03,   2.53295898e-03],
                        [  1.09252930e-02,   1.07727051e-02],
                        [  1.08337402e-02,   1.08642578e-02],
                        [  5.09643555e-03,   5.06591797e-03],
                        [ -2.80761719e-03,  -3.02124023e-03],
                        [ -1.31835938e-02,  -1.34277344e-02],
                        [ -2.43835449e-02,  -2.44445801e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.37731934e-02,  -2.38952637e-02],
                        [ -1.07421875e-02,  -1.09558105e-02],
                        [  3.26538086e-03,   3.14331055e-03],
                        [  1.40991211e-02,   1.40380859e-02],
                        [  1.99279785e-02,   1.98059082e-02],
                        [  2.09655762e-02,   2.07824707e-02],
                        [  2.07519531e-02,   2.06298828e-02],
                        [  2.45666504e-02,   2.44750977e-02],
                        [  3.35998535e-02,   3.34472656e-02],
                        [  4.15954590e-02,   4.14123535e-02],
                        [  4.27246094e-02,   4.26330566e-02],
                        [  3.97644043e-02,   3.96728516e-02],
                        [  3.83605957e-02,   3.81469727e-02],
                        [  3.79943848e-02,   3.77807617e-02],
                        [  3.47290039e-02,   3.46984863e-02],
                        [  2.86254883e-02,   2.85949707e-02],
                        [  2.34680176e-02,   2.32543945e-02],
                        [  2.19116211e-02,   2.16674805e-02],
                        [  2.40783691e-02,   2.40478516e-02],
                        [  2.81066895e-02,   2.80761719e-02],
                        [  2.95715332e-02,   2.93884277e-02],
                        [  2.49633789e-02,   2.47802734e-02],
                        [  1.74865723e-02,   1.74560547e-02],
                        [  1.23291016e-02,   1.22985840e-02],
                        [  8.11767578e-03,   7.93457031e-03],
                        [  1.80053711e-03,   1.64794922e-03],
                        [ -3.17382812e-03,  -3.20434570e-03],
                        [ -2.71606445e-03,  -2.77709961e-03],
                        [  6.71386719e-04,   5.18798828e-04],
                        [  1.46484375e-03,   1.31225586e-03],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [ -1.27563477e-02,  -1.28173828e-02],
                        [ -2.45361328e-02,  -2.46887207e-02],
                        [ -3.54003906e-02,  -3.55224609e-02],
                        [ -4.26025391e-02,  -4.26330566e-02],
                        [ -4.55932617e-02,  -4.56542969e-02],
                        [ -4.54101562e-02,  -4.55322266e-02],
                        [ -4.26635742e-02,  -4.27856445e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -2.91137695e-02,  -2.92358398e-02],
                        [ -2.53601074e-02,  -2.54516602e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.16271973e-02,  -1.17187500e-02],
                        [ -8.57543945e-03,  -8.66699219e-03],
                        [ -9.09423828e-03,  -9.06372070e-03],
                        [ -1.09863281e-02,  -1.09558105e-02],
                        [ -1.25732422e-02,  -1.26342773e-02],
                        [ -1.29089355e-02,  -1.29699707e-02],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -4.42504883e-03,  -4.39453125e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -2.19726562e-03,  -2.25830078e-03],
                        [ -1.09558105e-02,  -1.09863281e-02],
                        [ -1.76391602e-02,  -1.75781250e-02],
                        [ -1.43737793e-02,  -1.43432617e-02],
                        [ -4.42504883e-03,  -4.48608398e-03],
                        [  1.43432617e-03,   1.37329102e-03],
                        [ -6.10351562e-05,   3.05175781e-05],
                        [ -1.52587891e-03,  -1.43432617e-03],
                        [  1.61743164e-03,   1.55639648e-03],
                        [  5.98144531e-03,   5.92041016e-03],
                        [  9.27734375e-03,   9.36889648e-03],
                        [  1.34887695e-02,   1.35803223e-02],
                        [  1.93481445e-02,   1.93176270e-02],
                        [  2.51770020e-02,   2.51464844e-02],
                        [  3.17687988e-02,   3.18603516e-02],
                        [  4.24804688e-02,   4.25415039e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  8.39233398e-02,   8.39843750e-02],
                        [  1.13952637e-01,   1.14044189e-01],
                        [  1.39831543e-01,   1.39862061e-01],
                        [  1.46575928e-01,   1.46575928e-01],
                        [  1.22528076e-01,   1.22650146e-01],
                        [  6.27136230e-02,   6.28356934e-02],
                        [ -3.11889648e-02,  -3.11584473e-02],
                        [ -1.47155762e-01,  -1.47125244e-01],
                        [ -2.57995605e-01,  -2.57873535e-01],
                        [ -3.28735352e-01,  -3.28643799e-01],
                        [ -3.39508057e-01,  -3.39477539e-01],
                        [ -3.00231934e-01,  -3.00140381e-01],
                        [ -2.41912842e-01,  -2.41821289e-01],
                        [ -1.96380615e-01,  -1.96380615e-01],
                        [ -1.75415039e-01,  -1.75384521e-01],
                        [ -1.64001465e-01,  -1.63848877e-01],
                        [ -1.39038086e-01,  -1.38885498e-01],
                        [ -9.45434570e-02,  -9.45739746e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [  8.20922852e-03,   8.39233398e-03],
                        [  5.77697754e-02,   5.79833984e-02],
                        [  1.01715088e-01,   1.01745605e-01],
                        [  1.29180908e-01,   1.29180908e-01],
                        [  1.37329102e-01,   1.37420654e-01],
                        [  1.33544922e-01,   1.33697510e-01],
                        [  1.26495361e-01,   1.26617432e-01],
                        [  1.19781494e-01,   1.19842529e-01],
                        [  1.09832764e-01,   1.09832764e-01],
                        [  9.21020508e-02,   9.21630859e-02],
                        [  7.26013184e-02,   7.27844238e-02],
                        [  6.47583008e-02,   6.49414062e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  7.88879395e-02,   7.88269043e-02],
                        [  7.37915039e-02,   7.39135742e-02],
                        [  5.58166504e-02,   5.60302734e-02],
                        [  3.13110352e-02,   3.14025879e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -2.12402344e-02,  -2.11791992e-02],
                        [ -3.82385254e-02,  -3.81164551e-02],
                        [ -3.94287109e-02,  -3.93371582e-02],
                        [ -2.49633789e-02,  -2.49023438e-02],
                        [ -3.93676758e-03,  -3.84521484e-03],
                        [  1.11999512e-02,   1.12304688e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  7.44628906e-03,   7.53784180e-03],
                        [  2.38037109e-03,   2.59399414e-03],
                        [  1.25122070e-03,   1.28173828e-03],
                        [ -8.85009766e-04,  -1.00708008e-03],
                        [ -5.85937500e-03,  -5.82885742e-03],
                        [ -7.11059570e-03,  -6.86645508e-03],
                        [  6.10351562e-04,   7.32421875e-04],
                        [  1.13220215e-02,   1.11999512e-02],
                        [  1.56860352e-02,   1.55944824e-02],
                        [  1.38244629e-02,   1.40075684e-02],
                        [  1.28173828e-02,   1.30004883e-02],
                        [  1.58081055e-02,   1.57775879e-02],
                        [  2.03857422e-02,   2.02941895e-02],
                        [  2.40478516e-02,   2.41088867e-02],
                        [  2.65197754e-02,   2.67028809e-02],
                        [  2.79846191e-02,   2.80456543e-02],
                        [  2.79235840e-02,   2.78320312e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.89001465e-02,   2.90222168e-02],
                        [  3.57971191e-02,   3.58886719e-02],
                        [  4.51660156e-02,   4.51049805e-02],
                        [  5.10559082e-02,   5.09948730e-02],
                        [  5.11169434e-02,   5.12390137e-02],
                        [  4.72717285e-02,   4.73632812e-02],
                        [  4.00695801e-02,   4.00085449e-02],
                        [  2.77099609e-02,   2.76489258e-02],
                        [  1.16882324e-02,   1.17797852e-02],
                        [ -5.18798828e-04,  -4.27246094e-04],
                        [ -4.18090820e-03,  -4.24194336e-03],
                        [ -3.69262695e-03,  -3.78417969e-03],
                        [ -4.51660156e-03,  -4.42504883e-03],
                        [ -5.24902344e-03,  -5.18798828e-03],
                        [ -3.72314453e-03,  -3.81469727e-03],
                        [ -2.25830078e-03,  -2.31933594e-03],
                        [ -2.96020508e-03,  -2.86865234e-03],
                        [ -4.97436523e-03,  -4.94384766e-03],
                        [ -9.36889648e-03,  -9.52148438e-03],
                        [ -1.82800293e-02,  -1.83105469e-02],
                        [ -2.79235840e-02,  -2.77709961e-02],
                        [ -3.21350098e-02,  -3.21655273e-02],
                        [ -3.11889648e-02,  -3.13720703e-02],
                        [ -2.81066895e-02,  -2.81372070e-02],
                        [ -2.23083496e-02,  -2.21862793e-02],
                        [ -1.57165527e-02,  -1.57470703e-02],
                        [ -1.60217285e-02,  -1.61743164e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.59497070e-02,  -3.58886719e-02],
                        [ -4.10461426e-02,  -4.11376953e-02],
                        [ -4.05883789e-02,  -4.06494141e-02],
                        [ -3.61328125e-02,  -3.61022949e-02],
                        [ -3.01513672e-02,  -3.02429199e-02],
                        [ -2.60009766e-02,  -2.61535645e-02],
                        [ -2.27661133e-02,  -2.27355957e-02],
                        [ -1.61437988e-02,  -1.60522461e-02],
                        [ -7.26318359e-03,  -7.35473633e-03],
                        [ -2.10571289e-03,  -2.28881836e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -9.15527344e-05,  -3.05175781e-05],
                        [  1.25122070e-03,   1.22070312e-03],
                        [ -6.40869141e-04,  -7.62939453e-04],
                        [ -4.69970703e-03,  -4.79125977e-03],
                        [ -7.08007812e-03,  -7.11059570e-03],
                        [ -6.34765625e-03,  -6.31713867e-03],
                        [ -3.96728516e-03,  -3.99780273e-03],
                        [ -2.41088867e-03,  -2.56347656e-03],
                        [ -2.59399414e-03,  -2.68554688e-03],
                        [ -1.12915039e-03,  -1.09863281e-03],
                        [  6.01196289e-03,   6.04248047e-03],
                        [  1.67846680e-02,   1.66931152e-02],
                        [  2.46887207e-02,   2.45666504e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.28576660e-02,   2.27966309e-02],
                        [  2.33154297e-02,   2.32238770e-02],
                        [  3.33862305e-02,   3.33557129e-02],
                        [  5.70068359e-02,   5.69458008e-02],
                        [  9.06982422e-02,   9.06372070e-02],
                        [  1.24511719e-01,   1.24481201e-01],
                        [  1.45568848e-01,   1.45538330e-01],
                        [  1.43920898e-01,   1.43890381e-01],
                        [  1.14349365e-01,   1.14288330e-01],
                        [  5.15136719e-02,   5.14526367e-02],
                        [ -4.73022461e-02,  -4.73632812e-02],
                        [ -1.68273926e-01,  -1.68273926e-01],
                        [ -2.77130127e-01,  -2.77160645e-01],
                        [ -3.38043213e-01,  -3.38134766e-01],
                        [ -3.35937500e-01,  -3.35998535e-01],
                        [ -2.85339355e-01,  -2.85339355e-01],
                        [ -2.22930908e-01,  -2.22991943e-01],
                        [ -1.82952881e-01,  -1.83044434e-01],
                        [ -1.71508789e-01,  -1.71539307e-01],
                        [ -1.68395996e-01,  -1.68395996e-01],
                        [ -1.51947021e-01,  -1.51947021e-01],
                        [ -1.15173340e-01,  -1.15234375e-01],
                        [ -6.35375977e-02,  -6.35986328e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  5.68847656e-02,   5.69458008e-02],
                        [  1.14410400e-01,   1.14379883e-01],
                        [  1.54296875e-01,   1.54144287e-01],
                        [  1.65985107e-01,   1.65985107e-01],
                        [  1.55364990e-01,   1.55517578e-01],
                        [  1.38031006e-01,   1.38000488e-01],
                        [  1.21490479e-01,   1.21246338e-01],
                        [  1.05438232e-01,   1.05407715e-01],
                        [  9.35668945e-02,   9.37500000e-02],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  9.23767090e-02,   9.21936035e-02],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  9.32006836e-02,   9.32617188e-02],
                        [  7.91320801e-02,   7.91015625e-02],
                        [  4.59289551e-02,   4.58984375e-02],
                        [  8.54492188e-04,   8.85009766e-04],
                        [ -3.92150879e-02,  -3.92761230e-02],
                        [ -6.03637695e-02,  -6.04858398e-02],
                        [ -5.70983887e-02,  -5.69763184e-02],
                        [ -3.36303711e-02,  -3.35083008e-02],
                        [ -5.24902344e-03,  -5.37109375e-03],
                        [  1.07116699e-02,   1.05285645e-02],
                        [  1.09558105e-02,   1.10778809e-02],
                        [  6.77490234e-03,   6.95800781e-03],
                        [  5.85937500e-03,   5.76782227e-03],
                        [  4.79125977e-03,   4.63867188e-03],
                        [  3.96728516e-04,   4.27246094e-04],
                        [ -3.72314453e-03,  -3.60107422e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  5.21850586e-03,   5.18798828e-03],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  2.96936035e-02,   2.97241211e-02],
                        [  3.58886719e-02,   3.59191895e-02],
                        [  3.68347168e-02,   3.68652344e-02],
                        [  3.49121094e-02,   3.48815918e-02],
                        [  3.00598145e-02,   3.00292969e-02],
                        [  2.20336914e-02,   2.20642090e-02],
                        [  1.32141113e-02,   1.32446289e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.10778809e-02,   1.11083984e-02],
                        [  2.41394043e-02,   2.41699219e-02],
                        [  4.03137207e-02,   4.03137207e-02],
                        [  4.90417480e-02,   4.90112305e-02],
                        [  4.69360352e-02,   4.69970703e-02],
                        [  3.97644043e-02,   3.98559570e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  3.20739746e-02,   3.20129395e-02],
                        [  3.24707031e-02,   3.25012207e-02],
                        [  3.20739746e-02,   3.21655273e-02],
                        [  2.89306641e-02,   2.89611816e-02],
                        [  2.41088867e-02,   2.40173340e-02],
                        [  1.90124512e-02,   1.89819336e-02],
                        [  1.38244629e-02,   1.39465332e-02],
                        [  9.36889648e-03,   9.46044922e-03],
                        [  5.52368164e-03,   5.43212891e-03],
                        [ -6.40869141e-04,  -7.01904297e-04],
                        [ -1.00097656e-02,  -9.88769531e-03],
                        [ -1.89514160e-02,  -1.88598633e-02],
                        [ -2.53295898e-02,  -2.53601074e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.92663574e-02,  -2.92053223e-02],
                        [ -2.50854492e-02,  -2.50549316e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -2.07519531e-02,  -2.07214355e-02],
                        [ -2.22473145e-02,  -2.22167969e-02],
                        [ -2.37426758e-02,  -2.37731934e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.75878906e-02,  -2.74963379e-02],
                        [ -2.96630859e-02,  -2.96325684e-02],
                        [ -3.26538086e-02,  -3.27148438e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.28063965e-02,  -3.27453613e-02],
                        [ -2.54211426e-02,  -2.53906250e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -2.20031738e-02,  -2.19726562e-02],
                        [ -2.64282227e-02,  -2.63366699e-02],
                        [ -2.59094238e-02,  -2.58789062e-02],
                        [ -1.95312500e-02,  -1.96228027e-02],
                        [ -1.10778809e-02,  -1.11389160e-02],
                        [ -3.35693359e-03,  -3.23486328e-03],
                        [  2.89916992e-03,   2.99072266e-03],
                        [  4.82177734e-03,   4.73022461e-03],
                        [  5.18798828e-04,   4.88281250e-04],
                        [ -5.09643555e-03,  -5.00488281e-03],
                        [ -6.34765625e-03,  -6.28662109e-03],
                        [ -4.57763672e-03,  -4.66918945e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.80053711e-03,  -1.70898438e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  4.33349609e-03,   4.27246094e-03],
                        [  5.34057617e-03,   5.40161133e-03],
                        [  4.94384766e-03,   5.00488281e-03],
                        [  5.49316406e-03,   5.46264648e-03],
                        [  9.61303711e-03,   9.55200195e-03],
                        [  1.92260742e-02,   1.92871094e-02],
                        [  3.48815918e-02,   3.49731445e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  7.64465332e-02,   7.63549805e-02],
                        [  9.76257324e-02,   9.75952148e-02],
                        [  1.16607666e-01,   1.16699219e-01],
                        [  1.28906250e-01,   1.28936768e-01],
                        [  1.25762939e-01,   1.25701904e-01],
                        [  9.67712402e-02,   9.67102051e-02],
                        [  3.57971191e-02,   3.58581543e-02],
                        [ -5.32531738e-02,  -5.31616211e-02],
                        [ -1.56097412e-01,  -1.56127930e-01],
                        [ -2.50183105e-01,  -2.50274658e-01],
                        [ -3.09448242e-01,  -3.09417725e-01],
                        [ -3.17291260e-01,  -3.17199707e-01],
                        [ -2.82135010e-01,  -2.82135010e-01],
                        [ -2.34466553e-01,  -2.34558105e-01],
                        [ -2.01019287e-01,  -2.01019287e-01],
                        [ -1.83319092e-01,  -1.83227539e-01],
                        [ -1.65618896e-01,  -1.65618896e-01],
                        [ -1.36871338e-01,  -1.36932373e-01],
                        [ -9.83581543e-02,  -9.83886719e-02],
                        [ -5.48706055e-02,  -5.48095703e-02],
                        [ -6.37817383e-03,  -6.34765625e-03],
                        [  4.82482910e-02,   4.82177734e-02],
                        [  1.02600098e-01,   1.02539062e-01],
                        [  1.42822266e-01,   1.42822266e-01],
                        [  1.59271240e-01,   1.59332275e-01],
                        [  1.55914307e-01,   1.55914307e-01],
                        [  1.45690918e-01,   1.45629883e-01],
                        [  1.37847900e-01,   1.37786865e-01],
                        [  1.32324219e-01,   1.32354736e-01],
                        [  1.24542236e-01,   1.24572754e-01],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  1.00463867e-01,   1.00433350e-01],
                        [  9.14916992e-02,   9.14306641e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  6.08520508e-02,   6.09130859e-02],
                        [  2.89916992e-02,   2.90222168e-02],
                        [ -8.57543945e-03,  -8.60595703e-03],
                        [ -4.16564941e-02,  -4.16870117e-02],
                        [ -6.14013672e-02,  -6.14318848e-02],
                        [ -6.52465820e-02,  -6.52160645e-02],
                        [ -5.45959473e-02,  -5.45349121e-02],
                        [ -3.25622559e-02,  -3.25927734e-02],
                        [ -7.96508789e-03,  -8.08715820e-03],
                        [  6.83593750e-03,   6.80541992e-03],
                        [  8.27026367e-03,   8.42285156e-03],
                        [  3.32641602e-03,   3.38745117e-03],
                        [ -2.16674805e-03,  -2.28881836e-03],
                        [ -7.41577148e-03,  -7.50732422e-03],
                        [ -1.01928711e-02,  -1.01013184e-02],
                        [ -5.64575195e-03,  -5.58471680e-03],
                        [  7.32421875e-03,   7.29370117e-03],
                        [  2.55737305e-02,   2.55432129e-02],
                        [  4.34570312e-02,   4.34265137e-02],
                        [  5.31921387e-02,   5.31616211e-02],
                        [  5.09033203e-02,   5.09643555e-02],
                        [  4.25109863e-02,   4.26025391e-02],
                        [  3.57360840e-02,   3.56140137e-02],
                        [  3.11279297e-02,   3.09753418e-02],
                        [  2.70996094e-02,   2.71911621e-02],
                        [  2.52990723e-02,   2.54516602e-02],
                        [  2.64282227e-02,   2.63671875e-02],
                        [  2.81372070e-02,   2.79541016e-02],
                        [  2.90527344e-02,   2.90832520e-02],
                        [  2.99377441e-02,   3.00292969e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  3.14025879e-02,   3.13110352e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.94287109e-02,   3.94592285e-02],
                        [  4.30908203e-02,   4.30603027e-02],
                        [  4.14123535e-02,   4.14428711e-02],
                        [  3.61022949e-02,   3.61633301e-02],
                        [  3.09448242e-02,   3.09143066e-02],
                        [  2.66113281e-02,   2.65197754e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  1.52282715e-02,   1.53198242e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [ -1.83105469e-03,  -1.92260742e-03],
                        [ -1.39465332e-02,  -1.40075684e-02],
                        [ -2.39257812e-02,  -2.38342285e-02],
                        [ -2.81066895e-02,  -2.80456543e-02],
                        [ -2.80761719e-02,  -2.81372070e-02],
                        [ -2.69775391e-02,  -2.70385742e-02],
                        [ -2.52075195e-02,  -2.51770020e-02],
                        [ -2.19116211e-02,  -2.18505859e-02],
                        [ -1.80969238e-02,  -1.81274414e-02],
                        [ -1.55944824e-02,  -1.56555176e-02],
                        [ -1.48010254e-02,  -1.47705078e-02],
                        [ -1.55334473e-02,  -1.54724121e-02],
                        [ -1.82495117e-02,  -1.82800293e-02],
                        [ -2.24609375e-02,  -2.24914551e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.43835449e-02,  -2.43225098e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.77001953e-02,  -1.77307129e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.13012695e-02,  -2.12707520e-02],
                        [ -1.42517090e-02,  -1.42211914e-02],
                        [ -6.68334961e-03,  -6.71386719e-03],
                        [ -1.19018555e-03,  -1.22070312e-03],
                        [  2.89916992e-03,   2.99072266e-03],
                        [  7.87353516e-03,   7.93457031e-03],
                        [  1.13830566e-02,   1.13220215e-02],
                        [  7.29370117e-03,   7.20214844e-03],
                        [ -4.15039062e-03,  -4.08935547e-03],
                        [ -1.47094727e-02,  -1.46484375e-02],
                        [ -1.96838379e-02,  -1.97448730e-02],
                        [ -2.04162598e-02,  -2.04772949e-02],
                        [ -1.74560547e-02,  -1.74255371e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  7.81250000e-03,   7.84301758e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.21252441e-02,   2.20336914e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  2.36206055e-02,   2.37121582e-02],
                        [  3.04565430e-02,   3.04870605e-02],
                        [  3.96118164e-02,   3.94897461e-02],
                        [  4.74243164e-02,   4.73937988e-02],
                        [  5.85327148e-02,   5.85937500e-02],
                        [  7.85522461e-02,   7.85827637e-02],
                        [  1.04248047e-01,   1.04217529e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.01379395e-01,   1.01318359e-01],
                        [  3.77197266e-02,   3.77502441e-02],
                        [ -5.53894043e-02,  -5.52978516e-02],
                        [ -1.60644531e-01,  -1.60675049e-01],
                        [ -2.54058838e-01,  -2.54211426e-01],
                        [ -3.09051514e-01,  -3.09051514e-01],
                        [ -3.09570312e-01,  -3.09417725e-01],
                        [ -2.66082764e-01,  -2.66052246e-01],
                        [ -2.12158203e-01,  -2.12341309e-01],
                        [ -1.77398682e-01,  -1.77459717e-01],
                        [ -1.65008545e-01,  -1.64886475e-01],
                        [ -1.58905029e-01,  -1.58813477e-01],
                        [ -1.45263672e-01,  -1.45355225e-01],
                        [ -1.21643066e-01,  -1.21704102e-01],
                        [ -8.91113281e-02,  -8.91113281e-02],
                        [ -4.51049805e-02,  -4.50134277e-02],
                        [  1.36108398e-02,   1.36718750e-02],
                        [  8.11462402e-02,   8.10852051e-02],
                        [  1.40472412e-01,   1.40380859e-01],
                        [  1.75109863e-01,   1.75140381e-01],
                        [  1.82403564e-01,   1.82495117e-01],
                        [  1.71905518e-01,   1.71875000e-01],
                        [  1.54418945e-01,   1.54327393e-01],
                        [  1.37207031e-01,   1.37207031e-01],
                        [  1.24267578e-01,   1.24359131e-01],
                        [  1.14898682e-01,   1.14868164e-01],
                        [  1.03698730e-01,   1.03607178e-01],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  5.85327148e-02,   5.85937500e-02],
                        [  2.36206055e-02,   2.35900879e-02],
                        [ -1.51977539e-02,  -1.52587891e-02],
                        [ -4.80651855e-02,  -4.80041504e-02],
                        [ -6.32324219e-02,  -6.31713867e-02],
                        [ -5.84716797e-02,  -5.85632324e-02],
                        [ -4.24804688e-02,  -4.25109863e-02],
                        [ -2.38647461e-02,  -2.37426758e-02],
                        [ -6.95800781e-03,  -6.92749023e-03],
                        [  4.11987305e-03,   3.99780273e-03],
                        [  6.56127930e-03,   6.53076172e-03],
                        [  3.08227539e-03,   3.23486328e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -4.97436523e-03,  -5.09643555e-03],
                        [ -7.04956055e-03,  -7.01904297e-03],
                        [ -2.38037109e-03,  -2.25830078e-03],
                        [  1.22070312e-02,   1.21765137e-02],
                        [  3.14636230e-02,   3.13720703e-02],
                        [  4.79125977e-02,   4.80041504e-02],
                        [  5.73425293e-02,   5.74035645e-02],
                        [  5.56030273e-02,   5.54504395e-02],
                        [  4.22363281e-02,   4.22058105e-02],
                        [  2.79235840e-02,   2.81066895e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  2.70080566e-02,   2.67944336e-02],
                        [  2.58178711e-02,   2.58483887e-02],
                        [  2.05078125e-02,   2.07214355e-02],
                        [  1.78527832e-02,   1.78222656e-02],
                        [  1.88903809e-02,   1.86767578e-02],
                        [  2.32238770e-02,   2.32543945e-02],
                        [  3.33557129e-02,   3.35083008e-02],
                        [  4.47387695e-02,   4.47082520e-02],
                        [  4.75158691e-02,   4.74243164e-02],
                        [  4.18701172e-02,   4.19006348e-02],
                        [  3.57360840e-02,   3.57666016e-02],
                        [  3.15856934e-02,   3.15246582e-02],
                        [  2.78015137e-02,   2.78625488e-02],
                        [  2.59094238e-02,   2.59704590e-02],
                        [  2.63061523e-02,   2.61840820e-02],
                        [  2.60314941e-02,   2.59704590e-02],
                        [  2.49633789e-02,   2.50854492e-02],
                        [  2.48413086e-02,   2.49023438e-02],
                        [  2.23388672e-02,   2.21862793e-02],
                        [  1.30920410e-02,   1.30310059e-02],
                        [ -2.74658203e-04,  -1.52587891e-04],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -2.45056152e-02,  -2.46276855e-02],
                        [ -3.34472656e-02,  -3.34167480e-02],
                        [ -3.57360840e-02,  -3.56445312e-02],
                        [ -3.19213867e-02,  -3.19824219e-02],
                        [ -2.86560059e-02,  -2.87475586e-02],
                        [ -2.92663574e-02,  -2.91748047e-02],
                        [ -2.98156738e-02,  -2.97241211e-02],
                        [ -2.70080566e-02,  -2.71301270e-02],
                        [ -2.42004395e-02,  -2.42919922e-02],
                        [ -2.43835449e-02,  -2.42309570e-02],
                        [ -2.49938965e-02,  -2.48718262e-02],
                        [ -2.46582031e-02,  -2.48107910e-02],
                        [ -2.61230469e-02,  -2.62451172e-02],
                        [ -2.82592773e-02,  -2.81372070e-02],
                        [ -2.65197754e-02,  -2.64282227e-02],
                        [ -2.18505859e-02,  -2.19421387e-02],
                        [ -1.79443359e-02,  -1.80358887e-02],
                        [ -1.29089355e-02,  -1.28479004e-02],
                        [ -4.82177734e-03,  -4.76074219e-03],
                        [  7.32421875e-04,   7.01904297e-04],
                        [ -1.70898438e-03,  -1.73950195e-03],
                        [ -9.33837891e-03,  -9.39941406e-03],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.78527832e-02,  -1.77612305e-02],
                        [ -1.58691406e-02,  -1.58386230e-02],
                        [ -1.60217285e-02,  -1.61437988e-02],
                        [ -2.10266113e-02,  -2.11181641e-02],
                        [ -2.28576660e-02,  -2.27050781e-02],
                        [ -1.28784180e-02,  -1.27563477e-02],
                        [  3.11279297e-03,   2.99072266e-03],
                        [  1.14135742e-02,   1.12609863e-02],
                        [  8.78906250e-03,   8.88061523e-03],
                        [  3.69262695e-03,   3.81469727e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  8.54492188e-04,   7.62939453e-04],
                        [ -1.83105469e-04,  -2.44140625e-04],
                        [  1.52587891e-04,   1.83105469e-04],
                        [  5.43212891e-03,   5.49316406e-03],
                        [  1.78222656e-02,   1.78527832e-02],
                        [  3.39965820e-02,   3.39050293e-02],
                        [  4.86755371e-02,   4.85839844e-02],
                        [  6.32019043e-02,   6.32324219e-02],
                        [  8.36181641e-02,   8.37097168e-02],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.34063721e-01,   1.33941650e-01],
                        [  1.39068604e-01,   1.39007568e-01],
                        [  1.12182617e-01,   1.12274170e-01],
                        [  4.85229492e-02,   4.86145020e-02],
                        [ -4.66308594e-02,  -4.66613770e-02],
                        [ -1.57318115e-01,  -1.57440186e-01],
                        [ -2.56927490e-01,  -2.56988525e-01],
                        [ -3.14819336e-01,  -3.14727783e-01],
                        [ -3.13842773e-01,  -3.13751221e-01],
                        [ -2.66754150e-01,  -2.66845703e-01],
                        [ -2.09411621e-01,  -2.09533691e-01],
                        [ -1.71752930e-01,  -1.71722412e-01],
                        [ -1.58081055e-01,  -1.57989502e-01],
                        [ -1.53900146e-01,  -1.53869629e-01],
                        [ -1.43859863e-01,  -1.43920898e-01],
                        [ -1.22619629e-01,  -1.22650146e-01],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -5.06896973e-02,  -5.06286621e-02],
                        [  4.30297852e-03,   4.36401367e-03],
                        [  6.97631836e-02,   6.97021484e-02],
                        [  1.29760742e-01,   1.29699707e-01],
                        [  1.67938232e-01,   1.67968750e-01],
                        [  1.81335449e-01,   1.81427002e-01],
                        [  1.78588867e-01,   1.78588867e-01],
                        [  1.68884277e-01,   1.68792725e-01],
                        [  1.56188965e-01,   1.56158447e-01],
                        [  1.40258789e-01,   1.40350342e-01],
                        [  1.19964600e-01,   1.20025635e-01],
                        [  9.55200195e-02,   9.54589844e-02],
                        [  6.73217773e-02,   6.72302246e-02],
                        [  3.43322754e-02,   3.43627930e-02],
                        [ -2.80761719e-03,  -2.68554688e-03],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -6.02722168e-02,  -6.03942871e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -4.14428711e-02,  -4.12902832e-02],
                        [ -1.63879395e-02,  -1.63574219e-02],
                        [ -2.53295898e-03,  -2.68554688e-03],
                        [ -1.86157227e-03,  -1.89208984e-03],
                        [ -2.28881836e-03,  -2.16674805e-03],
                        [  2.96020508e-03,   2.99072266e-03],
                        [  7.56835938e-03,   7.47680664e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  5.21850586e-03,   5.27954102e-03],
                        [  1.11083984e-02,   1.10778809e-02],
                        [  2.35595703e-02,   2.34985352e-02],
                        [  3.65295410e-02,   3.65600586e-02],
                        [  4.55627441e-02,   4.56237793e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  5.00793457e-02,   4.99877930e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  3.36608887e-02,   3.37829590e-02],
                        [  2.16674805e-02,   2.16979980e-02],
                        [  1.24206543e-02,   1.22680664e-02],
                        [  7.41577148e-03,   7.32421875e-03],
                        [  8.08715820e-03,   8.20922852e-03],
                        [  1.55334473e-02,   1.56555176e-02],
                        [  2.51159668e-02,   2.49938965e-02],
                        [  2.95104980e-02,   2.93273926e-02],
                        [  2.92663574e-02,   2.93273926e-02],
                        [  3.06091309e-02,   3.07922363e-02],
                        [  3.41186523e-02,   3.40881348e-02],
                        [  3.49121094e-02,   3.47900391e-02],
                        [  3.21960449e-02,   3.21350098e-02],
                        [  3.04870605e-02,   3.05480957e-02],
                        [  3.33862305e-02,   3.34777832e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  4.55932617e-02,   4.55017090e-02],
                        [  4.70886230e-02,   4.70275879e-02],
                        [  4.19616699e-02,   4.19921875e-02],
                        [  3.14331055e-02,   3.15551758e-02],
                        [  1.98059082e-02,   1.97753906e-02],
                        [  1.00402832e-02,   9.94873047e-03],
                        [  3.11279297e-03,   3.08227539e-03],
                        [ -1.40380859e-03,  -1.34277344e-03],
                        [ -6.22558594e-03,  -6.19506836e-03],
                        [ -1.33056641e-02,  -1.32751465e-02],
                        [ -2.02636719e-02,  -2.02941895e-02],
                        [ -2.52685547e-02,  -2.53601074e-02],
                        [ -3.08837891e-02,  -3.09143066e-02],
                        [ -3.78723145e-02,  -3.77197266e-02],
                        [ -4.20837402e-02,  -4.19921875e-02],
                        [ -4.18395996e-02,  -4.20227051e-02],
                        [ -4.05578613e-02,  -4.07104492e-02],
                        [ -3.85437012e-02,  -3.83605957e-02],
                        [ -3.22875977e-02,  -3.20739746e-02],
                        [ -2.47497559e-02,  -2.49023438e-02],
                        [ -2.39562988e-02,  -2.41699219e-02],
                        [ -2.90527344e-02,  -2.89611816e-02],
                        [ -3.15856934e-02,  -3.14025879e-02],
                        [ -2.93884277e-02,  -2.94494629e-02],
                        [ -2.59399414e-02,  -2.60925293e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.35803223e-02,  -1.34887695e-02],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -3.87573242e-03,  -3.93676758e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.40380859e-02,  -1.40075684e-02],
                        [ -1.61132812e-02,  -1.60827637e-02],
                        [ -1.33056641e-02,  -1.33361816e-02],
                        [ -9.58251953e-03,  -9.61303711e-03],
                        [ -7.81250000e-03,  -7.78198242e-03],
                        [ -6.89697266e-03,  -6.86645508e-03],
                        [ -5.95092773e-03,  -5.98144531e-03],
                        [ -5.61523438e-03,  -5.64575195e-03],
                        [ -6.13403320e-03,  -6.10351562e-03],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -6.43920898e-03,  -6.46972656e-03],
                        [ -3.17382812e-03,  -3.20434570e-03],
                        [  2.53295898e-03,   2.59399414e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  7.44628906e-03,   7.38525391e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  7.53784180e-03,   7.59887695e-03],
                        [  1.67846680e-02,   1.67541504e-02],
                        [  3.04260254e-02,   3.03955078e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  6.16455078e-02,   6.16760254e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  1.13189697e-01,   1.13159180e-01],
                        [  1.37054443e-01,   1.36993408e-01],
                        [  1.40502930e-01,   1.40502930e-01],
                        [  1.12121582e-01,   1.12182617e-01],
                        [  4.94689941e-02,   4.95300293e-02],
                        [ -4.26940918e-02,  -4.27856445e-02],
                        [ -1.51916504e-01,  -1.52008057e-01],
                        [ -2.53265381e-01,  -2.53173828e-01],
                        [ -3.15002441e-01,  -3.14910889e-01],
                        [ -3.18908691e-01,  -3.18969727e-01],
                        [ -2.75604248e-01,  -2.75726318e-01],
                        [ -2.15667725e-01,  -2.15637207e-01],
                        [ -1.67694092e-01,  -1.67633057e-01],
                        [ -1.43310547e-01,  -1.43310547e-01],
                        [ -1.35131836e-01,  -1.35162354e-01],
                        [ -1.27990723e-01,  -1.28021240e-01],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -9.18579102e-02,  -9.17968750e-02],
                        [ -6.10046387e-02,  -6.09436035e-02],
                        [ -1.59301758e-02,  -1.59912109e-02],
                        [  4.35791016e-02,   4.34875488e-02],
                        [  1.07696533e-01,   1.07757568e-01],
                        [  1.60308838e-01,   1.60400391e-01],
                        [  1.88293457e-01,   1.88232422e-01],
                        [  1.90979004e-01,   1.90917969e-01],
                        [  1.80908203e-01,   1.80938721e-01],
                        [  1.69952393e-01,   1.70013428e-01],
                        [  1.56372070e-01,   1.56341553e-01],
                        [  1.30706787e-01,   1.30676270e-01],
                        [  9.04846191e-02,   9.05456543e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [ -5.00488281e-03,  -5.09643555e-03],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -5.66711426e-02,  -5.65490723e-02],
                        [ -4.90112305e-02,  -4.89501953e-02],
                        [ -3.17687988e-02,  -3.19213867e-02],
                        [ -2.13928223e-02,  -2.14538574e-02],
                        [ -2.00805664e-02,  -1.99584961e-02],
                        [ -1.80358887e-02,  -1.79443359e-02],
                        [ -9.30786133e-03,  -9.39941406e-03],
                        [  2.65502930e-03,   2.50244141e-03],
                        [  1.30615234e-02,   1.30920410e-02],
                        [  2.08740234e-02,   2.09960938e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  3.22875977e-02,   3.21655273e-02],
                        [  3.76892090e-02,   3.76281738e-02],
                        [  4.29687500e-02,   4.30603027e-02],
                        [  4.60815430e-02,   4.61425781e-02],
                        [  4.47387695e-02,   4.47082520e-02],
                        [  3.90625000e-02,   3.90014648e-02],
                        [  3.10974121e-02,   3.10668945e-02],
                        [  2.28881836e-02,   2.29187012e-02],
                        [  1.68457031e-02,   1.69372559e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  1.57775879e-02,   1.56250000e-02],
                        [  1.49536133e-02,   1.48620605e-02],
                        [  1.41296387e-02,   1.43127441e-02],
                        [  1.91650391e-02,   1.92871094e-02],
                        [  2.92358398e-02,   2.90527344e-02],
                        [  3.66821289e-02,   3.65295410e-02],
                        [  3.83605957e-02,   3.84826660e-02],
                        [  3.81774902e-02,   3.83300781e-02],
                        [  3.92150879e-02,   3.91845703e-02],
                        [  3.98559570e-02,   3.97644043e-02],
                        [  3.80249023e-02,   3.79943848e-02],
                        [  3.58581543e-02,   3.58886719e-02],
                        [  3.75976562e-02,   3.77197266e-02],
                        [  4.32739258e-02,   4.33044434e-02],
                        [  4.63867188e-02,   4.62646484e-02],
                        [  4.07104492e-02,   4.05883789e-02],
                        [  2.96020508e-02,   2.97241211e-02],
                        [  2.29797363e-02,   2.31323242e-02],
                        [  2.27661133e-02,   2.27050781e-02],
                        [  2.02941895e-02,   2.01110840e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  2.44140625e-04,   3.96728516e-04],
                        [ -6.74438477e-03,  -6.71386719e-03],
                        [ -1.19018555e-02,  -1.19934082e-02],
                        [ -1.94091797e-02,  -1.94702148e-02],
                        [ -3.08532715e-02,  -3.07922363e-02],
                        [ -4.42504883e-02,  -4.41894531e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -5.42297363e-02,  -5.42602539e-02],
                        [ -4.21752930e-02,  -4.22363281e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.71508789e-02,  -1.70898438e-02],
                        [ -1.73950195e-02,  -1.73645020e-02],
                        [ -2.42614746e-02,  -2.42919922e-02],
                        [ -3.25012207e-02,  -3.25622559e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -2.95410156e-02,  -2.94494629e-02],
                        [ -1.93481445e-02,  -1.93176270e-02],
                        [ -1.25122070e-02,  -1.25732422e-02],
                        [ -1.27258301e-02,  -1.27563477e-02],
                        [ -1.66625977e-02,  -1.66320801e-02],
                        [ -1.69677734e-02,  -1.69067383e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  7.32421875e-04,   6.40869141e-04],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  6.71386719e-03,   6.74438477e-03],
                        [  2.80761719e-03,   2.83813477e-03],
                        [ -2.28881836e-03,  -2.31933594e-03],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.23596191e-02,  -1.23901367e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.51367188e-02,   1.51062012e-02],
                        [  1.51367188e-02,   1.51062012e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [ -6.71386719e-04,  -6.10351562e-04],
                        [ -1.25122070e-03,  -1.22070312e-03],
                        [  6.86645508e-03,   6.83593750e-03],
                        [  1.94702148e-02,   1.94396973e-02],
                        [  3.51867676e-02,   3.52172852e-02],
                        [  5.68237305e-02,   5.68847656e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  1.14685059e-01,   1.14593506e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  1.33361816e-01,   1.33453369e-01],
                        [  1.05499268e-01,   1.05560303e-01],
                        [  4.82788086e-02,   4.81872559e-02],
                        [ -3.71398926e-02,  -3.72009277e-02],
                        [ -1.40625000e-01,  -1.40563965e-01],
                        [ -2.37518311e-01,  -2.37457275e-01],
                        [ -2.96203613e-01,  -2.96264648e-01],
                        [ -2.99560547e-01,  -2.99621582e-01],
                        [ -2.58209229e-01,  -2.58148193e-01],
                        [ -2.02606201e-01,  -2.02575684e-01],
                        [ -1.63055420e-01,  -1.63085938e-01],
                        [ -1.50115967e-01,  -1.50085449e-01],
                        [ -1.50115967e-01,  -1.50024414e-01],
                        [ -1.42974854e-01,  -1.43005371e-01],
                        [ -1.22314453e-01,  -1.22406006e-01],
                        [ -9.32922363e-02,  -9.32617188e-02],
                        [ -5.77087402e-02,  -5.76171875e-02],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [  4.86755371e-02,   4.85534668e-02],
                        [  1.12457275e-01,   1.12426758e-01],
                        [  1.66564941e-01,   1.66656494e-01],
                        [  1.98059082e-01,   1.98089600e-01],
                        [  2.03063965e-01,   2.03002930e-01],
                        [  1.90795898e-01,   1.90734863e-01],
                        [  1.73095703e-01,   1.73126221e-01],
                        [  1.50512695e-01,   1.50573730e-01],
                        [  1.14654541e-01,   1.14685059e-01],
                        [  6.27441406e-02,   6.27136230e-02],
                        [  5.98144531e-03,   5.95092773e-03],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -5.19104004e-02,  -5.18798828e-02],
                        [ -4.52880859e-02,  -4.52575684e-02],
                        [ -2.98156738e-02,  -2.98767090e-02],
                        [ -1.92565918e-02,  -1.93176270e-02],
                        [ -1.85852051e-02,  -1.85546875e-02],
                        [ -2.07214355e-02,  -2.06604004e-02],
                        [ -1.69372559e-02,  -1.69982910e-02],
                        [ -7.38525391e-03,  -7.44628906e-03],
                        [  3.14331055e-03,   3.17382812e-03],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.79748535e-02,   1.79138184e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  2.42004395e-02,   2.42614746e-02],
                        [  3.24096680e-02,   3.23486328e-02],
                        [  4.44641113e-02,   4.44030762e-02],
                        [  5.48095703e-02,   5.48706055e-02],
                        [  5.93872070e-02,   5.94482422e-02],
                        [  5.67932129e-02,   5.67016602e-02],
                        [  4.77600098e-02,   4.76684570e-02],
                        [  3.72924805e-02,   3.73840332e-02],
                        [  3.02429199e-02,   3.03344727e-02],
                        [  2.41394043e-02,   2.40478516e-02],
                        [  1.47094727e-02,   1.45874023e-02],
                        [  6.25610352e-03,   6.31713867e-03],
                        [  7.56835938e-03,   7.69042969e-03],
                        [  1.90124512e-02,   1.89819336e-02],
                        [  3.12805176e-02,   3.11279297e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.79333496e-02,   3.80859375e-02],
                        [  3.96118164e-02,   3.96423340e-02],
                        [  4.25720215e-02,   4.24499512e-02],
                        [  4.26940918e-02,   4.26025391e-02],
                        [  3.88488770e-02,   3.89404297e-02],
                        [  3.59497070e-02,   3.60717773e-02],
                        [  3.75976562e-02,   3.75671387e-02],
                        [  4.08020020e-02,   4.06799316e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  3.63769531e-02,   3.64990234e-02],
                        [  2.99377441e-02,   2.99987793e-02],
                        [  2.33459473e-02,   2.32543945e-02],
                        [  1.65405273e-02,   1.65100098e-02],
                        [  9.58251953e-03,   9.61303711e-03],
                        [  2.92968750e-03,   2.96020508e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -1.52893066e-02,  -1.53198242e-02],
                        [ -2.67639160e-02,  -2.67944336e-02],
                        [ -3.45153809e-02,  -3.45458984e-02],
                        [ -3.79333496e-02,  -3.78723145e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -2.71911621e-02,  -2.72216797e-02],
                        [ -2.09655762e-02,  -2.09350586e-02],
                        [ -1.62353516e-02,  -1.61437988e-02],
                        [ -1.46179199e-02,  -1.46789551e-02],
                        [ -1.80358887e-02,  -1.81579590e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.05688477e-02,  -2.04162598e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -2.77709961e-03,  -2.96020508e-03],
                        [ -7.62939453e-04,  -8.23974609e-04],
                        [ -2.44140625e-04,  -1.22070312e-04],
                        [  4.21142578e-03,   4.33349609e-03],
                        [  8.63647461e-03,   8.51440430e-03],
                        [  4.69970703e-03,   4.60815430e-03],
                        [ -8.45336914e-03,  -8.39233398e-03],
                        [ -2.27355957e-02,  -2.26745605e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.13317871e-02,  -2.13012695e-02],
                        [ -1.20849609e-02,  -1.21154785e-02],
                        [ -4.24194336e-03,  -4.27246094e-03],
                        [ -4.88281250e-04,  -3.96728516e-04],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [ -1.25122070e-03,  -1.34277344e-03],
                        [ -3.81469727e-03,  -3.87573242e-03],
                        [ -7.78198242e-03,  -7.72094727e-03],
                        [ -1.03759766e-02,  -1.02844238e-02],
                        [ -1.01013184e-02,  -1.01623535e-02],
                        [ -8.36181641e-03,  -8.48388672e-03],
                        [ -2.92968750e-03,  -2.89916992e-03],
                        [  1.04675293e-02,   1.05590820e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  4.19311523e-02,   4.18395996e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  6.50329590e-02,   6.50634766e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.23901367e-01,   1.23931885e-01],
                        [  1.32415771e-01,   1.32385254e-01],
                        [  1.14196777e-01,   1.14166260e-01],
                        [  5.71899414e-02,   5.71899414e-02],
                        [ -3.56750488e-02,  -3.56445312e-02],
                        [ -1.44775391e-01,  -1.44775391e-01],
                        [ -2.41607666e-01,  -2.41638184e-01],
                        [ -2.99316406e-01,  -2.99346924e-01],
                        [ -3.03344727e-01,  -3.03314209e-01],
                        [ -2.61627197e-01,  -2.61566162e-01],
                        [ -2.03674316e-01,  -2.03704834e-01],
                        [ -1.60522461e-01,  -1.60614014e-01],
                        [ -1.41510010e-01,  -1.41510010e-01],
                        [ -1.33605957e-01,  -1.33483887e-01],
                        [ -1.22436523e-01,  -1.22436523e-01],
                        [ -1.06933594e-01,  -1.07025146e-01],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -7.25097656e-02,  -7.24487305e-02],
                        [ -3.75366211e-02,  -3.75061035e-02],
                        [  2.09045410e-02,   2.08435059e-02],
                        [  9.70153809e-02,   9.69848633e-02],
                        [  1.70837402e-01,   1.70867920e-01],
                        [  2.18048096e-01,   2.18078613e-01],
                        [  2.27813721e-01,   2.27813721e-01],
                        [  2.08831787e-01,   2.08801270e-01],
                        [  1.75384521e-01,   1.75384521e-01],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  8.10241699e-02,   8.10546875e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [ -2.70080566e-02,  -2.70690918e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.16967773e-02,  -5.16662598e-02],
                        [ -3.63464355e-02,  -3.63159180e-02],
                        [ -1.98059082e-02,  -1.98364258e-02],
                        [ -9.12475586e-03,  -9.15527344e-03],
                        [ -2.80761719e-03,  -2.77709961e-03],
                        [  3.29589844e-03,   3.32641602e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  9.46044922e-03,   9.42993164e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  1.52587891e-04,   1.83105469e-04],
                        [  2.31933594e-03,   2.34985352e-03],
                        [  1.39465332e-02,   1.39160156e-02],
                        [  3.26538086e-02,   3.26232910e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  7.28759766e-02,   7.29064941e-02],
                        [  8.53881836e-02,   8.54187012e-02],
                        [  8.72802734e-02,   8.72497559e-02],
                        [  7.69042969e-02,   7.68432617e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  3.96728516e-02,   3.97644043e-02],
                        [  2.28271484e-02,   2.27966309e-02],
                        [  6.83593750e-03,   6.74438477e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -4.39453125e-03,  -4.30297852e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.57873535e-02,   2.57263184e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.23889160e-02,   4.24499512e-02],
                        [  4.62341309e-02,   4.62646484e-02],
                        [  4.88281250e-02,   4.87976074e-02],
                        [  5.02014160e-02,   5.01708984e-02],
                        [  4.90112305e-02,   4.90417480e-02],
                        [  4.31823730e-02,   4.32128906e-02],
                        [  3.57055664e-02,   3.57360840e-02],
                        [  3.34167480e-02,   3.33862305e-02],
                        [  3.69262695e-02,   3.68957520e-02],
                        [  3.86047363e-02,   3.86352539e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  2.04467773e-02,   2.04162598e-02],
                        [  7.75146484e-03,   7.78198242e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -8.36181641e-03,  -8.42285156e-03],
                        [ -1.16577148e-02,  -1.16882324e-02],
                        [ -1.43737793e-02,  -1.42822266e-02],
                        [ -1.85241699e-02,  -1.84936523e-02],
                        [ -2.43225098e-02,  -2.44445801e-02],
                        [ -2.97851562e-02,  -2.98461914e-02],
                        [ -3.21655273e-02,  -3.20434570e-02],
                        [ -3.05175781e-02,  -3.04260254e-02],
                        [ -2.67639160e-02,  -2.68554688e-02],
                        [ -2.40478516e-02,  -2.41088867e-02],
                        [ -2.38037109e-02,  -2.37426758e-02],
                        [ -2.47497559e-02,  -2.47192383e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -1.12915039e-02,  -1.13220215e-02],
                        [ -4.36401367e-03,  -4.39453125e-03],
                        [ -2.86865234e-03,  -2.80761719e-03],
                        [ -6.62231445e-03,  -6.59179688e-03],
                        [ -1.29089355e-02,  -1.29699707e-02],
                        [ -1.94702148e-02,  -1.95312500e-02],
                        [ -2.47192383e-02,  -2.46582031e-02],
                        [ -2.78320312e-02,  -2.77404785e-02],
                        [ -2.99072266e-02,  -2.99682617e-02],
                        [ -3.20434570e-02,  -3.21350098e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -2.74658203e-02,  -2.73742676e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -1.54724121e-02,  -1.55334473e-02],
                        [ -1.50756836e-02,  -1.51062012e-02],
                        [ -1.72119141e-02,  -1.71508789e-02],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.87072754e-02,  -1.87377930e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [  4.21142578e-03,   4.24194336e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  1.38854980e-02,   1.39160156e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  5.18798828e-03,   5.12695312e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  1.47399902e-02,   1.48010254e-02],
                        [  3.12805176e-02,   3.12500000e-02],
                        [  5.27954102e-02,   5.27648926e-02],
                        [  7.62939453e-02,   7.62634277e-02],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  1.17919922e-01,   1.17980957e-01],
                        [  1.29974365e-01,   1.30004883e-01],
                        [  1.26892090e-01,   1.26800537e-01],
                        [  9.98229980e-02,   9.97619629e-02],
                        [  4.48913574e-02,   4.49829102e-02],
                        [ -3.44543457e-02,  -3.43933105e-02],
                        [ -1.28784180e-01,  -1.28845215e-01],
                        [ -2.20794678e-01,  -2.20855713e-01],
                        [ -2.83111572e-01,  -2.83081055e-01],
                        [ -2.92144775e-01,  -2.92083740e-01],
                        [ -2.51831055e-01,  -2.51831055e-01],
                        [ -1.95220947e-01,  -1.95281982e-01],
                        [ -1.56341553e-01,  -1.56372070e-01],
                        [ -1.44042969e-01,  -1.43981934e-01],
                        [ -1.44653320e-01,  -1.44592285e-01],
                        [ -1.42669678e-01,  -1.42730713e-01],
                        [ -1.32873535e-01,  -1.32934570e-01],
                        [ -1.16058350e-01,  -1.15997314e-01],
                        [ -9.02404785e-02,  -9.01794434e-02],
                        [ -4.84924316e-02,  -4.85534668e-02],
                        [  1.42822266e-02,   1.42211914e-02],
                        [  9.29565430e-02,   9.29870605e-02],
                        [  1.70745850e-01,   1.70776367e-01],
                        [  2.26806641e-01,   2.26776123e-01],
                        [  2.46612549e-01,   2.46582031e-01],
                        [  2.27722168e-01,   2.27752686e-01],
                        [  1.77215576e-01,   1.77215576e-01],
                        [  1.06262207e-01,   1.06262207e-01],
                        [  3.13110352e-02,   3.13110352e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -5.05065918e-02,  -5.05371094e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -2.60009766e-02,  -2.59704590e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  1.07421875e-02,   1.07116699e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  6.59179688e-03,   6.62231445e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  6.34765625e-03,   6.31713867e-03],
                        [  4.88281250e-03,   4.85229492e-03],
                        [  5.24902344e-03,   5.27954102e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  7.38525391e-02,   7.38220215e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  9.70764160e-02,   9.71374512e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  7.35778809e-02,   7.35168457e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  3.96423340e-02,   3.97033691e-02],
                        [  2.91442871e-02,   2.91748047e-02],
                        [  2.27050781e-02,   2.26440430e-02],
                        [  1.76391602e-02,   1.76086426e-02],
                        [  1.38854980e-02,   1.39160156e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.50451660e-02,   1.50146484e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.55432129e-02,   2.55737305e-02],
                        [  3.26232910e-02,   3.25927734e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.16467285e-02,   3.16772461e-02],
                        [  2.89306641e-02,   2.89611816e-02],
                        [  3.11584473e-02,   3.11279297e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  3.92456055e-02,   3.92456055e-02],
                        [  3.18908691e-02,   3.18603516e-02],
                        [  2.34680176e-02,   2.34985352e-02],
                        [  1.55029297e-02,   1.55334473e-02],
                        [  4.48608398e-03,   4.45556641e-03],
                        [ -9.67407227e-03,  -9.70458984e-03],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -3.04260254e-02,  -3.03955078e-02],
                        [ -3.27758789e-02,  -3.28063965e-02],
                        [ -2.89306641e-02,  -2.89611816e-02],
                        [ -2.07214355e-02,  -2.06909180e-02],
                        [ -1.22375488e-02,  -1.22070312e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -2.50549316e-02,  -2.50854492e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -3.34472656e-02,  -3.34167480e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -1.88598633e-02,  -1.88903809e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -1.70593262e-02,  -1.70288086e-02],
                        [ -2.21862793e-02,  -2.22167969e-02],
                        [ -2.37731934e-02,  -2.38037109e-02],
                        [ -2.13623047e-02,  -2.13317871e-02],
                        [ -1.89208984e-02,  -1.88903809e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.92053223e-02,  -2.91748047e-02],
                        [ -3.00903320e-02,  -3.00598145e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [  2.44140625e-03,   2.41088867e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -3.47900391e-03,  -3.44848633e-03],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  1.10778809e-02,   1.10473633e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.95410156e-02,   2.95715332e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  4.26025391e-02,   4.25415039e-02],
                        [  5.31921387e-02,   5.31616211e-02],
                        [  7.15026855e-02,   7.15637207e-02],
                        [  9.45129395e-02,   9.45434570e-02],
                        [  1.14044189e-01,   1.13983154e-01],
                        [  1.24542236e-01,   1.24511719e-01],
                        [  1.23565674e-01,   1.23596191e-01],
                        [  1.04095459e-01,   1.04125977e-01],
                        [  5.52978516e-02,   5.53283691e-02],
                        [ -2.60925293e-02,  -2.61230469e-02],
                        [ -1.29333496e-01,  -1.29364014e-01],
                        [ -2.30926514e-01,  -2.30926514e-01],
                        [ -2.99133301e-01,  -2.99072266e-01],
                        [ -3.08746338e-01,  -3.08715820e-01],
                        [ -2.64556885e-01,  -2.64587402e-01],
                        [ -2.02056885e-01,  -2.02087402e-01],
                        [ -1.55426025e-01,  -1.55426025e-01],
                        [ -1.31286621e-01,  -1.31225586e-01],
                        [ -1.18072510e-01,  -1.18072510e-01],
                        [ -1.07818604e-01,  -1.07879639e-01],
                        [ -1.00402832e-01,  -1.00433350e-01],
                        [ -9.45739746e-02,  -9.45434570e-02],
                        [ -8.11767578e-02,  -8.11462402e-02],
                        [ -4.66308594e-02,  -4.66613770e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  9.50622559e-02,   9.50622559e-02],
                        [  1.70715332e-01,   1.70715332e-01],
                        [  2.20489502e-01,   2.20520020e-01],
                        [  2.31628418e-01,   2.31628418e-01],
                        [  2.02972412e-01,   2.02941895e-01],
                        [  1.44714355e-01,   1.44683838e-01],
                        [  7.41577148e-02,   7.42187500e-02],
                        [  9.70458984e-03,   9.73510742e-03],
                        [ -3.41186523e-02,  -3.41796875e-02],
                        [ -5.11779785e-02,  -5.12084961e-02],
                        [ -4.70581055e-02,  -4.69970703e-02],
                        [ -3.32641602e-02,  -3.32336426e-02],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -6.10351562e-04,  -6.40869141e-04],
                        [  1.49536133e-02,   1.49841309e-02],
                        [  2.37121582e-02,   2.37426758e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  1.71813965e-02,   1.71508789e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  7.79724121e-02,   7.79418945e-02],
                        [  9.22851562e-02,   9.22851562e-02],
                        [  9.54284668e-02,   9.54589844e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  7.34863281e-02,   7.34558105e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  2.63671875e-02,   2.63977051e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.48010254e-02,   1.47705078e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.76794434e-02,   2.76489258e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.07006836e-02,   3.07312012e-02],
                        [  3.31420898e-02,   3.31726074e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  8.60595703e-03,   8.63647461e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -8.14819336e-03,  -8.17871094e-03],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -2.24914551e-02,  -2.24609375e-02],
                        [ -2.71606445e-02,  -2.71301270e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -1.59301758e-02,  -1.59606934e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.73742676e-02,  -2.74047852e-02],
                        [ -2.60009766e-02,  -2.60314941e-02],
                        [ -2.27050781e-02,  -2.26745605e-02],
                        [ -1.84326172e-02,  -1.84020996e-02],
                        [ -1.60217285e-02,  -1.60522461e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.52990723e-02,  -2.53295898e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -4.48608398e-03,  -4.51660156e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -1.15966797e-02,  -1.15661621e-02],
                        [ -1.86157227e-02,  -1.85852051e-02],
                        [ -2.35900879e-02,  -2.36206055e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.74255371e-02,  -1.73645020e-02],
                        [ -1.14746094e-02,  -1.14440918e-02],
                        [ -8.94165039e-03,  -8.97216797e-03],
                        [ -9.06372070e-03,  -9.09423828e-03],
                        [ -8.42285156e-03,  -8.39233398e-03],
                        [ -4.97436523e-03,  -4.94384766e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  2.80761719e-03,   2.77709961e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  9.07287598e-02,   9.07592773e-02],
                        [  1.12060547e-01,   1.12030029e-01],
                        [  1.22406006e-01,   1.22375488e-01],
                        [  1.13952637e-01,   1.13952637e-01],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  2.12402344e-02,   2.12707520e-02],
                        [ -6.39953613e-02,  -6.40258789e-02],
                        [ -1.61010742e-01,  -1.61041260e-01],
                        [ -2.45391846e-01,  -2.45391846e-01],
                        [ -2.89245605e-01,  -2.89215088e-01],
                        [ -2.77465820e-01,  -2.77465820e-01],
                        [ -2.23388672e-01,  -2.23419189e-01],
                        [ -1.62841797e-01,  -1.62841797e-01],
                        [ -1.26312256e-01,  -1.26312256e-01],
                        [ -1.17858887e-01,  -1.17858887e-01],
                        [ -1.21704102e-01,  -1.21673584e-01],
                        [ -1.22375488e-01,  -1.22375488e-01],
                        [ -1.15051270e-01,  -1.15051270e-01],
                        [ -1.01806641e-01,  -1.01776123e-01],
                        [ -8.38928223e-02,  -8.38928223e-02],
                        [ -5.60913086e-02,  -5.61218262e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  1.43280029e-01,   1.43280029e-01],
                        [  2.08831787e-01,   2.08801270e-01],
                        [  2.28973389e-01,   2.29003906e-01],
                        [  1.91253662e-01,   1.91253662e-01],
                        [  1.12121582e-01,   1.12121582e-01],
                        [  2.87475586e-02,   2.87475586e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.82080078e-02,  -3.81774902e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -1.48315430e-02,  -1.48620605e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  3.41186523e-02,   3.41491699e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  3.31115723e-02,   3.31420898e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  8.21228027e-02,   8.20922852e-02],
                        [  9.58862305e-02,   9.58557129e-02],
                        [  9.69848633e-02,   9.70153809e-02],
                        [  8.47778320e-02,   8.48083496e-02],
                        [  6.63146973e-02,   6.62841797e-02],
                        [  5.21240234e-02,   5.20935059e-02],
                        [  4.51660156e-02,   4.51965332e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.41186523e-02,   3.40881348e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.45666504e-02,   2.45361328e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.53601074e-02,   2.53906250e-02],
                        [  2.11181641e-02,   2.10876465e-02],
                        [  1.96533203e-02,   1.96228027e-02],
                        [  2.18811035e-02,   2.19116211e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  3.46984863e-02,   3.47290039e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  2.92968750e-02,   2.92663574e-02],
                        [  2.64282227e-02,   2.64587402e-02],
                        [  2.38647461e-02,   2.38952637e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.56958008e-02,  -2.56652832e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -4.35180664e-02,  -4.34875488e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -3.35388184e-02,  -3.35693359e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.53906250e-02,  -2.53601074e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -5.88989258e-03,  -5.85937500e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -2.53601074e-02,  -2.53295898e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  3.50952148e-02,   3.51257324e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  6.77795410e-02,   6.77795410e-02],
                        [  7.99255371e-02,   7.99560547e-02],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  9.86022949e-02,   9.85717773e-02],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  1.08734131e-01,   1.08734131e-01],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  4.89196777e-02,   4.88891602e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -1.30706787e-01,  -1.30706787e-01],
                        [ -2.33367920e-01,  -2.33398438e-01],
                        [ -2.99407959e-01,  -2.99407959e-01],
                        [ -3.02093506e-01,  -3.02093506e-01],
                        [ -2.50274658e-01,  -2.50305176e-01],
                        [ -1.83380127e-01,  -1.83380127e-01],
                        [ -1.36962891e-01,  -1.36932373e-01],
                        [ -1.17767334e-01,  -1.17767334e-01],
                        [ -1.11877441e-01,  -1.11907959e-01],
                        [ -1.06201172e-01,  -1.06201172e-01],
                        [ -9.60388184e-02,  -9.60388184e-02],
                        [ -8.06579590e-02,  -8.06579590e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [  2.71606445e-03,   2.74658203e-03],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  1.13861084e-01,   1.13861084e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.77978516e-01,   1.77978516e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  8.79516602e-02,   8.79516602e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  1.70898438e-03,   1.73950195e-03],
                        [  7.41577148e-03,   7.38525391e-03],
                        [  1.61437988e-02,   1.61743164e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  3.79333496e-02,   3.79028320e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  2.22778320e-03,   2.22778320e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  1.01928711e-02,   1.02233887e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.09130859e-01,   1.09130859e-01],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  7.37609863e-02,   7.37609863e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  3.06091309e-02,   3.05786133e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  4.24499512e-02,   4.24804688e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  5.76782227e-03,   5.79833984e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -9.97924805e-03,  -1.00097656e-02],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -2.66418457e-02,  -2.66723633e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.31420898e-02,  -3.31115723e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.19311523e-02,  -4.19616699e-02],
                        [ -3.69262695e-02,  -3.68957520e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.29699707e-02,  -1.30004883e-02],
                        [ -3.72314453e-03,  -3.69262695e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  6.10351562e-05,   3.05175781e-05],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  3.32031250e-02,   3.32336426e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  8.77380371e-02,   8.77685547e-02],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  1.23840332e-01,   1.23840332e-01],
                        [  1.26739502e-01,   1.26739502e-01],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  4.97131348e-02,   4.97131348e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -1.31042480e-01,  -1.31042480e-01],
                        [ -2.28546143e-01,  -2.28576660e-01],
                        [ -2.92266846e-01,  -2.92266846e-01],
                        [ -2.98370361e-01,  -2.98370361e-01],
                        [ -2.52990723e-01,  -2.53021240e-01],
                        [ -1.90063477e-01,  -1.90032959e-01],
                        [ -1.42242432e-01,  -1.42242432e-01],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -1.04278564e-01,  -1.04278564e-01],
                        [ -9.43298340e-02,  -9.43298340e-02],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -7.51953125e-02,  -7.51647949e-02],
                        [ -6.13708496e-02,  -6.13403320e-02],
                        [ -4.29687500e-02,  -4.29992676e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [  1.62353516e-02,   1.62658691e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  9.44824219e-02,   9.44824219e-02],
                        [  1.10534668e-01,   1.10534668e-01],
                        [  1.02264404e-01,   1.02264404e-01],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  4.91333008e-02,   4.91333008e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  2.01416016e-02,   2.01110840e-02],
                        [  2.94494629e-02,   2.94799805e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.03912354e-01,   1.03912354e-01],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  5.65795898e-02,   5.66101074e-02],
                        [  5.30700684e-02,   5.30700684e-02],
                        [  4.10156250e-02,   4.09851074e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.37426758e-02,   2.37121582e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -2.74658203e-04,  -2.44140625e-04],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -2.80761719e-02,  -2.80456543e-02],
                        [ -3.16772461e-02,  -3.16467285e-02],
                        [ -3.46374512e-02,  -3.46679688e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.63464355e-02,  -3.63769531e-02],
                        [ -4.06188965e-02,  -4.06494141e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -3.24096680e-02,  -3.24401855e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -2.34680176e-02,  -2.34375000e-02],
                        [ -2.70690918e-02,  -2.70996094e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.35900879e-02,  -2.35595703e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.49023438e-02,  -2.49328613e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.25732422e-02,  -1.25427246e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -3.08227539e-03,  -3.11279297e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  5.91430664e-02,   5.91430664e-02],
                        [  7.14111328e-02,   7.14111328e-02],
                        [  7.87963867e-02,   7.88269043e-02],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  1.06140137e-01,   1.06109619e-01],
                        [  1.21429443e-01,   1.21429443e-01],
                        [  1.22680664e-01,   1.22680664e-01],
                        [  1.03179932e-01,   1.03179932e-01],
                        [  5.67932129e-02,   5.67932129e-02],
                        [ -2.27355957e-02,  -2.27050781e-02],
                        [ -1.27166748e-01,  -1.27166748e-01],
                        [ -2.27478027e-01,  -2.27508545e-01],
                        [ -2.89398193e-01,  -2.89398193e-01],
                        [ -2.94738770e-01,  -2.94738770e-01],
                        [ -2.52471924e-01,  -2.52471924e-01],
                        [ -1.92901611e-01,  -1.92901611e-01],
                        [ -1.46575928e-01,  -1.46575928e-01],
                        [ -1.22070312e-01,  -1.22070312e-01],
                        [ -1.06781006e-01,  -1.06781006e-01],
                        [ -8.95996094e-02,  -8.95996094e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  3.68041992e-02,   3.68347168e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  3.44238281e-02,   3.43933105e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  2.88085938e-02,   2.87780762e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  8.51135254e-02,   8.51135254e-02],
                        [  1.12426758e-01,   1.12457275e-01],
                        [  1.26281738e-01,   1.26281738e-01],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  9.49401855e-02,   9.49401855e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.54003906e-02,   3.53698730e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  3.28063965e-02,   3.27758789e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -1.54418945e-02,  -1.54113770e-02],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -2.46887207e-02,  -2.46582031e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.04980469e-02,  -1.05285645e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -5.70678711e-03,  -5.73730469e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  1.72119141e-02,   1.71813965e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  3.37829590e-02,   3.37829590e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  8.29162598e-02,   8.29162598e-02],
                        [  1.06628418e-01,   1.06628418e-01],
                        [  1.18835449e-01,   1.18835449e-01],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -1.32171631e-01,  -1.32171631e-01],
                        [ -2.22808838e-01,  -2.22808838e-01],
                        [ -2.77496338e-01,  -2.77496338e-01],
                        [ -2.78991699e-01,  -2.78991699e-01],
                        [ -2.34466553e-01,  -2.34466553e-01],
                        [ -1.75567627e-01,  -1.75567627e-01],
                        [ -1.33422852e-01,  -1.33422852e-01],
                        [ -1.11877441e-01,  -1.11846924e-01],
                        [ -9.32312012e-02,  -9.32312012e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  9.60388184e-02,   9.60388184e-02],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  8.02307129e-02,   8.02307129e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  3.84826660e-02,   3.85131836e-02],
                        [  3.39660645e-02,   3.39355469e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  3.80859375e-02,   3.81164551e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  7.71484375e-02,   7.71484375e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  1.02111816e-01,   1.02111816e-01],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  9.56420898e-02,   9.56420898e-02],
                        [  8.07189941e-02,   8.07189941e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  4.54711914e-02,   4.54406738e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  3.75671387e-02,   3.75976562e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  3.97338867e-02,   3.97644043e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  3.41491699e-02,   3.41796875e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -6.74438477e-03,  -6.77490234e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -2.99377441e-02,  -2.99072266e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.53906250e-02,  -2.54211426e-02],
                        [ -2.93579102e-02,  -2.93273926e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -4.04663086e-02,  -4.04968262e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -3.39660645e-02,  -3.39355469e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.10974121e-02,  -3.11279297e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  2.10266113e-02,   2.09960938e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.18988037e-01,   1.18988037e-01],
                        [  1.29882812e-01,   1.29882812e-01],
                        [  1.21185303e-01,   1.21154785e-01],
                        [  8.99658203e-02,   8.99963379e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -2.21405029e-01,  -2.21374512e-01],
                        [ -2.81829834e-01,  -2.81860352e-01],
                        [ -2.83477783e-01,  -2.83477783e-01],
                        [ -2.30316162e-01,  -2.30316162e-01],
                        [ -1.58477783e-01,  -1.58477783e-01],
                        [ -1.04797363e-01,  -1.04797363e-01],
                        [ -7.99255371e-02,  -7.98950195e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -4.67529297e-02,  -4.67834473e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -7.83996582e-02,  -7.83996582e-02],
                        [ -9.45129395e-02,  -9.44824219e-02],
                        [ -9.80224609e-02,  -9.80224609e-02],
                        [ -8.12072754e-02,  -8.12072754e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  7.67517090e-02,   7.67211914e-02],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  1.02966309e-01,   1.02966309e-01],
                        [  8.42285156e-02,   8.41979980e-02],
                        [  6.96411133e-02,   6.96411133e-02],
                        [  6.32934570e-02,   6.33239746e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.26800537e-01,   1.26800537e-01],
                        [  1.22375488e-01,   1.22344971e-01],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  3.19824219e-02,   3.19519043e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -4.25109863e-02,  -4.24804688e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -4.00390625e-02,  -4.00695801e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -3.31420898e-02,  -3.31726074e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.80957031e-02,   4.80957031e-02],
                        [  6.95800781e-02,   6.95800781e-02],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  1.28936768e-01,   1.28906250e-01],
                        [  1.26434326e-01,   1.26434326e-01],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -1.36596680e-01,  -1.36596680e-01],
                        [ -2.13531494e-01,  -2.13531494e-01],
                        [ -2.56469727e-01,  -2.56469727e-01],
                        [ -2.52716064e-01,  -2.52716064e-01],
                        [ -2.07458496e-01,  -2.07427979e-01],
                        [ -1.47583008e-01,  -1.47583008e-01],
                        [ -1.03729248e-01,  -1.03759766e-01],
                        [ -8.48693848e-02,  -8.48693848e-02],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -4.07409668e-02,  -4.07714844e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -1.10473633e-01,  -1.10443115e-01],
                        [ -1.40777588e-01,  -1.40747070e-01],
                        [ -1.47094727e-01,  -1.47094727e-01],
                        [ -1.23199463e-01,  -1.23199463e-01],
                        [ -7.13195801e-02,  -7.12890625e-02],
                        [ -2.13623047e-03,  -2.16674805e-03],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  1.06445312e-01,   1.06445312e-01],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  1.06201172e-01,   1.06170654e-01],
                        [  9.34753418e-02,   9.34448242e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  5.25817871e-02,   5.25817871e-02],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  6.28967285e-02,   6.29272461e-02],
                        [  6.20117188e-02,   6.20117188e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  7.58666992e-02,   7.58666992e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  8.85314941e-02,   8.85620117e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  5.32531738e-02,   5.32531738e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  5.02929688e-02,   5.02624512e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  3.87573242e-02,   3.87268066e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  2.40783691e-02,   2.40478516e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  6.59179688e-03,   6.62231445e-03],
                        [  9.55200195e-03,   9.58251953e-03],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  2.27355957e-02,   2.27050781e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.85852051e-02,  -1.86157227e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -4.18090820e-02,  -4.17785645e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -4.72412109e-02,  -4.72717285e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -3.06091309e-02,  -3.05786133e-02],
                        [ -3.10058594e-02,  -3.10363770e-02],
                        [ -3.18603516e-02,  -3.18908691e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -1.62963867e-02,  -1.63269043e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -5.49316406e-04,  -5.18798828e-04],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  8.23974609e-04,   8.23974609e-04],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  3.57666016e-02,   3.57971191e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  6.13098145e-02,   6.13098145e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.16668701e-01,  -1.16668701e-01],
                        [ -2.05413818e-01,  -2.05413818e-01],
                        [ -2.63275146e-01,  -2.63275146e-01],
                        [ -2.73620605e-01,  -2.73620605e-01],
                        [ -2.36907959e-01,  -2.36907959e-01],
                        [ -1.75964355e-01,  -1.75964355e-01],
                        [ -1.21154785e-01,  -1.21154785e-01],
                        [ -8.56933594e-02,  -8.56933594e-02],
                        [ -6.21643066e-02,  -6.21337891e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -1.05621338e-01,  -1.05651855e-01],
                        [ -1.47430420e-01,  -1.47430420e-01],
                        [ -1.73645020e-01,  -1.73645020e-01],
                        [ -1.70196533e-01,  -1.70196533e-01],
                        [ -1.31439209e-01,  -1.31439209e-01],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  1.38397217e-01,   1.38397217e-01],
                        [  1.39434814e-01,   1.39434814e-01],
                        [  1.26586914e-01,   1.26586914e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  6.97631836e-02,   6.97631836e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  4.69665527e-02,   4.69665527e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  1.17523193e-01,   1.17523193e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.18438721e-01,   1.18438721e-01],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  6.54296875e-02,   6.54602051e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -4.40063477e-02,  -4.40368652e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  7.14111328e-02,   7.14111328e-02],
                        [  8.63037109e-02,   8.63037109e-02],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  1.33575439e-01,   1.33575439e-01],
                        [  1.35009766e-01,   1.35009766e-01],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  6.29577637e-02,   6.29577637e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -2.06542969e-01,  -2.06542969e-01],
                        [ -2.71514893e-01,  -2.71514893e-01],
                        [ -2.82562256e-01,  -2.82562256e-01],
                        [ -2.41455078e-01,  -2.41455078e-01],
                        [ -1.77368164e-01,  -1.77368164e-01],
                        [ -1.23199463e-01,  -1.23199463e-01],
                        [ -9.00878906e-02,  -9.00878906e-02],
                        [ -6.86950684e-02,  -6.86950684e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -1.12976074e-01,  -1.12976074e-01],
                        [ -1.65069580e-01,  -1.65069580e-01],
                        [ -1.98425293e-01,  -1.98425293e-01],
                        [ -1.99523926e-01,  -1.99523926e-01],
                        [ -1.70379639e-01,  -1.70379639e-01],
                        [ -1.21154785e-01,  -1.21154785e-01],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  9.98535156e-02,   9.98535156e-02],
                        [  1.31988525e-01,   1.31988525e-01],
                        [  1.42547607e-01,   1.42547607e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  7.54089355e-02,   7.53784180e-02],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  7.37609863e-02,   7.37609863e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  8.20617676e-02,   8.20617676e-02],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  1.13739014e-01,   1.13739014e-01],
                        [  1.31835938e-01,   1.31835938e-01],
                        [  1.38153076e-01,   1.38153076e-01],
                        [  1.30950928e-01,   1.30950928e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  1.00616455e-01,   1.00616455e-01],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  6.19812012e-02,   6.19812012e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -4.69970703e-03,  -4.73022461e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.60620117e-02,  -2.60925293e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  3.87573242e-03,   3.90625000e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  8.25195312e-02,   8.25195312e-02],
                        [  9.66186523e-02,   9.66186523e-02],
                        [  1.17492676e-01,   1.17492676e-01],
                        [  1.39678955e-01,   1.39678955e-01],
                        [  1.49139404e-01,   1.49139404e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -1.94976807e-01,  -1.94976807e-01],
                        [ -2.66601562e-01,  -2.66601562e-01],
                        [ -2.81097412e-01,  -2.81097412e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -1.68823242e-01,  -1.68823242e-01],
                        [ -1.02630615e-01,  -1.02630615e-01],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -1.51245117e-01,  -1.51245117e-01],
                        [ -1.98364258e-01,  -1.98364258e-01],
                        [ -2.20489502e-01,  -2.20489502e-01],
                        [ -2.06390381e-01,  -2.06390381e-01],
                        [ -1.62384033e-01,  -1.62384033e-01],
                        [ -1.09313965e-01,  -1.09313965e-01],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  6.05163574e-02,   6.05163574e-02],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.38092041e-01,   1.38092041e-01],
                        [  1.22283936e-01,   1.22283936e-01],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  8.73413086e-02,   8.73413086e-02],
                        [  8.44726562e-02,   8.44726562e-02],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  8.58154297e-02,   8.58154297e-02],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  1.24694824e-01,   1.24694824e-01],
                        [  1.43646240e-01,   1.43646240e-01],
                        [  1.50878906e-01,   1.50909424e-01],
                        [  1.44042969e-01,   1.44042969e-01],
                        [  1.26892090e-01,   1.26892090e-01],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  8.33435059e-02,   8.33435059e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  7.00378418e-02,   7.00378418e-02],
                        [  6.34765625e-02,   6.34765625e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  2.07519531e-03,   2.07519531e-03],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  1.02600098e-01,   1.02600098e-01],
                        [  1.27441406e-01,   1.27441406e-01],
                        [  1.47277832e-01,   1.47277832e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.29516602e-01,   1.29516602e-01],
                        [  8.59069824e-02,   8.59069824e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -1.81488037e-01,  -1.81488037e-01],
                        [ -2.52593994e-01,  -2.52593994e-01],
                        [ -2.69042969e-01,  -2.69042969e-01],
                        [ -2.31201172e-01,  -2.31201172e-01],
                        [ -1.64306641e-01,  -1.64306641e-01],
                        [ -1.00799561e-01,  -1.00799561e-01],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -9.86938477e-02,  -9.86938477e-02],
                        [ -1.52099609e-01,  -1.52099609e-01],
                        [ -1.97967529e-01,  -1.97967529e-01],
                        [ -2.17041016e-01,  -2.17041016e-01],
                        [ -2.04315186e-01,  -2.04315186e-01],
                        [ -1.69677734e-01,  -1.69677734e-01],
                        [ -1.29241943e-01,  -1.29241943e-01],
                        [ -9.26208496e-02,  -9.26208496e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  1.47949219e-01,   1.47949219e-01],
                        [  1.62353516e-01,   1.62353516e-01],
                        [  1.49780273e-01,   1.49780273e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  1.01318359e-01,   1.01318359e-01],
                        [  1.19812012e-01,   1.19812012e-01],
                        [  1.38244629e-01,   1.38244629e-01],
                        [  1.48040771e-01,   1.48040771e-01],
                        [  1.45263672e-01,   1.45263672e-01],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  9.06372070e-02,   9.06372070e-02],
                        [  8.19396973e-02,   8.19396973e-02],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  7.39440918e-02,   7.39440918e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  7.64465332e-02,   7.64465332e-02],
                        [  1.03240967e-01,   1.03240967e-01],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.49444580e-01,   1.49444580e-01],
                        [  1.49566650e-01,   1.49566650e-01],
                        [  1.23077393e-01,   1.23077393e-01],
                        [  6.99157715e-02,   6.99157715e-02],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -9.78393555e-02,  -9.78393555e-02],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -2.47955322e-01,  -2.47955322e-01],
                        [ -2.55828857e-01,  -2.55828857e-01],
                        [ -2.11853027e-01,  -2.11853027e-01],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -7.11364746e-02,  -7.11364746e-02],
                        [ -9.07897949e-02,  -9.07897949e-02],
                        [ -1.17156982e-01,  -1.17156982e-01],
                        [ -1.47125244e-01,  -1.47125244e-01],
                        [ -1.74255371e-01,  -1.74255371e-01],
                        [ -1.87744141e-01,  -1.87744141e-01],
                        [ -1.81732178e-01,  -1.81732178e-01],
                        [ -1.61621094e-01,  -1.61621094e-01],
                        [ -1.37817383e-01,  -1.37817383e-01],
                        [ -1.14654541e-01,  -1.14654541e-01],
                        [ -8.88061523e-02,  -8.88061523e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [  3.64379883e-02,   3.64074707e-02],
                        [  8.66088867e-02,   8.66088867e-02],
                        [  1.26007080e-01,   1.25976562e-01],
                        [  1.45782471e-01,   1.45782471e-01],
                        [  1.44836426e-01,   1.44836426e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.09924316e-01,   1.09924316e-01],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  9.53979492e-02,   9.53979492e-02],
                        [  1.01226807e-01,   1.01196289e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  1.25671387e-01,   1.25671387e-01],
                        [  1.38427734e-01,   1.38427734e-01],
                        [  1.41021729e-01,   1.41021729e-01],
                        [  1.30859375e-01,   1.30859375e-01],
                        [  1.12762451e-01,   1.12731934e-01],
                        [  9.31396484e-02,   9.31396484e-02],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  5.55114746e-02,   5.55114746e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  2.38647461e-02,   2.38342285e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  1.22680664e-02,   1.22375488e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -1.06201172e-02,  -1.06506348e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -5.92041016e-03,  -5.95092773e-03],
                        [ -7.93457031e-03,  -7.96508789e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.63964844e-02,  -5.63964844e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.75476074e-02,  -1.75781250e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  7.34863281e-02,   7.34558105e-02],
                        [  1.00891113e-01,   1.00860596e-01],
                        [  1.35772705e-01,   1.35772705e-01],
                        [  1.60583496e-01,   1.60583496e-01],
                        [  1.58691406e-01,   1.58660889e-01],
                        [  1.27105713e-01,   1.27105713e-01],
                        [  7.05566406e-02,   7.05566406e-02],
                        [ -7.78198242e-03,  -7.81250000e-03],
                        [ -1.01684570e-01,  -1.01715088e-01],
                        [ -1.91894531e-01,  -1.91894531e-01],
                        [ -2.48260498e-01,  -2.48291016e-01],
                        [ -2.47741699e-01,  -2.47772217e-01],
                        [ -1.94335938e-01,  -1.94335938e-01],
                        [ -1.21765137e-01,  -1.21765137e-01],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -8.93859863e-02,  -8.93859863e-02],
                        [ -1.29943848e-01,  -1.29974365e-01],
                        [ -1.67816162e-01,  -1.67846680e-01],
                        [ -1.91192627e-01,  -1.91192627e-01],
                        [ -1.91986084e-01,  -1.91986084e-01],
                        [ -1.70593262e-01,  -1.70593262e-01],
                        [ -1.39099121e-01,  -1.39099121e-01],
                        [ -1.13311768e-01,  -1.13311768e-01],
                        [ -1.00311279e-01,  -1.00311279e-01],
                        [ -9.46960449e-02,  -9.47265625e-02],
                        [ -8.56018066e-02,  -8.56323242e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -3.13415527e-02,  -3.13720703e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  1.46820068e-01,   1.46789551e-01],
                        [  1.54388428e-01,   1.54388428e-01],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  9.26513672e-02,   9.26208496e-02],
                        [  9.25292969e-02,   9.24987793e-02],
                        [  1.02020264e-01,   1.02020264e-01],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  1.43066406e-01,   1.43035889e-01],
                        [  1.58020020e-01,   1.58020020e-01],
                        [  1.61682129e-01,   1.61682129e-01],
                        [  1.52404785e-01,   1.52374268e-01],
                        [  1.30401611e-01,   1.30401611e-01],
                        [  1.02508545e-01,   1.02478027e-01],
                        [  7.96813965e-02,   7.96508789e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  6.03332520e-02,   6.03027344e-02],
                        [  5.54504395e-02,   5.54199219e-02],
                        [  5.24291992e-02,   5.23986816e-02],
                        [  5.26733398e-02,   5.26428223e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  5.36499023e-02,   5.36193848e-02],
                        [  4.67224121e-02,   4.66918945e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  1.80969238e-02,   1.80664062e-02],
                        [  7.53784180e-03,   7.50732422e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  5.92041016e-03,   5.88989258e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  2.62451172e-02,   2.62145996e-02],
                        [  2.64282227e-02,   2.63977051e-02],
                        [  2.31323242e-02,   2.31018066e-02],
                        [  1.78527832e-02,   1.78222656e-02],
                        [  1.26342773e-02,   1.26037598e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  5.09643555e-03,   5.06591797e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -1.80053711e-03,  -1.83105469e-03],
                        [ -5.49316406e-04,  -5.79833984e-04],
                        [  2.34985352e-03,   2.31933594e-03],
                        [  1.49536133e-03,   1.46484375e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -9.94873047e-03,  -9.97924805e-03],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.66113281e-02,  -2.66418457e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -3.47900391e-02,  -3.48205566e-02],
                        [ -3.97644043e-02,  -3.97949219e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -5.59997559e-02,  -5.60302734e-02],
                        [ -6.26525879e-02,  -6.26831055e-02],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -6.32019043e-02,  -6.32324219e-02],
                        [ -6.29882812e-02,  -6.30187988e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -4.96520996e-02,  -4.96826172e-02],
                        [ -3.82995605e-02,  -3.83300781e-02],
                        [ -2.94189453e-02,  -2.94494629e-02],
                        [ -2.87780762e-02,  -2.88085938e-02],
                        [ -3.53393555e-02,  -3.53698730e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.99169922e-02,  -3.99475098e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -2.63366699e-02,  -2.63671875e-02],
                        [ -2.11486816e-02,  -2.11791992e-02],
                        [ -1.62658691e-02,  -1.62963867e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.48925781e-02,  -1.49230957e-02],
                        [ -1.60827637e-02,  -1.61132812e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  1.22375488e-02,   1.22070312e-02],
                        [  1.92871094e-02,   1.92565918e-02],
                        [  2.95715332e-02,   2.95410156e-02],
                        [  4.31213379e-02,   4.30908203e-02],
                        [  5.33752441e-02,   5.33447266e-02],
                        [  6.03637695e-02,   6.03332520e-02],
                        [  7.28454590e-02,   7.28149414e-02],
                        [  9.57336426e-02,   9.57031250e-02],
                        [  1.23809814e-01,   1.23779297e-01],
                        [  1.46545410e-01,   1.46514893e-01],
                        [  1.52343750e-01,   1.52343750e-01],
                        [  1.31072998e-01,   1.31042480e-01],
                        [  7.95288086e-02,   7.94982910e-02],
                        [  3.47900391e-03,   3.44848633e-03],
                        [ -8.59375000e-02,  -8.59680176e-02],
                        [ -1.71691895e-01,  -1.71722412e-01],
                        [ -2.29278564e-01,  -2.29309082e-01],
                        [ -2.37213135e-01,  -2.37243652e-01],
                        [ -1.96014404e-01,  -1.96044922e-01],
                        [ -1.34582520e-01,  -1.34613037e-01],
                        [ -9.25292969e-02,  -9.25598145e-02],
                        [ -9.06982422e-02,  -9.06982422e-02],
                        [ -1.18652344e-01,  -1.18682861e-01],
                        [ -1.51977539e-01,  -1.52008057e-01],
                        [ -1.75476074e-01,  -1.75476074e-01],
                        [ -1.85363770e-01,  -1.85394287e-01],
                        [ -1.81030273e-01,  -1.81060791e-01],
                        [ -1.64764404e-01,  -1.64764404e-01],
                        [ -1.43524170e-01,  -1.43554688e-01],
                        [ -1.23748779e-01,  -1.23779297e-01],
                        [ -1.06781006e-01,  -1.06811523e-01],
                        [ -9.18273926e-02,  -9.18579102e-02],
                        [ -7.79724121e-02,  -7.80029297e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -4.16564941e-02,  -4.16870117e-02],
                        [ -8.30078125e-03,  -8.33129883e-03],
                        [  3.97644043e-02,   3.97338867e-02],
                        [  9.50927734e-02,   9.50622559e-02],
                        [  1.39892578e-01,   1.39892578e-01],
                        [  1.58172607e-01,   1.58142090e-01],
                        [  1.49841309e-01,   1.49810791e-01],
                        [  1.30493164e-01,   1.30493164e-01],
                        [  1.16485596e-01,   1.16455078e-01],
                        [  1.12976074e-01,   1.12945557e-01],
                        [  1.16088867e-01,   1.16058350e-01],
                        [  1.22070312e-01,   1.22039795e-01],
                        [  1.31317139e-01,   1.31286621e-01],
                        [  1.44653320e-01,   1.44622803e-01],
                        [  1.57836914e-01,   1.57806396e-01],
                        [  1.63574219e-01,   1.63543701e-01],
                        [  1.58935547e-01,   1.58905029e-01],
                        [  1.46575928e-01,   1.46545410e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.07482910e-01,   1.07452393e-01],
                        [  8.46557617e-02,   8.46252441e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  5.28564453e-02,   5.28259277e-02],
                        [  4.60510254e-02,   4.60205078e-02],
                        [  4.41894531e-02,   4.41589355e-02],
                        [  4.55322266e-02,   4.55017090e-02],
                        [  4.70886230e-02,   4.70581055e-02],
                        [  4.62951660e-02,   4.62646484e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  3.37219238e-02,   3.36914062e-02],
                        [  2.33154297e-02,   2.32849121e-02],
                        [  1.50756836e-02,   1.50451660e-02],
                        [  1.23901367e-02,   1.23596191e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  8.85009766e-03,   8.81958008e-03],
                        [  2.59399414e-03,   2.56347656e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  6.98852539e-03,   6.95800781e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.18713379e-02,   1.18408203e-02],
                        [  1.40075684e-02,   1.39770508e-02],
                        [  1.95922852e-02,   1.95617676e-02],
                        [  2.56958008e-02,   2.56652832e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.46679688e-02,   3.46374512e-02],
                        [  2.91137695e-02,   2.90832520e-02],
                        [  1.51062012e-02,   1.50756836e-02],
                        [  2.92968750e-03,   2.86865234e-03],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  4.27246094e-04,   3.96728516e-04],
                        [ -2.65502930e-03,  -2.68554688e-03],
                        [ -8.27026367e-03,  -8.30078125e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -1.93481445e-02,  -1.93786621e-02],
                        [ -2.70690918e-02,  -2.70996094e-02],
                        [ -3.23181152e-02,  -3.23486328e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.67224121e-02,  -4.67529297e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -5.67016602e-02,  -5.67321777e-02],
                        [ -6.25305176e-02,  -6.25610352e-02],
                        [ -6.80236816e-02,  -6.80541992e-02],
                        [ -6.77795410e-02,  -6.78100586e-02],
                        [ -6.06689453e-02,  -6.06994629e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.26330566e-02,  -4.26635742e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.81469727e-02,  -3.81774902e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.15246582e-02,  -3.15551758e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.63464355e-02,  -3.63769531e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -2.81066895e-02,  -2.81372070e-02],
                        [ -2.24914551e-02,  -2.25219727e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.68762207e-02,  -1.69067383e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -2.74658203e-03,  -2.77709961e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  6.71386719e-03,   6.68334961e-03],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  3.05480957e-02,   3.05175781e-02],
                        [  3.89709473e-02,   3.89404297e-02],
                        [  4.64477539e-02,   4.64172363e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  8.57543945e-02,   8.57238770e-02],
                        [  1.14624023e-01,   1.14593506e-01],
                        [  1.41326904e-01,   1.41296387e-01],
                        [  1.59423828e-01,   1.59423828e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.33666992e-01,   1.33636475e-01],
                        [  7.74230957e-02,   7.74230957e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -9.39025879e-02,  -9.39331055e-02],
                        [ -1.75811768e-01,  -1.75842285e-01],
                        [ -2.24945068e-01,  -2.24945068e-01],
                        [ -2.24395752e-01,  -2.24395752e-01],
                        [ -1.81427002e-01,  -1.81427002e-01],
                        [ -1.29791260e-01,  -1.29791260e-01],
                        [ -1.05438232e-01,  -1.05438232e-01],
                        [ -1.19110107e-01,  -1.19140625e-01],
                        [ -1.54815674e-01,  -1.54846191e-01],
                        [ -1.88537598e-01,  -1.88537598e-01],
                        [ -2.03399658e-01,  -2.03399658e-01],
                        [ -1.94793701e-01,  -1.94793701e-01],
                        [ -1.68792725e-01,  -1.68792725e-01],
                        [ -1.36962891e-01,  -1.36962891e-01],
                        [ -1.10076904e-01,  -1.10107422e-01],
                        [ -9.42687988e-02,  -9.42687988e-02],
                        [ -8.91113281e-02,  -8.91113281e-02],
                        [ -8.80737305e-02,  -8.81042480e-02],
                        [ -8.35266113e-02,  -8.35571289e-02],
                        [ -7.18078613e-02,  -7.18078613e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  1.38427734e-01,   1.38397217e-01],
                        [  1.68609619e-01,   1.68609619e-01],
                        [  1.72119141e-01,   1.72149658e-01],
                        [  1.57257080e-01,   1.57226562e-01],
                        [  1.38031006e-01,   1.38000488e-01],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  1.29455566e-01,   1.29425049e-01],
                        [  1.45416260e-01,   1.45416260e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.73400879e-01,   1.73400879e-01],
                        [  1.73858643e-01,   1.73858643e-01],
                        [  1.61041260e-01,   1.61071777e-01],
                        [  1.38885498e-01,   1.38854980e-01],
                        [  1.16790771e-01,   1.16790771e-01],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  4.26025391e-02,   4.26330566e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  2.80456543e-02,   2.80761719e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.47290039e-02,   3.47595215e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.06811523e-03,   1.09863281e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -2.44140625e-03,  -2.41088867e-03],
                        [ -7.90405273e-03,  -7.87353516e-03],
                        [ -8.14819336e-03,  -8.11767578e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  1.46484375e-03,   1.49536133e-03],
                        [ -2.96020508e-03,  -2.92968750e-03],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.64990234e-02,  -3.64685059e-02],
                        [ -4.24499512e-02,  -4.24194336e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -6.76879883e-02,  -6.76574707e-02],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -5.65490723e-02,  -5.65490723e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -4.01000977e-02,  -4.00695801e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.88586426e-02,  -4.88281250e-02],
                        [ -5.74951172e-02,  -5.74645996e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.36193848e-02,  -5.35888672e-02],
                        [ -4.88281250e-02,  -4.87976074e-02],
                        [ -3.96423340e-02,  -3.96118164e-02],
                        [ -2.42919922e-02,  -2.42614746e-02],
                        [ -1.24511719e-02,  -1.24206543e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.51672363e-02,  -1.51367188e-02],
                        [ -1.83715820e-02,  -1.83410645e-02],
                        [ -2.05383301e-02,  -2.05078125e-02],
                        [ -2.16979980e-02,  -2.16674805e-02],
                        [ -1.87377930e-02,  -1.86767578e-02],
                        [ -1.05895996e-02,  -1.05590820e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  5.40161133e-03,   5.43212891e-03],
                        [  9.70458984e-03,   9.73510742e-03],
                        [  1.81884766e-02,   1.82189941e-02],
                        [  3.49121094e-02,   3.49426270e-02],
                        [  5.61828613e-02,   5.62133789e-02],
                        [  7.57446289e-02,   7.57751465e-02],
                        [  9.35668945e-02,   9.35974121e-02],
                        [  1.14013672e-01,   1.14013672e-01],
                        [  1.36230469e-01,   1.36291504e-01],
                        [  1.51580811e-01,   1.51641846e-01],
                        [  1.50024414e-01,   1.50024414e-01],
                        [  1.24542236e-01,   1.24572754e-01],
                        [  7.13195801e-02,   7.13806152e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -9.38415527e-02,  -9.38415527e-02],
                        [ -1.70806885e-01,  -1.70776367e-01],
                        [ -2.17376709e-01,  -2.17315674e-01],
                        [ -2.20764160e-01,  -2.20764160e-01],
                        [ -1.88354492e-01,  -1.88293457e-01],
                        [ -1.52587891e-01,  -1.52526855e-01],
                        [ -1.47613525e-01,  -1.47613525e-01],
                        [ -1.77764893e-01,  -1.77764893e-01],
                        [ -2.16705322e-01,  -2.16644287e-01],
                        [ -2.34710693e-01,  -2.34680176e-01],
                        [ -2.22076416e-01,  -2.22076416e-01],
                        [ -1.90277100e-01,  -1.90216064e-01],
                        [ -1.57409668e-01,  -1.57379150e-01],
                        [ -1.33392334e-01,  -1.33392334e-01],
                        [ -1.15600586e-01,  -1.15539551e-01],
                        [ -9.54895020e-02,  -9.54284668e-02],
                        [ -7.04650879e-02,  -7.04345703e-02],
                        [ -4.97131348e-02,  -4.96826172e-02],
                        [ -4.36096191e-02,  -4.35791016e-02],
                        [ -4.74853516e-02,  -4.74243164e-02],
                        [ -4.40368652e-02,  -4.40063477e-02],
                        [ -2.13317871e-02,  -2.13012695e-02],
                        [  1.99890137e-02,   2.00195312e-02],
                        [  7.20214844e-02,   7.20825195e-02],
                        [  1.22985840e-01,   1.23046875e-01],
                        [  1.58416748e-01,   1.58447266e-01],
                        [  1.68609619e-01,   1.68670654e-01],
                        [  1.55883789e-01,   1.55944824e-01],
                        [  1.32751465e-01,   1.32781982e-01],
                        [  1.13830566e-01,   1.13861084e-01],
                        [  1.08886719e-01,   1.08947754e-01],
                        [  1.19995117e-01,   1.20025635e-01],
                        [  1.42242432e-01,   1.42272949e-01],
                        [  1.66229248e-01,   1.66290283e-01],
                        [  1.82769775e-01,   1.82830811e-01],
                        [  1.87286377e-01,   1.87316895e-01],
                        [  1.79199219e-01,   1.79229736e-01],
                        [  1.59179688e-01,   1.59240723e-01],
                        [  1.29638672e-01,   1.29699707e-01],
                        [  9.67102051e-02,   9.67407227e-02],
                        [  6.81762695e-02,   6.82373047e-02],
                        [  5.07202148e-02,   5.07812500e-02],
                        [  4.67529297e-02,   4.67834473e-02],
                        [  5.00183105e-02,   5.00488281e-02],
                        [  4.85534668e-02,   4.86145020e-02],
                        [  3.80249023e-02,   3.80859375e-02],
                        [  2.65197754e-02,   2.65502930e-02],
                        [  2.19726562e-02,   2.20336914e-02],
                        [  2.27661133e-02,   2.27966309e-02],
                        [  2.41394043e-02,   2.41699219e-02],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  2.29797363e-02,   2.30407715e-02],
                        [  1.78527832e-02,   1.78833008e-02],
                        [  1.07116699e-02,   1.07421875e-02],
                        [  4.69970703e-03,   4.73022461e-03],
                        [  1.03759766e-03,   1.09863281e-03],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [ -1.55639648e-03,  -1.52587891e-03],
                        [ -1.61743164e-03,  -1.55639648e-03],
                        [  9.15527344e-04,   9.76562500e-04],
                        [  8.69750977e-03,   8.72802734e-03],
                        [  2.05383301e-02,   2.05688477e-02],
                        [  3.04260254e-02,   3.04870605e-02],
                        [  3.33557129e-02,   3.33862305e-02],
                        [  2.84118652e-02,   2.84729004e-02],
                        [  1.76086426e-02,   1.76696777e-02],
                        [  4.69970703e-03,   4.73022461e-03],
                        [ -5.49316406e-03,  -5.46264648e-03],
                        [ -1.03149414e-02,  -1.02539062e-02],
                        [ -1.03454590e-02,  -1.02844238e-02],
                        [ -7.75146484e-03,  -7.72094727e-03],
                        [ -6.43920898e-03,  -6.40869141e-03],
                        [ -1.06811523e-02,  -1.06201172e-02],
                        [ -1.91345215e-02,  -1.90734863e-02],
                        [ -2.55432129e-02,  -2.54821777e-02],
                        [ -2.83508301e-02,  -2.82897949e-02],
                        [ -3.20739746e-02,  -3.20434570e-02],
                        [ -3.86962891e-02,  -3.86352539e-02],
                        [ -4.67529297e-02,  -4.66918945e-02],
                        [ -5.62438965e-02,  -5.61828613e-02],
                        [ -6.51550293e-02,  -6.51245117e-02],
                        [ -6.76574707e-02,  -6.75964355e-02],
                        [ -6.34765625e-02,  -6.34155273e-02],
                        [ -6.06689453e-02,  -6.06384277e-02],
                        [ -6.27746582e-02,  -6.27136230e-02],
                        [ -6.38122559e-02,  -6.37817383e-02],
                        [ -6.07299805e-02,  -6.06689453e-02],
                        [ -5.81359863e-02,  -5.80749512e-02],
                        [ -5.81970215e-02,  -5.81665039e-02],
                        [ -5.77392578e-02,  -5.76782227e-02],
                        [ -5.64880371e-02,  -5.64270020e-02],
                        [ -5.75866699e-02,  -5.75256348e-02],
                        [ -5.95703125e-02,  -5.95092773e-02],
                        [ -5.74951172e-02,  -5.74340820e-02],
                        [ -5.06286621e-02,  -5.05676270e-02],
                        [ -4.20837402e-02,  -4.20227051e-02],
                        [ -3.40881348e-02,  -3.40576172e-02],
                        [ -2.77404785e-02,  -2.76794434e-02],
                        [ -2.29187012e-02,  -2.28881836e-02],
                        [ -1.78527832e-02,  -1.78222656e-02],
                        [ -1.23291016e-02,  -1.22680664e-02],
                        [ -9.03320312e-03,  -8.97216797e-03],
                        [ -7.81250000e-03,  -7.78198242e-03],
                        [ -4.27246094e-03,  -4.21142578e-03],
                        [  3.05175781e-03,   3.14331055e-03],
                        [  1.06506348e-02,   1.07116699e-02],
                        [  1.67846680e-02,   1.68457031e-02],
                        [  2.29492188e-02,   2.30102539e-02],
                        [  2.92663574e-02,   2.93273926e-02],
                        [  3.55224609e-02,   3.55529785e-02],
                        [  4.36096191e-02,   4.36706543e-02],
                        [  5.56945801e-02,   5.57556152e-02],
                        [  7.28454590e-02,   7.28759766e-02],
                        [  9.62829590e-02,   9.63439941e-02],
                        [  1.24053955e-01,   1.24114990e-01],
                        [  1.47155762e-01,   1.47186279e-01],
                        [  1.54357910e-01,   1.54388428e-01],
                        [  1.39129639e-01,   1.39190674e-01],
                        [  1.00616455e-01,   1.00677490e-01],
                        [  4.05883789e-02,   4.06188965e-02],
                        [ -3.74450684e-02,  -3.73840332e-02],
                        [ -1.23016357e-01,  -1.22955322e-01],
                        [ -1.94427490e-01,  -1.94366455e-01],
                        [ -2.30163574e-01,  -2.30102539e-01],
                        [ -2.30865479e-01,  -2.30804443e-01],
                        [ -2.21099854e-01,  -2.21038818e-01],
                        [ -2.23083496e-01,  -2.23052979e-01],
                        [ -2.34863281e-01,  -2.34802246e-01],
                        [ -2.37426758e-01,  -2.37365723e-01],
                        [ -2.18200684e-01,  -2.18139648e-01],
                        [ -1.82952881e-01,  -1.82891846e-01],
                        [ -1.48620605e-01,  -1.48559570e-01],
                        [ -1.28021240e-01,  -1.27960205e-01],
                        [ -1.21246338e-01,  -1.21185303e-01],
                        [ -1.16668701e-01,  -1.16607666e-01],
                        [ -1.01318359e-01,  -1.01287842e-01],
                        [ -7.44628906e-02,  -7.44018555e-02],
                        [ -4.87365723e-02,  -4.86755371e-02],
                        [ -3.43627930e-02,  -3.43322754e-02],
                        [ -2.84729004e-02,  -2.84118652e-02],
                        [ -2.27355957e-02,  -2.26745605e-02],
                        [ -1.24206543e-02,  -1.23901367e-02],
                        [  6.43920898e-03,   6.50024414e-03],
                        [  3.87268066e-02,   3.87878418e-02],
                        [  8.21533203e-02,   8.22143555e-02],
                        [  1.23535156e-01,   1.23596191e-01],
                        [  1.47949219e-01,   1.48010254e-01],
                        [  1.51306152e-01,   1.51367188e-01],
                        [  1.42547607e-01,   1.42578125e-01],
                        [  1.36169434e-01,   1.36230469e-01],
                        [  1.43585205e-01,   1.43646240e-01],
                        [  1.66717529e-01,   1.66748047e-01],
                        [  1.95617676e-01,   1.95678711e-01],
                        [  2.14538574e-01,   2.14599609e-01],
                        [  2.14355469e-01,   2.14416504e-01],
                        [  1.97753906e-01,   1.97784424e-01],
                        [  1.72515869e-01,   1.72576904e-01],
                        [  1.44927979e-01,   1.44958496e-01],
                        [  1.18316650e-01,   1.18347168e-01],
                        [  9.36279297e-02,   9.36889648e-02],
                        [  7.13500977e-02,   7.13806152e-02],
                        [  5.43212891e-02,   5.43518066e-02],
                        [  4.64477539e-02,   4.65087891e-02],
                        [  4.75463867e-02,   4.76074219e-02],
                        [  5.19409180e-02,   5.19714355e-02],
                        [  5.25207520e-02,   5.25817871e-02],
                        [  4.55322266e-02,   4.55932617e-02],
                        [  3.21044922e-02,   3.21655273e-02],
                        [  1.70898438e-02,   1.71508789e-02],
                        [  6.31713867e-03,   6.37817383e-03],
                        [  4.15039062e-03,   4.18090820e-03],
                        [  1.06811523e-02,   1.07116699e-02],
                        [  2.05993652e-02,   2.06604004e-02],
                        [  2.67028809e-02,   2.67333984e-02],
                        [  2.53906250e-02,   2.54211426e-02],
                        [  1.85852051e-02,   1.86462402e-02],
                        [  1.10778809e-02,   1.11083984e-02],
                        [  6.59179688e-03,   6.65283203e-03],
                        [  5.00488281e-03,   5.03540039e-03],
                        [  3.81469727e-03,   3.84521484e-03],
                        [  3.99780273e-03,   4.05883789e-03],
                        [  1.02539062e-02,   1.03149414e-02],
                        [  2.22473145e-02,   2.23083496e-02],
                        [  3.03039551e-02,   3.03649902e-02],
                        [  2.60925293e-02,   2.61230469e-02],
                        [  1.35803223e-02,   1.36108398e-02],
                        [  3.47900391e-03,   3.54003906e-03],
                        [  8.54492188e-04,   8.85009766e-04],
                        [  4.48608398e-03,   4.54711914e-03],
                        [  1.22680664e-02,   1.22985840e-02],
                        [  1.93481445e-02,   1.94091797e-02],
                        [  1.76696777e-02,   1.77307129e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -1.60522461e-02,  -1.59912109e-02],
                        [ -3.22570801e-02,  -3.21960449e-02],
                        [ -4.13513184e-02,  -4.13208008e-02],
                        [ -4.59594727e-02,  -4.59289551e-02],
                        [ -4.89501953e-02,  -4.88891602e-02],
                        [ -4.96826172e-02,  -4.96520996e-02],
                        [ -4.70275879e-02,  -4.69970703e-02],
                        [ -4.36401367e-02,  -4.35791016e-02],
                        [ -4.34265137e-02,  -4.33959961e-02],
                        [ -4.69360352e-02,  -4.69055176e-02],
                        [ -5.27648926e-02,  -5.27343750e-02],
                        [ -6.03637695e-02,  -6.03027344e-02],
                        [ -6.77185059e-02,  -6.76574707e-02],
                        [ -6.99462891e-02,  -6.99157715e-02],
                        [ -6.40258789e-02,  -6.39953613e-02],
                        [ -5.29785156e-02,  -5.29479980e-02],
                        [ -4.38842773e-02,  -4.38232422e-02],
                        [ -4.24804688e-02,  -4.24499512e-02],
                        [ -4.94689941e-02,  -4.94384766e-02],
                        [ -5.96313477e-02,  -5.96008301e-02],
                        [ -6.50939941e-02,  -6.50634766e-02],
                        [ -6.21337891e-02,  -6.21032715e-02],
                        [ -5.45043945e-02,  -5.44433594e-02],
                        [ -4.70581055e-02,  -4.70275879e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -2.75573730e-02,  -2.75268555e-02],
                        [ -1.37634277e-02,  -1.37023926e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  1.83105469e-04,   2.13623047e-04],
                        [ -3.47900391e-03,  -3.44848633e-03],
                        [ -7.65991211e-03,  -7.62939453e-03],
                        [ -6.40869141e-03,  -6.37817383e-03],
                        [ -1.40380859e-03,  -1.37329102e-03],
                        [  2.19726562e-03,   2.22778320e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.19323730e-02,   1.19934082e-02],
                        [  2.49023438e-02,   2.49328613e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  6.11267090e-02,   6.11572266e-02],
                        [  8.45336914e-02,   8.45642090e-02],
                        [  1.14562988e-01,   1.14593506e-01],
                        [  1.48315430e-01,   1.48345947e-01],
                        [  1.74865723e-01,   1.74896240e-01],
                        [  1.82067871e-01,   1.82098389e-01],
                        [  1.63116455e-01,   1.63146973e-01],
                        [  1.15600586e-01,   1.15661621e-01],
                        [  4.11987305e-02,   4.12292480e-02],
                        [ -5.02929688e-02,  -5.02624512e-02],
                        [ -1.41418457e-01,  -1.41387939e-01],
                        [ -2.14355469e-01,  -2.14324951e-01],
                        [ -2.57995605e-01,  -2.57965088e-01],
                        [ -2.71911621e-01,  -2.71881104e-01],
                        [ -2.66204834e-01,  -2.66174316e-01],
                        [ -2.54852295e-01,  -2.54852295e-01],
                        [ -2.45239258e-01,  -2.45208740e-01],
                        [ -2.32482910e-01,  -2.32421875e-01],
                        [ -2.07000732e-01,  -2.07000732e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -1.35864258e-01,  -1.35833740e-01],
                        [ -1.15173340e-01,  -1.15142822e-01],
                        [ -1.00067139e-01,  -1.00067139e-01],
                        [ -7.87353516e-02,  -7.87048340e-02],
                        [ -5.59387207e-02,  -5.58776855e-02],
                        [ -4.56237793e-02,  -4.55932617e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -5.22155762e-02,  -5.21850586e-02],
                        [ -4.88891602e-02,  -4.88586426e-02],
                        [ -4.20837402e-02,  -4.20532227e-02],
                        [ -3.26843262e-02,  -3.26538086e-02],
                        [ -1.34887695e-02,  -1.34582520e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  5.78308105e-02,   5.78613281e-02],
                        [  9.44824219e-02,   9.45129395e-02],
                        [  1.26861572e-01,   1.26892090e-01],
                        [  1.52862549e-01,   1.52862549e-01],
                        [  1.67144775e-01,   1.67175293e-01],
                        [  1.70074463e-01,   1.70104980e-01],
                        [  1.71722412e-01,   1.71722412e-01],
                        [  1.80969238e-01,   1.80969238e-01],
                        [  1.94702148e-01,   1.94732666e-01],
                        [  2.02331543e-01,   2.02331543e-01],
                        [  1.97753906e-01,   1.97753906e-01],
                        [  1.83105469e-01,   1.83105469e-01],
                        [  1.62689209e-01,   1.62719727e-01],
                        [  1.39923096e-01,   1.39953613e-01],
                        [  1.18621826e-01,   1.18652344e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  8.32214355e-02,   8.32519531e-02],
                        [  6.57043457e-02,   6.57043457e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.24914551e-02,   2.25219727e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  6.56127930e-03,   6.59179688e-03],
                        [  9.97924805e-03,   1.00097656e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  3.66821289e-02,   3.67126465e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  2.36511230e-02,   2.36816406e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  8.63647461e-03,   8.66699219e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  2.53295898e-03,   2.56347656e-03],
                        [ -1.34277344e-03,  -1.31225586e-03],
                        [ -2.01416016e-03,  -1.98364258e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  1.64794922e-03,   1.67846680e-03],
                        [ -8.57543945e-03,  -8.54492188e-03],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -1.98974609e-02,  -1.98669434e-02],
                        [ -1.60827637e-02,  -1.60522461e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -4.22973633e-02,  -4.22668457e-02],
                        [ -4.32128906e-02,  -4.31823730e-02],
                        [ -4.59594727e-02,  -4.59899902e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -6.09741211e-02,  -6.09436035e-02],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.05773926e-02,  -6.06079102e-02],
                        [ -6.39953613e-02,  -6.39648438e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.68334961e-02,  -6.68640137e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -1.86157227e-02,  -1.86157227e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  1.06811523e-03,   1.03759766e-03],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.15356445e-02,   1.15051270e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  6.19201660e-02,   6.19506836e-02],
                        [  7.44628906e-02,   7.44323730e-02],
                        [  9.81750488e-02,   9.81445312e-02],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.59912109e-01,   1.59912109e-01],
                        [  1.81121826e-01,   1.81121826e-01],
                        [  1.84204102e-01,   1.84204102e-01],
                        [  1.57379150e-01,   1.57379150e-01],
                        [  9.39331055e-02,   9.39025879e-02],
                        [ -2.04467773e-03,  -2.07519531e-03],
                        [ -1.16333008e-01,  -1.16333008e-01],
                        [ -2.26196289e-01,  -2.26196289e-01],
                        [ -3.05664062e-01,  -3.05694580e-01],
                        [ -3.38806152e-01,  -3.38836670e-01],
                        [ -3.29803467e-01,  -3.29803467e-01],
                        [ -2.96722412e-01,  -2.96722412e-01],
                        [ -2.55706787e-01,  -2.55737305e-01],
                        [ -2.13043213e-01,  -2.13043213e-01],
                        [ -1.70379639e-01,  -1.70379639e-01],
                        [ -1.32751465e-01,  -1.32781982e-01],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -9.80529785e-02,  -9.80529785e-02],
                        [ -9.21630859e-02,  -9.21936035e-02],
                        [ -8.02001953e-02,  -8.02307129e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -3.63464355e-02,  -3.63769531e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  6.26220703e-02,   6.25915527e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.42639160e-01,   1.42639160e-01],
                        [  1.70135498e-01,   1.70104980e-01],
                        [  1.83319092e-01,   1.83319092e-01],
                        [  1.90216064e-01,   1.90216064e-01],
                        [  1.99249268e-01,   1.99218750e-01],
                        [  2.09716797e-01,   2.09686279e-01],
                        [  2.13195801e-01,   2.13165283e-01],
                        [  2.04315186e-01,   2.04315186e-01],
                        [  1.87988281e-01,   1.87957764e-01],
                        [  1.72119141e-01,   1.72088623e-01],
                        [  1.57714844e-01,   1.57714844e-01],
                        [  1.41174316e-01,   1.41143799e-01],
                        [  1.22070312e-01,   1.22039795e-01],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  6.14624023e-02,   6.14318848e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  2.79235840e-02,   2.78930664e-02],
                        [  1.48315430e-02,   1.48010254e-02],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -5.52368164e-03,  -5.55419922e-03],
                        [ -3.72314453e-03,  -3.75366211e-03],
                        [  4.54711914e-03,   4.51660156e-03],
                        [  1.34887695e-02,   1.34582520e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.07824707e-02,   2.07519531e-02],
                        [  1.30004883e-02,   1.29699707e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  1.11694336e-02,   1.11389160e-02],
                        [  1.84020996e-02,   1.83715820e-02],
                        [  2.35900879e-02,   2.35595703e-02],
                        [  2.60620117e-02,   2.60314941e-02],
                        [  2.92663574e-02,   2.92358398e-02],
                        [  3.35083008e-02,   3.34777832e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  3.04260254e-02,   3.03955078e-02],
                        [  2.20336914e-02,   2.20031738e-02],
                        [  1.06811523e-02,   1.06506348e-02],
                        [ -3.72314453e-03,  -3.75366211e-03],
                        [ -1.72119141e-02,  -1.72424316e-02],
                        [ -2.18505859e-02,  -2.18811035e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -5.95092773e-03,  -6.01196289e-03],
                        [ -1.06506348e-02,  -1.06811523e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -2.02636719e-02,  -2.02941895e-02],
                        [ -2.89611816e-02,  -2.89916992e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -5.14526367e-02,  -5.15136719e-02],
                        [ -5.06591797e-02,  -5.06896973e-02],
                        [ -5.02014160e-02,  -5.02319336e-02],
                        [ -4.91027832e-02,  -4.91333008e-02],
                        [ -4.73937988e-02,  -4.74243164e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -5.31921387e-02,  -5.32226562e-02],
                        [ -5.89599609e-02,  -5.89904785e-02],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [ -7.17468262e-02,  -7.17773438e-02],
                        [ -7.68127441e-02,  -7.68432617e-02],
                        [ -7.69348145e-02,  -7.69653320e-02],
                        [ -7.21130371e-02,  -7.21435547e-02],
                        [ -6.49719238e-02,  -6.50024414e-02],
                        [ -5.80444336e-02,  -5.80749512e-02],
                        [ -5.22155762e-02,  -5.22460938e-02],
                        [ -4.65698242e-02,  -4.66308594e-02],
                        [ -4.05883789e-02,  -4.06188965e-02],
                        [ -3.53088379e-02,  -3.53393555e-02],
                        [ -3.13720703e-02,  -3.14025879e-02],
                        [ -2.67944336e-02,  -2.68249512e-02],
                        [ -1.99279785e-02,  -1.99890137e-02],
                        [ -1.36108398e-02,  -1.36413574e-02],
                        [ -1.11999512e-02,  -1.12304688e-02],
                        [ -1.04675293e-02,  -1.04980469e-02],
                        [ -6.40869141e-03,  -6.43920898e-03],
                        [  1.46484375e-03,   1.43432617e-03],
                        [  9.73510742e-03,   9.70458984e-03],
                        [  1.59606934e-02,   1.59301758e-02],
                        [  1.90734863e-02,   1.90429688e-02],
                        [  1.99279785e-02,   1.98974609e-02],
                        [  2.29187012e-02,   2.28881836e-02],
                        [  3.20739746e-02,   3.20434570e-02],
                        [  4.61730957e-02,   4.61425781e-02],
                        [  6.37207031e-02,   6.36901855e-02],
                        [  8.91113281e-02,   8.90808105e-02],
                        [  1.26922607e-01,   1.26892090e-01],
                        [  1.70745850e-01,   1.70715332e-01],
                        [  2.04040527e-01,   2.04010010e-01],
                        [  2.11273193e-01,   2.11212158e-01],
                        [  1.83349609e-01,   1.83288574e-01],
                        [  1.15875244e-01,   1.15814209e-01],
                        [  9.91821289e-03,   9.88769531e-03],
                        [ -1.22772217e-01,  -1.22802734e-01],
                        [ -2.56591797e-01,  -2.56622314e-01],
                        [ -3.56445312e-01,  -3.56506348e-01],
                        [ -3.94531250e-01,  -3.94592285e-01],
                        [ -3.70269775e-01,  -3.70300293e-01],
                        [ -3.10424805e-01,  -3.10485840e-01],
                        [ -2.46856689e-01,  -2.46917725e-01],
                        [ -1.97662354e-01,  -1.97692871e-01],
                        [ -1.65557861e-01,  -1.65588379e-01],
                        [ -1.44134521e-01,  -1.44195557e-01],
                        [ -1.24816895e-01,  -1.24847412e-01],
                        [ -1.03973389e-01,  -1.04034424e-01],
                        [ -8.52661133e-02,  -8.53271484e-02],
                        [ -7.25097656e-02,  -7.25708008e-02],
                        [ -6.14929199e-02,  -6.15234375e-02],
                        [ -4.35180664e-02,  -4.35791016e-02],
                        [ -1.95922852e-02,  -1.96533203e-02],
                        [ -3.08227539e-03,  -3.11279297e-03],
                        [ -3.90625000e-03,  -3.96728516e-03],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -3.13110352e-02,  -3.13415527e-02],
                        [ -3.87268066e-02,  -3.87878418e-02],
                        [ -3.71398926e-02,  -3.72009277e-02],
                        [ -2.27661133e-02,  -2.28271484e-02],
                        [  1.05285645e-02,   1.04675293e-02],
                        [  6.32629395e-02,   6.32019043e-02],
                        [  1.25000000e-01,   1.24969482e-01],
                        [  1.81976318e-01,   1.81915283e-01],
                        [  2.25402832e-01,   2.25341797e-01],
                        [  2.50549316e-01,   2.50518799e-01],
                        [  2.56622314e-01,   2.56591797e-01],
                        [  2.49206543e-01,   2.49145508e-01],
                        [  2.35595703e-01,   2.35565186e-01],
                        [  2.18261719e-01,   2.18231201e-01],
                        [  1.97326660e-01,   1.97265625e-01],
                        [  1.75415039e-01,   1.75384521e-01],
                        [  1.56311035e-01,   1.56280518e-01],
                        [  1.40502930e-01,   1.40441895e-01],
                        [  1.24176025e-01,   1.24114990e-01],
                        [  1.03393555e-01,   1.03363037e-01],
                        [  7.89794922e-02,   7.89184570e-02],
                        [  5.48706055e-02,   5.48400879e-02],
                        [  3.34472656e-02,   3.34167480e-02],
                        [  1.58691406e-02,   1.58081055e-02],
                        [  4.18090820e-03,   4.11987305e-03],
                        [ -7.32421875e-04,  -7.93457031e-04],
                        [ -5.49316406e-04,  -5.79833984e-04],
                        [  3.44848633e-03,   3.41796875e-03],
                        [  1.13525391e-02,   1.13220215e-02],
                        [  2.27050781e-02,   2.26440430e-02],
                        [  3.46679688e-02,   3.46069336e-02],
                        [  4.30908203e-02,   4.30603027e-02],
                        [  4.57153320e-02,   4.56542969e-02],
                        [  4.33349609e-02,   4.32739258e-02],
                        [  3.74450684e-02,   3.73840332e-02],
                        [  2.78625488e-02,   2.78015137e-02],
                        [  1.53808594e-02,   1.53198242e-02],
                        [  4.97436523e-03,   4.91333008e-03],
                        [  2.19726562e-03,   2.16674805e-03],
                        [  6.22558594e-03,   6.16455078e-03],
                        [  1.15966797e-02,   1.15356445e-02],
                        [  1.64794922e-02,   1.64184570e-02],
                        [  2.15148926e-02,   2.14843750e-02],
                        [  2.30407715e-02,   2.29797363e-02],
                        [  1.68762207e-02,   1.68151855e-02],
                        [  6.40869141e-03,   6.34765625e-03],
                        [ -1.89208984e-03,  -1.95312500e-03],
                        [ -7.75146484e-03,  -7.81250000e-03],
                        [ -1.37023926e-02,  -1.37634277e-02],
                        [ -1.77917480e-02,  -1.78527832e-02],
                        [ -1.63879395e-02,  -1.64489746e-02],
                        [ -1.21765137e-02,  -1.22680664e-02],
                        [ -1.33666992e-02,  -1.33972168e-02],
                        [ -2.31628418e-02,  -2.32238770e-02],
                        [ -3.47900391e-02,  -3.48510742e-02],
                        [ -3.95202637e-02,  -3.95812988e-02],
                        [ -3.80249023e-02,  -3.80554199e-02],
                        [ -3.79638672e-02,  -3.80249023e-02],
                        [ -4.26025391e-02,  -4.26635742e-02],
                        [ -4.74548340e-02,  -4.75158691e-02],
                        [ -4.95300293e-02,  -4.95910645e-02],
                        [ -5.23376465e-02,  -5.23986816e-02],
                        [ -5.92346191e-02,  -5.92956543e-02],
                        [ -6.75354004e-02,  -6.75659180e-02],
                        [ -7.22045898e-02,  -7.22656250e-02],
                        [ -7.15637207e-02,  -7.16247559e-02],
                        [ -6.65893555e-02,  -6.66503906e-02],
                        [ -5.92956543e-02,  -5.93566895e-02],
                        [ -5.29174805e-02,  -5.29785156e-02],
                        [ -5.00793457e-02,  -5.01403809e-02],
                        [ -4.89196777e-02,  -4.89807129e-02],
                        [ -4.47998047e-02,  -4.48608398e-02],
                        [ -3.77197266e-02,  -3.77807617e-02],
                        [ -3.30200195e-02,  -3.30505371e-02],
                        [ -3.28369141e-02,  -3.28979492e-02],
                        [ -3.33862305e-02,  -3.34472656e-02],
                        [ -3.18298340e-02,  -3.18603516e-02],
                        [ -2.90832520e-02,  -2.91442871e-02],
                        [ -2.67028809e-02,  -2.67639160e-02],
                        [ -2.51770020e-02,  -2.52075195e-02],
                        [ -2.36511230e-02,  -2.37121582e-02],
                        [ -2.06604004e-02,  -2.07214355e-02],
                        [ -1.73645020e-02,  -1.73950195e-02],
                        [ -1.50451660e-02,  -1.51062012e-02],
                        [ -8.30078125e-03,  -8.39233398e-03],
                        [  8.39233398e-03,   8.36181641e-03],
                        [  2.95104980e-02,   2.94799805e-02],
                        [  4.52575684e-02,   4.51965332e-02],
                        [  5.48400879e-02,   5.47790527e-02],
                        [  6.27136230e-02,   6.26831055e-02],
                        [  7.08923340e-02,   7.08618164e-02],
                        [  8.18481445e-02,   8.17565918e-02],
                        [  1.00433350e-01,   1.00372314e-01],
                        [  1.29028320e-01,   1.28967285e-01],
                        [  1.63543701e-01,   1.63452148e-01],
                        [  1.93298340e-01,   1.93206787e-01],
                        [  2.02362061e-01,   2.02331543e-01],
                        [  1.74652100e-01,   1.74591064e-01],
                        [  1.00280762e-01,   1.00189209e-01],
                        [ -2.01110840e-02,  -2.01416016e-02],
                        [ -1.69433594e-01,  -1.69464111e-01],
                        [ -3.10668945e-01,  -3.10729980e-01],
                        [ -3.99475098e-01,  -3.99536133e-01],
                        [ -4.11895752e-01,  -4.11956787e-01],
                        [ -3.59680176e-01,  -3.59710693e-01],
                        [ -2.78625488e-01,  -2.78717041e-01],
                        [ -2.06115723e-01,  -2.06176758e-01],
                        [ -1.62780762e-01,  -1.62811279e-01],
                        [ -1.43432617e-01,  -1.43493652e-01],
                        [ -1.26464844e-01,  -1.26525879e-01],
                        [ -9.88159180e-02,  -9.88464355e-02],
                        [ -6.79626465e-02,  -6.80236816e-02],
                        [ -4.76989746e-02,  -4.77905273e-02],
                        [ -4.00390625e-02,  -4.00695801e-02],
                        [ -3.47290039e-02,  -3.47595215e-02],
                        [ -2.26440430e-02,  -2.27355957e-02],
                        [ -6.62231445e-03,  -6.68334961e-03],
                        [  2.07519531e-03,   2.01416016e-03],
                        [ -3.20434570e-03,  -3.26538086e-03],
                        [ -1.95922852e-02,  -1.96838379e-02],
                        [ -4.05578613e-02,  -4.06188965e-02],
                        [ -5.85327148e-02,  -5.85632324e-02],
                        [ -6.47277832e-02,  -6.47888184e-02],
                        [ -5.26428223e-02,  -5.26733398e-02],
                        [ -2.05993652e-02,  -2.06604004e-02],
                        [  3.03955078e-02,   3.03344727e-02],
                        [  9.79003906e-02,   9.78393555e-02],
                        [  1.74011230e-01,   1.73950195e-01],
                        [  2.41271973e-01,   2.41241455e-01],
                        [  2.79632568e-01,   2.79602051e-01],
                        [  2.83630371e-01,   2.83569336e-01],
                        [  2.67120361e-01,   2.67059326e-01],
                        [  2.45666504e-01,   2.45605469e-01],
                        [  2.22564697e-01,   2.22503662e-01],
                        [  1.97143555e-01,   1.97113037e-01],
                        [  1.73583984e-01,   1.73553467e-01],
                        [  1.54144287e-01,   1.54083252e-01],
                        [  1.34185791e-01,   1.34124756e-01],
                        [  1.10870361e-01,   1.10839844e-01],
                        [  8.81652832e-02,   8.81042480e-02],
                        [  6.92749023e-02,   6.92138672e-02],
                        [  5.28869629e-02,   5.28259277e-02],
                        [  3.87878418e-02,   3.87268066e-02],
                        [  2.81982422e-02,   2.81372070e-02],
                        [  1.82800293e-02,   1.82495117e-02],
                        [  6.46972656e-03,   6.40869141e-03],
                        [ -1.92260742e-03,  -1.95312500e-03],
                        [  9.15527344e-04,   8.54492188e-04],
                        [  1.41601562e-02,   1.40991211e-02],
                        [  2.94494629e-02,   2.93884277e-02],
                        [  3.92761230e-02,   3.92456055e-02],
                        [  4.09240723e-02,   4.08630371e-02],
                        [  3.49426270e-02,   3.49121094e-02],
                        [  2.38647461e-02,   2.38037109e-02],
                        [  1.17187500e-02,   1.16577148e-02],
                        [  3.14331055e-03,   3.08227539e-03],
                        [  5.79833984e-04,   5.18798828e-04],
                        [  2.92968750e-03,   2.86865234e-03],
                        [  7.53784180e-03,   7.47680664e-03],
                        [  1.29089355e-02,   1.28479004e-02],
                        [  1.89208984e-02,   1.88903809e-02],
                        [  2.38952637e-02,   2.38342285e-02],
                        [  2.27050781e-02,   2.26745605e-02],
                        [  1.21765137e-02,   1.21459961e-02],
                        [ -2.92968750e-03,  -2.99072266e-03],
                        [ -1.45568848e-02,  -1.45874023e-02],
                        [ -2.01721191e-02,  -2.02026367e-02],
                        [ -2.16064453e-02,  -2.16369629e-02],
                        [ -1.87072754e-02,  -1.87683105e-02],
                        [ -1.11083984e-02,  -1.11389160e-02],
                        [ -2.77709961e-03,  -2.83813477e-03],
                        [ -3.66210938e-04,  -4.27246094e-04],
                        [ -7.01904297e-03,  -7.08007812e-03],
                        [ -1.97448730e-02,  -1.98059082e-02],
                        [ -3.26843262e-02,  -3.27453613e-02],
                        [ -4.24499512e-02,  -4.24804688e-02],
                        [ -4.92248535e-02,  -4.92553711e-02],
                        [ -5.33142090e-02,  -5.33752441e-02],
                        [ -5.38940430e-02,  -5.39245605e-02],
                        [ -5.20019531e-02,  -5.20629883e-02],
                        [ -5.21850586e-02,  -5.22155762e-02],
                        [ -5.77697754e-02,  -5.78308105e-02],
                        [ -6.61926270e-02,  -6.62231445e-02],
                        [ -7.18994141e-02,  -7.19299316e-02],
                        [ -7.36999512e-02,  -7.37304688e-02],
                        [ -7.47070312e-02,  -7.47375488e-02],
                        [ -7.58056641e-02,  -7.58666992e-02],
                        [ -7.38220215e-02,  -7.38525391e-02],
                        [ -6.61315918e-02,  -6.61621094e-02],
                        [ -5.49621582e-02,  -5.49926758e-02],
                        [ -4.57458496e-02,  -4.57763672e-02],
                        [ -4.19616699e-02,  -4.19921875e-02],
                        [ -4.13818359e-02,  -4.14123535e-02],
                        [ -3.89709473e-02,  -3.90014648e-02],
                        [ -3.27148438e-02,  -3.27453613e-02],
                        [ -2.63671875e-02,  -2.63977051e-02],
                        [ -2.54211426e-02,  -2.54516602e-02],
                        [ -2.99072266e-02,  -2.99377441e-02],
                        [ -3.31420898e-02,  -3.31726074e-02],
                        [ -3.01208496e-02,  -3.01513672e-02],
                        [ -2.35900879e-02,  -2.36206055e-02],
                        [ -1.84936523e-02,  -1.85546875e-02],
                        [ -1.42517090e-02,  -1.42822266e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  4.39453125e-03,   4.36401367e-03],
                        [  1.49536133e-02,   1.49230957e-02],
                        [  2.31628418e-02,   2.31323242e-02],
                        [  3.25927734e-02,   3.25317383e-02],
                        [  4.45861816e-02,   4.45556641e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  6.48803711e-02,   6.48498535e-02],
                        [  8.16650391e-02,   8.16345215e-02],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  1.42883301e-01,   1.42852783e-01],
                        [  1.70013428e-01,   1.69982910e-01],
                        [  1.81518555e-01,   1.81488037e-01],
                        [  1.65679932e-01,   1.65649414e-01],
                        [  1.11846924e-01,   1.11816406e-01],
                        [  1.77917480e-02,   1.77612305e-02],
                        [ -1.08367920e-01,  -1.08398438e-01],
                        [ -2.46582031e-01,  -2.46582031e-01],
                        [ -3.60290527e-01,  -3.60290527e-01],
                        [ -4.08081055e-01,  -4.08111572e-01],
                        [ -3.76190186e-01,  -3.76220703e-01],
                        [ -2.95837402e-01,  -2.95837402e-01],
                        [ -2.18292236e-01,  -2.18322754e-01],
                        [ -1.73675537e-01,  -1.73675537e-01],
                        [ -1.56280518e-01,  -1.56280518e-01],
                        [ -1.43646240e-01,  -1.43646240e-01],
                        [ -1.22802734e-01,  -1.22802734e-01],
                        [ -9.82055664e-02,  -9.82055664e-02],
                        [ -7.86743164e-02,  -7.87048340e-02],
                        [ -6.42089844e-02,  -6.42395020e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.60107422e-03,  -3.63159180e-03],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  2.96020508e-03,   2.96020508e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -2.97851562e-02,  -2.98156738e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -3.86352539e-02,  -3.86657715e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  1.70898438e-01,   1.70867920e-01],
                        [  2.34924316e-01,   2.34924316e-01],
                        [  2.74200439e-01,   2.74230957e-01],
                        [  2.80487061e-01,   2.80456543e-01],
                        [  2.62725830e-01,   2.62695312e-01],
                        [  2.35870361e-01,   2.35870361e-01],
                        [  2.08892822e-01,   2.08892822e-01],
                        [  1.84112549e-01,   1.84112549e-01],
                        [  1.61926270e-01,   1.61956787e-01],
                        [  1.43951416e-01,   1.43951416e-01],
                        [  1.31500244e-01,   1.31500244e-01],
                        [  1.21856689e-01,   1.21856689e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  8.93249512e-02,   8.93249512e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  2.20947266e-02,   2.21252441e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -6.89697266e-03,  -6.86645508e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  1.94702148e-02,   1.95007324e-02],
                        [  3.00292969e-02,   3.00598145e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  3.54919434e-02,   3.55224609e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  1.52282715e-02,   1.52587891e-02],
                        [  4.69970703e-03,   4.69970703e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.73950195e-03,  -1.70898438e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -2.83813477e-03,  -2.80761719e-03],
                        [ -7.93457031e-04,  -7.62939453e-04],
                        [ -4.57763672e-04,  -4.27246094e-04],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [  1.25122070e-03,   1.28173828e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -4.54711914e-03,  -4.51660156e-03],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -4.16870117e-02,  -4.16564941e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -3.99169922e-02,  -3.98864746e-02],
                        [ -3.91845703e-02,  -3.91540527e-02],
                        [ -4.09545898e-02,  -4.09240723e-02],
                        [ -4.68139648e-02,  -4.67834473e-02],
                        [ -5.68847656e-02,  -5.68542480e-02],
                        [ -6.54602051e-02,  -6.54296875e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -5.88378906e-02,  -5.88073730e-02],
                        [ -5.30090332e-02,  -5.29785156e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -5.28564453e-02,  -5.28259277e-02],
                        [ -5.51452637e-02,  -5.50842285e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -5.53283691e-02,  -5.52673340e-02],
                        [ -6.20422363e-02,  -6.20117188e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -5.88073730e-02,  -5.87768555e-02],
                        [ -4.54711914e-02,  -4.54101562e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -2.70690918e-02,  -2.70385742e-02],
                        [ -2.21252441e-02,  -2.20642090e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -8.05664062e-03,  -8.02612305e-03],
                        [  3.05175781e-04,   3.35693359e-04],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  1.89208984e-02,   1.89819336e-02],
                        [  2.67639160e-02,   2.68249512e-02],
                        [  2.99072266e-02,   2.99377441e-02],
                        [  3.06091309e-02,   3.06396484e-02],
                        [  3.60412598e-02,   3.61022949e-02],
                        [  5.05981445e-02,   5.06286621e-02],
                        [  7.11364746e-02,   7.11669922e-02],
                        [  9.18273926e-02,   9.18579102e-02],
                        [  1.11938477e-01,   1.11968994e-01],
                        [  1.35833740e-01,   1.35864258e-01],
                        [  1.63848877e-01,   1.63879395e-01],
                        [  1.85333252e-01,   1.85363770e-01],
                        [  1.83959961e-01,   1.83990479e-01],
                        [  1.48406982e-01,   1.48437500e-01],
                        [  7.42187500e-02,   7.42492676e-02],
                        [ -3.75061035e-02,  -3.74755859e-02],
                        [ -1.72912598e-01,  -1.72882080e-01],
                        [ -2.99804688e-01,  -2.99774170e-01],
                        [ -3.79547119e-01,  -3.79516602e-01],
                        [ -3.90777588e-01,  -3.90747070e-01],
                        [ -3.43261719e-01,  -3.43200684e-01],
                        [ -2.70507812e-01,  -2.70477295e-01],
                        [ -2.07366943e-01,  -2.07336426e-01],
                        [ -1.69219971e-01,  -1.69189453e-01],
                        [ -1.48742676e-01,  -1.48712158e-01],
                        [ -1.30554199e-01,  -1.30493164e-01],
                        [ -1.09039307e-01,  -1.09008789e-01],
                        [ -9.05456543e-02,  -9.04846191e-02],
                        [ -7.85522461e-02,  -7.84912109e-02],
                        [ -6.53991699e-02,  -6.53686523e-02],
                        [ -4.34875488e-02,  -4.34265137e-02],
                        [ -1.66931152e-02,  -1.66320801e-02],
                        [  5.24902344e-03,   5.27954102e-03],
                        [  1.73339844e-02,   1.73645020e-02],
                        [  1.88598633e-02,   1.89208984e-02],
                        [  1.08947754e-02,   1.09252930e-02],
                        [ -2.53295898e-03,  -2.50244141e-03],
                        [ -1.70898438e-02,  -1.70288086e-02],
                        [ -3.20739746e-02,  -3.20129395e-02],
                        [ -4.53186035e-02,  -4.52880859e-02],
                        [ -4.76684570e-02,  -4.76074219e-02],
                        [ -2.69775391e-02,  -2.69165039e-02],
                        [  2.33459473e-02,   2.33764648e-02],
                        [  9.88464355e-02,   9.88769531e-02],
                        [  1.83166504e-01,   1.83227539e-01],
                        [  2.53906250e-01,   2.53936768e-01],
                        [  2.92907715e-01,   2.92938232e-01],
                        [  2.93945312e-01,   2.94006348e-01],
                        [  2.66387939e-01,   2.66448975e-01],
                        [  2.31170654e-01,   2.31201172e-01],
                        [  2.04711914e-01,   2.04772949e-01],
                        [  1.86767578e-01,   1.86828613e-01],
                        [  1.69403076e-01,   1.69433594e-01],
                        [  1.51611328e-01,   1.51672363e-01],
                        [  1.36657715e-01,   1.36718750e-01],
                        [  1.22314453e-01,   1.22344971e-01],
                        [  1.03607178e-01,   1.03637695e-01],
                        [  7.98339844e-02,   7.98950195e-02],
                        [  5.34057617e-02,   5.34667969e-02],
                        [  2.74047852e-02,   2.74658203e-02],
                        [  7.56835938e-03,   7.62939453e-03],
                        [ -5.79833984e-04,  -5.18798828e-04],
                        [  1.00708008e-03,   1.06811523e-03],
                        [  4.39453125e-03,   4.42504883e-03],
                        [  5.98144531e-03,   6.04248047e-03],
                        [  1.06506348e-02,   1.07116699e-02],
                        [  2.27355957e-02,   2.27966309e-02],
                        [  3.77502441e-02,   3.78112793e-02],
                        [  4.68444824e-02,   4.69055176e-02],
                        [  4.57763672e-02,   4.58374023e-02],
                        [  3.61633301e-02,   3.61938477e-02],
                        [  2.26135254e-02,   2.26745605e-02],
                        [  1.03149414e-02,   1.03759766e-02],
                        [  2.50244141e-03,   2.56347656e-03],
                        [ -4.57763672e-04,  -3.96728516e-04],
                        [  6.40869141e-04,   7.01904297e-04],
                        [  4.11987305e-03,   4.15039062e-03],
                        [  6.89697266e-03,   6.92749023e-03],
                        [  6.28662109e-03,   6.31713867e-03],
                        [  2.96020508e-03,   3.02124023e-03],
                        [  7.32421875e-04,   7.93457031e-04],
                        [  1.40380859e-03,   1.46484375e-03],
                        [  5.49316406e-04,   6.10351562e-04],
                        [ -6.56127930e-03,  -6.50024414e-03],
                        [ -1.67541504e-02,  -1.67236328e-02],
                        [ -2.27966309e-02,  -2.27661133e-02],
                        [ -2.21557617e-02,  -2.20947266e-02],
                        [ -1.73645020e-02,  -1.73034668e-02],
                        [ -1.24206543e-02,  -1.23596191e-02],
                        [ -1.23901367e-02,  -1.23291016e-02],
                        [ -2.02636719e-02,  -2.02026367e-02],
                        [ -3.09753418e-02,  -3.09143066e-02],
                        [ -3.61022949e-02,  -3.60717773e-02],
                        [ -3.61022949e-02,  -3.60412598e-02],
                        [ -3.92761230e-02,  -3.92150879e-02],
                        [ -4.92858887e-02,  -4.92553711e-02],
                        [ -6.22253418e-02,  -6.21948242e-02],
                        [ -7.39746094e-02,  -7.39135742e-02],
                        [ -8.16650391e-02,  -8.16345215e-02],
                        [ -8.23364258e-02,  -8.23059082e-02],
                        [ -7.72705078e-02,  -7.72094727e-02],
                        [ -7.22961426e-02,  -7.22351074e-02],
                        [ -6.93969727e-02,  -6.93664551e-02],
                        [ -6.43615723e-02,  -6.43310547e-02],
                        [ -5.50537109e-02,  -5.49621582e-02],
                        [ -4.63256836e-02,  -4.62646484e-02],
                        [ -4.50744629e-02,  -4.50439453e-02],
                        [ -5.22460938e-02,  -5.21850586e-02],
                        [ -6.12792969e-02,  -6.12182617e-02],
                        [ -6.51855469e-02,  -6.51550293e-02],
                        [ -6.25915527e-02,  -6.25305176e-02],
                        [ -5.47180176e-02,  -5.46569824e-02],
                        [ -4.21447754e-02,  -4.20837402e-02],
                        [ -2.78930664e-02,  -2.78320312e-02],
                        [ -1.78833008e-02,  -1.78527832e-02],
                        [ -1.36413574e-02,  -1.35803223e-02],
                        [ -1.15356445e-02,  -1.14746094e-02],
                        [ -9.79614258e-03,  -9.76562500e-03],
                        [ -8.08715820e-03,  -8.02612305e-03],
                        [ -3.17382812e-03,  -3.11279297e-03],
                        [  7.04956055e-03,   7.11059570e-03],
                        [  1.92871094e-02,   1.93176270e-02],
                        [  2.90527344e-02,   2.91137695e-02],
                        [  3.61022949e-02,   3.61633301e-02],
                        [  4.39758301e-02,   4.40063477e-02],
                        [  5.61828613e-02,   5.62438965e-02],
                        [  7.31811523e-02,   7.32421875e-02],
                        [  9.31091309e-02,   9.31396484e-02],
                        [  1.15325928e-01,   1.15356445e-01],
                        [  1.41021729e-01,   1.41082764e-01],
                        [  1.68518066e-01,   1.68579102e-01],
                        [  1.88507080e-01,   1.88537598e-01],
                        [  1.85363770e-01,   1.85424805e-01],
                        [  1.45660400e-01,   1.45721436e-01],
                        [  6.47277832e-02,   6.47583008e-02],
                        [ -5.19104004e-02,  -5.18798828e-02],
                        [ -1.86920166e-01,  -1.86859131e-01],
                        [ -3.09173584e-01,  -3.09112549e-01],
                        [ -3.83453369e-01,  -3.83422852e-01],
                        [ -3.90960693e-01,  -3.90899658e-01],
                        [ -3.42102051e-01,  -3.42041016e-01],
                        [ -2.69653320e-01,  -2.69622803e-01],
                        [ -2.06573486e-01,  -2.06512451e-01],
                        [ -1.66076660e-01,  -1.66015625e-01],
                        [ -1.40228271e-01,  -1.40197754e-01],
                        [ -1.15447998e-01,  -1.15417480e-01],
                        [ -8.78295898e-02,  -8.77685547e-02],
                        [ -6.37207031e-02,  -6.36901855e-02],
                        [ -4.82482910e-02,  -4.82177734e-02],
                        [ -3.66516113e-02,  -3.66210938e-02],
                        [ -2.09045410e-02,  -2.08740234e-02],
                        [ -2.77709961e-03,  -2.71606445e-03],
                        [  6.92749023e-03,   6.95800781e-03],
                        [  3.47900391e-03,   3.54003906e-03],
                        [ -6.01196289e-03,  -5.95092773e-03],
                        [ -1.54724121e-02,  -1.54418945e-02],
                        [ -2.74963379e-02,  -2.74353027e-02],
                        [ -4.40673828e-02,  -4.40368652e-02],
                        [ -5.95092773e-02,  -5.94787598e-02],
                        [ -6.51550293e-02,  -6.51245117e-02],
                        [ -5.52673340e-02,  -5.52368164e-02],
                        [ -2.71911621e-02,  -2.71301270e-02],
                        [  2.05993652e-02,   2.06604004e-02],
                        [  8.88061523e-02,   8.88671875e-02],
                        [  1.72576904e-01,   1.72637939e-01],
                        [  2.55279541e-01,   2.55310059e-01],
                        [  3.12469482e-01,   3.12530518e-01],
                        [  3.27850342e-01,   3.27880859e-01],
                        [  3.05053711e-01,   3.05084229e-01],
                        [  2.62969971e-01,   2.63031006e-01],
                        [  2.20123291e-01,   2.20184326e-01],
                        [  1.84143066e-01,   1.84173584e-01],
                        [  1.53717041e-01,   1.53778076e-01],
                        [  1.27532959e-01,   1.27563477e-01],
                        [  1.08764648e-01,   1.08795166e-01],
                        [  1.00433350e-01,   1.00463867e-01],
                        [  9.84191895e-02,   9.84802246e-02],
                        [  9.30175781e-02,   9.30480957e-02],
                        [  7.76062012e-02,   7.76367188e-02],
                        [  5.47180176e-02,   5.47790527e-02],
                        [  3.31726074e-02,   3.32031250e-02],
                        [  1.94396973e-02,   1.94702148e-02],
                        [  1.32446289e-02,   1.32751465e-02],
                        [  1.12304688e-02,   1.12609863e-02],
                        [  1.22680664e-02,   1.22985840e-02],
                        [  1.70288086e-02,   1.70898438e-02],
                        [  2.44445801e-02,   2.44750977e-02],
                        [  3.07617188e-02,   3.07922363e-02],
                        [  3.20434570e-02,   3.20739746e-02],
                        [  2.70080566e-02,   2.70690918e-02],
                        [  1.83410645e-02,   1.83715820e-02],
                        [  1.23901367e-02,   1.24206543e-02],
                        [  1.45568848e-02,   1.46179199e-02],
                        [  2.23388672e-02,   2.23693848e-02],
                        [  2.62145996e-02,   2.62451172e-02],
                        [  2.18811035e-02,   2.19421387e-02],
                        [  1.54418945e-02,   1.55029297e-02],
                        [  1.34887695e-02,   1.35192871e-02],
                        [  1.38549805e-02,   1.38854980e-02],
                        [  1.06506348e-02,   1.06811523e-02],
                        [  3.96728516e-03,   3.99780273e-03],
                        [ -1.55639648e-03,  -1.52587891e-03],
                        [ -5.09643555e-03,  -5.06591797e-03],
                        [ -9.58251953e-03,  -9.55200195e-03],
                        [ -1.48010254e-02,  -1.47705078e-02],
                        [ -1.88598633e-02,  -1.88293457e-02],
                        [ -2.35290527e-02,  -2.34985352e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -3.37524414e-02,  -3.37219238e-02],
                        [ -3.18908691e-02,  -3.18603516e-02],
                        [ -2.94799805e-02,  -2.94494629e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.92456055e-02,  -3.92150879e-02],
                        [ -4.55627441e-02,  -4.55322266e-02],
                        [ -4.95300293e-02,  -4.94995117e-02],
                        [ -5.21850586e-02,  -5.21545410e-02],
                        [ -5.56030273e-02,  -5.55725098e-02],
                        [ -6.12487793e-02,  -6.12182617e-02],
                        [ -6.70166016e-02,  -6.69860840e-02],
                        [ -6.91223145e-02,  -6.90917969e-02],
                        [ -6.82067871e-02,  -6.81762695e-02],
                        [ -6.78405762e-02,  -6.78100586e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -6.50024414e-02,  -6.49719238e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -5.89294434e-02,  -5.88989258e-02],
                        [ -5.71289062e-02,  -5.70983887e-02],
                        [ -5.27648926e-02,  -5.27343750e-02],
                        [ -4.70581055e-02,  -4.70275879e-02],
                        [ -4.32128906e-02,  -4.31823730e-02],
                        [ -4.02832031e-02,  -4.02526855e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.03955078e-02,  -3.03649902e-02],
                        [ -3.04260254e-02,  -3.03955078e-02],
                        [ -3.50952148e-02,  -3.50646973e-02],
                        [ -3.71704102e-02,  -3.71398926e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  6.28662109e-03,   6.31713867e-03],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  3.17687988e-02,   3.17993164e-02],
                        [  4.32434082e-02,   4.32739258e-02],
                        [  5.29479980e-02,   5.29785156e-02],
                        [  6.19812012e-02,   6.20117188e-02],
                        [  7.43713379e-02,   7.44018555e-02],
                        [  9.42687988e-02,   9.42687988e-02],
                        [  1.23046875e-01,   1.23046875e-01],
                        [  1.54266357e-01,   1.54296875e-01],
                        [  1.74163818e-01,   1.74163818e-01],
                        [  1.69769287e-01,   1.69769287e-01],
                        [  1.35437012e-01,   1.35467529e-01],
                        [  7.25708008e-02,   7.26013184e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.08642578e-01,  -1.08642578e-01],
                        [ -2.06756592e-01,  -2.06756592e-01],
                        [ -2.92266846e-01,  -2.92266846e-01],
                        [ -3.46893311e-01,  -3.46893311e-01],
                        [ -3.57055664e-01,  -3.57025146e-01],
                        [ -3.24279785e-01,  -3.24279785e-01],
                        [ -2.65655518e-01,  -2.65655518e-01],
                        [ -2.04010010e-01,  -2.03979492e-01],
                        [ -1.55548096e-01,  -1.55517578e-01],
                        [ -1.21765137e-01,  -1.21734619e-01],
                        [ -9.39636230e-02,  -9.39331055e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -5.09948730e-02,  -5.09643555e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.86047363e-02,  -3.85742188e-02],
                        [ -2.67333984e-02,  -2.67028809e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  1.83410645e-01,   1.83410645e-01],
                        [  2.53204346e-01,   2.53204346e-01],
                        [  2.94982910e-01,   2.94982910e-01],
                        [  3.00567627e-01,   3.00567627e-01],
                        [  2.77130127e-01,   2.77130127e-01],
                        [  2.40844727e-01,   2.40844727e-01],
                        [  2.04986572e-01,   2.05017090e-01],
                        [  1.74682617e-01,   1.74682617e-01],
                        [  1.49017334e-01,   1.49017334e-01],
                        [  1.26464844e-01,   1.26464844e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.72729492e-02,   1.72424316e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [ -2.56347656e-03,  -2.59399414e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -1.44653320e-02,  -1.44958496e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -3.67431641e-02,  -3.67736816e-02],
                        [ -3.93066406e-02,  -3.93371582e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.00695801e-02,  -4.01000977e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.24597168e-02,  -5.24902344e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -7.27233887e-02,  -7.27233887e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -5.88073730e-02,  -5.88378906e-02],
                        [ -5.57250977e-02,  -5.57556152e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -6.38732910e-02,  -6.38732910e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -4.15344238e-02,  -4.15649414e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.06701660e-02,  -3.07006836e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.32751465e-02,  -1.33056641e-02],
                        [ -3.69262695e-03,  -3.72314453e-03],
                        [  1.13220215e-02,   1.12915039e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  5.15747070e-02,   5.15441895e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  1.09741211e-01,   1.09741211e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.51641846e-01,   1.51611328e-01],
                        [  1.61437988e-01,   1.61437988e-01],
                        [  1.54083252e-01,   1.54083252e-01],
                        [  1.25457764e-01,   1.25457764e-01],
                        [  7.72094727e-02,   7.71789551e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -2.36999512e-01,  -2.37030029e-01],
                        [ -3.11859131e-01,  -3.11859131e-01],
                        [ -3.55926514e-01,  -3.55926514e-01],
                        [ -3.53454590e-01,  -3.53454590e-01],
                        [ -3.06823730e-01,  -3.06854248e-01],
                        [ -2.38769531e-01,  -2.38800049e-01],
                        [ -1.78039551e-01,  -1.78039551e-01],
                        [ -1.39831543e-01,  -1.39831543e-01],
                        [ -1.16638184e-01,  -1.16638184e-01],
                        [ -9.14916992e-02,  -9.15222168e-02],
                        [ -6.17980957e-02,  -6.18286133e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -3.47900391e-02,  -3.48205566e-02],
                        [ -3.14636230e-02,  -3.14941406e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -6.12487793e-02,  -6.12792969e-02],
                        [ -6.45446777e-02,  -6.45751953e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  1.12579346e-01,   1.12579346e-01],
                        [  1.91833496e-01,   1.91833496e-01],
                        [  2.60040283e-01,   2.60040283e-01],
                        [  3.00994873e-01,   3.00994873e-01],
                        [  3.09539795e-01,   3.09539795e-01],
                        [  2.90435791e-01,   2.90435791e-01],
                        [  2.53479004e-01,   2.53448486e-01],
                        [  2.10601807e-01,   2.10601807e-01],
                        [  1.72027588e-01,   1.72027588e-01],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  1.72729492e-02,   1.72424316e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  3.13110352e-02,   3.12805176e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  3.71093750e-02,   3.70788574e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  6.04248047e-03,   6.01196289e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -7.99560547e-03,  -8.02612305e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -3.38745117e-03,  -3.41796875e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -8.27026367e-03,  -8.30078125e-03],
                        [ -1.26037598e-02,  -1.26342773e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -2.80761719e-02,  -2.81066895e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -4.97131348e-02,  -4.97436523e-02],
                        [ -5.94177246e-02,  -5.94482422e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -6.61926270e-02,  -6.61926270e-02],
                        [ -6.95190430e-02,  -6.95190430e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.97937012e-02,  -6.98242188e-02],
                        [ -6.93359375e-02,  -6.93664551e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -5.89294434e-02,  -5.89294434e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -3.86962891e-02,  -3.87268066e-02],
                        [ -4.07714844e-02,  -4.08020020e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -4.25415039e-02,  -4.25720215e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  4.16259766e-02,   4.15954590e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  1.01898193e-01,   1.01898193e-01],
                        [  1.23260498e-01,   1.23229980e-01],
                        [  1.40655518e-01,   1.40655518e-01],
                        [  1.49963379e-01,   1.49963379e-01],
                        [  1.46606445e-01,   1.46606445e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  9.09729004e-02,   9.09423828e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -8.77685547e-02,  -8.77685547e-02],
                        [ -1.58508301e-01,  -1.58508301e-01],
                        [ -2.30468750e-01,  -2.30468750e-01],
                        [ -2.96936035e-01,  -2.96966553e-01],
                        [ -3.40606689e-01,  -3.40606689e-01],
                        [ -3.40209961e-01,  -3.40209961e-01],
                        [ -2.91442871e-01,  -2.91442871e-01],
                        [ -2.18780518e-01,  -2.18780518e-01],
                        [ -1.57958984e-01,  -1.57958984e-01],
                        [ -1.24114990e-01,  -1.24114990e-01],
                        [ -1.04827881e-01,  -1.04827881e-01],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  2.18750000e-01,   2.18750000e-01],
                        [  2.68676758e-01,   2.68676758e-01],
                        [  2.94860840e-01,   2.94860840e-01],
                        [  2.90802002e-01,   2.90771484e-01],
                        [  2.60070801e-01,   2.60070801e-01],
                        [  2.19024658e-01,   2.19024658e-01],
                        [  1.85791016e-01,   1.85791016e-01],
                        [  1.65466309e-01,   1.65466309e-01],
                        [  1.51000977e-01,   1.51000977e-01],
                        [  1.34735107e-01,   1.34735107e-01],
                        [  1.15509033e-01,   1.15509033e-01],
                        [  9.67102051e-02,   9.67102051e-02],
                        [  7.87658691e-02,   7.87658691e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -1.22375488e-02,  -1.22680664e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -7.48901367e-02,  -7.48901367e-02],
                        [ -8.00476074e-02,  -8.00476074e-02],
                        [ -7.83996582e-02,  -7.83996582e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  1.03240967e-01,   1.03240967e-01],
                        [  1.20697021e-01,   1.20697021e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.27136230e-01,   1.27136230e-01],
                        [  1.06292725e-01,   1.06292725e-01],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -8.38623047e-02,  -8.38623047e-02],
                        [ -1.15875244e-01,  -1.15875244e-01],
                        [ -1.73553467e-01,  -1.73553467e-01],
                        [ -2.50549316e-01,  -2.50549316e-01],
                        [ -3.10028076e-01,  -3.10028076e-01],
                        [ -3.16314697e-01,  -3.16314697e-01],
                        [ -2.69012451e-01,  -2.69012451e-01],
                        [ -2.00744629e-01,  -2.00744629e-01],
                        [ -1.47949219e-01,  -1.47949219e-01],
                        [ -1.23809814e-01,  -1.23809814e-01],
                        [ -1.13098145e-01,  -1.13098145e-01],
                        [ -9.37194824e-02,  -9.37194824e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  1.01928711e-02,   1.01928711e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  1.54235840e-01,   1.54235840e-01],
                        [  2.02270508e-01,   2.02270508e-01],
                        [  2.44964600e-01,   2.44964600e-01],
                        [  2.76245117e-01,   2.76245117e-01],
                        [  2.84637451e-01,   2.84637451e-01],
                        [  2.64770508e-01,   2.64770508e-01],
                        [  2.28088379e-01,   2.28088379e-01],
                        [  1.91680908e-01,   1.91680908e-01],
                        [  1.61956787e-01,   1.61956787e-01],
                        [  1.37512207e-01,   1.37512207e-01],
                        [  1.18011475e-01,   1.18011475e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  3.51562500e-02,   3.51562500e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  9.23156738e-02,   9.23156738e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -1.04705811e-01,  -1.04705811e-01],
                        [ -1.85363770e-01,  -1.85363770e-01],
                        [ -2.71942139e-01,  -2.71942139e-01],
                        [ -3.24890137e-01,  -3.24890137e-01],
                        [ -3.17993164e-01,  -3.17993164e-01],
                        [ -2.60772705e-01,  -2.60772705e-01],
                        [ -1.90856934e-01,  -1.90856934e-01],
                        [ -1.40136719e-01,  -1.40136719e-01],
                        [ -1.11938477e-01,  -1.11938477e-01],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.84387207e-01,   1.84387207e-01],
                        [  2.21435547e-01,   2.21435547e-01],
                        [  2.57873535e-01,   2.57873535e-01],
                        [  2.82012939e-01,   2.82012939e-01],
                        [  2.76580811e-01,   2.76580811e-01],
                        [  2.39715576e-01,   2.39715576e-01],
                        [  1.90460205e-01,   1.90460205e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  1.21124268e-01,   1.21124268e-01],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  8.61511230e-02,   8.61511230e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  6.69860840e-02,   6.69860840e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -6.56127930e-02,  -6.56127930e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  7.29980469e-02,   7.29980469e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.08947754e-01,   1.08947754e-01],
                        [  1.05651855e-01,   1.05651855e-01],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -1.92077637e-01,  -1.92077637e-01],
                        [ -2.73315430e-01,  -2.73315430e-01],
                        [ -3.12408447e-01,  -3.12408447e-01],
                        [ -2.96295166e-01,  -2.96295166e-01],
                        [ -2.42218018e-01,  -2.42218018e-01],
                        [ -1.82373047e-01,  -1.82373047e-01],
                        [ -1.40502930e-01,  -1.40502930e-01],
                        [ -1.17309570e-01,  -1.17309570e-01],
                        [ -9.62829590e-02,  -9.62829590e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.34185791e-01,   1.34185791e-01],
                        [  1.59423828e-01,   1.59423828e-01],
                        [  1.91619873e-01,   1.91619873e-01],
                        [  2.27081299e-01,   2.27081299e-01],
                        [  2.52838135e-01,   2.52838135e-01],
                        [  2.56652832e-01,   2.56652832e-01],
                        [  2.38983154e-01,   2.38983154e-01],
                        [  2.10723877e-01,   2.10723877e-01],
                        [  1.80572510e-01,   1.80572510e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.24908447e-01,   1.24908447e-01],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  2.55126953e-02,   2.55126953e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -6.58569336e-02,  -6.58569336e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.04705811e-01,   1.04705811e-01],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  2.48107910e-02,   2.48107910e-02],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -1.67785645e-01,  -1.67785645e-01],
                        [ -2.53479004e-01,  -2.53479004e-01],
                        [ -3.03894043e-01,  -3.03894043e-01],
                        [ -3.00476074e-01,  -3.00476074e-01],
                        [ -2.50274658e-01,  -2.50274658e-01],
                        [ -1.82281494e-01,  -1.82281494e-01],
                        [ -1.24877930e-01,  -1.24877930e-01],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -6.53686523e-02,  -6.53686523e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  1.00372314e-01,   1.00372314e-01],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  1.30981445e-01,   1.30981445e-01],
                        [  1.70074463e-01,   1.70074463e-01],
                        [  2.10845947e-01,   2.10845947e-01],
                        [  2.32971191e-01,   2.32971191e-01],
                        [  2.26165771e-01,   2.26165771e-01],
                        [  1.97540283e-01,   1.97540283e-01],
                        [  1.63696289e-01,   1.63696289e-01],
                        [  1.38610840e-01,   1.38610840e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  7.29370117e-02,   7.29370117e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -7.04650879e-02,  -7.04650879e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -6.21948242e-02,  -6.21948242e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  5.44738770e-02,   5.44738770e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  9.48181152e-02,   9.48181152e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -1.00219727e-01,  -1.00219727e-01],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -1.42059326e-01,  -1.42059326e-01],
                        [ -2.16949463e-01,  -2.16949463e-01],
                        [ -2.66845703e-01,  -2.66845703e-01],
                        [ -2.72460938e-01,  -2.72460938e-01],
                        [ -2.34008789e-01,  -2.34008789e-01],
                        [ -1.74896240e-01,  -1.74896240e-01],
                        [ -1.22711182e-01,  -1.22711182e-01],
                        [ -8.92333984e-02,  -8.92333984e-02],
                        [ -7.03735352e-02,  -7.03735352e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  9.71374512e-02,   9.71374512e-02],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.06323242e-01,   1.06323242e-01],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.46759033e-01,   1.46759033e-01],
                        [  1.87500000e-01,   1.87500000e-01],
                        [  2.20794678e-01,   2.20794678e-01],
                        [  2.32940674e-01,   2.32940674e-01],
                        [  2.22320557e-01,   2.22320557e-01],
                        [  1.94793701e-01,   1.94793701e-01],
                        [  1.60858154e-01,   1.60858154e-01],
                        [  1.31713867e-01,   1.31713867e-01],
                        [  1.10717773e-01,   1.10717773e-01],
                        [  9.30175781e-02,   9.30175781e-02],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  6.01196289e-02,   6.01196289e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -6.73828125e-02,  -6.73828125e-02],
                        [ -6.61926270e-02,  -6.61926270e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -6.75354004e-02,  -6.75354004e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -7.09838867e-02,  -7.09838867e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  9.35363770e-02,   9.35363770e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -8.98437500e-02,  -8.98437500e-02],
                        [ -9.90600586e-02,  -9.90600586e-02],
                        [ -7.29064941e-02,  -7.29064941e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -1.87438965e-01,  -1.87438965e-01],
                        [ -2.67913818e-01,  -2.67913818e-01],
                        [ -3.03131104e-01,  -3.03131104e-01],
                        [ -2.79479980e-01,  -2.79479980e-01],
                        [ -2.14965820e-01,  -2.14965820e-01],
                        [ -1.43127441e-01,  -1.43127441e-01],
                        [ -9.07897949e-02,  -9.07897949e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  9.24377441e-02,   9.24377441e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  9.38720703e-02,   9.38720703e-02],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.52954102e-01,   1.52954102e-01],
                        [  1.94000244e-01,   1.94000244e-01],
                        [  2.25280762e-01,   2.25280762e-01],
                        [  2.34039307e-01,   2.34039307e-01],
                        [  2.19207764e-01,   2.19207764e-01],
                        [  1.91558838e-01,   1.91558838e-01],
                        [  1.63421631e-01,   1.63421631e-01],
                        [  1.40991211e-01,   1.40991211e-01],
                        [  1.23504639e-01,   1.23504639e-01],
                        [  1.06018066e-01,   1.06018066e-01],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -5.74340820e-02,  -5.74340820e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -7.44628906e-02,  -7.44628906e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -7.69348145e-02,  -7.69348145e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  8.52966309e-02,   8.52966309e-02],
                        [  8.55407715e-02,   8.55407715e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -7.61108398e-02,  -7.61108398e-02],
                        [ -1.06781006e-01,  -1.06781006e-01],
                        [ -1.00891113e-01,  -1.00891113e-01],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -1.07299805e-01,  -1.07299805e-01],
                        [ -1.84875488e-01,  -1.84875488e-01],
                        [ -2.44323730e-01,  -2.44323730e-01],
                        [ -2.61474609e-01,  -2.61474609e-01],
                        [ -2.31781006e-01,  -2.31781006e-01],
                        [ -1.76574707e-01,  -1.76574707e-01],
                        [ -1.25915527e-01,  -1.25915527e-01],
                        [ -9.56115723e-02,  -9.56115723e-02],
                        [ -8.13293457e-02,  -8.13293457e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  1.04034424e-01,   1.04034424e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  1.38397217e-01,   1.38397217e-01],
                        [  1.87652588e-01,   1.87652588e-01],
                        [  2.22961426e-01,   2.22961426e-01],
                        [  2.30377197e-01,   2.30377197e-01],
                        [  2.11700439e-01,   2.11700439e-01],
                        [  1.79626465e-01,   1.79626465e-01],
                        [  1.47186279e-01,   1.47186279e-01],
                        [  1.22344971e-01,   1.22344971e-01],
                        [  1.06689453e-01,   1.06689453e-01],
                        [  9.51843262e-02,   9.51843262e-02],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  5.82885742e-02,   5.82885742e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  4.42504883e-03,   4.42504883e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -6.94580078e-02,  -6.94580078e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -1.13311768e-01,  -1.13311768e-01],
                        [ -1.39648438e-01,  -1.39648438e-01],
                        [ -1.25305176e-01,  -1.25305176e-01],
                        [ -7.69348145e-02,  -7.69348145e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -1.28387451e-01,  -1.28387451e-01],
                        [ -2.11090088e-01,  -2.11090088e-01],
                        [ -2.62115479e-01,  -2.62115479e-01],
                        [ -2.60589600e-01,  -2.60589600e-01],
                        [ -2.13134766e-01,  -2.13134766e-01],
                        [ -1.46209717e-01,  -1.46209717e-01],
                        [ -8.96911621e-02,  -8.96911621e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  1.09771729e-01,   1.09771729e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.48132324e-01,   1.48132324e-01],
                        [  1.35040283e-01,   1.35040283e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  6.92749023e-02,   6.92749023e-02],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  1.54754639e-01,   1.54754639e-01],
                        [  1.96166992e-01,   1.96166992e-01],
                        [  2.20489502e-01,   2.20489502e-01],
                        [  2.22351074e-01,   2.22351074e-01],
                        [  2.01507568e-01,   2.01507568e-01],
                        [  1.68395996e-01,   1.68395996e-01],
                        [  1.39343262e-01,   1.39343262e-01],
                        [  1.19232178e-01,   1.19232178e-01],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  8.37097168e-02,   8.37097168e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -7.37609863e-02,  -7.37609863e-02],
                        [ -7.45849609e-02,  -7.45849609e-02],
                        [ -7.28759766e-02,  -7.28759766e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  9.38415527e-02,   9.38415527e-02],
                        [  9.78088379e-02,   9.78088379e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -9.73205566e-02,  -9.73205566e-02],
                        [ -1.40319824e-01,  -1.40319824e-01],
                        [ -1.39739990e-01,  -1.39739990e-01],
                        [ -9.85412598e-02,  -9.85412598e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [ -7.74536133e-02,  -7.74536133e-02],
                        [ -1.74468994e-01,  -1.74468994e-01],
                        [ -2.53051758e-01,  -2.53051758e-01],
                        [ -2.81829834e-01,  -2.81829834e-01],
                        [ -2.51678467e-01,  -2.51678467e-01],
                        [ -1.86492920e-01,  -1.86492920e-01],
                        [ -1.26464844e-01,  -1.26464844e-01],
                        [ -9.59167480e-02,  -9.59167480e-02],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -8.38928223e-02,  -8.38928223e-02],
                        [ -6.91528320e-02,  -6.91528320e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  1.17614746e-01,   1.17614746e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  1.19445801e-01,   1.19445801e-01],
                        [  1.02142334e-01,   1.02142334e-01],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  7.67211914e-02,   7.67211914e-02],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.41937256e-01,   1.41937256e-01],
                        [  1.82830811e-01,   1.82830811e-01],
                        [  2.14172363e-01,   2.14172363e-01],
                        [  2.26898193e-01,   2.26898193e-01],
                        [  2.17163086e-01,   2.17163086e-01],
                        [  1.87713623e-01,   1.87713623e-01],
                        [  1.50604248e-01,   1.50604248e-01],
                        [  1.21032715e-01,   1.21032715e-01],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  6.79626465e-02,   6.79626465e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -8.50219727e-02,  -8.50219727e-02],
                        [ -1.33331299e-01,  -1.33331299e-01],
                        [ -1.44409180e-01,  -1.44409180e-01],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -1.39129639e-01,  -1.39129639e-01],
                        [ -2.30285645e-01,  -2.30285645e-01],
                        [ -2.82043457e-01,  -2.82043457e-01],
                        [ -2.75543213e-01,  -2.75543213e-01],
                        [ -2.21130371e-01,  -2.21130371e-01],
                        [ -1.51000977e-01,  -1.51000977e-01],
                        [ -9.70764160e-02,  -9.70764160e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  7.26928711e-02,   7.26928711e-02],
                        [  1.01287842e-01,   1.01287842e-01],
                        [  1.21368408e-01,   1.21368408e-01],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  9.20715332e-02,   9.20715332e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  1.37512207e-01,   1.37512207e-01],
                        [  1.77429199e-01,   1.77429199e-01],
                        [  2.10815430e-01,   2.10815430e-01],
                        [  2.25982666e-01,   2.25982666e-01],
                        [  2.15362549e-01,   2.15362549e-01],
                        [  1.82434082e-01,   1.82434082e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.12762451e-01,   1.12762451e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  6.81152344e-02,   6.81152344e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -6.60400391e-02,  -6.60400391e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -5.66101074e-02,  -5.66101074e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  6.79321289e-02,   6.79321289e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -1.28417969e-01,  -1.28417969e-01],
                        [ -1.62384033e-01,  -1.62384033e-01],
                        [ -1.54022217e-01,  -1.54022217e-01],
                        [ -1.07147217e-01,  -1.07147217e-01],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -1.31866455e-01,  -1.31866455e-01],
                        [ -2.23754883e-01,  -2.23754883e-01],
                        [ -2.75146484e-01,  -2.75146484e-01],
                        [ -2.65930176e-01,  -2.65930176e-01],
                        [ -2.07550049e-01,  -2.07550049e-01],
                        [ -1.36840820e-01,  -1.36840820e-01],
                        [ -8.67919922e-02,  -8.67919922e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.61218262e-02,  -5.61218262e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  1.40380859e-01,   1.40380859e-01],
                        [  1.11358643e-01,   1.11358643e-01],
                        [  8.05664062e-02,   8.05664062e-02],
                        [  6.05773926e-02,   6.05773926e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.75323486e-01,   1.75323486e-01],
                        [  2.13104248e-01,   2.13104248e-01],
                        [  2.29278564e-01,   2.29278564e-01],
                        [  2.19421387e-01,   2.19421387e-01],
                        [  1.88934326e-01,   1.88934326e-01],
                        [  1.50177002e-01,   1.50177002e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -7.14111328e-02,  -7.14111328e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  6.05468750e-02,   6.05468750e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -6.70166016e-02,  -6.70166016e-02],
                        [ -1.36474609e-01,  -1.36474609e-01],
                        [ -1.69952393e-01,  -1.69952393e-01],
                        [ -1.55822754e-01,  -1.55822754e-01],
                        [ -1.06994629e-01,  -1.06994629e-01],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -1.45050049e-01,  -1.45050049e-01],
                        [ -2.16888428e-01,  -2.16888428e-01],
                        [ -2.43774414e-01,  -2.43774414e-01],
                        [ -2.23205566e-01,  -2.23205566e-01],
                        [ -1.74896240e-01,  -1.74896240e-01],
                        [ -1.22589111e-01,  -1.22589111e-01],
                        [ -8.29162598e-02,  -8.29162598e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  1.30920410e-01,   1.30920410e-01],
                        [  1.47857666e-01,   1.47857666e-01],
                        [  1.46362305e-01,   1.46362305e-01],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  9.19189453e-02,   9.19189453e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.54327393e-01,   1.54327393e-01],
                        [  1.90460205e-01,   1.90460205e-01],
                        [  2.10906982e-01,   2.10906982e-01],
                        [  2.11486816e-01,   2.11486816e-01],
                        [  1.92108154e-01,   1.92108154e-01],
                        [  1.60308838e-01,   1.60308838e-01],
                        [  1.30615234e-01,   1.30615234e-01],
                        [  1.11816406e-01,   1.11816406e-01],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.63964844e-02,  -5.63964844e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -6.92443848e-02,  -6.92443848e-02],
                        [ -7.65686035e-02,  -7.65686035e-02],
                        [ -7.29064941e-02,  -7.29064941e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -7.42797852e-02,  -7.42797852e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  8.20007324e-02,   8.20007324e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -1.11633301e-01,  -1.11633301e-01],
                        [ -1.68273926e-01,  -1.68273926e-01],
                        [ -1.79321289e-01,  -1.79321289e-01],
                        [ -1.45690918e-01,  -1.45690918e-01],
                        [ -8.69750977e-02,  -8.69750977e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.07635498e-01,  -1.07635498e-01],
                        [ -1.89270020e-01,  -1.89270020e-01],
                        [ -2.44384766e-01,  -2.44384766e-01],
                        [ -2.56317139e-01,  -2.56317139e-01],
                        [ -2.23907471e-01,  -2.23907471e-01],
                        [ -1.66046143e-01,  -1.66046143e-01],
                        [ -1.12060547e-01,  -1.12060547e-01],
                        [ -8.07189941e-02,  -8.07189941e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  1.39465332e-01,   1.39465332e-01],
                        [  1.53137207e-01,   1.53137207e-01],
                        [  1.42120361e-01,   1.42120361e-01],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.65466309e-01,   1.65466309e-01],
                        [  2.00439453e-01,   2.00439453e-01],
                        [  2.16400146e-01,   2.16400146e-01],
                        [  2.07550049e-01,   2.07550049e-01],
                        [  1.80358887e-01,   1.80358887e-01],
                        [  1.49322510e-01,   1.49322510e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  5.55114746e-02,   5.55114746e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  3.53393555e-02,   3.53393555e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -6.91833496e-02,  -6.91833496e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -7.10449219e-02,  -7.10449219e-02],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -7.41882324e-02,  -7.41882324e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  7.76367188e-02,   7.76367188e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -8.18176270e-02,  -8.18176270e-02],
                        [ -1.45629883e-01,  -1.45629883e-01],
                        [ -1.76513672e-01,  -1.76513672e-01],
                        [ -1.60095215e-01,  -1.60095215e-01],
                        [ -1.04827881e-01,  -1.04827881e-01],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -1.33117676e-01,  -1.33117676e-01],
                        [ -2.22625732e-01,  -2.22625732e-01],
                        [ -2.68554688e-01,  -2.68554688e-01],
                        [ -2.60955811e-01,  -2.60955811e-01],
                        [ -2.13012695e-01,  -2.13012695e-01],
                        [ -1.51428223e-01,  -1.51428223e-01],
                        [ -1.03607178e-01,  -1.03607178e-01],
                        [ -8.14819336e-02,  -8.14819336e-02],
                        [ -7.49206543e-02,  -7.49206543e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  4.29992676e-02,   4.29992676e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  1.07391357e-01,   1.07391357e-01],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  1.38610840e-01,   1.38610840e-01],
                        [  1.26861572e-01,   1.26861572e-01],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  8.05053711e-02,   8.05053711e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  5.98449707e-02,   5.98449707e-02],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  1.42364502e-01,   1.42364502e-01],
                        [  1.90582275e-01,   1.90582275e-01],
                        [  2.23907471e-01,   2.23907471e-01],
                        [  2.30010986e-01,   2.30010986e-01],
                        [  2.08312988e-01,   2.08312988e-01],
                        [  1.73645020e-01,   1.73645020e-01],
                        [  1.42517090e-01,   1.42517090e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  6.06994629e-02,   6.06994629e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  4.62646484e-02,   4.62646484e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -6.78710938e-02,  -6.78710938e-02],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  8.25805664e-02,   8.25805664e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -1.30096436e-01,  -1.30096436e-01],
                        [ -1.67968750e-01,  -1.67968750e-01],
                        [ -1.67938232e-01,  -1.67938232e-01],
                        [ -1.33209229e-01,  -1.33209229e-01],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -1.32049561e-01,  -1.32049561e-01],
                        [ -2.02148438e-01,  -2.02148438e-01],
                        [ -2.34588623e-01,  -2.34588623e-01],
                        [ -2.18505859e-01,  -2.18505859e-01],
                        [ -1.69189453e-01,  -1.69189453e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -9.03015137e-02,  -9.03015137e-02],
                        [ -8.15124512e-02,  -8.15124512e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  1.11633301e-01,   1.11633301e-01],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.26556396e-01,   1.26556396e-01],
                        [  1.18041992e-01,   1.18041992e-01],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  1.10351562e-01,   1.10351562e-01],
                        [  1.59759521e-01,   1.59759521e-01],
                        [  2.04956055e-01,   2.04956055e-01],
                        [  2.32788086e-01,   2.32788086e-01],
                        [  2.34436035e-01,   2.34436035e-01],
                        [  2.09991455e-01,   2.09991455e-01],
                        [  1.68457031e-01,   1.68457031e-01],
                        [  1.23046875e-01,   1.23046875e-01],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  5.77392578e-02,   5.77392578e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -1.22222900e-01,  -1.22222900e-01],
                        [ -1.64459229e-01,  -1.64459229e-01],
                        [ -1.64520264e-01,  -1.64520264e-01],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -8.23364258e-02,  -8.23364258e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  6.62536621e-02,   6.62536621e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -1.51519775e-01,  -1.51519775e-01],
                        [ -2.16064453e-01,  -2.16064453e-01],
                        [ -2.38067627e-01,  -2.38067627e-01],
                        [ -2.14599609e-01,  -2.14599609e-01],
                        [ -1.63208008e-01,  -1.63208008e-01],
                        [ -1.12060547e-01,  -1.12060547e-01],
                        [ -8.20007324e-02,  -8.20007324e-02],
                        [ -7.30590820e-02,  -7.30590820e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  1.23413086e-01,   1.23413086e-01],
                        [  1.41326904e-01,   1.41326904e-01],
                        [  1.42578125e-01,   1.42578125e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  8.45336914e-02,   8.45336914e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.90032959e-01,   1.90032959e-01],
                        [  2.14080811e-01,   2.14080811e-01],
                        [  2.09869385e-01,   2.09869385e-01],
                        [  1.82037354e-01,   1.82037354e-01],
                        [  1.46057129e-01,   1.46057129e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  8.06274414e-02,   8.06274414e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  5.33447266e-02,   5.33447266e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.44836426e-02,  -6.44836426e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -6.74743652e-02,  -6.74743652e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -6.66809082e-02,  -6.66809082e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -1.27807617e-01,  -1.27807617e-01],
                        [ -1.76910400e-01,  -1.76910400e-01],
                        [ -1.88751221e-01,  -1.88751221e-01],
                        [ -1.59393311e-01,  -1.59393311e-01],
                        [ -1.07055664e-01,  -1.07055664e-01],
                        [ -5.77392578e-02,  -5.77392578e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  5.52673340e-02,   5.52673340e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -2.15179443e-01,  -2.15179443e-01],
                        [ -2.35900879e-01,  -2.35900879e-01],
                        [ -2.14324951e-01,  -2.14324951e-01],
                        [ -1.69097900e-01,  -1.69097900e-01],
                        [ -1.25640869e-01,  -1.25640869e-01],
                        [ -9.76562500e-02,  -9.76562500e-02],
                        [ -8.07495117e-02,  -8.07495117e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  9.58557129e-02,   9.58557129e-02],
                        [  1.31561279e-01,   1.31561279e-01],
                        [  1.50939941e-01,   1.50939941e-01],
                        [  1.51000977e-01,   1.51000977e-01],
                        [  1.36627197e-01,   1.36627197e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  8.70056152e-02,   8.70056152e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  1.62841797e-01,   1.62841797e-01],
                        [  1.96075439e-01,   1.96075439e-01],
                        [  2.05993652e-01,   2.05993652e-01],
                        [  1.90185547e-01,   1.90185547e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  9.90905762e-02,   9.90905762e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  6.14624023e-02,   6.14624023e-02],
                        [  6.05163574e-02,   6.05163574e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  4.36401367e-03,   4.36401367e-03],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -1.07543945e-01,  -1.07543945e-01],
                        [ -1.61224365e-01,  -1.61224365e-01],
                        [ -1.87377930e-01,  -1.87377930e-01],
                        [ -1.73736572e-01,  -1.73736572e-01],
                        [ -1.29821777e-01,  -1.29821777e-01],
                        [ -8.01391602e-02,  -8.01391602e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  8.49609375e-02,   8.49609375e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -1.41601562e-01,  -1.41601562e-01],
                        [ -2.03063965e-01,  -2.03063965e-01],
                        [ -2.25860596e-01,  -2.25860596e-01],
                        [ -2.05627441e-01,  -2.05627441e-01],
                        [ -1.61621094e-01,  -1.61621094e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -9.23156738e-02,  -9.23156738e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  1.22802734e-01,   1.22802734e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.24938965e-01,   1.24938965e-01],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  9.65576172e-02,   9.65576172e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  6.14624023e-02,   6.14624023e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.57196045e-01,   1.57196045e-01],
                        [  1.84875488e-01,   1.84875488e-01],
                        [  1.88262939e-01,   1.88262939e-01],
                        [  1.67449951e-01,   1.67449951e-01],
                        [  1.37725830e-01,   1.37725830e-01],
                        [  1.15570068e-01,   1.15570068e-01],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  8.67614746e-02,   8.67614746e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  4.44335938e-02,   4.44335938e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.99060059e-02,  -5.99060059e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  5.19714355e-02,   5.19714355e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -1.28540039e-01,  -1.28540039e-01],
                        [ -1.86004639e-01,  -1.86004639e-01],
                        [ -2.09289551e-01,  -2.09289551e-01],
                        [ -1.92596436e-01,  -1.92596436e-01],
                        [ -1.49108887e-01,  -1.49108887e-01],
                        [ -9.80529785e-02,  -9.80529785e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  8.51440430e-02,   8.51440430e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -1.23229980e-01,  -1.23229980e-01],
                        [ -2.00317383e-01,  -2.00317383e-01],
                        [ -2.38006592e-01,  -2.38006592e-01],
                        [ -2.27264404e-01,  -2.27264404e-01],
                        [ -1.83319092e-01,  -1.83319092e-01],
                        [ -1.31011963e-01,  -1.31011963e-01],
                        [ -8.93859863e-02,  -8.93859863e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  1.21002197e-01,   1.21002197e-01],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.24542236e-01,   1.24542236e-01],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  8.43200684e-02,   8.43200684e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  1.30645752e-01,   1.30645752e-01],
                        [  1.71234131e-01,   1.71234131e-01],
                        [  1.91894531e-01,   1.91894531e-01],
                        [  1.82434082e-01,   1.82434082e-01],
                        [  1.53686523e-01,   1.53686523e-01],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  9.45434570e-02,   9.45434570e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -1.89910889e-01,  -1.89910889e-01],
                        [ -2.14813232e-01,  -2.14813232e-01],
                        [ -1.95495605e-01,  -1.95495605e-01],
                        [ -1.51275635e-01,  -1.51275635e-01],
                        [ -1.07543945e-01,  -1.07543945e-01],
                        [ -7.58361816e-02,  -7.58361816e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  6.47583008e-02,   6.47583008e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  1.22100830e-01,   1.22100830e-01],
                        [  1.01287842e-01,   1.01287842e-01],
                        [  4.04052734e-02,   4.04052734e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -1.47491455e-01,  -1.47491455e-01],
                        [ -2.16339111e-01,  -2.16339111e-01],
                        [ -2.35992432e-01,  -2.35992432e-01],
                        [ -2.07427979e-01,  -2.07427979e-01],
                        [ -1.55578613e-01,  -1.55578613e-01],
                        [ -1.12152100e-01,  -1.12152100e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -8.54492188e-02,  -8.54492188e-02],
                        [ -7.51037598e-02,  -7.51037598e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  1.15295410e-01,   1.15295410e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.81030273e-01,   1.81030273e-01],
                        [  1.92810059e-01,   1.92810059e-01],
                        [  1.79382324e-01,   1.79382324e-01],
                        [  1.49627686e-01,   1.49627686e-01],
                        [  1.20239258e-01,   1.20239258e-01],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  5.31005859e-03,   5.31005859e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -6.63452148e-02,  -6.63452148e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -1.05682373e-01,  -1.05682373e-01],
                        [ -1.63421631e-01,  -1.63421631e-01],
                        [ -1.92932129e-01,  -1.92932129e-01],
                        [ -1.88903809e-01,  -1.88903809e-01],
                        [ -1.60186768e-01,  -1.60186768e-01],
                        [ -1.22589111e-01,  -1.22589111e-01],
                        [ -8.99963379e-02,  -8.99963379e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  1.11785889e-01,   1.11785889e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -1.33148193e-01,  -1.33148193e-01],
                        [ -2.08557129e-01,  -2.08557129e-01],
                        [ -2.37335205e-01,  -2.37335205e-01],
                        [ -2.15393066e-01,  -2.15393066e-01],
                        [ -1.62353516e-01,  -1.62353516e-01],
                        [ -1.10290527e-01,  -1.10290527e-01],
                        [ -7.93762207e-02,  -7.93762207e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  1.36932373e-01,   1.36932373e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.59179688e-01,   1.59179688e-01],
                        [  1.78436279e-01,   1.78436279e-01],
                        [  1.72515869e-01,   1.72515869e-01],
                        [  1.46911621e-01,   1.46911621e-01],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  5.77392578e-02,   5.77392578e-02],
                        [  5.24291992e-02,   5.24291992e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -7.01293945e-02,  -7.01293945e-02],
                        [ -7.27233887e-02,  -7.27233887e-02],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -1.66717529e-01,  -1.66717529e-01],
                        [ -1.93756104e-01,  -1.93756104e-01],
                        [ -1.89147949e-01,  -1.89147949e-01],
                        [ -1.58020020e-01,  -1.58020020e-01],
                        [ -1.19567871e-01,  -1.19567871e-01],
                        [ -9.05456543e-02,  -9.05456543e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  8.59985352e-02,   8.59985352e-02],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.35803223e-01,   1.35803223e-01],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  2.07519531e-02,   2.07519531e-02],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -1.91436768e-01,  -1.91436768e-01],
                        [ -2.52166748e-01,  -2.52166748e-01],
                        [ -2.53936768e-01,  -2.53936768e-01],
                        [ -2.05505371e-01,  -2.05505371e-01],
                        [ -1.38763428e-01,  -1.38763428e-01],
                        [ -8.83483887e-02,  -8.83483887e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  7.30285645e-02,   7.30285645e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.17767334e-01,   1.17767334e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.34704590e-01,   1.34704590e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  9.81750488e-02,   9.81750488e-02],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  8.01086426e-02,   8.01086426e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  1.25823975e-01,   1.25823975e-01],
                        [  1.58020020e-01,   1.58020020e-01],
                        [  1.72241211e-01,   1.72241211e-01],
                        [  1.63696289e-01,   1.63696289e-01],
                        [  1.38977051e-01,   1.38977051e-01],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  8.74023438e-02,   8.74023438e-02],
                        [  7.72399902e-02,   7.72399902e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  3.50646973e-02,   3.50646973e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -8.83483887e-02,  -8.83483887e-02],
                        [ -1.58966064e-01,  -1.58966064e-01],
                        [ -2.08618164e-01,  -2.08618164e-01],
                        [ -2.18811035e-01,  -2.18811035e-01],
                        [ -1.88842773e-01,  -1.88842773e-01],
                        [ -1.39923096e-01,  -1.39923096e-01],
                        [ -9.78088379e-02,  -9.78088379e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  1.26525879e-01,   1.26525879e-01],
                        [  1.37664795e-01,   1.37664795e-01],
                        [  1.10839844e-01,   1.10839844e-01],
                        [  4.43420410e-02,   4.43420410e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -1.43218994e-01,  -1.43218994e-01],
                        [ -2.10052490e-01,  -2.10052490e-01],
                        [ -2.29309082e-01,  -2.29309082e-01],
                        [ -2.03369141e-01,  -2.03369141e-01],
                        [ -1.53717041e-01,  -1.53717041e-01],
                        [ -1.06414795e-01,  -1.06414795e-01],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [  4.08935547e-03,   4.08935547e-03],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  1.44042969e-01,   1.44042969e-01],
                        [  1.37908936e-01,   1.37908936e-01],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  9.68017578e-02,   9.68017578e-02],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  4.19311523e-02,   4.19311523e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  1.38580322e-01,   1.38580322e-01],
                        [  1.78527832e-01,   1.78527832e-01],
                        [  1.92169189e-01,   1.92169189e-01],
                        [  1.75659180e-01,   1.75659180e-01],
                        [  1.40899658e-01,   1.40899658e-01],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -7.08923340e-02,  -7.08923340e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -1.25518799e-01,  -1.25518799e-01],
                        [ -1.87133789e-01,  -1.87133789e-01],
                        [ -2.19116211e-01,  -2.19116211e-01],
                        [ -2.10357666e-01,  -2.10357666e-01],
                        [ -1.71600342e-01,  -1.71600342e-01],
                        [ -1.27471924e-01,  -1.27471924e-01],
                        [ -9.49707031e-02,  -9.49707031e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  1.08764648e-01,   1.08764648e-01],
                        [  1.29791260e-01,   1.29791260e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.05590820e-01,   1.05590820e-01],
                        [  4.49218750e-02,   4.49218750e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -1.46209717e-01,  -1.46209717e-01],
                        [ -2.19360352e-01,  -2.19360352e-01],
                        [ -2.40966797e-01,  -2.40966797e-01],
                        [ -2.10266113e-01,  -2.10266113e-01],
                        [ -1.52313232e-01,  -1.52313232e-01],
                        [ -9.99450684e-02,  -9.99450684e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.31622314e-01,   1.31622314e-01],
                        [  1.35131836e-01,   1.35131836e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  1.15203857e-01,   1.15203857e-01],
                        [  1.15814209e-01,   1.15814209e-01],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  8.38623047e-02,   8.38623047e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  1.45843506e-01,   1.45843506e-01],
                        [  1.69616699e-01,   1.69616699e-01],
                        [  1.69494629e-01,   1.69494629e-01],
                        [  1.49719238e-01,   1.49719238e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  9.94262695e-02,   9.94262695e-02],
                        [  8.00781250e-02,   8.00781250e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -7.07397461e-02,  -7.07397461e-02],
                        [ -7.87048340e-02,  -7.87048340e-02],
                        [ -7.51037598e-02,  -7.51037598e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  7.03125000e-02,   7.03125000e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -1.49383545e-01,  -1.49383545e-01],
                        [ -2.15362549e-01,  -2.15362549e-01],
                        [ -2.40905762e-01,  -2.40905762e-01],
                        [ -2.23846436e-01,  -2.23846436e-01],
                        [ -1.79779053e-01,  -1.79779053e-01],
                        [ -1.31225586e-01,  -1.31225586e-01],
                        [ -9.50622559e-02,  -9.50622559e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.47857666e-01,   1.47857666e-01],
                        [  1.57226562e-01,   1.57226562e-01],
                        [  1.30004883e-01,   1.30004883e-01],
                        [  5.69458008e-02,   5.69458008e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -1.54602051e-01,  -1.54602051e-01],
                        [ -2.31658936e-01,  -2.31658936e-01],
                        [ -2.57049561e-01,  -2.57049561e-01],
                        [ -2.27630615e-01,  -2.27630615e-01],
                        [ -1.65313721e-01,  -1.65313721e-01],
                        [ -1.03668213e-01,  -1.03668213e-01],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.49139404e-01,   1.49139404e-01],
                        [  1.53930664e-01,   1.53930664e-01],
                        [  1.44226074e-01,   1.44226074e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  9.50622559e-02,   9.50622559e-02],
                        [  8.97827148e-02,   8.97827148e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  5.88378906e-02,   5.88378906e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  1.54174805e-01,   1.54174805e-01],
                        [  1.72607422e-01,   1.72607422e-01],
                        [  1.64337158e-01,   1.64337158e-01],
                        [  1.38824463e-01,   1.38824463e-01],
                        [  1.10900879e-01,   1.10900879e-01],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  7.28454590e-02,   7.28454590e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  5.54199219e-02,   5.54199219e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.77697754e-02,  -5.77697754e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -6.09436035e-02,  -6.09436035e-02],
                        [ -5.68237305e-02,  -5.68237305e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -8.15429688e-02,  -8.15429688e-02],
                        [ -1.62322998e-01,  -1.62322998e-01],
                        [ -2.27203369e-01,  -2.27203369e-01],
                        [ -2.53845215e-01,  -2.53845215e-01],
                        [ -2.32574463e-01,  -2.32574463e-01],
                        [ -1.79687500e-01,  -1.79687500e-01],
                        [ -1.26556396e-01,  -1.26556396e-01],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -6.55212402e-02,  -6.55212402e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  9.57031250e-02,   9.57031250e-02],
                        [  1.25793457e-01,   1.25793457e-01],
                        [  1.39282227e-01,   1.39282227e-01],
                        [  1.25122070e-01,   1.25122070e-01],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -9.14001465e-02,  -9.14001465e-02],
                        [ -1.79901123e-01,  -1.79901123e-01],
                        [ -2.29248047e-01,  -2.29248047e-01],
                        [ -2.24700928e-01,  -2.24700928e-01],
                        [ -1.80938721e-01,  -1.80938721e-01],
                        [ -1.29638672e-01,  -1.29638672e-01],
                        [ -9.41772461e-02,  -9.41772461e-02],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -5.50537109e-02,  -5.50537109e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.40899658e-01,   1.40899658e-01],
                        [  1.51367188e-01,   1.51367188e-01],
                        [  1.44958496e-01,   1.44958496e-01],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  1.52954102e-01,   1.52954102e-01],
                        [  1.69281006e-01,   1.69281006e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.30493164e-01,   1.30493164e-01],
                        [  9.60083008e-02,   9.60083008e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -1.93420410e-01,  -1.93420410e-01],
                        [ -2.32269287e-01,  -2.32269287e-01],
                        [ -2.25982666e-01,  -2.25982666e-01],
                        [ -1.87347412e-01,  -1.87347412e-01],
                        [ -1.41632080e-01,  -1.41632080e-01],
                        [ -1.07757568e-01,  -1.07757568e-01],
                        [ -8.74938965e-02,  -8.74938965e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  6.06079102e-02,   6.06079102e-02],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  1.41052246e-01,   1.41052246e-01],
                        [  1.60705566e-01,   1.60705566e-01],
                        [  1.55181885e-01,   1.55181885e-01],
                        [  1.13342285e-01,   1.13342285e-01],
                        [  3.00598145e-02,   3.00598145e-02],
                        [ -7.97424316e-02,  -7.97424316e-02],
                        [ -1.81549072e-01,  -1.81549072e-01],
                        [ -2.40631104e-01,  -2.40631104e-01],
                        [ -2.41821289e-01,  -2.41821289e-01],
                        [ -1.95281982e-01,  -1.95281982e-01],
                        [ -1.30004883e-01,  -1.30004883e-01],
                        [ -7.75756836e-02,  -7.75756836e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  1.36169434e-01,   1.36169434e-01],
                        [  1.23443604e-01,   1.23443604e-01],
                        [  1.14044189e-01,   1.14044189e-01],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.19079590e-01,   1.19079590e-01],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  8.08715820e-02,   8.08715820e-02],
                        [  1.31317139e-01,   1.31317139e-01],
                        [  1.65344238e-01,   1.65344238e-01],
                        [  1.66778564e-01,   1.66778564e-01],
                        [  1.41143799e-01,   1.41143799e-01],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  5.35888672e-02,   5.35888672e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.88696289e-02,  -2.88696289e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.29785156e-02,   5.29785156e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -1.16119385e-01,  -1.16119385e-01],
                        [ -1.82128906e-01,  -1.82128906e-01],
                        [ -2.20306396e-01,  -2.20306396e-01],
                        [ -2.17010498e-01,  -2.17010498e-01],
                        [ -1.77978516e-01,  -1.77978516e-01],
                        [ -1.28051758e-01,  -1.28051758e-01],
                        [ -9.20104980e-02,  -9.20104980e-02],
                        [ -7.60498047e-02,  -7.60498047e-02],
                        [ -7.03430176e-02,  -7.03430176e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.26098633e-01,   1.26098633e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  4.62951660e-02,   4.62951660e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -1.36718750e-01,  -1.36718750e-01],
                        [ -2.08251953e-01,  -2.08251953e-01],
                        [ -2.28820801e-01,  -2.28820801e-01],
                        [ -1.97418213e-01,  -1.97418213e-01],
                        [ -1.40319824e-01,  -1.40319824e-01],
                        [ -9.04541016e-02,  -9.04541016e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  1.23962402e-01,   1.23962402e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.50085449e-01,   1.50085449e-01],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  1.22344971e-01,   1.22344971e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.59332275e-01,   1.59332275e-01],
                        [  1.52709961e-01,   1.52709961e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  6.14013672e-02,   6.14013672e-02],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -7.43103027e-02,  -7.43103027e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -1.78100586e-01,  -1.78100586e-01],
                        [ -2.24456787e-01,  -2.24456787e-01],
                        [ -2.31414795e-01,  -2.31414795e-01],
                        [ -1.97052002e-01,  -1.97052002e-01],
                        [ -1.39007568e-01,  -1.39007568e-01],
                        [ -8.74938965e-02,  -8.74938965e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  1.13464355e-01,   1.13464355e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -1.91223145e-01,  -1.91223145e-01],
                        [ -2.21343994e-01,  -2.21343994e-01],
                        [ -1.98913574e-01,  -1.98913574e-01],
                        [ -1.43402100e-01,  -1.43402100e-01],
                        [ -8.88671875e-02,  -8.88671875e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.51153564e-01,   1.51153564e-01],
                        [  1.70684814e-01,   1.70684814e-01],
                        [  1.63940430e-01,   1.63940430e-01],
                        [  1.44744873e-01,   1.44744873e-01],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  1.18255615e-01,   1.18255615e-01],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  1.02294922e-01,   1.02294922e-01],
                        [  9.26513672e-02,   9.26513672e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  7.00378418e-02,   7.00378418e-02],
                        [  6.05468750e-02,   6.05468750e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  3.23486328e-03,   3.23486328e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.41784668e-01,   1.41784668e-01],
                        [  1.41357422e-01,   1.41357422e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  8.15124512e-02,   8.15124512e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  4.21142578e-03,   4.21142578e-03],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -7.95593262e-02,  -7.95593262e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -7.15637207e-02,  -7.15637207e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -1.24328613e-01,  -1.24328613e-01],
                        [ -1.89758301e-01,  -1.89758301e-01],
                        [ -2.27020264e-01,  -2.27020264e-01],
                        [ -2.22961426e-01,  -2.22961426e-01],
                        [ -1.84875488e-01,  -1.84875488e-01],
                        [ -1.35742188e-01,  -1.35742188e-01],
                        [ -9.82971191e-02,  -9.82971191e-02],
                        [ -7.94677734e-02,  -7.94677734e-02],
                        [ -7.05871582e-02,  -7.05871582e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  7.00378418e-02,   7.00378418e-02],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  1.22863770e-01,   1.22863770e-01],
                        [  1.32141113e-01,   1.32141113e-01],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  6.35070801e-02,   6.35070801e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -9.67407227e-02,  -9.67407227e-02],
                        [ -1.75079346e-01,  -1.75079346e-01],
                        [ -2.21343994e-01,  -2.21343994e-01],
                        [ -2.19757080e-01,  -2.19757080e-01],
                        [ -1.78253174e-01,  -1.78253174e-01],
                        [ -1.24237061e-01,  -1.24237061e-01],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  1.28906250e-01,   1.28906250e-01],
                        [  1.50665283e-01,   1.50665283e-01],
                        [  1.56005859e-01,   1.56005859e-01],
                        [  1.47796631e-01,   1.47796631e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.14410400e-01,   1.14410400e-01],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  9.94262695e-02,   9.94262695e-02],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  7.83386230e-02,   7.83386230e-02],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.38275146e-01,   1.38275146e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -1.34979248e-01,  -1.34979248e-01],
                        [ -2.01507568e-01,  -2.01507568e-01],
                        [ -2.39868164e-01,  -2.39868164e-01],
                        [ -2.36480713e-01,  -2.36480713e-01],
                        [ -1.97387695e-01,  -1.97387695e-01],
                        [ -1.46362305e-01,  -1.46362305e-01],
                        [ -1.07604980e-01,  -1.07604980e-01],
                        [ -8.70971680e-02,  -8.70971680e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  1.35589600e-01,   1.35589600e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.14196777e-01,   1.14196777e-01],
                        [  5.76477051e-02,   5.76477051e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -1.18957520e-01,  -1.18957520e-01],
                        [ -1.95953369e-01,  -1.95953369e-01],
                        [ -2.30987549e-01,  -2.30987549e-01],
                        [ -2.13623047e-01,  -2.13623047e-01],
                        [ -1.60736084e-01,  -1.60736084e-01],
                        [ -1.05895996e-01,  -1.05895996e-01],
                        [ -7.22045898e-02,  -7.22045898e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  4.03137207e-02,   4.03137207e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  1.25946045e-01,   1.25946045e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.77368164e-01,   1.77368164e-01],
                        [  1.75781250e-01,   1.75781250e-01],
                        [  1.62139893e-01,   1.62139893e-01],
                        [  1.43981934e-01,   1.43981934e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.16760254e-01,   1.16760254e-01],
                        [  1.11175537e-01,   1.11175537e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  5.19714355e-02,   5.19714355e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.56433105e-01,   1.56433105e-01],
                        [  1.64245605e-01,   1.64245605e-01],
                        [  1.47491455e-01,   1.47491455e-01],
                        [  1.19262695e-01,   1.19262695e-01],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -7.47375488e-02,  -7.47375488e-02],
                        [ -8.13293457e-02,  -8.13293457e-02],
                        [ -8.17260742e-02,  -8.17260742e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -1.30035400e-01,  -1.30035400e-01],
                        [ -2.02545166e-01,  -2.02545166e-01],
                        [ -2.47314453e-01,  -2.47314453e-01],
                        [ -2.49572754e-01,  -2.49572754e-01],
                        [ -2.14233398e-01,  -2.14233398e-01],
                        [ -1.62322998e-01,  -1.62322998e-01],
                        [ -1.15783691e-01,  -1.15783691e-01],
                        [ -8.37707520e-02,  -8.37707520e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  1.28143311e-01,   1.28143311e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.19262695e-01,   1.19262695e-01],
                        [  6.80847168e-02,   6.80847168e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.24877930e-01,  -1.24877930e-01],
                        [ -2.10723877e-01,  -2.10723877e-01],
                        [ -2.46826172e-01,  -2.46826172e-01],
                        [ -2.26196289e-01,  -2.26196289e-01],
                        [ -1.65710449e-01,  -1.65710449e-01],
                        [ -9.72595215e-02,  -9.72595215e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  1.02081299e-01,   1.02081299e-01],
                        [  1.35772705e-01,   1.35772705e-01],
                        [  1.58203125e-01,   1.58203125e-01],
                        [  1.63818359e-01,   1.63818359e-01],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  1.44897461e-01,   1.44897461e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.13220215e-01,   1.13220215e-01],
                        [  1.00036621e-01,   1.00036621e-01],
                        [  8.03833008e-02,   8.03833008e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  1.39587402e-01,   1.39587402e-01],
                        [  1.75842285e-01,   1.75842285e-01],
                        [  1.78405762e-01,   1.78405762e-01],
                        [  1.53564453e-01,   1.53564453e-01],
                        [  1.18316650e-01,   1.18316650e-01],
                        [  8.26721191e-02,   8.26721191e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -7.08007812e-02,  -7.08007812e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -1.08276367e-01,  -1.08276367e-01],
                        [ -1.72851562e-01,  -1.72851562e-01],
                        [ -2.12707520e-01,  -2.12707520e-01],
                        [ -2.13378906e-01,  -2.13378906e-01],
                        [ -1.82128906e-01,  -1.82128906e-01],
                        [ -1.43005371e-01,  -1.43005371e-01],
                        [ -1.15478516e-01,  -1.15478516e-01],
                        [ -1.01074219e-01,  -1.01074219e-01],
                        [ -9.02709961e-02,  -9.02709961e-02],
                        [ -7.60498047e-02,  -7.60498047e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  1.35620117e-01,   1.35620117e-01],
                        [  1.47918701e-01,   1.47918701e-01],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [ -8.76770020e-02,  -8.76770020e-02],
                        [ -1.71600342e-01,  -1.71600342e-01],
                        [ -2.16583252e-01,  -2.16583252e-01],
                        [ -2.13134766e-01,  -2.13134766e-01],
                        [ -1.70166016e-01,  -1.70166016e-01],
                        [ -1.12884521e-01,  -1.12884521e-01],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  4.69665527e-02,   4.69665527e-02],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.49444580e-01,   1.49444580e-01],
                        [  1.54602051e-01,   1.54602051e-01],
                        [  1.43371582e-01,   1.43371582e-01],
                        [  1.29272461e-01,   1.29272461e-01],
                        [  1.22467041e-01,   1.22467041e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  1.24298096e-01,   1.24298096e-01],
                        [  1.25640869e-01,   1.25640869e-01],
                        [  1.24908447e-01,   1.24908447e-01],
                        [  1.17218018e-01,   1.17218018e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  1.44531250e-01,   1.44531250e-01],
                        [  1.58355713e-01,   1.58355713e-01],
                        [  1.41571045e-01,   1.41571045e-01],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  5.63659668e-02,   5.63659668e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  4.08935547e-03,   4.08935547e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  6.70166016e-02,   6.70166016e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -1.29394531e-01,  -1.29394531e-01],
                        [ -2.12005615e-01,  -2.12005615e-01],
                        [ -2.58666992e-01,  -2.58666992e-01],
                        [ -2.54791260e-01,  -2.54791260e-01],
                        [ -2.14660645e-01,  -2.14660645e-01],
                        [ -1.66137695e-01,  -1.66137695e-01],
                        [ -1.29638672e-01,  -1.29638672e-01],
                        [ -1.07879639e-01,  -1.07879639e-01],
                        [ -9.10339355e-02,  -9.10339355e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  5.09033203e-02,   5.09033203e-02],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.38366699e-01,   1.38366699e-01],
                        [  1.31011963e-01,   1.31011963e-01],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [ -7.78808594e-02,  -7.78808594e-02],
                        [ -1.72149658e-01,  -1.72149658e-01],
                        [ -2.26165771e-01,  -2.26165771e-01],
                        [ -2.25769043e-01,  -2.25769043e-01],
                        [ -1.83013916e-01,  -1.83013916e-01],
                        [ -1.24053955e-01,  -1.24053955e-01],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  2.41088867e-03,   2.41088867e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  8.35266113e-02,   8.35266113e-02],
                        [  1.29852295e-01,   1.29852295e-01],
                        [  1.66473389e-01,   1.66473389e-01],
                        [  1.83349609e-01,   1.83349609e-01],
                        [  1.77947998e-01,   1.77947998e-01],
                        [  1.58416748e-01,   1.58416748e-01],
                        [  1.38488770e-01,   1.38488770e-01],
                        [  1.26617432e-01,   1.26617432e-01],
                        [  1.19476318e-01,   1.19476318e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  8.05664062e-02,   8.05664062e-02],
                        [  7.49511719e-02,   7.49511719e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  7.80334473e-02,   7.80334473e-02],
                        [  1.23626709e-01,   1.23626709e-01],
                        [  1.52679443e-01,   1.52679443e-01],
                        [  1.53228760e-01,   1.53228760e-01],
                        [  1.29241943e-01,   1.29241943e-01],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  4.91333008e-02,   4.91333008e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -8.09631348e-02,  -8.09631348e-02],
                        [ -1.56097412e-01,  -1.56097412e-01],
                        [ -2.14172363e-01,  -2.14172363e-01],
                        [ -2.34710693e-01,  -2.34710693e-01],
                        [ -2.14324951e-01,  -2.14324951e-01],
                        [ -1.71325684e-01,  -1.71325684e-01],
                        [ -1.31896973e-01,  -1.31896973e-01],
                        [ -1.09222412e-01,  -1.09222412e-01],
                        [ -9.84497070e-02,  -9.84497070e-02],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.50634766e-01,   1.50634766e-01],
                        [  1.36688232e-01,   1.36688232e-01],
                        [  8.52966309e-02,   8.52966309e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -1.16638184e-01,  -1.16638184e-01],
                        [ -2.07397461e-01,  -2.07397461e-01],
                        [ -2.45147705e-01,  -2.45147705e-01],
                        [ -2.23541260e-01,  -2.23541260e-01],
                        [ -1.63421631e-01,  -1.63421631e-01],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  5.27038574e-02,   5.27038574e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  8.13293457e-02,   8.13293457e-02],
                        [  1.24328613e-01,   1.24328613e-01],
                        [  1.56494141e-01,   1.56494141e-01],
                        [  1.68365479e-01,   1.68365479e-01],
                        [  1.62078857e-01,   1.62078857e-01],
                        [  1.49200439e-01,   1.49200439e-01],
                        [  1.38610840e-01,   1.38610840e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  7.86437988e-02,   7.86437988e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.32507324e-01,   1.32507324e-01],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  9.29260254e-02,   9.29260254e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  5.34362793e-02,   5.34362793e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -7.46459961e-02,  -7.46459961e-02],
                        [ -1.49810791e-01,  -1.49810791e-01],
                        [ -2.07580566e-01,  -2.07580566e-01],
                        [ -2.32086182e-01,  -2.32086182e-01],
                        [ -2.18841553e-01,  -2.18841553e-01],
                        [ -1.82189941e-01,  -1.82189941e-01],
                        [ -1.46697998e-01,  -1.46697998e-01],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -1.12304688e-01,  -1.12304688e-01],
                        [ -9.48486328e-02,  -9.48486328e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  5.93261719e-02,   5.93261719e-02],
                        [  8.66088867e-02,   8.66088867e-02],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.37695312e-01,   1.37695312e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  3.28674316e-02,   3.28674316e-02],
                        [ -7.33947754e-02,  -7.33947754e-02],
                        [ -1.75567627e-01,  -1.75567627e-01],
                        [ -2.31048584e-01,  -2.31048584e-01],
                        [ -2.22137451e-01,  -2.22137451e-01],
                        [ -1.70074463e-01,  -1.70074463e-01],
                        [ -1.13189697e-01,  -1.13189697e-01],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  1.45263672e-01,   1.45263672e-01],
                        [  1.63726807e-01,   1.63726807e-01],
                        [  1.65832520e-01,   1.65832520e-01],
                        [  1.61376953e-01,   1.61376953e-01],
                        [  1.58172607e-01,   1.58172607e-01],
                        [  1.56341553e-01,   1.56341553e-01],
                        [  1.51550293e-01,   1.51550293e-01],
                        [  1.39984131e-01,   1.39984131e-01],
                        [  1.20727539e-01,   1.20727539e-01],
                        [  9.62524414e-02,   9.62524414e-02],
                        [  7.20214844e-02,   7.20214844e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  1.10656738e-01,   1.10656738e-01],
                        [  1.40441895e-01,   1.40441895e-01],
                        [  1.40289307e-01,   1.40289307e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -1.05682373e-01,  -1.05682373e-01],
                        [ -1.90032959e-01,  -1.90032959e-01],
                        [ -2.42614746e-01,  -2.42614746e-01],
                        [ -2.49511719e-01,  -2.49511719e-01],
                        [ -2.19696045e-01,  -2.19696045e-01],
                        [ -1.76239014e-01,  -1.76239014e-01],
                        [ -1.39801025e-01,  -1.39801025e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -9.81445312e-02,  -9.81445312e-02],
                        [ -7.92236328e-02,  -7.92236328e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  6.28356934e-02,   6.28356934e-02],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  1.36077881e-01,   1.36077881e-01],
                        [  1.40441895e-01,   1.40441895e-01],
                        [  1.29516602e-01,   1.29516602e-01],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [ -9.59777832e-02,  -9.59777832e-02],
                        [ -1.89025879e-01,  -1.89025879e-01],
                        [ -2.34802246e-01,  -2.34802246e-01],
                        [ -2.21801758e-01,  -2.21801758e-01],
                        [ -1.68334961e-01,  -1.68334961e-01],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  8.85620117e-02,   8.85620117e-02],
                        [  1.41601562e-01,   1.41601562e-01],
                        [  1.80358887e-01,   1.80358887e-01],
                        [  1.96380615e-01,   1.96380615e-01],
                        [  1.89971924e-01,   1.89971924e-01],
                        [  1.69647217e-01,   1.69647217e-01],
                        [  1.48040771e-01,   1.48040771e-01],
                        [  1.32232666e-01,   1.32232666e-01],
                        [  1.19689941e-01,   1.19689941e-01],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  5.03540039e-02,   5.03540039e-02],
                        [  9.71374512e-02,   9.71374512e-02],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.41967773e-01,   1.41967773e-01],
                        [  1.25091553e-01,   1.25091553e-01],
                        [  9.39941406e-02,   9.39941406e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  5.30090332e-02,   5.30090332e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  4.19311523e-02,   4.19311523e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  6.96411133e-02,   6.96411133e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -9.50012207e-02,  -9.50012207e-02],
                        [ -1.80145264e-01,  -1.80145264e-01],
                        [ -2.41577148e-01,  -2.41577148e-01],
                        [ -2.58728027e-01,  -2.58728027e-01],
                        [ -2.31018066e-01,  -2.31018066e-01],
                        [ -1.79351807e-01,  -1.79351807e-01],
                        [ -1.31774902e-01,  -1.31774902e-01],
                        [ -1.03668213e-01,  -1.03668213e-01],
                        [ -9.01184082e-02,  -9.01184082e-02],
                        [ -7.83386230e-02,  -7.83386230e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  6.30187988e-02,   6.30187988e-02],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  1.15325928e-01,   1.15325928e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.32110596e-01,   1.32110596e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  7.65686035e-02,   7.65686035e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -9.97314453e-02,  -9.97314453e-02],
                        [ -1.86706543e-01,  -1.86706543e-01],
                        [ -2.22290039e-01,  -2.22290039e-01],
                        [ -1.97723389e-01,  -1.97723389e-01],
                        [ -1.39373779e-01,  -1.39373779e-01],
                        [ -8.22753906e-02,  -8.22753906e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.45629883e-01,   1.45629883e-01],
                        [  1.81427002e-01,   1.81427002e-01],
                        [  1.94183350e-01,   1.94183350e-01],
                        [  1.83044434e-01,   1.83044434e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.39648438e-01,   1.39648438e-01],
                        [  1.25091553e-01,   1.25091553e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  8.64257812e-02,   8.64257812e-02],
                        [  7.86437988e-02,   7.86437988e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  5.58471680e-02,   5.58471680e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.41204834e-01,   1.41204834e-01],
                        [  1.34033203e-01,   1.34033203e-01],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -1.17858887e-01,  -1.17858887e-01],
                        [ -1.88232422e-01,  -1.88232422e-01],
                        [ -2.32574463e-01,  -2.32574463e-01],
                        [ -2.34313965e-01,  -2.34313965e-01],
                        [ -1.98089600e-01,  -1.98089600e-01],
                        [ -1.51855469e-01,  -1.51855469e-01],
                        [ -1.22375488e-01,  -1.22375488e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -1.02905273e-01,  -1.02905273e-01],
                        [ -8.91113281e-02,  -8.91113281e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.37908936e-01,   1.37908936e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  4.10156250e-02,   4.10156250e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -2.06268311e-01,  -2.06268311e-01],
                        [ -2.14874268e-01,  -2.14874268e-01],
                        [ -1.75170898e-01,  -1.75170898e-01],
                        [ -1.15905762e-01,  -1.15905762e-01],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.77703857e-01,   1.77703857e-01],
                        [  1.90185547e-01,   1.90185547e-01],
                        [  1.80938721e-01,   1.80938721e-01],
                        [  1.60308838e-01,   1.60308838e-01],
                        [  1.41479492e-01,   1.41479492e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.13006592e-01,   1.13006592e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  9.98229980e-02,   9.98229980e-02],
                        [  1.31011963e-01,   1.31011963e-01],
                        [  1.37176514e-01,   1.37176514e-01],
                        [  1.21124268e-01,   1.21124268e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  3.23486328e-03,   3.23486328e-03],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.91528320e-02,  -6.91528320e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  5.58471680e-02,   5.58471680e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  7.33032227e-02,   7.33032227e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -1.56219482e-01,  -1.56219482e-01],
                        [ -2.22503662e-01,  -2.22503662e-01],
                        [ -2.48199463e-01,  -2.48199463e-01],
                        [ -2.28576660e-01,  -2.28576660e-01],
                        [ -1.83044434e-01,  -1.83044434e-01],
                        [ -1.39251709e-01,  -1.39251709e-01],
                        [ -1.11907959e-01,  -1.11907959e-01],
                        [ -9.58557129e-02,  -9.58557129e-02],
                        [ -7.97424316e-02,  -7.97424316e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.35223389e-01,   1.35223389e-01],
                        [  1.31195068e-01,   1.31195068e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  4.71191406e-02,   4.71191406e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -1.32629395e-01,  -1.32629395e-01],
                        [ -2.00225830e-01,  -2.00225830e-01],
                        [ -2.15637207e-01,  -2.15637207e-01],
                        [ -1.80938721e-01,  -1.80938721e-01],
                        [ -1.25579834e-01,  -1.25579834e-01],
                        [ -8.26416016e-02,  -8.26416016e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  5.41076660e-02,   5.41076660e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.61102295e-01,   1.61102295e-01],
                        [  1.80145264e-01,   1.80145264e-01],
                        [  1.78253174e-01,   1.78253174e-01],
                        [  1.61712646e-01,   1.61712646e-01],
                        [  1.44104004e-01,   1.44104004e-01],
                        [  1.33636475e-01,   1.33636475e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  1.17340088e-01,   1.17340088e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.44104004e-01,   1.44104004e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  9.29565430e-02,   9.29565430e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  7.84301758e-03,   7.84301758e-03],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -1.36840820e-01,  -1.36840820e-01],
                        [ -2.09625244e-01,  -2.09625244e-01],
                        [ -2.56591797e-01,  -2.56591797e-01],
                        [ -2.60711670e-01,  -2.60711670e-01],
                        [ -2.23602295e-01,  -2.23602295e-01],
                        [ -1.70410156e-01,  -1.70410156e-01],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -1.10870361e-01,  -1.10870361e-01],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -8.32519531e-02,  -8.32519531e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  1.11877441e-01,   1.11877441e-01],
                        [  1.21063232e-01,   1.21063232e-01],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -1.32995605e-01,  -1.32995605e-01],
                        [ -1.93603516e-01,  -1.93603516e-01],
                        [ -2.05261230e-01,  -2.05261230e-01],
                        [ -1.70288086e-01,  -1.70288086e-01],
                        [ -1.16333008e-01,  -1.16333008e-01],
                        [ -7.36999512e-02,  -7.36999512e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  1.83197021e-01,   1.83197021e-01],
                        [  1.90917969e-01,   1.90917969e-01],
                        [  1.73889160e-01,   1.73889160e-01],
                        [  1.48803711e-01,   1.48803711e-01],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  1.19812012e-01,   1.19812012e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  1.25366211e-01,   1.25366211e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.07482910e-01,   1.07482910e-01],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  5.82885742e-02,   5.82885742e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -1.22039795e-01,  -1.22039795e-01],
                        [ -1.97113037e-01,  -1.97113037e-01],
                        [ -2.49023438e-01,  -2.49023438e-01],
                        [ -2.59155273e-01,  -2.59155273e-01],
                        [ -2.26715088e-01,  -2.26715088e-01],
                        [ -1.73370361e-01,  -1.73370361e-01],
                        [ -1.27655029e-01,  -1.27655029e-01],
                        [ -1.03759766e-01,  -1.03759766e-01],
                        [ -9.46350098e-02,  -9.46350098e-02],
                        [ -8.49914551e-02,  -8.49914551e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  8.15124512e-02,   8.15124512e-02],
                        [  1.02630615e-01,   1.02630615e-01],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.33850098e-01,   1.33850098e-01],
                        [  1.29913330e-01,   1.29913330e-01],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  4.43420410e-02,   4.43420410e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -1.36291504e-01,  -1.36291504e-01],
                        [ -2.02056885e-01,  -2.02056885e-01],
                        [ -2.14111328e-01,  -2.14111328e-01],
                        [ -1.75445557e-01,  -1.75445557e-01],
                        [ -1.14562988e-01,  -1.14562988e-01],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  1.26007080e-01,   1.26007080e-01],
                        [  1.54418945e-01,   1.54418945e-01],
                        [  1.68975830e-01,   1.68975830e-01],
                        [  1.71478271e-01,   1.71478271e-01],
                        [  1.68731689e-01,   1.68731689e-01],
                        [  1.66168213e-01,   1.66168213e-01],
                        [  1.62689209e-01,   1.62689209e-01],
                        [  1.52832031e-01,   1.52832031e-01],
                        [  1.34155273e-01,   1.34155273e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  7.03125000e-02,   7.03125000e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  8.71276855e-02,   8.71276855e-02],
                        [  1.32995605e-01,   1.32995605e-01],
                        [  1.49932861e-01,   1.49932861e-01],
                        [  1.34063721e-01,   1.34063721e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -9.37805176e-02,  -9.37805176e-02],
                        [ -1.70196533e-01,  -1.70196533e-01],
                        [ -2.33978271e-01,  -2.33978271e-01],
                        [ -2.63519287e-01,  -2.63519287e-01],
                        [ -2.49389648e-01,  -2.49389648e-01],
                        [ -2.02056885e-01,  -2.02056885e-01],
                        [ -1.47125244e-01,  -1.47125244e-01],
                        [ -1.10717773e-01,  -1.10717773e-01],
                        [ -1.01043701e-01,  -1.01043701e-01],
                        [ -1.03057861e-01,  -1.03057861e-01],
                        [ -9.62524414e-02,  -9.62524414e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  6.30187988e-02,   6.30187988e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  1.33483887e-01,   1.33483887e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -1.39617920e-01,  -1.39617920e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -2.16094971e-01,  -2.16094971e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.11968994e-01,  -1.11968994e-01],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.43249512e-01,   1.43249512e-01],
                        [  1.75384521e-01,   1.75384521e-01],
                        [  1.84387207e-01,   1.84387207e-01],
                        [  1.73583984e-01,   1.73583984e-01],
                        [  1.56616211e-01,   1.56616211e-01],
                        [  1.43341064e-01,   1.43341064e-01],
                        [  1.34094238e-01,   1.34094238e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -5.95397949e-02,  -5.95397949e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.38092041e-01,   1.38092041e-01],
                        [  1.34490967e-01,   1.34490967e-01],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  8.57849121e-02,   8.57849121e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  2.92968750e-03,   2.92968750e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -1.53656006e-01,  -1.53656006e-01],
                        [ -2.29766846e-01,  -2.29766846e-01],
                        [ -2.65716553e-01,  -2.65716553e-01],
                        [ -2.54821777e-01,  -2.54821777e-01],
                        [ -2.10754395e-01,  -2.10754395e-01],
                        [ -1.57073975e-01,  -1.57073975e-01],
                        [ -1.14593506e-01,  -1.14593506e-01],
                        [ -8.99963379e-02,  -8.99963379e-02],
                        [ -7.75146484e-02,  -7.75146484e-02],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -6.57043457e-02,  -6.57043457e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.15447998e-01,   1.15447998e-01],
                        [  1.20269775e-01,   1.20269775e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  6.76879883e-02,   6.76879883e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -9.88159180e-02,  -9.88159180e-02],
                        [ -1.76239014e-01,  -1.76239014e-01],
                        [ -2.08160400e-01,  -2.08160400e-01],
                        [ -1.89117432e-01,  -1.89117432e-01],
                        [ -1.38610840e-01,  -1.38610840e-01],
                        [ -8.48999023e-02,  -8.48999023e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.79656982e-01,   1.79656982e-01],
                        [  1.82647705e-01,   1.82647705e-01],
                        [  1.73583984e-01,   1.73583984e-01],
                        [  1.59332275e-01,   1.59332275e-01],
                        [  1.45782471e-01,   1.45782471e-01],
                        [  1.35314941e-01,   1.35314941e-01],
                        [  1.26220703e-01,   1.26220703e-01],
                        [  1.15570068e-01,   1.15570068e-01],
                        [  1.03057861e-01,   1.03057861e-01],
                        [  8.90197754e-02,   8.90197754e-02],
                        [  7.16247559e-02,   7.16247559e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  1.11389160e-02,   1.11389160e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  8.35876465e-02,   8.35876465e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  5.08117676e-02,   5.08117676e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.06597900e-01,  -1.06597900e-01],
                        [ -1.93267822e-01,  -1.93267822e-01],
                        [ -2.56134033e-01,  -2.56134033e-01],
                        [ -2.75024414e-01,  -2.75024414e-01],
                        [ -2.48077393e-01,  -2.48077393e-01],
                        [ -1.96502686e-01,  -1.96502686e-01],
                        [ -1.49261475e-01,  -1.49261475e-01],
                        [ -1.19384766e-01,  -1.19384766e-01],
                        [ -1.00555420e-01,  -1.00555420e-01],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -6.66809082e-02,  -6.66809082e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  1.14379883e-01,   1.14379883e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.21215820e-01,   1.21215820e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  6.68640137e-02,   6.68640137e-02],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [ -8.80126953e-02,  -8.80126953e-02],
                        [ -1.68151855e-01,  -1.68151855e-01],
                        [ -2.09533691e-01,  -2.09533691e-01],
                        [ -1.97326660e-01,  -1.97326660e-01],
                        [ -1.46148682e-01,  -1.46148682e-01],
                        [ -9.11865234e-02,  -9.11865234e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  5.55725098e-02,   5.55725098e-02],
                        [  9.62524414e-02,   9.62524414e-02],
                        [  1.36779785e-01,   1.36779785e-01],
                        [  1.65191650e-01,   1.65191650e-01],
                        [  1.75872803e-01,   1.75872803e-01],
                        [  1.71234131e-01,   1.71234131e-01],
                        [  1.58569336e-01,   1.58569336e-01],
                        [  1.46057129e-01,   1.46057129e-01],
                        [  1.38183594e-01,   1.38183594e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.22467041e-01,   1.22467041e-01],
                        [  1.12670898e-01,   1.12670898e-01],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  9.01794434e-02,   9.01794434e-02],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  3.18908691e-02,   3.18908691e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -6.93664551e-02,  -6.93664551e-02],
                        [ -1.55181885e-01,  -1.55181885e-01],
                        [ -2.31079102e-01,  -2.31079102e-01],
                        [ -2.70507812e-01,  -2.70507812e-01],
                        [ -2.64038086e-01,  -2.64038086e-01],
                        [ -2.23388672e-01,  -2.23388672e-01],
                        [ -1.73034668e-01,  -1.73034668e-01],
                        [ -1.35894775e-01,  -1.35894775e-01],
                        [ -1.17828369e-01,  -1.17828369e-01],
                        [ -1.05163574e-01,  -1.05163574e-01],
                        [ -8.34655762e-02,  -8.34655762e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  7.78198242e-02,   7.78198242e-02],
                        [  8.97216797e-02,   8.97216797e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  8.28857422e-02,   8.28857422e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -1.34948730e-01,  -1.34948730e-01],
                        [ -1.84600830e-01,  -1.84600830e-01],
                        [ -1.90032959e-01,  -1.90032959e-01],
                        [ -1.58142090e-01,  -1.58142090e-01],
                        [ -1.13098145e-01,  -1.13098145e-01],
                        [ -7.65380859e-02,  -7.65380859e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.61682129e-01,   1.61682129e-01],
                        [  1.80358887e-01,   1.80358887e-01],
                        [  1.78924561e-01,   1.78924561e-01],
                        [  1.61071777e-01,   1.61071777e-01],
                        [  1.40686035e-01,   1.40686035e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  7.05566406e-02,   7.05566406e-02],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  7.32116699e-02,   7.32116699e-02],
                        [  5.25817871e-02,   5.25817871e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -1.58813477e-01,  -1.58813477e-01],
                        [ -2.30621338e-01,  -2.30621338e-01],
                        [ -2.66265869e-01,  -2.66265869e-01],
                        [ -2.51556396e-01,  -2.51556396e-01],
                        [ -2.00378418e-01,  -2.00378418e-01],
                        [ -1.45477295e-01,  -1.45477295e-01],
                        [ -1.11846924e-01,  -1.11846924e-01],
                        [ -1.00616455e-01,  -1.00616455e-01],
                        [ -9.70458984e-02,  -9.70458984e-02],
                        [ -8.77990723e-02,  -8.77990723e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  1.11938477e-01,   1.11938477e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  7.29064941e-02,   7.29064941e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -1.00616455e-01,  -1.00616455e-01],
                        [ -1.74804688e-01,  -1.74804688e-01],
                        [ -2.02850342e-01,  -2.02850342e-01],
                        [ -1.79473877e-01,  -1.79473877e-01],
                        [ -1.25793457e-01,  -1.25793457e-01],
                        [ -7.47985840e-02,  -7.47985840e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.52679443e-01,   1.52679443e-01],
                        [  1.81793213e-01,   1.81793213e-01],
                        [  1.84112549e-01,   1.84112549e-01],
                        [  1.66107178e-01,   1.66107178e-01],
                        [  1.44256592e-01,   1.44256592e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.29974365e-01,   1.29974365e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.25579834e-01,   1.25579834e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.12152100e-01,   1.12152100e-01],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  5.85632324e-02,   5.85632324e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -1.56280518e-01,  -1.56280518e-01],
                        [ -2.22473145e-01,  -2.22473145e-01],
                        [ -2.58483887e-01,  -2.58483887e-01],
                        [ -2.50793457e-01,  -2.50793457e-01],
                        [ -2.06115723e-01,  -2.06115723e-01],
                        [ -1.53381348e-01,  -1.53381348e-01],
                        [ -1.20483398e-01,  -1.20483398e-01],
                        [ -1.08795166e-01,  -1.08795166e-01],
                        [ -1.00585938e-01,  -1.00585938e-01],
                        [ -8.68225098e-02,  -8.68225098e-02],
                        [ -7.39135742e-02,  -7.39135742e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  8.03527832e-02,   8.03527832e-02],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.30004883e-01,   1.30004883e-01],
                        [  1.13677979e-01,   1.13677979e-01],
                        [  6.82678223e-02,   6.82678223e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.01104736e-01,  -1.01104736e-01],
                        [ -1.78863525e-01,  -1.78863525e-01],
                        [ -2.07763672e-01,  -2.07763672e-01],
                        [ -1.79443359e-01,  -1.79443359e-01],
                        [ -1.19201660e-01,  -1.19201660e-01],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  1.43707275e-01,   1.43707275e-01],
                        [  1.64367676e-01,   1.64367676e-01],
                        [  1.65893555e-01,   1.65893555e-01],
                        [  1.55212402e-01,   1.55212402e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.40441895e-01,   1.40441895e-01],
                        [  1.36810303e-01,   1.36810303e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  1.16577148e-01,   1.16577148e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  9.54895020e-02,   9.54895020e-02],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  9.11865234e-02,   9.11865234e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -8.41369629e-02,  -8.41369629e-02],
                        [ -1.63696289e-01,  -1.63696289e-01],
                        [ -2.30651855e-01,  -2.30651855e-01],
                        [ -2.59643555e-01,  -2.59643555e-01],
                        [ -2.39898682e-01,  -2.39898682e-01],
                        [ -1.86340332e-01,  -1.86340332e-01],
                        [ -1.32629395e-01,  -1.32629395e-01],
                        [ -1.05590820e-01,  -1.05590820e-01],
                        [ -1.04370117e-01,  -1.04370117e-01],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -8.93554688e-02,  -8.93554688e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  7.18383789e-02,   7.18383789e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  8.86535645e-02,   8.86535645e-02],
                        [  1.00830078e-01,   1.00830078e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  9.95788574e-02,   9.95788574e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.03424072e-01,  -1.03424072e-01],
                        [ -1.62200928e-01,  -1.62200928e-01],
                        [ -1.74316406e-01,  -1.74316406e-01],
                        [ -1.42852783e-01,  -1.42852783e-01],
                        [ -9.52148438e-02,  -9.52148438e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  1.58233643e-01,   1.58233643e-01],
                        [  1.79138184e-01,   1.79138184e-01],
                        [  1.74530029e-01,   1.74530029e-01],
                        [  1.53350830e-01,   1.53350830e-01],
                        [  1.30798340e-01,   1.30798340e-01],
                        [  1.19445801e-01,   1.19445801e-01],
                        [  1.20880127e-01,   1.20880127e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  1.19842529e-01,   1.19842529e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  9.92431641e-02,   9.92431641e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  8.30078125e-02,   8.30078125e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  9.04235840e-02,   9.04235840e-02],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  9.94262695e-02,   9.94262695e-02],
                        [  7.00683594e-02,   7.00683594e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -1.44866943e-01,  -1.44866943e-01],
                        [ -2.25921631e-01,  -2.25921631e-01],
                        [ -2.75451660e-01,  -2.75451660e-01],
                        [ -2.76519775e-01,  -2.76519775e-01],
                        [ -2.37030029e-01,  -2.37030029e-01],
                        [ -1.84967041e-01,  -1.84967041e-01],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -1.18194580e-01,  -1.18194580e-01],
                        [ -9.72595215e-02,  -9.72595215e-02],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -1.20941162e-01,  -1.20941162e-01],
                        [ -1.66198730e-01,  -1.66198730e-01],
                        [ -1.63848877e-01,  -1.63848877e-01],
                        [ -1.29058838e-01,  -1.29058838e-01],
                        [ -9.07897949e-02,  -9.07897949e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  1.62902832e-01,   1.62902832e-01],
                        [  1.91406250e-01,   1.91406250e-01],
                        [  1.98272705e-01,   1.98272705e-01],
                        [  1.81518555e-01,   1.81518555e-01],
                        [  1.48590088e-01,   1.48590088e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.02569580e-01,   1.02569580e-01],
                        [  8.74023438e-02,   8.74023438e-02],
                        [  7.21435547e-02,   7.21435547e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -6.87866211e-02,  -6.87866211e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  1.14624023e-01,   1.14624023e-01],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -1.18896484e-01,  -1.18896484e-01],
                        [ -2.01416016e-01,  -2.01416016e-01],
                        [ -2.60498047e-01,  -2.60498047e-01],
                        [ -2.75970459e-01,  -2.75970459e-01],
                        [ -2.47406006e-01,  -2.47406006e-01],
                        [ -1.94610596e-01,  -1.94610596e-01],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -1.12792969e-01,  -1.12792969e-01],
                        [ -9.78393555e-02,  -9.78393555e-02],
                        [ -8.84094238e-02,  -8.84094238e-02],
                        [ -7.90100098e-02,  -7.90100098e-02],
                        [ -7.18078613e-02,  -7.18078613e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  1.17004395e-01,   1.17004395e-01],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.00860596e-01,  -1.00860596e-01],
                        [ -1.55883789e-01,  -1.55883789e-01],
                        [ -1.70043945e-01,  -1.70043945e-01],
                        [ -1.43310547e-01,  -1.43310547e-01],
                        [ -9.65881348e-02,  -9.65881348e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  1.42456055e-01,   1.42456055e-01],
                        [  1.70257568e-01,   1.70257568e-01],
                        [  1.75262451e-01,   1.75262451e-01],
                        [  1.60247803e-01,   1.60247803e-01],
                        [  1.33911133e-01,   1.33911133e-01],
                        [  1.08734131e-01,   1.08734131e-01],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  9.36279297e-02,   9.36279297e-02],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  1.08123779e-01,   1.08123779e-01],
                        [  1.15905762e-01,   1.15905762e-01],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  5.21850586e-03,   5.21850586e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -6.16455078e-02,  -6.16455078e-02],
                        [ -1.42303467e-01,  -1.42303467e-01],
                        [ -2.17437744e-01,  -2.17437744e-01],
                        [ -2.65441895e-01,  -2.65441895e-01],
                        [ -2.70843506e-01,  -2.70843506e-01],
                        [ -2.35443115e-01,  -2.35443115e-01],
                        [ -1.80084229e-01,  -1.80084229e-01],
                        [ -1.31042480e-01,  -1.31042480e-01],
                        [ -1.03424072e-01,  -1.03424072e-01],
                        [ -9.51538086e-02,  -9.51538086e-02],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -8.83178711e-02,  -8.83178711e-02],
                        [ -7.72094727e-02,  -7.72094727e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  6.84814453e-02,   6.84814453e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  1.21215820e-01,   1.21215820e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -1.22375488e-01,  -1.22375488e-01],
                        [ -1.71234131e-01,  -1.71234131e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -9.44824219e-02,  -9.44824219e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  1.19934082e-01,   1.19934082e-01],
                        [  1.72058105e-01,   1.72058105e-01],
                        [  2.03155518e-01,   2.03155518e-01],
                        [  2.01202393e-01,   2.01202393e-01],
                        [  1.70806885e-01,   1.70806885e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  1.05377197e-01,   1.05377197e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  8.64868164e-02,   8.64868164e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  1.19537354e-01,   1.19537354e-01],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  4.78515625e-02,   4.78515625e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -1.36962891e-01,  -1.36962891e-01],
                        [ -2.11242676e-01,  -2.11242676e-01],
                        [ -2.58361816e-01,  -2.58361816e-01],
                        [ -2.64038086e-01,  -2.64038086e-01],
                        [ -2.34558105e-01,  -2.34558105e-01],
                        [ -1.91619873e-01,  -1.91619873e-01],
                        [ -1.53503418e-01,  -1.53503418e-01],
                        [ -1.23840332e-01,  -1.23840332e-01],
                        [ -9.97009277e-02,  -9.97009277e-02],
                        [ -8.10852051e-02,  -8.10852051e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -6.06994629e-02,  -6.07299805e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  7.39746094e-02,   7.39746094e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  9.79919434e-02,   9.79919434e-02],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  1.17553711e-01,   1.17553711e-01],
                        [  1.10321045e-01,   1.10321045e-01],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -7.74841309e-02,  -7.74841309e-02],
                        [ -1.50329590e-01,  -1.50329590e-01],
                        [ -1.81060791e-01,  -1.81060791e-01],
                        [ -1.64398193e-01,  -1.64398193e-01],
                        [ -1.21765137e-01,  -1.21765137e-01],
                        [ -8.28247070e-02,  -8.28247070e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  1.13250732e-01,   1.13250732e-01],
                        [  1.62322998e-01,   1.62322998e-01],
                        [  1.92871094e-01,   1.92871094e-01],
                        [  1.97174072e-01,   1.97174072e-01],
                        [  1.78588867e-01,   1.78558350e-01],
                        [  1.48376465e-01,   1.48376465e-01],
                        [  1.16760254e-01,   1.16790771e-01],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  7.04956055e-02,   7.04650879e-02],
                        [  6.19506836e-02,   6.19201660e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  1.00830078e-01,   1.00830078e-01],
                        [  9.34143066e-02,   9.34143066e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  6.11572266e-02,   6.11877441e-02],
                        [  4.43725586e-02,   4.43420410e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  1.81274414e-02,   1.81579590e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [  8.05664062e-03,   8.02612305e-03],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  9.97619629e-02,   9.97924805e-02],
                        [  1.17675781e-01,   1.17675781e-01],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  1.46484375e-03,   1.46484375e-03],
                        [  4.42504883e-03,   4.42504883e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -1.93176270e-02,  -1.92871094e-02],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -2.86254883e-02,  -2.86560059e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  2.81982422e-02,   2.81677246e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  4.46472168e-02,   4.46472168e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [ -2.68859863e-02,  -2.69165039e-02],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -1.67083740e-01,  -1.67083740e-01],
                        [ -2.26654053e-01,  -2.26654053e-01],
                        [ -2.47924805e-01,  -2.47955322e-01],
                        [ -2.30682373e-01,  -2.30682373e-01],
                        [ -1.93969727e-01,  -1.93969727e-01],
                        [ -1.57440186e-01,  -1.57440186e-01],
                        [ -1.30401611e-01,  -1.30401611e-01],
                        [ -1.12213135e-01,  -1.12213135e-01],
                        [ -9.66796875e-02,  -9.66796875e-02],
                        [ -7.94677734e-02,  -7.94677734e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -3.32031250e-02,  -3.32336426e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.98364258e-03,  -1.95312500e-03],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  7.94372559e-02,   7.94677734e-02],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  1.15234375e-01,   1.15234375e-01],
                        [  1.31439209e-01,   1.31439209e-01],
                        [  1.30340576e-01,   1.30371094e-01],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [ -8.12683105e-02,  -8.12683105e-02],
                        [ -1.62506104e-01,  -1.62506104e-01],
                        [ -1.98944092e-01,  -1.98944092e-01],
                        [ -1.84936523e-01,  -1.84936523e-01],
                        [ -1.42791748e-01,  -1.42791748e-01],
                        [ -1.00402832e-01,  -1.00402832e-01],
                        [ -7.00988770e-02,  -7.00683594e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.59594727e-02,  -4.59289551e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  1.52160645e-01,   1.52160645e-01],
                        [  1.72241211e-01,   1.72241211e-01],
                        [  1.67907715e-01,   1.67877197e-01],
                        [  1.46331787e-01,   1.46331787e-01],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  9.60388184e-02,   9.60388184e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  9.05761719e-02,   9.05761719e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  9.02709961e-02,   9.02404785e-02],
                        [  7.93762207e-02,   7.93457031e-02],
                        [  7.16247559e-02,   7.16247559e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  5.78002930e-02,   5.77697754e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  3.88183594e-02,   3.88488770e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  2.76489258e-02,   2.76794434e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -1.89208984e-02,  -1.89514160e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.90625000e-02,  -3.90319824e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.04663086e-02,  -4.04968262e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.60107422e-02,  -3.59802246e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.06799316e-02,  -4.07104492e-02],
                        [ -4.21752930e-02,  -4.22058105e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [  1.00708008e-03,   1.03759766e-03],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  4.69055176e-02,   4.68750000e-02],
                        [  5.69458008e-02,   5.69152832e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  1.29089355e-02,   1.29394531e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -1.22741699e-01,  -1.22741699e-01],
                        [ -1.97082520e-01,  -1.97113037e-01],
                        [ -2.47833252e-01,  -2.47833252e-01],
                        [ -2.62207031e-01,  -2.62176514e-01],
                        [ -2.43682861e-01,  -2.43682861e-01],
                        [ -2.07733154e-01,  -2.07794189e-01],
                        [ -1.69769287e-01,  -1.69799805e-01],
                        [ -1.36505127e-01,  -1.36474609e-01],
                        [ -1.08886719e-01,  -1.08856201e-01],
                        [ -8.85009766e-02,  -8.85314941e-02],
                        [ -7.72399902e-02,  -7.72705078e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -5.19104004e-02,  -5.18798828e-02],
                        [ -3.57971191e-02,  -3.57666016e-02],
                        [ -1.80053711e-02,  -1.80358887e-02],
                        [  7.62939453e-04,   7.01904297e-04],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  2.58483887e-02,   2.59094238e-02],
                        [  2.94799805e-02,   2.95104980e-02],
                        [  3.31726074e-02,   3.31420898e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  5.47485352e-02,   5.47790527e-02],
                        [  7.68127441e-02,   7.68432617e-02],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  1.42425537e-01,   1.42425537e-01],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  8.51135254e-02,   8.51440430e-02],
                        [  1.02539062e-02,   1.02844238e-02],
                        [ -7.98950195e-02,  -7.99255371e-02],
                        [ -1.57958984e-01,  -1.58020020e-01],
                        [ -1.95434570e-01,  -1.95434570e-01],
                        [ -1.82067871e-01,  -1.82006836e-01],
                        [ -1.35314941e-01,  -1.35314941e-01],
                        [ -8.75244141e-02,  -8.75854492e-02],
                        [ -6.28662109e-02,  -6.28967285e-02],
                        [ -6.27746582e-02,  -6.27441406e-02],
                        [ -7.07092285e-02,  -7.06787109e-02],
                        [ -7.13806152e-02,  -7.14111328e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -1.71203613e-02,  -1.70898438e-02],
                        [  3.13415527e-02,   3.13720703e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  1.49536133e-01,   1.49505615e-01],
                        [  1.83258057e-01,   1.83227539e-01],
                        [  1.88995361e-01,   1.89025879e-01],
                        [  1.72607422e-01,   1.72668457e-01],
                        [  1.47094727e-01,   1.47064209e-01],
                        [  1.23535156e-01,   1.23474121e-01],
                        [  1.05316162e-01,   1.05346680e-01],
                        [  9.18273926e-02,   9.18579102e-02],
                        [  8.41979980e-02,   8.41979980e-02],
                        [  8.43811035e-02,   8.43505859e-02],
                        [  8.97216797e-02,   8.96911621e-02],
                        [  9.34448242e-02,   9.34753418e-02],
                        [  9.10339355e-02,   9.10644531e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  7.77893066e-02,   7.77893066e-02],
                        [  7.32421875e-02,   7.32116699e-02],
                        [  6.67724609e-02,   6.67419434e-02],
                        [  5.67932129e-02,   5.68237305e-02],
                        [  4.71496582e-02,   4.72106934e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  3.12805176e-02,   3.11889648e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  5.15747070e-03,   5.24902344e-03],
                        [ -1.98364258e-03,  -1.92260742e-03],
                        [ -7.96508789e-03,  -8.02612305e-03],
                        [ -1.81884766e-02,  -1.82495117e-02],
                        [ -2.89611816e-02,  -2.89306641e-02],
                        [ -3.43017578e-02,  -3.42407227e-02],
                        [ -3.17687988e-02,  -3.17993164e-02],
                        [ -1.75781250e-02,  -1.76086426e-02],
                        [  1.29699707e-02,   1.29394531e-02],
                        [  5.58471680e-02,   5.58471680e-02],
                        [  9.51843262e-02,   9.52148438e-02],
                        [  1.12915039e-01,   1.12945557e-01],
                        [  1.03088379e-01,   1.03057861e-01],
                        [  7.69348145e-02,   7.68737793e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  3.86047363e-02,   3.86657715e-02],
                        [  3.16772461e-02,   3.17077637e-02],
                        [  2.51770020e-02,   2.51159668e-02],
                        [  1.98364258e-02,   1.98059082e-02],
                        [  1.90734863e-02,   1.91345215e-02],
                        [  2.04467773e-02,   2.05383301e-02],
                        [  1.84936523e-02,   1.84631348e-02],
                        [  1.20849609e-02,   1.19934082e-02],
                        [  4.30297852e-03,   4.27246094e-03],
                        [ -2.83813477e-03,  -2.77709961e-03],
                        [ -9.70458984e-03,  -9.67407227e-03],
                        [ -1.73339844e-02,  -1.73645020e-02],
                        [ -2.60620117e-02,  -2.60925293e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -4.13208008e-02,  -4.12902832e-02],
                        [ -4.28161621e-02,  -4.27856445e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.15246582e-02,  -3.15551758e-02],
                        [ -2.56042480e-02,  -2.56347656e-02],
                        [ -2.21557617e-02,  -2.20947266e-02],
                        [ -1.95617676e-02,  -1.95312500e-02],
                        [ -1.92260742e-02,  -1.92871094e-02],
                        [ -2.46276855e-02,  -2.46887207e-02],
                        [ -3.44543457e-02,  -3.44238281e-02],
                        [ -4.11376953e-02,  -4.11071777e-02],
                        [ -3.78723145e-02,  -3.79028320e-02],
                        [ -2.50854492e-02,  -2.51159668e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  1.27563477e-02,   1.27868652e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  5.45349121e-02,   5.45043945e-02],
                        [  6.82373047e-02,   6.82678223e-02],
                        [  6.91528320e-02,   6.91833496e-02],
                        [  4.90722656e-02,   4.90112305e-02],
                        [  1.98364258e-03,   1.95312500e-03],
                        [ -7.04345703e-02,  -7.03735352e-02],
                        [ -1.55120850e-01,  -1.55090332e-01],
                        [ -2.28393555e-01,  -2.28485107e-01],
                        [ -2.66998291e-01,  -2.67059326e-01],
                        [ -2.62878418e-01,  -2.62817383e-01],
                        [ -2.27630615e-01,  -2.27569580e-01],
                        [ -1.83013916e-01,  -1.83044434e-01],
                        [ -1.46209717e-01,  -1.46270752e-01],
                        [ -1.21795654e-01,  -1.21795654e-01],
                        [ -1.05255127e-01,  -1.05224609e-01],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -7.33032227e-02,  -7.33337402e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -4.13818359e-02,  -4.14123535e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -1.84631348e-02,  -1.84326172e-02],
                        [  2.50244141e-03,   2.53295898e-03],
                        [  2.76184082e-02,   2.75878906e-02],
                        [  4.41894531e-02,   4.41284180e-02],
                        [  4.69360352e-02,   4.69665527e-02],
                        [  4.32434082e-02,   4.33044434e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  4.48608398e-02,   4.47998047e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  6.51550293e-02,   6.52160645e-02],
                        [  8.60595703e-02,   8.60900879e-02],
                        [  1.10046387e-01,   1.10015869e-01],
                        [  1.28051758e-01,   1.28021240e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  9.86938477e-02,   9.87548828e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [ -5.06896973e-02,  -5.07202148e-02],
                        [ -1.27777100e-01,  -1.27807617e-01],
                        [ -1.69952393e-01,  -1.69891357e-01],
                        [ -1.69281006e-01,  -1.69250488e-01],
                        [ -1.40472412e-01,  -1.40502930e-01],
                        [ -1.07543945e-01,  -1.07604980e-01],
                        [ -8.56933594e-02,  -8.56933594e-02],
                        [ -7.49206543e-02,  -7.48596191e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -6.31713867e-02,  -6.32324219e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -4.22363281e-02,  -4.21752930e-02],
                        [ -1.24816895e-02,  -1.24206543e-02],
                        [  3.36303711e-02,   3.35693359e-02],
                        [  8.56018066e-02,   8.55407715e-02],
                        [  1.29425049e-01,   1.29486084e-01],
                        [  1.56890869e-01,   1.56951904e-01],
                        [  1.66595459e-01,   1.66564941e-01],
                        [  1.61956787e-01,   1.61865234e-01],
                        [  1.50115967e-01,   1.50146484e-01],
                        [  1.38549805e-01,   1.38610840e-01],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.19262695e-01,   1.19232178e-01],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  8.58459473e-02,   8.58459473e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  8.01086426e-02,   8.01391602e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  6.46057129e-02,   6.45751953e-02],
                        [  5.63964844e-02,   5.63659668e-02],
                        [  5.22460938e-02,   5.23071289e-02],
                        [  4.70275879e-02,   4.70581055e-02],
                        [  3.60107422e-02,   3.59497070e-02],
                        [  2.39562988e-02,   2.38952637e-02],
                        [  1.94091797e-02,   1.94396973e-02],
                        [  2.36816406e-02,   2.37121582e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.62145996e-02,   2.61535645e-02],
                        [  1.25732422e-02,   1.25427246e-02],
                        [ -8.85009766e-03,  -8.81958008e-03],
                        [ -2.85644531e-02,  -2.85034180e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -2.49633789e-02,  -2.49938965e-02],
                        [ -3.78417969e-03,  -3.81469727e-03],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  5.38330078e-02,   5.38635254e-02],
                        [  7.76672363e-02,   7.76977539e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  6.84814453e-02,   6.84509277e-02],
                        [  4.43725586e-02,   4.43420410e-02],
                        [  2.75268555e-02,   2.75573730e-02],
                        [  2.46887207e-02,   2.47497559e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  3.29895020e-02,   3.29284668e-02],
                        [  2.99072266e-02,   2.98767090e-02],
                        [  2.37426758e-02,   2.37731934e-02],
                        [  2.02941895e-02,   2.03552246e-02],
                        [  2.04772949e-02,   2.05078125e-02],
                        [  1.90734863e-02,   1.90124512e-02],
                        [  9.97924805e-03,   9.91821289e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -2.87475586e-02,  -2.86865234e-02],
                        [ -4.48303223e-02,  -4.47998047e-02],
                        [ -5.10559082e-02,  -5.11169434e-02],
                        [ -4.84924316e-02,  -4.86145020e-02],
                        [ -4.16259766e-02,  -4.15954590e-02],
                        [ -3.43627930e-02,  -3.42102051e-02],
                        [ -2.80761719e-02,  -2.80456543e-02],
                        [ -2.26135254e-02,  -2.27355957e-02],
                        [ -1.84326172e-02,  -1.85241699e-02],
                        [ -1.61743164e-02,  -1.60827637e-02],
                        [ -1.54418945e-02,  -1.52893066e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -2.52685547e-02,  -2.53906250e-02],
                        [ -3.72314453e-02,  -3.73229980e-02],
                        [ -4.65393066e-02,  -4.64477539e-02],
                        [ -4.72412109e-02,  -4.71191406e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -2.17590332e-02,  -2.19116211e-02],
                        [ -4.51660156e-03,  -4.60815430e-03],
                        [  1.10168457e-02,   1.11083984e-02],
                        [  2.67028809e-02,   2.68249512e-02],
                        [  4.38842773e-02,   4.38537598e-02],
                        [  5.72204590e-02,   5.70678711e-02],
                        [  5.55419922e-02,   5.55114746e-02],
                        [  2.96630859e-02,   2.97851562e-02],
                        [ -2.28271484e-02,  -2.27355957e-02],
                        [ -9.74731445e-02,  -9.75036621e-02],
                        [ -1.79382324e-01,  -1.79473877e-01],
                        [ -2.43804932e-01,  -2.43835449e-01],
                        [ -2.70629883e-01,  -2.70568848e-01],
                        [ -2.58209229e-01,  -2.58178711e-01],
                        [ -2.21618652e-01,  -2.21618652e-01],
                        [ -1.80541992e-01,  -1.80603027e-01],
                        [ -1.47277832e-01,  -1.47338867e-01],
                        [ -1.22680664e-01,  -1.22650146e-01],
                        [ -1.01928711e-01,  -1.01867676e-01],
                        [ -8.17871094e-02,  -8.17871094e-02],
                        [ -6.25305176e-02,  -6.25915527e-02],
                        [ -4.55322266e-02,  -4.55627441e-02],
                        [ -3.02124023e-02,  -3.01818848e-02],
                        [ -1.47094727e-02,  -1.46789551e-02],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.36108398e-02,   1.35803223e-02],
                        [  2.22473145e-02,   2.22167969e-02],
                        [  2.65502930e-02,   2.65197754e-02],
                        [  2.83813477e-02,   2.84118652e-02],
                        [  3.11584473e-02,   3.11889648e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.62646484e-02,   4.62036133e-02],
                        [  5.40466309e-02,   5.40161133e-02],
                        [  6.28662109e-02,   6.28967285e-02],
                        [  8.12683105e-02,   8.13293457e-02],
                        [  1.10748291e-01,   1.10717773e-01],
                        [  1.36138916e-01,   1.36077881e-01],
                        [  1.35711670e-01,   1.35681152e-01],
                        [  9.69543457e-02,   9.69848633e-02],
                        [  2.23083496e-02,   2.23693848e-02],
                        [ -7.08618164e-02,  -7.08923340e-02],
                        [ -1.52618408e-01,  -1.52709961e-01],
                        [ -1.93481445e-01,  -1.93481445e-01],
                        [ -1.84387207e-01,  -1.84326172e-01],
                        [ -1.43829346e-01,  -1.43829346e-01],
                        [ -1.01959229e-01,  -1.01989746e-01],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -3.06091309e-02,  -3.05786133e-02],
                        [ -7.62939453e-03,  -7.59887695e-03],
                        [  2.50549316e-02,   2.49938965e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  1.12945557e-01,   1.13037109e-01],
                        [  1.50878906e-01,   1.50939941e-01],
                        [  1.67968750e-01,   1.67877197e-01],
                        [  1.60339355e-01,   1.60278320e-01],
                        [  1.39343262e-01,   1.39434814e-01],
                        [  1.21856689e-01,   1.21948242e-01],
                        [  1.14288330e-01,   1.14227295e-01],
                        [  1.10900879e-01,   1.10809326e-01],
                        [  1.04125977e-01,   1.04156494e-01],
                        [  9.28649902e-02,   9.29565430e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  7.52258301e-02,   7.51342773e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  7.00988770e-02,   7.01599121e-02],
                        [  6.75354004e-02,   6.75659180e-02],
                        [  6.21337891e-02,   6.21032715e-02],
                        [  5.38024902e-02,   5.37719727e-02],
                        [  4.65698242e-02,   4.66003418e-02],
                        [  4.44030762e-02,   4.44641113e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  4.66918945e-02,   4.66003418e-02],
                        [  4.23583984e-02,   4.23278809e-02],
                        [  3.54003906e-02,   3.54614258e-02],
                        [  2.77099609e-02,   2.78015137e-02],
                        [  1.55944824e-02,   1.55334473e-02],
                        [ -5.09643555e-03,  -5.18798828e-03],
                        [ -2.98461914e-02,  -2.98156738e-02],
                        [ -4.63562012e-02,  -4.62646484e-02],
                        [ -4.48913574e-02,  -4.48608398e-02],
                        [ -2.49328613e-02,  -2.50549316e-02],
                        [  7.69042969e-03,   7.62939453e-03],
                        [  4.51354980e-02,   4.52270508e-02],
                        [  7.71789551e-02,   7.72399902e-02],
                        [  9.39025879e-02,   9.38720703e-02],
                        [  9.24987793e-02,   9.24377441e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  5.57250977e-02,   5.57556152e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.69470215e-02,   2.68859863e-02],
                        [  2.13928223e-02,   2.13623047e-02],
                        [  1.40380859e-02,   1.41296387e-02],
                        [  1.29089355e-02,   1.29699707e-02],
                        [  1.71508789e-02,   1.70593262e-02],
                        [  1.65100098e-02,   1.64184570e-02],
                        [  4.91333008e-03,   5.00488281e-03],
                        [ -1.22375488e-02,  -1.21154785e-02],
                        [ -2.63366699e-02,  -2.63977051e-02],
                        [ -3.40270996e-02,  -3.41491699e-02],
                        [ -3.45153809e-02,  -3.44543457e-02],
                        [ -2.83813477e-02,  -2.82897949e-02],
                        [ -2.20336914e-02,  -2.20642090e-02],
                        [ -2.35595703e-02,  -2.36511230e-02],
                        [ -3.04565430e-02,  -3.04260254e-02],
                        [ -3.11279297e-02,  -3.10974121e-02],
                        [ -2.25830078e-02,  -2.26440430e-02],
                        [ -1.50451660e-02,  -1.50756836e-02],
                        [ -1.61132812e-02,  -1.60522461e-02],
                        [ -2.34680176e-02,  -2.34375000e-02],
                        [ -3.34167480e-02,  -3.35083008e-02],
                        [ -4.39758301e-02,  -4.40368652e-02],
                        [ -5.08728027e-02,  -5.07507324e-02],
                        [ -4.88586426e-02,  -4.87976074e-02],
                        [ -3.63159180e-02,  -3.64074707e-02],
                        [ -1.52282715e-02,  -1.53198242e-02],
                        [  1.11694336e-02,   1.11999512e-02],
                        [  3.98864746e-02,   3.99780273e-02],
                        [  6.66809082e-02,   6.67114258e-02],
                        [  8.36791992e-02,   8.36181641e-02],
                        [  8.06884766e-02,   8.06274414e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [ -1.23291016e-02,  -1.22375488e-02],
                        [ -9.69543457e-02,  -9.69238281e-02],
                        [ -1.87347412e-01,  -1.87377930e-01],
                        [ -2.59582520e-01,  -2.59704590e-01],
                        [ -2.90618896e-01,  -2.90618896e-01],
                        [ -2.70660400e-01,  -2.70538330e-01],
                        [ -2.14263916e-01,  -2.14202881e-01],
                        [ -1.55273438e-01,  -1.55426025e-01],
                        [ -1.21246338e-01,  -1.21368408e-01],
                        [ -1.10595703e-01,  -1.10504150e-01],
                        [ -1.02020264e-01,  -1.01867676e-01],
                        [ -8.38012695e-02,  -8.38623047e-02],
                        [ -6.32019043e-02,  -6.33544922e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -4.29992676e-02,  -4.28771973e-02],
                        [ -3.64685059e-02,  -3.64379883e-02],
                        [ -2.53295898e-02,  -2.53906250e-02],
                        [ -8.54492188e-03,  -8.60595703e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  2.77709961e-02,   2.78320312e-02],
                        [  3.95812988e-02,   3.96728516e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  4.33654785e-02,   4.32128906e-02],
                        [  3.75976562e-02,   3.75061035e-02],
                        [  3.66210938e-02,   3.67736816e-02],
                        [  4.92858887e-02,   4.94079590e-02],
                        [  7.51647949e-02,   7.50732422e-02],
                        [  1.04736328e-01,   1.04583740e-01],
                        [  1.26678467e-01,   1.26708984e-01],
                        [  1.30859375e-01,   1.31042480e-01],
                        [  1.07482910e-01,   1.07513428e-01],
                        [  5.26733398e-02,   5.25207520e-02],
                        [ -2.41699219e-02,  -2.42309570e-02],
                        [ -1.01501465e-01,  -1.01440430e-01],
                        [ -1.55426025e-01,  -1.55364990e-01],
                        [ -1.72576904e-01,  -1.72576904e-01],
                        [ -1.57928467e-01,  -1.57958984e-01],
                        [ -1.30187988e-01,  -1.30249023e-01],
                        [ -1.08276367e-01,  -1.08306885e-01],
                        [ -9.90600586e-02,  -9.89990234e-02],
                        [ -9.39941406e-02,  -9.39025879e-02],
                        [ -7.90710449e-02,  -7.91015625e-02],
                        [ -4.73327637e-02,  -4.74548340e-02],
                        [ -3.66210938e-04,  -3.96728516e-04],
                        [  5.63049316e-02,   5.64270020e-02],
                        [  1.12579346e-01,   1.12640381e-01],
                        [  1.53137207e-01,   1.53076172e-01],
                        [  1.66320801e-01,   1.66229248e-01],
                        [  1.55944824e-01,   1.55975342e-01],
                        [  1.38183594e-01,   1.38275146e-01],
                        [  1.24725342e-01,   1.24755859e-01],
                        [  1.15783691e-01,   1.15692139e-01],
                        [  1.08093262e-01,   1.08062744e-01],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  9.19799805e-02,   9.20104980e-02],
                        [  8.34655762e-02,   8.34960938e-02],
                        [  7.67211914e-02,   7.67822266e-02],
                        [  7.22045898e-02,   7.21435547e-02],
                        [  6.75354004e-02,   6.74133301e-02],
                        [  6.12182617e-02,   6.12792969e-02],
                        [  5.52062988e-02,   5.53588867e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  4.67529297e-02,   4.65698242e-02],
                        [  4.11987305e-02,   4.11682129e-02],
                        [  3.99780273e-02,   4.01306152e-02],
                        [  4.68139648e-02,   4.69055176e-02],
                        [  5.48400879e-02,   5.47180176e-02],
                        [  5.37719727e-02,   5.36804199e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  2.38037109e-02,   2.38647461e-02],
                        [  3.38745117e-03,   3.44848633e-03],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -3.21655273e-02,  -3.22265625e-02],
                        [ -4.22058105e-02,  -4.22973633e-02],
                        [ -4.35485840e-02,  -4.34875488e-02],
                        [ -2.96325684e-02,  -2.95104980e-02],
                        [  2.56347656e-03,   2.53295898e-03],
                        [  4.34265137e-02,   4.32739258e-02],
                        [  7.61108398e-02,   7.61108398e-02],
                        [  8.91418457e-02,   8.92639160e-02],
                        [  7.99865723e-02,   8.00476074e-02],
                        [  5.49011230e-02,   5.48400879e-02],
                        [  2.92358398e-02,   2.91748047e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  2.40783691e-02,   2.41088867e-02],
                        [  3.65600586e-02,   3.66210938e-02],
                        [  4.45251465e-02,   4.45556641e-02],
                        [  4.21142578e-02,   4.20532227e-02],
                        [  3.09448242e-02,   3.08532715e-02],
                        [  1.80053711e-02,   1.80664062e-02],
                        [  9.09423828e-03,   9.24682617e-03],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  1.40380859e-03,   1.25122070e-03],
                        [ -3.60107422e-03,  -3.66210938e-03],
                        [ -1.06811523e-02,  -1.05285645e-02],
                        [ -1.88293457e-02,  -1.87377930e-02],
                        [ -2.74353027e-02,  -2.75268555e-02],
                        [ -3.60107422e-02,  -3.61328125e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -4.40368652e-02,  -4.39147949e-02],
                        [ -3.90014648e-02,  -3.89709473e-02],
                        [ -3.17993164e-02,  -3.18908691e-02],
                        [ -2.71911621e-02,  -2.72521973e-02],
                        [ -2.64282227e-02,  -2.63671875e-02],
                        [ -2.92053223e-02,  -2.91748047e-02],
                        [ -3.38439941e-02,  -3.38745117e-02],
                        [ -3.57055664e-02,  -3.57360840e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -1.94396973e-02,  -1.94091797e-02],
                        [ -6.65283203e-03,  -6.62231445e-03],
                        [  4.63867188e-03,   4.66918945e-03],
                        [  1.53503418e-02,   1.53198242e-02],
                        [  2.77709961e-02,   2.77099609e-02],
                        [  4.22058105e-02,   4.22363281e-02],
                        [  5.69152832e-02,   5.69458008e-02],
                        [  6.69250488e-02,   6.68945312e-02],
                        [  6.25000000e-02,   6.24389648e-02],
                        [  3.17993164e-02,   3.18298340e-02],
                        [ -3.19519043e-02,  -3.18603516e-02],
                        [ -1.23168945e-01,  -1.23199463e-01],
                        [ -2.20245361e-01,  -2.20306396e-01],
                        [ -2.90008545e-01,  -2.90008545e-01],
                        [ -3.05603027e-01,  -3.05541992e-01],
                        [ -2.66601562e-01,  -2.66571045e-01],
                        [ -2.01324463e-01,  -2.01354980e-01],
                        [ -1.45751953e-01,  -1.45782471e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -1.14440918e-01,  -1.14410400e-01],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -6.89392090e-02,  -6.89697266e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.13110352e-02,  -3.12805176e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -1.16271973e-02,  -1.16577148e-02],
                        [  5.00488281e-03,   4.97436523e-03],
                        [  2.26440430e-02,   2.26745605e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.32031250e-02,   3.31726074e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  3.01513672e-02,   3.01818848e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  7.55004883e-02,   7.54394531e-02],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  1.32904053e-01,   1.32965088e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.28723145e-01,   1.28692627e-01],
                        [  7.39135742e-02,   7.38830566e-02],
                        [ -1.27258301e-02,  -1.26647949e-02],
                        [ -1.05377197e-01,  -1.05377197e-01],
                        [ -1.72698975e-01,  -1.72729492e-01],
                        [ -1.95373535e-01,  -1.95404053e-01],
                        [ -1.76635742e-01,  -1.76635742e-01],
                        [ -1.39221191e-01,  -1.39160156e-01],
                        [ -1.08428955e-01,  -1.08459473e-01],
                        [ -9.39636230e-02,  -9.39636230e-02],
                        [ -8.46862793e-02,  -8.46862793e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -1.73339844e-02,  -1.73034668e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  9.17358398e-02,   9.17358398e-02],
                        [  1.28051758e-01,   1.28021240e-01],
                        [  1.44042969e-01,   1.44042969e-01],
                        [  1.43859863e-01,   1.43890381e-01],
                        [  1.35498047e-01,   1.35498047e-01],
                        [  1.25793457e-01,   1.25762939e-01],
                        [  1.18194580e-01,   1.18164062e-01],
                        [  1.12091064e-01,   1.12121582e-01],
                        [  1.04736328e-01,   1.04766846e-01],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  8.48083496e-02,   8.47778320e-02],
                        [  7.44018555e-02,   7.43408203e-02],
                        [  6.24084473e-02,   6.23779297e-02],
                        [  4.80041504e-02,   4.80346680e-02],
                        [  3.50646973e-02,   3.51257324e-02],
                        [  2.99682617e-02,   2.99377441e-02],
                        [  3.42102051e-02,   3.41186523e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  4.99267578e-02,   5.00488281e-02],
                        [  5.34362793e-02,   5.34973145e-02],
                        [  5.41687012e-02,   5.40771484e-02],
                        [  5.54199219e-02,   5.53283691e-02],
                        [  5.96923828e-02,   5.97229004e-02],
                        [  6.39648438e-02,   6.40869141e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  4.26025391e-02,   4.25109863e-02],
                        [  1.11694336e-02,   1.11083984e-02],
                        [ -2.44750977e-02,  -2.44140625e-02],
                        [ -5.10864258e-02,  -5.09948730e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -5.61218262e-02,  -5.62133789e-02],
                        [ -3.72314453e-02,  -3.72924805e-02],
                        [ -3.47900391e-03,  -3.44848633e-03],
                        [  4.08020020e-02,   4.08935547e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  9.86633301e-02,   9.86022949e-02],
                        [  9.03015137e-02,   9.02404785e-02],
                        [  6.61926270e-02,   6.62231445e-02],
                        [  4.39147949e-02,   4.39758301e-02],
                        [  3.48815918e-02,   3.49121094e-02],
                        [  3.68957520e-02,   3.68347168e-02],
                        [  4.00390625e-02,   3.99780273e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  3.38745117e-02,   3.39355469e-02],
                        [  2.54821777e-02,   2.55126953e-02],
                        [  1.30920410e-02,   1.30615234e-02],
                        [ -1.15966797e-03,  -1.22070312e-03],
                        [ -1.15661621e-02,  -1.15966797e-02],
                        [ -1.25122070e-02,  -1.24206543e-02],
                        [ -4.33349609e-03,  -4.24194336e-03],
                        [  3.44848633e-03,   3.38745117e-03],
                        [ -3.35693359e-04,  -4.88281250e-04],
                        [ -1.56860352e-02,  -1.56555176e-02],
                        [ -3.05786133e-02,  -3.03955078e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -3.87878418e-02,  -3.89404297e-02],
                        [ -4.33959961e-02,  -4.34570312e-02],
                        [ -4.78515625e-02,  -4.76989746e-02],
                        [ -4.66613770e-02,  -4.66003418e-02],
                        [ -4.08630371e-02,  -4.09545898e-02],
                        [ -3.44848633e-02,  -3.45153809e-02],
                        [ -2.74963379e-02,  -2.74047852e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -6.50024414e-03,  -6.59179688e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  1.92565918e-02,   1.93481445e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  5.52978516e-02,   5.51757812e-02],
                        [  6.60705566e-02,   6.60400391e-02],
                        [  6.98852539e-02,   7.00073242e-02],
                        [  6.72912598e-02,   6.73522949e-02],
                        [  5.20629883e-02,   5.19714355e-02],
                        [  1.30310059e-02,   1.29394531e-02],
                        [ -5.47180176e-02,  -5.46875000e-02],
                        [ -1.41143799e-01,  -1.41052246e-01],
                        [ -2.23205566e-01,  -2.23205566e-01],
                        [ -2.75665283e-01,  -2.75756836e-01],
                        [ -2.85186768e-01,  -2.85186768e-01],
                        [ -2.56561279e-01,  -2.56500244e-01],
                        [ -2.07977295e-01,  -2.07977295e-01],
                        [ -1.60247803e-01,  -1.60278320e-01],
                        [ -1.26281738e-01,  -1.26251221e-01],
                        [ -1.06018066e-01,  -1.05957031e-01],
                        [ -9.22241211e-02,  -9.22851562e-02],
                        [ -7.98339844e-02,  -7.98950195e-02],
                        [ -6.64978027e-02,  -6.64367676e-02],
                        [ -5.01403809e-02,  -5.00183105e-02],
                        [ -3.21350098e-02,  -3.21655273e-02],
                        [ -1.73645020e-02,  -1.74865723e-02],
                        [ -6.77490234e-03,  -6.80541992e-03],
                        [  4.21142578e-03,   4.36401367e-03],
                        [  1.69677734e-02,   1.70288086e-02],
                        [  2.56652832e-02,   2.55432129e-02],
                        [  2.56958008e-02,   2.55737305e-02],
                        [  2.09655762e-02,   2.10266113e-02],
                        [  1.95007324e-02,   1.96228027e-02],
                        [  2.42309570e-02,   2.42919922e-02],
                        [  3.17687988e-02,   3.16772461e-02],
                        [  3.93981934e-02,   3.93066406e-02],
                        [  5.07812500e-02,   5.08117676e-02],
                        [  7.15332031e-02,   7.16552734e-02],
                        [  1.01104736e-01,   1.01165771e-01],
                        [  1.30828857e-01,   1.30767822e-01],
                        [  1.49475098e-01,   1.49353027e-01],
                        [  1.46911621e-01,   1.46911621e-01],
                        [  1.13647461e-01,   1.13769531e-01],
                        [  4.44946289e-02,   4.45861816e-02],
                        [ -5.14221191e-02,  -5.15136719e-02],
                        [ -1.47064209e-01,  -1.47186279e-01],
                        [ -2.08618164e-01,  -2.08648682e-01],
                        [ -2.16583252e-01,  -2.16461182e-01],
                        [ -1.79473877e-01,  -1.79351807e-01],
                        [ -1.25549316e-01,  -1.25640869e-01],
                        [ -7.79418945e-02,  -7.80944824e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [  2.71606445e-03,   2.89916992e-03],
                        [  5.09033203e-02,   5.09643555e-02],
                        [  9.42687988e-02,   9.41467285e-02],
                        [  1.18377686e-01,   1.18286133e-01],
                        [  1.20819092e-01,   1.20880127e-01],
                        [  1.11114502e-01,   1.11236572e-01],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  9.53979492e-02,   9.53369141e-02],
                        [  9.38415527e-02,   9.37805176e-02],
                        [  9.20104980e-02,   9.19799805e-02],
                        [  8.77990723e-02,   8.78601074e-02],
                        [  8.25500488e-02,   8.26416016e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  7.49511719e-02,   7.48291016e-02],
                        [  6.89086914e-02,   6.88476562e-02],
                        [  6.14624023e-02,   6.15844727e-02],
                        [  5.70678711e-02,   5.71899414e-02],
                        [  5.60913086e-02,   5.60302734e-02],
                        [  5.38024902e-02,   5.36499023e-02],
                        [  4.71496582e-02,   4.71496582e-02],
                        [  3.90930176e-02,   3.92456055e-02],
                        [  3.43933105e-02,   3.44543457e-02],
                        [  3.43017578e-02,   3.41796875e-02],
                        [  3.75671387e-02,   3.74755859e-02],
                        [  4.29077148e-02,   4.29687500e-02],
                        [  4.84313965e-02,   4.85229492e-02],
                        [  5.03540039e-02,   5.03540039e-02],
                        [  4.32128906e-02,   4.31213379e-02],
                        [  2.32238770e-02,   2.31933594e-02],
                        [ -6.53076172e-03,  -6.50024414e-03],
                        [ -3.67126465e-02,  -3.66821289e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -2.81677246e-02,  -2.81982422e-02],
                        [  1.22070312e-02,   1.21765137e-02],
                        [  5.91735840e-02,   5.92346191e-02],
                        [  9.89685059e-02,   9.89990234e-02],
                        [  1.15203857e-01,   1.15081787e-01],
                        [  1.00830078e-01,   1.00738525e-01],
                        [  6.76879883e-02,   6.77795410e-02],
                        [  3.80554199e-02,   3.81469727e-02],
                        [  2.40478516e-02,   2.39868164e-02],
                        [  2.03552246e-02,   2.02331543e-02],
                        [  1.70898438e-02,   1.71203613e-02],
                        [  1.18713379e-02,   1.19628906e-02],
                        [  7.90405273e-03,   7.87353516e-03],
                        [  7.11059570e-03,   7.04956055e-03],
                        [  8.54492188e-03,   8.51440430e-03],
                        [  1.02539062e-02,   1.03149414e-02],
                        [  1.07116699e-02,   1.07421875e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -6.98852539e-03,  -7.01904297e-03],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -3.86962891e-02,  -3.86352539e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -5.06896973e-02,  -5.07202148e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -3.24401855e-02,  -3.23791504e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -1.88598633e-02,  -1.89208984e-02],
                        [ -1.98974609e-02,  -1.99279785e-02],
                        [ -2.07824707e-02,  -2.07214355e-02],
                        [ -1.71203613e-02,  -1.70898438e-02],
                        [ -9.70458984e-03,  -9.73510742e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  6.56127930e-03,   6.59179688e-03],
                        [  1.81274414e-02,   1.81579590e-02],
                        [  3.17687988e-02,   3.17382812e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  4.24194336e-02,   4.24804688e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  1.95007324e-02,   1.94396973e-02],
                        [ -1.32141113e-02,  -1.32446289e-02],
                        [ -6.40563965e-02,  -6.39648438e-02],
                        [ -1.25976562e-01,  -1.25915527e-01],
                        [ -1.85272217e-01,  -1.85394287e-01],
                        [ -2.27508545e-01,  -2.27600098e-01],
                        [ -2.41546631e-01,  -2.41424561e-01],
                        [ -2.25311279e-01,  -2.25189209e-01],
                        [ -1.92199707e-01,  -1.92321777e-01],
                        [ -1.63330078e-01,  -1.63482666e-01],
                        [ -1.47491455e-01,  -1.47430420e-01],
                        [ -1.36566162e-01,  -1.36413574e-01],
                        [ -1.21124268e-01,  -1.21154785e-01],
                        [ -1.00769043e-01,  -1.00891113e-01],
                        [ -7.89184570e-02,  -7.89489746e-02],
                        [ -5.69152832e-02,  -5.68237305e-02],
                        [ -3.62854004e-02,  -3.62243652e-02],
                        [ -2.02026367e-02,  -2.02331543e-02],
                        [ -9.42993164e-03,  -9.52148438e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  1.77001953e-03,   1.86157227e-03],
                        [  8.23974609e-04,   9.15527344e-04],
                        [ -4.27246094e-03,  -4.30297852e-03],
                        [ -8.85009766e-03,  -8.97216797e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  5.85937500e-03,   5.95092773e-03],
                        [  2.48718262e-02,   2.49328613e-02],
                        [  4.58374023e-02,   4.57763672e-02],
                        [  6.71997070e-02,   6.71386719e-02],
                        [  8.89587402e-02,   8.89892578e-02],
                        [  1.08856201e-01,   1.08917236e-01],
                        [  1.23229980e-01,   1.23229980e-01],
                        [  1.30401611e-01,   1.30401611e-01],
                        [  1.30737305e-01,   1.30676270e-01],
                        [  1.20300293e-01,   1.20239258e-01],
                        [  8.72802734e-02,   8.73413086e-02],
                        [  2.10571289e-02,   2.11486816e-02],
                        [ -7.18688965e-02,  -7.18994141e-02],
                        [ -1.62567139e-01,  -1.62719727e-01],
                        [ -2.14050293e-01,  -2.14050293e-01],
                        [ -2.04498291e-01,  -2.04345703e-01],
                        [ -1.43676758e-01,  -1.43615723e-01],
                        [ -6.70776367e-02,  -6.71997070e-02],
                        [ -8.23974609e-03,  -8.36181641e-03],
                        [  2.55432129e-02,   2.56347656e-02],
                        [  4.77600098e-02,   4.78820801e-02],
                        [  6.83898926e-02,   6.83593750e-02],
                        [  8.38928223e-02,   8.37402344e-02],
                        [  8.71887207e-02,   8.71582031e-02],
                        [  7.94372559e-02,   7.95288086e-02],
                        [  6.92749023e-02,   6.93054199e-02],
                        [  6.47583008e-02,   6.46972656e-02],
                        [  6.80541992e-02,   6.79931641e-02],
                        [  7.65686035e-02,   7.65380859e-02],
                        [  8.68835449e-02,   8.69140625e-02],
                        [  9.62524414e-02,   9.63134766e-02],
                        [  1.01593018e-01,   1.01623535e-01],
                        [  9.92431641e-02,   9.91516113e-02],
                        [  8.69445801e-02,   8.68530273e-02],
                        [  6.82678223e-02,   6.83288574e-02],
                        [  5.34667969e-02,   5.36193848e-02],
                        [  5.02624512e-02,   5.02319336e-02],
                        [  5.43212891e-02,   5.41381836e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  5.08422852e-02,   5.10253906e-02],
                        [  4.27551270e-02,   4.28161621e-02],
                        [  3.31726074e-02,   3.30505371e-02],
                        [  2.32238770e-02,   2.31628418e-02],
                        [  1.73339844e-02,   1.73950195e-02],
                        [  1.94702148e-02,   1.95312500e-02],
                        [  2.66418457e-02,   2.66113281e-02],
                        [  3.19824219e-02,   3.19213867e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.43225098e-02,   2.43530273e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.66918945e-03,  -4.69970703e-03],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  9.60388184e-02,   9.60998535e-02],
                        [  1.17218018e-01,   1.17279053e-01],
                        [  1.10778809e-01,   1.10656738e-01],
                        [  8.52966309e-02,   8.52050781e-02],
                        [  5.67016602e-02,   5.67932129e-02],
                        [  3.90930176e-02,   3.92761230e-02],
                        [  3.47595215e-02,   3.46984863e-02],
                        [  3.42102051e-02,   3.39965820e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  2.38037109e-02,   2.40173340e-02],
                        [  1.95922852e-02,   1.96838379e-02],
                        [  1.51062012e-02,   1.49230957e-02],
                        [  6.68334961e-03,   6.53076172e-03],
                        [ -4.97436523e-03,  -4.88281250e-03],
                        [ -1.58386230e-02,  -1.56555176e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.99377441e-02,  -3.00903320e-02],
                        [ -3.35388184e-02,  -3.36303711e-02],
                        [ -3.11889648e-02,  -3.10974121e-02],
                        [ -2.12707520e-02,  -2.11181641e-02],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -2.07519531e-03,  -2.25830078e-03],
                        [ -5.49316406e-03,  -5.55419922e-03],
                        [ -1.24816895e-02,  -1.23901367e-02],
                        [ -1.54113770e-02,  -1.52893066e-02],
                        [ -1.45263672e-02,  -1.45874023e-02],
                        [ -1.36108398e-02,  -1.37329102e-02],
                        [ -1.23901367e-02,  -1.24511719e-02],
                        [ -8.54492188e-03,  -8.48388672e-03],
                        [ -1.89208984e-03,  -1.80053711e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  8.39233398e-03,   8.27026367e-03],
                        [  7.08007812e-03,   7.01904297e-03],
                        [  6.37817383e-03,   6.46972656e-03],
                        [  1.11083984e-02,   1.12304688e-02],
                        [  1.60827637e-02,   1.59912109e-02],
                        [  8.02612305e-03,   7.90405273e-03],
                        [ -2.13317871e-02,  -2.13012695e-02],
                        [ -6.70776367e-02,  -6.69555664e-02],
                        [ -1.16088867e-01,  -1.16058350e-01],
                        [ -1.57409668e-01,  -1.57501221e-01],
                        [ -1.85333252e-01,  -1.85363770e-01],
                        [ -1.97174072e-01,  -1.97113037e-01],
                        [ -1.93542480e-01,  -1.93481445e-01],
                        [ -1.78649902e-01,  -1.78680420e-01],
                        [ -1.58874512e-01,  -1.58935547e-01],
                        [ -1.39465332e-01,  -1.39465332e-01],
                        [ -1.21795654e-01,  -1.21734619e-01],
                        [ -1.05316162e-01,  -1.05285645e-01],
                        [ -9.10034180e-02,  -9.10949707e-02],
                        [ -7.96813965e-02,  -7.97424316e-02],
                        [ -6.99462891e-02,  -6.98852539e-02],
                        [ -5.96008301e-02,  -5.95397949e-02],
                        [ -4.73632812e-02,  -4.74243164e-02],
                        [ -3.34472656e-02,  -3.35388184e-02],
                        [ -1.84326172e-02,  -1.84020996e-02],
                        [ -2.34985352e-03,  -2.25830078e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  2.07214355e-02,   2.06604004e-02],
                        [  2.28576660e-02,   2.28271484e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.49023438e-02,   2.49328613e-02],
                        [  2.98156738e-02,   2.98461914e-02],
                        [  3.88488770e-02,   3.88183594e-02],
                        [  5.10253906e-02,   5.09643555e-02],
                        [  6.44836426e-02,   6.44531250e-02],
                        [  7.88269043e-02,   7.89184570e-02],
                        [  9.53674316e-02,   9.54589844e-02],
                        [  1.13250732e-01,   1.13220215e-01],
                        [  1.26037598e-01,   1.25885010e-01],
                        [  1.23779297e-01,   1.23779297e-01],
                        [  9.83886719e-02,   9.85107422e-02],
                        [  4.60815430e-02,   4.61425781e-02],
                        [ -2.83813477e-02,  -2.85034180e-02],
                        [ -1.07696533e-01,  -1.07818604e-01],
                        [ -1.65649414e-01,  -1.65618896e-01],
                        [ -1.80145264e-01,  -1.79992676e-01],
                        [ -1.48345947e-01,  -1.48284912e-01],
                        [ -9.11560059e-02,  -9.13391113e-02],
                        [ -3.69262695e-02,  -3.70788574e-02],
                        [  1.00708008e-03,   1.09863281e-03],
                        [  2.83203125e-02,   2.85339355e-02],
                        [  5.37414551e-02,   5.37109375e-02],
                        [  7.40051270e-02,   7.38220215e-02],
                        [  7.95898438e-02,   7.95288086e-02],
                        [  7.02819824e-02,   7.04345703e-02],
                        [  5.67932129e-02,   5.68847656e-02],
                        [  4.87976074e-02,   4.87365723e-02],
                        [  4.97131348e-02,   4.95910645e-02],
                        [  5.93261719e-02,   5.92956543e-02],
                        [  7.37304688e-02,   7.38220215e-02],
                        [  8.55407715e-02,   8.56018066e-02],
                        [  8.79211426e-02,   8.78906250e-02],
                        [  7.80639648e-02,   7.79724121e-02],
                        [  5.95703125e-02,   5.95397949e-02],
                        [  4.19616699e-02,   4.20227051e-02],
                        [  3.30505371e-02,   3.31420898e-02],
                        [  3.12805176e-02,   3.12500000e-02],
                        [  2.92358398e-02,   2.91137695e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.30712891e-02,   2.31628418e-02],
                        [  3.01818848e-02,   3.02429199e-02],
                        [  4.28161621e-02,   4.27856445e-02],
                        [  5.35278320e-02,   5.34973145e-02],
                        [  5.70373535e-02,   5.70373535e-02],
                        [  5.15441895e-02,   5.15747070e-02],
                        [  3.86047363e-02,   3.86352539e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  4.82177734e-03,   4.79125977e-03],
                        [ -1.12609863e-02,  -1.12915039e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -3.37524414e-02,  -3.36914062e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -4.75769043e-02,  -4.76074219e-02],
                        [ -3.86657715e-02,  -3.87268066e-02],
                        [ -7.20214844e-03,  -7.17163086e-03],
                        [  4.31213379e-02,   4.32128906e-02],
                        [  9.22851562e-02,   9.23156738e-02],
                        [  1.18041992e-01,   1.17919922e-01],
                        [  1.14288330e-01,   1.14257812e-01],
                        [  9.42382812e-02,   9.43603516e-02],
                        [  7.52868652e-02,   7.53479004e-02],
                        [  6.16149902e-02,   6.15234375e-02],
                        [  4.60510254e-02,   4.59899902e-02],
                        [  2.70385742e-02,   2.70690918e-02],
                        [  1.17492676e-02,   1.18408203e-02],
                        [  4.97436523e-03,   5.00488281e-03],
                        [  5.40161133e-03,   5.34057617e-03],
                        [  8.94165039e-03,   8.91113281e-03],
                        [  1.05590820e-02,   1.05895996e-02],
                        [  6.74438477e-03,   6.80541992e-03],
                        [ -3.20434570e-03,  -3.17382812e-03],
                        [ -1.78222656e-02,  -1.79138184e-02],
                        [ -3.19519043e-02,  -3.20434570e-02],
                        [ -3.76281738e-02,  -3.75366211e-02],
                        [ -3.07006836e-02,  -3.05480957e-02],
                        [ -1.64184570e-02,  -1.64794922e-02],
                        [ -6.74438477e-03,  -6.92749023e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -1.43127441e-02,  -1.41296387e-02],
                        [ -1.55639648e-02,  -1.54724121e-02],
                        [ -1.10168457e-02,  -1.11389160e-02],
                        [ -5.58471680e-03,  -5.70678711e-03],
                        [ -1.25122070e-03,  -1.19018555e-03],
                        [  3.35693359e-03,   3.47900391e-03],
                        [  8.45336914e-03,   8.48388672e-03],
                        [  1.21765137e-02,   1.21154785e-02],
                        [  1.35803223e-02,   1.34887695e-02],
                        [  1.42822266e-02,   1.42517090e-02],
                        [  1.65710449e-02,   1.66931152e-02],
                        [  2.04772949e-02,   2.05688477e-02],
                        [  2.14233398e-02,   2.13012695e-02],
                        [  1.10778809e-02,   1.09252930e-02],
                        [ -1.55639648e-02,  -1.55029297e-02],
                        [ -5.57861328e-02,  -5.56030273e-02],
                        [ -1.04339600e-01,  -1.04309082e-01],
                        [ -1.55792236e-01,  -1.55944824e-01],
                        [ -1.98699951e-01,  -1.98791504e-01],
                        [ -2.19116211e-01,  -2.18994141e-01],
                        [ -2.13714600e-01,  -2.13592529e-01],
                        [ -1.92138672e-01,  -1.92169189e-01],
                        [ -1.66259766e-01,  -1.66351318e-01],
                        [ -1.41845703e-01,  -1.41876221e-01],
                        [ -1.18835449e-01,  -1.18774414e-01],
                        [ -9.74426270e-02,  -9.73815918e-02],
                        [ -8.20312500e-02,  -8.20617676e-02],
                        [ -7.56530762e-02,  -7.57141113e-02],
                        [ -7.39135742e-02,  -7.39440918e-02],
                        [ -6.86645508e-02,  -6.86340332e-02],
                        [ -5.54809570e-02,  -5.54504395e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -1.35803223e-02,  -1.36413574e-02],
                        [  5.61523438e-03,   5.58471680e-03],
                        [  1.65405273e-02,   1.65710449e-02],
                        [  1.79138184e-02,   1.79443359e-02],
                        [  1.43737793e-02,   1.43432617e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.06506348e-02,   1.06811523e-02],
                        [  1.54418945e-02,   1.54113770e-02],
                        [  2.33764648e-02,   2.33154297e-02],
                        [  3.07006836e-02,   3.07312012e-02],
                        [  3.89099121e-02,   3.90014648e-02],
                        [  5.16662598e-02,   5.16357422e-02],
                        [  6.74438477e-02,   6.72912598e-02],
                        [  8.27636719e-02,   8.27331543e-02],
                        [  9.84497070e-02,   9.86328125e-02],
                        [  1.15600586e-01,   1.15661621e-01],
                        [  1.26739502e-01,   1.26586914e-01],
                        [  1.17553711e-01,   1.17431641e-01],
                        [  7.84301758e-02,   7.85522461e-02],
                        [  1.25122070e-02,   1.26342773e-02],
                        [ -6.48193359e-02,  -6.48498535e-02],
                        [ -1.28753662e-01,  -1.28845215e-01],
                        [ -1.53717041e-01,  -1.53717041e-01],
                        [ -1.28479004e-01,  -1.28417969e-01],
                        [ -6.69250488e-02,  -6.68640137e-02],
                        [ -1.77001953e-03,  -1.80053711e-03],
                        [  3.81469727e-02,   3.80859375e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  4.83093262e-02,   4.83398438e-02],
                        [  5.19104004e-02,   5.19714355e-02],
                        [  5.88684082e-02,   5.88378906e-02],
                        [  5.91125488e-02,   5.90515137e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  3.93066406e-02,   3.93676758e-02],
                        [  3.68957520e-02,   3.68652344e-02],
                        [  4.41284180e-02,   4.40673828e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  7.04345703e-02,   7.04650879e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  7.26623535e-02,   7.26013184e-02],
                        [  5.59082031e-02,   5.59387207e-02],
                        [  3.71704102e-02,   3.72314453e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  2.85644531e-02,   2.85034180e-02],
                        [  3.33251953e-02,   3.32946777e-02],
                        [  3.52783203e-02,   3.53088379e-02],
                        [  3.51562500e-02,   3.52172852e-02],
                        [  3.77197266e-02,   3.76892090e-02],
                        [  4.43115234e-02,   4.42199707e-02],
                        [  4.99877930e-02,   4.99572754e-02],
                        [  4.83093262e-02,   4.84008789e-02],
                        [  3.82690430e-02,   3.83605957e-02],
                        [  2.36511230e-02,   2.35900879e-02],
                        [  7.32421875e-03,   7.23266602e-03],
                        [ -8.97216797e-03,  -8.94165039e-03],
                        [ -2.24609375e-02,  -2.23693848e-02],
                        [ -3.13110352e-02,  -3.12805176e-02],
                        [ -3.61022949e-02,  -3.61633301e-02],
                        [ -3.69873047e-02,  -3.70178223e-02],
                        [ -3.10668945e-02,  -3.10363770e-02],
                        [ -1.38549805e-02,  -1.38244629e-02],
                        [  1.65100098e-02,   1.65710449e-02],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  8.79211426e-02,   8.78295898e-02],
                        [  1.00799561e-01,   1.00769043e-01],
                        [  9.12475586e-02,   9.13085938e-02],
                        [  7.23266602e-02,   7.23876953e-02],
                        [  5.72814941e-02,   5.72509766e-02],
                        [  4.73327637e-02,   4.72717285e-02],
                        [  3.77807617e-02,   3.77502441e-02],
                        [  2.68554688e-02,   2.69165039e-02],
                        [  1.69677734e-02,   1.70593262e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  9.12475586e-03,   9.03320312e-03],
                        [  5.09643555e-03,   5.03540039e-03],
                        [ -2.28881836e-03,  -2.19726562e-03],
                        [ -9.97924805e-03,  -9.85717773e-03],
                        [ -1.65405273e-02,  -1.66015625e-02],
                        [ -2.21252441e-02,  -2.22778320e-02],
                        [ -2.28576660e-02,  -2.27966309e-02],
                        [ -1.44042969e-02,  -1.42517090e-02],
                        [ -1.77001953e-03,  -1.80053711e-03],
                        [  3.84521484e-03,   3.69262695e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -9.15527344e-03,  -9.03320312e-03],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -1.46179199e-02,  -1.47094727e-02],
                        [ -1.15661621e-02,  -1.15356445e-02],
                        [ -4.82177734e-03,  -4.73022461e-03],
                        [  4.11987305e-03,   4.08935547e-03],
                        [  1.18408203e-02,   1.17492676e-02],
                        [  1.61132812e-02,   1.61437988e-02],
                        [  1.95312500e-02,   1.95922852e-02],
                        [  2.73132324e-02,   2.72827148e-02],
                        [  4.10461426e-02,   4.09851074e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  6.47277832e-02,   6.47888184e-02],
                        [  5.49621582e-02,   5.49926758e-02],
                        [  1.90124512e-02,   1.89514160e-02],
                        [ -4.22668457e-02,  -4.22973633e-02],
                        [ -1.17706299e-01,  -1.17614746e-01],
                        [ -1.90734863e-01,  -1.90704346e-01],
                        [ -2.44598389e-01,  -2.44659424e-01],
                        [ -2.65533447e-01,  -2.65563965e-01],
                        [ -2.49084473e-01,  -2.49023438e-01],
                        [ -2.06268311e-01,  -2.06237793e-01],
                        [ -1.59393311e-01,  -1.59454346e-01],
                        [ -1.26159668e-01,  -1.26190186e-01],
                        [ -1.07391357e-01,  -1.07299805e-01],
                        [ -9.40551758e-02,  -9.40246582e-02],
                        [ -8.35876465e-02,  -8.36791992e-02],
                        [ -7.96508789e-02,  -7.97119141e-02],
                        [ -7.93762207e-02,  -7.92846680e-02],
                        [ -7.30895996e-02,  -7.30590820e-02],
                        [ -5.78308105e-02,  -5.79223633e-02],
                        [ -4.00695801e-02,  -4.01306152e-02],
                        [ -2.43225098e-02,  -2.42309570e-02],
                        [ -7.96508789e-03,  -7.87353516e-03],
                        [  1.04064941e-02,   1.03454590e-02],
                        [  2.50549316e-02,   2.49633789e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.21252441e-02,   2.22473145e-02],
                        [  1.11389160e-02,   1.11694336e-02],
                        [  3.47900391e-03,   3.38745117e-03],
                        [  4.88281250e-04,   3.96728516e-04],
                        [  5.79833984e-04,   6.71386719e-04],
                        [  5.49316406e-03,   5.58471680e-03],
                        [  1.69067383e-02,   1.68457031e-02],
                        [  3.20739746e-02,   3.19519043e-02],
                        [  4.97741699e-02,   4.98046875e-02],
                        [  7.31811523e-02,   7.33337402e-02],
                        [  1.00677490e-01,   1.00677490e-01],
                        [  1.21429443e-01,   1.21337891e-01],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.17126465e-01,   1.17187500e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  4.88586426e-02,   4.88281250e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -7.80029297e-02,  -7.80029297e-02],
                        [ -1.16363525e-01,  -1.16394043e-01],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -4.81567383e-02,  -4.80651855e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  6.53381348e-02,   6.52465820e-02],
                        [  6.43615723e-02,   6.43310547e-02],
                        [  3.78112793e-02,   3.79333496e-02],
                        [  1.53198242e-02,   1.53503418e-02],
                        [  9.46044922e-03,   9.33837891e-03],
                        [  1.18103027e-02,   1.17187500e-02],
                        [  1.15966797e-02,   1.16882324e-02],
                        [  1.09558105e-02,   1.10778809e-02],
                        [  1.89514160e-02,   1.89208984e-02],
                        [  3.56750488e-02,   3.55834961e-02],
                        [  5.09948730e-02,   5.09643555e-02],
                        [  5.70373535e-02,   5.71289062e-02],
                        [  5.39855957e-02,   5.40466309e-02],
                        [  4.59594727e-02,   4.58679199e-02],
                        [  3.77807617e-02,   3.77197266e-02],
                        [  3.39050293e-02,   3.39660645e-02],
                        [  3.66821289e-02,   3.67431641e-02],
                        [  4.46777344e-02,   4.46472168e-02],
                        [  5.06286621e-02,   5.05981445e-02],
                        [  4.66918945e-02,   4.67224121e-02],
                        [  3.43017578e-02,   3.43322754e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  1.53808594e-02,   1.53503418e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  4.88281250e-03,   4.94384766e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  3.57055664e-03,   3.54003906e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -7.59887695e-03,  -7.56835938e-03],
                        [ -2.20031738e-02,  -2.19726562e-02],
                        [ -3.60412598e-02,  -3.60717773e-02],
                        [ -4.46472168e-02,  -4.47082520e-02],
                        [ -4.17480469e-02,  -4.17175293e-02],
                        [ -2.11791992e-02,  -2.11181641e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  6.21337891e-02,   6.20727539e-02],
                        [  1.01318359e-01,   1.01318359e-01],
                        [  1.21002197e-01,   1.21032715e-01],
                        [  1.14807129e-01,   1.14837646e-01],
                        [  8.96911621e-02,   8.96606445e-02],
                        [  6.17675781e-02,   6.17370605e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  2.71911621e-02,   2.72216797e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  4.11987305e-03,   4.08935547e-03],
                        [  2.04467773e-03,   2.01416016e-03],
                        [  9.55200195e-03,   9.58251953e-03],
                        [  2.13928223e-02,   2.14233398e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [ -6.40869141e-04,  -6.71386719e-04],
                        [ -2.03857422e-02,  -2.03552246e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -1.01013184e-02,  -1.01318359e-02],
                        [  7.59887695e-03,   7.56835938e-03],
                        [  2.37731934e-02,   2.38037109e-02],
                        [  3.16162109e-02,   3.16467285e-02],
                        [  2.99682617e-02,   2.99377441e-02],
                        [  2.13317871e-02,   2.12707520e-02],
                        [  1.23901367e-02,   1.24206543e-02],
                        [  1.24511719e-02,   1.25427246e-02],
                        [  2.49023438e-02,   2.48718262e-02],
                        [  4.40673828e-02,   4.39758301e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  6.93664551e-02,   6.94580078e-02],
                        [  5.80749512e-02,   5.81054688e-02],
                        [  2.14843750e-02,   2.14233398e-02],
                        [ -3.77502441e-02,  -3.77807617e-02],
                        [ -1.07971191e-01,  -1.07940674e-01],
                        [ -1.73858643e-01,  -1.73858643e-01],
                        [ -2.20794678e-01,  -2.20794678e-01],
                        [ -2.38067627e-01,  -2.38037109e-01],
                        [ -2.24609375e-01,  -2.24639893e-01],
                        [ -1.92199707e-01,  -1.92230225e-01],
                        [ -1.58203125e-01,  -1.58172607e-01],
                        [ -1.34155273e-01,  -1.34124756e-01],
                        [ -1.20513916e-01,  -1.20544434e-01],
                        [ -1.10626221e-01,  -1.10687256e-01],
                        [ -9.94262695e-02,  -9.94567871e-02],
                        [ -8.80737305e-02,  -8.80432129e-02],
                        [ -7.94982910e-02,  -7.94677734e-02],
                        [ -7.25708008e-02,  -7.25402832e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -4.61425781e-02,  -4.61730957e-02],
                        [ -2.53601074e-02,  -2.53906250e-02],
                        [ -3.96728516e-03,  -3.90625000e-03],
                        [  1.58081055e-02,   1.58691406e-02],
                        [  3.09753418e-02,   3.09143066e-02],
                        [  3.58886719e-02,   3.57971191e-02],
                        [  2.81372070e-02,   2.81677246e-02],
                        [  1.42517090e-02,   1.43432617e-02],
                        [  3.99780273e-03,   3.96728516e-03],
                        [  4.27246094e-04,   3.35693359e-04],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  2.92968750e-03,   2.99072266e-03],
                        [  1.01623535e-02,   1.01928711e-02],
                        [  2.37426758e-02,   2.37121582e-02],
                        [  4.24804688e-02,   4.24499512e-02],
                        [  6.34765625e-02,   6.34765625e-02],
                        [  8.31909180e-02,   8.32214355e-02],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.15600586e-01,   1.15570068e-01],
                        [  1.30310059e-01,   1.30279541e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  8.50219727e-02,   8.49914551e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -8.71276855e-02,  -8.71276855e-02],
                        [ -9.49096680e-02,  -9.49096680e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -1.70593262e-02,  -1.70898438e-02],
                        [  1.49841309e-02,   1.49536133e-02],
                        [  2.41088867e-02,   2.41699219e-02],
                        [  2.16674805e-02,   2.16979980e-02],
                        [  2.18505859e-02,   2.17895508e-02],
                        [  2.63671875e-02,   2.63061523e-02],
                        [  2.74353027e-02,   2.74658203e-02],
                        [  2.19116211e-02,   2.19726562e-02],
                        [  1.55334473e-02,   1.55639648e-02],
                        [  1.34582520e-02,   1.33666992e-02],
                        [  1.52587891e-02,   1.51977539e-02],
                        [  1.95617676e-02,   1.96533203e-02],
                        [  2.61535645e-02,   2.62756348e-02],
                        [  3.54309082e-02,   3.53698730e-02],
                        [  4.78820801e-02,   4.76989746e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  6.40258789e-02,   6.41784668e-02],
                        [  5.79528809e-02,   5.80139160e-02],
                        [  4.63867188e-02,   4.62951660e-02],
                        [  3.43017578e-02,   3.41796875e-02],
                        [  2.57263184e-02,   2.57568359e-02],
                        [  2.45056152e-02,   2.46276855e-02],
                        [  2.92968750e-02,   2.93273926e-02],
                        [  3.21044922e-02,   3.20129395e-02],
                        [  2.69165039e-02,   2.67944336e-02],
                        [  1.64489746e-02,   1.65100098e-02],
                        [  8.23974609e-03,   8.39233398e-03],
                        [  4.94384766e-03,   4.97436523e-03],
                        [  1.15966797e-03,   1.03759766e-03],
                        [ -9.24682617e-03,  -9.33837891e-03],
                        [ -2.52685547e-02,  -2.52380371e-02],
                        [ -4.01306152e-02,  -4.00390625e-02],
                        [ -4.69665527e-02,  -4.69360352e-02],
                        [ -4.06188965e-02,  -4.06799316e-02],
                        [ -1.76391602e-02,  -1.77307129e-02],
                        [  2.09960938e-02,   2.10266113e-02],
                        [  6.65588379e-02,   6.66503906e-02],
                        [  1.03973389e-01,   1.04003906e-01],
                        [  1.19689941e-01,   1.19628906e-01],
                        [  1.10290527e-01,   1.10198975e-01],
                        [  8.42285156e-02,   8.42590332e-02],
                        [  5.53588867e-02,   5.54809570e-02],
                        [  3.36608887e-02,   3.37219238e-02],
                        [  2.13928223e-02,   2.13012695e-02],
                        [  1.62353516e-02,   1.61132812e-02],
                        [  1.53503418e-02,   1.53808594e-02],
                        [  1.68762207e-02,   1.70288086e-02],
                        [  1.97753906e-02,   1.98059082e-02],
                        [  2.13317871e-02,   2.12097168e-02],
                        [  1.56555176e-02,   1.55639648e-02],
                        [  7.32421875e-04,   7.93457031e-04],
                        [ -1.53503418e-02,  -1.52282715e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.42614746e-02,  -2.43835449e-02],
                        [ -2.41699219e-02,  -2.42309570e-02],
                        [ -2.44140625e-02,  -2.43225098e-02],
                        [ -2.16674805e-02,  -2.15759277e-02],
                        [ -1.57775879e-02,  -1.58386230e-02],
                        [ -9.64355469e-03,  -9.73510742e-03],
                        [ -3.90625000e-03,  -3.87573242e-03],
                        [  2.74658203e-03,   2.83813477e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.57470703e-02,   1.56860352e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  2.86560059e-02,   2.86865234e-02],
                        [  3.63464355e-02,   3.63769531e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  4.54406738e-02,   4.54101562e-02],
                        [  4.85534668e-02,   4.85839844e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [ -2.90832520e-02,  -2.91137695e-02],
                        [ -9.54284668e-02,  -9.54284668e-02],
                        [ -1.70104980e-01,  -1.70104980e-01],
                        [ -2.31506348e-01,  -2.31536865e-01],
                        [ -2.58422852e-01,  -2.58392334e-01],
                        [ -2.46368408e-01,  -2.46368408e-01],
                        [ -2.10662842e-01,  -2.10662842e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.44592285e-01,  -1.44561768e-01],
                        [ -1.27471924e-01,  -1.27471924e-01],
                        [ -1.14990234e-01,  -1.15051270e-01],
                        [ -1.01623535e-01,  -1.01593018e-01],
                        [ -8.55712891e-02,  -8.54797363e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -5.44128418e-02,  -5.45043945e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -4.36401367e-02,  -4.35791016e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -2.88696289e-02,  -2.89306641e-02],
                        [ -1.35803223e-02,  -1.36108398e-02],
                        [  3.38745117e-03,   3.41796875e-03],
                        [  1.71813965e-02,   1.72119141e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  1.75476074e-02,   1.75170898e-02],
                        [  9.67407227e-03,   9.64355469e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  9.64355469e-03,   9.67407227e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  5.67321777e-02,   5.67626953e-02],
                        [  7.99255371e-02,   7.98950195e-02],
                        [  9.93957520e-02,   9.93957520e-02],
                        [  1.15234375e-01,   1.15203857e-01],
                        [  1.27746582e-01,   1.27746582e-01],
                        [  1.35101318e-01,   1.35131836e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  1.13891602e-01,   1.13861084e-01],
                        [  6.99768066e-02,   6.99462891e-02],
                        [  7.01904297e-03,   7.04956055e-03],
                        [ -5.20629883e-02,  -5.20324707e-02],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -7.57446289e-02,  -7.57751465e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -1.57165527e-02,  -1.56555176e-02],
                        [  3.23486328e-03,   3.26538086e-03],
                        [  1.15966797e-02,   1.15661621e-02],
                        [  1.56555176e-02,   1.56250000e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.50146484e-02,   1.50451660e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  5.54809570e-02,   5.55114746e-02],
                        [  5.62133789e-02,   5.61828613e-02],
                        [  5.57556152e-02,   5.57250977e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -8.69750977e-03,  -8.72802734e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  7.62939453e-04,   7.93457031e-04],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  3.10058594e-02,   3.09753418e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  2.28881836e-03,   2.31933594e-03],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -4.79431152e-02,  -4.79736328e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -6.40563965e-02,  -6.40258789e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -1.52587891e-03,  -1.55639648e-03],
                        [  5.26123047e-02,   5.25817871e-02],
                        [  1.02996826e-01,   1.03027344e-01],
                        [  1.29913330e-01,   1.29943848e-01],
                        [  1.22344971e-01,   1.22314453e-01],
                        [  8.83178711e-02,   8.82873535e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.15356445e-02,   1.15661621e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.09252930e-02,   1.08642578e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [ -7.32421875e-04,  -7.01904297e-04],
                        [ -1.60217285e-02,  -1.59912109e-02],
                        [ -2.20642090e-02,  -2.20947266e-02],
                        [ -1.66015625e-02,  -1.66320801e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -5.24902344e-03,  -5.21850586e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -2.22778320e-03,  -2.28881836e-03],
                        [  1.34277344e-03,   1.31225586e-03],
                        [  7.44628906e-03,   7.50732422e-03],
                        [  1.55334473e-02,   1.55639648e-02],
                        [  2.13317871e-02,   2.13012695e-02],
                        [  2.12402344e-02,   2.12097168e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  3.02124023e-02,   3.02429199e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  7.91015625e-02,   7.90710449e-02],
                        [  9.17968750e-02,   9.17663574e-02],
                        [  8.35571289e-02,   8.35876465e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [ -7.78503418e-02,  -7.78503418e-02],
                        [ -1.53747559e-01,  -1.53747559e-01],
                        [ -2.15576172e-01,  -2.15576172e-01],
                        [ -2.52746582e-01,  -2.52746582e-01],
                        [ -2.59857178e-01,  -2.59826660e-01],
                        [ -2.36572266e-01,  -2.36572266e-01],
                        [ -1.93725586e-01,  -1.93786621e-01],
                        [ -1.52069092e-01,  -1.52069092e-01],
                        [ -1.26983643e-01,  -1.26922607e-01],
                        [ -1.16363525e-01,  -1.16333008e-01],
                        [ -1.06079102e-01,  -1.06170654e-01],
                        [ -8.73718262e-02,  -8.74023438e-02],
                        [ -6.50329590e-02,  -6.49719238e-02],
                        [ -4.89501953e-02,  -4.89196777e-02],
                        [ -4.17785645e-02,  -4.18090820e-02],
                        [ -3.83911133e-02,  -3.84216309e-02],
                        [ -3.32336426e-02,  -3.32031250e-02],
                        [ -2.44445801e-02,  -2.44140625e-02],
                        [ -1.42822266e-02,  -1.42517090e-02],
                        [ -6.13403320e-03,  -6.16455078e-03],
                        [ -4.57763672e-04,  -4.88281250e-04],
                        [  5.34057617e-03,   5.37109375e-03],
                        [  1.25732422e-02,   1.26342773e-02],
                        [  1.92871094e-02,   1.92565918e-02],
                        [  2.13928223e-02,   2.13623047e-02],
                        [  1.58691406e-02,   1.59301758e-02],
                        [  5.61523438e-03,   5.64575195e-03],
                        [ -1.06811523e-03,  -1.09863281e-03],
                        [  5.79833984e-04,   5.49316406e-04],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.40380859e-02,   1.40686035e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  3.39660645e-02,   3.39355469e-02],
                        [  4.95300293e-02,   4.95605469e-02],
                        [  6.81457520e-02,   6.81762695e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  1.28967285e-01,   1.28936768e-01],
                        [  1.73614502e-01,   1.73614502e-01],
                        [  2.13378906e-01,   2.13439941e-01],
                        [  2.25982666e-01,   2.25952148e-01],
                        [  1.91802979e-01,   1.91772461e-01],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  6.40869141e-03,   6.43920898e-03],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -1.16149902e-01,  -1.16180420e-01],
                        [ -1.01654053e-01,  -1.01654053e-01],
                        [ -6.12487793e-02,  -6.12182617e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -1.17492676e-02,  -1.17797852e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  8.36181641e-03,   8.33129883e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  7.81250000e-03,   7.78198242e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.71203613e-02,   1.71508789e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  4.29077148e-02,   4.28771973e-02],
                        [  5.02319336e-02,   5.02014160e-02],
                        [  4.69970703e-02,   4.70275879e-02],
                        [  3.64379883e-02,   3.64685059e-02],
                        [  2.49633789e-02,   2.49328613e-02],
                        [  1.86462402e-02,   1.85852051e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  1.84326172e-02,   1.84631348e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.24206543e-02,   1.23901367e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -2.42919922e-02,  -2.43225098e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  8.04748535e-02,   8.04748535e-02],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  1.31256104e-01,   1.31286621e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  7.45849609e-02,   7.45544434e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  3.21044922e-02,   3.21350098e-02],
                        [  2.26745605e-02,   2.27050781e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  1.80358887e-02,   1.80053711e-02],
                        [  1.98974609e-02,   1.98669434e-02],
                        [  2.02331543e-02,   2.02636719e-02],
                        [  1.74865723e-02,   1.75170898e-02],
                        [  9.94873047e-03,   9.91821289e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -1.59912109e-02,  -1.59606934e-02],
                        [ -2.15759277e-02,  -2.15454102e-02],
                        [ -1.85852051e-02,  -1.86157227e-02],
                        [ -1.33972168e-02,  -1.34277344e-02],
                        [ -9.88769531e-03,  -9.85717773e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  4.13818359e-02,   4.14123535e-02],
                        [  5.69458008e-02,   5.69152832e-02],
                        [  6.55212402e-02,   6.54907227e-02],
                        [  6.85729980e-02,   6.86035156e-02],
                        [  7.14721680e-02,   7.15026855e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  8.23364258e-02,   8.23364258e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [ -1.85241699e-02,  -1.84936523e-02],
                        [ -9.90905762e-02,  -9.91210938e-02],
                        [ -1.85180664e-01,  -1.85211182e-01],
                        [ -2.55584717e-01,  -2.55554199e-01],
                        [ -2.88055420e-01,  -2.88024902e-01],
                        [ -2.72064209e-01,  -2.72064209e-01],
                        [ -2.22991943e-01,  -2.22991943e-01],
                        [ -1.74285889e-01,  -1.74285889e-01],
                        [ -1.45904541e-01,  -1.45904541e-01],
                        [ -1.30096436e-01,  -1.30065918e-01],
                        [ -1.12609863e-01,  -1.12579346e-01],
                        [ -9.28649902e-02,  -9.29260254e-02],
                        [ -7.78198242e-02,  -7.78503418e-02],
                        [ -6.90307617e-02,  -6.89697266e-02],
                        [ -6.30798340e-02,  -6.30798340e-02],
                        [ -5.66101074e-02,  -5.66406250e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -3.06701660e-02,  -3.06396484e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  3.78417969e-03,   3.75366211e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -1.44653320e-02,  -1.44348145e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  1.25732422e-02,   1.25427246e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  1.50024414e-01,   1.50024414e-01],
                        [  2.10693359e-01,   2.10693359e-01],
                        [  2.65228271e-01,   2.65228271e-01],
                        [  2.88787842e-01,   2.88818359e-01],
                        [  2.60162354e-01,   2.60162354e-01],
                        [  1.72882080e-01,   1.72851562e-01],
                        [  4.85229492e-02,   4.85229492e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -1.37390137e-01,  -1.37359619e-01],
                        [ -1.48010254e-01,  -1.48010254e-01],
                        [ -1.16058350e-01,  -1.16058350e-01],
                        [ -7.00683594e-02,  -7.00683594e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.44140625e-03,  -2.47192383e-03],
                        [ -6.80541992e-03,  -6.83593750e-03],
                        [ -2.32849121e-02,  -2.32543945e-02],
                        [ -3.92150879e-02,  -3.91845703e-02],
                        [ -3.81774902e-02,  -3.82080078e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  5.00183105e-02,   4.99877930e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  6.31408691e-02,   6.31713867e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [ -7.35473633e-03,  -7.32421875e-03],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.24914551e-02,  -2.24609375e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -3.66210938e-02,  -3.66516113e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.53393555e-02,  -3.53088379e-02],
                        [ -1.39770508e-02,  -1.40075684e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  7.25708008e-02,   7.25708008e-02],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  1.10839844e-01,   1.10839844e-01],
                        [  9.39941406e-02,   9.40246582e-02],
                        [  7.16552734e-02,   7.16247559e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [ -8.27026367e-03,  -8.30078125e-03],
                        [ -2.61230469e-02,  -2.60925293e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -9.76562500e-04,  -9.46044922e-04],
                        [  5.95092773e-03,   5.98144531e-03],
                        [  8.94165039e-03,   8.91113281e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  2.33154297e-02,   2.33459473e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  8.75244141e-02,   8.75549316e-02],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  1.11175537e-01,   1.11145020e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  7.98339844e-02,   7.98645020e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [ -1.15966797e-02,  -1.16271973e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -1.61285400e-01,  -1.61254883e-01],
                        [ -2.35107422e-01,  -2.35137939e-01],
                        [ -2.73071289e-01,  -2.73040771e-01],
                        [ -2.66265869e-01,  -2.66265869e-01],
                        [ -2.29980469e-01,  -2.30010986e-01],
                        [ -1.88171387e-01,  -1.88201904e-01],
                        [ -1.57836914e-01,  -1.57836914e-01],
                        [ -1.41632080e-01,  -1.41601562e-01],
                        [ -1.30310059e-01,  -1.30340576e-01],
                        [ -1.14990234e-01,  -1.14990234e-01],
                        [ -9.58862305e-02,  -9.58557129e-02],
                        [ -7.83996582e-02,  -7.83996582e-02],
                        [ -6.48498535e-02,  -6.48803711e-02],
                        [ -5.34667969e-02,  -5.34362793e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -2.77709961e-02,  -2.78015137e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -7.78198242e-03,  -7.75146484e-03],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  8.30078125e-03,   8.33129883e-03],
                        [  1.50146484e-02,   1.50451660e-02],
                        [  1.91650391e-02,   1.91345215e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -3.05175781e-03,  -3.08227539e-03],
                        [ -9.46044922e-03,  -9.42993164e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.65405273e-02,  -1.65710449e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.75476074e-02,  -1.75170898e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  6.97937012e-02,   6.98242188e-02],
                        [  1.48925781e-01,   1.48925781e-01],
                        [  2.33245850e-01,   2.33215332e-01],
                        [  2.99224854e-01,   2.99224854e-01],
                        [  3.30047607e-01,   3.30047607e-01],
                        [  3.17596436e-01,   3.17596436e-01],
                        [  2.58880615e-01,   2.58880615e-01],
                        [  1.57287598e-01,   1.57287598e-01],
                        [  3.08837891e-02,   3.08837891e-02],
                        [ -8.55712891e-02,  -8.55712891e-02],
                        [ -1.54754639e-01,  -1.54754639e-01],
                        [ -1.59332275e-01,  -1.59332275e-01],
                        [ -1.15997314e-01,  -1.16027832e-01],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.20947266e-02,  -2.21252441e-02],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  5.75561523e-02,   5.75256348e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  2.04772949e-02,   2.05078125e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -6.95800781e-03,  -6.98852539e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.09863281e-02,  -1.09558105e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -3.28674316e-02,  -3.28979492e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -3.55224609e-02,  -3.54919434e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [  1.17187500e-02,   1.16882324e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  9.54895020e-02,   9.55200195e-02],
                        [  1.15447998e-01,   1.15447998e-01],
                        [  1.09130859e-01,   1.09100342e-01],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  7.09228516e-02,   7.09228516e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  2.38037109e-02,   2.37731934e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.93884277e-02,  -2.94189453e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.22375488e-02,  -1.22070312e-02],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -4.27246094e-04,  -4.57763672e-04],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  4.11987305e-03,   4.15039062e-03],
                        [  2.00195312e-02,   1.99890137e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  5.84106445e-02,   5.84411621e-02],
                        [  6.36901855e-02,   6.36596680e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  8.20617676e-02,   8.20922852e-02],
                        [  1.02691650e-01,   1.02691650e-01],
                        [  1.16027832e-01,   1.15997314e-01],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  1.32751465e-02,   1.32446289e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -1.54571533e-01,  -1.54541016e-01],
                        [ -2.33184814e-01,  -2.33184814e-01],
                        [ -2.79052734e-01,  -2.79083252e-01],
                        [ -2.77496338e-01,  -2.77496338e-01],
                        [ -2.36663818e-01,  -2.36663818e-01],
                        [ -1.82464600e-01,  -1.82495117e-01],
                        [ -1.39648438e-01,  -1.39648438e-01],
                        [ -1.18713379e-01,  -1.18713379e-01],
                        [ -1.15966797e-01,  -1.15966797e-01],
                        [ -1.18225098e-01,  -1.18225098e-01],
                        [ -1.11511230e-01,  -1.11511230e-01],
                        [ -9.28344727e-02,  -9.28344727e-02],
                        [ -7.24487305e-02,  -7.24487305e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [  1.83105469e-03,   1.80053711e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  7.93457031e-03,   7.90405273e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.75476074e-02,  -1.75781250e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -1.27868652e-02,  -1.28173828e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  9.22241211e-02,   9.21936035e-02],
                        [  1.65008545e-01,   1.65008545e-01],
                        [  2.41638184e-01,   2.41638184e-01],
                        [  2.97515869e-01,   2.97485352e-01],
                        [  3.17535400e-01,   3.17535400e-01],
                        [  3.02093506e-01,   3.02093506e-01],
                        [  2.59643555e-01,   2.59643555e-01],
                        [  1.96472168e-01,   1.96472168e-01],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.20239258e-02,   1.20544434e-02],
                        [ -8.78295898e-02,  -8.78295898e-02],
                        [ -1.54235840e-01,  -1.54235840e-01],
                        [ -1.62261963e-01,  -1.62261963e-01],
                        [ -1.19140625e-01,  -1.19140625e-01],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -6.65893555e-02,  -6.65588379e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.15234375e-02,  -6.15234375e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -3.54614258e-02,  -3.54309082e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  4.88281250e-02,   4.88586426e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  6.43615723e-02,   6.43310547e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -2.42919922e-02,  -2.43225098e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -1.78833008e-02,  -1.79138184e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -2.35290527e-02,  -2.34985352e-02],
                        [ -3.60412598e-02,  -3.60717773e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  8.47473145e-02,   8.47473145e-02],
                        [  1.14929199e-01,   1.14929199e-01],
                        [  1.22711182e-01,   1.22680664e-01],
                        [  1.09252930e-01,   1.09252930e-01],
                        [  8.15124512e-02,   8.15124512e-02],
                        [  5.09643555e-02,   5.09643555e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  1.66931152e-02,   1.67236328e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.12609863e-02,   1.12304688e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  3.78417969e-03,   3.81469727e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -7.23266602e-03,  -7.26318359e-03],
                        [ -1.69067383e-02,  -1.68762207e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.62145996e-02,  -2.62451172e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.00097656e-02,  -9.97924805e-03],
                        [  7.44628906e-03,   7.41577148e-03],
                        [  2.91748047e-02,   2.91442871e-02],
                        [  5.11779785e-02,   5.12084961e-02],
                        [  7.14416504e-02,   7.14721680e-02],
                        [  9.14611816e-02,   9.14306641e-02],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  1.23626709e-01,   1.23657227e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [ -7.43103027e-02,  -7.43103027e-02],
                        [ -1.73187256e-01,  -1.73187256e-01],
                        [ -2.57965088e-01,  -2.57965088e-01],
                        [ -3.10333252e-01,  -3.10333252e-01],
                        [ -3.15277100e-01,  -3.15277100e-01],
                        [ -2.72369385e-01,  -2.72369385e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -1.51763916e-01,  -1.51763916e-01],
                        [ -1.23779297e-01,  -1.23779297e-01],
                        [ -1.09191895e-01,  -1.09191895e-01],
                        [ -9.17968750e-02,  -9.17663574e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.35070801e-02,  -6.34765625e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -6.67419434e-02,  -6.67724609e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -5.21850586e-03,  -5.24902344e-03],
                        [  5.55419922e-03,   5.52368164e-03],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -3.44848633e-03,  -3.47900391e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -1.70898438e-02,  -1.71203613e-02],
                        [ -2.67639160e-02,  -2.67333984e-02],
                        [ -3.63464355e-02,  -3.63769531e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.31115723e-02,  -3.30810547e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  2.38037109e-02,   2.38342285e-02],
                        [  7.22656250e-02,   7.22656250e-02],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.88964844e-01,   1.88964844e-01],
                        [  2.39593506e-01,   2.39593506e-01],
                        [  2.72766113e-01,   2.72766113e-01],
                        [  2.82409668e-01,   2.82409668e-01],
                        [  2.70507812e-01,   2.70538330e-01],
                        [  2.45941162e-01,   2.45941162e-01],
                        [  2.14874268e-01,   2.14874268e-01],
                        [  1.71905518e-01,   1.71905518e-01],
                        [  1.05621338e-01,   1.05590820e-01],
                        [  1.52282715e-02,   1.52282715e-02],
                        [ -8.00170898e-02,  -8.00170898e-02],
                        [ -1.49169922e-01,  -1.49169922e-01],
                        [ -1.71600342e-01,  -1.71630859e-01],
                        [ -1.54632568e-01,  -1.54602051e-01],
                        [ -1.24786377e-01,  -1.24786377e-01],
                        [ -1.02539062e-01,  -1.02539062e-01],
                        [ -9.05761719e-02,  -9.05761719e-02],
                        [ -8.26721191e-02,  -8.26416016e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -1.64794922e-03,  -1.67846680e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.93786621e-02,   1.94091797e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  4.36096191e-02,   4.36401367e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  3.91540527e-02,   3.91235352e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -9.33837891e-03,  -9.30786133e-03],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -3.26538086e-02,  -3.26843262e-02],
                        [ -5.03845215e-02,  -5.03540039e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -2.72216797e-02,  -2.71911621e-02],
                        [  1.14440918e-02,   1.14135742e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  1.11816406e-01,   1.11816406e-01],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  1.60827637e-02,   1.61132812e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.53503418e-02,  -1.53808594e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  1.13525391e-02,   1.13220215e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  7.29675293e-02,   7.29370117e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  1.29974365e-01,   1.29974365e-01],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  1.20513916e-01,   1.20513916e-01],
                        [  7.88879395e-02,   7.88879395e-02],
                        [  7.81250000e-03,   7.78198242e-03],
                        [ -8.65478516e-02,  -8.65478516e-02],
                        [ -1.86553955e-01,  -1.86553955e-01],
                        [ -2.63488770e-01,  -2.63519287e-01],
                        [ -2.92541504e-01,  -2.92541504e-01],
                        [ -2.71911621e-01,  -2.71911621e-01],
                        [ -2.23480225e-01,  -2.23510742e-01],
                        [ -1.75323486e-01,  -1.75323486e-01],
                        [ -1.44287109e-01,  -1.44287109e-01],
                        [ -1.29364014e-01,  -1.29364014e-01],
                        [ -1.17584229e-01,  -1.17584229e-01],
                        [ -1.00006104e-01,  -1.00006104e-01],
                        [ -8.12683105e-02,  -8.12683105e-02],
                        [ -7.07702637e-02,  -7.07702637e-02],
                        [ -6.75048828e-02,  -6.75048828e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -5.15747070e-03,  -5.18798828e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -5.08422852e-02,  -5.08117676e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.95983887e-01,   1.95983887e-01],
                        [  2.39349365e-01,   2.39349365e-01],
                        [  2.50335693e-01,   2.50335693e-01],
                        [  2.39562988e-01,   2.39562988e-01],
                        [  2.26226807e-01,   2.26196289e-01],
                        [  2.21588135e-01,   2.21588135e-01],
                        [  2.22564697e-01,   2.22595215e-01],
                        [  2.16705322e-01,   2.16705322e-01],
                        [  1.91345215e-01,   1.91345215e-01],
                        [  1.40014648e-01,   1.40014648e-01],
                        [  6.42089844e-02,   6.42089844e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -1.57745361e-01,  -1.57745361e-01],
                        [ -1.64337158e-01,  -1.64337158e-01],
                        [ -1.36352539e-01,  -1.36383057e-01],
                        [ -1.01318359e-01,  -1.01318359e-01],
                        [ -8.40148926e-02,  -8.40148926e-02],
                        [ -8.50219727e-02,  -8.50524902e-02],
                        [ -8.41979980e-02,  -8.41979980e-02],
                        [ -6.73522949e-02,  -6.73217773e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  1.44348145e-02,   1.44653320e-02],
                        [  2.47192383e-02,   2.46887207e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.10668945e-02,   3.10974121e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  2.67333984e-02,   2.67639160e-02],
                        [  1.29089355e-02,   1.29394531e-02],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -5.34667969e-02,  -5.34362793e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  8.05053711e-02,   8.05053711e-02],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  8.06884766e-02,   8.06579590e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  2.36816406e-02,   2.36511230e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  6.65283203e-03,   6.68334961e-03],
                        [ -9.06372070e-03,  -9.09423828e-03],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  3.75366211e-03,   3.78417969e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  1.32141113e-02,   1.32446289e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  7.33642578e-02,   7.33642578e-02],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  1.33911133e-01,   1.33880615e-01],
                        [  1.57379150e-01,   1.57379150e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  6.05773926e-02,   6.05773926e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.11999512e-01,  -1.11999512e-01],
                        [ -2.07031250e-01,  -2.07031250e-01],
                        [ -2.79205322e-01,  -2.79205322e-01],
                        [ -3.05053711e-01,  -3.05053711e-01],
                        [ -2.79876709e-01,  -2.79876709e-01],
                        [ -2.25006104e-01,  -2.25006104e-01],
                        [ -1.73980713e-01,  -1.73980713e-01],
                        [ -1.46667480e-01,  -1.46697998e-01],
                        [ -1.36535645e-01,  -1.36566162e-01],
                        [ -1.24694824e-01,  -1.24694824e-01],
                        [ -1.01562500e-01,  -1.01562500e-01],
                        [ -7.24792480e-02,  -7.24792480e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -3.59497070e-02,  -3.59191895e-02],
                        [ -3.06396484e-02,  -3.06701660e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.65100098e-02,  -1.65405273e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -4.79125977e-03,  -4.82177734e-03],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.93981934e-02,  -3.94287109e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  1.43035889e-01,   1.43035889e-01],
                        [  1.90185547e-01,   1.90185547e-01],
                        [  2.20092773e-01,   2.20092773e-01],
                        [  2.27020264e-01,   2.27020264e-01],
                        [  2.17712402e-01,   2.17712402e-01],
                        [  2.07885742e-01,   2.07885742e-01],
                        [  2.08465576e-01,   2.08465576e-01],
                        [  2.15881348e-01,   2.15881348e-01],
                        [  2.17285156e-01,   2.17285156e-01],
                        [  2.00927734e-01,   2.00927734e-01],
                        [  1.59362793e-01,   1.59362793e-01],
                        [  8.85009766e-02,   8.85009766e-02],
                        [ -7.44628906e-03,  -7.41577148e-03],
                        [ -1.07879639e-01,  -1.07879639e-01],
                        [ -1.81365967e-01,  -1.81396484e-01],
                        [ -2.06268311e-01,  -2.06237793e-01],
                        [ -1.85791016e-01,  -1.85760498e-01],
                        [ -1.43707275e-01,  -1.43737793e-01],
                        [ -1.06597900e-01,  -1.06597900e-01],
                        [ -8.56018066e-02,  -8.56018066e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.32751465e-02,  -1.33056641e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  1.23626709e-01,   1.23626709e-01],
                        [  1.30310059e-01,   1.30310059e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  1.04064941e-01,   1.04064941e-01],
                        [  1.30310059e-01,   1.30310059e-01],
                        [  1.47735596e-01,   1.47735596e-01],
                        [  1.47216797e-01,   1.47186279e-01],
                        [  1.23352051e-01,   1.23352051e-01],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [ -6.82678223e-02,  -6.82678223e-02],
                        [ -1.54785156e-01,  -1.54785156e-01],
                        [ -2.36877441e-01,  -2.36877441e-01],
                        [ -2.90832520e-01,  -2.90863037e-01],
                        [ -2.94982910e-01,  -2.94982910e-01],
                        [ -2.54608154e-01,  -2.54577637e-01],
                        [ -2.01995850e-01,  -2.02026367e-01],
                        [ -1.64978027e-01,  -1.64978027e-01],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -1.26678467e-01,  -1.26678467e-01],
                        [ -1.06353760e-01,  -1.06353760e-01],
                        [ -8.65478516e-02,  -8.65478516e-02],
                        [ -6.92443848e-02,  -6.92138672e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.51660156e-02,  -4.51354980e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -2.17590332e-02,  -2.17285156e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -4.82177734e-02,  -4.81872559e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  7.27233887e-02,   7.27233887e-02],
                        [  1.19873047e-01,   1.19903564e-01],
                        [  1.66229248e-01,   1.66229248e-01],
                        [  2.07489014e-01,   2.07489014e-01],
                        [  2.30560303e-01,   2.30560303e-01],
                        [  2.26562500e-01,   2.26562500e-01],
                        [  2.04223633e-01,   2.04223633e-01],
                        [  1.82922363e-01,   1.82922363e-01],
                        [  1.73309326e-01,   1.73309326e-01],
                        [  1.72149658e-01,   1.72149658e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  1.69982910e-01,   1.69982910e-01],
                        [  1.62322998e-01,   1.62322998e-01],
                        [  1.42639160e-01,   1.42639160e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  1.91955566e-02,   1.92260742e-02],
                        [ -8.07495117e-02,  -8.07495117e-02],
                        [ -1.67358398e-01,  -1.67358398e-01],
                        [ -2.09777832e-01,  -2.09777832e-01],
                        [ -2.02697754e-01,  -2.02697754e-01],
                        [ -1.63665771e-01,  -1.63665771e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -8.75854492e-02,  -8.75854492e-02],
                        [ -7.11059570e-02,  -7.11059570e-02],
                        [ -5.65490723e-02,  -5.65490723e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [  6.40869141e-04,   6.71386719e-04],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [ -8.85009766e-03,  -8.85009766e-03],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -3.26843262e-02,  -3.27148438e-02],
                        [  2.02026367e-02,   2.02331543e-02],
                        [  8.25195312e-02,   8.25195312e-02],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.40594482e-01,   1.40594482e-01],
                        [  1.20727539e-01,   1.20727539e-01],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  5.19104004e-02,   5.19104004e-02],
                        [  3.22265625e-02,   3.22570801e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.61437988e-02,   1.61743164e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  4.46166992e-02,   4.45861816e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.46972656e-01,   1.47003174e-01],
                        [  1.43035889e-01,   1.43035889e-01],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  3.86962891e-02,   3.86962891e-02],
                        [ -5.66711426e-02,  -5.66711426e-02],
                        [ -1.62048340e-01,  -1.62048340e-01],
                        [ -2.54699707e-01,  -2.54699707e-01],
                        [ -3.06823730e-01,  -3.06823730e-01],
                        [ -3.00170898e-01,  -3.00170898e-01],
                        [ -2.48138428e-01,  -2.48138428e-01],
                        [ -1.90429688e-01,  -1.90460205e-01],
                        [ -1.55273438e-01,  -1.55273438e-01],
                        [ -1.36047363e-01,  -1.36047363e-01],
                        [ -1.12945557e-01,  -1.12945557e-01],
                        [ -8.49609375e-02,  -8.49609375e-02],
                        [ -6.68029785e-02,  -6.67724609e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [  2.62451172e-03,   2.65502930e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -5.66101074e-02,  -5.65795898e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -7.32116699e-02,  -7.32116699e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  9.50622559e-02,   9.50622559e-02],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.87164307e-01,   1.87164307e-01],
                        [  2.12829590e-01,   2.12829590e-01],
                        [  2.11669922e-01,   2.11669922e-01],
                        [  1.90765381e-01,   1.90765381e-01],
                        [  1.66687012e-01,   1.66687012e-01],
                        [  1.48529053e-01,   1.48529053e-01],
                        [  1.35955811e-01,   1.35955811e-01],
                        [  1.28265381e-01,   1.28265381e-01],
                        [  1.27716064e-01,   1.27716064e-01],
                        [  1.35284424e-01,   1.35284424e-01],
                        [  1.47308350e-01,   1.47308350e-01],
                        [  1.54205322e-01,   1.54205322e-01],
                        [  1.41845703e-01,   1.41845703e-01],
                        [  9.79003906e-02,   9.79309082e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [ -7.67211914e-02,  -7.67211914e-02],
                        [ -1.66137695e-01,  -1.66137695e-01],
                        [ -2.11608887e-01,  -2.11608887e-01],
                        [ -1.93145752e-01,  -1.93145752e-01],
                        [ -1.30798340e-01,  -1.30798340e-01],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  2.89001465e-02,   2.89306641e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -5.20935059e-02,  -5.21240234e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.32751465e-01,   1.32751465e-01],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  6.07604980e-02,   6.07299805e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  6.52770996e-02,   6.52770996e-02],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  1.15447998e-01,   1.15447998e-01],
                        [  1.29425049e-01,   1.29394531e-01],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  1.27960205e-01,   1.27960205e-01],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  5.81359863e-02,   5.81359863e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -1.25732422e-01,  -1.25732422e-01],
                        [ -2.23449707e-01,  -2.23480225e-01],
                        [ -2.89825439e-01,  -2.89825439e-01],
                        [ -3.04443359e-01,  -3.04443359e-01],
                        [ -2.68157959e-01,  -2.68188477e-01],
                        [ -2.07458496e-01,  -2.07458496e-01],
                        [ -1.54022217e-01,  -1.53991699e-01],
                        [ -1.20819092e-01,  -1.20819092e-01],
                        [ -1.02050781e-01,  -1.02050781e-01],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -7.77282715e-02,  -7.77282715e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -6.54907227e-02,  -6.54602051e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -7.35778809e-02,  -7.35778809e-02],
                        [ -7.76062012e-02,  -7.75756836e-02],
                        [ -7.15942383e-02,  -7.16247559e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  9.10339355e-02,   9.10034180e-02],
                        [  1.54998779e-01,   1.54998779e-01],
                        [  2.08923340e-01,   2.08923340e-01],
                        [  2.37243652e-01,   2.37243652e-01],
                        [  2.34008789e-01,   2.34008789e-01],
                        [  2.06939697e-01,   2.06939697e-01],
                        [  1.71569824e-01,   1.71539307e-01],
                        [  1.40228271e-01,   1.40228271e-01],
                        [  1.17340088e-01,   1.17340088e-01],
                        [  1.03240967e-01,   1.03240967e-01],
                        [  9.88159180e-02,   9.88159180e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.13525391e-01,   1.13525391e-01],
                        [  1.25091553e-01,   1.25091553e-01],
                        [  1.36169434e-01,   1.36169434e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.15051270e-01,   1.15051270e-01],
                        [  5.17883301e-02,   5.17883301e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -1.37542725e-01,  -1.37542725e-01],
                        [ -1.97265625e-01,  -1.97265625e-01],
                        [ -2.04467773e-01,  -2.04467773e-01],
                        [ -1.68914795e-01,  -1.68914795e-01],
                        [ -1.17675781e-01,  -1.17675781e-01],
                        [ -7.65380859e-02,  -7.65380859e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  5.31005859e-03,   5.34057617e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -2.09655762e-02,  -2.09960938e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -1.91650391e-02,  -1.91345215e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  1.04614258e-01,   1.04644775e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  4.57458496e-02,   4.57458496e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  1.12823486e-01,   1.12823486e-01],
                        [  1.37542725e-01,   1.37542725e-01],
                        [  1.50665283e-01,   1.50665283e-01],
                        [  1.52954102e-01,   1.52954102e-01],
                        [  1.41082764e-01,   1.41082764e-01],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  3.03955078e-02,   3.03955078e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -1.78649902e-01,  -1.78649902e-01],
                        [ -2.73376465e-01,  -2.73376465e-01],
                        [ -3.21685791e-01,  -3.21685791e-01],
                        [ -3.04840088e-01,  -3.04840088e-01],
                        [ -2.38677979e-01,  -2.38677979e-01],
                        [ -1.67877197e-01,  -1.67877197e-01],
                        [ -1.27807617e-01,  -1.27807617e-01],
                        [ -1.15173340e-01,  -1.15173340e-01],
                        [ -1.03424072e-01,  -1.03424072e-01],
                        [ -8.05969238e-02,  -8.05969238e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.41687012e-02,  -5.41992188e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -7.80029297e-02,  -7.80029297e-02],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -7.56530762e-02,  -7.56530762e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  1.45751953e-01,   1.45751953e-01],
                        [  2.02575684e-01,   2.02575684e-01],
                        [  2.34222412e-01,   2.34222412e-01],
                        [  2.31719971e-01,   2.31719971e-01],
                        [  2.04040527e-01,   2.04040527e-01],
                        [  1.67785645e-01,   1.67785645e-01],
                        [  1.35559082e-01,   1.35559082e-01],
                        [  1.14349365e-01,   1.14349365e-01],
                        [  1.06048584e-01,   1.06048584e-01],
                        [  1.08032227e-01,   1.08032227e-01],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.43676758e-01,   1.43676758e-01],
                        [  1.42639160e-01,   1.42639160e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.00097656e-01,   1.00097656e-01],
                        [  4.07714844e-02,   4.07714844e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -1.29669189e-01,  -1.29669189e-01],
                        [ -1.87652588e-01,  -1.87652588e-01],
                        [ -1.99249268e-01,  -1.99249268e-01],
                        [ -1.69647217e-01,  -1.69647217e-01],
                        [ -1.20330811e-01,  -1.20330811e-01],
                        [ -7.58972168e-02,  -7.58972168e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  1.18896484e-01,   1.18896484e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.58477783e-01,   1.58477783e-01],
                        [  1.56036377e-01,   1.56036377e-01],
                        [  1.36230469e-01,   1.36230469e-01],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -1.67388916e-01,  -1.67388916e-01],
                        [ -2.61352539e-01,  -2.61352539e-01],
                        [ -3.13079834e-01,  -3.13079834e-01],
                        [ -2.98400879e-01,  -2.98400879e-01],
                        [ -2.30834961e-01,  -2.30834961e-01],
                        [ -1.56738281e-01,  -1.56738281e-01],
                        [ -1.13983154e-01,  -1.13983154e-01],
                        [ -1.01928711e-01,  -1.01928711e-01],
                        [ -9.75646973e-02,  -9.75646973e-02],
                        [ -8.89587402e-02,  -8.89587402e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -7.82165527e-02,  -7.82165527e-02],
                        [ -7.72094727e-02,  -7.72094727e-02],
                        [ -7.27844238e-02,  -7.27844238e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -2.81677246e-02,  -2.81982422e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -7.27844238e-02,  -7.27844238e-02],
                        [ -7.44018555e-02,  -7.44018555e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  1.14044189e-01,   1.14044189e-01],
                        [  1.69769287e-01,   1.69769287e-01],
                        [  2.00897217e-01,   2.00897217e-01],
                        [  2.04193115e-01,   2.04193115e-01],
                        [  1.86645508e-01,   1.86645508e-01],
                        [  1.60308838e-01,   1.60308838e-01],
                        [  1.35223389e-01,   1.35223389e-01],
                        [  1.15814209e-01,   1.15814209e-01],
                        [  1.02172852e-01,   1.02172852e-01],
                        [  9.33227539e-02,   9.33227539e-02],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  6.34765625e-02,   6.34765625e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -8.27331543e-02,  -8.27331543e-02],
                        [ -1.55792236e-01,  -1.55792236e-01],
                        [ -1.97875977e-01,  -1.97875977e-01],
                        [ -1.94610596e-01,  -1.94610596e-01],
                        [ -1.54541016e-01,  -1.54541016e-01],
                        [ -1.07574463e-01,  -1.07574463e-01],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -7.25402832e-02,  -7.25402832e-02],
                        [ -6.46362305e-02,  -6.46362305e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  8.54492188e-02,   8.54492188e-02],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  8.34350586e-02,   8.34350586e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  1.25366211e-01,   1.25366211e-01],
                        [  1.50573730e-01,   1.50573730e-01],
                        [  1.59576416e-01,   1.59576416e-01],
                        [  1.43371582e-01,   1.43371582e-01],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  3.71704102e-02,   3.71704102e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -1.53900146e-01,  -1.53900146e-01],
                        [ -2.52380371e-01,  -2.52380371e-01],
                        [ -3.07800293e-01,  -3.07800293e-01],
                        [ -2.94525146e-01,  -2.94525146e-01],
                        [ -2.25982666e-01,  -2.25982666e-01],
                        [ -1.50054932e-01,  -1.50054932e-01],
                        [ -1.07574463e-01,  -1.07574463e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -9.81445312e-02,  -9.81445312e-02],
                        [ -9.21630859e-02,  -9.21630859e-02],
                        [ -8.40148926e-02,  -8.40148926e-02],
                        [ -7.53479004e-02,  -7.53479004e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -7.11669922e-02,  -7.11669922e-02],
                        [ -7.35168457e-02,  -7.35168457e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  1.41021729e-01,   1.41021729e-01],
                        [  1.87683105e-01,   1.87683105e-01],
                        [  2.05169678e-01,   2.05169678e-01],
                        [  1.92077637e-01,   1.92077637e-01],
                        [  1.60369873e-01,   1.60369873e-01],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.08245850e-01,   1.08245850e-01],
                        [  1.03179932e-01,   1.03179932e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  6.77795410e-02,   6.77795410e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  6.28356934e-02,   6.28356934e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -9.69848633e-02,  -9.69848633e-02],
                        [ -1.72760010e-01,  -1.72760010e-01],
                        [ -2.07611084e-01,  -2.07611084e-01],
                        [ -1.93084717e-01,  -1.93084717e-01],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -1.11724854e-01,  -1.11724854e-01],
                        [ -8.86840820e-02,  -8.86840820e-02],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -6.43920898e-02,  -6.43920898e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.72290039e-02,   9.72290039e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  1.40228271e-01,   1.40228271e-01],
                        [  1.60980225e-01,   1.60980225e-01],
                        [  1.65924072e-01,   1.65924072e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  9.59167480e-02,   9.59167480e-02],
                        [  1.40380859e-02,   1.40380859e-02],
                        [ -8.74633789e-02,  -8.74633789e-02],
                        [ -1.85516357e-01,  -1.85516357e-01],
                        [ -2.56713867e-01,  -2.56713867e-01],
                        [ -2.84912109e-01,  -2.84912109e-01],
                        [ -2.65380859e-01,  -2.65380859e-01],
                        [ -2.12005615e-01,  -2.12005615e-01],
                        [ -1.55609131e-01,  -1.55609131e-01],
                        [ -1.22283936e-01,  -1.22283936e-01],
                        [ -1.12030029e-01,  -1.12030029e-01],
                        [ -1.06475830e-01,  -1.06475830e-01],
                        [ -9.45129395e-02,  -9.45129395e-02],
                        [ -8.20617676e-02,  -8.20617676e-02],
                        [ -7.67517090e-02,  -7.67517090e-02],
                        [ -7.28149414e-02,  -7.28149414e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  1.74621582e-01,   1.74621582e-01],
                        [  2.09747314e-01,   2.09747314e-01],
                        [  2.09960938e-01,   2.09960938e-01],
                        [  1.83013916e-01,   1.83013916e-01],
                        [  1.47277832e-01,   1.47277832e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  5.94177246e-02,   5.94177246e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -1.29516602e-01,  -1.29516602e-01],
                        [ -1.55517578e-01,  -1.55517578e-01],
                        [ -1.51214600e-01,  -1.51214600e-01],
                        [ -1.28936768e-01,  -1.28936768e-01],
                        [ -1.03057861e-01,  -1.03057861e-01],
                        [ -8.20922852e-02,  -8.20922852e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -8.09020996e-02,  -8.09020996e-02],
                        [ -8.54492188e-02,  -8.54492188e-02],
                        [ -7.61718750e-02,  -7.61718750e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  5.34362793e-02,   5.34362793e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  1.06231689e-01,   1.06231689e-01],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  2.76489258e-02,   2.76489258e-02],
                        [  3.28979492e-02,   3.28979492e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.42364502e-01,   1.42364502e-01],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  7.16247559e-02,   7.16247559e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -1.14257812e-01,  -1.14257812e-01],
                        [ -2.05474854e-01,  -2.05474854e-01],
                        [ -2.65411377e-01,  -2.65411377e-01],
                        [ -2.77099609e-01,  -2.77099609e-01],
                        [ -2.43316650e-01,  -2.43316650e-01],
                        [ -1.90124512e-01,  -1.90124512e-01],
                        [ -1.46148682e-01,  -1.46148682e-01],
                        [ -1.19567871e-01,  -1.19567871e-01],
                        [ -1.01623535e-01,  -1.01623535e-01],
                        [ -8.56018066e-02,  -8.56018066e-02],
                        [ -7.35168457e-02,  -7.35168457e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -7.86132812e-02,  -7.86132812e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.77886963e-01,   1.77886963e-01],
                        [  1.99096680e-01,   1.99096680e-01],
                        [  1.91589355e-01,   1.91589355e-01],
                        [  1.65069580e-01,   1.65069580e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.07177734e-01,   1.07177734e-01],
                        [  9.13085938e-02,   9.13085938e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  7.08312988e-02,   7.08312988e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  7.07092285e-02,   7.07092285e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  1.07269287e-01,   1.07269287e-01],
                        [  7.96813965e-02,   7.96813965e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -1.36352539e-01,  -1.36352539e-01],
                        [ -1.94000244e-01,  -1.94000244e-01],
                        [ -2.02056885e-01,  -2.02056885e-01],
                        [ -1.70440674e-01,  -1.70440674e-01],
                        [ -1.29760742e-01,  -1.29760742e-01],
                        [ -1.02478027e-01,  -1.02478027e-01],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -8.59069824e-02,  -8.59069824e-02],
                        [ -8.65783691e-02,  -8.65783691e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  6.93054199e-02,   6.93054199e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  8.45336914e-02,   8.45336914e-02],
                        [  1.10198975e-01,   1.10198975e-01],
                        [  1.29882812e-01,   1.29882812e-01],
                        [  1.36077881e-01,   1.36077881e-01],
                        [  1.22619629e-01,   1.22619629e-01],
                        [  8.30078125e-02,   8.30078125e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -1.68273926e-01,  -1.68273926e-01],
                        [ -2.44232178e-01,  -2.44232178e-01],
                        [ -2.71789551e-01,  -2.71789551e-01],
                        [ -2.43988037e-01,  -2.43988037e-01],
                        [ -1.86157227e-01,  -1.86157227e-01],
                        [ -1.33819580e-01,  -1.33819580e-01],
                        [ -1.05987549e-01,  -1.05987549e-01],
                        [ -9.90600586e-02,  -9.90600586e-02],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -8.35266113e-02,  -8.35266113e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -7.37304688e-02,  -7.37304688e-02],
                        [ -7.01293945e-02,  -7.01293945e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  1.34033203e-01,   1.34033203e-01],
                        [  1.99737549e-01,   1.99737549e-01],
                        [  2.34222412e-01,   2.34222412e-01],
                        [  2.27539062e-01,   2.27539062e-01],
                        [  1.87927246e-01,   1.87927246e-01],
                        [  1.38824463e-01,   1.38824463e-01],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  9.42687988e-02,   9.42687988e-02],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  1.23413086e-01,   1.23413086e-01],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -8.78906250e-02,  -8.78906250e-02],
                        [ -1.69586182e-01,  -1.69586182e-01],
                        [ -2.14782715e-01,  -2.14782715e-01],
                        [ -2.09045410e-01,  -2.09045410e-01],
                        [ -1.67846680e-01,  -1.67846680e-01],
                        [ -1.20605469e-01,  -1.20605469e-01],
                        [ -8.54797363e-02,  -8.54797363e-02],
                        [ -6.35681152e-02,  -6.35681152e-02],
                        [ -4.97741699e-02,  -4.97741699e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -8.05358887e-02,  -8.05358887e-02],
                        [ -9.75036621e-02,  -9.75036621e-02],
                        [ -9.71984863e-02,  -9.71984863e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  7.78198242e-02,   7.78198242e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  7.37304688e-02,   7.37304688e-02],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  7.34863281e-02,   7.34863281e-02],
                        [  9.39331055e-02,   9.39331055e-02],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.42547607e-01,   1.42547607e-01],
                        [  1.39404297e-01,   1.39404297e-01],
                        [  1.01104736e-01,   1.01104736e-01],
                        [  2.45361328e-02,   2.45361328e-02],
                        [ -8.04748535e-02,  -8.04748535e-02],
                        [ -1.88720703e-01,  -1.88720703e-01],
                        [ -2.67608643e-01,  -2.67608643e-01],
                        [ -2.92663574e-01,  -2.92663574e-01],
                        [ -2.61291504e-01,  -2.61291504e-01],
                        [ -1.95770264e-01,  -1.95770264e-01],
                        [ -1.29486084e-01,  -1.29486084e-01],
                        [ -8.70666504e-02,  -8.70666504e-02],
                        [ -7.36694336e-02,  -7.36694336e-02],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -8.58459473e-02,  -8.58459473e-02],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  1.42364502e-01,   1.42364502e-01],
                        [  1.88903809e-01,   1.88903809e-01],
                        [  2.05291748e-01,   2.05291748e-01],
                        [  1.91040039e-01,   1.91040039e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.00280762e-01,   1.00280762e-01],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  6.19812012e-02,   6.19812012e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.26953125e-01,   1.26953125e-01],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  8.63037109e-02,   8.63037109e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [ -8.53576660e-02,  -8.53576660e-02],
                        [ -1.69647217e-01,  -1.69647217e-01],
                        [ -2.17864990e-01,  -2.17864990e-01],
                        [ -2.18261719e-01,  -2.18261719e-01],
                        [ -1.79382324e-01,  -1.79382324e-01],
                        [ -1.27380371e-01,  -1.27380371e-01],
                        [ -8.73718262e-02,  -8.73718262e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.84411621e-02,  -5.84411621e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -7.07397461e-02,  -7.07397461e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -7.81860352e-02,  -7.81860352e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  9.37194824e-02,   9.37194824e-02],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  1.00830078e-01,   1.00830078e-01],
                        [  8.28552246e-02,   8.28552246e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  6.80847168e-02,   6.80847168e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  7.28759766e-02,   7.28759766e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  8.15429688e-02,   8.15429688e-02],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.51306152e-01,   1.51306152e-01],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [ -7.49816895e-02,  -7.49816895e-02],
                        [ -1.82952881e-01,  -1.82952881e-01],
                        [ -2.67730713e-01,  -2.67730713e-01],
                        [ -2.99041748e-01,  -2.99041748e-01],
                        [ -2.72918701e-01,  -2.72918701e-01],
                        [ -2.13226318e-01,  -2.13226318e-01],
                        [ -1.52526855e-01,  -1.52526855e-01],
                        [ -1.11541748e-01,  -1.11541748e-01],
                        [ -9.18273926e-02,  -9.18273926e-02],
                        [ -8.23364258e-02,  -8.23364258e-02],
                        [ -7.23571777e-02,  -7.23571777e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -7.26318359e-02,  -7.26318359e-02],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  1.37725830e-01,   1.37725830e-01],
                        [  1.91741943e-01,   1.91741943e-01],
                        [  2.14385986e-01,   2.14385986e-01],
                        [  2.03155518e-01,   2.03155518e-01],
                        [  1.75109863e-01,   1.75109863e-01],
                        [  1.45080566e-01,   1.45080566e-01],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  8.33435059e-02,   8.33435059e-02],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  9.91210938e-02,   9.91210938e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  1.98364258e-03,   1.98364258e-03],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -1.46301270e-01,  -1.46301270e-01],
                        [ -1.90643311e-01,  -1.90643311e-01],
                        [ -1.95343018e-01,  -1.95343018e-01],
                        [ -1.65191650e-01,  -1.65191650e-01],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -8.38317871e-02,  -8.38317871e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -7.69653320e-02,  -7.69653320e-02],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -7.55615234e-02,  -7.55615234e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -9.25598145e-02,  -9.25598145e-02],
                        [ -1.04095459e-01,  -1.04095459e-01],
                        [ -9.82971191e-02,  -9.82971191e-02],
                        [ -6.98547363e-02,  -6.98547363e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  9.23156738e-02,   9.23156738e-02],
                        [  1.21124268e-01,   1.21124268e-01],
                        [  1.24420166e-01,   1.24420166e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  7.84912109e-02,   7.84912109e-02],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  5.10864258e-02,   5.10864258e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  6.13403320e-02,   6.13403320e-02],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  1.13677979e-01,   1.13677979e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.37756348e-01,   1.37756348e-01],
                        [  1.25854492e-01,   1.25854492e-01],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [ -8.64562988e-02,  -8.64562988e-02],
                        [ -2.00012207e-01,  -2.00012207e-01],
                        [ -2.81738281e-01,  -2.81738281e-01],
                        [ -3.06121826e-01,  -3.06121826e-01],
                        [ -2.75970459e-01,  -2.75970459e-01],
                        [ -2.15393066e-01,  -2.15393066e-01],
                        [ -1.55914307e-01,  -1.55914307e-01],
                        [ -1.18957520e-01,  -1.18957520e-01],
                        [ -1.02569580e-01,  -1.02569580e-01],
                        [ -9.19189453e-02,  -9.19189453e-02],
                        [ -8.04748535e-02,  -8.04748535e-02],
                        [ -7.09228516e-02,  -7.09228516e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -6.87255859e-02,  -6.87255859e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -8.95996094e-02,  -8.95996094e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.63635254e-01,   1.63635254e-01],
                        [  2.07519531e-01,   2.07519531e-01],
                        [  2.20794678e-01,   2.20794678e-01],
                        [  2.04437256e-01,   2.04437256e-01],
                        [  1.72119141e-01,   1.72119141e-01],
                        [  1.39099121e-01,   1.39099121e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -8.99658203e-02,  -8.99658203e-02],
                        [ -1.68975830e-01,  -1.68975830e-01],
                        [ -2.10296631e-01,  -2.10296631e-01],
                        [ -2.02270508e-01,  -2.02270508e-01],
                        [ -1.61590576e-01,  -1.61590576e-01],
                        [ -1.19964600e-01,  -1.19964600e-01],
                        [ -9.79003906e-02,  -9.79003906e-02],
                        [ -9.15222168e-02,  -9.15222168e-02],
                        [ -8.62731934e-02,  -8.62731934e-02],
                        [ -7.60803223e-02,  -7.60803223e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -8.27026367e-02,  -8.27026367e-02],
                        [ -9.93041992e-02,  -9.93041992e-02],
                        [ -1.00463867e-01,  -1.00463867e-01],
                        [ -8.92028809e-02,  -8.92028809e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  1.33880615e-01,   1.33880615e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  6.47583008e-02,   6.47583008e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  1.01104736e-01,   1.01104736e-01],
                        [  1.10656738e-01,   1.10656738e-01],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.32141113e-01,   1.32141113e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.13342285e-01,   1.13342285e-01],
                        [  6.56127930e-02,   6.56127930e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.24725342e-01,  -1.24725342e-01],
                        [ -2.26470947e-01,  -2.26470947e-01],
                        [ -2.84484863e-01,  -2.84484863e-01],
                        [ -2.80914307e-01,  -2.80914307e-01],
                        [ -2.33825684e-01,  -2.33825684e-01],
                        [ -1.81060791e-01,  -1.81060791e-01],
                        [ -1.47155762e-01,  -1.47155762e-01],
                        [ -1.30096436e-01,  -1.30096436e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -9.55505371e-02,  -9.55505371e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  8.31298828e-02,   8.31298828e-02],
                        [  1.50543213e-01,   1.50543213e-01],
                        [  1.99066162e-01,   1.99066162e-01],
                        [  2.05017090e-01,   2.05017090e-01],
                        [  1.76452637e-01,   1.76452637e-01],
                        [  1.45599365e-01,   1.45599365e-01],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.28143311e-01,   1.28143311e-01],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  9.22851562e-02,   9.22851562e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.22778320e-03,   2.22778320e-03],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  7.97119141e-02,   7.97119141e-02],
                        [  1.00708008e-01,   1.00708008e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.24694824e-01,  -1.24694824e-01],
                        [ -2.08618164e-01,  -2.08618164e-01],
                        [ -2.37335205e-01,  -2.37335205e-01],
                        [ -2.06848145e-01,  -2.06848145e-01],
                        [ -1.50512695e-01,  -1.50512695e-01],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -8.56628418e-02,  -8.56628418e-02],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -5.29174805e-02,  -5.29174805e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -8.10546875e-02,  -8.10546875e-02],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -8.89282227e-02,  -8.89282227e-02],
                        [ -7.94372559e-02,  -7.94372559e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  1.09252930e-01,   1.09252930e-01],
                        [  1.27441406e-01,   1.27441406e-01],
                        [  1.17248535e-01,   1.17248535e-01],
                        [  9.24072266e-02,   9.24072266e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.02752686e-01,   1.02752686e-01],
                        [  1.08062744e-01,   1.08062744e-01],
                        [  1.06475830e-01,   1.06475830e-01],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  1.21520996e-01,   1.21520996e-01],
                        [  1.29821777e-01,   1.29821777e-01],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  6.60095215e-02,   6.60095215e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.04003906e-01,  -1.04003906e-01],
                        [ -1.94244385e-01,  -1.94244385e-01],
                        [ -2.59338379e-01,  -2.59338379e-01],
                        [ -2.76702881e-01,  -2.76702881e-01],
                        [ -2.44445801e-01,  -2.44445801e-01],
                        [ -1.86614990e-01,  -1.86614990e-01],
                        [ -1.35253906e-01,  -1.35253906e-01],
                        [ -1.09100342e-01,  -1.09100342e-01],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -1.06384277e-01,  -1.06384277e-01],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -8.02307129e-02,  -8.02307129e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  5.23681641e-02,   5.23681641e-02],
                        [  1.05377197e-01,   1.05377197e-01],
                        [  1.58233643e-01,   1.58233643e-01],
                        [  1.96838379e-01,   1.96838379e-01],
                        [  2.03857422e-01,   2.03857422e-01],
                        [  1.77764893e-01,   1.77764893e-01],
                        [  1.39892578e-01,   1.39892578e-01],
                        [  1.15051270e-01,   1.15051270e-01],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.09680176e-01,   1.09680176e-01],
                        [  1.01593018e-01,   1.01593018e-01],
                        [  8.29162598e-02,   8.29162598e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  6.51855469e-02,   6.51855469e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.06658936e-01,  -1.06658936e-01],
                        [ -1.93786621e-01,  -1.93786621e-01],
                        [ -2.33917236e-01,  -2.33917236e-01],
                        [ -2.16491699e-01,  -2.16491699e-01],
                        [ -1.63208008e-01,  -1.63208008e-01],
                        [ -1.08825684e-01,  -1.08825684e-01],
                        [ -7.58056641e-02,  -7.58056641e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -5.99060059e-02,  -5.99060059e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -7.25097656e-02,  -7.25097656e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -9.05456543e-02,  -9.05456543e-02],
                        [ -9.88159180e-02,  -9.88159180e-02],
                        [ -9.07287598e-02,  -9.07287598e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  1.22192383e-01,   1.22192383e-01],
                        [  1.20758057e-01,   1.20758057e-01],
                        [  1.09527588e-01,   1.09527588e-01],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  9.97924805e-02,   9.97924805e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  8.31298828e-02,   8.31298828e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  1.07879639e-01,   1.07879639e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.23199463e-01,   1.23199463e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  7.40966797e-02,   7.40966797e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -1.76696777e-01,  -1.76696777e-01],
                        [ -2.46582031e-01,  -2.46582031e-01],
                        [ -2.77130127e-01,  -2.77130127e-01],
                        [ -2.54852295e-01,  -2.54852295e-01],
                        [ -1.98760986e-01,  -1.98760986e-01],
                        [ -1.48590088e-01,  -1.48590088e-01],
                        [ -1.25946045e-01,  -1.25946045e-01],
                        [ -1.19903564e-01,  -1.19903564e-01],
                        [ -1.11083984e-01,  -1.11083984e-01],
                        [ -9.53063965e-02,  -9.53063965e-02],
                        [ -7.99560547e-02,  -7.99560547e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  1.39038086e-01,   1.39038086e-01],
                        [  1.80053711e-01,   1.80053711e-01],
                        [  1.99096680e-01,   1.99096680e-01],
                        [  1.93389893e-01,   1.93389893e-01],
                        [  1.70715332e-01,   1.70715332e-01],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  1.17523193e-01,   1.17523193e-01],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  8.88061523e-02,   8.88061523e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  6.79626465e-02,   6.79626465e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  1.16699219e-01,   1.16699219e-01],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -1.85516357e-01,  -1.85516357e-01],
                        [ -2.24456787e-01,  -2.24456787e-01],
                        [ -2.05139160e-01,  -2.05139160e-01],
                        [ -1.52008057e-01,  -1.52008057e-01],
                        [ -1.03271484e-01,  -1.03271484e-01],
                        [ -7.94677734e-02,  -7.94677734e-02],
                        [ -7.33032227e-02,  -7.33032227e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.63964844e-02,  -5.63964844e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -9.13391113e-02,  -9.13391113e-02],
                        [ -1.03515625e-01,  -1.03515625e-01],
                        [ -9.75952148e-02,  -9.75952148e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  1.31439209e-01,   1.31439209e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  8.73413086e-02,   8.73413086e-02],
                        [  9.77478027e-02,   9.77478027e-02],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.42944336e-01,   1.42944336e-01],
                        [  1.56494141e-01,   1.56494141e-01],
                        [  1.64581299e-01,   1.64581299e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.32232666e-01,   1.32232666e-01],
                        [  7.36999512e-02,   7.36999512e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.19232178e-01,  -1.19232178e-01],
                        [ -2.18811035e-01,  -2.18811035e-01],
                        [ -2.88055420e-01,  -2.88055420e-01],
                        [ -3.05847168e-01,  -3.05847168e-01],
                        [ -2.68615723e-01,  -2.68615723e-01],
                        [ -2.01507568e-01,  -2.01507568e-01],
                        [ -1.43707275e-01,  -1.43707275e-01],
                        [ -1.15142822e-01,  -1.15142822e-01],
                        [ -1.05224609e-01,  -1.05224609e-01],
                        [ -9.73510742e-02,  -9.73510742e-02],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -8.55712891e-02,  -8.55712891e-02],
                        [ -7.39440918e-02,  -7.39440918e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.74530029e-01,   1.74530029e-01],
                        [  1.97967529e-01,   1.97967529e-01],
                        [  1.96716309e-01,   1.96716309e-01],
                        [  1.76055908e-01,   1.76055908e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.35375977e-01,   1.35375977e-01],
                        [  1.24969482e-01,   1.24969482e-01],
                        [  1.08612061e-01,   1.08612061e-01],
                        [  8.90197754e-02,   8.90197754e-02],
                        [  7.66296387e-02,   7.66296387e-02],
                        [  7.01293945e-02,   7.01293945e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.02941895e-02,  -2.02941895e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  8.39843750e-02,   8.39843750e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -1.10809326e-01,  -1.10809326e-01],
                        [ -1.83929443e-01,  -1.83929443e-01],
                        [ -2.11120605e-01,  -2.11120605e-01],
                        [ -1.83258057e-01,  -1.83258057e-01],
                        [ -1.27502441e-01,  -1.27502441e-01],
                        [ -8.33435059e-02,  -8.33435059e-02],
                        [ -6.94580078e-02,  -6.94580078e-02],
                        [ -7.39440918e-02,  -7.39440918e-02],
                        [ -7.47985840e-02,  -7.47985840e-02],
                        [ -6.68945312e-02,  -6.68945312e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -9.01184082e-02,  -9.01184082e-02],
                        [ -9.53674316e-02,  -9.53674316e-02],
                        [ -8.98742676e-02,  -8.98742676e-02],
                        [ -7.66296387e-02,  -7.66296387e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -6.47888184e-02,  -6.48193359e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  1.10382080e-01,   1.10382080e-01],
                        [  1.23138428e-01,   1.23138428e-01],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  9.29565430e-02,   9.29565430e-02],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.26007080e-01,   1.26007080e-01],
                        [  1.51763916e-01,   1.51763916e-01],
                        [  1.71966553e-01,   1.71966553e-01],
                        [  1.78619385e-01,   1.78619385e-01],
                        [  1.64215088e-01,   1.64215088e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  5.57861328e-02,   5.57861328e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -1.40350342e-01,  -1.40350342e-01],
                        [ -2.33795166e-01,  -2.33795166e-01],
                        [ -2.87689209e-01,  -2.87689209e-01],
                        [ -2.88452148e-01,  -2.88452148e-01],
                        [ -2.47924805e-01,  -2.47924805e-01],
                        [ -1.94305420e-01,  -1.94305420e-01],
                        [ -1.53656006e-01,  -1.53656006e-01],
                        [ -1.33758545e-01,  -1.33758545e-01],
                        [ -1.22772217e-01,  -1.22772217e-01],
                        [ -1.07238770e-01,  -1.07238770e-01],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  1.23962402e-01,   1.23962402e-01],
                        [  1.66595459e-01,   1.66595459e-01],
                        [  1.93389893e-01,   1.93389893e-01],
                        [  2.02758789e-01,   2.02758789e-01],
                        [  1.95068359e-01,   1.95068359e-01],
                        [  1.76818848e-01,   1.76818848e-01],
                        [  1.57073975e-01,   1.57073975e-01],
                        [  1.38580322e-01,   1.38580322e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  5.03540039e-02,   5.03540039e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.55639648e-03,   1.55639648e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  7.49511719e-02,   7.49511719e-02],
                        [  8.35266113e-02,   8.35266113e-02],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -1.15051270e-01,  -1.15051270e-01],
                        [ -1.79992676e-01,  -1.79992676e-01],
                        [ -2.02178955e-01,  -2.02178955e-01],
                        [ -1.78100586e-01,  -1.78100586e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -8.51135254e-02,  -8.51135254e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -7.40661621e-02,  -7.40661621e-02],
                        [ -8.63037109e-02,  -8.63037109e-02],
                        [ -9.24987793e-02,  -9.24987793e-02],
                        [ -9.18579102e-02,  -9.18579102e-02],
                        [ -8.85314941e-02,  -8.85314941e-02],
                        [ -8.45947266e-02,  -8.45947266e-02],
                        [ -7.84912109e-02,  -7.84912109e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.25640869e-01,   1.25640869e-01],
                        [  1.29791260e-01,   1.29791260e-01],
                        [  1.17492676e-01,   1.17492676e-01],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  8.93249512e-02,   8.93249512e-02],
                        [  9.30480957e-02,   9.30480957e-02],
                        [  1.03759766e-01,   1.03729248e-01],
                        [  1.14654541e-01,   1.14654541e-01],
                        [  1.25000000e-01,   1.25000000e-01],
                        [  1.37176514e-01,   1.37176514e-01],
                        [  1.53747559e-01,   1.53747559e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.85607910e-01,   1.85607910e-01],
                        [  1.79046631e-01,   1.79046631e-01],
                        [  1.46972656e-01,   1.46972656e-01],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -1.07940674e-01,  -1.07940674e-01],
                        [ -2.14385986e-01,  -2.14385986e-01],
                        [ -2.90740967e-01,  -2.90740967e-01],
                        [ -3.12866211e-01,  -3.12866211e-01],
                        [ -2.72460938e-01,  -2.72460938e-01],
                        [ -1.93695068e-01,  -1.93695068e-01],
                        [ -1.27075195e-01,  -1.27075195e-01],
                        [ -1.04919434e-01,  -1.04919434e-01],
                        [ -1.11511230e-01,  -1.11511230e-01],
                        [ -1.12335205e-01,  -1.12335205e-01],
                        [ -9.80834961e-02,  -9.80834961e-02],
                        [ -8.37707520e-02,  -8.37707520e-02],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -7.85827637e-02,  -7.85827637e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.37219238e-02,  -3.36914062e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  9.84802246e-02,   9.84802246e-02],
                        [  1.50939941e-01,   1.50939941e-01],
                        [  1.86706543e-01,   1.86706543e-01],
                        [  1.98394775e-01,   1.98394775e-01],
                        [  1.84692383e-01,   1.84692383e-01],
                        [  1.55487061e-01,   1.55487061e-01],
                        [  1.30371094e-01,   1.30371094e-01],
                        [  1.21734619e-01,   1.21734619e-01],
                        [  1.23596191e-01,   1.23596191e-01],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  1.18255615e-01,   1.18255615e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  8.85009766e-04,   8.85009766e-04],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  9.52758789e-02,   9.52758789e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -1.39617920e-01,  -1.39617920e-01],
                        [ -1.88110352e-01,  -1.88110352e-01],
                        [ -1.92687988e-01,  -1.92687988e-01],
                        [ -1.63970947e-01,  -1.63940430e-01],
                        [ -1.30554199e-01,  -1.30554199e-01],
                        [ -1.12152100e-01,  -1.12152100e-01],
                        [ -1.08276367e-01,  -1.08276367e-01],
                        [ -1.10198975e-01,  -1.10198975e-01],
                        [ -1.10473633e-01,  -1.10473633e-01],
                        [ -1.04919434e-01,  -1.04919434e-01],
                        [ -9.46960449e-02,  -9.46960449e-02],
                        [ -8.49609375e-02,  -8.49609375e-02],
                        [ -7.73315430e-02,  -7.73315430e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  1.06689453e-01,   1.06689453e-01],
                        [  1.19476318e-01,   1.19476318e-01],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.27441406e-01,   1.27441406e-01],
                        [  1.21673584e-01,   1.21704102e-01],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  1.12731934e-01,   1.12731934e-01],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.21917725e-01,   1.21917725e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.71264648e-01,   1.71264648e-01],
                        [  1.85729980e-01,   1.85729980e-01],
                        [  1.75598145e-01,   1.75598145e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  5.94482422e-02,   5.94482422e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -1.51062012e-01,  -1.51062012e-01],
                        [ -2.46582031e-01,  -2.46582031e-01],
                        [ -2.98370361e-01,  -2.98370361e-01],
                        [ -2.90710449e-01,  -2.90710449e-01],
                        [ -2.36022949e-01,  -2.36022949e-01],
                        [ -1.72332764e-01,  -1.72332764e-01],
                        [ -1.35986328e-01,  -1.35986328e-01],
                        [ -1.32385254e-01,  -1.32385254e-01],
                        [ -1.37847900e-01,  -1.37847900e-01],
                        [ -1.30126953e-01,  -1.30126953e-01],
                        [ -1.08764648e-01,  -1.08764648e-01],
                        [ -8.42895508e-02,  -8.42895508e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  1.58050537e-01,   1.58050537e-01],
                        [  1.99188232e-01,   1.99188232e-01],
                        [  2.10449219e-01,   2.10449219e-01],
                        [  1.96350098e-01,   1.96350098e-01],
                        [  1.73126221e-01,   1.73126221e-01],
                        [  1.50909424e-01,   1.50909424e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  8.25805664e-02,   8.25805664e-02],
                        [  7.97119141e-02,   7.97119141e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [ -6.16455078e-02,  -6.16455078e-02],
                        [ -1.43493652e-01,  -1.43493652e-01],
                        [ -1.96136475e-01,  -1.96136475e-01],
                        [ -2.07550049e-01,  -2.07550049e-01],
                        [ -1.85577393e-01,  -1.85577393e-01],
                        [ -1.51397705e-01,  -1.51397705e-01],
                        [ -1.23596191e-01,  -1.23596191e-01],
                        [ -1.07513428e-01,  -1.07513428e-01],
                        [ -9.74121094e-02,  -9.74121094e-02],
                        [ -8.61206055e-02,  -8.61206055e-02],
                        [ -7.36999512e-02,  -7.36999512e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -7.15637207e-02,  -7.15942383e-02],
                        [ -8.23974609e-02,  -8.23974609e-02],
                        [ -8.65173340e-02,  -8.65173340e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.15234375e-01,   1.15234375e-01],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  9.98229980e-02,   9.98229980e-02],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.52587891e-01,   1.52587891e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.95617676e-01,   1.95617676e-01],
                        [  1.99279785e-01,   1.99249268e-01],
                        [  1.81213379e-01,   1.81213379e-01],
                        [  1.35894775e-01,   1.35894775e-01],
                        [  6.11572266e-02,   6.11572266e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -1.47430420e-01,  -1.47430420e-01],
                        [ -2.46917725e-01,  -2.46917725e-01],
                        [ -3.12408447e-01,  -3.12408447e-01],
                        [ -3.23669434e-01,  -3.23669434e-01],
                        [ -2.77038574e-01,  -2.77038574e-01],
                        [ -1.97418213e-01,  -1.97418213e-01],
                        [ -1.27807617e-01,  -1.27807617e-01],
                        [ -9.63745117e-02,  -9.63745117e-02],
                        [ -9.62219238e-02,  -9.62219238e-02],
                        [ -1.01043701e-01,  -1.01043701e-01],
                        [ -9.50012207e-02,  -9.50012207e-02],
                        [ -8.16040039e-02,  -8.16040039e-02],
                        [ -7.03735352e-02,  -7.03735352e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -6.65893555e-02,  -6.65893555e-02],
                        [ -7.11059570e-02,  -7.11059570e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -6.61926270e-02,  -6.61926270e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  1.25427246e-01,   1.25427246e-01],
                        [  1.70776367e-01,   1.70776367e-01],
                        [  1.97143555e-01,   1.97143555e-01],
                        [  1.94458008e-01,   1.94458008e-01],
                        [  1.69189453e-01,   1.69189453e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.28906250e-01,   1.28936768e-01],
                        [  1.22100830e-01,   1.22100830e-01],
                        [  1.14196777e-01,   1.14196777e-01],
                        [  1.06475830e-01,   1.06475830e-01],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  1.00097656e-01,   1.00097656e-01],
                        [  9.69238281e-02,   9.69238281e-02],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  4.48608398e-03,   4.51660156e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -7.78198242e-03,  -7.81250000e-03],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  7.33032227e-02,   7.33032227e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -1.06536865e-01,  -1.06536865e-01],
                        [ -1.70715332e-01,  -1.70715332e-01],
                        [ -1.93542480e-01,  -1.93542480e-01],
                        [ -1.76055908e-01,  -1.76055908e-01],
                        [ -1.39160156e-01,  -1.39160156e-01],
                        [ -1.10687256e-01,  -1.10687256e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -1.13494873e-01,  -1.13494873e-01],
                        [ -1.16058350e-01,  -1.16058350e-01],
                        [ -1.04492188e-01,  -1.04492188e-01],
                        [ -8.79516602e-02,  -8.79516602e-02],
                        [ -8.04138184e-02,  -8.03833008e-02],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -8.49914551e-02,  -8.49914551e-02],
                        [ -7.51953125e-02,  -7.51647949e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  1.15295410e-01,   1.15295410e-01],
                        [  1.22955322e-01,   1.22955322e-01],
                        [  1.18103027e-01,   1.18103027e-01],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  1.19018555e-01,   1.19018555e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.24420166e-01,   1.24420166e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.43524170e-01,   1.43524170e-01],
                        [  1.71020508e-01,   1.71020508e-01],
                        [  1.94915771e-01,   1.94915771e-01],
                        [  2.02026367e-01,   2.02026367e-01],
                        [  1.90093994e-01,   1.90093994e-01],
                        [  1.59149170e-01,   1.59149170e-01],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.55944824e-02,   1.55944824e-02],
                        [ -9.81445312e-02,  -9.81445312e-02],
                        [ -2.15423584e-01,  -2.15423584e-01],
                        [ -2.99865723e-01,  -2.99865723e-01],
                        [ -3.21685791e-01,  -3.21685791e-01],
                        [ -2.81768799e-01,  -2.81768799e-01],
                        [ -2.11120605e-01,  -2.11120605e-01],
                        [ -1.46423340e-01,  -1.46423340e-01],
                        [ -1.08551025e-01,  -1.08551025e-01],
                        [ -9.68017578e-02,  -9.68017578e-02],
                        [ -9.48791504e-02,  -9.48791504e-02],
                        [ -8.71582031e-02,  -8.71582031e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  1.11175537e-01,   1.11175537e-01],
                        [  1.60308838e-01,   1.60308838e-01],
                        [  1.87500000e-01,   1.87500000e-01],
                        [  1.88293457e-01,   1.88293457e-01],
                        [  1.73034668e-01,   1.73034668e-01],
                        [  1.55944824e-01,   1.55944824e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.37115479e-01,   1.37115479e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.29730225e-01,   1.29730225e-01],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  4.78515625e-02,   4.78515625e-02],
                        [ -1.01318359e-02,  -1.01623535e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -1.38885498e-01,  -1.38885498e-01],
                        [ -1.73797607e-01,  -1.73797607e-01],
                        [ -1.73553467e-01,  -1.73553467e-01],
                        [ -1.51397705e-01,  -1.51397705e-01],
                        [ -1.30096436e-01,  -1.30096436e-01],
                        [ -1.22711182e-01,  -1.22711182e-01],
                        [ -1.26312256e-01,  -1.26312256e-01],
                        [ -1.28204346e-01,  -1.28204346e-01],
                        [ -1.18927002e-01,  -1.18927002e-01],
                        [ -1.03027344e-01,  -1.03027344e-01],
                        [ -9.34143066e-02,  -9.33837891e-02],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -9.27734375e-02,  -9.27734375e-02],
                        [ -8.20312500e-02,  -8.20312500e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  8.41979980e-02,   8.41979980e-02],
                        [  1.00982666e-01,   1.00982666e-01],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  1.10198975e-01,   1.10198975e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.40563965e-01,   1.40563965e-01],
                        [  1.56951904e-01,   1.56921387e-01],
                        [  1.74743652e-01,   1.74743652e-01],
                        [  1.95037842e-01,   1.95037842e-01],
                        [  2.12646484e-01,   2.12646484e-01],
                        [  2.14202881e-01,   2.14202881e-01],
                        [  1.86187744e-01,   1.86187744e-01],
                        [  1.22344971e-01,   1.22344971e-01],
                        [  2.66723633e-02,   2.66723633e-02],
                        [ -8.63342285e-02,  -8.63342285e-02],
                        [ -1.96990967e-01,  -1.96990967e-01],
                        [ -2.83203125e-01,  -2.83203125e-01],
                        [ -3.20373535e-01,  -3.20373535e-01],
                        [ -2.95532227e-01,  -2.95532227e-01],
                        [ -2.28576660e-01,  -2.28576660e-01],
                        [ -1.62841797e-01,  -1.62841797e-01],
                        [ -1.27349854e-01,  -1.27349854e-01],
                        [ -1.17126465e-01,  -1.17126465e-01],
                        [ -1.11358643e-01,  -1.11358643e-01],
                        [ -9.77172852e-02,  -9.77172852e-02],
                        [ -7.83691406e-02,  -7.83691406e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -8.17260742e-02,  -8.17260742e-02],
                        [ -8.93249512e-02,  -8.93249512e-02],
                        [ -8.21838379e-02,  -8.21838379e-02],
                        [ -6.82067871e-02,  -6.82067871e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.88171387e-01,   1.88171387e-01],
                        [  2.16674805e-01,   2.16674805e-01],
                        [  2.09197998e-01,   2.09197998e-01],
                        [  1.80755615e-01,   1.80755615e-01],
                        [  1.54937744e-01,   1.54937744e-01],
                        [  1.41143799e-01,   1.41143799e-01],
                        [  1.33789062e-01,   1.33789062e-01],
                        [  1.24969482e-01,   1.24969482e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  2.12402344e-02,   2.12097168e-02],
                        [  3.55529785e-02,   3.55834961e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  4.62646484e-02,   4.62646484e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -9.54895020e-02,  -9.54895020e-02],
                        [ -1.69250488e-01,  -1.69250488e-01],
                        [ -2.13348389e-01,  -2.13348389e-01],
                        [ -2.12524414e-01,  -2.12524414e-01],
                        [ -1.78771973e-01,  -1.78771973e-01],
                        [ -1.41174316e-01,  -1.41174316e-01],
                        [ -1.17767334e-01,  -1.17767334e-01],
                        [ -1.05163574e-01,  -1.05163574e-01],
                        [ -9.54284668e-02,  -9.54284668e-02],
                        [ -9.03625488e-02,  -9.03625488e-02],
                        [ -9.49401855e-02,  -9.49401855e-02],
                        [ -1.06445312e-01,  -1.06445312e-01],
                        [ -1.16149902e-01,  -1.16149902e-01],
                        [ -1.15203857e-01,  -1.15203857e-01],
                        [ -9.89685059e-02,  -9.89685059e-02],
                        [ -7.13500977e-02,  -7.13500977e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  1.22711182e-01,   1.22711182e-01],
                        [  1.24542236e-01,   1.24511719e-01],
                        [  1.23260498e-01,   1.23260498e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  1.46850586e-01,   1.46850586e-01],
                        [  1.66137695e-01,   1.66137695e-01],
                        [  1.87377930e-01,   1.87377930e-01],
                        [  2.07580566e-01,   2.07580566e-01],
                        [  2.20703125e-01,   2.20703125e-01],
                        [  2.14721680e-01,   2.14721680e-01],
                        [  1.76422119e-01,   1.76422119e-01],
                        [  1.02478027e-01,   1.02478027e-01],
                        [  2.07519531e-03,   2.07519531e-03],
                        [ -1.11145020e-01,  -1.11145020e-01],
                        [ -2.20916748e-01,  -2.20916748e-01],
                        [ -3.02673340e-01,  -3.02673340e-01],
                        [ -3.30322266e-01,  -3.30322266e-01],
                        [ -2.96295166e-01,  -2.96295166e-01],
                        [ -2.23999023e-01,  -2.23999023e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.15722656e-01,  -1.15722656e-01],
                        [ -1.06475830e-01,  -1.06475830e-01],
                        [ -1.08428955e-01,  -1.08428955e-01],
                        [ -1.08062744e-01,  -1.08062744e-01],
                        [ -1.02996826e-01,  -1.02996826e-01],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  1.33087158e-01,   1.33087158e-01],
                        [  1.93176270e-01,   1.93176270e-01],
                        [  2.26135254e-01,   2.26135254e-01],
                        [  2.26318359e-01,   2.26318359e-01],
                        [  2.00683594e-01,   2.00683594e-01],
                        [  1.64855957e-01,   1.64855957e-01],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  1.20513916e-01,   1.20513916e-01],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  8.50524902e-02,   8.50524902e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  7.62329102e-02,   7.62329102e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  1.52587891e-02,   1.52282715e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  8.85314941e-02,   8.85314941e-02],
                        [  1.15447998e-01,   1.15447998e-01],
                        [  1.25885010e-01,   1.25885010e-01],
                        [  1.10382080e-01,   1.10382080e-01],
                        [  6.46362305e-02,   6.46362305e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -1.69433594e-01,  -1.69433594e-01],
                        [ -2.10571289e-01,  -2.10571289e-01],
                        [ -2.06848145e-01,  -2.06848145e-01],
                        [ -1.73583984e-01,  -1.73583984e-01],
                        [ -1.39770508e-01,  -1.39770508e-01],
                        [ -1.23168945e-01,  -1.23168945e-01],
                        [ -1.20117188e-01,  -1.20086670e-01],
                        [ -1.17095947e-01,  -1.17095947e-01],
                        [ -1.09283447e-01,  -1.09283447e-01],
                        [ -1.04187012e-01,  -1.04187012e-01],
                        [ -1.07910156e-01,  -1.07910156e-01],
                        [ -1.13983154e-01,  -1.13983154e-01],
                        [ -1.10534668e-01,  -1.10534668e-01],
                        [ -9.46960449e-02,  -9.46960449e-02],
                        [ -7.55310059e-02,  -7.55310059e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.66308594e-02,  -4.66003418e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  1.20208740e-01,   1.20178223e-01],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  9.87548828e-02,   9.87548828e-02],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.32476807e-01,   1.32476807e-01],
                        [  1.50756836e-01,   1.50756836e-01],
                        [  1.63269043e-01,   1.63269043e-01],
                        [  1.78466797e-01,   1.78466797e-01],
                        [  2.03369141e-01,   2.03369141e-01],
                        [  2.24914551e-01,   2.24914551e-01],
                        [  2.17407227e-01,   2.17407227e-01],
                        [  1.71539307e-01,   1.71539307e-01],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.47094727e-02,   1.47094727e-02],
                        [ -8.85314941e-02,  -8.85314941e-02],
                        [ -2.02148438e-01,  -2.02148438e-01],
                        [ -2.94525146e-01,  -2.94525146e-01],
                        [ -3.29315186e-01,  -3.29315186e-01],
                        [ -2.95898438e-01,  -2.95898438e-01],
                        [ -2.20764160e-01,  -2.20764160e-01],
                        [ -1.51550293e-01,  -1.51550293e-01],
                        [ -1.19140625e-01,  -1.19140625e-01],
                        [ -1.14654541e-01,  -1.14654541e-01],
                        [ -1.13769531e-01,  -1.13769531e-01],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -1.12121582e-01,  -1.12121582e-01],
                        [ -1.15997314e-01,  -1.15997314e-01],
                        [ -1.11755371e-01,  -1.11755371e-01],
                        [ -9.54589844e-02,  -9.54589844e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  1.38244629e-01,   1.38244629e-01],
                        [  1.97326660e-01,   1.97326660e-01],
                        [  2.35107422e-01,   2.35107422e-01],
                        [  2.27630615e-01,   2.27630615e-01],
                        [  1.82495117e-01,   1.82495117e-01],
                        [  1.36260986e-01,   1.36260986e-01],
                        [  1.16271973e-01,   1.16271973e-01],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.17401123e-01,   1.17401123e-01],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -1.50146484e-02,  -1.49841309e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  8.18481445e-02,   8.18481445e-02],
                        [  9.86633301e-02,   9.86633301e-02],
                        [  1.05651855e-01,   1.05651855e-01],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -1.11267090e-01,  -1.11267090e-01],
                        [ -1.75689697e-01,  -1.75689697e-01],
                        [ -2.04254150e-01,  -2.04254150e-01],
                        [ -1.91436768e-01,  -1.91436768e-01],
                        [ -1.60217285e-01,  -1.60217285e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -1.30889893e-01,  -1.30889893e-01],
                        [ -1.24053955e-01,  -1.24053955e-01],
                        [ -1.13250732e-01,  -1.13250732e-01],
                        [ -1.06445312e-01,  -1.06445312e-01],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -1.02600098e-01,  -1.02569580e-01],
                        [ -8.46557617e-02,  -8.46557617e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.25000000e-01,   1.25000000e-01],
                        [  1.26098633e-01,   1.26098633e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  9.79919434e-02,   9.79919434e-02],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.38397217e-01,   1.38397217e-01],
                        [  1.61285400e-01,   1.61285400e-01],
                        [  1.80877686e-01,   1.80877686e-01],
                        [  2.04040527e-01,   2.04040527e-01],
                        [  2.21740723e-01,   2.21740723e-01],
                        [  2.14050293e-01,   2.14080811e-01],
                        [  1.73065186e-01,   1.73065186e-01],
                        [  1.03607178e-01,   1.03607178e-01],
                        [  8.11767578e-03,   8.11767578e-03],
                        [ -1.09466553e-01,  -1.09466553e-01],
                        [ -2.27172852e-01,  -2.27172852e-01],
                        [ -3.08319092e-01,  -3.08319092e-01],
                        [ -3.26110840e-01,  -3.26110840e-01],
                        [ -2.84606934e-01,  -2.84606934e-01],
                        [ -2.17681885e-01,  -2.17681885e-01],
                        [ -1.64428711e-01,  -1.64428711e-01],
                        [ -1.39953613e-01,  -1.39953613e-01],
                        [ -1.29577637e-01,  -1.29577637e-01],
                        [ -1.14288330e-01,  -1.14288330e-01],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -8.14819336e-02,  -8.14819336e-02],
                        [ -8.04138184e-02,  -8.04138184e-02],
                        [ -8.76464844e-02,  -8.76464844e-02],
                        [ -9.67712402e-02,  -9.67712402e-02],
                        [ -9.71069336e-02,  -9.71069336e-02],
                        [ -7.85217285e-02,  -7.85217285e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  1.77246094e-01,   1.77246094e-01],
                        [  2.18170166e-01,   2.18170166e-01],
                        [  2.32208252e-01,   2.32208252e-01],
                        [  2.20550537e-01,   2.20550537e-01],
                        [  1.92199707e-01,   1.92199707e-01],
                        [  1.59484863e-01,   1.59484863e-01],
                        [  1.33636475e-01,   1.33666992e-01],
                        [  1.18011475e-01,   1.18011475e-01],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  7.44934082e-02,   7.44934082e-02],
                        [  6.14013672e-02,   6.13708496e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  5.33447266e-02,   5.33447266e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  9.05761719e-02,   9.05761719e-02],
                        [  9.62524414e-02,   9.62524414e-02],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -1.16271973e-01,  -1.16271973e-01],
                        [ -1.87042236e-01,  -1.87042236e-01],
                        [ -2.11914062e-01,  -2.11914062e-01],
                        [ -1.92657471e-01,  -1.92657471e-01],
                        [ -1.54113770e-01,  -1.54113770e-01],
                        [ -1.21612549e-01,  -1.21612549e-01],
                        [ -1.08306885e-01,  -1.08306885e-01],
                        [ -1.13311768e-01,  -1.13311768e-01],
                        [ -1.23962402e-01,  -1.23962402e-01],
                        [ -1.25854492e-01,  -1.25854492e-01],
                        [ -1.15112305e-01,  -1.15112305e-01],
                        [ -9.76257324e-02,  -9.76562500e-02],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -6.63146973e-02,  -6.63146973e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  9.93347168e-02,   9.93347168e-02],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  9.39636230e-02,   9.39941406e-02],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.40014648e-01,   1.40014648e-01],
                        [  1.64184570e-01,   1.64215088e-01],
                        [  1.81793213e-01,   1.81793213e-01],
                        [  1.95861816e-01,   1.95861816e-01],
                        [  2.04925537e-01,   2.04925537e-01],
                        [  2.01019287e-01,   2.01019287e-01],
                        [  1.75140381e-01,   1.75140381e-01],
                        [  1.19812012e-01,   1.19812012e-01],
                        [  3.37219238e-02,   3.37219238e-02],
                        [ -7.20520020e-02,  -7.20520020e-02],
                        [ -1.77459717e-01,  -1.77459717e-01],
                        [ -2.61566162e-01,  -2.61566162e-01],
                        [ -3.04534912e-01,  -3.04534912e-01],
                        [ -2.92083740e-01,  -2.92083740e-01],
                        [ -2.31719971e-01,  -2.31719971e-01],
                        [ -1.59881592e-01,  -1.59881592e-01],
                        [ -1.15661621e-01,  -1.15661621e-01],
                        [ -1.06201172e-01,  -1.06201172e-01],
                        [ -1.10778809e-01,  -1.10778809e-01],
                        [ -1.12579346e-01,  -1.12579346e-01],
                        [ -1.11145020e-01,  -1.11145020e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -1.08459473e-01,  -1.08459473e-01],
                        [ -1.02355957e-01,  -1.02355957e-01],
                        [ -8.82263184e-02,  -8.82263184e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  2.02117920e-01,   2.02117920e-01],
                        [  2.30743408e-01,   2.30743408e-01],
                        [  2.18383789e-01,   2.18383789e-01],
                        [  1.77734375e-01,   1.77734375e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.09985352e-01,   1.09985352e-01],
                        [  1.03149414e-01,   1.03149414e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  1.03485107e-01,   1.03485107e-01],
                        [  1.02539062e-01,   1.02539062e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -2.21557617e-02,  -2.21862793e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  8.04748535e-02,   8.04748535e-02],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  8.85314941e-02,   8.85314941e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -1.43127441e-01,  -1.43127441e-01],
                        [ -2.01049805e-01,  -2.01049805e-01],
                        [ -2.11944580e-01,  -2.11944580e-01],
                        [ -1.83898926e-01,  -1.83898926e-01],
                        [ -1.44866943e-01,  -1.44866943e-01],
                        [ -1.19079590e-01,  -1.19079590e-01],
                        [ -1.12243652e-01,  -1.12243652e-01],
                        [ -1.16271973e-01,  -1.16271973e-01],
                        [ -1.18499756e-01,  -1.18499756e-01],
                        [ -1.10504150e-01,  -1.10504150e-01],
                        [ -9.65576172e-02,  -9.65576172e-02],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -8.74938965e-02,  -8.74938965e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  1.03179932e-01,   1.03179932e-01],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  8.76159668e-02,   8.76159668e-02],
                        [  9.31396484e-02,   9.31396484e-02],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.35833740e-01,   1.35833740e-01],
                        [  1.52404785e-01,   1.52404785e-01],
                        [  1.66137695e-01,   1.66137695e-01],
                        [  1.84051514e-01,   1.84082031e-01],
                        [  2.02362061e-01,   2.02362061e-01],
                        [  2.09228516e-01,   2.09228516e-01],
                        [  1.96105957e-01,   1.96105957e-01],
                        [  1.57592773e-01,   1.57592773e-01],
                        [  8.67614746e-02,   8.67614746e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -2.55065918e-01,  -2.55096436e-01],
                        [ -3.14880371e-01,  -3.14880371e-01],
                        [ -3.05389404e-01,  -3.05389404e-01],
                        [ -2.43194580e-01,  -2.43194580e-01],
                        [ -1.73767090e-01,  -1.73767090e-01],
                        [ -1.36627197e-01,  -1.36627197e-01],
                        [ -1.33850098e-01,  -1.33850098e-01],
                        [ -1.39343262e-01,  -1.39343262e-01],
                        [ -1.35070801e-01,  -1.35101318e-01],
                        [ -1.27349854e-01,  -1.27349854e-01],
                        [ -1.26708984e-01,  -1.26708984e-01],
                        [ -1.28326416e-01,  -1.28326416e-01],
                        [ -1.20574951e-01,  -1.20574951e-01],
                        [ -1.00006104e-01,  -1.00006104e-01],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  9.71984863e-02,   9.71984863e-02],
                        [  1.46026611e-01,   1.46026611e-01],
                        [  1.81915283e-01,   1.81915283e-01],
                        [  1.99035645e-01,   1.99035645e-01],
                        [  1.91345215e-01,   1.91345215e-01],
                        [  1.65435791e-01,   1.65435791e-01],
                        [  1.38732910e-01,   1.38732910e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  1.18560791e-01,   1.18560791e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  1.21734619e-01,   1.21734619e-01],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  9.82971191e-02,   9.82971191e-02],
                        [  7.49511719e-02,   7.49511719e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.99072266e-02,  -2.99377441e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  1.07421875e-01,   1.07421875e-01],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -1.76361084e-01,  -1.76361084e-01],
                        [ -2.27264404e-01,  -2.27264404e-01],
                        [ -2.27020264e-01,  -2.27020264e-01],
                        [ -1.87622070e-01,  -1.87622070e-01],
                        [ -1.43585205e-01,  -1.43554688e-01],
                        [ -1.18743896e-01,  -1.18743896e-01],
                        [ -1.09252930e-01,  -1.09252930e-01],
                        [ -1.01959229e-01,  -1.01928711e-01],
                        [ -9.31091309e-02,  -9.31091309e-02],
                        [ -8.78906250e-02,  -8.78906250e-02],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -1.05133057e-01,  -1.05133057e-01],
                        [ -1.11236572e-01,  -1.11236572e-01],
                        [ -1.02203369e-01,  -1.02203369e-01],
                        [ -8.74328613e-02,  -8.74328613e-02],
                        [ -7.88574219e-02,  -7.88574219e-02],
                        [ -7.10754395e-02,  -7.10754395e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.29455566e-01,   1.29455566e-01],
                        [  1.49078369e-01,   1.49078369e-01],
                        [  1.71264648e-01,   1.71264648e-01],
                        [  2.02026367e-01,   2.01995850e-01],
                        [  2.31353760e-01,   2.31353760e-01],
                        [  2.34924316e-01,   2.34924316e-01],
                        [  1.96563721e-01,   1.96563721e-01],
                        [  1.17767334e-01,   1.17767334e-01],
                        [  8.91113281e-03,   8.91113281e-03],
                        [ -1.16333008e-01,  -1.16333008e-01],
                        [ -2.36114502e-01,  -2.36114502e-01],
                        [ -3.18817139e-01,  -3.18817139e-01],
                        [ -3.36883545e-01,  -3.36883545e-01],
                        [ -2.90161133e-01,  -2.90161133e-01],
                        [ -2.12921143e-01,  -2.12921143e-01],
                        [ -1.50207520e-01,  -1.50207520e-01],
                        [ -1.23992920e-01,  -1.23992920e-01],
                        [ -1.23870850e-01,  -1.23870850e-01],
                        [ -1.27899170e-01,  -1.27899170e-01],
                        [ -1.24450684e-01,  -1.24450684e-01],
                        [ -1.15203857e-01,  -1.15203857e-01],
                        [ -1.07208252e-01,  -1.07208252e-01],
                        [ -1.05010986e-01,  -1.05010986e-01],
                        [ -1.04705811e-01,  -1.04705811e-01],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  7.91015625e-02,   7.91015625e-02],
                        [  1.50604248e-01,   1.50604248e-01],
                        [  2.04528809e-01,   2.04528809e-01],
                        [  2.31384277e-01,   2.31384277e-01],
                        [  2.28149414e-01,   2.28149414e-01],
                        [  2.02270508e-01,   2.02270508e-01],
                        [  1.67510986e-01,   1.67510986e-01],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  8.70971680e-02,   8.70971680e-02],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  9.93957520e-02,   9.93957520e-02],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [ -5.74340820e-02,  -5.74340820e-02],
                        [ -1.24023438e-01,  -1.24023438e-01],
                        [ -1.75689697e-01,  -1.75720215e-01],
                        [ -2.02209473e-01,  -2.02209473e-01],
                        [ -1.98303223e-01,  -1.98303223e-01],
                        [ -1.72546387e-01,  -1.72546387e-01],
                        [ -1.44287109e-01,  -1.44287109e-01],
                        [ -1.25274658e-01,  -1.25274658e-01],
                        [ -1.12304688e-01,  -1.12304688e-01],
                        [ -1.00982666e-01,  -1.00982666e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -9.20410156e-02,  -9.20410156e-02],
                        [ -9.23156738e-02,  -9.23156738e-02],
                        [ -9.18579102e-02,  -9.18579102e-02],
                        [ -8.99047852e-02,  -8.99047852e-02],
                        [ -8.73413086e-02,  -8.73413086e-02],
                        [ -8.24279785e-02,  -8.24279785e-02],
                        [ -6.63452148e-02,  -6.63452148e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  7.67822266e-02,   7.67822266e-02],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.31896973e-01,   1.31896973e-01],
                        [  1.26190186e-01,   1.26220703e-01],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  1.29425049e-01,   1.29425049e-01],
                        [  1.50695801e-01,   1.50695801e-01],
                        [  1.78070068e-01,   1.78070068e-01],
                        [  2.08709717e-01,   2.08709717e-01],
                        [  2.26257324e-01,   2.26257324e-01],
                        [  2.09930420e-01,   2.09930420e-01],
                        [  1.52404785e-01,   1.52404785e-01],
                        [  6.36596680e-02,   6.36596680e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -1.50451660e-01,  -1.50451660e-01],
                        [ -2.46673584e-01,  -2.46673584e-01],
                        [ -3.02215576e-01,  -3.02215576e-01],
                        [ -2.95135498e-01,  -2.95135498e-01],
                        [ -2.36694336e-01,  -2.36694336e-01],
                        [ -1.71966553e-01,  -1.71966553e-01],
                        [ -1.39648438e-01,  -1.39648438e-01],
                        [ -1.37329102e-01,  -1.37329102e-01],
                        [ -1.38427734e-01,  -1.38427734e-01],
                        [ -1.30737305e-01,  -1.30737305e-01],
                        [ -1.22558594e-01,  -1.22558594e-01],
                        [ -1.22894287e-01,  -1.22894287e-01],
                        [ -1.30126953e-01,  -1.30126953e-01],
                        [ -1.33636475e-01,  -1.33636475e-01],
                        [ -1.19628906e-01,  -1.19628906e-01],
                        [ -7.85827637e-02,  -7.85827637e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  1.51885986e-01,   1.51885986e-01],
                        [  2.12493896e-01,   2.12493896e-01],
                        [  2.38189697e-01,   2.38189697e-01],
                        [  2.29217529e-01,   2.29217529e-01],
                        [  2.00012207e-01,   2.00012207e-01],
                        [  1.67724609e-01,   1.67724609e-01],
                        [  1.41784668e-01,   1.41784668e-01],
                        [  1.20239258e-01,   1.20239258e-01],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  9.01489258e-02,   9.01489258e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  6.40869141e-03,   6.43920898e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  7.17773438e-02,   7.17773438e-02],
                        [  9.24072266e-02,   9.24072266e-02],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  1.05773926e-01,   1.05773926e-01],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -1.76757812e-01,  -1.76757812e-01],
                        [ -2.19421387e-01,  -2.19421387e-01],
                        [ -2.19848633e-01,  -2.19848633e-01],
                        [ -1.92077637e-01,  -1.92077637e-01],
                        [ -1.60491943e-01,  -1.60491943e-01],
                        [ -1.39801025e-01,  -1.39801025e-01],
                        [ -1.28845215e-01,  -1.28845215e-01],
                        [ -1.18591309e-01,  -1.18560791e-01],
                        [ -1.02325439e-01,  -1.02325439e-01],
                        [ -8.30993652e-02,  -8.30993652e-02],
                        [ -7.22045898e-02,  -7.22045898e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -8.65173340e-02,  -8.65173340e-02],
                        [ -9.21936035e-02,  -9.21936035e-02],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.36993408e-01,   1.36993408e-01],
                        [  1.26007080e-01,   1.26007080e-01],
                        [  1.05529785e-01,   1.05529785e-01],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.68395996e-01,   1.68395996e-01],
                        [  2.02667236e-01,   2.02667236e-01],
                        [  2.20123291e-01,   2.20123291e-01],
                        [  2.13378906e-01,   2.13378906e-01],
                        [  1.75811768e-01,   1.75811768e-01],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -1.17950439e-01,  -1.17950439e-01],
                        [ -2.27996826e-01,  -2.27996826e-01],
                        [ -3.01391602e-01,  -3.01391602e-01],
                        [ -3.15887451e-01,  -3.15887451e-01],
                        [ -2.75024414e-01,  -2.75024414e-01],
                        [ -2.12524414e-01,  -2.12524414e-01],
                        [ -1.66351318e-01,  -1.66351318e-01],
                        [ -1.47888184e-01,  -1.47888184e-01],
                        [ -1.43188477e-01,  -1.43188477e-01],
                        [ -1.37786865e-01,  -1.37756348e-01],
                        [ -1.30249023e-01,  -1.30249023e-01],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -1.22497559e-01,  -1.22497559e-01],
                        [ -1.13311768e-01,  -1.13311768e-01],
                        [ -9.06066895e-02,  -9.06066895e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  1.54296875e-01,   1.54296875e-01],
                        [  2.11975098e-01,   2.11975098e-01],
                        [  2.36450195e-01,   2.36450195e-01],
                        [  2.23876953e-01,   2.23876953e-01],
                        [  1.85760498e-01,   1.85760498e-01],
                        [  1.43493652e-01,   1.43493652e-01],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.13616943e-01,   1.13616943e-01],
                        [  1.10351562e-01,   1.10351562e-01],
                        [  1.02996826e-01,   1.02996826e-01],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -2.88696289e-02,  -2.88696289e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  6.01196289e-02,   6.01196289e-02],
                        [  7.01904297e-02,   7.01904297e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  8.47778320e-02,   8.47778320e-02],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -1.20727539e-01,  -1.20727539e-01],
                        [ -1.85089111e-01,  -1.85089111e-01],
                        [ -2.10876465e-01,  -2.10876465e-01],
                        [ -1.99493408e-01,  -1.99493408e-01],
                        [ -1.72698975e-01,  -1.72698975e-01],
                        [ -1.48956299e-01,  -1.48956299e-01],
                        [ -1.33850098e-01,  -1.33850098e-01],
                        [ -1.26251221e-01,  -1.26251221e-01],
                        [ -1.23107910e-01,  -1.23107910e-01],
                        [ -1.20086670e-01,  -1.20086670e-01],
                        [ -1.14196777e-01,  -1.14196777e-01],
                        [ -1.08093262e-01,  -1.08093262e-01],
                        [ -1.05804443e-01,  -1.05804443e-01],
                        [ -1.02264404e-01,  -1.02264404e-01],
                        [ -8.67614746e-02,  -8.67614746e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  8.61511230e-02,   8.61511230e-02],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.16241455e-01,   1.16241455e-01],
                        [  9.01184082e-02,   9.01184082e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  7.94372559e-02,   7.94372559e-02],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.64703369e-01,   1.64703369e-01],
                        [  1.95281982e-01,   1.95281982e-01],
                        [  2.10968018e-01,   2.10968018e-01],
                        [  2.06359863e-01,   2.06359863e-01],
                        [  1.77734375e-01,   1.77734375e-01],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  9.94873047e-03,   9.94873047e-03],
                        [ -1.20300293e-01,  -1.20300293e-01],
                        [ -2.43164062e-01,  -2.43164062e-01],
                        [ -3.21441650e-01,  -3.21441650e-01],
                        [ -3.30627441e-01,  -3.30627441e-01],
                        [ -2.77191162e-01,  -2.77191162e-01],
                        [ -2.02423096e-01,  -2.02423096e-01],
                        [ -1.52130127e-01,  -1.52130127e-01],
                        [ -1.37756348e-01,  -1.37756348e-01],
                        [ -1.38336182e-01,  -1.38336182e-01],
                        [ -1.36993408e-01,  -1.36993408e-01],
                        [ -1.36199951e-01,  -1.36199951e-01],
                        [ -1.38397217e-01,  -1.38397217e-01],
                        [ -1.33239746e-01,  -1.33239746e-01],
                        [ -1.11358643e-01,  -1.11358643e-01],
                        [ -7.62939453e-02,  -7.62939453e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  1.64855957e-01,   1.64855957e-01],
                        [  2.16979980e-01,   2.16979980e-01],
                        [  2.32849121e-01,   2.32849121e-01],
                        [  2.11029053e-01,   2.11029053e-01],
                        [  1.70074463e-01,   1.70074463e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  9.35363770e-02,   9.35363770e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  5.09033203e-02,   5.09033203e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -7.00683594e-02,  -7.00683594e-02],
                        [ -1.43035889e-01,  -1.43035889e-01],
                        [ -1.98242188e-01,  -1.98242188e-01],
                        [ -2.16430664e-01,  -2.16430664e-01],
                        [ -2.00134277e-01,  -2.00134277e-01],
                        [ -1.69036865e-01,  -1.69036865e-01],
                        [ -1.42944336e-01,  -1.42944336e-01],
                        [ -1.28997803e-01,  -1.28997803e-01],
                        [ -1.20605469e-01,  -1.20605469e-01],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -9.76562500e-02,  -9.76562500e-02],
                        [ -9.06677246e-02,  -9.06677246e-02],
                        [ -8.77685547e-02,  -8.77685547e-02],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -7.83691406e-02,  -7.83691406e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  8.64868164e-02,   8.64868164e-02],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.20819092e-01,   1.20819092e-01],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  1.41479492e-01,   1.41479492e-01],
                        [  1.65069580e-01,   1.65069580e-01],
                        [  1.89849854e-01,   1.89849854e-01],
                        [  2.09289551e-01,   2.09289551e-01],
                        [  2.11700439e-01,   2.11700439e-01],
                        [  1.79443359e-01,   1.79443359e-01],
                        [  1.00433350e-01,   1.00433350e-01],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -1.43585205e-01,  -1.43585205e-01],
                        [ -2.50030518e-01,  -2.50030518e-01],
                        [ -3.10424805e-01,  -3.10424805e-01],
                        [ -3.08929443e-01,  -3.08929443e-01],
                        [ -2.50793457e-01,  -2.50793457e-01],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -1.22406006e-01,  -1.22406006e-01],
                        [ -1.17614746e-01,  -1.17614746e-01],
                        [ -1.37237549e-01,  -1.37237549e-01],
                        [ -1.56219482e-01,  -1.56219482e-01],
                        [ -1.67022705e-01,  -1.67022705e-01],
                        [ -1.66992188e-01,  -1.66992188e-01],
                        [ -1.49810791e-01,  -1.49810791e-01],
                        [ -1.13067627e-01,  -1.13067627e-01],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  1.33911133e-01,   1.33911133e-01],
                        [  1.92108154e-01,   1.92108154e-01],
                        [  2.28424072e-01,   2.28424072e-01],
                        [  2.29583740e-01,   2.29583740e-01],
                        [  1.98577881e-01,   1.98577881e-01],
                        [  1.56311035e-01,   1.56311035e-01],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  8.94775391e-02,   8.94775391e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  8.51440430e-02,   8.51440430e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  8.64562988e-02,   8.64562988e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -1.03424072e-01,  -1.03424072e-01],
                        [ -1.66412354e-01,  -1.66412354e-01],
                        [ -2.08099365e-01,  -2.08099365e-01],
                        [ -2.18048096e-01,  -2.18048096e-01],
                        [ -1.96441650e-01,  -1.96441650e-01],
                        [ -1.56799316e-01,  -1.56799316e-01],
                        [ -1.21948242e-01,  -1.21948242e-01],
                        [ -1.06658936e-01,  -1.06658936e-01],
                        [ -1.04766846e-01,  -1.04766846e-01],
                        [ -9.88464355e-02,  -9.88464355e-02],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -7.11364746e-02,  -7.11364746e-02],
                        [ -7.60192871e-02,  -7.60192871e-02],
                        [ -9.06982422e-02,  -9.06982422e-02],
                        [ -9.77478027e-02,  -9.77478027e-02],
                        [ -8.87145996e-02,  -8.87145996e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  1.39038086e-01,   1.39038086e-01],
                        [  1.44287109e-01,   1.44287109e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  1.37817383e-01,   1.37817383e-01],
                        [  1.41540527e-01,   1.41540527e-01],
                        [  1.57348633e-01,   1.57348633e-01],
                        [  1.86248779e-01,   1.86248779e-01],
                        [  2.16674805e-01,   2.16674805e-01],
                        [  2.28790283e-01,   2.28790283e-01],
                        [  2.10754395e-01,   2.10754395e-01],
                        [  1.61163330e-01,   1.61163330e-01],
                        [  8.02307129e-02,   8.02307129e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -1.52648926e-01,  -1.52648926e-01],
                        [ -2.62084961e-01,  -2.62084961e-01],
                        [ -3.23760986e-01,  -3.23760986e-01],
                        [ -3.17443848e-01,  -3.17443848e-01],
                        [ -2.55737305e-01,  -2.55737305e-01],
                        [ -1.81945801e-01,  -1.81945801e-01],
                        [ -1.38305664e-01,  -1.38305664e-01],
                        [ -1.32263184e-01,  -1.32263184e-01],
                        [ -1.39923096e-01,  -1.39923096e-01],
                        [ -1.39923096e-01,  -1.39923096e-01],
                        [ -1.31896973e-01,  -1.31896973e-01],
                        [ -1.24206543e-01,  -1.24206543e-01],
                        [ -1.14776611e-01,  -1.14776611e-01],
                        [ -8.93859863e-02,  -8.93859863e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.63818359e-01,   1.63818359e-01],
                        [  2.06573486e-01,   2.06573486e-01],
                        [  2.20001221e-01,   2.20001221e-01],
                        [  1.99249268e-01,   1.99249268e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  1.20819092e-01,   1.20819092e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  9.39941406e-02,   9.39941406e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  8.43505859e-02,   8.43505859e-02],
                        [  8.70056152e-02,   8.70056152e-02],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  8.29162598e-02,   8.29162598e-02],
                        [  6.98242188e-02,   6.98242188e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  7.84301758e-03,   7.84301758e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  5.33447266e-02,   5.33447266e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -1.08703613e-01,  -1.08703613e-01],
                        [ -1.70135498e-01,  -1.70135498e-01],
                        [ -2.08923340e-01,  -2.08923340e-01],
                        [ -2.14996338e-01,  -2.14996338e-01],
                        [ -1.90460205e-01,  -1.90460205e-01],
                        [ -1.51275635e-01,  -1.51275635e-01],
                        [ -1.18957520e-01,  -1.18957520e-01],
                        [ -1.05285645e-01,  -1.05285645e-01],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -1.05865479e-01,  -1.05865479e-01],
                        [ -1.00158691e-01,  -1.00158691e-01],
                        [ -9.16748047e-02,  -9.16748047e-02],
                        [ -8.58459473e-02,  -8.58459473e-02],
                        [ -8.26416016e-02,  -8.26416016e-02],
                        [ -7.47070312e-02,  -7.47070312e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  1.19232178e-01,   1.19232178e-01],
                        [  1.35559082e-01,   1.35559082e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  1.36230469e-01,   1.36230469e-01],
                        [  1.33483887e-01,   1.33483887e-01],
                        [  1.40930176e-01,   1.40930176e-01],
                        [  1.64581299e-01,   1.64581299e-01],
                        [  1.97418213e-01,   1.97418213e-01],
                        [  2.20031738e-01,   2.20031738e-01],
                        [  2.15545654e-01,   2.15545654e-01],
                        [  1.80206299e-01,   1.80206299e-01],
                        [  1.14898682e-01,   1.14898682e-01],
                        [  1.76696777e-02,   1.76696777e-02],
                        [ -1.04095459e-01,  -1.04095459e-01],
                        [ -2.22473145e-01,  -2.22473145e-01],
                        [ -2.99041748e-01,  -2.99041748e-01],
                        [ -3.08197021e-01,  -3.08197021e-01],
                        [ -2.58392334e-01,  -2.58392334e-01],
                        [ -1.90612793e-01,  -1.90612793e-01],
                        [ -1.47033691e-01,  -1.47033691e-01],
                        [ -1.39526367e-01,  -1.39526367e-01],
                        [ -1.50573730e-01,  -1.50573730e-01],
                        [ -1.58264160e-01,  -1.58264160e-01],
                        [ -1.53076172e-01,  -1.53076172e-01],
                        [ -1.35925293e-01,  -1.35925293e-01],
                        [ -1.10748291e-01,  -1.10748291e-01],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  9.38720703e-02,   9.38720703e-02],
                        [  1.69097900e-01,   1.69097900e-01],
                        [  2.23449707e-01,   2.23449707e-01],
                        [  2.39318848e-01,   2.39318848e-01],
                        [  2.16430664e-01,   2.16430664e-01],
                        [  1.73583984e-01,   1.73583984e-01],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  8.07189941e-02,   8.07189941e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  8.51135254e-02,   8.51135254e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  7.62023926e-02,   7.62023926e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -1.54846191e-01,  -1.54846191e-01],
                        [ -2.06146240e-01,  -2.06146240e-01],
                        [ -2.15484619e-01,  -2.15484619e-01],
                        [ -1.87225342e-01,  -1.87225342e-01],
                        [ -1.48284912e-01,  -1.48284912e-01],
                        [ -1.21337891e-01,  -1.21337891e-01],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -9.97924805e-02,  -9.97924805e-02],
                        [ -9.52453613e-02,  -9.52453613e-02],
                        [ -9.53369141e-02,  -9.53369141e-02],
                        [ -9.71984863e-02,  -9.71984863e-02],
                        [ -9.57641602e-02,  -9.57641602e-02],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -7.41882324e-02,  -7.41882324e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  1.37268066e-01,   1.37268066e-01],
                        [  1.62231445e-01,   1.62231445e-01],
                        [  1.62170410e-01,   1.62170410e-01],
                        [  1.51092529e-01,   1.51092529e-01],
                        [  1.52069092e-01,   1.52069092e-01],
                        [  1.73309326e-01,   1.73309326e-01],
                        [  1.99218750e-01,   1.99218750e-01],
                        [  2.12097168e-01,   2.12097168e-01],
                        [  2.07641602e-01,   2.07641602e-01],
                        [  1.82312012e-01,   1.82312012e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  2.69165039e-02,   2.69165039e-02],
                        [ -9.49401855e-02,  -9.49401855e-02],
                        [ -2.15698242e-01,  -2.15698242e-01],
                        [ -3.05114746e-01,  -3.05114746e-01],
                        [ -3.33557129e-01,  -3.33557129e-01],
                        [ -2.90954590e-01,  -2.90954590e-01],
                        [ -2.08374023e-01,  -2.08374023e-01],
                        [ -1.39739990e-01,  -1.39739990e-01],
                        [ -1.13281250e-01,  -1.13281250e-01],
                        [ -1.17034912e-01,  -1.17034912e-01],
                        [ -1.29455566e-01,  -1.29455566e-01],
                        [ -1.40625000e-01,  -1.40625000e-01],
                        [ -1.43646240e-01,  -1.43646240e-01],
                        [ -1.27899170e-01,  -1.27899170e-01],
                        [ -8.79211426e-02,  -8.79211426e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.94274902e-01,   1.94274902e-01],
                        [  2.26593018e-01,   2.26593018e-01],
                        [  2.17834473e-01,   2.17834473e-01],
                        [  1.85211182e-01,   1.85211182e-01],
                        [  1.48010254e-01,   1.48010254e-01],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  8.98742676e-02,   8.98742676e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  6.77795410e-02,   6.77795410e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -9.19189453e-02,  -9.19189453e-02],
                        [ -1.58935547e-01,  -1.58935547e-01],
                        [ -2.02362061e-01,  -2.02362061e-01],
                        [ -2.07763672e-01,  -2.07763672e-01],
                        [ -1.83410645e-01,  -1.83410645e-01],
                        [ -1.52496338e-01,  -1.52496338e-01],
                        [ -1.32019043e-01,  -1.32019043e-01],
                        [ -1.20086670e-01,  -1.20086670e-01],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -9.03930664e-02,  -9.03930664e-02],
                        [ -7.98339844e-02,  -7.98339844e-02],
                        [ -7.88879395e-02,  -7.88879395e-02],
                        [ -7.71789551e-02,  -7.71789551e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  1.42944336e-01,   1.42944336e-01],
                        [  1.54693604e-01,   1.54693604e-01],
                        [  1.70043945e-01,   1.70043945e-01],
                        [  1.88201904e-01,   1.88201904e-01],
                        [  2.01110840e-01,   2.01110840e-01],
                        [  2.04254150e-01,   2.04254150e-01],
                        [  1.95343018e-01,   1.95343018e-01],
                        [  1.66564941e-01,   1.66564941e-01],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.20849609e-02,   1.20849609e-02],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -2.19879150e-01,  -2.19879150e-01],
                        [ -2.99468994e-01,  -2.99468994e-01],
                        [ -3.20190430e-01,  -3.20190430e-01],
                        [ -2.84332275e-01,  -2.84332275e-01],
                        [ -2.21557617e-01,  -2.21557617e-01],
                        [ -1.68640137e-01,  -1.68640137e-01],
                        [ -1.44989014e-01,  -1.44989014e-01],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -1.46850586e-01,  -1.46850586e-01],
                        [ -1.39770508e-01,  -1.39770508e-01],
                        [ -1.25244141e-01,  -1.25244141e-01],
                        [ -1.08551025e-01,  -1.08551025e-01],
                        [ -8.22143555e-02,  -8.22143555e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  1.33758545e-01,   1.33758545e-01],
                        [  1.99523926e-01,   1.99523926e-01],
                        [  2.26531982e-01,   2.26531982e-01],
                        [  2.12371826e-01,   2.12371826e-01],
                        [  1.73370361e-01,   1.73370361e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  6.07299805e-02,   6.07299805e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  6.58874512e-02,   6.58874512e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  5.09643555e-03,   5.09643555e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -9.90905762e-02,  -9.90905762e-02],
                        [ -1.61834717e-01,  -1.61834717e-01],
                        [ -1.96990967e-01,  -1.96990967e-01],
                        [ -1.94427490e-01,  -1.94427490e-01],
                        [ -1.65985107e-01,  -1.65985107e-01],
                        [ -1.35589600e-01,  -1.35589600e-01],
                        [ -1.17248535e-01,  -1.17248535e-01],
                        [ -1.05957031e-01,  -1.05957031e-01],
                        [ -9.34143066e-02,  -9.34143066e-02],
                        [ -8.18786621e-02,  -8.18786621e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -7.74536133e-02,  -7.74536133e-02],
                        [ -7.44018555e-02,  -7.44018555e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  8.40148926e-02,   8.40148926e-02],
                        [  1.26556396e-01,   1.26556396e-01],
                        [  1.53930664e-01,   1.53930664e-01],
                        [  1.63116455e-01,   1.63116455e-01],
                        [  1.66809082e-01,   1.66809082e-01],
                        [  1.79931641e-01,   1.79931641e-01],
                        [  2.02880859e-01,   2.02880859e-01],
                        [  2.20764160e-01,   2.20764160e-01],
                        [  2.13439941e-01,   2.13439941e-01],
                        [  1.67388916e-01,   1.67388916e-01],
                        [  8.29772949e-02,   8.29772949e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -1.47888184e-01,  -1.47888184e-01],
                        [ -2.50762939e-01,  -2.50762939e-01],
                        [ -3.06915283e-01,  -3.06915283e-01],
                        [ -3.00506592e-01,  -3.00506592e-01],
                        [ -2.47009277e-01,  -2.47009277e-01],
                        [ -1.87103271e-01,  -1.87103271e-01],
                        [ -1.54998779e-01,  -1.54998779e-01],
                        [ -1.52740479e-01,  -1.52740479e-01],
                        [ -1.59423828e-01,  -1.59423828e-01],
                        [ -1.58691406e-01,  -1.58691406e-01],
                        [ -1.47644043e-01,  -1.47644043e-01],
                        [ -1.27044678e-01,  -1.27044678e-01],
                        [ -9.41467285e-02,  -9.41467285e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  1.68487549e-01,   1.68487549e-01],
                        [  2.10937500e-01,   2.10937500e-01],
                        [  2.17742920e-01,   2.17742920e-01],
                        [  1.99615479e-01,   1.99615479e-01],
                        [  1.71325684e-01,   1.71325684e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  6.39648438e-02,   6.39648438e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  7.68737793e-02,   7.68737793e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -9.34448242e-02,  -9.34448242e-02],
                        [ -1.48101807e-01,  -1.48101807e-01],
                        [ -1.82098389e-01,  -1.82098389e-01],
                        [ -1.82128906e-01,  -1.82128906e-01],
                        [ -1.57531738e-01,  -1.57531738e-01],
                        [ -1.30218506e-01,  -1.30218506e-01],
                        [ -1.12548828e-01,  -1.12548828e-01],
                        [ -1.02233887e-01,  -1.02233887e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -8.54492188e-02,  -8.54492188e-02],
                        [ -7.62329102e-02,  -7.62329102e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.66711426e-02,  -5.66711426e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  1.63421631e-01,   1.63421631e-01],
                        [  1.95220947e-01,   1.95220947e-01],
                        [  2.17132568e-01,   2.17132568e-01],
                        [  2.30438232e-01,   2.30438232e-01],
                        [  2.33001709e-01,   2.33001709e-01],
                        [  2.20367432e-01,   2.20367432e-01],
                        [  1.85638428e-01,   1.85638428e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  2.93884277e-02,   2.93884277e-02],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -1.99615479e-01,  -1.99615479e-01],
                        [ -2.93090820e-01,  -2.93090820e-01],
                        [ -3.31939697e-01,  -3.31939697e-01],
                        [ -3.03680420e-01,  -3.03680420e-01],
                        [ -2.37091064e-01,  -2.37091064e-01],
                        [ -1.81060791e-01,  -1.81060791e-01],
                        [ -1.60003662e-01,  -1.60003662e-01],
                        [ -1.60339355e-01,  -1.60339355e-01],
                        [ -1.58172607e-01,  -1.58172607e-01],
                        [ -1.45629883e-01,  -1.45629883e-01],
                        [ -1.26586914e-01,  -1.26586914e-01],
                        [ -9.97619629e-02,  -9.97619629e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.03149414e-01,   1.03149414e-01],
                        [  1.83013916e-01,   1.83013916e-01],
                        [  2.24121094e-01,   2.24121094e-01],
                        [  2.16644287e-01,   2.16644287e-01],
                        [  1.80480957e-01,   1.80480957e-01],
                        [  1.45538330e-01,   1.45538330e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  6.91528320e-02,   6.91528320e-02],
                        [  8.15429688e-02,   8.15429688e-02],
                        [  8.56323242e-02,   8.56323242e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -1.69616699e-01,  -1.69616699e-01],
                        [ -1.84570312e-01,  -1.84570312e-01],
                        [ -1.74194336e-01,  -1.74194336e-01],
                        [ -1.45233154e-01,  -1.45233154e-01],
                        [ -1.12945557e-01,  -1.12945557e-01],
                        [ -9.09423828e-02,  -9.09423828e-02],
                        [ -8.11157227e-02,  -8.11157227e-02],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.77947998e-01,   1.77947998e-01],
                        [  2.09259033e-01,   2.09259033e-01],
                        [  2.30499268e-01,   2.30499268e-01],
                        [  2.35992432e-01,   2.35992432e-01],
                        [  2.18444824e-01,   2.18444824e-01],
                        [  1.66412354e-01,   1.66412354e-01],
                        [  7.55310059e-02,   7.55310059e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -1.61895752e-01,  -1.61895752e-01],
                        [ -2.60864258e-01,  -2.60864258e-01],
                        [ -3.15765381e-01,  -3.15765381e-01],
                        [ -3.12927246e-01,  -3.12927246e-01],
                        [ -2.62145996e-01,  -2.62145996e-01],
                        [ -1.99035645e-01,  -1.99035645e-01],
                        [ -1.60522461e-01,  -1.60522461e-01],
                        [ -1.53656006e-01,  -1.53656006e-01],
                        [ -1.56005859e-01,  -1.56005859e-01],
                        [ -1.47644043e-01,  -1.47644043e-01],
                        [ -1.28662109e-01,  -1.28662109e-01],
                        [ -1.04248047e-01,  -1.04248047e-01],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  1.56860352e-01,   1.56860352e-01],
                        [  2.14019775e-01,   2.14019775e-01],
                        [  2.28240967e-01,   2.28240967e-01],
                        [  2.04162598e-01,   2.04162598e-01],
                        [  1.65069580e-01,   1.65069580e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  9.67102051e-02,   9.67102051e-02],
                        [  8.05053711e-02,   8.05053711e-02],
                        [  6.93054199e-02,   6.93054199e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  7.32116699e-02,   7.32116699e-02],
                        [  7.81250000e-02,   7.81250000e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  5.77392578e-02,   5.77392578e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  7.84301758e-03,   7.84301758e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -1.06994629e-01,  -1.06994629e-01],
                        [ -1.62139893e-01,  -1.62139893e-01],
                        [ -1.88537598e-01,  -1.88537598e-01],
                        [ -1.76330566e-01,  -1.76330566e-01],
                        [ -1.40014648e-01,  -1.40014648e-01],
                        [ -1.06872559e-01,  -1.06872559e-01],
                        [ -9.12780762e-02,  -9.12780762e-02],
                        [ -8.73718262e-02,  -8.73718262e-02],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -8.12072754e-02,  -8.12072754e-02],
                        [ -7.82470703e-02,  -7.82470703e-02],
                        [ -7.25097656e-02,  -7.25097656e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  1.27624512e-01,   1.27624512e-01],
                        [  1.72729492e-01,   1.72729492e-01],
                        [  2.04681396e-01,   2.04681396e-01],
                        [  2.23785400e-01,   2.23785400e-01],
                        [  2.32360840e-01,   2.32360840e-01],
                        [  2.28729248e-01,   2.28729248e-01],
                        [  2.02117920e-01,   2.02117920e-01],
                        [  1.38946533e-01,   1.38946533e-01],
                        [  3.70483398e-02,   3.70483398e-02],
                        [ -8.80432129e-02,  -8.80432129e-02],
                        [ -2.09350586e-01,  -2.09350586e-01],
                        [ -2.97607422e-01,  -2.97607422e-01],
                        [ -3.29559326e-01,  -3.29559326e-01],
                        [ -3.02185059e-01,  -3.02185059e-01],
                        [ -2.42309570e-01,  -2.42309570e-01],
                        [ -1.90307617e-01,  -1.90307617e-01],
                        [ -1.67694092e-01,  -1.67694092e-01],
                        [ -1.64398193e-01,  -1.64398193e-01],
                        [ -1.57775879e-01,  -1.57775879e-01],
                        [ -1.37268066e-01,  -1.37268066e-01],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  1.91864014e-01,   1.91864014e-01],
                        [  2.17590332e-01,   2.17590332e-01],
                        [  2.14385986e-01,   2.14385986e-01],
                        [  1.89361572e-01,   1.89361572e-01],
                        [  1.52130127e-01,   1.52130127e-01],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  6.30493164e-02,   6.30493164e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  6.51245117e-02,   6.51245117e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  7.40661621e-02,   7.40661621e-02],
                        [  8.11462402e-02,   8.11462402e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  7.50732422e-02,   7.50732422e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -1.02783203e-01,  -1.02783203e-01],
                        [ -1.58020020e-01,  -1.58020020e-01],
                        [ -1.84387207e-01,  -1.84387207e-01],
                        [ -1.77154541e-01,  -1.77154541e-01],
                        [ -1.50299072e-01,  -1.50299072e-01],
                        [ -1.25061035e-01,  -1.25061035e-01],
                        [ -1.12182617e-01,  -1.12182617e-01],
                        [ -1.05163574e-01,  -1.05163574e-01],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -7.56530762e-02,  -7.56530762e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  1.47186279e-01,   1.47186279e-01],
                        [  1.92901611e-01,   1.92901611e-01],
                        [  2.26470947e-01,   2.26470947e-01],
                        [  2.49450684e-01,   2.49450684e-01],
                        [  2.58575439e-01,   2.58575439e-01],
                        [  2.39166260e-01,   2.39166260e-01],
                        [  1.76055908e-01,   1.76055908e-01],
                        [  7.03735352e-02,   7.03735352e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -1.91772461e-01,  -1.91772461e-01],
                        [ -2.98706055e-01,  -2.98706055e-01],
                        [ -3.51745605e-01,  -3.51745605e-01],
                        [ -3.36181641e-01,  -3.36181641e-01],
                        [ -2.72583008e-01,  -2.72583008e-01],
                        [ -2.05841064e-01,  -2.05841064e-01],
                        [ -1.68426514e-01,  -1.68426514e-01],
                        [ -1.58905029e-01,  -1.58905029e-01],
                        [ -1.55303955e-01,  -1.55303955e-01],
                        [ -1.40197754e-01,  -1.40197754e-01],
                        [ -1.10015869e-01,  -1.10015869e-01],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  7.01904297e-02,   7.01904297e-02],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  2.01995850e-01,   2.01995850e-01],
                        [  2.22656250e-01,   2.22656250e-01],
                        [  2.10693359e-01,   2.10693359e-01],
                        [  1.80511475e-01,   1.80511475e-01],
                        [  1.46759033e-01,   1.46759033e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  1.04064941e-01,   1.04064941e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  9.46044922e-02,   9.46044922e-02],
                        [  7.22656250e-02,   7.22656250e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -1.21032715e-01,  -1.21032715e-01],
                        [ -1.71478271e-01,  -1.71478271e-01],
                        [ -1.90521240e-01,  -1.90521240e-01],
                        [ -1.78375244e-01,  -1.78375244e-01],
                        [ -1.49261475e-01,  -1.49261475e-01],
                        [ -1.21185303e-01,  -1.21185303e-01],
                        [ -1.02447510e-01,  -1.02447510e-01],
                        [ -8.90197754e-02,  -8.90197754e-02],
                        [ -7.58056641e-02,  -7.58056641e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.85089111e-01,   1.85089111e-01],
                        [  2.26440430e-01,   2.26440430e-01],
                        [  2.45788574e-01,   2.45788574e-01],
                        [  2.40875244e-01,   2.40875244e-01],
                        [  2.08343506e-01,   2.08343506e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  4.03747559e-02,   4.03747559e-02],
                        [ -8.48999023e-02,  -8.48999023e-02],
                        [ -2.09442139e-01,  -2.09442139e-01],
                        [ -3.03588867e-01,  -3.03588867e-01],
                        [ -3.42376709e-01,  -3.42376709e-01],
                        [ -3.19732666e-01,  -3.19732666e-01],
                        [ -2.58422852e-01,  -2.58422852e-01],
                        [ -1.99127197e-01,  -1.99127197e-01],
                        [ -1.69006348e-01,  -1.69006348e-01],
                        [ -1.61224365e-01,  -1.61224365e-01],
                        [ -1.50329590e-01,  -1.50329590e-01],
                        [ -1.22192383e-01,  -1.22192383e-01],
                        [ -8.06274414e-02,  -8.06274414e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  9.72900391e-02,   9.72900391e-02],
                        [  1.59515381e-01,   1.59515381e-01],
                        [  1.99188232e-01,   1.99188232e-01],
                        [  2.08282471e-01,   2.08282471e-01],
                        [  1.91650391e-01,   1.91650391e-01],
                        [  1.62933350e-01,   1.62933350e-01],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  2.95410156e-02,   2.95410156e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -1.51184082e-01,  -1.51184082e-01],
                        [ -1.58691406e-01,  -1.58691406e-01],
                        [ -1.36627197e-01,  -1.36627197e-01],
                        [ -1.08489990e-01,  -1.08489990e-01],
                        [ -9.23156738e-02,  -9.23156738e-02],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -7.63244629e-02,  -7.63244629e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  1.17340088e-01,   1.17340088e-01],
                        [  1.73034668e-01,   1.73034668e-01],
                        [  2.16125488e-01,   2.16125488e-01],
                        [  2.39471436e-01,   2.39471436e-01],
                        [  2.33612061e-01,   2.33612061e-01],
                        [  1.90795898e-01,   1.90795898e-01],
                        [  1.10534668e-01,   1.10534668e-01],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -1.31347656e-01,  -1.31347656e-01],
                        [ -2.52716064e-01,  -2.52716064e-01],
                        [ -3.29132080e-01,  -3.29132080e-01],
                        [ -3.38134766e-01,  -3.38134766e-01],
                        [ -2.90832520e-01,  -2.90832520e-01],
                        [ -2.25402832e-01,  -2.25402832e-01],
                        [ -1.79504395e-01,  -1.79504395e-01],
                        [ -1.65069580e-01,  -1.65069580e-01],
                        [ -1.64550781e-01,  -1.64550781e-01],
                        [ -1.51031494e-01,  -1.51031494e-01],
                        [ -1.12731934e-01,  -1.12731934e-01],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  1.25823975e-01,   1.25823975e-01],
                        [  1.76971436e-01,   1.76971436e-01],
                        [  2.03338623e-01,   2.03338623e-01],
                        [  2.01751709e-01,   2.01751709e-01],
                        [  1.83410645e-01,   1.83410645e-01],
                        [  1.59820557e-01,   1.59820557e-01],
                        [  1.32843018e-01,   1.32843018e-01],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  5.27038574e-02,   5.27038574e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  1.46484375e-03,   1.46484375e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -7.96203613e-02,  -7.96203613e-02],
                        [ -1.28326416e-01,  -1.28326416e-01],
                        [ -1.52069092e-01,  -1.52069092e-01],
                        [ -1.45599365e-01,  -1.45599365e-01],
                        [ -1.23321533e-01,  -1.23321533e-01],
                        [ -1.02233887e-01,  -1.02233887e-01],
                        [ -8.84399414e-02,  -8.84399414e-02],
                        [ -7.88574219e-02,  -7.88574219e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  1.84204102e-01,   1.84204102e-01],
                        [  2.30682373e-01,   2.30682373e-01],
                        [  2.42553711e-01,   2.42553711e-01],
                        [  2.17437744e-01,   2.17437744e-01],
                        [  1.57958984e-01,   1.57958984e-01],
                        [  6.44531250e-02,   6.44531250e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -1.89361572e-01,  -1.89361572e-01],
                        [ -2.96447754e-01,  -2.96447754e-01],
                        [ -3.46618652e-01,  -3.46618652e-01],
                        [ -3.28857422e-01,  -3.28857422e-01],
                        [ -2.66387939e-01,  -2.66387939e-01],
                        [ -2.03338623e-01,  -2.03338623e-01],
                        [ -1.69799805e-01,  -1.69799805e-01],
                        [ -1.60308838e-01,  -1.60308838e-01],
                        [ -1.48651123e-01,  -1.48651123e-01],
                        [ -1.18133545e-01,  -1.18133545e-01],
                        [ -7.19909668e-02,  -7.19909668e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  1.42761230e-01,   1.42761230e-01],
                        [  1.75506592e-01,   1.75506592e-01],
                        [  1.86035156e-01,   1.86035156e-01],
                        [  1.78924561e-01,   1.78924561e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.40716553e-01,   1.40716553e-01],
                        [  1.14013672e-01,   1.14013672e-01],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -1.09466553e-01,  -1.09466553e-01],
                        [ -1.40289307e-01,  -1.40289307e-01],
                        [ -1.46514893e-01,  -1.46514893e-01],
                        [ -1.31103516e-01,  -1.31103516e-01],
                        [ -1.05621338e-01,  -1.05621338e-01],
                        [ -8.17565918e-02,  -8.17565918e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -5.28259277e-02,  -5.28259277e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  1.06140137e-01,   1.06140137e-01],
                        [  1.63208008e-01,   1.63208008e-01],
                        [  2.11914062e-01,   2.11914062e-01],
                        [  2.29034424e-01,   2.29034424e-01],
                        [  2.01263428e-01,   2.01263428e-01],
                        [  1.31195068e-01,   1.31195068e-01],
                        [  2.91442871e-02,   2.91442871e-02],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -2.18505859e-01,  -2.18505859e-01],
                        [ -3.15124512e-01,  -3.15124512e-01],
                        [ -3.52600098e-01,  -3.52600098e-01],
                        [ -3.25561523e-01,  -3.25561523e-01],
                        [ -2.63793945e-01,  -2.63793945e-01],
                        [ -2.07489014e-01,  -2.07489014e-01],
                        [ -1.72729492e-01,  -1.72729492e-01],
                        [ -1.46850586e-01,  -1.46850586e-01],
                        [ -1.14349365e-01,  -1.14349365e-01],
                        [ -7.55310059e-02,  -7.55310059e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  1.16241455e-01,   1.16241455e-01],
                        [  1.64794922e-01,   1.64794922e-01],
                        [  1.86279297e-01,   1.86279297e-01],
                        [  1.81579590e-01,   1.81579590e-01],
                        [  1.65863037e-01,   1.65863037e-01],
                        [  1.51306152e-01,   1.51306152e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  7.16247559e-02,   7.16247559e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  5.35583496e-02,   5.35583496e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  3.23486328e-03,   3.23486328e-03],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -9.06372070e-02,  -9.06372070e-02],
                        [ -1.41754150e-01,  -1.41754150e-01],
                        [ -1.68853760e-01,  -1.68853760e-01],
                        [ -1.61285400e-01,  -1.61285400e-01],
                        [ -1.25762939e-01,  -1.25762939e-01],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  2.02178955e-01,   2.02178955e-01],
                        [  2.37579346e-01,   2.37579346e-01],
                        [  2.30895996e-01,   2.30895996e-01],
                        [  1.79138184e-01,   1.79138184e-01],
                        [  8.98742676e-02,   8.98742676e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -1.58081055e-01,  -1.58081055e-01],
                        [ -2.78625488e-01,  -2.78625488e-01],
                        [ -3.53515625e-01,  -3.53515625e-01],
                        [ -3.58978271e-01,  -3.58978271e-01],
                        [ -3.08654785e-01,  -3.08654785e-01],
                        [ -2.48199463e-01,  -2.48199463e-01],
                        [ -2.12768555e-01,  -2.12768555e-01],
                        [ -1.96563721e-01,  -1.96563721e-01],
                        [ -1.70837402e-01,  -1.70837402e-01],
                        [ -1.22436523e-01,  -1.22436523e-01],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  1.05316162e-01,   1.05316162e-01],
                        [  1.53015137e-01,   1.53015137e-01],
                        [  1.82189941e-01,   1.82189941e-01],
                        [  1.89331055e-01,   1.89331055e-01],
                        [  1.81243896e-01,   1.81243896e-01],
                        [  1.66809082e-01,   1.66809082e-01],
                        [  1.49414062e-01,   1.49414062e-01],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  7.39135742e-02,   7.39135742e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -1.18408203e-01,  -1.18408203e-01],
                        [ -1.38610840e-01,  -1.38610840e-01],
                        [ -1.35833740e-01,  -1.35833740e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -8.71887207e-02,  -8.71887207e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  1.72027588e-01,   1.72027588e-01],
                        [  2.15850830e-01,   2.15850830e-01],
                        [  2.29278564e-01,   2.29278564e-01],
                        [  1.97692871e-01,   1.97692871e-01],
                        [  1.23229980e-01,   1.23229980e-01],
                        [  1.69372559e-02,   1.69372559e-02],
                        [ -1.10748291e-01,  -1.10748291e-01],
                        [ -2.40936279e-01,  -2.40936279e-01],
                        [ -3.37341309e-01,  -3.37341309e-01],
                        [ -3.66760254e-01,  -3.66760254e-01],
                        [ -3.31604004e-01,  -3.31604004e-01],
                        [ -2.69775391e-01,  -2.69775391e-01],
                        [ -2.18933105e-01,  -2.18933105e-01],
                        [ -1.88446045e-01,  -1.88446045e-01],
                        [ -1.65832520e-01,  -1.65832520e-01],
                        [ -1.36779785e-01,  -1.36779785e-01],
                        [ -9.19799805e-02,  -9.19799805e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  1.21246338e-01,   1.21246338e-01],
                        [  1.65374756e-01,   1.65374756e-01],
                        [  1.82617188e-01,   1.82617188e-01],
                        [  1.83502197e-01,   1.83502197e-01],
                        [  1.76330566e-01,   1.76330566e-01],
                        [  1.65130615e-01,   1.65130615e-01],
                        [  1.51031494e-01,   1.51031494e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  6.27136230e-02,   6.27136230e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  7.87963867e-02,   7.87963867e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  4.85229492e-03,   4.85229492e-03],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -7.10144043e-02,  -7.10144043e-02],
                        [ -1.16729736e-01,  -1.16729736e-01],
                        [ -1.41082764e-01,  -1.41082764e-01],
                        [ -1.32141113e-01,  -1.32141113e-01],
                        [ -1.01013184e-01,  -1.01013184e-01],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  8.95996094e-02,   8.95996094e-02],
                        [  1.48529053e-01,   1.48529053e-01],
                        [  2.01446533e-01,   2.01446533e-01],
                        [  2.27996826e-01,   2.27996826e-01],
                        [  2.12799072e-01,   2.12799072e-01],
                        [  1.52709961e-01,   1.52709961e-01],
                        [  5.31921387e-02,   5.31921387e-02],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -2.01171875e-01,  -2.01171875e-01],
                        [ -3.00872803e-01,  -3.00872803e-01],
                        [ -3.45886230e-01,  -3.45886230e-01],
                        [ -3.31512451e-01,  -3.31512451e-01],
                        [ -2.80059814e-01,  -2.80059814e-01],
                        [ -2.26928711e-01,  -2.26928711e-01],
                        [ -1.94183350e-01,  -1.94183350e-01],
                        [ -1.75354004e-01,  -1.75354004e-01],
                        [ -1.46942139e-01,  -1.46942139e-01],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.58081055e-01,   1.58081055e-01],
                        [  1.66259766e-01,   1.66259766e-01],
                        [  1.68914795e-01,   1.68914795e-01],
                        [  1.73034668e-01,   1.73034668e-01],
                        [  1.69525146e-01,   1.69525146e-01],
                        [  1.48895264e-01,   1.48895264e-01],
                        [  1.17401123e-01,   1.17401123e-01],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  6.81457520e-02,   6.81457520e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -1.33666992e-01,  -1.33666992e-01],
                        [ -1.28448486e-01,  -1.28448486e-01],
                        [ -9.52453613e-02,  -9.52453613e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -6.09436035e-02,  -6.09436035e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.88262939e-01,   1.88262939e-01],
                        [  2.24273682e-01,   2.24273682e-01],
                        [  2.23144531e-01,   2.23144531e-01],
                        [  1.77124023e-01,   1.77124023e-01],
                        [  8.74023438e-02,   8.74023438e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -1.70745850e-01,  -1.70745850e-01],
                        [ -2.81982422e-01,  -2.81982422e-01],
                        [ -3.39233398e-01,  -3.39233398e-01],
                        [ -3.34411621e-01,  -3.34411621e-01],
                        [ -2.87200928e-01,  -2.87200928e-01],
                        [ -2.32299805e-01,  -2.32299805e-01],
                        [ -1.95495605e-01,  -1.95495605e-01],
                        [ -1.76757812e-01,  -1.76757812e-01],
                        [ -1.55944824e-01,  -1.55944824e-01],
                        [ -1.14990234e-01,  -1.14990234e-01],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  8.70971680e-02,   8.70971680e-02],
                        [  1.35437012e-01,   1.35437012e-01],
                        [  1.58691406e-01,   1.58691406e-01],
                        [  1.60064697e-01,   1.60064697e-01],
                        [  1.54052734e-01,   1.54052734e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.58843994e-01,   1.58843994e-01],
                        [  1.52069092e-01,   1.52069092e-01],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  5.50231934e-02,   5.50231934e-02],
                        [  6.65283203e-02,   6.65283203e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  6.80541992e-02,   6.80541992e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -1.02752686e-01,  -1.02752686e-01],
                        [ -1.40228271e-01,  -1.40228271e-01],
                        [ -1.47186279e-01,  -1.47186279e-01],
                        [ -1.21185303e-01,  -1.21185303e-01],
                        [ -8.13293457e-02,  -8.13293457e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  1.40502930e-01,   1.40502930e-01],
                        [  1.86767578e-01,   1.86767578e-01],
                        [  2.16003418e-01,   2.16003418e-01],
                        [  2.11486816e-01,   2.11486816e-01],
                        [  1.60736084e-01,   1.60736084e-01],
                        [  6.59484863e-02,   6.59484863e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -1.94000244e-01,  -1.94000244e-01],
                        [ -3.07220459e-01,  -3.07220459e-01],
                        [ -3.64868164e-01,  -3.64868164e-01],
                        [ -3.51318359e-01,  -3.51318359e-01],
                        [ -2.87322998e-01,  -2.87322998e-01],
                        [ -2.19207764e-01,  -2.19207764e-01],
                        [ -1.80297852e-01,  -1.80297852e-01],
                        [ -1.64733887e-01,  -1.64733887e-01],
                        [ -1.42639160e-01,  -1.42639160e-01],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  1.09954834e-01,   1.09954834e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.57897949e-01,   1.57897949e-01],
                        [  1.56127930e-01,   1.56127930e-01],
                        [  1.56280518e-01,   1.56280518e-01],
                        [  1.60858154e-01,   1.60858154e-01],
                        [  1.58752441e-01,   1.58752441e-01],
                        [  1.40228271e-01,   1.40228271e-01],
                        [  1.08337402e-01,   1.08337402e-01],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  5.23681641e-02,   5.23681641e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  7.35473633e-02,   7.35473633e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -1.03881836e-01,  -1.03881836e-01],
                        [ -1.42578125e-01,  -1.42578125e-01],
                        [ -1.51306152e-01,  -1.51306152e-01],
                        [ -1.28051758e-01,  -1.28051758e-01],
                        [ -8.75549316e-02,  -8.75549316e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  4.02526855e-02,   4.02526855e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  1.35955811e-01,   1.35955811e-01],
                        [  1.77581787e-01,   1.77581787e-01],
                        [  1.98944092e-01,   1.98944092e-01],
                        [  1.85455322e-01,   1.85455322e-01],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  1.23291016e-02,   1.23291016e-02],
                        [ -1.24114990e-01,  -1.24114990e-01],
                        [ -2.52532959e-01,  -2.52532959e-01],
                        [ -3.40118408e-01,  -3.40118408e-01],
                        [ -3.64074707e-01,  -3.64074707e-01],
                        [ -3.25042725e-01,  -3.25042725e-01],
                        [ -2.54791260e-01,  -2.54791260e-01],
                        [ -1.96380615e-01,  -1.96380615e-01],
                        [ -1.68457031e-01,  -1.68457031e-01],
                        [ -1.52587891e-01,  -1.52587891e-01],
                        [ -1.17431641e-01,  -1.17431641e-01],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  1.45996094e-01,   1.45996094e-01],
                        [  1.53808594e-01,   1.53808594e-01],
                        [  1.44744873e-01,   1.44744873e-01],
                        [  1.39556885e-01,   1.39556885e-01],
                        [  1.42974854e-01,   1.42974854e-01],
                        [  1.42730713e-01,   1.42730713e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.04705811e-01,   1.04705811e-01],
                        [  8.06274414e-02,   8.06274414e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  8.56323242e-02,   8.56323242e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  7.80334473e-02,   7.80334473e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.21850586e-03,   5.21850586e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -1.01531982e-01,  -1.01531982e-01],
                        [ -1.27075195e-01,  -1.27075195e-01],
                        [ -1.29119873e-01,  -1.29119873e-01],
                        [ -1.07147217e-01,  -1.07147217e-01],
                        [ -7.11059570e-02,  -7.11059570e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  1.55029297e-01,   1.55029297e-01],
                        [  1.87683105e-01,   1.87683105e-01],
                        [  1.94702148e-01,   1.94702148e-01],
                        [  1.56555176e-01,   1.56555176e-01],
                        [  6.82067871e-02,   6.82067871e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -1.89300537e-01,  -1.89300537e-01],
                        [ -3.03009033e-01,  -3.03009033e-01],
                        [ -3.66577148e-01,  -3.66577148e-01],
                        [ -3.65661621e-01,  -3.65661621e-01],
                        [ -3.14788818e-01,  -3.14788818e-01],
                        [ -2.47833252e-01,  -2.47833252e-01],
                        [ -1.93145752e-01,  -1.93145752e-01],
                        [ -1.56280518e-01,  -1.56280518e-01],
                        [ -1.22283936e-01,  -1.22283936e-01],
                        [ -7.35473633e-02,  -7.35473633e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  1.35284424e-01,   1.35284424e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  1.40075684e-01,   1.40075684e-01],
                        [  1.41113281e-01,   1.41113281e-01],
                        [  1.45721436e-01,   1.45721436e-01],
                        [  1.43218994e-01,   1.43218994e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  9.17968750e-02,   9.17968750e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  6.02722168e-02,   6.02722168e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  1.29089355e-02,   1.29089355e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -9.71069336e-02,  -9.71069336e-02],
                        [ -1.19903564e-01,  -1.19903564e-01],
                        [ -1.17828369e-01,  -1.17828369e-01],
                        [ -9.53063965e-02,  -9.53063965e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  1.20910645e-01,   1.20910645e-01],
                        [  1.72454834e-01,   1.72454834e-01],
                        [  2.02911377e-01,   2.02911377e-01],
                        [  1.94580078e-01,   1.94580078e-01],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  4.40673828e-02,   4.40673828e-02],
                        [ -8.61816406e-02,  -8.61816406e-02],
                        [ -2.25067139e-01,  -2.25067139e-01],
                        [ -3.35357666e-01,  -3.35357666e-01],
                        [ -3.84368896e-01,  -3.84368896e-01],
                        [ -3.63891602e-01,  -3.63891602e-01],
                        [ -2.98675537e-01,  -2.98675537e-01],
                        [ -2.31536865e-01,  -2.31536865e-01],
                        [ -1.89544678e-01,  -1.89544678e-01],
                        [ -1.63452148e-01,  -1.63452148e-01],
                        [ -1.25122070e-01,  -1.25122070e-01],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.35162354e-01,   1.35162354e-01],
                        [  1.41571045e-01,   1.41571045e-01],
                        [  1.31042480e-01,   1.31042480e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.25854492e-01,   1.25854492e-01],
                        [  1.29974365e-01,   1.29974365e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.19659424e-01,   1.19659424e-01],
                        [  1.05529785e-01,   1.05529785e-01],
                        [  8.96301270e-02,   8.96301270e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  7.61108398e-02,   7.61108398e-02],
                        [  9.39025879e-02,   9.39025879e-02],
                        [  1.04614258e-01,   1.04614258e-01],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  7.26928711e-02,   7.26928711e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -1.05590820e-01,  -1.05590820e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -1.23016357e-01,  -1.23016357e-01],
                        [ -9.47265625e-02,  -9.47265625e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.58721924e-01,   1.58721924e-01],
                        [  1.92596436e-01,   1.92596436e-01],
                        [  1.95831299e-01,   1.95831299e-01],
                        [  1.55212402e-01,   1.55212402e-01],
                        [  6.46362305e-02,   6.46362305e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -2.04772949e-01,  -2.04772949e-01],
                        [ -3.17199707e-01,  -3.17199707e-01],
                        [ -3.71948242e-01,  -3.71948242e-01],
                        [ -3.60809326e-01,  -3.60809326e-01],
                        [ -3.05908203e-01,  -3.05908203e-01],
                        [ -2.45513916e-01,  -2.45513916e-01],
                        [ -2.04528809e-01,  -2.04528809e-01],
                        [ -1.76727295e-01,  -1.76727295e-01],
                        [ -1.37268066e-01,  -1.37268066e-01],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  1.17828369e-01,   1.17828369e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  1.25366211e-01,   1.25366211e-01],
                        [  1.34460449e-01,   1.34460449e-01],
                        [  1.40747070e-01,   1.40747070e-01],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  8.86230469e-02,   8.86535645e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  8.88671875e-02,   8.88671875e-02],
                        [  9.11865234e-02,   9.11865234e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  4.61730957e-02,   4.62036133e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -5.46264648e-03,  -5.43212891e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -3.32031250e-02,  -3.31726074e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -7.26623535e-02,  -7.26623535e-02],
                        [ -9.62829590e-02,  -9.62829590e-02],
                        [ -9.42687988e-02,  -9.42687988e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  5.19104004e-02,   5.18798828e-02],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.67297363e-01,   1.67297363e-01],
                        [  1.72454834e-01,   1.72485352e-01],
                        [  1.35955811e-01,   1.35955811e-01],
                        [  5.05371094e-02,   5.05371094e-02],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -2.07275391e-01,  -2.07275391e-01],
                        [ -3.13537598e-01,  -3.13537598e-01],
                        [ -3.62792969e-01,  -3.62792969e-01],
                        [ -3.48419189e-01,  -3.48419189e-01],
                        [ -2.91290283e-01,  -2.91290283e-01],
                        [ -2.27569580e-01,  -2.27569580e-01],
                        [ -1.82861328e-01,  -1.82861328e-01],
                        [ -1.53259277e-01,  -1.53259277e-01],
                        [ -1.14440918e-01,  -1.14440918e-01],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  1.15722656e-01,   1.15722656e-01],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.30798340e-01,   1.30798340e-01],
                        [  1.20971680e-01,   1.20971680e-01],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.46679688e-02,   3.46374512e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  6.26831055e-02,   6.26831055e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  4.64172363e-02,   4.63867188e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.05895996e-02,  -1.05590820e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.95312500e-02,   1.95617676e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  4.30908203e-02,   4.30908203e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -2.80151367e-02,  -2.79846191e-02],
                        [ -3.32641602e-02,  -3.32946777e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -2.45971680e-02,  -2.45666504e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -1.84936523e-02,  -1.84631348e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.52880859e-02,  -4.53186035e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  1.58386230e-02,   1.58386230e-02],
                        [ -2.80761719e-03,  -2.83813477e-03],
                        [ -2.99377441e-02,  -2.99072266e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -1.94091797e-02,  -1.93786621e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  3.27758789e-02,   3.28063965e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  8.78295898e-02,   8.78295898e-02],
                        [  1.25457764e-01,   1.25457764e-01],
                        [  1.50665283e-01,   1.50665283e-01],
                        [  1.41601562e-01,   1.41601562e-01],
                        [  8.31604004e-02,   8.31604004e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.46179199e-01,  -1.46179199e-01],
                        [ -2.63824463e-01,  -2.63824463e-01],
                        [ -3.44207764e-01,  -3.44207764e-01],
                        [ -3.68011475e-01,  -3.68011475e-01],
                        [ -3.38134766e-01,  -3.38134766e-01],
                        [ -2.79205322e-01,  -2.79205322e-01],
                        [ -2.18231201e-01,  -2.18231201e-01],
                        [ -1.67663574e-01,  -1.67663574e-01],
                        [ -1.22283936e-01,  -1.22283936e-01],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.31774902e-01,   1.31774902e-01],
                        [  1.14776611e-01,   1.14776611e-01],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  1.15295410e-01,   1.15295410e-01],
                        [  1.21917725e-01,   1.21887207e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  1.00189209e-01,   1.00189209e-01],
                        [  8.41369629e-02,   8.41369629e-02],
                        [  6.13403320e-02,   6.13708496e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  2.05078125e-02,   2.04772949e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.09558105e-02,   1.09252930e-02],
                        [  2.07824707e-02,   2.08129883e-02],
                        [  3.61022949e-02,   3.61328125e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  7.25708008e-02,   7.25402832e-02],
                        [  8.59680176e-02,   8.59985352e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  3.34777832e-02,   3.35083008e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -1.81274414e-02,  -1.81579590e-02],
                        [ -3.04260254e-02,  -3.03955078e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -2.62451172e-02,  -2.62756348e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  7.23266602e-03,   7.20214844e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -4.08935547e-03,  -4.05883789e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -3.66210938e-04,  -3.96728516e-04],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  2.11181641e-02,   2.10876465e-02],
                        [  2.19726562e-02,   2.19421387e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.93884277e-02,  -2.94189453e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -3.75671387e-02,  -3.75976562e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -6.68945312e-02,  -6.69250488e-02],
                        [ -6.68640137e-02,  -6.68334961e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [  1.69372559e-02,   1.69677734e-02],
                        [  4.89807129e-02,   4.89501953e-02],
                        [  9.08813477e-02,   9.08813477e-02],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.54388428e-01,   1.54357910e-01],
                        [  1.39556885e-01,   1.39556885e-01],
                        [  8.06274414e-02,   8.06274414e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.48651123e-01,  -1.48651123e-01],
                        [ -2.73162842e-01,  -2.73162842e-01],
                        [ -3.55041504e-01,  -3.55010986e-01],
                        [ -3.72528076e-01,  -3.72528076e-01],
                        [ -3.33831787e-01,  -3.33831787e-01],
                        [ -2.68188477e-01,  -2.68188477e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.59973145e-01,  -1.59973145e-01],
                        [ -1.20788574e-01,  -1.20788574e-01],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  1.21063232e-01,   1.21063232e-01],
                        [  1.18988037e-01,   1.18988037e-01],
                        [  1.15112305e-01,   1.15142822e-01],
                        [  1.17492676e-01,   1.17492676e-01],
                        [  1.23016357e-01,   1.22985840e-01],
                        [  1.26037598e-01,   1.26007080e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.14318848e-01,   1.14318848e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  5.48706055e-02,   5.49011230e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  1.30310059e-02,   1.30004883e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  2.80761719e-03,   2.77709961e-03],
                        [  1.42211914e-02,   1.42517090e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  5.27343750e-02,   5.27038574e-02],
                        [  7.32116699e-02,   7.32116699e-02],
                        [  8.42895508e-02,   8.43200684e-02],
                        [  8.50830078e-02,   8.50524902e-02],
                        [  7.97424316e-02,   7.97119141e-02],
                        [  7.36694336e-02,   7.36999512e-02],
                        [  6.86645508e-02,   6.86340332e-02],
                        [  6.17065430e-02,   6.16760254e-02],
                        [  5.10253906e-02,   5.10559082e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.82592773e-02,   2.82287598e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  6.77490234e-03,   6.80541992e-03],
                        [ -5.79833984e-03,  -5.82885742e-03],
                        [ -2.14538574e-02,  -2.14843750e-02],
                        [ -3.60717773e-02,  -3.60412598e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -2.89001465e-02,  -2.89306641e-02],
                        [ -1.13525391e-02,  -1.13220215e-02],
                        [  1.43432617e-03,   1.46484375e-03],
                        [  7.84301758e-03,   7.81250000e-03],
                        [  1.42211914e-02,   1.41906738e-02],
                        [  2.40478516e-02,   2.41088867e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  3.50952148e-02,   3.50646973e-02],
                        [  3.08532715e-02,   3.08837891e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.16979980e-02,   2.16369629e-02],
                        [  1.91955566e-02,   1.92260742e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  1.71508789e-02,   1.71203613e-02],
                        [  1.01013184e-02,   1.00708008e-02],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [ -8.75854492e-03,  -8.78906250e-03],
                        [ -1.22680664e-02,  -1.22985840e-02],
                        [ -1.41906738e-02,  -1.41601562e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.77917480e-02,  -1.78222656e-02],
                        [ -2.37731934e-02,  -2.37426758e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -4.12292480e-02,  -4.12597656e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -2.81677246e-02,  -2.81372070e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -1.53808594e-02,  -1.54113770e-02],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  1.28784180e-02,   1.29089355e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.54113770e-02,   1.54418945e-02],
                        [  1.11389160e-02,   1.11083984e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -6.62841797e-02,  -6.63146973e-02],
                        [ -8.33435059e-02,  -8.33740234e-02],
                        [ -7.61108398e-02,  -7.61108398e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  7.90710449e-02,   7.90710449e-02],
                        [  1.23352051e-01,   1.23352051e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.71447754e-01,   1.71447754e-01],
                        [  1.36535645e-01,   1.36505127e-01],
                        [  4.60510254e-02,   4.60510254e-02],
                        [ -8.82263184e-02,  -8.81958008e-02],
                        [ -2.32452393e-01,  -2.32482910e-01],
                        [ -3.43170166e-01,  -3.43170166e-01],
                        [ -3.87908936e-01,  -3.87878418e-01],
                        [ -3.64105225e-01,  -3.64135742e-01],
                        [ -3.00262451e-01,  -3.00262451e-01],
                        [ -2.33612061e-01,  -2.33612061e-01],
                        [ -1.81610107e-01,  -1.81610107e-01],
                        [ -1.33819580e-01,  -1.33819580e-01],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  1.01684570e-01,   1.01715088e-01],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  9.45129395e-02,   9.44824219e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  1.00891113e-01,   1.00921631e-01],
                        [  1.17492676e-01,   1.17431641e-01],
                        [  1.25061035e-01,   1.25061035e-01],
                        [  1.17218018e-01,   1.17279053e-01],
                        [  1.00738525e-01,   1.00708008e-01],
                        [  8.48999023e-02,   8.48693848e-02],
                        [  7.19909668e-02,   7.20520020e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  4.08630371e-02,   4.08020020e-02],
                        [  2.02941895e-02,   2.03247070e-02],
                        [  3.81469727e-03,   3.87573242e-03],
                        [ -2.34985352e-03,  -2.38037109e-03],
                        [  3.47900391e-03,   3.44848633e-03],
                        [  2.11486816e-02,   2.12097168e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  7.55920410e-02,   7.55615234e-02],
                        [  9.61914062e-02,   9.62219238e-02],
                        [  1.06903076e-01,   1.06933594e-01],
                        [  1.07116699e-01,   1.07055664e-01],
                        [  9.71069336e-02,   9.71374512e-02],
                        [  8.16040039e-02,   8.16345215e-02],
                        [  6.62536621e-02,   6.62231445e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  3.28369141e-02,   3.28674316e-02],
                        [  1.08337402e-02,   1.08032227e-02],
                        [ -9.79614258e-03,  -9.82666016e-03],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -1.32446289e-02,  -1.32751465e-02],
                        [ -5.46264648e-03,  -5.43212891e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [ -1.22070312e-04,  -1.52587891e-04],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  7.96508789e-03,   7.93457031e-03],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  2.06604004e-02,   2.06298828e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  1.90124512e-02,   1.90429688e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  1.70898438e-02,   1.70593262e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.94396973e-02,   1.94702148e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  6.98852539e-03,   6.98852539e-03],
                        [ -2.59399414e-03,  -2.56347656e-03],
                        [ -1.04370117e-02,  -1.04064941e-02],
                        [ -1.58386230e-02,  -1.58691406e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -3.20434570e-02,  -3.20129395e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -4.96215820e-02,  -4.95910645e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -1.13220215e-02,  -1.13525391e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -1.56555176e-02,  -1.56250000e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.16064453e-02,  -2.16369629e-02],
                        [ -1.06201172e-02,  -1.06506348e-02],
                        [  1.00708008e-03,   1.03759766e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  7.08007812e-03,   7.04956055e-03],
                        [ -1.67846680e-03,  -1.64794922e-03],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -3.58581543e-02,  -3.58886719e-02],
                        [ -5.00488281e-02,  -5.00183105e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -3.41796875e-02,  -3.42102051e-02],
                        [ -4.69970703e-03,  -4.66918945e-03],
                        [  3.10974121e-02,   3.11279297e-02],
                        [  6.71081543e-02,   6.70776367e-02],
                        [  1.00372314e-01,   1.00341797e-01],
                        [  1.30310059e-01,   1.30371094e-01],
                        [  1.52557373e-01,   1.52557373e-01],
                        [  1.54693604e-01,   1.54663086e-01],
                        [  1.21704102e-01,   1.21734619e-01],
                        [  4.43420410e-02,   4.43725586e-02],
                        [ -7.51647949e-02,  -7.52258301e-02],
                        [ -2.15301514e-01,  -2.15301514e-01],
                        [ -3.33465576e-01,  -3.33404541e-01],
                        [ -3.88916016e-01,  -3.88946533e-01],
                        [ -3.72283936e-01,  -3.72314453e-01],
                        [ -3.08471680e-01,  -3.08410645e-01],
                        [ -2.33978271e-01,  -2.33978271e-01],
                        [ -1.72637939e-01,  -1.72698975e-01],
                        [ -1.24542236e-01,  -1.24481201e-01],
                        [ -7.51647949e-02,  -7.51037598e-02],
                        [ -1.68762207e-02,  -1.69372559e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  7.68127441e-02,   7.68737793e-02],
                        [  8.51135254e-02,   8.50830078e-02],
                        [  7.46765137e-02,   7.46154785e-02],
                        [  6.63452148e-02,   6.64062500e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  9.23767090e-02,   9.23156738e-02],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  1.14532471e-01,   1.14562988e-01],
                        [  1.14532471e-01,   1.14501953e-01],
                        [  1.12274170e-01,   1.12243652e-01],
                        [  1.05804443e-01,   1.05865479e-01],
                        [  8.99963379e-02,   8.99658203e-02],
                        [  6.44836426e-02,   6.44531250e-02],
                        [  3.72619629e-02,   3.73229980e-02],
                        [  1.85241699e-02,   1.85546875e-02],
                        [  1.31225586e-02,   1.30920410e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  3.29895020e-02,   3.30200195e-02],
                        [  4.68444824e-02,   4.68139648e-02],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  7.00073242e-02,   7.00378418e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  9.50927734e-02,   9.50622559e-02],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  8.55102539e-02,   8.55407715e-02],
                        [  7.05871582e-02,   7.05566406e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  2.97546387e-02,   2.97851562e-02],
                        [  5.31005859e-03,   5.31005859e-03],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -3.10974121e-02,  -3.10668945e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.37426758e-02,   2.37121582e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -9.70458984e-03,  -9.73510742e-03],
                        [  2.74658203e-04,   2.44140625e-04],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  3.33557129e-02,   3.33251953e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  5.39855957e-02,   5.40161133e-02],
                        [  5.91430664e-02,   5.91125488e-02],
                        [  5.85632324e-02,   5.85632324e-02],
                        [  5.09033203e-02,   5.09338379e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  1.38244629e-02,   1.37939453e-02],
                        [ -8.42285156e-03,  -8.39233398e-03],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -4.78210449e-02,  -4.78515625e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -6.89086914e-02,  -6.89392090e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [  4.57763672e-04,   4.88281250e-04],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  8.81958008e-03,   8.78906250e-03],
                        [  4.51660156e-03,   4.54711914e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -3.62243652e-02,  -3.62548828e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.65808105e-02,  -2.66113281e-02],
                        [ -3.56445312e-02,  -3.56140137e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -5.43212891e-02,  -5.43518066e-02],
                        [ -4.11987305e-02,  -4.11682129e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [  3.41186523e-02,   3.40881348e-02],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  1.24908447e-01,   1.24938965e-01],
                        [  1.60064697e-01,   1.60064697e-01],
                        [  1.77825928e-01,   1.77825928e-01],
                        [  1.68243408e-01,   1.68273926e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  2.92358398e-02,   2.92053223e-02],
                        [ -1.06445312e-01,  -1.06414795e-01],
                        [ -2.63000488e-01,  -2.62969971e-01],
                        [ -3.97827148e-01,  -3.97857666e-01],
                        [ -4.66156006e-01,  -4.66156006e-01],
                        [ -4.48944092e-01,  -4.48944092e-01],
                        [ -3.68377686e-01,  -3.68408203e-01],
                        [ -2.70416260e-01,  -2.70416260e-01],
                        [ -1.87469482e-01,  -1.87438965e-01],
                        [ -1.18316650e-01,  -1.18316650e-01],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [  4.22668457e-02,   4.22973633e-02],
                        [  1.20330811e-01,   1.20330811e-01],
                        [  1.64001465e-01,   1.63970947e-01],
                        [  1.65954590e-01,   1.65985107e-01],
                        [  1.42608643e-01,   1.42578125e-01],
                        [  1.16882324e-01,   1.16851807e-01],
                        [  1.01043701e-01,   1.01043701e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  7.78198242e-02,   7.77893066e-02],
                        [  5.84106445e-02,   5.84411621e-02],
                        [  4.16870117e-02,   4.17175293e-02],
                        [  3.41186523e-02,   3.40881348e-02],
                        [  3.11584473e-02,   3.11889648e-02],
                        [  2.39868164e-02,   2.40173340e-02],
                        [  1.23291016e-02,   1.22985840e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.15356445e-02,   1.15661621e-02],
                        [  2.87170410e-02,   2.86865234e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  6.91223145e-02,   6.91528320e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  8.77075195e-02,   8.76770020e-02],
                        [  9.53369141e-02,   9.53674316e-02],
                        [  1.04644775e-01,   1.04675293e-01],
                        [  1.08306885e-01,   1.08276367e-01],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  8.34655762e-02,   8.34960938e-02],
                        [  6.18896484e-02,   6.18591309e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [  1.76391602e-02,   1.76696777e-02],
                        [  1.09863281e-03,   1.09863281e-03],
                        [ -1.19018555e-02,  -1.19323730e-02],
                        [ -2.30712891e-02,  -2.30407715e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -2.91137695e-02,  -2.91442871e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.04064941e-02,  -1.04370117e-02],
                        [ -7.72094727e-03,  -7.75146484e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.80358887e-02,   1.80053711e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.92968750e-02,   2.93273926e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  3.92761230e-02,   3.92456055e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  4.00085449e-02,   4.00390625e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  1.69677734e-02,   1.69982910e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [ -6.89697266e-03,  -6.92749023e-03],
                        [ -1.67846680e-02,  -1.67541504e-02],
                        [ -2.19116211e-02,  -2.18811035e-02],
                        [ -2.47192383e-02,  -2.47802734e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.72009277e-02,  -3.71704102e-02],
                        [ -4.30603027e-02,  -4.30908203e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -3.95812988e-02,  -3.95507812e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -2.88085938e-02,  -2.88391113e-02],
                        [ -2.42614746e-02,  -2.42309570e-02],
                        [ -2.07214355e-02,  -2.06909180e-02],
                        [ -2.10266113e-02,  -2.10571289e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -3.08837891e-02,  -3.08532715e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -2.79846191e-02,  -2.80151367e-02],
                        [ -2.62451172e-02,  -2.62145996e-02],
                        [ -2.51159668e-02,  -2.50854492e-02],
                        [ -2.18200684e-02,  -2.18505859e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -8.05664062e-03,  -8.02612305e-03],
                        [  2.68554688e-03,   2.65502930e-03],
                        [  1.42822266e-02,   1.42517090e-02],
                        [  2.31933594e-02,   2.32238770e-02],
                        [  2.64587402e-02,   2.64892578e-02],
                        [  2.04772949e-02,   2.04467773e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -2.28881836e-02,  -2.28576660e-02],
                        [ -4.28771973e-02,  -4.29382324e-02],
                        [ -4.56848145e-02,  -4.57153320e-02],
                        [ -2.93884277e-02,  -2.93273926e-02],
                        [ -1.06811523e-03,  -1.09863281e-03],
                        [  3.16162109e-02,   3.15856934e-02],
                        [  6.56433105e-02,   6.56738281e-02],
                        [  9.89074707e-02,   9.89379883e-02],
                        [  1.25640869e-01,   1.25610352e-01],
                        [  1.35772705e-01,   1.35772705e-01],
                        [  1.14349365e-01,   1.14379883e-01],
                        [  4.45861816e-02,   4.45556641e-02],
                        [ -7.44934082e-02,  -7.45239258e-02],
                        [ -2.12585449e-01,  -2.12524414e-01],
                        [ -3.21380615e-01,  -3.21380615e-01],
                        [ -3.66271973e-01,  -3.66333008e-01],
                        [ -3.44421387e-01,  -3.44390869e-01],
                        [ -2.81585693e-01,  -2.81555176e-01],
                        [ -2.14996338e-01,  -2.15026855e-01],
                        [ -1.67755127e-01,  -1.67755127e-01],
                        [ -1.33026123e-01,  -1.32995605e-01],
                        [ -8.87756348e-02,  -8.88061523e-02],
                        [ -2.97241211e-02,  -2.97546387e-02],
                        [  2.36511230e-02,   2.36816406e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  4.93164062e-02,   4.92858887e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  6.67114258e-02,   6.67724609e-02],
                        [  1.01379395e-01,   1.01348877e-01],
                        [  1.32110596e-01,   1.32110596e-01],
                        [  1.44042969e-01,   1.44073486e-01],
                        [  1.39587402e-01,   1.39587402e-01],
                        [  1.31256104e-01,   1.31225586e-01],
                        [  1.24633789e-01,   1.24664307e-01],
                        [  1.12518311e-01,   1.12548828e-01],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  3.23486328e-02,   3.23791504e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  1.68457031e-02,   1.68151855e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  3.19519043e-02,   3.19213867e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  8.01391602e-02,   8.01696777e-02],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  7.38525391e-02,   7.38220215e-02],
                        [  5.84106445e-02,   5.84411621e-02],
                        [  4.05883789e-02,   4.06188965e-02],
                        [  2.65502930e-02,   2.65197754e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.27563477e-02,   1.27868652e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.77001953e-03,  -1.73950195e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.73950195e-03,  -1.77001953e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.26342773e-02,  -1.26647949e-02],
                        [ -3.44848633e-03,  -3.47900391e-03],
                        [  9.27734375e-03,   9.30786133e-03],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  2.23083496e-02,   2.22473145e-02],
                        [  2.86560059e-02,   2.86865234e-02],
                        [  3.84521484e-02,   3.84826660e-02],
                        [  4.76074219e-02,   4.75463867e-02],
                        [  5.30700684e-02,   5.31005859e-02],
                        [  5.51147461e-02,   5.51757812e-02],
                        [  5.15441895e-02,   5.14831543e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  1.15051270e-02,   1.15661621e-02],
                        [ -2.09655762e-02,  -2.09960938e-02],
                        [ -5.05981445e-02,  -5.06591797e-02],
                        [ -6.71386719e-02,  -6.70776367e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -6.37207031e-02,  -6.37817383e-02],
                        [ -6.31408691e-02,  -6.31103516e-02],
                        [ -6.78710938e-02,  -6.78100586e-02],
                        [ -7.46154785e-02,  -7.46765137e-02],
                        [ -8.00170898e-02,  -8.00476074e-02],
                        [ -7.83691406e-02,  -7.83386230e-02],
                        [ -6.47277832e-02,  -6.47583008e-02],
                        [ -4.23889160e-02,  -4.24194336e-02],
                        [ -2.09350586e-02,  -2.09045410e-02],
                        [ -7.81250000e-03,  -7.78198242e-03],
                        [ -3.63159180e-03,  -3.69262695e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  5.42602539e-02,   5.42602539e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  5.36804199e-02,   5.36499023e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [ -3.47900391e-03,  -3.50952148e-03],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  6.98242188e-02,   6.98242188e-02],
                        [  1.02294922e-01,   1.02294922e-01],
                        [  1.13983154e-01,   1.14013672e-01],
                        [  8.92944336e-02,   8.92639160e-02],
                        [  1.57470703e-02,   1.57165527e-02],
                        [ -1.01043701e-01,  -1.01013184e-01],
                        [ -2.29248047e-01,  -2.29248047e-01],
                        [ -3.24432373e-01,  -3.24462891e-01],
                        [ -3.56231689e-01,  -3.56231689e-01],
                        [ -3.26690674e-01,  -3.26660156e-01],
                        [ -2.65930176e-01,  -2.65960693e-01],
                        [ -2.06695557e-01,  -2.06695557e-01],
                        [ -1.59454346e-01,  -1.59423828e-01],
                        [ -1.12213135e-01,  -1.12213135e-01],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [  1.94091797e-02,   1.94396973e-02],
                        [  7.80639648e-02,   7.80334473e-02],
                        [  1.04248047e-01,   1.04217529e-01],
                        [  9.77172852e-02,   9.77478027e-02],
                        [  7.63854980e-02,   7.64160156e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  4.02526855e-02,   4.02526855e-02],
                        [  3.92456055e-02,   3.92456055e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  6.62536621e-02,   6.62536621e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  7.08312988e-02,   7.08007812e-02],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  1.03698730e-01,   1.03729248e-01],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.06140137e-01,   1.06170654e-01],
                        [  9.35974121e-02,   9.35668945e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  5.02319336e-02,   5.02624512e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [ -5.92041016e-03,  -5.95092773e-03],
                        [ -1.95007324e-02,  -1.94702148e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -1.10778809e-02,  -1.11083984e-02],
                        [ -5.52368164e-03,  -5.49316406e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [  8.85009766e-04,   8.54492188e-04],
                        [  6.59179688e-03,   6.62231445e-03],
                        [  1.19628906e-02,   1.19934082e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -9.94873047e-03,  -9.97924805e-03],
                        [ -8.51440430e-03,  -8.48388672e-03],
                        [  2.38037109e-03,   2.34985352e-03],
                        [  2.33459473e-02,   2.33154297e-02],
                        [  4.53186035e-02,   4.53491211e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  2.99377441e-02,   2.99682617e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  3.78417969e-03,   3.75366211e-03],
                        [ -4.18090820e-03,  -4.15039062e-03],
                        [ -9.70458984e-03,  -9.67407227e-03],
                        [ -1.20849609e-02,  -1.21154785e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -3.20434570e-03,  -3.17382812e-03],
                        [  7.14111328e-03,   7.11059570e-03],
                        [  1.51672363e-02,   1.51367188e-02],
                        [  1.75476074e-02,   1.75781250e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  8.39233398e-03,   8.36181641e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.90429688e-02,  -1.90124512e-02],
                        [ -3.73535156e-02,  -3.73840332e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -6.63757324e-02,  -6.63452148e-02],
                        [ -6.90917969e-02,  -6.90917969e-02],
                        [ -6.40563965e-02,  -6.40869141e-02],
                        [ -5.56335449e-02,  -5.56030273e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -4.13513184e-02,  -4.13818359e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -2.26440430e-02,  -2.26135254e-02],
                        [ -4.85229492e-03,  -4.88281250e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.72729492e-02,   1.73034668e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.07421875e-02,   1.07116699e-02],
                        [  1.35803223e-02,   1.36108398e-02],
                        [  2.16064453e-02,   2.16369629e-02],
                        [  2.57568359e-02,   2.57263184e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -4.32434082e-02,  -4.32739258e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [  1.71508789e-02,   1.71203613e-02],
                        [  6.45446777e-02,   6.45446777e-02],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  1.20117188e-01,   1.20086670e-01],
                        [  7.48291016e-02,   7.48291016e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.23809814e-01,  -1.23809814e-01],
                        [ -2.48962402e-01,  -2.48992920e-01],
                        [ -3.40698242e-01,  -3.40698242e-01],
                        [ -3.64715576e-01,  -3.64685059e-01],
                        [ -3.21868896e-01,  -3.21899414e-01],
                        [ -2.46093750e-01,  -2.46124268e-01],
                        [ -1.76574707e-01,  -1.76544189e-01],
                        [ -1.31011963e-01,  -1.31011963e-01],
                        [ -9.95788574e-02,  -9.96093750e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -1.29089355e-02,  -1.28784180e-02],
                        [  2.93273926e-02,   2.92968750e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  3.72314453e-02,   3.72619629e-02],
                        [  2.99682617e-02,   2.99377441e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  7.11059570e-02,   7.11364746e-02],
                        [  1.03424072e-01,   1.03393555e-01],
                        [  1.24389648e-01,   1.24359131e-01],
                        [  1.30187988e-01,   1.30218506e-01],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  1.13433838e-01,   1.13403320e-01],
                        [  9.65270996e-02,   9.65576172e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  5.21240234e-02,   5.20935059e-02],
                        [  3.46679688e-02,   3.46984863e-02],
                        [  2.74658203e-02,   2.74963379e-02],
                        [  3.04260254e-02,   3.03955078e-02],
                        [  4.00390625e-02,   4.00695801e-02],
                        [  5.19104004e-02,   5.19409180e-02],
                        [  6.16149902e-02,   6.15844727e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  7.29980469e-02,   7.30590820e-02],
                        [  7.97424316e-02,   7.97119141e-02],
                        [  8.52050781e-02,   8.51440430e-02],
                        [  8.56323242e-02,   8.56933594e-02],
                        [  7.87353516e-02,   7.87658691e-02],
                        [  6.35070801e-02,   6.34460449e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  2.41088867e-02,   2.41394043e-02],
                        [  1.13525391e-02,   1.13220215e-02],
                        [  3.14331055e-03,   3.11279297e-03],
                        [ -2.74658203e-03,  -2.71606445e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.10473633e-02,  -1.11083984e-02],
                        [ -1.43127441e-02,  -1.42822266e-02],
                        [ -1.37023926e-02,  -1.36718750e-02],
                        [ -8.08715820e-03,  -8.11767578e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  1.06811523e-02,   1.07421875e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.79028320e-02,   3.78417969e-02],
                        [  5.16357422e-02,   5.16662598e-02],
                        [  6.14929199e-02,   6.15234375e-02],
                        [  6.33544922e-02,   6.33239746e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [  4.17480469e-02,   4.18090820e-02],
                        [  2.88696289e-02,   2.88391113e-02],
                        [  1.87988281e-02,   1.87377930e-02],
                        [  1.13525391e-02,   1.14135742e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [ -5.79833984e-04,  -6.40869141e-04],
                        [ -9.61303711e-03,  -9.58251953e-03],
                        [ -1.81274414e-02,  -1.80969238e-02],
                        [ -2.32238770e-02,  -2.32849121e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.78320312e-02,  -2.78015137e-02],
                        [ -2.73437500e-02,  -2.73742676e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -2.08740234e-02,  -2.08129883e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -1.10473633e-02,  -1.10778809e-02],
                        [  7.62939453e-04,   7.93457031e-04],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.33666992e-02,   1.33361816e-02],
                        [  2.99072266e-03,   3.05175781e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -2.53906250e-02,  -2.54211426e-02],
                        [ -3.25012207e-02,  -3.24707031e-02],
                        [ -3.49731445e-02,  -3.49426270e-02],
                        [ -3.95812988e-02,  -3.96118164e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -6.31408691e-02,  -6.31103516e-02],
                        [ -6.75659180e-02,  -6.76269531e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.43518066e-02,  -5.42907715e-02],
                        [ -4.32128906e-02,  -4.32434082e-02],
                        [ -2.75573730e-02,  -2.75878906e-02],
                        [ -6.89697266e-03,  -6.83593750e-03],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  2.69165039e-02,   2.68859863e-02],
                        [  2.42004395e-02,   2.42309570e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [ -1.91650391e-02,  -1.91955566e-02],
                        [ -3.74450684e-02,  -3.74145508e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -3.03039551e-02,  -3.03344727e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [  8.94165039e-03,   8.97216797e-03],
                        [  3.17993164e-02,   3.17687988e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  7.63854980e-02,   7.64160156e-02],
                        [  9.76257324e-02,   9.75952148e-02],
                        [  1.14013672e-01,   1.13983154e-01],
                        [  1.22497559e-01,   1.22528076e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  1.14776611e-01,   1.14746094e-01],
                        [  9.13085938e-02,   9.13391113e-02],
                        [  4.23278809e-02,   4.23583984e-02],
                        [ -4.03747559e-02,  -4.04052734e-02],
                        [ -1.49658203e-01,  -1.49658203e-01],
                        [ -2.55859375e-01,  -2.55798340e-01],
                        [ -3.21655273e-01,  -3.21685791e-01],
                        [ -3.28460693e-01,  -3.28491211e-01],
                        [ -2.88665771e-01,  -2.88635254e-01],
                        [ -2.34466553e-01,  -2.34466553e-01],
                        [ -1.91345215e-01,  -1.91375732e-01],
                        [ -1.58630371e-01,  -1.58630371e-01],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -5.67932129e-02,  -5.68542480e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  5.62133789e-02,   5.62438965e-02],
                        [  7.48901367e-02,   7.48596191e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  7.97119141e-02,   7.97424316e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  1.06506348e-01,   1.06475830e-01],
                        [  1.14685059e-01,   1.14685059e-01],
                        [  1.12976074e-01,   1.13006592e-01],
                        [  1.02691650e-01,   1.02661133e-01],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  7.25097656e-02,   7.25402832e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  4.50744629e-02,   4.50439453e-02],
                        [  2.99377441e-02,   2.99682617e-02],
                        [  1.89819336e-02,   1.90124512e-02],
                        [  1.74255371e-02,   1.73645020e-02],
                        [  2.37731934e-02,   2.38037109e-02],
                        [  3.20434570e-02,   3.20739746e-02],
                        [  3.76892090e-02,   3.76586914e-02],
                        [  4.19921875e-02,   4.19616699e-02],
                        [  5.05981445e-02,   5.06286621e-02],
                        [  6.60705566e-02,   6.60400391e-02],
                        [  8.36791992e-02,   8.36486816e-02],
                        [  9.55200195e-02,   9.55505371e-02],
                        [  9.59167480e-02,   9.59167480e-02],
                        [  8.45947266e-02,   8.45642090e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  5.05371094e-02,   5.05676270e-02],
                        [  3.57666016e-02,   3.57360840e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [ -3.44848633e-03,  -3.41796875e-03],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -3.61938477e-02,  -3.62243652e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -3.17993164e-02,  -3.18298340e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.01110840e-02,  -2.00805664e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  3.25012207e-02,   3.25317383e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  2.27966309e-02,   2.27661133e-02],
                        [  6.80541992e-03,   6.80541992e-03],
                        [ -1.41296387e-02,  -1.40991211e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -5.39550781e-02,  -5.39245605e-02],
                        [ -4.82177734e-02,  -4.82482910e-02],
                        [ -3.30810547e-02,  -3.31115723e-02],
                        [ -1.84631348e-02,  -1.84326172e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -8.51440430e-03,  -8.57543945e-03],
                        [ -9.33837891e-03,  -9.30786133e-03],
                        [ -1.01013184e-02,  -1.00708008e-02],
                        [ -1.06506348e-02,  -1.07116699e-02],
                        [ -1.25732422e-02,  -1.26037598e-02],
                        [ -1.75476074e-02,  -1.74865723e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -4.53491211e-02,  -4.54101562e-02],
                        [ -6.43310547e-02,  -6.42700195e-02],
                        [ -7.52258301e-02,  -7.51953125e-02],
                        [ -7.36389160e-02,  -7.36999512e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -4.49523926e-02,  -4.48913574e-02],
                        [ -2.75878906e-02,  -2.76489258e-02],
                        [ -1.39160156e-02,  -1.39465332e-02],
                        [ -2.86865234e-03,  -2.77709961e-03],
                        [  7.29370117e-03,   7.26318359e-03],
                        [  1.36108398e-02,   1.35192871e-02],
                        [  1.48620605e-02,   1.49230957e-02],
                        [  1.60522461e-02,   1.61132812e-02],
                        [  2.00805664e-02,   1.99890137e-02],
                        [  2.38952637e-02,   2.39257812e-02],
                        [  2.53601074e-02,   2.54516602e-02],
                        [  2.38952637e-02,   2.38647461e-02],
                        [  1.69067383e-02,   1.68457031e-02],
                        [  3.60107422e-03,   3.69262695e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.96838379e-02,  -1.97753906e-02],
                        [ -1.52893066e-02,  -1.52587891e-02],
                        [  5.12695312e-03,   5.15747070e-03],
                        [  3.78112793e-02,   3.77502441e-02],
                        [  7.52868652e-02,   7.52868652e-02],
                        [  1.12762451e-01,   1.12823486e-01],
                        [  1.47949219e-01,   1.47888184e-01],
                        [  1.75262451e-01,   1.75262451e-01],
                        [  1.83105469e-01,   1.83166504e-01],
                        [  1.54846191e-01,   1.54785156e-01],
                        [  7.86132812e-02,   7.85827637e-02],
                        [ -3.75976562e-02,  -3.75061035e-02],
                        [ -1.65008545e-01,  -1.65008545e-01],
                        [ -2.69165039e-01,  -2.69226074e-01],
                        [ -3.24615479e-01,  -3.24584961e-01],
                        [ -3.25347900e-01,  -3.25317383e-01],
                        [ -2.88391113e-01,  -2.88452148e-01],
                        [ -2.40875244e-01,  -2.40844727e-01],
                        [ -1.98699951e-01,  -1.98669434e-01],
                        [ -1.59881592e-01,  -1.59942627e-01],
                        [ -1.15692139e-01,  -1.15692139e-01],
                        [ -6.39953613e-02,  -6.39343262e-02],
                        [ -1.30004883e-02,  -1.30310059e-02],
                        [  2.60314941e-02,   2.59704590e-02],
                        [  4.92248535e-02,   4.92858887e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  7.20214844e-02,   7.19604492e-02],
                        [  8.58154297e-02,   8.58459473e-02],
                        [  1.03729248e-01,   1.03759766e-01],
                        [  1.18621826e-01,   1.18560791e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  1.15142822e-01,   1.15203857e-01],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  8.37097168e-02,   8.36486816e-02],
                        [  6.16760254e-02,   6.17065430e-02],
                        [  3.78417969e-02,   3.78723145e-02],
                        [  1.68762207e-02,   1.68457031e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -5.09643555e-03,  -5.06591797e-03],
                        [ -4.51660156e-03,  -4.54711914e-03],
                        [  4.21142578e-03,   4.18090820e-03],
                        [  2.10266113e-02,   2.10571289e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  6.00585938e-02,   5.99975586e-02],
                        [  6.99157715e-02,   6.99462891e-02],
                        [  7.35168457e-02,   7.35778809e-02],
                        [  7.30895996e-02,   7.30590820e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  5.82580566e-02,   5.82885742e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.38232422e-02,   4.37927246e-02],
                        [  4.21447754e-02,   4.21752930e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  3.24707031e-02,   3.24401855e-02],
                        [  1.81884766e-02,   1.82189941e-02],
                        [  1.58691406e-03,   1.61743164e-03],
                        [ -1.26953125e-02,  -1.27258301e-02],
                        [ -2.47497559e-02,  -2.47802734e-02],
                        [ -3.62548828e-02,  -3.62243652e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -4.92248535e-02,  -4.92553711e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.01416016e-03,  -1.98364258e-03],
                        [  1.95617676e-02,   1.95312500e-02],
                        [  3.88793945e-02,   3.88488770e-02],
                        [  5.03540039e-02,   5.04150391e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  4.95910645e-02,   4.95605469e-02],
                        [  4.76074219e-02,   4.76379395e-02],
                        [  4.98962402e-02,   4.99267578e-02],
                        [  5.40161133e-02,   5.39855957e-02],
                        [  5.67932129e-02,   5.68237305e-02],
                        [  5.82580566e-02,   5.82885742e-02],
                        [  5.88073730e-02,   5.87768555e-02],
                        [  5.74645996e-02,   5.74340820e-02],
                        [  5.34362793e-02,   5.34667969e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  2.95715332e-02,   2.95410156e-02],
                        [  7.04956055e-03,   7.08007812e-03],
                        [ -1.91955566e-02,  -1.92260742e-02],
                        [ -4.69665527e-02,  -4.69970703e-02],
                        [ -7.43713379e-02,  -7.43103027e-02],
                        [ -9.64965820e-02,  -9.64660645e-02],
                        [ -1.06842041e-01,  -1.06903076e-01],
                        [ -1.02203369e-01,  -1.02203369e-01],
                        [ -8.55407715e-02,  -8.54797363e-02],
                        [ -6.50634766e-02,  -6.51245117e-02],
                        [ -4.80957031e-02,  -4.81262207e-02],
                        [ -3.50952148e-02,  -3.50341797e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.15661621e-02,  -1.16271973e-02],
                        [ -6.71386719e-04,  -6.40869141e-04],
                        [  9.97924805e-03,   1.00097656e-02],
                        [  1.85241699e-02,   1.84936523e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -4.50134277e-02,  -4.50439453e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.62341309e-02,  -4.62036133e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -2.64282227e-02,  -2.64587402e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -3.29589844e-03,  -3.26538086e-03],
                        [  1.23596191e-02,   1.23291016e-02],
                        [  2.88085938e-02,   2.87475586e-02],
                        [  4.33654785e-02,   4.33959961e-02],
                        [  5.36499023e-02,   5.36804199e-02],
                        [  5.78002930e-02,   5.77697754e-02],
                        [  5.65185547e-02,   5.65185547e-02],
                        [  5.34362793e-02,   5.34667969e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  4.78515625e-02,   4.78210449e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  4.48303223e-02,   4.48608398e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  6.90917969e-02,   6.90917969e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  1.14654541e-01,   1.14624023e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.01226807e-01,   1.01257324e-01],
                        [  4.76074219e-02,   4.76074219e-02],
                        [ -4.10156250e-02,  -4.10461426e-02],
                        [ -1.50207520e-01,  -1.50207520e-01],
                        [ -2.50549316e-01,  -2.50518799e-01],
                        [ -3.12957764e-01,  -3.12957764e-01],
                        [ -3.24645996e-01,  -3.24645996e-01],
                        [ -2.93701172e-01,  -2.93701172e-01],
                        [ -2.43835449e-01,  -2.43865967e-01],
                        [ -1.97937012e-01,  -1.97937012e-01],
                        [ -1.60888672e-01,  -1.60827637e-01],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -6.85424805e-02,  -6.85729980e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [  2.99682617e-02,   2.99987793e-02],
                        [  4.79736328e-02,   4.80041504e-02],
                        [  5.05065918e-02,   5.04760742e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  1.03240967e-01,   1.03210449e-01],
                        [  1.07208252e-01,   1.07177734e-01],
                        [  9.82055664e-02,   9.82360840e-02],
                        [  8.40148926e-02,   8.40454102e-02],
                        [  7.42797852e-02,   7.42187500e-02],
                        [  7.07092285e-02,   7.06787109e-02],
                        [  6.67724609e-02,   6.68029785e-02],
                        [  5.61218262e-02,   5.61523438e-02],
                        [  4.03442383e-02,   4.03137207e-02],
                        [  2.66113281e-02,   2.65808105e-02],
                        [  1.92565918e-02,   1.92871094e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  1.75476074e-02,   1.75781250e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  1.94091797e-02,   1.94396973e-02],
                        [  1.69982910e-02,   1.69677734e-02],
                        [  1.41906738e-02,   1.41601562e-02],
                        [  9.30786133e-03,   9.33837891e-03],
                        [  4.33349609e-03,   4.36401367e-03],
                        [  4.18090820e-03,   4.11987305e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  1.83715820e-02,   1.84326172e-02],
                        [  2.45666504e-02,   2.45361328e-02],
                        [  2.91442871e-02,   2.90832520e-02],
                        [  3.32641602e-02,   3.32946777e-02],
                        [  3.55529785e-02,   3.56140137e-02],
                        [  3.40270996e-02,   3.39965820e-02],
                        [  2.98767090e-02,   2.98461914e-02],
                        [  2.61840820e-02,   2.62145996e-02],
                        [  2.23693848e-02,   2.23999023e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.08642578e-02,   1.08337402e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  4.94384766e-03,   4.97436523e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -7.38525391e-03,  -7.41577148e-03],
                        [ -1.14135742e-02,  -1.13830566e-02],
                        [ -1.27258301e-02,  -1.26953125e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -8.20922852e-03,  -8.27026367e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  1.62963867e-02,   1.63269043e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  3.22265625e-02,   3.21960449e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -6.07299805e-03,  -6.04248047e-03],
                        [ -1.63269043e-02,  -1.63574219e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -2.09960938e-02,  -2.10266113e-02],
                        [ -1.97448730e-02,  -1.97753906e-02],
                        [ -1.87683105e-02,  -1.87377930e-02],
                        [ -2.14538574e-02,  -2.14233398e-02],
                        [ -3.03649902e-02,  -3.03955078e-02],
                        [ -4.35791016e-02,  -4.36401367e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -6.60400391e-02,  -6.59790039e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -6.29577637e-02,  -6.30187988e-02],
                        [ -4.59594727e-02,  -4.59289551e-02],
                        [ -2.13317871e-02,  -2.13012695e-02],
                        [  2.96020508e-03,   2.89916992e-03],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  2.32849121e-02,   2.33459473e-02],
                        [  1.73339844e-02,   1.73034668e-02],
                        [  6.13403320e-03,   6.10351562e-03],
                        [ -2.89916992e-03,  -2.83813477e-03],
                        [ -5.34057617e-03,  -5.31005859e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [ -2.34985352e-03,  -2.38037109e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.28271484e-02,  -2.27966309e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -2.19116211e-02,  -2.19726562e-02],
                        [ -1.70288086e-02,  -1.70593262e-02],
                        [ -1.12609863e-02,  -1.11999512e-02],
                        [ -4.60815430e-03,  -4.57763672e-03],
                        [  5.40161133e-03,   5.34057617e-03],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  3.49426270e-02,   3.49731445e-02],
                        [  4.61730957e-02,   4.62036133e-02],
                        [  5.37109375e-02,   5.36804199e-02],
                        [  6.30798340e-02,   6.30493164e-02],
                        [  7.88269043e-02,   7.88574219e-02],
                        [  1.01104736e-01,   1.01135254e-01],
                        [  1.25244141e-01,   1.25213623e-01],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  1.40869141e-01,   1.40899658e-01],
                        [  1.12426758e-01,   1.12365723e-01],
                        [  5.02929688e-02,   5.02624512e-02],
                        [ -4.50439453e-02,  -4.49829102e-02],
                        [ -1.60552979e-01,  -1.60522461e-01],
                        [ -2.68951416e-01,  -2.69012451e-01],
                        [ -3.38165283e-01,  -3.38165283e-01],
                        [ -3.51318359e-01,  -3.51287842e-01],
                        [ -3.17932129e-01,  -3.17962646e-01],
                        [ -2.63397217e-01,  -2.63427734e-01],
                        [ -2.10754395e-01,  -2.10723877e-01],
                        [ -1.68670654e-01,  -1.68670654e-01],
                        [ -1.29089355e-01,  -1.29119873e-01],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [  4.91027832e-02,   4.91333008e-02],
                        [  9.23156738e-02,   9.23461914e-02],
                        [  1.12121582e-01,   1.12091064e-01],
                        [  1.18438721e-01,   1.18408203e-01],
                        [  1.20971680e-01,   1.21002197e-01],
                        [  1.21795654e-01,   1.21826172e-01],
                        [  1.18316650e-01,   1.18255615e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  9.31701660e-02,   9.32312012e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  5.44433594e-02,   5.44128418e-02],
                        [  3.60412598e-02,   3.60717773e-02],
                        [  2.09045410e-02,   2.09350586e-02],
                        [  7.65991211e-03,   7.62939453e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -8.11767578e-03,  -8.08715820e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  4.73022461e-03,   4.69970703e-03],
                        [  1.74560547e-02,   1.74255371e-02],
                        [  3.21655273e-02,   3.21960449e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  5.67321777e-02,   5.67016602e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  6.80236816e-02,   6.79931641e-02],
                        [  6.91528320e-02,   6.91528320e-02],
                        [  6.39648438e-02,   6.39648438e-02],
                        [  5.25512695e-02,   5.25512695e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  1.99890137e-02,   1.99584961e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  6.16455078e-03,   6.19506836e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -2.08740234e-02,  -2.09045410e-02],
                        [ -2.64587402e-02,  -2.64892578e-02],
                        [ -2.01721191e-02,  -2.01416016e-02],
                        [ -5.82885742e-03,  -5.79833984e-03],
                        [  1.06811523e-02,   1.07116699e-02],
                        [  2.43530273e-02,   2.43225098e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.57263184e-02,   2.57873535e-02],
                        [  1.70593262e-02,   1.70898438e-02],
                        [  1.08947754e-02,   1.08642578e-02],
                        [  9.12475586e-03,   9.09423828e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  3.08227539e-03,   3.11279297e-03],
                        [  2.07519531e-03,   2.10571289e-03],
                        [  9.46044922e-03,   9.39941406e-03],
                        [  2.64892578e-02,   2.63977051e-02],
                        [  4.77294922e-02,   4.77905273e-02],
                        [  6.24694824e-02,   6.25915527e-02],
                        [  6.31103516e-02,   6.30798340e-02],
                        [  5.16357422e-02,   5.15441895e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  1.77917480e-02,   1.78833008e-02],
                        [ -9.46044922e-04,  -9.15527344e-04],
                        [ -2.02026367e-02,  -2.02941895e-02],
                        [ -3.63769531e-02,  -3.64379883e-02],
                        [ -4.76684570e-02,  -4.75769043e-02],
                        [ -5.49011230e-02,  -5.48400879e-02],
                        [ -5.88989258e-02,  -5.89599609e-02],
                        [ -5.96313477e-02,  -5.97229004e-02],
                        [ -5.68542480e-02,  -5.67932129e-02],
                        [ -5.02319336e-02,  -5.01098633e-02],
                        [ -3.88488770e-02,  -3.88793945e-02],
                        [ -2.16369629e-02,  -2.17285156e-02],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  1.58081055e-02,   1.59301758e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  1.80053711e-02,   1.79443359e-02],
                        [  9.67407227e-03,   9.64355469e-03],
                        [  3.05175781e-04,   3.35693359e-04],
                        [ -1.16271973e-02,  -1.15661621e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -4.08935547e-02,  -4.09240723e-02],
                        [ -5.23681641e-02,  -5.23986816e-02],
                        [ -5.82580566e-02,  -5.82275391e-02],
                        [ -5.71594238e-02,  -5.71289062e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -1.80969238e-02,  -1.81274414e-02],
                        [ -2.65502930e-03,  -2.68554688e-03],
                        [  1.03149414e-02,   1.03759766e-02],
                        [  2.02636719e-02,   2.02941895e-02],
                        [  2.60925293e-02,   2.60314941e-02],
                        [  2.65502930e-02,   2.65197754e-02],
                        [  2.23693848e-02,   2.24609375e-02],
                        [  1.68151855e-02,   1.68457031e-02],
                        [  1.25732422e-02,   1.25122070e-02],
                        [  1.01013184e-02,   1.00708008e-02],
                        [  9.00268555e-03,   9.03320312e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  3.54003906e-03,   3.50952148e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.21154785e-02,   1.21459961e-02],
                        [  2.84118652e-02,   2.84423828e-02],
                        [  5.52062988e-02,   5.51757812e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  1.24176025e-01,   1.24206543e-01],
                        [  1.48895264e-01,   1.48864746e-01],
                        [  1.58905029e-01,   1.58874512e-01],
                        [  1.47857666e-01,   1.47888184e-01],
                        [  1.04431152e-01,   1.04461670e-01],
                        [  2.17285156e-02,   2.16979980e-02],
                        [ -9.07897949e-02,  -9.08203125e-02],
                        [ -2.08587646e-01,  -2.08557129e-01],
                        [ -3.02032471e-01,  -3.02001953e-01],
                        [ -3.46771240e-01,  -3.46771240e-01],
                        [ -3.36944580e-01,  -3.36944580e-01],
                        [ -2.92144775e-01,  -2.92144775e-01],
                        [ -2.42614746e-01,  -2.42614746e-01],
                        [ -2.04467773e-01,  -2.04467773e-01],
                        [ -1.70776367e-01,  -1.70776367e-01],
                        [ -1.26220703e-01,  -1.26190186e-01],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [  1.70898438e-03,   1.64794922e-03],
                        [  6.01196289e-02,   6.00891113e-02],
                        [  9.53674316e-02,   9.54284668e-02],
                        [  1.05743408e-01,   1.05773926e-01],
                        [  1.02935791e-01,   1.02844238e-01],
                        [  9.98535156e-02,   9.98229980e-02],
                        [  1.01379395e-01,   1.01470947e-01],
                        [  1.03149414e-01,   1.03149414e-01],
                        [  9.79919434e-02,   9.79003906e-02],
                        [  8.51745605e-02,   8.52050781e-02],
                        [  7.01293945e-02,   7.01904297e-02],
                        [  5.74035645e-02,   5.73425293e-02],
                        [  4.78515625e-02,   4.78210449e-02],
                        [  3.81774902e-02,   3.82385254e-02],
                        [  2.38342285e-02,   2.38952637e-02],
                        [  6.46972656e-03,   6.40869141e-03],
                        [ -5.95092773e-03,  -6.01196289e-03],
                        [ -7.41577148e-03,  -7.38525391e-03],
                        [  9.15527344e-04,   9.46044922e-04],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  2.73132324e-02,   2.72827148e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.95910645e-02,   4.95605469e-02],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  5.13305664e-02,   5.13916016e-02],
                        [  4.44641113e-02,   4.44030762e-02],
                        [  3.34472656e-02,   3.33862305e-02],
                        [  2.07214355e-02,   2.07519531e-02],
                        [  8.91113281e-03,   9.00268555e-03],
                        [  2.19726562e-03,   2.16674805e-03],
                        [  3.41796875e-03,   3.32641602e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  1.67541504e-02,   1.68457031e-02],
                        [  1.76696777e-02,   1.77001953e-02],
                        [  1.27868652e-02,   1.26953125e-02],
                        [  3.47900391e-03,   3.44848633e-03],
                        [ -9.00268555e-03,  -8.94165039e-03],
                        [ -2.10266113e-02,  -2.09960938e-02],
                        [ -2.77404785e-02,  -2.78320312e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.18811035e-02,  -2.18200684e-02],
                        [ -1.49230957e-02,  -1.49536133e-02],
                        [ -6.04248047e-03,  -6.10351562e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  2.60314941e-02,   2.60620117e-02],
                        [  4.43725586e-02,   4.43420410e-02],
                        [  5.82580566e-02,   5.82275391e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  5.81359863e-02,   5.81665039e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  1.76696777e-02,   1.77001953e-02],
                        [  8.42285156e-03,   8.45336914e-03],
                        [  6.10351562e-04,   5.79833984e-04],
                        [ -3.72314453e-03,  -3.75366211e-03],
                        [ -3.87573242e-03,  -3.84521484e-03],
                        [ -2.04467773e-03,  -1.98364258e-03],
                        [ -1.67846680e-03,  -1.73950195e-03],
                        [ -4.97436523e-03,  -5.03540039e-03],
                        [ -1.25122070e-02,  -1.24511719e-02],
                        [ -2.42919922e-02,  -2.42309570e-02],
                        [ -3.70483398e-02,  -3.70788574e-02],
                        [ -4.62341309e-02,  -4.62951660e-02],
                        [ -5.09033203e-02,  -5.08728027e-02],
                        [ -5.16967773e-02,  -5.16662598e-02],
                        [ -4.84008789e-02,  -4.84313965e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -2.82592773e-02,  -2.82287598e-02],
                        [ -1.62658691e-02,  -1.62963867e-02],
                        [ -9.39941406e-03,  -9.46044922e-03],
                        [ -8.02612305e-03,  -7.99560547e-03],
                        [ -8.97216797e-03,  -8.88061523e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -3.87573242e-03,  -3.99780273e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -2.86865234e-03,  -2.77709961e-03],
                        [ -1.23291016e-02,  -1.23596191e-02],
                        [ -2.42614746e-02,  -2.43530273e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.49426270e-02,  -3.48815918e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.44848633e-02,  -3.45764160e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.00598145e-02,  -2.99682617e-02],
                        [ -2.32238770e-02,  -2.32543945e-02],
                        [ -1.23596191e-02,  -1.24206543e-02],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  1.20239258e-02,   1.21154785e-02],
                        [  1.99890137e-02,   1.99584961e-02],
                        [  2.57263184e-02,   2.56347656e-02],
                        [  2.99987793e-02,   2.99682617e-02],
                        [  3.13110352e-02,   3.13720703e-02],
                        [  2.67944336e-02,   2.68249512e-02],
                        [  1.64794922e-02,   1.64489746e-02],
                        [  5.85937500e-03,   5.82885742e-03],
                        [  2.13623047e-04,   2.74658203e-04],
                        [  2.04467773e-03,   2.10571289e-03],
                        [  1.22680664e-02,   1.22070312e-02],
                        [  2.86865234e-02,   2.86560059e-02],
                        [  4.81262207e-02,   4.81567383e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  8.99353027e-02,   8.98742676e-02],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.29516602e-01,   1.29608154e-01],
                        [  1.39373779e-01,   1.39404297e-01],
                        [  1.32812500e-01,   1.32720947e-01],
                        [  9.96398926e-02,   9.96093750e-02],
                        [  3.22265625e-02,   3.22875977e-02],
                        [ -6.65893555e-02,  -6.65588379e-02],
                        [ -1.78253174e-01,  -1.78283691e-01],
                        [ -2.72308350e-01,  -2.72369385e-01],
                        [ -3.23394775e-01,  -3.23364258e-01],
                        [ -3.26049805e-01,  -3.25958252e-01],
                        [ -2.94189453e-01,  -2.94219971e-01],
                        [ -2.49755859e-01,  -2.49847412e-01],
                        [ -2.09564209e-01,  -2.09503174e-01],
                        [ -1.76452637e-01,  -1.76391602e-01],
                        [ -1.39526367e-01,  -1.39587402e-01],
                        [ -8.67004395e-02,  -8.67614746e-02],
                        [ -2.21557617e-02,  -2.20947266e-02],
                        [  3.47900391e-02,   3.48510742e-02],
                        [  6.88171387e-02,   6.87561035e-02],
                        [  8.05664062e-02,   8.05053711e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  9.05456543e-02,   9.06066895e-02],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.24420166e-01,   1.24389648e-01],
                        [  1.33697510e-01,   1.33636475e-01],
                        [  1.28112793e-01,   1.28143311e-01],
                        [  1.11145020e-01,   1.11206055e-01],
                        [  8.96911621e-02,   8.96606445e-02],
                        [  6.80236816e-02,   6.79626465e-02],
                        [  4.67529297e-02,   4.67224121e-02],
                        [  2.50244141e-02,   2.50854492e-02],
                        [  5.40161133e-03,   5.43212891e-03],
                        [ -7.01904297e-03,  -7.04956055e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -3.02124023e-03,  -3.05175781e-03],
                        [  6.10351562e-03,   6.07299805e-03],
                        [  1.44042969e-02,   1.44653320e-02],
                        [  2.29492188e-02,   2.30102539e-02],
                        [  3.42102051e-02,   3.41491699e-02],
                        [  4.90112305e-02,   4.89501953e-02],
                        [  6.37817383e-02,   6.38427734e-02],
                        [  7.24792480e-02,   7.25402832e-02],
                        [  7.43103027e-02,   7.42492676e-02],
                        [  7.17163086e-02,   7.16552734e-02],
                        [  6.32019043e-02,   6.32934570e-02],
                        [  4.62951660e-02,   4.63562012e-02],
                        [  2.42614746e-02,   2.42004395e-02],
                        [  4.57763672e-03,   4.54711914e-03],
                        [ -8.66699219e-03,  -8.57543945e-03],
                        [ -1.67236328e-02,  -1.66931152e-02],
                        [ -2.14538574e-02,  -2.15148926e-02],
                        [ -2.28881836e-02,  -2.29187012e-02],
                        [ -2.15454102e-02,  -2.14843750e-02],
                        [ -1.81274414e-02,  -1.80664062e-02],
                        [ -1.21765137e-02,  -1.22375488e-02],
                        [ -3.99780273e-03,  -4.02832031e-03],
                        [  3.93676758e-03,   3.96728516e-03],
                        [  9.79614258e-03,   9.82666016e-03],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  2.43530273e-02,   2.43225098e-02],
                        [  3.65295410e-02,   3.65600586e-02],
                        [  4.84924316e-02,   4.84619141e-02],
                        [  5.64575195e-02,   5.64270020e-02],
                        [  5.90820312e-02,   5.91430664e-02],
                        [  5.61828613e-02,   5.62133789e-02],
                        [  4.91027832e-02,   4.90722656e-02],
                        [  4.08935547e-02,   4.08020020e-02],
                        [  3.18603516e-02,   3.19213867e-02],
                        [  2.07824707e-02,   2.08740234e-02],
                        [  9.55200195e-03,   9.52148438e-03],
                        [  1.37329102e-03,   1.34277344e-03],
                        [ -4.39453125e-03,  -4.36401367e-03],
                        [ -1.21459961e-02,  -1.21154785e-02],
                        [ -2.38342285e-02,  -2.38647461e-02],
                        [ -3.70178223e-02,  -3.70483398e-02],
                        [ -4.93164062e-02,  -4.92553711e-02],
                        [ -5.85327148e-02,  -5.84716797e-02],
                        [ -6.02416992e-02,  -6.03027344e-02],
                        [ -5.14526367e-02,  -5.14831543e-02],
                        [ -3.40576172e-02,  -3.39660645e-02],
                        [ -1.33666992e-02,  -1.33056641e-02],
                        [  5.21850586e-03,   5.12695312e-03],
                        [  1.69372559e-02,   1.68457031e-02],
                        [  1.84020996e-02,   1.84631348e-02],
                        [  1.12304688e-02,   1.12609863e-02],
                        [  2.25830078e-03,   2.22778320e-03],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [ -7.01904297e-03,  -6.98852539e-03],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -2.54821777e-02,  -2.55126953e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -4.22363281e-02,  -4.22058105e-02],
                        [ -4.26330566e-02,  -4.26635742e-02],
                        [ -3.73229980e-02,  -3.73840332e-02],
                        [ -2.92968750e-02,  -2.92663574e-02],
                        [ -2.40478516e-02,  -2.39562988e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.43530273e-02,  -2.44445801e-02],
                        [ -2.02941895e-02,  -2.03552246e-02],
                        [ -1.26342773e-02,  -1.25427246e-02],
                        [ -6.22558594e-03,  -6.16455078e-03],
                        [ -3.29589844e-03,  -3.38745117e-03],
                        [ -3.32641602e-03,  -3.38745117e-03],
                        [ -5.43212891e-03,  -5.37109375e-03],
                        [ -8.42285156e-03,  -8.36181641e-03],
                        [ -8.66699219e-03,  -8.69750977e-03],
                        [ -1.95312500e-03,  -1.98364258e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.97753906e-02,   1.98364258e-02],
                        [  2.52075195e-02,   2.51770020e-02],
                        [  2.62756348e-02,   2.62451172e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  2.21252441e-02,   2.21557617e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  3.02429199e-02,   3.02124023e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  6.41174316e-02,   6.41479492e-02],
                        [  8.37707520e-02,   8.38012695e-02],
                        [  1.03485107e-01,   1.03454590e-01],
                        [  1.22467041e-01,   1.22436523e-01],
                        [  1.34185791e-01,   1.34216309e-01],
                        [  1.26800537e-01,   1.26861572e-01],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  7.59887695e-03,   7.56835938e-03],
                        [ -1.03790283e-01,  -1.03820801e-01],
                        [ -2.19299316e-01,  -2.19299316e-01],
                        [ -3.04229736e-01,  -3.04168701e-01],
                        [ -3.37219238e-01,  -3.37188721e-01],
                        [ -3.21472168e-01,  -3.21533203e-01],
                        [ -2.78717041e-01,  -2.78778076e-01],
                        [ -2.34558105e-01,  -2.34497070e-01],
                        [ -2.01721191e-01,  -2.01629639e-01],
                        [ -1.72393799e-01,  -1.72424316e-01],
                        [ -1.30889893e-01,  -1.30981445e-01],
                        [ -7.19299316e-02,  -7.19299316e-02],
                        [ -4.85229492e-03,  -4.82177734e-03],
                        [  5.35583496e-02,   5.35888672e-02],
                        [  9.16442871e-02,   9.16748047e-02],
                        [  1.10839844e-01,   1.10809326e-01],
                        [  1.20330811e-01,   1.20300293e-01],
                        [  1.26098633e-01,   1.26129150e-01],
                        [  1.27746582e-01,   1.27777100e-01],
                        [  1.23168945e-01,   1.23138428e-01],
                        [  1.12091064e-01,   1.12030029e-01],
                        [  9.47570801e-02,   9.47875977e-02],
                        [  7.17468262e-02,   7.17773438e-02],
                        [  4.53491211e-02,   4.53186035e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [  6.80541992e-03,   6.77490234e-03],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  4.87365723e-02,   4.87976074e-02],
                        [  6.85119629e-02,   6.85119629e-02],
                        [  8.23364258e-02,   8.22448730e-02],
                        [  8.69140625e-02,   8.69140625e-02],
                        [  8.13293457e-02,   8.14208984e-02],
                        [  6.89697266e-02,   6.90002441e-02],
                        [  5.52368164e-02,   5.51757812e-02],
                        [  4.33959961e-02,   4.33654785e-02],
                        [  3.25317383e-02,   3.25927734e-02],
                        [  2.03552246e-02,   2.03857422e-02],
                        [  7.65991211e-03,   7.62939453e-03],
                        [ -3.32641602e-03,  -3.35693359e-03],
                        [ -1.34277344e-02,  -1.33972168e-02],
                        [ -2.31933594e-02,  -2.31628418e-02],
                        [ -2.89611816e-02,  -2.89916992e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -1.97143555e-02,  -1.96533203e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -3.05175781e-05,  -1.22070312e-04],
                        [  9.12475586e-03,   9.09423828e-03],
                        [  1.62963867e-02,   1.64184570e-02],
                        [  2.09045410e-02,   2.09350586e-02],
                        [  2.64892578e-02,   2.63671875e-02],
                        [  3.44848633e-02,   3.44238281e-02],
                        [  3.84521484e-02,   3.85437012e-02],
                        [  3.37829590e-02,   3.38745117e-02],
                        [  2.54211426e-02,   2.53601074e-02],
                        [  2.15759277e-02,   2.15148926e-02],
                        [  2.51464844e-02,   2.51770020e-02],
                        [  3.02734375e-02,   3.03649902e-02],
                        [  2.89001465e-02,   2.89306641e-02],
                        [  2.03247070e-02,   2.02636719e-02],
                        [  9.73510742e-03,   9.67407227e-03],
                        [  1.37329102e-03,   1.40380859e-03],
                        [ -3.50952148e-03,  -3.47900391e-03],
                        [ -5.09643555e-03,  -5.12695312e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [  9.27734375e-03,   9.24682617e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  5.18798828e-03,   5.18798828e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -1.36718750e-02,  -1.36413574e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.31018066e-02,  -2.31323242e-02],
                        [ -2.49023438e-02,  -2.48718262e-02],
                        [ -2.87780762e-02,  -2.87170410e-02],
                        [ -3.38745117e-02,  -3.39050293e-02],
                        [ -3.65905762e-02,  -3.66821289e-02],
                        [ -3.61022949e-02,  -3.60717773e-02],
                        [ -3.60717773e-02,  -3.59802246e-02],
                        [ -3.83605957e-02,  -3.83911133e-02],
                        [ -3.85131836e-02,  -3.85742188e-02],
                        [ -3.28674316e-02,  -3.28369141e-02],
                        [ -2.38342285e-02,  -2.38037109e-02],
                        [ -1.56555176e-02,  -1.56860352e-02],
                        [ -1.04675293e-02,  -1.05285645e-02],
                        [ -9.03320312e-03,  -8.97216797e-03],
                        [ -1.09252930e-02,  -1.08642578e-02],
                        [ -1.35192871e-02,  -1.35498047e-02],
                        [ -1.29394531e-02,  -1.30004883e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -6.68334961e-03,  -6.62231445e-03],
                        [ -9.61303711e-03,  -9.58251953e-03],
                        [ -1.59301758e-02,  -1.60217285e-02],
                        [ -2.24914551e-02,  -2.25524902e-02],
                        [ -2.76794434e-02,  -2.76184082e-02],
                        [ -2.86254883e-02,  -2.85644531e-02],
                        [ -1.99890137e-02,  -2.00195312e-02],
                        [  1.83105469e-04,   6.10351562e-05],
                        [  2.49938965e-02,   2.50244141e-02],
                        [  4.27856445e-02,   4.28771973e-02],
                        [  4.66308594e-02,   4.66613770e-02],
                        [  3.93676758e-02,   3.92761230e-02],
                        [  2.85339355e-02,   2.85034180e-02],
                        [  1.88598633e-02,   1.88903809e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.07421875e-02,   1.07116699e-02],
                        [  1.65100098e-02,   1.65405273e-02],
                        [  2.80761719e-02,   2.81066895e-02],
                        [  4.55932617e-02,   4.55322266e-02],
                        [  7.01293945e-02,   7.00988770e-02],
                        [  9.73205566e-02,   9.73815918e-02],
                        [  1.19415283e-01,   1.19445801e-01],
                        [  1.32720947e-01,   1.32659912e-01],
                        [  1.34948730e-01,   1.34918213e-01],
                        [  1.18011475e-01,   1.18041992e-01],
                        [  6.97937012e-02,   6.98242188e-02],
                        [ -1.62658691e-02,  -1.62353516e-02],
                        [ -1.30523682e-01,  -1.30584717e-01],
                        [ -2.43865967e-01,  -2.43896484e-01],
                        [ -3.21014404e-01,  -3.20983887e-01],
                        [ -3.43933105e-01,  -3.43872070e-01],
                        [ -3.21594238e-01,  -3.21624756e-01],
                        [ -2.79724121e-01,  -2.79785156e-01],
                        [ -2.41882324e-01,  -2.41851807e-01],
                        [ -2.13745117e-01,  -2.13653564e-01],
                        [ -1.81488037e-01,  -1.81518555e-01],
                        [ -1.27899170e-01,  -1.27990723e-01],
                        [ -5.24291992e-02,  -5.23986816e-02],
                        [  2.49328613e-02,   2.50549316e-02],
                        [  8.24279785e-02,   8.23974609e-02],
                        [  1.14868164e-01,   1.14746094e-01],
                        [  1.30371094e-01,   1.30371094e-01],
                        [  1.37054443e-01,   1.37207031e-01],
                        [  1.38092041e-01,   1.38122559e-01],
                        [  1.33483887e-01,   1.33361816e-01],
                        [  1.22467041e-01,   1.22406006e-01],
                        [  1.04980469e-01,   1.05072021e-01],
                        [  8.35876465e-02,   8.36486816e-02],
                        [  6.32934570e-02,   6.32324219e-02],
                        [  4.70886230e-02,   4.70275879e-02],
                        [  3.22875977e-02,   3.23181152e-02],
                        [  1.60217285e-02,   1.60522461e-02],
                        [  2.62451172e-03,   2.62451172e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.73339844e-02,   1.73034668e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.90527344e-02,   2.90832520e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  3.70788574e-02,   3.70178223e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  5.27343750e-02,   5.27648926e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  5.30090332e-02,   5.29785156e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  4.03442383e-02,   4.03442383e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  1.01928711e-02,   1.02233887e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -3.23486328e-03,  -3.29589844e-03],
                        [  1.01623535e-02,   1.01928711e-02],
                        [  2.51770020e-02,   2.52685547e-02],
                        [  3.52172852e-02,   3.51867676e-02],
                        [  3.89709473e-02,   3.88488770e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  4.01306152e-02,   4.02526855e-02],
                        [  3.75366211e-02,   3.75671387e-02],
                        [  3.37219238e-02,   3.35998535e-02],
                        [  2.91748047e-02,   2.91442871e-02],
                        [  2.29187012e-02,   2.30102539e-02],
                        [  1.50756836e-02,   1.51062012e-02],
                        [  8.51440430e-03,   8.48388672e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  4.24194336e-03,   4.21142578e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  2.56347656e-03,   2.59399414e-03],
                        [  3.75366211e-03,   3.72314453e-03],
                        [  7.93457031e-03,   7.87353516e-03],
                        [  1.00708008e-02,   1.01013184e-02],
                        [  5.67626953e-03,   5.76782227e-03],
                        [ -5.21850586e-03,  -5.24902344e-03],
                        [ -1.95922852e-02,  -1.96533203e-02],
                        [ -3.30505371e-02,  -3.30200195e-02],
                        [ -4.65087891e-02,  -4.64172363e-02],
                        [ -6.12487793e-02,  -6.12182617e-02],
                        [ -7.05261230e-02,  -7.06176758e-02],
                        [ -6.76879883e-02,  -6.77185059e-02],
                        [ -5.43212891e-02,  -5.41992188e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -2.10876465e-02,  -2.11791992e-02],
                        [ -7.62939453e-03,  -7.65991211e-03],
                        [  1.49536133e-03,   1.58691406e-03],
                        [  5.82885742e-03,   5.88989258e-03],
                        [  1.02539062e-02,   1.01623535e-02],
                        [  1.64184570e-02,   1.63574219e-02],
                        [  1.85852051e-02,   1.86462402e-02],
                        [  1.19934082e-02,   1.20239258e-02],
                        [ -4.88281250e-04,  -5.49316406e-04],
                        [ -1.04064941e-02,  -1.04370117e-02],
                        [ -1.27563477e-02,  -1.27258301e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.80053711e-03,  -1.83105469e-03],
                        [  2.92968750e-03,   2.99072266e-03],
                        [  1.15966797e-03,   1.22070312e-03],
                        [ -4.02832031e-03,  -4.11987305e-03],
                        [ -5.70678711e-03,  -5.76782227e-03],
                        [ -1.12915039e-03,  -1.03759766e-03],
                        [  5.64575195e-03,   5.70678711e-03],
                        [  1.06506348e-02,   1.05590820e-02],
                        [  1.57775879e-02,   1.57165527e-02],
                        [  2.31323242e-02,   2.31933594e-02],
                        [  3.16162109e-02,   3.16467285e-02],
                        [  4.10156250e-02,   4.09851074e-02],
                        [  5.13305664e-02,   5.13610840e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  7.65991211e-02,   7.65380859e-02],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  1.23809814e-01,   1.23931885e-01],
                        [  1.44531250e-01,   1.44531250e-01],
                        [  1.48620605e-01,   1.48498535e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  5.33142090e-02,   5.34362793e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -1.81823730e-01,  -1.81915283e-01],
                        [ -2.81494141e-01,  -2.81463623e-01],
                        [ -3.30291748e-01,  -3.30200195e-01],
                        [ -3.25439453e-01,  -3.25439453e-01],
                        [ -2.87109375e-01,  -2.87139893e-01],
                        [ -2.44323730e-01,  -2.44293213e-01],
                        [ -2.13043213e-01,  -2.13012695e-01],
                        [ -1.86737061e-01,  -1.86767578e-01],
                        [ -1.49414062e-01,  -1.49414062e-01],
                        [ -9.35363770e-02,  -9.35058594e-02],
                        [ -2.66113281e-02,  -2.66418457e-02],
                        [  3.34167480e-02,   3.33862305e-02],
                        [  7.10754395e-02,   7.11364746e-02],
                        [  8.52050781e-02,   8.52355957e-02],
                        [  8.77075195e-02,   8.76159668e-02],
                        [  9.15527344e-02,   9.14916992e-02],
                        [  9.97314453e-02,   9.98229980e-02],
                        [  1.05773926e-01,   1.05895996e-01],
                        [  1.05010986e-01,   1.04949951e-01],
                        [  9.99450684e-02,   9.98229980e-02],
                        [  9.43298340e-02,   9.43603516e-02],
                        [  8.70666504e-02,   8.72192383e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  5.98754883e-02,   5.97534180e-02],
                        [  4.49523926e-02,   4.48913574e-02],
                        [  3.19519043e-02,   3.20434570e-02],
                        [  2.10266113e-02,   2.10571289e-02],
                        [  1.46484375e-02,   1.45874023e-02],
                        [  1.56860352e-02,   1.56555176e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.81164551e-02,   3.81469727e-02],
                        [  3.81469727e-02,   3.81164551e-02],
                        [  3.93371582e-02,   3.92761230e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.01306152e-02,   4.01916504e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  9.06372070e-03,   9.03320312e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -3.90625000e-03,  -3.87573242e-03],
                        [  4.94384766e-03,   4.97436523e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.15966797e-02,  -1.16577148e-02],
                        [ -2.37426758e-02,  -2.37731934e-02],
                        [ -2.25830078e-02,  -2.24914551e-02],
                        [ -1.04064941e-02,  -1.03454590e-02],
                        [  1.61743164e-03,   1.52587891e-03],
                        [  5.64575195e-03,   5.61523438e-03],
                        [  1.80053711e-03,   1.89208984e-03],
                        [ -2.96020508e-03,  -2.89916992e-03],
                        [  1.03759766e-03,   9.46044922e-04],
                        [  1.54113770e-02,   1.53503418e-02],
                        [  2.94494629e-02,   2.95715332e-02],
                        [  3.31115723e-02,   3.31420898e-02],
                        [  2.85949707e-02,   2.85034180e-02],
                        [  2.52990723e-02,   2.52380371e-02],
                        [  2.77709961e-02,   2.78625488e-02],
                        [  3.26843262e-02,   3.27453613e-02],
                        [  3.52478027e-02,   3.51867676e-02],
                        [  3.44848633e-02,   3.44238281e-02],
                        [  3.23486328e-02,   3.23791504e-02],
                        [  3.10974121e-02,   3.11279297e-02],
                        [  3.06701660e-02,   3.07006836e-02],
                        [  2.83813477e-02,   2.83508301e-02],
                        [  2.09655762e-02,   2.09350586e-02],
                        [  7.87353516e-03,   7.90405273e-03],
                        [ -6.28662109e-03,  -6.25610352e-03],
                        [ -1.52587891e-02,  -1.52893066e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.51672363e-02,  -1.51977539e-02],
                        [ -2.01416016e-02,  -2.01721191e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.87475586e-02,  -2.86865234e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -3.14025879e-02,  -3.14941406e-02],
                        [ -2.54211426e-02,  -2.54516602e-02],
                        [ -1.61743164e-02,  -1.60827637e-02],
                        [ -1.00402832e-02,  -1.00097656e-02],
                        [ -1.17797852e-02,  -1.18408203e-02],
                        [ -1.90734863e-02,  -1.91650391e-02],
                        [ -2.75573730e-02,  -2.75268555e-02],
                        [ -3.46984863e-02,  -3.46069336e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -3.76586914e-02,  -3.77197266e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.51770020e-02,  -2.51464844e-02],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -1.60217285e-02,  -1.60827637e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -5.67626953e-03,  -5.61523438e-03],
                        [ -1.40380859e-03,  -1.43432617e-03],
                        [  2.25830078e-03,   2.19726562e-03],
                        [  4.05883789e-03,   4.08935547e-03],
                        [  2.34985352e-03,   2.41088867e-03],
                        [ -3.20434570e-03,  -3.26538086e-03],
                        [ -9.36889648e-03,  -9.39941406e-03],
                        [ -1.24816895e-02,  -1.24511719e-02],
                        [ -1.22985840e-02,  -1.22375488e-02],
                        [ -7.87353516e-03,  -7.90405273e-03],
                        [  1.55639648e-03,   1.49536133e-03],
                        [  1.23596191e-02,   1.23901367e-02],
                        [  1.95922852e-02,   1.96228027e-02],
                        [  2.19116211e-02,   2.18811035e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.31323242e-02,   2.31933594e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.91442871e-02,   2.90832520e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  5.33447266e-02,   5.34057617e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  1.05255127e-01,   1.05194092e-01],
                        [  1.34246826e-01,   1.34246826e-01],
                        [  1.51245117e-01,   1.51245117e-01],
                        [  1.43218994e-01,   1.43188477e-01],
                        [  1.00036621e-01,   1.00006104e-01],
                        [  1.72424316e-02,   1.72729492e-02],
                        [ -9.79003906e-02,  -9.79003906e-02],
                        [ -2.20550537e-01,  -2.20611572e-01],
                        [ -3.16345215e-01,  -3.16375732e-01],
                        [ -3.59863281e-01,  -3.59771729e-01],
                        [ -3.47290039e-01,  -3.47259521e-01],
                        [ -2.95745850e-01,  -2.95837402e-01],
                        [ -2.31658936e-01,  -2.31750488e-01],
                        [ -1.77276611e-01,  -1.77185059e-01],
                        [ -1.38854980e-01,  -1.38732910e-01],
                        [ -1.03424072e-01,  -1.03515625e-01],
                        [ -5.47790527e-02,  -5.48706055e-02],
                        [  4.69970703e-03,   4.79125977e-03],
                        [  5.55114746e-02,   5.56030273e-02],
                        [  8.31909180e-02,   8.30993652e-02],
                        [  9.06982422e-02,   9.06372070e-02],
                        [  8.93554688e-02,   8.94470215e-02],
                        [  8.76770020e-02,   8.77075195e-02],
                        [  8.98132324e-02,   8.97216797e-02],
                        [  9.35974121e-02,   9.35668945e-02],
                        [  9.11254883e-02,   9.12475586e-02],
                        [  7.96813965e-02,   7.97119141e-02],
                        [  6.59179688e-02,   6.58264160e-02],
                        [  5.63049316e-02,   5.62744141e-02],
                        [  5.00793457e-02,   5.01403809e-02],
                        [  4.24804688e-02,   4.25109863e-02],
                        [  3.10974121e-02,   3.10668945e-02],
                        [  1.95312500e-02,   1.95007324e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  5.70068359e-02,   5.70373535e-02],
                        [  7.46154785e-02,   7.45849609e-02],
                        [  8.83483887e-02,   8.82873535e-02],
                        [  9.66796875e-02,   9.67102051e-02],
                        [  9.61608887e-02,   9.61914062e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  6.33850098e-02,   6.33544922e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  3.17382812e-03,   3.20434570e-03],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -5.17272949e-02,  -5.17578125e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -6.50024414e-02,  -6.49719238e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.48095703e-02,  -5.48400879e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.79736328e-02,  -4.79431152e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -2.12097168e-02,  -2.12707520e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  3.22265625e-02,   3.22875977e-02],
                        [  4.89196777e-02,   4.89501953e-02],
                        [  5.65795898e-02,   5.65490723e-02],
                        [  6.04858398e-02,   6.04553223e-02],
                        [  6.31713867e-02,   6.32019043e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  6.50329590e-02,   6.50024414e-02],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  6.39648438e-02,   6.39953613e-02],
                        [  5.72509766e-02,   5.72204590e-02],
                        [  4.86755371e-02,   4.86145020e-02],
                        [  3.91235352e-02,   3.91540527e-02],
                        [  2.53601074e-02,   2.54516602e-02],
                        [  6.89697266e-03,   6.86645508e-03],
                        [ -1.03454590e-02,  -1.04675293e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -2.51770020e-02,  -2.50549316e-02],
                        [ -2.88696289e-02,  -2.88085938e-02],
                        [ -3.20434570e-02,  -3.21350098e-02],
                        [ -3.03649902e-02,  -3.03955078e-02],
                        [ -2.18200684e-02,  -2.17895508e-02],
                        [ -9.24682617e-03,  -9.21630859e-03],
                        [  3.57055664e-03,   3.54003906e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.72424316e-02,   1.72729492e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  9.73510742e-03,   9.70458984e-03],
                        [  1.06811523e-03,   1.09863281e-03],
                        [ -1.15661621e-02,  -1.15051270e-02],
                        [ -2.74353027e-02,  -2.74658203e-02],
                        [ -4.11987305e-02,  -4.12902832e-02],
                        [ -4.79736328e-02,  -4.80041504e-02],
                        [ -4.91027832e-02,  -4.90112305e-02],
                        [ -4.87670898e-02,  -4.87365723e-02],
                        [ -4.79431152e-02,  -4.80041504e-02],
                        [ -4.43725586e-02,  -4.44030762e-02],
                        [ -3.81469727e-02,  -3.81164551e-02],
                        [ -3.22265625e-02,  -3.21655273e-02],
                        [ -2.59704590e-02,  -2.60009766e-02],
                        [ -1.70288086e-02,  -1.70593262e-02],
                        [ -7.41577148e-03,  -7.38525391e-03],
                        [ -1.19018555e-03,  -1.15966797e-03],
                        [  1.22070312e-04,   9.15527344e-05],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -6.62231445e-03,  -6.59179688e-03],
                        [ -1.01318359e-02,  -1.01013184e-02],
                        [ -1.29699707e-02,  -1.30004883e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -5.06591797e-03,  -5.03540039e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.71508789e-02,   1.71203613e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.82189941e-02,   1.82495117e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.07519531e-02,   2.06909180e-02],
                        [  2.76794434e-02,   2.76489258e-02],
                        [  3.63464355e-02,   3.64074707e-02],
                        [  4.32128906e-02,   4.32434082e-02],
                        [  4.90722656e-02,   4.89807129e-02],
                        [  5.74951172e-02,   5.74035645e-02],
                        [  6.82678223e-02,   6.83288574e-02],
                        [  7.80334473e-02,   7.81250000e-02],
                        [  8.68225098e-02,   8.67919922e-02],
                        [  9.63439941e-02,   9.62524414e-02],
                        [  1.00128174e-01,   1.00158691e-01],
                        [  8.10852051e-02,   8.11462402e-02],
                        [  2.29492188e-02,   2.29187012e-02],
                        [ -7.42797852e-02,  -7.43408203e-02],
                        [ -1.89880371e-01,  -1.89849854e-01],
                        [ -2.88665771e-01,  -2.88604736e-01],
                        [ -3.36700439e-01,  -3.36761475e-01],
                        [ -3.24310303e-01,  -3.24371338e-01],
                        [ -2.74597168e-01,  -2.74536133e-01],
                        [ -2.23510742e-01,  -2.23419189e-01],
                        [ -1.90551758e-01,  -1.90612793e-01],
                        [ -1.68090820e-01,  -1.68182373e-01],
                        [ -1.37054443e-01,  -1.37023926e-01],
                        [ -8.77380371e-02,  -8.76159668e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [  3.14025879e-02,   3.13110352e-02],
                        [  7.01599121e-02,   7.01599121e-02],
                        [  8.85009766e-02,   8.85925293e-02],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  1.05926514e-01,   1.05865479e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.32232666e-01,   1.32263184e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.20056152e-01,   1.20025635e-01],
                        [  9.93652344e-02,   9.94262695e-02],
                        [  7.41577148e-02,   7.41882324e-02],
                        [  4.92553711e-02,   4.92248535e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  1.80053711e-02,   1.80358887e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.38244629e-02,   1.37939453e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  3.96423340e-02,   3.96118164e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  5.62133789e-02,   5.62744141e-02],
                        [  6.10656738e-02,   6.10351562e-02],
                        [  6.37817383e-02,   6.37512207e-02],
                        [  6.21032715e-02,   6.21337891e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  3.20434570e-02,   3.20129395e-02],
                        [  1.08947754e-02,   1.09252930e-02],
                        [ -5.98144531e-03,  -5.95092773e-03],
                        [ -1.60522461e-02,  -1.60827637e-02],
                        [ -1.87377930e-02,  -1.87683105e-02],
                        [ -1.67846680e-02,  -1.67541504e-02],
                        [ -1.49230957e-02,  -1.48620605e-02],
                        [ -1.73034668e-02,  -1.73339844e-02],
                        [ -2.50854492e-02,  -2.51464844e-02],
                        [ -3.31726074e-02,  -3.31420898e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -2.84118652e-02,  -2.83813477e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  4.69970703e-03,   4.63867188e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.47399902e-02,   1.48315430e-02],
                        [  2.15759277e-02,   2.16064453e-02],
                        [  3.38745117e-02,   3.37524414e-02],
                        [  4.75158691e-02,   4.74853516e-02],
                        [  5.40771484e-02,   5.41687012e-02],
                        [  4.98046875e-02,   4.98657227e-02],
                        [  4.01306152e-02,   4.01000977e-02],
                        [  3.29895020e-02,   3.28979492e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  3.35388184e-02,   3.35998535e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  4.05273438e-02,   4.04968262e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  3.20739746e-02,   3.21044922e-02],
                        [  2.40783691e-02,   2.41088867e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -5.00488281e-03,  -4.94384766e-03],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -2.26745605e-02,  -2.27661133e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -3.08532715e-02,  -3.07922363e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.61022949e-02,  -3.61328125e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -2.69470215e-02,  -2.69775391e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -1.37939453e-02,  -1.37329102e-02],
                        [ -1.38244629e-02,  -1.38549805e-02],
                        [ -1.55639648e-02,  -1.56555176e-02],
                        [ -1.75476074e-02,  -1.75170898e-02],
                        [ -2.07519531e-02,  -2.06298828e-02],
                        [ -2.33459473e-02,  -2.34069824e-02],
                        [ -2.20642090e-02,  -2.22167969e-02],
                        [ -1.93481445e-02,  -1.93176270e-02],
                        [ -1.96533203e-02,  -1.95312500e-02],
                        [ -2.11181641e-02,  -2.11486816e-02],
                        [ -1.92565918e-02,  -1.93176270e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.49536133e-02,  -1.49230957e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.81274414e-02,  -1.81579590e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -5.67626953e-03,  -5.70678711e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.01928711e-02,   1.02539062e-02],
                        [  9.88769531e-03,   9.85717773e-03],
                        [  5.92041016e-03,   5.85937500e-03],
                        [  4.15039062e-03,   4.18090820e-03],
                        [  7.78198242e-03,   7.84301758e-03],
                        [  1.47705078e-02,   1.47094727e-02],
                        [  2.10266113e-02,   2.09350586e-02],
                        [  2.29187012e-02,   2.29797363e-02],
                        [  1.85546875e-02,   1.86462402e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  7.62939453e-03,   7.56835938e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  2.82897949e-02,   2.83508301e-02],
                        [  4.81872559e-02,   4.82482910e-02],
                        [  6.93664551e-02,   6.93969727e-02],
                        [  9.28039551e-02,   9.27124023e-02],
                        [  1.18774414e-01,   1.18713379e-01],
                        [  1.37329102e-01,   1.37390137e-01],
                        [  1.32751465e-01,   1.32873535e-01],
                        [  9.65270996e-02,   9.64965820e-02],
                        [  2.86865234e-02,   2.85644531e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -1.73828125e-01,  -1.73706055e-01],
                        [ -2.69805908e-01,  -2.69744873e-01],
                        [ -3.25866699e-01,  -3.25988770e-01],
                        [ -3.30261230e-01,  -3.30322266e-01],
                        [ -2.97424316e-01,  -2.97332764e-01],
                        [ -2.54913330e-01,  -2.54852295e-01],
                        [ -2.20001221e-01,  -2.20031738e-01],
                        [ -1.88201904e-01,  -1.88232422e-01],
                        [ -1.42486572e-01,  -1.42486572e-01],
                        [ -7.46154785e-02,  -7.45849609e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  1.08734131e-01,   1.08703613e-01],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  9.82971191e-02,   9.83581543e-02],
                        [  9.56726074e-02,   9.57031250e-02],
                        [  9.46044922e-02,   9.45129395e-02],
                        [  9.06677246e-02,   9.06372070e-02],
                        [  8.00476074e-02,   8.01391602e-02],
                        [  6.37207031e-02,   6.37817383e-02],
                        [  4.81262207e-02,   4.80346680e-02],
                        [  3.93981934e-02,   3.92761230e-02],
                        [  3.58276367e-02,   3.59191895e-02],
                        [  3.18603516e-02,   3.20129395e-02],
                        [  2.71606445e-02,   2.71301270e-02],
                        [  2.73437500e-02,   2.71301270e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  4.75463867e-02,   4.77600098e-02],
                        [  5.72509766e-02,   5.73120117e-02],
                        [  6.63757324e-02,   6.61926270e-02],
                        [  7.66906738e-02,   7.65686035e-02],
                        [  8.20312500e-02,   8.22143555e-02],
                        [  7.45544434e-02,   7.46765137e-02],
                        [  5.40161133e-02,   5.39245605e-02],
                        [  2.75573730e-02,   2.74353027e-02],
                        [  2.53295898e-03,   2.56347656e-03],
                        [ -1.64184570e-02,  -1.63574219e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -3.03344727e-02,  -3.03649902e-02],
                        [ -3.14331055e-02,  -3.14636230e-02],
                        [ -3.22570801e-02,  -3.22265625e-02],
                        [ -3.01818848e-02,  -3.01208496e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -1.62963867e-02,  -1.63879395e-02],
                        [ -6.56127930e-03,  -6.59179688e-03],
                        [  2.10571289e-03,   2.16674805e-03],
                        [  8.88061523e-03,   8.91113281e-03],
                        [  1.55029297e-02,   1.54418945e-02],
                        [  2.38037109e-02,   2.37121582e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  4.04357910e-02,   4.05273438e-02],
                        [  4.33654785e-02,   4.33959961e-02],
                        [  4.47692871e-02,   4.46777344e-02],
                        [  4.78210449e-02,   4.77600098e-02],
                        [  5.03845215e-02,   5.04760742e-02],
                        [  4.75769043e-02,   4.76989746e-02],
                        [  4.07714844e-02,   4.07104492e-02],
                        [  3.70788574e-02,   3.69567871e-02],
                        [  3.64685059e-02,   3.65295410e-02],
                        [  3.14331055e-02,   3.15551758e-02],
                        [  2.06604004e-02,   2.06298828e-02],
                        [  1.03454590e-02,   1.02233887e-02],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  1.19018555e-03,   1.28173828e-03],
                        [  1.06811523e-03,   1.09863281e-03],
                        [  2.71606445e-03,   2.68554688e-03],
                        [  4.94384766e-03,   4.85229492e-03],
                        [  7.78198242e-03,   7.75146484e-03],
                        [  1.07421875e-02,   1.08337402e-02],
                        [  9.61303711e-03,   9.67407227e-03],
                        [  1.61743164e-03,   1.55639648e-03],
                        [ -1.01013184e-02,  -1.02233887e-02],
                        [ -2.14233398e-02,  -2.13928223e-02],
                        [ -2.98156738e-02,  -2.96630859e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.27758789e-02,  -3.28979492e-02],
                        [ -2.88391113e-02,  -2.88696289e-02],
                        [ -2.44750977e-02,  -2.44140625e-02],
                        [ -2.20336914e-02,  -2.19726562e-02],
                        [ -2.14538574e-02,  -2.14843750e-02],
                        [ -2.15759277e-02,  -2.16369629e-02],
                        [ -2.07824707e-02,  -2.07519531e-02],
                        [ -1.75170898e-02,  -1.74560547e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -3.57055664e-03,  -3.63159180e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  2.65502930e-03,   2.71606445e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -1.49841309e-02,  -1.50451660e-02],
                        [ -2.12097168e-02,  -2.11791992e-02],
                        [ -2.22778320e-02,  -2.22167969e-02],
                        [ -2.06298828e-02,  -2.06604004e-02],
                        [ -1.70898438e-02,  -1.71508789e-02],
                        [ -1.11694336e-02,  -1.11389160e-02],
                        [ -3.50952148e-03,  -3.44848633e-03],
                        [  4.88281250e-03,   4.85229492e-03],
                        [  1.20849609e-02,   1.20544434e-02],
                        [  1.49536133e-02,   1.50146484e-02],
                        [  1.33666992e-02,   1.33972168e-02],
                        [  1.12915039e-02,   1.12304688e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.26037598e-02,   1.26647949e-02],
                        [  1.09558105e-02,   1.10168457e-02],
                        [  9.06372070e-03,   8.97216797e-03],
                        [  9.64355469e-03,   9.58251953e-03],
                        [  1.12915039e-02,   1.13525391e-02],
                        [  1.31835938e-02,   1.32751465e-02],
                        [  1.84631348e-02,   1.84020996e-02],
                        [  3.03039551e-02,   3.02124023e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [  7.28454590e-02,   7.29675293e-02],
                        [  9.85412598e-02,   9.85717773e-02],
                        [  1.21673584e-01,   1.21551514e-01],
                        [  1.35620117e-01,   1.35559082e-01],
                        [  1.31805420e-01,   1.31896973e-01],
                        [  9.96704102e-02,   9.97619629e-02],
                        [  3.25622559e-02,   3.25012207e-02],
                        [ -6.48193359e-02,  -6.49108887e-02],
                        [ -1.76574707e-01,  -1.76513672e-01],
                        [ -2.77862549e-01,  -2.77770996e-01],
                        [ -3.39172363e-01,  -3.39202881e-01],
                        [ -3.41888428e-01,  -3.41949463e-01],
                        [ -2.96783447e-01,  -2.96752930e-01],
                        [ -2.40386963e-01,  -2.40325928e-01],
                        [ -2.02697754e-01,  -2.02758789e-01],
                        [ -1.81060791e-01,  -1.81121826e-01],
                        [ -1.52343750e-01,  -1.52313232e-01],
                        [ -1.02447510e-01,  -1.02416992e-01],
                        [ -3.58276367e-02,  -3.58581543e-02],
                        [  3.08837891e-02,   3.08532715e-02],
                        [  7.91015625e-02,   7.91320801e-02],
                        [  1.02478027e-01,   1.02447510e-01],
                        [  1.10839844e-01,   1.10809326e-01],
                        [  1.16546631e-01,   1.16607666e-01],
                        [  1.22497559e-01,   1.22528076e-01],
                        [  1.25366211e-01,   1.25305176e-01],
                        [  1.22558594e-01,   1.22497559e-01],
                        [  1.11968994e-01,   1.12060547e-01],
                        [  9.28344727e-02,   9.29260254e-02],
                        [  6.92749023e-02,   6.91833496e-02],
                        [  4.67224121e-02,   4.66308594e-02],
                        [  2.59704590e-02,   2.60620117e-02],
                        [  7.20214844e-03,   7.29370117e-03],
                        [ -3.87573242e-03,  -3.90625000e-03],
                        [ -9.15527344e-04,  -9.76562500e-04],
                        [  1.51977539e-02,   1.52282715e-02],
                        [  3.68957520e-02,   3.69567871e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  8.07189941e-02,   8.06884766e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  3.96423340e-02,   3.96728516e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -1.87988281e-02,  -1.88598633e-02],
                        [ -3.18603516e-02,  -3.18908691e-02],
                        [ -3.40270996e-02,  -3.39660645e-02],
                        [ -3.20434570e-02,  -3.20129395e-02],
                        [ -3.19519043e-02,  -3.20434570e-02],
                        [ -3.51867676e-02,  -3.52172852e-02],
                        [ -3.85437012e-02,  -3.84521484e-02],
                        [ -3.92456055e-02,  -3.91845703e-02],
                        [ -3.63159180e-02,  -3.64074707e-02],
                        [ -2.75268555e-02,  -2.75878906e-02],
                        [ -1.17797852e-02,  -1.17187500e-02],
                        [  5.82885742e-03,   5.92041016e-03],
                        [  1.90124512e-02,   1.89819336e-02],
                        [  2.75573730e-02,   2.74658203e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  3.71093750e-02,   3.72009277e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.72619629e-02,   3.71704102e-02],
                        [  4.36706543e-02,   4.36096191e-02],
                        [  4.96520996e-02,   4.97131348e-02],
                        [  4.94689941e-02,   4.95300293e-02],
                        [  4.52270508e-02,   4.51660156e-02],
                        [  4.19616699e-02,   4.19006348e-02],
                        [  4.06188965e-02,   4.06494141e-02],
                        [  3.87573242e-02,   3.88183594e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  2.96936035e-02,   2.96325684e-02],
                        [  2.19421387e-02,   2.19726562e-02],
                        [  1.28784180e-02,   1.29089355e-02],
                        [  5.88989258e-03,   5.85937500e-03],
                        [  4.82177734e-03,   4.79125977e-03],
                        [  9.30786133e-03,   9.33837891e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.04980469e-02,   1.04675293e-02],
                        [  1.49536133e-03,   1.46484375e-03],
                        [ -1.17492676e-02,  -1.17187500e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.54919434e-02,  -3.55529785e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -3.49426270e-02,  -3.49121094e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -3.27453613e-02,  -3.28063965e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.60717773e-02,  -3.60107422e-02],
                        [ -3.59497070e-02,  -3.59191895e-02],
                        [ -3.43627930e-02,  -3.44238281e-02],
                        [ -2.95104980e-02,  -2.95715332e-02],
                        [ -2.28881836e-02,  -2.28271484e-02],
                        [ -2.02636719e-02,  -2.02026367e-02],
                        [ -2.29187012e-02,  -2.29492188e-02],
                        [ -2.38342285e-02,  -2.39257812e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -1.32141113e-02,  -1.31225586e-02],
                        [ -1.00402832e-02,  -1.00097656e-02],
                        [ -7.44628906e-03,  -7.53784180e-03],
                        [ -1.25122070e-03,  -1.31225586e-03],
                        [  7.50732422e-03,   7.53784180e-03],
                        [  1.17187500e-02,   1.17797852e-02],
                        [  8.72802734e-03,   8.69750977e-03],
                        [  5.12695312e-03,   5.06591797e-03],
                        [  6.46972656e-03,   6.43920898e-03],
                        [  9.03320312e-03,   9.06372070e-03],
                        [  6.62231445e-03,   6.68334961e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -3.81469727e-03,  -3.87573242e-03],
                        [ -3.87573242e-03,  -3.90625000e-03],
                        [ -1.06811523e-03,  -1.00708008e-03],
                        [  3.69262695e-03,   3.72314453e-03],
                        [  9.94873047e-03,   9.88769531e-03],
                        [  1.59912109e-02,   1.59301758e-02],
                        [  1.93176270e-02,   1.93786621e-02],
                        [  2.02941895e-02,   2.03552246e-02],
                        [  2.25524902e-02,   2.24914551e-02],
                        [  2.82897949e-02,   2.82287598e-02],
                        [  3.68652344e-02,   3.68957520e-02],
                        [  4.81872559e-02,   4.82482910e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  8.50830078e-02,   8.50219727e-02],
                        [  1.07513428e-01,   1.07482910e-01],
                        [  1.22619629e-01,   1.22650146e-01],
                        [  1.19232178e-01,   1.19262695e-01],
                        [  8.92028809e-02,   8.92028809e-02],
                        [  3.18603516e-02,   3.18298340e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -1.44622803e-01,  -1.44561768e-01],
                        [ -2.38708496e-01,  -2.38708496e-01],
                        [ -3.04138184e-01,  -3.04138184e-01],
                        [ -3.21807861e-01,  -3.21807861e-01],
                        [ -2.97027588e-01,  -2.97058105e-01],
                        [ -2.54516602e-01,  -2.54516602e-01],
                        [ -2.17498779e-01,  -2.17468262e-01],
                        [ -1.91650391e-01,  -1.91650391e-01],
                        [ -1.64276123e-01,  -1.64337158e-01],
                        [ -1.19354248e-01,  -1.19415283e-01],
                        [ -5.59387207e-02,  -5.58471680e-02],
                        [  1.15051270e-02,   1.15966797e-02],
                        [  6.83288574e-02,   6.82678223e-02],
                        [  1.09588623e-01,   1.09466553e-01],
                        [  1.35040283e-01,   1.35070801e-01],
                        [  1.43249512e-01,   1.43371582e-01],
                        [  1.36688232e-01,   1.36688232e-01],
                        [  1.24633789e-01,   1.24511719e-01],
                        [  1.12457275e-01,   1.12426758e-01],
                        [  9.62524414e-02,   9.63439941e-02],
                        [  7.28454590e-02,   7.28759766e-02],
                        [  4.80957031e-02,   4.80346680e-02],
                        [  3.14331055e-02,   3.13720703e-02],
                        [  2.47802734e-02,   2.48107910e-02],
                        [  2.24304199e-02,   2.24609375e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.90429688e-02,   1.89819336e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  3.71093750e-02,   3.71398926e-02],
                        [  5.82580566e-02,   5.82580566e-02],
                        [  7.96508789e-02,   7.96203613e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  8.40148926e-02,   8.40148926e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [ -4.15039062e-03,  -4.18090820e-03],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -8.08715820e-03,  -8.05664062e-03],
                        [ -7.90405273e-03,  -7.87353516e-03],
                        [ -1.82495117e-02,  -1.82800293e-02],
                        [ -3.44848633e-02,  -3.45458984e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -5.03540039e-02,  -5.02929688e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -3.30200195e-02,  -3.30810547e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.80053711e-03,  -1.73950195e-03],
                        [  1.27868652e-02,   1.28173828e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  3.89099121e-02,   3.88793945e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.27246094e-02,   4.26940918e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  2.92053223e-02,   2.92663574e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  2.07519531e-02,   2.07214355e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  2.68249512e-02,   2.68554688e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  2.92968750e-02,   2.92663574e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  4.01916504e-02,   4.02221680e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.21044922e-02,  -3.21350098e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -3.76892090e-02,  -3.76586914e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -3.56445312e-02,  -3.56750488e-02],
                        [ -2.90222168e-02,  -2.90527344e-02],
                        [ -2.54211426e-02,  -2.53601074e-02],
                        [ -2.44445801e-02,  -2.44140625e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -1.39160156e-02,  -1.39465332e-02],
                        [ -1.21765137e-02,  -1.21459961e-02],
                        [ -1.40991211e-02,  -1.40686035e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -7.29370117e-03,  -7.32421875e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -1.30920410e-02,  -1.31225586e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -7.26318359e-03,  -7.23266602e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.77001953e-02,   1.77307129e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.19018555e-02,   1.18713379e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -2.41088867e-03,  -2.38037109e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.33056641e-02,  -1.33361816e-02],
                        [ -4.57763672e-03,  -4.60815430e-03],
                        [  8.02612305e-03,   8.05664062e-03],
                        [  1.58386230e-02,   1.58691406e-02],
                        [  2.05993652e-02,   2.05688477e-02],
                        [  2.89611816e-02,   2.89306641e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  5.00488281e-02,   5.00793457e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  7.76367188e-02,   7.76367188e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.31072998e-01,   1.31103516e-01],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  6.40258789e-02,   6.40258789e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -1.43127441e-01,  -1.43127441e-01],
                        [ -2.52929688e-01,  -2.52899170e-01],
                        [ -3.22448730e-01,  -3.22418213e-01],
                        [ -3.32733154e-01,  -3.32733154e-01],
                        [ -2.91137695e-01,  -2.91137695e-01],
                        [ -2.30682373e-01,  -2.30682373e-01],
                        [ -1.88049316e-01,  -1.88049316e-01],
                        [ -1.71905518e-01,  -1.71905518e-01],
                        [ -1.59393311e-01,  -1.59393311e-01],
                        [ -1.26251221e-01,  -1.26251221e-01],
                        [ -7.12280273e-02,  -7.12280273e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [  4.49218750e-02,   4.49523926e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.21063232e-01,   1.21063232e-01],
                        [  1.16821289e-01,   1.16821289e-01],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  7.47375488e-02,   7.47070312e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  1.81884766e-02,   1.82189941e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  3.85437012e-02,   3.85131836e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  7.81250000e-02,   7.81250000e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  5.91735840e-02,   5.91430664e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [ -5.49316406e-04,  -5.18798828e-04],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.33972168e-02,  -1.33666992e-02],
                        [ -1.09558105e-02,  -1.09252930e-02],
                        [ -1.77307129e-02,  -1.77612305e-02],
                        [ -2.96936035e-02,  -2.97241211e-02],
                        [ -4.01611328e-02,  -4.01306152e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.44543457e-02,  -3.44848633e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  3.55224609e-02,   3.54919434e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.93273926e-02,   2.93579102e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  3.23181152e-02,   3.22875977e-02],
                        [  3.23791504e-02,   3.24096680e-02],
                        [  3.40881348e-02,   3.41186523e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.53088379e-02,   3.52783203e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  3.33251953e-02,   3.33557129e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  1.78527832e-02,   1.78833008e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  7.93457031e-04,   7.93457031e-04],
                        [ -3.05175781e-03,  -3.02124023e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -4.15344238e-02,  -4.15039062e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.26342773e-02,  -1.26647949e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.27355957e-02,  -2.27661133e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  6.98852539e-03,   7.01904297e-03],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.27410889e-01,   1.27380371e-01],
                        [  1.26190186e-01,   1.26190186e-01],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -1.40167236e-01,  -1.40167236e-01],
                        [ -2.49816895e-01,  -2.49816895e-01],
                        [ -3.26843262e-01,  -3.26843262e-01],
                        [ -3.42895508e-01,  -3.42895508e-01],
                        [ -3.04779053e-01,  -3.04809570e-01],
                        [ -2.46948242e-01,  -2.46948242e-01],
                        [ -1.99645996e-01,  -1.99645996e-01],
                        [ -1.70043945e-01,  -1.70043945e-01],
                        [ -1.47308350e-01,  -1.47308350e-01],
                        [ -1.16912842e-01,  -1.16912842e-01],
                        [ -7.26623535e-02,  -7.26623535e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  1.24847412e-01,   1.24847412e-01],
                        [  1.34216309e-01,   1.34216309e-01],
                        [  1.32568359e-01,   1.32568359e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  4.31823730e-02,   4.31518555e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  4.93164062e-02,   4.93469238e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  5.97534180e-02,   5.97229004e-02],
                        [  5.98449707e-02,   5.98449707e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.68457031e-02,  -1.68762207e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.42517090e-02,  -1.42211914e-02],
                        [ -2.08435059e-02,  -2.08129883e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -1.71508789e-02,  -1.71813965e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  2.76489258e-02,   2.76489258e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.15966797e-03,   1.15966797e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  1.25793457e-01,   1.25793457e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.18041992e-01,   1.18041992e-01],
                        [  7.15637207e-02,   7.15637207e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.21002197e-01,  -1.21002197e-01],
                        [ -2.36389160e-01,  -2.36389160e-01],
                        [ -3.19396973e-01,  -3.19396973e-01],
                        [ -3.41003418e-01,  -3.41003418e-01],
                        [ -3.03405762e-01,  -3.03405762e-01],
                        [ -2.40875244e-01,  -2.40875244e-01],
                        [ -1.91802979e-01,  -1.91802979e-01],
                        [ -1.68670654e-01,  -1.68670654e-01],
                        [ -1.56341553e-01,  -1.56341553e-01],
                        [ -1.34124756e-01,  -1.34124756e-01],
                        [ -9.37194824e-02,  -9.37194824e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  1.33544922e-01,   1.33544922e-01],
                        [  1.43920898e-01,   1.43920898e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.23321533e-01,   1.23321533e-01],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  6.26831055e-02,   6.26831055e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  4.11682129e-02,   4.11682129e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  1.41052246e-01,   1.41052246e-01],
                        [  1.50909424e-01,   1.50909424e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  7.19299316e-02,   7.19299316e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -2.56866455e-01,  -2.56866455e-01],
                        [ -3.27270508e-01,  -3.27270508e-01],
                        [ -3.37799072e-01,  -3.37799072e-01],
                        [ -2.98919678e-01,  -2.98919678e-01],
                        [ -2.41455078e-01,  -2.41455078e-01],
                        [ -1.95587158e-01,  -1.95587158e-01],
                        [ -1.71081543e-01,  -1.71081543e-01],
                        [ -1.54998779e-01,  -1.54998779e-01],
                        [ -1.29608154e-01,  -1.29608154e-01],
                        [ -9.10949707e-02,  -9.10949707e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.37817383e-01,   1.37817383e-01],
                        [  1.34002686e-01,   1.34002686e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.17340088e-01,   1.17340088e-01],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  7.45544434e-02,   7.45544434e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  8.58154297e-02,   8.58154297e-02],
                        [  7.92236328e-02,   7.92236328e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  4.03747559e-02,   4.03747559e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  4.41284180e-02,   4.41284180e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  9.28344727e-02,   9.28344727e-02],
                        [  1.20788574e-01,   1.20788574e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  4.45556641e-02,   4.45556641e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -1.61132812e-01,  -1.61132812e-01],
                        [ -2.65045166e-01,  -2.65045166e-01],
                        [ -3.26080322e-01,  -3.26080322e-01],
                        [ -3.28186035e-01,  -3.28186035e-01],
                        [ -2.83935547e-01,  -2.83935547e-01],
                        [ -2.26867676e-01,  -2.26867676e-01],
                        [ -1.87438965e-01,  -1.87438965e-01],
                        [ -1.71813965e-01,  -1.71813965e-01],
                        [ -1.63818359e-01,  -1.63818359e-01],
                        [ -1.45446777e-01,  -1.45446777e-01],
                        [ -1.11114502e-01,  -1.11114502e-01],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  1.08154297e-01,   1.08154297e-01],
                        [  1.53564453e-01,   1.53564453e-01],
                        [  1.71478271e-01,   1.71478271e-01],
                        [  1.65161133e-01,   1.65161133e-01],
                        [  1.49871826e-01,   1.49871826e-01],
                        [  1.34582520e-01,   1.34582520e-01],
                        [  1.18408203e-01,   1.18408203e-01],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  9.08203125e-02,   9.08203125e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.83105469e-03,   1.83105469e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  1.19293213e-01,   1.19293213e-01],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -1.60491943e-01,  -1.60491943e-01],
                        [ -2.52227783e-01,  -2.52227783e-01],
                        [ -3.10272217e-01,  -3.10272217e-01],
                        [ -3.14544678e-01,  -3.14544678e-01],
                        [ -2.72888184e-01,  -2.72888184e-01],
                        [ -2.18811035e-01,  -2.18811035e-01],
                        [ -1.82250977e-01,  -1.82250977e-01],
                        [ -1.65435791e-01,  -1.65435791e-01],
                        [ -1.51550293e-01,  -1.51550293e-01],
                        [ -1.28112793e-01,  -1.28112793e-01],
                        [ -9.47875977e-02,  -9.47875977e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  1.45263672e-01,   1.45263672e-01],
                        [  1.64184570e-01,   1.64184570e-01],
                        [  1.60675049e-01,   1.60675049e-01],
                        [  1.47796631e-01,   1.47796631e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.31256104e-01,   1.31256104e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  6.52770996e-02,   6.52770996e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [  1.46484375e-03,   1.46484375e-03],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.28979492e-02,   3.28979492e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.03747559e-02,   4.03747559e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  4.14733887e-02,   4.14733887e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [  3.16467285e-02,   3.16467285e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  9.26513672e-02,   9.26513672e-02],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  1.14685059e-01,   1.14685059e-01],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -2.50030518e-01,  -2.50030518e-01],
                        [ -3.08135986e-01,  -3.08135986e-01],
                        [ -3.09478760e-01,  -3.09478760e-01],
                        [ -2.63244629e-01,  -2.63244629e-01],
                        [ -2.03613281e-01,  -2.03613281e-01],
                        [ -1.64337158e-01,  -1.64337158e-01],
                        [ -1.51550293e-01,  -1.51550293e-01],
                        [ -1.46392822e-01,  -1.46392822e-01],
                        [ -1.32171631e-01,  -1.32171631e-01],
                        [ -1.08154297e-01,  -1.08154297e-01],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  1.32232666e-01,   1.32232666e-01],
                        [  1.66381836e-01,   1.66381836e-01],
                        [  1.75598145e-01,   1.75598145e-01],
                        [  1.65374756e-01,   1.65374756e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  4.57458496e-02,   4.57458496e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  5.85632324e-02,   5.85632324e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  1.01318359e-01,   1.01318359e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.37603760e-01,   1.37603760e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  5.38024902e-02,   5.38024902e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -1.57897949e-01,  -1.57897949e-01],
                        [ -2.60406494e-01,  -2.60406494e-01],
                        [ -3.19030762e-01,  -3.19030762e-01],
                        [ -3.16467285e-01,  -3.16467285e-01],
                        [ -2.65838623e-01,  -2.65838623e-01],
                        [ -2.03918457e-01,  -2.03918457e-01],
                        [ -1.62658691e-01,  -1.62658691e-01],
                        [ -1.47857666e-01,  -1.47857666e-01],
                        [ -1.43798828e-01,  -1.43798828e-01],
                        [ -1.33544922e-01,  -1.33544922e-01],
                        [ -1.12487793e-01,  -1.12487793e-01],
                        [ -8.41674805e-02,  -8.41674805e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.69006348e-01,   1.69006348e-01],
                        [  1.84326172e-01,   1.84326172e-01],
                        [  1.80084229e-01,   1.80084229e-01],
                        [  1.67266846e-01,   1.67266846e-01],
                        [  1.51855469e-01,   1.51855469e-01],
                        [  1.34704590e-01,   1.34704590e-01],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  7.93457031e-04,   7.93457031e-04],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  1.07177734e-01,   1.07177734e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.36322021e-01,   1.36322021e-01],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  4.98962402e-02,   4.98962402e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -1.48071289e-01,  -1.48071289e-01],
                        [ -2.48382568e-01,  -2.48382568e-01],
                        [ -3.10821533e-01,  -3.10821533e-01],
                        [ -3.17382812e-01,  -3.17382812e-01],
                        [ -2.77526855e-01,  -2.77526855e-01],
                        [ -2.21313477e-01,  -2.21313477e-01],
                        [ -1.77185059e-01,  -1.77185059e-01],
                        [ -1.54724121e-01,  -1.54724121e-01],
                        [ -1.43646240e-01,  -1.43646240e-01],
                        [ -1.29272461e-01,  -1.29272461e-01],
                        [ -1.07513428e-01,  -1.07513428e-01],
                        [ -8.22753906e-02,  -8.22753906e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  1.07116699e-01,   1.07116699e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.92718506e-01,   1.92718506e-01],
                        [  2.00561523e-01,   2.00561523e-01],
                        [  1.93420410e-01,   1.93420410e-01],
                        [  1.79931641e-01,   1.79931641e-01],
                        [  1.58843994e-01,   1.58843994e-01],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  5.76171875e-02,   5.76171875e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.11389160e-02,   1.11389160e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  1.21215820e-01,   1.21215820e-01],
                        [  1.38702393e-01,   1.38702393e-01],
                        [  1.36688232e-01,   1.36688232e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  4.86450195e-02,   4.86450195e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -1.46759033e-01,  -1.46759033e-01],
                        [ -2.44445801e-01,  -2.44445801e-01],
                        [ -3.02093506e-01,  -3.02093506e-01],
                        [ -3.03131104e-01,  -3.03131104e-01],
                        [ -2.59429932e-01,  -2.59429932e-01],
                        [ -2.04071045e-01,  -2.04071045e-01],
                        [ -1.67297363e-01,  -1.67297363e-01],
                        [ -1.56005859e-01,  -1.56005859e-01],
                        [ -1.54663086e-01,  -1.54663086e-01],
                        [ -1.45690918e-01,  -1.45690918e-01],
                        [ -1.24572754e-01,  -1.24572754e-01],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  1.17675781e-01,   1.17675781e-01],
                        [  1.71447754e-01,   1.71447754e-01],
                        [  2.00347900e-01,   2.00347900e-01],
                        [  2.03491211e-01,   2.03491211e-01],
                        [  1.91009521e-01,   1.91009521e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.49291992e-01,   1.49291992e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  5.69763184e-02,   5.69763184e-02],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  7.08923340e-02,   7.08923340e-02],
                        [  7.21435547e-02,   7.21435547e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  8.37402344e-02,   8.37402344e-02],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  1.18804932e-01,   1.18804932e-01],
                        [  1.23321533e-01,   1.23321533e-01],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  4.89196777e-02,   4.89196777e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -1.37298584e-01,  -1.37298584e-01],
                        [ -2.28240967e-01,  -2.28240967e-01],
                        [ -2.85675049e-01,  -2.85675049e-01],
                        [ -2.93884277e-01,  -2.93884277e-01],
                        [ -2.57781982e-01,  -2.57781982e-01],
                        [ -2.05718994e-01,  -2.05718994e-01],
                        [ -1.68548584e-01,  -1.68548584e-01],
                        [ -1.53045654e-01,  -1.53045654e-01],
                        [ -1.43615723e-01,  -1.43615723e-01],
                        [ -1.28204346e-01,  -1.28204346e-01],
                        [ -1.10565186e-01,  -1.10565186e-01],
                        [ -9.60083008e-02,  -9.60083008e-02],
                        [ -7.69042969e-02,  -7.69042969e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  1.77459717e-01,   1.77459717e-01],
                        [  2.23602295e-01,   2.23602295e-01],
                        [  2.30529785e-01,   2.30529785e-01],
                        [  2.07885742e-01,   2.07885742e-01],
                        [  1.72271729e-01,   1.72271729e-01],
                        [  1.30462646e-01,   1.30462646e-01],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  2.68249512e-02,   2.68249512e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  1.24511719e-01,   1.24511719e-01],
                        [  1.23352051e-01,   1.23352051e-01],
                        [  9.63745117e-02,   9.63745117e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -1.32354736e-01,  -1.32354736e-01],
                        [ -2.21588135e-01,  -2.21588135e-01],
                        [ -2.81005859e-01,  -2.81005859e-01],
                        [ -2.86254883e-01,  -2.86254883e-01],
                        [ -2.42980957e-01,  -2.42980957e-01],
                        [ -1.87347412e-01,  -1.87347412e-01],
                        [ -1.52709961e-01,  -1.52709961e-01],
                        [ -1.44012451e-01,  -1.44012451e-01],
                        [ -1.45996094e-01,  -1.45996094e-01],
                        [ -1.43554688e-01,  -1.43554688e-01],
                        [ -1.30432129e-01,  -1.30432129e-01],
                        [ -1.07269287e-01,  -1.07269287e-01],
                        [ -7.51953125e-02,  -7.51953125e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  1.67480469e-01,   1.67480469e-01],
                        [  2.13562012e-01,   2.13562012e-01],
                        [  2.30163574e-01,   2.30163574e-01],
                        [  2.15301514e-01,   2.15301514e-01],
                        [  1.70501709e-01,   1.70501709e-01],
                        [  1.04064941e-01,   1.04064941e-01],
                        [  3.32641602e-02,   3.32641602e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  9.38415527e-02,   9.38415527e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  7.33642578e-02,   7.33642578e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  8.59985352e-02,   8.59985352e-02],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  5.12695312e-02,   5.12695312e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -1.29272461e-01,  -1.29272461e-01],
                        [ -2.24304199e-01,  -2.24304199e-01],
                        [ -2.86743164e-01,  -2.86743164e-01],
                        [ -2.94342041e-01,  -2.94342041e-01],
                        [ -2.52502441e-01,  -2.52502441e-01],
                        [ -1.95220947e-01,  -1.95220947e-01],
                        [ -1.54510498e-01,  -1.54510498e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -1.27136230e-01,  -1.27136230e-01],
                        [ -1.18713379e-01,  -1.18713379e-01],
                        [ -1.07940674e-01,  -1.07940674e-01],
                        [ -9.45434570e-02,  -9.45434570e-02],
                        [ -7.41271973e-02,  -7.41271973e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  9.21936035e-02,   9.21936035e-02],
                        [  1.63513184e-01,   1.63513184e-01],
                        [  2.14416504e-01,   2.14416504e-01],
                        [  2.30834961e-01,   2.30834961e-01],
                        [  2.07092285e-01,   2.07092285e-01],
                        [  1.48498535e-01,   1.48498535e-01],
                        [  7.17773438e-02,   7.17773438e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -5.77697754e-02,  -5.77697754e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  3.16467285e-02,   3.16467285e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  9.73510742e-02,   9.73510742e-02],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  4.42504883e-03,   4.42504883e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  4.77294922e-02,   4.77294922e-02],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.25640869e-01,   1.25640869e-01],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -2.41638184e-01,  -2.41638184e-01],
                        [ -2.91534424e-01,  -2.91534424e-01],
                        [ -2.87384033e-01,  -2.87384033e-01],
                        [ -2.40112305e-01,  -2.40112305e-01],
                        [ -1.81488037e-01,  -1.81488037e-01],
                        [ -1.38824463e-01,  -1.38824463e-01],
                        [ -1.18652344e-01,  -1.18652344e-01],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -1.07604980e-01,  -1.07604980e-01],
                        [ -1.02386475e-01,  -1.02386475e-01],
                        [ -9.67102051e-02,  -9.67102051e-02],
                        [ -8.72497559e-02,  -8.72497559e-02],
                        [ -6.32324219e-02,  -6.32324219e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  1.45446777e-01,   1.45446777e-01],
                        [  2.07122803e-01,   2.07122803e-01],
                        [  2.23083496e-01,   2.23083496e-01],
                        [  1.85699463e-01,   1.85699463e-01],
                        [  1.10961914e-01,   1.10961914e-01],
                        [  3.16467285e-02,   3.16467285e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  8.51135254e-02,   8.51135254e-02],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  4.37316895e-02,   4.37316895e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  1.12457275e-01,   1.12457275e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -1.44317627e-01,  -1.44317627e-01],
                        [ -2.44567871e-01,  -2.44567871e-01],
                        [ -3.04199219e-01,  -3.04199219e-01],
                        [ -3.00659180e-01,  -3.00659180e-01],
                        [ -2.43682861e-01,  -2.43682861e-01],
                        [ -1.72393799e-01,  -1.72393799e-01],
                        [ -1.22924805e-01,  -1.22924805e-01],
                        [ -1.02874756e-01,  -1.02874756e-01],
                        [ -9.86022949e-02,  -9.86022949e-02],
                        [ -9.57336426e-02,  -9.57336426e-02],
                        [ -8.83789062e-02,  -8.83789062e-02],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.53594971e-01,   1.53594971e-01],
                        [  1.65039062e-01,   1.65039062e-01],
                        [  1.34307861e-01,   1.34307861e-01],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  9.78088379e-02,   9.78088379e-02],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  9.50927734e-02,   9.50927734e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  6.45751953e-02,   6.45751953e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.30187988e-01,   1.30187988e-01],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  4.88281250e-02,   4.88281250e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -1.35864258e-01,  -1.35864258e-01],
                        [ -2.30560303e-01,  -2.30560303e-01],
                        [ -2.89672852e-01,  -2.89672852e-01],
                        [ -2.91656494e-01,  -2.91656494e-01],
                        [ -2.43103027e-01,  -2.43103027e-01],
                        [ -1.78344727e-01,  -1.78344727e-01],
                        [ -1.31072998e-01,  -1.31072998e-01],
                        [ -1.08703613e-01,  -1.08703613e-01],
                        [ -9.91821289e-02,  -9.91821289e-02],
                        [ -9.33227539e-02,  -9.33227539e-02],
                        [ -8.91418457e-02,  -8.91418457e-02],
                        [ -8.29772949e-02,  -8.29772949e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  9.31396484e-02,   9.31396484e-02],
                        [  1.08337402e-01,   1.08337402e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  7.96508789e-02,   7.96508789e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  7.66296387e-02,   7.66296387e-02],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  6.39953613e-02,   6.39953613e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -3.30810547e-02,  -3.30810547e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  7.79113770e-02,   7.79113770e-02],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  5.49011230e-02,   5.49011230e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -1.27166748e-01,  -1.27166748e-01],
                        [ -2.24945068e-01,  -2.24945068e-01],
                        [ -2.84454346e-01,  -2.84454346e-01],
                        [ -2.87689209e-01,  -2.87689209e-01],
                        [ -2.43896484e-01,  -2.43896484e-01],
                        [ -1.83227539e-01,  -1.83227539e-01],
                        [ -1.36779785e-01,  -1.36779785e-01],
                        [ -1.14257812e-01,  -1.14257812e-01],
                        [ -1.02783203e-01,  -1.02783203e-01],
                        [ -8.89587402e-02,  -8.89587402e-02],
                        [ -7.33947754e-02,  -7.33947754e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  5.98449707e-02,   5.98449707e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  1.03851318e-01,   1.03851318e-01],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  1.18438721e-01,   1.18438721e-01],
                        [  1.02020264e-01,   1.02020264e-01],
                        [  7.61718750e-02,   7.61718750e-02],
                        [  5.21850586e-02,   5.21850586e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  5.02624512e-02,   5.02624512e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.19903564e-01,   1.19903564e-01],
                        [  1.14593506e-01,   1.14593506e-01],
                        [  9.14306641e-02,   9.14306641e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -1.36444092e-01,  -1.36444092e-01],
                        [ -2.23571777e-01,  -2.23571777e-01],
                        [ -2.74475098e-01,  -2.74475098e-01],
                        [ -2.74505615e-01,  -2.74505615e-01],
                        [ -2.30957031e-01,  -2.30957031e-01],
                        [ -1.73583984e-01,  -1.73583984e-01],
                        [ -1.33911133e-01,  -1.33911133e-01],
                        [ -1.17553711e-01,  -1.17553711e-01],
                        [ -1.05377197e-01,  -1.05377197e-01],
                        [ -8.32824707e-02,  -8.32824707e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  8.86535645e-02,   8.86535645e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  5.78308105e-02,   5.78308105e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  9.33837891e-02,   9.33837891e-02],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  9.80529785e-02,   9.80529785e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  9.10644531e-02,   9.10644531e-02],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -1.30065918e-01,  -1.30065918e-01],
                        [ -2.22259521e-01,  -2.22259521e-01],
                        [ -2.81402588e-01,  -2.81402588e-01],
                        [ -2.82043457e-01,  -2.82043457e-01],
                        [ -2.29705811e-01,  -2.29705811e-01],
                        [ -1.60247803e-01,  -1.60247803e-01],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -8.32824707e-02,  -8.32824707e-02],
                        [ -7.05261230e-02,  -7.05261230e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -9.41467285e-02,  -9.41467285e-02],
                        [ -1.16882324e-01,  -1.16882324e-01],
                        [ -1.18286133e-01,  -1.18286133e-01],
                        [ -9.12170410e-02,  -9.12170410e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  1.18499756e-01,   1.18499756e-01],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  8.61511230e-02,   8.61511230e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  7.30285645e-02,   7.30285645e-02],
                        [  8.98742676e-02,   8.98742676e-02],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  1.00189209e-01,   1.00189209e-01],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  3.37524414e-02,   3.37524414e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  9.72290039e-02,   9.72290039e-02],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -1.30615234e-01,  -1.30615234e-01],
                        [ -2.12921143e-01,  -2.12921143e-01],
                        [ -2.61871338e-01,  -2.61871338e-01],
                        [ -2.61749268e-01,  -2.61749268e-01],
                        [ -2.17956543e-01,  -2.17956543e-01],
                        [ -1.58630371e-01,  -1.58630371e-01],
                        [ -1.13037109e-01,  -1.13037109e-01],
                        [ -8.85009766e-02,  -8.85009766e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -1.08032227e-01,  -1.08032227e-01],
                        [ -1.35864258e-01,  -1.35864258e-01],
                        [ -1.39831543e-01,  -1.39831543e-01],
                        [ -1.13983154e-01,  -1.13983154e-01],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  6.84814453e-02,   6.84814453e-02],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.17401123e-01,   1.17401123e-01],
                        [  1.07543945e-01,   1.07543945e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  6.30187988e-02,   6.30187988e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  3.66210938e-02,   3.66210938e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.69055176e-02,  -4.69055176e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  8.41369629e-02,   8.41369629e-02],
                        [  1.10900879e-01,   1.10900879e-01],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.41357422e-01,   1.41357422e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  6.46667480e-02,   6.46667480e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -2.07489014e-01,  -2.07489014e-01],
                        [ -2.71392822e-01,  -2.71392822e-01],
                        [ -2.85003662e-01,  -2.85003662e-01],
                        [ -2.48962402e-01,  -2.48962402e-01],
                        [ -1.86920166e-01,  -1.86920166e-01],
                        [ -1.26556396e-01,  -1.26556396e-01],
                        [ -8.05358887e-02,  -8.05358887e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -1.02111816e-01,  -1.02111816e-01],
                        [ -1.47491455e-01,  -1.47491455e-01],
                        [ -1.74835205e-01,  -1.74835205e-01],
                        [ -1.73919678e-01,  -1.73919678e-01],
                        [ -1.37725830e-01,  -1.37725830e-01],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  6.14624023e-02,   6.14624023e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  1.09252930e-01,   1.09252930e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.01806641e-01,   1.01806641e-01],
                        [  8.03527832e-02,   8.03527832e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  7.08923340e-02,   7.08923340e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  9.19189453e-02,   9.19189453e-02],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.38946533e-01,   1.38946533e-01],
                        [  1.38854980e-01,   1.38854980e-01],
                        [  1.15203857e-01,   1.15203857e-01],
                        [  6.38122559e-02,   6.38122559e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.09527588e-01,  -1.09527588e-01],
                        [ -2.05200195e-01,  -2.05200195e-01],
                        [ -2.73040771e-01,  -2.73040771e-01],
                        [ -2.87597656e-01,  -2.87597656e-01],
                        [ -2.47283936e-01,  -2.47283936e-01],
                        [ -1.80236816e-01,  -1.80236816e-01],
                        [ -1.21276855e-01,  -1.21276855e-01],
                        [ -8.52661133e-02,  -8.52661133e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -1.58355713e-01,  -1.58355713e-01],
                        [ -1.93908691e-01,  -1.93908691e-01],
                        [ -1.97601318e-01,  -1.97601318e-01],
                        [ -1.69219971e-01,  -1.69219971e-01],
                        [ -1.19415283e-01,  -1.19415283e-01],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  1.21887207e-01,   1.21887207e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.22711182e-01,   1.22711182e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  7.92236328e-02,   7.92236328e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  8.96301270e-02,   8.96301270e-02],
                        [  1.07910156e-01,   1.07910156e-01],
                        [  1.25061035e-01,   1.25061035e-01],
                        [  1.30706787e-01,   1.30706787e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  6.14013672e-02,   6.14013672e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  5.63964844e-02,   5.63964844e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  7.93457031e-04,   7.93457031e-04],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  2.10571289e-03,   2.10571289e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  1.16943359e-01,   1.16943359e-01],
                        [  1.38488770e-01,   1.38488770e-01],
                        [  1.45355225e-01,   1.45355225e-01],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  2.92968750e-03,   2.92968750e-03],
                        [ -9.33227539e-02,  -9.33227539e-02],
                        [ -1.92504883e-01,  -1.92504883e-01],
                        [ -2.66082764e-01,  -2.66082764e-01],
                        [ -2.87170410e-01,  -2.87170410e-01],
                        [ -2.51281738e-01,  -2.51281738e-01],
                        [ -1.81549072e-01,  -1.81549072e-01],
                        [ -1.11450195e-01,  -1.11450195e-01],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -7.77587891e-02,  -7.77587891e-02],
                        [ -1.22314453e-01,  -1.22314453e-01],
                        [ -1.69067383e-01,  -1.69067383e-01],
                        [ -1.99676514e-01,  -1.99676514e-01],
                        [ -1.98730469e-01,  -1.98730469e-01],
                        [ -1.66961670e-01,  -1.66961670e-01],
                        [ -1.20605469e-01,  -1.20605469e-01],
                        [ -7.51342773e-02,  -7.51342773e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.32415771e-01,   1.32415771e-01],
                        [  1.14410400e-01,   1.14410400e-01],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.26586914e-01,   1.26586914e-01],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.46118164e-01,   1.46118164e-01],
                        [  1.37451172e-01,   1.37451172e-01],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.01135254e-01,   1.01135254e-01],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  5.93872070e-02,   5.93872070e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  4.76074219e-03,   4.76074219e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.45629883e-01,   1.45629883e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.40686035e-01,   1.40686035e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [ -8.34655762e-02,  -8.34655762e-02],
                        [ -1.90765381e-01,  -1.90765381e-01],
                        [ -2.68310547e-01,  -2.68310547e-01],
                        [ -2.87353516e-01,  -2.87353516e-01],
                        [ -2.46215820e-01,  -2.46215820e-01],
                        [ -1.71447754e-01,  -1.71447754e-01],
                        [ -9.93652344e-02,  -9.93652344e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -1.47460938e-01,  -1.47460938e-01],
                        [ -1.93359375e-01,  -1.93359375e-01],
                        [ -2.14050293e-01,  -2.14050293e-01],
                        [ -2.02270508e-01,  -2.02270508e-01],
                        [ -1.66534424e-01,  -1.66534424e-01],
                        [ -1.23626709e-01,  -1.23626709e-01],
                        [ -8.59985352e-02,  -8.59985352e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  1.40136719e-01,   1.40136719e-01],
                        [  1.57501221e-01,   1.57501221e-01],
                        [  1.47430420e-01,   1.47430420e-01],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  9.63745117e-02,   9.63745117e-02],
                        [  8.95996094e-02,   8.95996094e-02],
                        [  9.36279297e-02,   9.36279297e-02],
                        [  9.61914062e-02,   9.61914062e-02],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.19171143e-01,   1.19171143e-01],
                        [  1.34979248e-01,   1.34979248e-01],
                        [  1.40808105e-01,   1.40808105e-01],
                        [  1.32751465e-01,   1.32751465e-01],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  8.83178711e-02,   8.83178711e-02],
                        [  8.47778320e-02,   8.47778320e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  8.68530273e-02,   8.68530273e-02],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.34948730e-01,   1.34948730e-01],
                        [  1.48468018e-01,   1.48468018e-01],
                        [  1.41387939e-01,   1.41387939e-01],
                        [  1.09954834e-01,   1.09954834e-01],
                        [  5.77392578e-02,   5.77392578e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -9.60083008e-02,  -9.60083008e-02],
                        [ -1.83471680e-01,  -1.83471680e-01],
                        [ -2.47192383e-01,  -2.47192383e-01],
                        [ -2.59460449e-01,  -2.59460449e-01],
                        [ -2.15850830e-01,  -2.15850830e-01],
                        [ -1.43463135e-01,  -1.43463135e-01],
                        [ -8.32519531e-02,  -8.32519531e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -6.75048828e-02,  -6.75048828e-02],
                        [ -8.77685547e-02,  -8.77685547e-02],
                        [ -1.12060547e-01,  -1.12060547e-01],
                        [ -1.42211914e-01,  -1.42211914e-01],
                        [ -1.73919678e-01,  -1.73919678e-01],
                        [ -1.92687988e-01,  -1.92687988e-01],
                        [ -1.88751221e-01,  -1.88751221e-01],
                        [ -1.67327881e-01,  -1.67327881e-01],
                        [ -1.40380859e-01,  -1.40380859e-01],
                        [ -1.13739014e-01,  -1.13739014e-01],
                        [ -8.57849121e-02,  -8.57849121e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.43157959e-01,   1.43157959e-01],
                        [  1.41998291e-01,   1.41998291e-01],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  9.53979492e-02,   9.53979492e-02],
                        [  1.01593018e-01,   1.01593018e-01],
                        [  1.07421875e-01,   1.07421875e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.35894775e-01,   1.35894775e-01],
                        [  1.37390137e-01,   1.37390137e-01],
                        [  1.28234863e-01,   1.28234863e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  8.30688477e-02,   8.30688477e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  6.51245117e-02,   6.51245117e-02],
                        [  6.36596680e-02,   6.36596680e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  6.13708496e-02,   6.13708496e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  4.91333008e-03,   4.91333008e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -4.89807129e-02,  -4.89807129e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  5.09033203e-02,   5.09033203e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  1.29333496e-01,   1.29333496e-01],
                        [  1.56280518e-01,   1.56280518e-01],
                        [  1.60583496e-01,   1.60583496e-01],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  7.62023926e-02,   7.62023926e-02],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -9.90905762e-02,  -9.90905762e-02],
                        [ -1.88140869e-01,  -1.88140869e-01],
                        [ -2.44079590e-01,  -2.44079590e-01],
                        [ -2.46520996e-01,  -2.46520996e-01],
                        [ -1.99218750e-01,  -1.99218750e-01],
                        [ -1.30401611e-01,  -1.30401611e-01],
                        [ -7.62939453e-02,  -7.62939453e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -1.20666504e-01,  -1.20666504e-01],
                        [ -1.60736084e-01,  -1.60736084e-01],
                        [ -1.88140869e-01,  -1.88140869e-01],
                        [ -1.95648193e-01,  -1.95648193e-01],
                        [ -1.83349609e-01,  -1.83349609e-01],
                        [ -1.59912109e-01,  -1.59912109e-01],
                        [ -1.36627197e-01,  -1.36627197e-01],
                        [ -1.18896484e-01,  -1.18896484e-01],
                        [ -1.03912354e-01,  -1.03912354e-01],
                        [ -8.50524902e-02,  -8.50524902e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  1.10198975e-01,   1.10198975e-01],
                        [  1.42944336e-01,   1.42944336e-01],
                        [  1.53106689e-01,   1.53106689e-01],
                        [  1.43341064e-01,   1.43341064e-01],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  1.14196777e-01,   1.14196777e-01],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  1.34979248e-01,   1.34979248e-01],
                        [  1.52862549e-01,   1.52862549e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.50207520e-01,   1.50207520e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  9.92736816e-02,   9.92736816e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  5.37414551e-02,   5.37414551e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  8.68225098e-02,   8.68225098e-02],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.31317139e-01,   1.31317139e-01],
                        [  1.44714355e-01,   1.44714355e-01],
                        [  1.43280029e-01,   1.43280029e-01],
                        [  1.19079590e-01,   1.19079590e-01],
                        [  6.88171387e-02,   6.88171387e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -8.97827148e-02,  -8.97827148e-02],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -2.27264404e-01,  -2.27264404e-01],
                        [ -2.33001709e-01,  -2.33001709e-01],
                        [ -1.92321777e-01,  -1.92321777e-01],
                        [ -1.34490967e-01,  -1.34490967e-01],
                        [ -9.65576172e-02,  -9.65576172e-02],
                        [ -9.66491699e-02,  -9.66491699e-02],
                        [ -1.24420166e-01,  -1.24420166e-01],
                        [ -1.57165527e-01,  -1.57165527e-01],
                        [ -1.79901123e-01,  -1.79901123e-01],
                        [ -1.87713623e-01,  -1.87713623e-01],
                        [ -1.79199219e-01,  -1.79199219e-01],
                        [ -1.57440186e-01,  -1.57440186e-01],
                        [ -1.32232666e-01,  -1.32232666e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -1.03759766e-01,  -1.03759766e-01],
                        [ -9.82666016e-02,  -9.82666016e-02],
                        [ -9.16748047e-02,  -9.16748047e-02],
                        [ -7.94677734e-02,  -7.94677734e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  1.50421143e-01,   1.50421143e-01],
                        [  1.70623779e-01,   1.70623779e-01],
                        [  1.61376953e-01,   1.61376953e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  1.07910156e-01,   1.07910156e-01],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  1.40838623e-01,   1.40838623e-01],
                        [  1.55426025e-01,   1.55426025e-01],
                        [  1.63604736e-01,   1.63604736e-01],
                        [  1.62597656e-01,   1.62597656e-01],
                        [  1.52740479e-01,   1.52740479e-01],
                        [  1.35009766e-01,   1.35009766e-01],
                        [  1.12152100e-01,   1.12152100e-01],
                        [  9.01794434e-02,   9.01794434e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  1.40350342e-01,   1.40350342e-01],
                        [  1.57318115e-01,   1.57318115e-01],
                        [  1.57440186e-01,   1.57440186e-01],
                        [  1.32751465e-01,   1.32751465e-01],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -9.23461914e-02,  -9.23461914e-02],
                        [ -1.78161621e-01,  -1.78161621e-01],
                        [ -2.29217529e-01,  -2.29217529e-01],
                        [ -2.28485107e-01,  -2.28485107e-01],
                        [ -1.86126709e-01,  -1.86126709e-01],
                        [ -1.36749268e-01,  -1.36749268e-01],
                        [ -1.13830566e-01,  -1.13830566e-01],
                        [ -1.26922607e-01,  -1.26922607e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.94458008e-01,  -1.94458008e-01],
                        [ -2.06329346e-01,  -2.06329346e-01],
                        [ -1.92230225e-01,  -1.92230225e-01],
                        [ -1.61804199e-01,  -1.61804199e-01],
                        [ -1.30126953e-01,  -1.30126953e-01],
                        [ -1.07147217e-01,  -1.07147217e-01],
                        [ -9.55200195e-02,  -9.55200195e-02],
                        [ -9.28344727e-02,  -9.28344727e-02],
                        [ -9.31091309e-02,  -9.31091309e-02],
                        [ -8.88366699e-02,  -8.88366699e-02],
                        [ -7.53479004e-02,  -7.53479004e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  1.53015137e-01,   1.53015137e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.72912598e-01,   1.72912598e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.34185791e-01,   1.34185791e-01],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.14257812e-01,   1.14257812e-01],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.45019531e-01,   1.45019531e-01],
                        [  1.61437988e-01,   1.61437988e-01],
                        [  1.68762207e-01,   1.68762207e-01],
                        [  1.60156250e-01,   1.60156250e-01],
                        [  1.39739990e-01,   1.39739990e-01],
                        [  1.20269775e-01,   1.20269775e-01],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  8.21228027e-02,   8.21228027e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  5.54199219e-02,   5.54199219e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.95092773e-02,  -5.95092773e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -6.09436035e-02,  -6.09436035e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  9.05761719e-02,   9.05761719e-02],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  1.30737305e-01,   1.30737305e-01],
                        [  1.47766113e-01,   1.47766113e-01],
                        [  1.49871826e-01,   1.49871826e-01],
                        [  1.27777100e-01,   1.27777100e-01],
                        [  7.38220215e-02,   7.38220215e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -1.03851318e-01,  -1.03851318e-01],
                        [ -1.83258057e-01,  -1.83258057e-01],
                        [ -2.25891113e-01,  -2.25891113e-01],
                        [ -2.22045898e-01,  -2.22045898e-01],
                        [ -1.83715820e-01,  -1.83715820e-01],
                        [ -1.46026611e-01,  -1.46026611e-01],
                        [ -1.43249512e-01,  -1.43249512e-01],
                        [ -1.77124023e-01,  -1.77124023e-01],
                        [ -2.18200684e-01,  -2.18200684e-01],
                        [ -2.36572266e-01,  -2.36572266e-01],
                        [ -2.24456787e-01,  -2.24456787e-01],
                        [ -1.92657471e-01,  -1.92657471e-01],
                        [ -1.56677246e-01,  -1.56677246e-01],
                        [ -1.26403809e-01,  -1.26403809e-01],
                        [ -1.02966309e-01,  -1.02966309e-01],
                        [ -8.17260742e-02,  -8.17260742e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.53625488e-01,   1.53625488e-01],
                        [  1.63909912e-01,   1.63909912e-01],
                        [  1.52252197e-01,   1.52252197e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  1.17584229e-01,   1.17584229e-01],
                        [  1.38305664e-01,   1.38305664e-01],
                        [  1.60858154e-01,   1.60858154e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.84173584e-01,   1.84173584e-01],
                        [  1.80297852e-01,   1.80297852e-01],
                        [  1.63146973e-01,   1.63146973e-01],
                        [  1.35040283e-01,   1.35040283e-01],
                        [  1.04217529e-01,   1.04217529e-01],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -6.60400391e-02,  -6.60400391e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -5.77392578e-02,  -5.77392578e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  5.21850586e-02,   5.21850586e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.55609131e-01,   1.55609131e-01],
                        [  1.62078857e-01,   1.62078857e-01],
                        [  1.43798828e-01,   1.43798828e-01],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  3.74450684e-02,   3.74450684e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -1.25885010e-01,  -1.25885010e-01],
                        [ -1.96960449e-01,  -1.96960449e-01],
                        [ -2.32940674e-01,  -2.32940674e-01],
                        [ -2.32879639e-01,  -2.32879639e-01],
                        [ -2.21069336e-01,  -2.21069336e-01],
                        [ -2.20581055e-01,  -2.20581055e-01],
                        [ -2.29766846e-01,  -2.29766846e-01],
                        [ -2.30651855e-01,  -2.30651855e-01],
                        [ -2.11975098e-01,  -2.11975098e-01],
                        [ -1.78741455e-01,  -1.78741455e-01],
                        [ -1.45172119e-01,  -1.45172119e-01],
                        [ -1.23291016e-01,  -1.23291016e-01],
                        [ -1.14288330e-01,  -1.14288330e-01],
                        [ -1.07177734e-01,  -1.07177734e-01],
                        [ -8.93859863e-02,  -8.93859863e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  1.26739502e-01,   1.26739502e-01],
                        [  1.47827148e-01,   1.47827148e-01],
                        [  1.49719238e-01,   1.49719238e-01],
                        [  1.40594482e-01,   1.40594482e-01],
                        [  1.34368896e-01,   1.34368896e-01],
                        [  1.42211914e-01,   1.42211914e-01],
                        [  1.65435791e-01,   1.65435791e-01],
                        [  1.93115234e-01,   1.93115234e-01],
                        [  2.09808350e-01,   2.09808350e-01],
                        [  2.08312988e-01,   2.08312988e-01],
                        [  1.92932129e-01,   1.92932129e-01],
                        [  1.70959473e-01,   1.70959473e-01],
                        [  1.47094727e-01,   1.47094727e-01],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  1.02172852e-01,   1.02172852e-01],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  4.63562012e-02,   4.63562012e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -7.03125000e-02,  -7.03125000e-02],
                        [ -6.71997070e-02,  -6.71997070e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  1.19598389e-01,   1.19598389e-01],
                        [  1.58538818e-01,   1.58538818e-01],
                        [  1.86889648e-01,   1.86889648e-01],
                        [  1.91925049e-01,   1.91925049e-01],
                        [  1.68762207e-01,   1.68762207e-01],
                        [  1.18225098e-01,   1.18225098e-01],
                        [  4.25415039e-02,   4.25415039e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -2.17529297e-01,  -2.17529297e-01],
                        [ -2.58850098e-01,  -2.58850098e-01],
                        [ -2.69683838e-01,  -2.69683838e-01],
                        [ -2.61993408e-01,  -2.61993408e-01],
                        [ -2.50549316e-01,  -2.50549316e-01],
                        [ -2.42614746e-01,  -2.42614746e-01],
                        [ -2.31933594e-01,  -2.31933594e-01],
                        [ -2.07519531e-01,  -2.07519531e-01],
                        [ -1.70654297e-01,  -1.70654297e-01],
                        [ -1.36840820e-01,  -1.36840820e-01],
                        [ -1.16485596e-01,  -1.16485596e-01],
                        [ -1.02050781e-01,  -1.02050781e-01],
                        [ -8.17260742e-02,  -8.17260742e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  1.09161377e-01,   1.09161377e-01],
                        [  1.39038086e-01,   1.39038086e-01],
                        [  1.59118652e-01,   1.59118652e-01],
                        [  1.68121338e-01,   1.68121338e-01],
                        [  1.69342041e-01,   1.69342041e-01],
                        [  1.70379639e-01,   1.70379639e-01],
                        [  1.76940918e-01,   1.76940918e-01],
                        [  1.86523438e-01,   1.86523438e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  1.83746338e-01,   1.83746338e-01],
                        [  1.69158936e-01,   1.69158936e-01],
                        [  1.51306152e-01,   1.51306152e-01],
                        [  1.32781982e-01,   1.32781982e-01],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  9.19799805e-02,   9.19799805e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -6.20117188e-02,  -6.20117188e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -6.62231445e-02,  -6.62231445e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  5.85632324e-02,   5.85632324e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  1.17553711e-01,   1.17553711e-01],
                        [  1.49139404e-01,   1.49139404e-01],
                        [  1.75292969e-01,   1.75292969e-01],
                        [  1.83959961e-01,   1.83959961e-01],
                        [  1.59698486e-01,   1.59698486e-01],
                        [  9.49707031e-02,   9.49707031e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.18164062e-01,  -1.18164062e-01],
                        [ -2.26409912e-01,  -2.26409912e-01],
                        [ -3.03222656e-01,  -3.03222656e-01],
                        [ -3.33709717e-01,  -3.33709717e-01],
                        [ -3.22357178e-01,  -3.22357178e-01],
                        [ -2.87658691e-01,  -2.87658691e-01],
                        [ -2.47192383e-01,  -2.47192383e-01],
                        [ -2.09075928e-01,  -2.09075928e-01],
                        [ -1.74377441e-01,  -1.74377441e-01],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -1.22589111e-01,  -1.22589111e-01],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -9.53674316e-02,  -9.53674316e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -5.76782227e-02,  -5.76782227e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  1.52679443e-01,   1.52679443e-01],
                        [  1.82220459e-01,   1.82220459e-01],
                        [  1.94732666e-01,   1.94732666e-01],
                        [  1.98822021e-01,   1.98822021e-01],
                        [  2.03155518e-01,   2.03155518e-01],
                        [  2.07519531e-01,   2.07519531e-01],
                        [  2.05200195e-01,   2.05200195e-01],
                        [  1.92810059e-01,   1.92810059e-01],
                        [  1.75872803e-01,   1.75872803e-01],
                        [  1.61895752e-01,   1.61895752e-01],
                        [  1.50878906e-01,   1.50878906e-01],
                        [  1.37786865e-01,   1.37786865e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  5.76171875e-02,   5.76171875e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.62451172e-03,   2.62451172e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -6.65893555e-02,  -6.65893555e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -7.36999512e-02,  -7.36999512e-02],
                        [ -7.81860352e-02,  -7.81860352e-02],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.65161133e-01,   1.65161133e-01],
                        [  1.95770264e-01,   1.95770264e-01],
                        [  2.02117920e-01,   2.02117920e-01],
                        [  1.75933838e-01,   1.75933838e-01],
                        [  1.11480713e-01,   1.11480713e-01],
                        [  8.17871094e-03,   8.17871094e-03],
                        [ -1.23718262e-01,  -1.23718262e-01],
                        [ -2.58605957e-01,  -2.58605957e-01],
                        [ -3.58551025e-01,  -3.58551025e-01],
                        [ -3.92303467e-01,  -3.92303467e-01],
                        [ -3.60626221e-01,  -3.60626221e-01],
                        [ -2.96478271e-01,  -2.96478271e-01],
                        [ -2.35229492e-01,  -2.35229492e-01],
                        [ -1.91406250e-01,  -1.91406250e-01],
                        [ -1.62414551e-01,  -1.62414551e-01],
                        [ -1.40991211e-01,  -1.40991211e-01],
                        [ -1.20971680e-01,  -1.20971680e-01],
                        [ -1.00433350e-01,  -1.00433350e-01],
                        [ -8.38012695e-02,  -8.38012695e-02],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.72546387e-01,   1.72546387e-01],
                        [  2.15728760e-01,   2.15728760e-01],
                        [  2.44018555e-01,   2.44018555e-01],
                        [  2.54943848e-01,   2.54943848e-01],
                        [  2.50305176e-01,   2.50305176e-01],
                        [  2.36846924e-01,   2.36846924e-01],
                        [  2.19390869e-01,   2.19390869e-01],
                        [  1.98760986e-01,   1.98760986e-01],
                        [  1.76971436e-01,   1.76971436e-01],
                        [  1.57684326e-01,   1.57684326e-01],
                        [  1.40655518e-01,   1.40655518e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  7.47985840e-02,   7.47985840e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  4.42504883e-03,   4.42504883e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  1.13220215e-01,   1.13220215e-01],
                        [  1.37969971e-01,   1.37969971e-01],
                        [  1.63360596e-01,   1.63360596e-01],
                        [  1.82708740e-01,   1.82708740e-01],
                        [  1.85424805e-01,   1.85424805e-01],
                        [  1.57287598e-01,   1.57287598e-01],
                        [  8.64868164e-02,   8.64868164e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -3.09112549e-01,  -3.09112549e-01],
                        [ -3.94592285e-01,  -3.94592285e-01],
                        [ -4.04174805e-01,  -4.04174805e-01],
                        [ -3.49609375e-01,  -3.49609375e-01],
                        [ -2.68402100e-01,  -2.68402100e-01],
                        [ -1.98059082e-01,  -1.98059082e-01],
                        [ -1.56707764e-01,  -1.56707764e-01],
                        [ -1.38183594e-01,  -1.38183594e-01],
                        [ -1.23260498e-01,  -1.23260498e-01],
                        [ -1.00646973e-01,  -1.00646973e-01],
                        [ -7.65075684e-02,  -7.65075684e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  1.78009033e-01,   1.78009033e-01],
                        [  2.39868164e-01,   2.39868164e-01],
                        [  2.71942139e-01,   2.71942139e-01],
                        [  2.72888184e-01,   2.72888184e-01],
                        [  2.58636475e-01,   2.58636475e-01],
                        [  2.44110107e-01,   2.44110107e-01],
                        [  2.29125977e-01,   2.29125977e-01],
                        [  2.08099365e-01,   2.08099365e-01],
                        [  1.82830811e-01,   1.82830811e-01],
                        [  1.57531738e-01,   1.57531738e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  2.95410156e-02,   2.95410156e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -7.67517090e-02,  -7.67517090e-02],
                        [ -7.70263672e-02,  -7.70263672e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  5.91430664e-02,   5.91430664e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  9.01489258e-02,   9.01489258e-02],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.59240723e-01,   1.59240723e-01],
                        [  1.86706543e-01,   1.86706543e-01],
                        [  1.93115234e-01,   1.93115234e-01],
                        [  1.69128418e-01,   1.69128418e-01],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  9.91821289e-03,   9.91821289e-03],
                        [ -1.17187500e-01,  -1.17187500e-01],
                        [ -2.55493164e-01,  -2.55493164e-01],
                        [ -3.70605469e-01,  -3.70605469e-01],
                        [ -4.21325684e-01,  -4.21325684e-01],
                        [ -3.92395020e-01,  -3.92395020e-01],
                        [ -3.13049316e-01,  -3.13049316e-01],
                        [ -2.32666016e-01,  -2.32666016e-01],
                        [ -1.80755615e-01,  -1.80755615e-01],
                        [ -1.54174805e-01,  -1.54174805e-01],
                        [ -1.34368896e-01,  -1.34368896e-01],
                        [ -1.09283447e-01,  -1.09283447e-01],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  1.02050781e-01,   1.02050781e-01],
                        [  1.75933838e-01,   1.75933838e-01],
                        [  2.40051270e-01,   2.40051270e-01],
                        [  2.78778076e-01,   2.78778076e-01],
                        [  2.85675049e-01,   2.85675049e-01],
                        [  2.67883301e-01,   2.67883301e-01],
                        [  2.39471436e-01,   2.39471436e-01],
                        [  2.11395264e-01,   2.11395264e-01],
                        [  1.86798096e-01,   1.86798096e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.42700195e-01,   1.42700195e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.00128174e-01,   1.00128174e-01],
                        [  8.08715820e-02,   8.08715820e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -6.46362305e-02,  -6.46362305e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  8.69140625e-02,   8.69140625e-02],
                        [  1.06323242e-01,   1.06323242e-01],
                        [  1.31713867e-01,   1.31713867e-01],
                        [  1.62750244e-01,   1.62750244e-01],
                        [  1.88140869e-01,   1.88140869e-01],
                        [  1.89727783e-01,   1.89727783e-01],
                        [  1.54693604e-01,   1.54693604e-01],
                        [  7.97424316e-02,   7.97424316e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -1.69891357e-01,  -1.69891357e-01],
                        [ -3.00781250e-01,  -3.00781250e-01],
                        [ -3.84613037e-01,  -3.84613037e-01],
                        [ -3.96881104e-01,  -3.96881104e-01],
                        [ -3.47076416e-01,  -3.47076416e-01],
                        [ -2.72491455e-01,  -2.72491455e-01],
                        [ -2.11029053e-01,  -2.11029053e-01],
                        [ -1.76025391e-01,  -1.76025391e-01],
                        [ -1.56555176e-01,  -1.56555176e-01],
                        [ -1.37847900e-01,  -1.37847900e-01],
                        [ -1.15783691e-01,  -1.15783691e-01],
                        [ -9.43908691e-02,  -9.43908691e-02],
                        [ -7.58361816e-02,  -7.58361816e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  1.87408447e-01,   1.87408447e-01],
                        [  2.55004883e-01,   2.55004883e-01],
                        [  2.95623779e-01,   2.95623779e-01],
                        [  2.99652100e-01,   2.99652100e-01],
                        [  2.72369385e-01,   2.72369385e-01],
                        [  2.34985352e-01,   2.34985352e-01],
                        [  2.07275391e-01,   2.07275391e-01],
                        [  1.90582275e-01,   1.90582275e-01],
                        [  1.75506592e-01,   1.75506592e-01],
                        [  1.58660889e-01,   1.58660889e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  9.72290039e-02,   9.72290039e-02],
                        [  7.07702637e-02,   7.07702637e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -7.70874023e-02,  -7.70874023e-02],
                        [ -8.33435059e-02,  -8.33435059e-02],
                        [ -8.02307129e-02,  -8.02307129e-02],
                        [ -6.90917969e-02,  -6.90917969e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -7.47375488e-02,  -7.47375488e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  7.88574219e-02,   7.88574219e-02],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  1.59637451e-01,   1.59637451e-01],
                        [  1.78894043e-01,   1.78894043e-01],
                        [  1.76055908e-01,   1.76055908e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  6.78405762e-02,   6.78405762e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -1.76818848e-01,  -1.76818848e-01],
                        [ -3.02368164e-01,  -3.02368164e-01],
                        [ -3.81652832e-01,  -3.81652832e-01],
                        [ -3.93218994e-01,  -3.93218994e-01],
                        [ -3.45672607e-01,  -3.45672607e-01],
                        [ -2.72155762e-01,  -2.72155762e-01],
                        [ -2.08099365e-01,  -2.08099365e-01],
                        [ -1.68304443e-01,  -1.68304443e-01],
                        [ -1.43585205e-01,  -1.43585205e-01],
                        [ -1.18621826e-01,  -1.18621826e-01],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -5.41076660e-02,  -5.41076660e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  9.32312012e-02,   9.32312012e-02],
                        [  1.76269531e-01,   1.76269531e-01],
                        [  2.55767822e-01,   2.55767822e-01],
                        [  3.09539795e-01,   3.09539795e-01],
                        [  3.22937012e-01,   3.22937012e-01],
                        [  2.99774170e-01,   2.99774170e-01],
                        [  2.58148193e-01,   2.58148193e-01],
                        [  2.16033936e-01,   2.16033936e-01],
                        [  1.80847168e-01,   1.80847168e-01],
                        [  1.51397705e-01,   1.51397705e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  9.58557129e-02,   9.58557129e-02],
                        [  9.10949707e-02,   9.10949707e-02],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -6.30798340e-02,  -6.30798340e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -7.35778809e-02,  -7.35778809e-02],
                        [ -7.66601562e-02,  -7.66601562e-02],
                        [ -7.45544434e-02,  -7.45544434e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -6.70166016e-02,  -6.70166016e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  1.23870850e-01,   1.23870850e-01],
                        [  1.55761719e-01,   1.55761719e-01],
                        [  1.77703857e-01,   1.77703857e-01],
                        [  1.74499512e-01,   1.74499512e-01],
                        [  1.40045166e-01,   1.40045166e-01],
                        [  7.57141113e-02,   7.57141113e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -1.11999512e-01,  -1.11999512e-01],
                        [ -2.12402344e-01,  -2.12402344e-01],
                        [ -2.98980713e-01,  -2.98980713e-01],
                        [ -3.54095459e-01,  -3.54095459e-01],
                        [ -3.63891602e-01,  -3.63891602e-01],
                        [ -3.29650879e-01,  -3.29650879e-01],
                        [ -2.68798828e-01,  -2.68798828e-01],
                        [ -2.05444336e-01,  -2.05444336e-01],
                        [ -1.57196045e-01,  -1.57196045e-01],
                        [ -1.24877930e-01,  -1.24877930e-01],
                        [ -9.73205566e-02,  -9.73205566e-02],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  1.03729248e-01,   1.03729248e-01],
                        [  1.84478760e-01,   1.84478760e-01],
                        [  2.54272461e-01,   2.54272461e-01],
                        [  2.96264648e-01,   2.96264648e-01],
                        [  3.02795410e-01,   3.02795410e-01],
                        [  2.81768799e-01,   2.81768799e-01],
                        [  2.48046875e-01,   2.48046875e-01],
                        [  2.11151123e-01,   2.11151123e-01],
                        [  1.74774170e-01,   1.74774170e-01],
                        [  1.43005371e-01,   1.43005371e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  8.27331543e-02,   8.27331543e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -3.68652344e-02,  -3.68652344e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -7.25402832e-02,  -7.25402832e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.50115967e-01,   1.50115967e-01],
                        [  1.59698486e-01,   1.59698486e-01],
                        [  1.53167725e-01,   1.53167725e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -7.20214844e-02,  -7.20214844e-02],
                        [ -1.54846191e-01,  -1.54846191e-01],
                        [ -2.36175537e-01,  -2.36175537e-01],
                        [ -3.03649902e-01,  -3.03649902e-01],
                        [ -3.42285156e-01,  -3.42285156e-01],
                        [ -3.40576172e-01,  -3.40576172e-01],
                        [ -2.98889160e-01,  -2.98889160e-01],
                        [ -2.34985352e-01,  -2.34985352e-01],
                        [ -1.76208496e-01,  -1.76208496e-01],
                        [ -1.39068604e-01,  -1.39068604e-01],
                        [ -1.16577148e-01,  -1.16577148e-01],
                        [ -9.32312012e-02,  -9.32312012e-02],
                        [ -6.82373047e-02,  -6.82373047e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.68249512e-02,   2.68249512e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  1.08337402e-01,   1.08337402e-01],
                        [  1.84967041e-01,   1.84967041e-01],
                        [  2.51098633e-01,   2.51098633e-01],
                        [  2.91229248e-01,   2.91198730e-01],
                        [  3.01177979e-01,   3.01177979e-01],
                        [  2.85430908e-01,   2.85430908e-01],
                        [  2.52227783e-01,   2.52227783e-01],
                        [  2.12280273e-01,   2.12280273e-01],
                        [  1.75170898e-01,   1.75170898e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  7.01904297e-02,   7.01904297e-02],
                        [  5.48400879e-02,   5.48400879e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.39282227e-01,   1.39282227e-01],
                        [  1.41296387e-01,   1.41296387e-01],
                        [  1.25183105e-01,   1.25183105e-01],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -8.54187012e-02,  -8.54187012e-02],
                        [ -1.54846191e-01,  -1.54846191e-01],
                        [ -2.26562500e-01,  -2.26562500e-01],
                        [ -2.94250488e-01,  -2.94250488e-01],
                        [ -3.40026855e-01,  -3.40026855e-01],
                        [ -3.41339111e-01,  -3.41339111e-01],
                        [ -2.93090820e-01,  -2.93090820e-01],
                        [ -2.19726562e-01,  -2.19726562e-01],
                        [ -1.56555176e-01,  -1.56555176e-01],
                        [ -1.19018555e-01,  -1.19018555e-01],
                        [ -9.68627930e-02,  -9.68627930e-02],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  1.56585693e-01,   1.56585693e-01],
                        [  2.21984863e-01,   2.21984863e-01],
                        [  2.70690918e-01,   2.70690918e-01],
                        [  2.92297363e-01,   2.92297363e-01],
                        [  2.85247803e-01,   2.85247803e-01],
                        [  2.55889893e-01,   2.55889893e-01],
                        [  2.17376709e-01,   2.17376709e-01],
                        [  1.83013916e-01,   1.83013916e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.36993408e-01,   1.36993408e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  3.19519043e-02,   3.19824219e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -4.60815430e-02,  -4.60510254e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  8.82568359e-02,   8.82568359e-02],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  1.26251221e-01,   1.26251221e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.00341797e-01,   1.00341797e-01],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -9.08203125e-02,  -9.08203125e-02],
                        [ -1.24023438e-01,  -1.24023438e-01],
                        [ -1.82678223e-01,  -1.82678223e-01],
                        [ -2.61474609e-01,  -2.61474609e-01],
                        [ -3.21838379e-01,  -3.21838379e-01],
                        [ -3.25134277e-01,  -3.25134277e-01],
                        [ -2.70721436e-01,  -2.70721436e-01],
                        [ -1.94061279e-01,  -1.94061279e-01],
                        [ -1.33972168e-01,  -1.33972168e-01],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -7.93762207e-02,  -7.93762207e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  6.80541992e-03,   6.80541992e-03],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  6.47583008e-02,   6.47583008e-02],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  2.03582764e-01,   2.03582764e-01],
                        [  2.43957520e-01,   2.43957520e-01],
                        [  2.72399902e-01,   2.72399902e-01],
                        [  2.79357910e-01,   2.79357910e-01],
                        [  2.62207031e-01,   2.62207031e-01],
                        [  2.30590820e-01,   2.30590820e-01],
                        [  1.96868896e-01,   1.96868896e-01],
                        [  1.66259766e-01,   1.66259766e-01],
                        [  1.38702393e-01,   1.38702393e-01],
                        [  1.13464355e-01,   1.13464355e-01],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.22875977e-02,   3.22570801e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.97741699e-02,  -4.97741699e-02],
                        [ -5.65490723e-02,  -5.65490723e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.29174805e-02,  -5.29174805e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.91735840e-02,  -5.91735840e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  7.88879395e-02,   7.88879395e-02],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.19476318e-01,   1.19476318e-01],
                        [  1.06842041e-01,   1.06842041e-01],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -1.06719971e-01,  -1.06719971e-01],
                        [ -1.86706543e-01,  -1.86676025e-01],
                        [ -2.71270752e-01,  -2.71270752e-01],
                        [ -3.20983887e-01,  -3.20983887e-01],
                        [ -3.11431885e-01,  -3.11431885e-01],
                        [ -2.54150391e-01,  -2.54150391e-01],
                        [ -1.86218262e-01,  -1.86218262e-01],
                        [ -1.37695312e-01,  -1.37695312e-01],
                        [ -1.11846924e-01,  -1.11846924e-01],
                        [ -9.40551758e-02,  -9.40551758e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  1.39617920e-01,   1.39617920e-01],
                        [  1.79809570e-01,   1.79809570e-01],
                        [  2.19451904e-01,   2.19451904e-01],
                        [  2.55157471e-01,   2.55157471e-01],
                        [  2.75482178e-01,   2.75482178e-01],
                        [  2.66571045e-01,   2.66571045e-01],
                        [  2.30682373e-01,   2.30682373e-01],
                        [  1.88293457e-01,   1.88293457e-01],
                        [  1.56402588e-01,   1.56402588e-01],
                        [  1.34704590e-01,   1.34704590e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -6.30798340e-02,  -6.30798340e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -7.01293945e-02,  -7.01293945e-02],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.41076660e-02,  -5.41076660e-02],
                        [ -6.15234375e-02,  -6.15234375e-02],
                        [ -6.71691895e-02,  -6.71386719e-02],
                        [ -6.58569336e-02,  -6.58569336e-02],
                        [ -5.91430664e-02,  -5.91430664e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  8.79516602e-02,   8.79516602e-02],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -1.06842041e-01,  -1.06842041e-01],
                        [ -1.83074951e-01,  -1.83074951e-01],
                        [ -2.55737305e-01,  -2.55737305e-01],
                        [ -2.91473389e-01,  -2.91473389e-01],
                        [ -2.76794434e-01,  -2.76794434e-01],
                        [ -2.26531982e-01,  -2.26531982e-01],
                        [ -1.71081543e-01,  -1.71081543e-01],
                        [ -1.33270264e-01,  -1.33239746e-01],
                        [ -1.13189697e-01,  -1.13189697e-01],
                        [ -9.49096680e-02,  -9.49096680e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  9.03015137e-02,   9.03015137e-02],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.54296875e-01,   1.54296875e-01],
                        [  1.89697266e-01,   1.89697266e-01],
                        [  2.28973389e-01,   2.28973389e-01],
                        [  2.55950928e-01,   2.55950928e-01],
                        [  2.57843018e-01,   2.57843018e-01],
                        [  2.36450195e-01,   2.36450195e-01],
                        [  2.04742432e-01,   2.04742432e-01],
                        [  1.72973633e-01,   1.72973633e-01],
                        [  1.43829346e-01,   1.43829346e-01],
                        [  1.18438721e-01,   1.18438721e-01],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -6.93664551e-02,  -6.93664551e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -7.68127441e-02,  -7.68127441e-02],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -6.70471191e-02,  -6.70471191e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  6.74438477e-03,   6.77490234e-03],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  9.12780762e-02,   9.12780762e-02],
                        [  1.01287842e-01,   1.01287842e-01],
                        [  9.63745117e-02,   9.63745117e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [ -8.05664062e-03,  -8.02612305e-03],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -1.59454346e-01,  -1.59454346e-01],
                        [ -2.46795654e-01,  -2.46795654e-01],
                        [ -2.98522949e-01,  -2.98522949e-01],
                        [ -2.94830322e-01,  -2.94830322e-01],
                        [ -2.44659424e-01,  -2.44659424e-01],
                        [ -1.78405762e-01,  -1.78405762e-01],
                        [ -1.23352051e-01,  -1.23352051e-01],
                        [ -8.79211426e-02,  -8.79211426e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  7.05566406e-02,   7.05566406e-02],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  1.09924316e-01,   1.09924316e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.71600342e-01,   1.71600342e-01],
                        [  2.09106445e-01,   2.09106445e-01],
                        [  2.29644775e-01,   2.29644775e-01],
                        [  2.21954346e-01,   2.21954346e-01],
                        [  1.92962646e-01,   1.92962646e-01],
                        [  1.60186768e-01,   1.60186768e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.29730225e-01,   1.29730225e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.15661621e-02,   1.15966797e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -6.20117188e-02,  -6.20117188e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -4.76379395e-02,  -4.76684570e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  9.92431641e-02,   9.92431641e-02],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -8.88366699e-02,  -8.88366699e-02],
                        [ -1.02172852e-01,  -1.02172852e-01],
                        [ -7.62023926e-02,  -7.62023926e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  1.58996582e-02,   1.58996582e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -1.43157959e-01,  -1.43157959e-01],
                        [ -2.15759277e-01,  -2.15759277e-01],
                        [ -2.63732910e-01,  -2.63732910e-01],
                        [ -2.67822266e-01,  -2.67822266e-01],
                        [ -2.29705811e-01,  -2.29705811e-01],
                        [ -1.73370361e-01,  -1.73370361e-01],
                        [ -1.24420166e-01,  -1.24420166e-01],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -7.02514648e-02,  -7.02514648e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -1.75781250e-02,  -1.75476074e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.96838379e-02,   1.96533203e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  1.62506104e-01,   1.62506104e-01],
                        [  2.00897217e-01,   2.00897217e-01],
                        [  2.30926514e-01,   2.30926514e-01],
                        [  2.40051270e-01,   2.40051270e-01],
                        [  2.25830078e-01,   2.25830078e-01],
                        [  1.95037842e-01,   1.95037842e-01],
                        [  1.60675049e-01,   1.60644531e-01],
                        [  1.33941650e-01,   1.33941650e-01],
                        [  1.15356445e-01,   1.15356445e-01],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  8.13293457e-02,   8.13293457e-02],
                        [  6.98242188e-02,   6.98242188e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  5.37414551e-02,   5.37414551e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  8.92028809e-02,   8.91723633e-02],
                        [  5.65185547e-02,   5.65185547e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -8.74328613e-02,  -8.74328613e-02],
                        [ -9.35668945e-02,  -9.35668945e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -1.02264404e-01,  -1.02264404e-01],
                        [ -1.90185547e-01,  -1.90185547e-01],
                        [ -2.66357422e-01,  -2.66357422e-01],
                        [ -2.99072266e-01,  -2.99072266e-01],
                        [ -2.74261475e-01,  -2.74261475e-01],
                        [ -2.10113525e-01,  -2.10113525e-01],
                        [ -1.41296387e-01,  -1.41296387e-01],
                        [ -9.39025879e-02,  -9.39025879e-02],
                        [ -7.26623535e-02,  -7.26623535e-02],
                        [ -6.41174316e-02,  -6.41479492e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  7.26928711e-02,   7.26928711e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  1.18408203e-01,   1.18408203e-01],
                        [  1.64459229e-01,   1.64459229e-01],
                        [  2.12463379e-01,   2.12463379e-01],
                        [  2.45727539e-01,   2.45727539e-01],
                        [  2.50671387e-01,   2.50671387e-01],
                        [  2.29187012e-01,   2.29187012e-01],
                        [  1.96044922e-01,   1.96044922e-01],
                        [  1.64947510e-01,   1.64947510e-01],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.73828125e-02,  -6.73828125e-02],
                        [ -6.93359375e-02,  -6.93359375e-02],
                        [ -7.03430176e-02,  -7.03430176e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -7.45239258e-02,  -7.45239258e-02],
                        [ -7.06787109e-02,  -7.06481934e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  7.17773438e-02,   7.17773438e-02],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  9.01184082e-02,   9.01184082e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -1.15631104e-01,  -1.15631104e-01],
                        [ -1.10565186e-01,  -1.10565186e-01],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -1.03393555e-01,  -1.03393555e-01],
                        [ -1.82189941e-01,  -1.82189941e-01],
                        [ -2.44934082e-01,  -2.44934082e-01],
                        [ -2.65472412e-01,  -2.65472412e-01],
                        [ -2.37365723e-01,  -2.37396240e-01],
                        [ -1.81274414e-01,  -1.81274414e-01],
                        [ -1.26892090e-01,  -1.26892090e-01],
                        [ -9.20715332e-02,  -9.20715332e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -6.55212402e-02,  -6.55212402e-02],
                        [ -4.91638184e-02,  -4.91333008e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  3.30810547e-02,   3.31115723e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  7.28454590e-02,   7.28454590e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.06536865e-01,   1.06536865e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  9.68017578e-02,   9.68322754e-02],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.82586670e-01,   1.82586670e-01],
                        [  2.18658447e-01,   2.18658447e-01],
                        [  2.30438232e-01,   2.30438232e-01],
                        [  2.17987061e-01,   2.17987061e-01],
                        [  1.90399170e-01,   1.90399170e-01],
                        [  1.58538818e-01,   1.58538818e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.12579346e-01,   1.12579346e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  7.59277344e-02,   7.58972168e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.72607422e-02,  -6.72607422e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -6.82067871e-02,  -6.81762695e-02],
                        [ -6.53686523e-02,  -6.53686523e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -5.91735840e-02,  -5.91735840e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  7.99865723e-02,   7.99865723e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -1.24023438e-01,  -1.24023438e-01],
                        [ -1.05804443e-01,  -1.05804443e-01],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -1.33575439e-01,  -1.33575439e-01],
                        [ -2.19970703e-01,  -2.19970703e-01],
                        [ -2.74993896e-01,  -2.74993896e-01],
                        [ -2.74810791e-01,  -2.74810791e-01],
                        [ -2.25708008e-01,  -2.25708008e-01],
                        [ -1.56341553e-01,  -1.56341553e-01],
                        [ -9.72900391e-02,  -9.72900391e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.62145996e-02,   2.61840820e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  5.92346191e-02,   5.92346191e-02],
                        [  9.73510742e-02,   9.73510742e-02],
                        [  1.27502441e-01,   1.27502441e-01],
                        [  1.37664795e-01,   1.37664795e-01],
                        [  1.25061035e-01,   1.25061035e-01],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  1.45935059e-01,   1.45935059e-01],
                        [  1.88537598e-01,   1.88537598e-01],
                        [  2.19665527e-01,   2.19665527e-01],
                        [  2.30743408e-01,   2.30743408e-01],
                        [  2.16827393e-01,   2.16827393e-01],
                        [  1.85333252e-01,   1.85333252e-01],
                        [  1.51458740e-01,   1.51458740e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  7.66296387e-02,   7.66296387e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -7.83081055e-02,  -7.83081055e-02],
                        [ -7.35778809e-02,  -7.35778809e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -5.19714355e-02,  -5.19714355e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -5.12390137e-02,  -5.12084961e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  7.74536133e-02,   7.74536133e-02],
                        [  9.03625488e-02,   9.03320312e-02],
                        [  9.82666016e-02,   9.82666016e-02],
                        [  9.93347168e-02,   9.93347168e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -1.01196289e-01,  -1.01196289e-01],
                        [ -1.45996094e-01,  -1.45996094e-01],
                        [ -1.46057129e-01,  -1.46057129e-01],
                        [ -1.02691650e-01,  -1.02691650e-01],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -1.76239014e-01,  -1.76239014e-01],
                        [ -2.48687744e-01,  -2.48687744e-01],
                        [ -2.74261475e-01,  -2.74261475e-01],
                        [ -2.44293213e-01,  -2.44293213e-01],
                        [ -1.80572510e-01,  -1.80572510e-01],
                        [ -1.21063232e-01,  -1.21063232e-01],
                        [ -8.94165039e-02,  -8.94165039e-02],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -7.33032227e-02,  -7.33032227e-02],
                        [ -5.91735840e-02,  -5.91735840e-02],
                        [ -4.33959961e-02,  -4.34265137e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [  5.49316406e-03,   5.52368164e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  1.02294922e-01,   1.02294922e-01],
                        [  1.29425049e-01,   1.29425049e-01],
                        [  1.38732910e-01,   1.38732910e-01],
                        [  1.25671387e-01,   1.25671387e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  7.37915039e-02,   7.37915039e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  7.01293945e-02,   7.01293945e-02],
                        [  9.87548828e-02,   9.87548828e-02],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  1.86340332e-01,   1.86340332e-01],
                        [  2.18048096e-01,   2.18048096e-01],
                        [  2.28179932e-01,   2.28179932e-01],
                        [  2.13867188e-01,   2.13867188e-01],
                        [  1.80145264e-01,   1.80145264e-01],
                        [  1.41754150e-01,   1.41754150e-01],
                        [  1.13861084e-01,   1.13861084e-01],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  7.86437988e-02,   7.86437988e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  6.65283203e-02,   6.65283203e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  3.99780273e-03,   3.99780273e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -5.90515137e-02,  -5.90820312e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  6.95495605e-02,   6.95495605e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -9.51843262e-02,  -9.51843262e-02],
                        [ -1.39923096e-01,  -1.39923096e-01],
                        [ -1.45385742e-01,  -1.45385742e-01],
                        [ -1.06445312e-01,  -1.06445312e-01],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  5.90209961e-02,   5.90515137e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -1.35772705e-01,  -1.35772705e-01],
                        [ -2.24548340e-01,  -2.24548340e-01],
                        [ -2.73101807e-01,  -2.73101807e-01],
                        [ -2.64587402e-01,  -2.64587402e-01],
                        [ -2.12066650e-01,  -2.12066650e-01],
                        [ -1.48529053e-01,  -1.48529053e-01],
                        [ -1.02539062e-01,  -1.02539062e-01],
                        [ -8.04443359e-02,  -8.04443359e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  8.11767578e-02,   8.11767578e-02],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.31011963e-01,   1.31011963e-01],
                        [  1.30187988e-01,   1.30187988e-01],
                        [  1.09680176e-01,   1.09680176e-01],
                        [  7.97119141e-02,   7.97119141e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  1.43188477e-01,   1.43188477e-01],
                        [  1.86737061e-01,   1.86737061e-01],
                        [  2.20123291e-01,   2.20123291e-01],
                        [  2.32147217e-01,   2.32147217e-01],
                        [  2.18078613e-01,   2.18078613e-01],
                        [  1.85302734e-01,   1.85302734e-01],
                        [  1.49261475e-01,   1.49261475e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -7.02514648e-02,  -7.02514648e-02],
                        [ -7.21130371e-02,  -7.21130371e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -6.72607422e-02,  -6.72607422e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -1.25213623e-01,  -1.25213623e-01],
                        [ -1.65557861e-01,  -1.65557861e-01],
                        [ -1.61132812e-01,  -1.61132812e-01],
                        [ -1.14105225e-01,  -1.14105225e-01],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -1.26678467e-01,  -1.26678467e-01],
                        [ -2.10876465e-01,  -2.10876465e-01],
                        [ -2.58026123e-01,  -2.58026123e-01],
                        [ -2.51831055e-01,  -2.51831055e-01],
                        [ -2.02392578e-01,  -2.02392578e-01],
                        [ -1.41784668e-01,  -1.41784668e-01],
                        [ -9.91210938e-02,  -9.91210938e-02],
                        [ -7.99865723e-02,  -7.99865723e-02],
                        [ -7.31201172e-02,  -7.31201172e-02],
                        [ -6.88781738e-02,  -6.88781738e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  3.18908691e-02,   3.18603516e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  1.23046875e-01,   1.23046875e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  1.38061523e-01,   1.38061523e-01],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  5.44738770e-02,   5.44738770e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.68975830e-01,   1.68975830e-01],
                        [  2.11578369e-01,   2.11578369e-01],
                        [  2.31811523e-01,   2.31811523e-01],
                        [  2.23815918e-01,   2.23815918e-01],
                        [  1.93634033e-01,   1.93634033e-01],
                        [  1.54815674e-01,   1.54815674e-01],
                        [  1.20941162e-01,   1.20941162e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -6.66809082e-02,  -6.66809082e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -4.74853516e-02,  -4.74853516e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -7.51342773e-02,  -7.51342773e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  6.45751953e-02,   6.45751953e-02],
                        [  7.01599121e-02,   7.01599121e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -1.19659424e-01,  -1.19659424e-01],
                        [ -1.54998779e-01,  -1.54998779e-01],
                        [ -1.47857666e-01,  -1.47857666e-01],
                        [ -1.08062744e-01,  -1.08062744e-01],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -1.40869141e-01,  -1.40869141e-01],
                        [ -2.19207764e-01,  -2.19207764e-01],
                        [ -2.55889893e-01,  -2.55889893e-01],
                        [ -2.42279053e-01,  -2.42279053e-01],
                        [ -1.93695068e-01,  -1.93695068e-01],
                        [ -1.35375977e-01,  -1.35375977e-01],
                        [ -8.99963379e-02,  -8.99963379e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  9.42687988e-02,   9.42687988e-02],
                        [  1.26525879e-01,   1.26525879e-01],
                        [  1.46545410e-01,   1.46545410e-01],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  1.26495361e-01,   1.26495361e-01],
                        [  9.67102051e-02,   9.67102051e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  6.98242188e-02,   6.98242188e-02],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  1.36505127e-01,   1.36505127e-01],
                        [  1.76452637e-01,   1.76452637e-01],
                        [  2.03216553e-01,   2.03216553e-01],
                        [  2.09442139e-01,   2.09442139e-01],
                        [  1.94610596e-01,   1.94610596e-01],
                        [  1.66687012e-01,   1.66687012e-01],
                        [  1.39709473e-01,   1.39709473e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.91442871e-02,  -2.91137695e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -7.01599121e-02,  -7.01599121e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.56127930e-02,  -6.56127930e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -6.68945312e-02,  -6.68945312e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  8.41979980e-02,   8.41979980e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -1.08673096e-01,  -1.08673096e-01],
                        [ -1.65771484e-01,  -1.65771484e-01],
                        [ -1.77825928e-01,  -1.77825928e-01],
                        [ -1.44531250e-01,  -1.44531250e-01],
                        [ -8.58154297e-02,  -8.58154297e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -1.96411133e-01,  -1.96411133e-01],
                        [ -2.58728027e-01,  -2.58728027e-01],
                        [ -2.71972656e-01,  -2.71972656e-01],
                        [ -2.36175537e-01,  -2.36175537e-01],
                        [ -1.74407959e-01,  -1.74407959e-01],
                        [ -1.17431641e-01,  -1.17431641e-01],
                        [ -8.31298828e-02,  -8.31298828e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.28875732e-01,   1.28875732e-01],
                        [  1.47552490e-01,   1.47552490e-01],
                        [  1.42364502e-01,   1.42364502e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  8.31298828e-02,   8.31298828e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  1.59454346e-01,   1.59454346e-01],
                        [  2.01202393e-01,   2.01202393e-01],
                        [  2.22290039e-01,   2.22290039e-01],
                        [  2.17559814e-01,   2.17559814e-01],
                        [  1.93084717e-01,   1.93084717e-01],
                        [  1.61712646e-01,   1.61712646e-01],
                        [  1.34155273e-01,   1.34155273e-01],
                        [  1.13433838e-01,   1.13433838e-01],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -7.39746094e-02,  -7.39746094e-02],
                        [ -7.17773438e-02,  -7.17773438e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  4.11682129e-02,   4.11682129e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -1.56677246e-01,  -1.56677246e-01],
                        [ -1.86950684e-01,  -1.86950684e-01],
                        [ -1.68060303e-01,  -1.68060303e-01],
                        [ -1.11083984e-01,  -1.11083984e-01],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -1.40777588e-01,  -1.40777588e-01],
                        [ -2.25891113e-01,  -2.25891113e-01],
                        [ -2.67608643e-01,  -2.67608643e-01],
                        [ -2.56561279e-01,  -2.56561279e-01],
                        [ -2.06726074e-01,  -2.06726074e-01],
                        [ -1.45721436e-01,  -1.45721436e-01],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  5.32531738e-02,   5.32531738e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  1.04949951e-01,   1.04949951e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.31469727e-01,   1.31469727e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.02752686e-01,   1.02752686e-01],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  6.79626465e-02,   6.79626465e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  2.27569580e-01,   2.27569580e-01],
                        [  2.34313965e-01,   2.34313965e-01],
                        [  2.11059570e-01,   2.11059570e-01],
                        [  1.74713135e-01,   1.74713135e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.20483398e-01,   1.20483398e-01],
                        [  1.02966309e-01,   1.02966309e-01],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  6.78710938e-02,   6.78710938e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.50842285e-02,  -5.50842285e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  6.90307617e-02,   6.90307617e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -1.20391846e-01,  -1.20391846e-01],
                        [ -1.57073975e-01,  -1.57073975e-01],
                        [ -1.60339355e-01,  -1.60339355e-01],
                        [ -1.30798340e-01,  -1.30798340e-01],
                        [ -8.08105469e-02,  -8.08105469e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -1.44195557e-01,  -1.44195557e-01],
                        [ -2.13073730e-01,  -2.13073730e-01],
                        [ -2.44140625e-01,  -2.44140625e-01],
                        [ -2.28149414e-01,  -2.28149414e-01],
                        [ -1.78497314e-01,  -1.78497314e-01],
                        [ -1.24206543e-01,  -1.24206543e-01],
                        [ -8.85925293e-02,  -8.85925293e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  1.17584229e-01,   1.17584229e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.22314453e-01,   1.22314453e-01],
                        [  1.13037109e-01,   1.13037109e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  8.20617676e-02,   8.20617676e-02],
                        [  6.84814453e-02,   6.84814453e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  5.92651367e-02,   5.92651367e-02],
                        [  7.57751465e-02,   7.57751465e-02],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.56127930e-01,   1.56127930e-01],
                        [  1.95007324e-01,   1.95007324e-01],
                        [  2.15576172e-01,   2.15576172e-01],
                        [  2.12432861e-01,   2.12432861e-01],
                        [  1.88842773e-01,   1.88842773e-01],
                        [  1.54449463e-01,   1.54449463e-01],
                        [  1.19873047e-01,   1.19873047e-01],
                        [  9.35363770e-02,   9.35363770e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  6.75048828e-02,   6.75048828e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -6.70166016e-02,  -6.70166016e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -5.92041016e-02,  -5.92041016e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  5.88378906e-02,   5.88378906e-02],
                        [  7.37915039e-02,   7.37915039e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -5.63964844e-02,  -5.63964844e-02],
                        [ -1.23687744e-01,  -1.23687744e-01],
                        [ -1.67419434e-01,  -1.67419434e-01],
                        [ -1.71234131e-01,  -1.71234131e-01],
                        [ -1.39282227e-01,  -1.39282227e-01],
                        [ -9.21936035e-02,  -9.21936035e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  5.29785156e-02,   5.29785156e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  7.88574219e-02,   7.88574219e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -1.53015137e-01,  -1.53015137e-01],
                        [ -2.23480225e-01,  -2.23480225e-01],
                        [ -2.45666504e-01,  -2.45666504e-01],
                        [ -2.16613770e-01,  -2.16613770e-01],
                        [ -1.58782959e-01,  -1.58782959e-01],
                        [ -1.04888916e-01,  -1.04888916e-01],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -6.93664551e-02,  -6.93664551e-02],
                        [ -6.92749023e-02,  -6.92749023e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  9.41772461e-02,   9.41772461e-02],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.43798828e-01,   1.43798828e-01],
                        [  1.39465332e-01,   1.39465332e-01],
                        [  1.20971680e-01,   1.20971680e-01],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.51367188e-01,   1.51367188e-01],
                        [  1.94732666e-01,   1.94732666e-01],
                        [  2.13226318e-01,   2.13226318e-01],
                        [  2.03948975e-01,   2.03948975e-01],
                        [  1.76635742e-01,   1.76635742e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -1.29760742e-01,  -1.29760742e-01],
                        [ -1.83288574e-01,  -1.83288574e-01],
                        [ -1.97845459e-01,  -1.97845459e-01],
                        [ -1.68151855e-01,  -1.68151855e-01],
                        [ -1.12030029e-01,  -1.12030029e-01],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -1.41052246e-01,  -1.41052246e-01],
                        [ -2.01416016e-01,  -2.01416016e-01],
                        [ -2.23907471e-01,  -2.23907471e-01],
                        [ -2.03369141e-01,  -2.03369141e-01],
                        [ -1.57623291e-01,  -1.57623291e-01],
                        [ -1.14837646e-01,  -1.14837646e-01],
                        [ -9.03930664e-02,  -9.03930664e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.46026611e-01,   1.46026611e-01],
                        [  1.49963379e-01,   1.49963379e-01],
                        [  1.37969971e-01,   1.37969971e-01],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  1.35620117e-01,   1.35620117e-01],
                        [  1.80175781e-01,   1.80175781e-01],
                        [  2.07519531e-01,   2.07519531e-01],
                        [  2.10235596e-01,   2.10235596e-01],
                        [  1.87530518e-01,   1.87530518e-01],
                        [  1.49047852e-01,   1.49047852e-01],
                        [  1.13433838e-01,   1.13433838e-01],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  8.77380371e-02,   8.77380371e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -7.13500977e-02,  -7.13500977e-02],
                        [ -7.19909668e-02,  -7.19909668e-02],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -5.60302734e-02,  -5.60302734e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  3.51562500e-02,   3.51562500e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  7.16247559e-02,   7.16247559e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -1.24389648e-01,  -1.24389648e-01],
                        [ -1.84722900e-01,  -1.84722900e-01],
                        [ -2.10723877e-01,  -2.10723877e-01],
                        [ -1.89056396e-01,  -1.89056396e-01],
                        [ -1.32324219e-01,  -1.32324219e-01],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [ -6.79931641e-02,  -6.79931641e-02],
                        [ -1.45172119e-01,  -1.45172119e-01],
                        [ -2.03399658e-01,  -2.03399658e-01],
                        [ -2.22259521e-01,  -2.22259521e-01],
                        [ -1.97784424e-01,  -1.97784424e-01],
                        [ -1.50146484e-01,  -1.50146484e-01],
                        [ -1.07757568e-01,  -1.07757568e-01],
                        [ -8.30078125e-02,  -8.30078125e-02],
                        [ -6.88781738e-02,  -6.88781738e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  8.00476074e-02,   8.00476074e-02],
                        [  1.06079102e-01,   1.06079102e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.44531250e-01,   1.44531250e-01],
                        [  1.40197754e-01,   1.40197754e-01],
                        [  1.26220703e-01,   1.26220703e-01],
                        [  1.09924316e-01,   1.09924316e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  4.37316895e-02,   4.37316895e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  8.86535645e-02,   8.86535645e-02],
                        [  1.25915527e-01,   1.25915527e-01],
                        [  1.64611816e-01,   1.64611816e-01],
                        [  1.89666748e-01,   1.89666748e-01],
                        [  1.89758301e-01,   1.89758301e-01],
                        [  1.67602539e-01,   1.67602539e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.16943359e-01,   1.16943359e-01],
                        [  1.06750488e-01,   1.06750488e-01],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  8.61206055e-02,   8.61206055e-02],
                        [  6.75048828e-02,   6.75048828e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.60302734e-02,  -5.60302734e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  4.49829102e-02,   4.49829102e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -1.30249023e-01,  -1.30249023e-01],
                        [ -1.90216064e-01,  -1.90216064e-01],
                        [ -2.14294434e-01,  -2.14294434e-01],
                        [ -1.98333740e-01,  -1.98333740e-01],
                        [ -1.55456543e-01,  -1.55456543e-01],
                        [ -1.02691650e-01,  -1.02691650e-01],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  9.33227539e-02,   9.33227539e-02],
                        [  9.78393555e-02,   9.78393555e-02],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -1.94641113e-01,  -1.94641113e-01],
                        [ -2.32147217e-01,  -2.32147217e-01],
                        [ -2.22137451e-01,  -2.22137451e-01],
                        [ -1.81060791e-01,  -1.81060791e-01],
                        [ -1.32934570e-01,  -1.32934570e-01],
                        [ -9.48486328e-02,  -9.48486328e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.21582031e-01,   1.21582031e-01],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  1.45629883e-01,   1.45629883e-01],
                        [  1.85241699e-01,   1.85241699e-01],
                        [  2.02270508e-01,   2.02270508e-01],
                        [  1.89514160e-01,   1.89514160e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.25793457e-01,   1.25793457e-01],
                        [  1.05072021e-01,   1.05072021e-01],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  8.15429688e-02,   8.15429688e-02],
                        [  7.65686035e-02,   7.65686035e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.54406738e-02,  -4.54406738e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -5.95092773e-02,  -5.95092773e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -1.17492676e-01,  -1.17492676e-01],
                        [ -1.83349609e-01,  -1.83349609e-01],
                        [ -2.11151123e-01,  -2.11151123e-01],
                        [ -1.95739746e-01,  -1.95739746e-01],
                        [ -1.55487061e-01,  -1.55487061e-01],
                        [ -1.14593506e-01,  -1.14593506e-01],
                        [ -8.32824707e-02,  -8.32824707e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  7.76977539e-02,   7.76977539e-02],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -1.37023926e-01,  -1.37023926e-01],
                        [ -2.05108643e-01,  -2.05108643e-01],
                        [ -2.30865479e-01,  -2.30865479e-01],
                        [ -2.11944580e-01,  -2.11944580e-01],
                        [ -1.64459229e-01,  -1.64459229e-01],
                        [ -1.15295410e-01,  -1.15295410e-01],
                        [ -8.48693848e-02,  -8.48693848e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  1.18347168e-01,   1.18347168e-01],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  1.02050781e-01,   1.02050781e-01],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  1.10656738e-01,   1.10656738e-01],
                        [  1.48986816e-01,   1.48986816e-01],
                        [  1.80999756e-01,   1.80999756e-01],
                        [  1.92962646e-01,   1.92962646e-01],
                        [  1.76788330e-01,   1.76788330e-01],
                        [  1.42822266e-01,   1.42822266e-01],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -6.40869141e-02,  -6.40869141e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -8.20312500e-02,  -8.20312500e-02],
                        [ -1.37878418e-01,  -1.37878418e-01],
                        [ -1.70959473e-01,  -1.70959473e-01],
                        [ -1.75811768e-01,  -1.75811768e-01],
                        [ -1.58172607e-01,  -1.58172607e-01],
                        [ -1.28540039e-01,  -1.28540039e-01],
                        [ -9.85107422e-02,  -9.85107422e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  8.19702148e-02,   8.19702148e-02],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -1.26403809e-01,  -1.26403809e-01],
                        [ -2.04742432e-01,  -2.04742432e-01],
                        [ -2.34771729e-01,  -2.34771729e-01],
                        [ -2.13104248e-01,  -2.13104248e-01],
                        [ -1.62475586e-01,  -1.62475586e-01],
                        [ -1.13159180e-01,  -1.13159180e-01],
                        [ -8.17871094e-02,  -8.17871094e-02],
                        [ -6.45751953e-02,  -6.45751953e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  5.41076660e-02,   5.41076660e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  1.43615723e-01,   1.43615723e-01],
                        [  1.51062012e-01,   1.51062012e-01],
                        [  1.37542725e-01,   1.37542725e-01],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.80541992e-02,   6.80541992e-02],
                        [  5.21240234e-02,   5.21240234e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  8.30078125e-02,   8.30078125e-02],
                        [  1.25335693e-01,   1.25335693e-01],
                        [  1.64184570e-01,   1.64184570e-01],
                        [  1.81762695e-01,   1.81762695e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  1.45629883e-01,   1.45629883e-01],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  6.57043457e-02,   6.57043457e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -7.01599121e-02,  -7.01599121e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -7.05871582e-02,  -7.05871582e-02],
                        [ -6.75354004e-02,  -6.75354004e-02],
                        [ -6.38732910e-02,  -6.38732910e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [  1.61743164e-03,   1.61743164e-03],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  4.69970703e-03,   4.69970703e-03],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -1.19140625e-01,  -1.19140625e-01],
                        [ -1.71844482e-01,  -1.71844482e-01],
                        [ -1.98883057e-01,  -1.98883057e-01],
                        [ -1.91528320e-01,  -1.91528320e-01],
                        [ -1.54174805e-01,  -1.54174805e-01],
                        [ -1.07727051e-01,  -1.07727051e-01],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  8.66699219e-02,   8.66699219e-02],
                        [  1.15570068e-01,   1.15570068e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -1.84753418e-01,  -1.84753418e-01],
                        [ -2.44598389e-01,  -2.44598389e-01],
                        [ -2.45391846e-01,  -2.45391846e-01],
                        [ -1.95922852e-01,  -1.95922852e-01],
                        [ -1.28509521e-01,  -1.28509521e-01],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.18908691e-02,   3.18908691e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  1.45263672e-01,   1.45263672e-01],
                        [  1.43035889e-01,   1.43035889e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.18133545e-01,   1.18133545e-01],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  9.06372070e-02,   9.06372070e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  1.15631104e-01,   1.15631104e-01],
                        [  1.53106689e-01,   1.53106689e-01],
                        [  1.72454834e-01,   1.72454834e-01],
                        [  1.68518066e-01,   1.68518066e-01],
                        [  1.49505615e-01,   1.49505615e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  6.73522949e-02,   6.73522949e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -1.03027344e-01,  -1.03027344e-01],
                        [ -1.77856445e-01,  -1.77856445e-01],
                        [ -2.25585938e-01,  -2.25585938e-01],
                        [ -2.29431152e-01,  -2.29431152e-01],
                        [ -1.92840576e-01,  -1.92840576e-01],
                        [ -1.39343262e-01,  -1.39343262e-01],
                        [ -9.53979492e-02,  -9.53979492e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [  9.76562500e-04,   9.76562500e-04],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  1.36260986e-01,   1.36260986e-01],
                        [  1.42120361e-01,   1.42120361e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  3.88488770e-02,   3.88488770e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -1.55273438e-01,  -1.55273438e-01],
                        [ -2.21618652e-01,  -2.21618652e-01],
                        [ -2.37854004e-01,  -2.37854004e-01],
                        [ -2.09289551e-01,  -2.09289551e-01],
                        [ -1.60400391e-01,  -1.60400391e-01],
                        [ -1.16546631e-01,  -1.16546631e-01],
                        [ -8.94470215e-02,  -8.94470215e-02],
                        [ -7.31201172e-02,  -7.31201172e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  1.22711182e-01,   1.22711182e-01],
                        [  1.47399902e-01,   1.47399902e-01],
                        [  1.50787354e-01,   1.50787354e-01],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  9.82971191e-02,   9.82971191e-02],
                        [  9.37194824e-02,   9.37194824e-02],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  9.39941406e-02,   9.39941406e-02],
                        [  8.40148926e-02,   8.40148926e-02],
                        [  6.84814453e-02,   6.84814453e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  1.36352539e-01,   1.36352539e-01],
                        [  1.79901123e-01,   1.79901123e-01],
                        [  1.95800781e-01,   1.95800781e-01],
                        [  1.78741455e-01,   1.78741455e-01],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  1.07208252e-01,   1.07208252e-01],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  4.42199707e-02,   4.42199707e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.44335938e-02,  -4.44641113e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -3.43017578e-02,  -3.42712402e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  3.18908691e-02,   3.18908691e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -6.84204102e-02,  -6.84204102e-02],
                        [ -1.38610840e-01,  -1.38610840e-01],
                        [ -1.96838379e-01,  -1.96838379e-01],
                        [ -2.23327637e-01,  -2.23327637e-01],
                        [ -2.09289551e-01,  -2.09289551e-01],
                        [ -1.68395996e-01,  -1.68395996e-01],
                        [ -1.27593994e-01,  -1.27593994e-01],
                        [ -1.03363037e-01,  -1.03363037e-01],
                        [ -9.26513672e-02,  -9.26513672e-02],
                        [ -8.34350586e-02,  -8.34350586e-02],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  6.42089844e-02,   6.42089844e-02],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  1.54663086e-01,   1.54663086e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  4.49218750e-02,   4.49218750e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -1.59362793e-01,  -1.59362793e-01],
                        [ -2.35961914e-01,  -2.35961914e-01],
                        [ -2.58728027e-01,  -2.58728027e-01],
                        [ -2.26654053e-01,  -2.26654053e-01],
                        [ -1.65100098e-01,  -1.65100098e-01],
                        [ -1.08703613e-01,  -1.08703613e-01],
                        [ -7.57141113e-02,  -7.57141113e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  3.69567871e-02,   3.69567871e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.42333984e-01,   1.42333984e-01],
                        [  1.31744385e-01,   1.31744385e-01],
                        [  1.13647461e-01,   1.13647461e-01],
                        [  1.02539062e-01,   1.02539062e-01],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  8.35876465e-02,   8.35876465e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.48071289e-01,   1.48071289e-01],
                        [  1.66717529e-01,   1.66717529e-01],
                        [  1.61895752e-01,   1.61895752e-01],
                        [  1.38824463e-01,   1.38824463e-01],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  8.59069824e-02,   8.59069824e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -8.15429688e-02,  -8.15429688e-02],
                        [ -8.29467773e-02,  -8.29467773e-02],
                        [ -7.63854980e-02,  -7.63854980e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  6.94580078e-02,   6.94580078e-02],
                        [  5.12695312e-02,   5.13000488e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [ -7.12280273e-02,  -7.12280273e-02],
                        [ -1.55975342e-01,  -1.55975342e-01],
                        [ -2.20001221e-01,  -2.19970703e-01],
                        [ -2.43713379e-01,  -2.43713379e-01],
                        [ -2.26074219e-01,  -2.26074219e-01],
                        [ -1.81427002e-01,  -1.81427002e-01],
                        [ -1.30920410e-01,  -1.30920410e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  4.94384766e-02,   4.94384766e-02],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.56036377e-01,   1.56036377e-01],
                        [  1.65435791e-01,   1.65435791e-01],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  6.53991699e-02,   6.53991699e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -1.49291992e-01,  -1.49261475e-01],
                        [ -2.25616455e-01,  -2.25616455e-01],
                        [ -2.49969482e-01,  -2.49969482e-01],
                        [ -2.22839355e-01,  -2.22839355e-01],
                        [ -1.66351318e-01,  -1.66351318e-01],
                        [ -1.10839844e-01,  -1.10839844e-01],
                        [ -7.48596191e-02,  -7.48596191e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.45843506e-01,   1.45843506e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  1.08276367e-01,   1.08276367e-01],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  3.50952148e-03,   3.50952148e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  1.33239746e-01,   1.33239746e-01],
                        [  1.57562256e-01,   1.57562256e-01],
                        [  1.58294678e-01,   1.58294678e-01],
                        [  1.39953613e-01,   1.39953613e-01],
                        [  1.16546631e-01,   1.16546631e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  9.20715332e-02,   9.20715332e-02],
                        [  8.27331543e-02,   8.27026367e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  3.25622559e-02,   3.25317383e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  6.71386719e-04,   6.71386719e-04],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -5.15747070e-02,  -5.15441895e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  3.37524414e-02,   3.37219238e-02],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  6.30798340e-02,   6.31103516e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [ -8.78906250e-03,  -8.75854492e-03],
                        [ -8.23364258e-02,  -8.23364258e-02],
                        [ -1.61987305e-01,  -1.61987305e-01],
                        [ -2.26470947e-01,  -2.26440430e-01],
                        [ -2.53265381e-01,  -2.53265381e-01],
                        [ -2.32360840e-01,  -2.32360840e-01],
                        [ -1.80145264e-01,  -1.80145264e-01],
                        [ -1.28662109e-01,  -1.28662109e-01],
                        [ -9.65270996e-02,  -9.65576172e-02],
                        [ -7.77893066e-02,  -7.77893066e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  7.34252930e-02,   7.34252930e-02],
                        [  1.07513428e-01,   1.07513428e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  7.79113770e-02,   7.79113770e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [ -9.42382812e-02,  -9.42382812e-02],
                        [ -1.80389404e-01,  -1.80389404e-01],
                        [ -2.30468750e-01,  -2.30468750e-01],
                        [ -2.30102539e-01,  -2.30102539e-01],
                        [ -1.90093994e-01,  -1.90093994e-01],
                        [ -1.38000488e-01,  -1.38000488e-01],
                        [ -9.68322754e-02,  -9.68322754e-02],
                        [ -6.98242188e-02,  -6.98242188e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.51367188e-02,   1.51672363e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  8.51135254e-02,   8.51135254e-02],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  1.53076172e-01,   1.53076172e-01],
                        [  1.47094727e-01,   1.47094727e-01],
                        [  1.34338379e-01,   1.34338379e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.17675781e-01,   1.17675781e-01],
                        [  1.06750488e-01,   1.06781006e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.45019531e-01,   1.45019531e-01],
                        [  1.62384033e-01,   1.62414551e-01],
                        [  1.56860352e-01,   1.56860352e-01],
                        [  1.34887695e-01,   1.34887695e-01],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  9.08203125e-02,   9.08203125e-02],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  6.67114258e-02,   6.67114258e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.60607910e-02,  -5.60302734e-02],
                        [ -5.27954102e-02,  -5.27648926e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [ -3.94592285e-02,  -3.94287109e-02],
                        [ -1.14105225e-01,  -1.14105225e-01],
                        [ -1.86553955e-01,  -1.86553955e-01],
                        [ -2.29858398e-01,  -2.29858398e-01],
                        [ -2.28942871e-01,  -2.28912354e-01],
                        [ -1.93084717e-01,  -1.93084717e-01],
                        [ -1.47216797e-01,  -1.47216797e-01],
                        [ -1.10565186e-01,  -1.10565186e-01],
                        [ -8.64868164e-02,  -8.64868164e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  1.07635498e-01,   1.07635498e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.59545898e-01,   1.59515381e-01],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  9.87243652e-02,   9.87548828e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [ -9.54589844e-02,  -9.54589844e-02],
                        [ -1.91345215e-01,  -1.91345215e-01],
                        [ -2.42126465e-01,  -2.42126465e-01],
                        [ -2.36572266e-01,  -2.36572266e-01],
                        [ -1.87957764e-01,  -1.87988281e-01],
                        [ -1.25122070e-01,  -1.25122070e-01],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  4.27246094e-03,   4.24194336e-03],
                        [  1.08032227e-02,   1.08337402e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.01721191e-02,   2.02026367e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  7.91015625e-02,   7.91015625e-02],
                        [  1.15814209e-01,   1.15783691e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.45965576e-01,   1.45965576e-01],
                        [  1.33483887e-01,   1.33483887e-01],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  1.21612549e-01,   1.21643066e-01],
                        [  1.18041992e-01,   1.18041992e-01],
                        [  1.05926514e-01,   1.05895996e-01],
                        [  9.04846191e-02,   9.05151367e-02],
                        [  7.70568848e-02,   7.70568848e-02],
                        [  6.57653809e-02,   6.57653809e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.60827637e-01,   1.60827637e-01],
                        [  1.62719727e-01,   1.62689209e-01],
                        [  1.40411377e-01,   1.40411377e-01],
                        [  1.11175537e-01,   1.11175537e-01],
                        [  8.69140625e-02,   8.69140625e-02],
                        [  6.92138672e-02,   6.91833496e-02],
                        [  5.65795898e-02,   5.66101074e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  2.30712891e-02,   2.31018066e-02],
                        [  2.16064453e-02,   2.15759277e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -1.42822266e-02,  -1.42517090e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.78015137e-02,  -2.78320312e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.06506348e-02,  -1.06811523e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -5.63354492e-02,  -5.63659668e-02],
                        [ -6.44836426e-02,  -6.44836426e-02],
                        [ -6.98547363e-02,  -6.98547363e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -6.86645508e-02,  -6.86950684e-02],
                        [ -6.21948242e-02,  -6.21948242e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.54211426e-02,  -2.54516602e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  3.66821289e-02,   3.66516113e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -4.87060547e-02,  -4.86755371e-02],
                        [ -1.15173340e-01,  -1.15173340e-01],
                        [ -1.77581787e-01,  -1.77612305e-01],
                        [ -2.14843750e-01,  -2.14843750e-01],
                        [ -2.10449219e-01,  -2.10449219e-01],
                        [ -1.69158936e-01,  -1.69158936e-01],
                        [ -1.17340088e-01,  -1.17340088e-01],
                        [ -8.09631348e-02,  -8.09326172e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -8.33129883e-03,  -8.30078125e-03],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  7.47985840e-02,   7.47680664e-02],
                        [  1.07360840e-01,   1.07360840e-01],
                        [  1.28051758e-01,   1.28051758e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.23779297e-01,   1.23779297e-01],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  2.95410156e-02,   2.95410156e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -1.35894775e-01,  -1.35894775e-01],
                        [ -1.99981689e-01,  -1.99981689e-01],
                        [ -2.19207764e-01,  -2.19207764e-01],
                        [ -1.90979004e-01,  -1.90979004e-01],
                        [ -1.36627197e-01,  -1.36596680e-01],
                        [ -8.66394043e-02,  -8.66394043e-02],
                        [ -5.95092773e-02,  -5.95397949e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.19311523e-02,  -4.19006348e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -6.13403320e-03,  -6.10351562e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  3.67431641e-02,   3.67736816e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  2.13317871e-02,   2.13012695e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.39923096e-01,   1.39923096e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.32354736e-01,   1.32324219e-01],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.26190186e-01,   1.26190186e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  1.00830078e-01,   1.00830078e-01],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  3.57055664e-03,   3.60107422e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  1.35620117e-01,   1.35620117e-01],
                        [  1.60430908e-01,   1.60430908e-01],
                        [  1.56860352e-01,   1.56860352e-01],
                        [  1.29882812e-01,   1.29852295e-01],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  7.01293945e-02,   7.01293945e-02],
                        [  5.02624512e-02,   5.02624512e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.51562500e-02,   3.51562500e-02],
                        [  3.31115723e-02,   3.31420898e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.57153320e-02,  -4.57458496e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -3.20434570e-03,  -3.17382812e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -6.03637695e-02,  -6.03332520e-02],
                        [ -6.84509277e-02,  -6.84509277e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -6.48803711e-02,  -6.48498535e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.39343262e-02,  -6.39343262e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -5.66711426e-02,  -5.66711426e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -1.24206543e-02,  -1.23901367e-02],
                        [  3.84521484e-03,   3.81469727e-03],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  4.14733887e-02,   4.14733887e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -1.74377441e-01,  -1.74377441e-01],
                        [ -2.17193604e-01,  -2.17193604e-01],
                        [ -2.22534180e-01,  -2.22534180e-01],
                        [ -1.89849854e-01,  -1.89849854e-01],
                        [ -1.37420654e-01,  -1.37420654e-01],
                        [ -9.25903320e-02,  -9.25903320e-02],
                        [ -7.11975098e-02,  -7.11975098e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -6.25915527e-02,  -6.26220703e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  7.82165527e-02,   7.81860352e-02],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -1.23962402e-01,  -1.23962402e-01],
                        [ -1.89727783e-01,  -1.89727783e-01],
                        [ -2.10784912e-01,  -2.10784912e-01],
                        [ -1.84051514e-01,  -1.84051514e-01],
                        [ -1.31591797e-01,  -1.31591797e-01],
                        [ -8.53271484e-02,  -8.53271484e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -5.70373535e-02,  -5.70068359e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [  1.70898438e-03,   1.73950195e-03],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  3.12500000e-02,   3.12194824e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  4.57458496e-02,   4.57458496e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  1.09832764e-01,   1.09832764e-01],
                        [  1.40319824e-01,   1.40319824e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.49780273e-01,   1.49780273e-01],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.24420166e-01,   1.24420166e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.02630615e-01,   1.02630615e-01],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.46942139e-01,   1.46911621e-01],
                        [  1.45782471e-01,   1.45782471e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  9.30480957e-02,   9.30480957e-02],
                        [  6.94274902e-02,   6.94580078e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  5.40771484e-02,   5.40466309e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  3.08532715e-02,   3.08837891e-02],
                        [  1.50451660e-02,   1.50146484e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.09863281e-02,  -1.09558105e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.92871094e-02,  -1.93176270e-02],
                        [ -2.15148926e-02,  -2.14843750e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -3.19213867e-02,  -3.18908691e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.65393066e-02,  -4.65087891e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.65588379e-02,  -6.65893555e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -7.29370117e-03,  -7.26318359e-03],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -1.25549316e-01,  -1.25549316e-01],
                        [ -1.87652588e-01,  -1.87652588e-01],
                        [ -2.22900391e-01,  -2.22869873e-01],
                        [ -2.19879150e-01,  -2.19879150e-01],
                        [ -1.84844971e-01,  -1.84844971e-01],
                        [ -1.37664795e-01,  -1.37634277e-01],
                        [ -9.99450684e-02,  -9.99450684e-02],
                        [ -8.06274414e-02,  -8.06274414e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  1.04125977e-01,   1.04125977e-01],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  5.61218262e-02,   5.61218262e-02],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -1.05895996e-01,  -1.05895996e-01],
                        [ -1.81121826e-01,  -1.81121826e-01],
                        [ -2.22991943e-01,  -2.22991943e-01],
                        [ -2.18994141e-01,  -2.19024658e-01],
                        [ -1.78100586e-01,  -1.78100586e-01],
                        [ -1.24938965e-01,  -1.24938965e-01],
                        [ -8.16955566e-02,  -8.16955566e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  1.46484375e-03,   1.43432617e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  8.92028809e-02,   8.92028809e-02],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.42333984e-01,   1.42333984e-01],
                        [  1.51245117e-01,   1.51245117e-01],
                        [  1.47186279e-01,   1.47186279e-01],
                        [  1.34857178e-01,   1.34857178e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  7.39135742e-02,   7.39135742e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  5.31921387e-02,   5.31921387e-02],
                        [  3.82995605e-02,   3.82690430e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  4.79125977e-03,   4.82177734e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -2.99072266e-03,  -3.02124023e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.37268066e-01,   1.37268066e-01],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  8.89587402e-02,   8.89587402e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -5.52673340e-02,  -5.52368164e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -5.05981445e-02,  -5.06286621e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -4.55932617e-02,  -4.56237793e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  5.80749512e-02,   5.81054688e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  4.84924316e-02,   4.85229492e-02],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -1.40319824e-01,  -1.40319824e-01],
                        [ -2.06298828e-01,  -2.06298828e-01],
                        [ -2.41821289e-01,  -2.41821289e-01],
                        [ -2.35260010e-01,  -2.35260010e-01],
                        [ -1.93664551e-01,  -1.93664551e-01],
                        [ -1.41021729e-01,  -1.41021729e-01],
                        [ -1.02416992e-01,  -1.02416992e-01],
                        [ -8.48693848e-02,  -8.48693848e-02],
                        [ -7.51953125e-02,  -7.51953125e-02],
                        [ -5.95397949e-02,  -5.95397949e-02],
                        [ -4.02221680e-02,  -4.02526855e-02],
                        [ -2.68859863e-02,  -2.68554688e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [  2.23388672e-02,   2.23083496e-02],
                        [  5.80749512e-02,   5.81054688e-02],
                        [  9.48791504e-02,   9.48791504e-02],
                        [  1.24298096e-01,   1.24298096e-01],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.43066406e-01,   1.43066406e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  6.56433105e-02,   6.56433105e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -1.12091064e-01,  -1.12091064e-01],
                        [ -1.90948486e-01,  -1.90948486e-01],
                        [ -2.27294922e-01,  -2.27294922e-01],
                        [ -2.11639404e-01,  -2.11639404e-01],
                        [ -1.61590576e-01,  -1.61590576e-01],
                        [ -1.09161377e-01,  -1.09191895e-01],
                        [ -7.40661621e-02,  -7.40661621e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  1.57165527e-01,   1.57165527e-01],
                        [  1.67633057e-01,   1.67633057e-01],
                        [  1.65161133e-01,   1.65161133e-01],
                        [  1.55456543e-01,   1.55456543e-01],
                        [  1.41845703e-01,   1.41845703e-01],
                        [  1.27960205e-01,   1.27960205e-01],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  5.52978516e-02,   5.52673340e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  1.67846680e-03,   1.67846680e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  1.54418945e-01,   1.54418945e-01],
                        [  1.57501221e-01,   1.57501221e-01],
                        [  1.35955811e-01,   1.35986328e-01],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  7.90710449e-02,   7.90405273e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  6.20727539e-02,   6.21032715e-02],
                        [  5.76171875e-02,   5.76171875e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  8.72802734e-03,   8.72802734e-03],
                        [ -5.85937500e-03,  -5.88989258e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -2.22473145e-02,  -2.22778320e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -1.67846680e-02,  -1.68151855e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -2.45971680e-02,  -2.46276855e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.23693848e-02,  -2.23999023e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -7.58972168e-02,  -7.58972168e-02],
                        [ -8.11767578e-02,  -8.11767578e-02],
                        [ -7.90710449e-02,  -7.90710449e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.21752930e-02,  -4.22058105e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  6.25610352e-02,   6.25305176e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -1.32293701e-01,  -1.32293701e-01],
                        [ -2.01629639e-01,  -2.01629639e-01],
                        [ -2.43896484e-01,  -2.43865967e-01],
                        [ -2.43194580e-01,  -2.43164062e-01],
                        [ -2.03643799e-01,  -2.03643799e-01],
                        [ -1.49200439e-01,  -1.49200439e-01],
                        [ -1.05010986e-01,  -1.05010986e-01],
                        [ -8.00476074e-02,  -8.00781250e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -3.30200195e-02,  -3.30505371e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [  4.57763672e-03,   4.54711914e-03],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  1.03149414e-01,   1.03149414e-01],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  1.41082764e-01,   1.41082764e-01],
                        [  1.26739502e-01,   1.26739502e-01],
                        [  7.89184570e-02,   7.89184570e-02],
                        [ -5.61523438e-03,  -5.64575195e-03],
                        [ -1.09680176e-01,  -1.09649658e-01],
                        [ -1.96014404e-01,  -1.96014404e-01],
                        [ -2.32910156e-01,  -2.32940674e-01],
                        [ -2.14965820e-01,  -2.14965820e-01],
                        [ -1.61132812e-01,  -1.61102295e-01],
                        [ -1.01654053e-01,  -1.01654053e-01],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -1.36108398e-02,  -1.36413574e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  4.36706543e-02,   4.36401367e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  2.20947266e-02,   2.20642090e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  3.48510742e-02,   3.48205566e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  1.09405518e-01,   1.09436035e-01],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.59881592e-01,   1.59881592e-01],
                        [  1.59576416e-01,   1.59576416e-01],
                        [  1.47247314e-01,   1.47247314e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.18682861e-01,   1.18682861e-01],
                        [  1.10534668e-01,   1.10534668e-01],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  1.04248047e-01,   1.04248047e-01],
                        [  9.19189453e-02,   9.19189453e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  4.75769043e-02,   4.76074219e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  8.65478516e-02,   8.65478516e-02],
                        [  1.38336182e-01,   1.38366699e-01],
                        [  1.69708252e-01,   1.69708252e-01],
                        [  1.69677734e-01,   1.69677734e-01],
                        [  1.46606445e-01,   1.46606445e-01],
                        [  1.16699219e-01,   1.16699219e-01],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -1.95312500e-03,  -1.92260742e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [  1.37023926e-02,   1.36718750e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  1.55944824e-02,   1.55639648e-02],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -1.41601562e-02,  -1.41296387e-02],
                        [ -2.78930664e-02,  -2.79235840e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -4.16259766e-02,  -4.16564941e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -4.11071777e-02,  -4.11376953e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -6.90307617e-02,  -6.90307617e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -6.37207031e-02,  -6.37512207e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -4.68139648e-02,  -4.68444824e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.48510742e-02,  -3.48205566e-02],
                        [ -2.85034180e-02,  -2.85339355e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -1.66625977e-02,  -1.66320801e-02],
                        [  1.55639648e-03,   1.58691406e-03],
                        [  2.38342285e-02,   2.38037109e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -1.18011475e-01,  -1.18011475e-01],
                        [ -1.82678223e-01,  -1.82678223e-01],
                        [ -2.19238281e-01,  -2.19238281e-01],
                        [ -2.14752197e-01,  -2.14752197e-01],
                        [ -1.80694580e-01,  -1.80694580e-01],
                        [ -1.42181396e-01,  -1.42181396e-01],
                        [ -1.15875244e-01,  -1.15875244e-01],
                        [ -1.01348877e-01,  -1.01348877e-01],
                        [ -9.05761719e-02,  -9.05761719e-02],
                        [ -7.86743164e-02,  -7.86743164e-02],
                        [ -6.46362305e-02,  -6.46362305e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  3.70483398e-02,   3.70788574e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  1.12274170e-01,   1.12243652e-01],
                        [  1.39587402e-01,   1.39587402e-01],
                        [  1.52679443e-01,   1.52679443e-01],
                        [  1.42944336e-01,   1.42944336e-01],
                        [  9.59777832e-02,   9.59777832e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -1.78985596e-01,  -1.78985596e-01],
                        [ -2.22412109e-01,  -2.22412109e-01],
                        [ -2.16430664e-01,  -2.16430664e-01],
                        [ -1.72332764e-01,  -1.72332764e-01],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -7.36999512e-02,  -7.36999512e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  6.10351562e-05,   3.05175781e-05],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.43554688e-01,   1.43585205e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.42791748e-01,   1.42791748e-01],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.23504639e-01,   1.23474121e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.17523193e-01,   1.17523193e-01],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [ -1.26647949e-02,  -1.26342773e-02],
                        [ -2.99987793e-02,  -3.00292969e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.41571045e-01,   1.41601562e-01],
                        [  1.55181885e-01,   1.55181885e-01],
                        [  1.38580322e-01,   1.38580322e-01],
                        [  1.08764648e-01,   1.08764648e-01],
                        [  8.37707520e-02,   8.37707520e-02],
                        [  6.78710938e-02,   6.78710938e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -4.79125977e-02,  -4.78820801e-02],
                        [ -5.86547852e-02,  -5.86242676e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -6.35681152e-02,  -6.35375977e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.55322266e-02,  -4.55017090e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  4.11682129e-02,   4.11682129e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  6.85729980e-02,   6.85424805e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  1.61132812e-02,   1.61437988e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -1.28997803e-01,  -1.28997803e-01],
                        [ -2.10052490e-01,  -2.10052490e-01],
                        [ -2.56195068e-01,  -2.56195068e-01],
                        [ -2.52807617e-01,  -2.52838135e-01],
                        [ -2.12921143e-01,  -2.12921143e-01],
                        [ -1.62139893e-01,  -1.62139893e-01],
                        [ -1.20727539e-01,  -1.20758057e-01],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -8.14514160e-02,  -8.14208984e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  3.82995605e-02,   3.83300781e-02],
                        [  7.16247559e-02,   7.16247559e-02],
                        [  1.05133057e-01,   1.05102539e-01],
                        [  1.30920410e-01,   1.30920410e-01],
                        [  1.43005371e-01,   1.43005371e-01],
                        [  1.34674072e-01,   1.34674072e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  2.18811035e-02,   2.19116211e-02],
                        [ -7.33032227e-02,  -7.33032227e-02],
                        [ -1.61010742e-01,  -1.61010742e-01],
                        [ -2.12768555e-01,  -2.12768555e-01],
                        [ -2.16339111e-01,  -2.16339111e-01],
                        [ -1.80816650e-01,  -1.80816650e-01],
                        [ -1.28723145e-01,  -1.28723145e-01],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -5.16357422e-02,  -5.16662598e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  2.99377441e-02,   2.99072266e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.62445068e-01,   1.62445068e-01],
                        [  1.82403564e-01,   1.82403564e-01],
                        [  1.79901123e-01,   1.79931641e-01],
                        [  1.64886475e-01,   1.64886475e-01],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.41021729e-01,   1.41052246e-01],
                        [  1.31561279e-01,   1.31561279e-01],
                        [  1.16088867e-01,   1.16088867e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  8.63037109e-02,   8.63037109e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  7.31201172e-02,   7.30895996e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  2.76489258e-02,   2.76489258e-02],
                        [  3.84521484e-03,   3.81469727e-03],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -2.40478516e-02,  -2.40173340e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.69152832e-02,   5.69458008e-02],
                        [  1.03485107e-01,   1.03454590e-01],
                        [  1.36230469e-01,   1.36230469e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.33819580e-01,   1.33819580e-01],
                        [  1.13616943e-01,   1.13586426e-01],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  4.29687500e-02,   4.29382324e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  1.17492676e-02,   1.17797852e-02],
                        [  1.15966797e-02,   1.15661621e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.54516602e-02,  -2.54211426e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.86560059e-02,  -2.86865234e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.05676270e-02,  -5.05371094e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [  5.31005859e-03,   5.34057617e-03],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  4.10156250e-02,   4.09851074e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -1.65618896e-01,  -1.65618896e-01],
                        [ -2.24426270e-01,  -2.24426270e-01],
                        [ -2.40692139e-01,  -2.40692139e-01],
                        [ -2.12402344e-01,  -2.12402344e-01],
                        [ -1.61071777e-01,  -1.61071777e-01],
                        [ -1.16668701e-01,  -1.16668701e-01],
                        [ -9.43603516e-02,  -9.43298340e-02],
                        [ -8.86840820e-02,  -8.86840820e-02],
                        [ -8.58459473e-02,  -8.58764648e-02],
                        [ -7.64465332e-02,  -7.64160156e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -6.83593750e-03,  -6.80541992e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  7.19604492e-02,   7.19909668e-02],
                        [  1.05682373e-01,   1.05712891e-01],
                        [  1.34857178e-01,   1.34826660e-01],
                        [  1.50848389e-01,   1.50848389e-01],
                        [  1.41235352e-01,   1.41235352e-01],
                        [  9.19494629e-02,   9.19189453e-02],
                        [ -5.49316406e-04,  -5.79833984e-04],
                        [ -1.14624023e-01,  -1.14624023e-01],
                        [ -2.08679199e-01,  -2.08648682e-01],
                        [ -2.47528076e-01,  -2.47528076e-01],
                        [ -2.24273682e-01,  -2.24273682e-01],
                        [ -1.60644531e-01,  -1.60644531e-01],
                        [ -9.14306641e-02,  -9.14611816e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  4.17785645e-02,   4.17480469e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  1.20117188e-01,   1.20147705e-01],
                        [  1.49475098e-01,   1.49475098e-01],
                        [  1.59484863e-01,   1.59515381e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.50451660e-01,   1.50451660e-01],
                        [  1.46118164e-01,   1.46118164e-01],
                        [  1.39587402e-01,   1.39617920e-01],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.17095947e-01,   1.17095947e-01],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  8.76159668e-02,   8.76159668e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -1.62658691e-02,  -1.62963867e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.28906250e-01,   1.28906250e-01],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.12426758e-01,   1.12457275e-01],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  2.80151367e-02,   2.80456543e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.10668945e-02,  -3.10974121e-02],
                        [ -3.82690430e-02,  -3.82995605e-02],
                        [ -4.12597656e-02,  -4.12292480e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.17480469e-02,  -4.17785645e-02],
                        [ -4.52575684e-02,  -4.52270508e-02],
                        [ -4.91638184e-02,  -4.91333008e-02],
                        [ -5.26123047e-02,  -5.26428223e-02],
                        [ -5.58471680e-02,  -5.58776855e-02],
                        [ -5.73730469e-02,  -5.73425293e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.27648926e-02,  -5.27954102e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -3.88183594e-02,  -3.88488770e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -4.76074219e-02,  -4.75769043e-02],
                        [ -4.19311523e-02,  -4.19006348e-02],
                        [ -2.67944336e-02,  -2.68249512e-02],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [  2.33764648e-02,   2.34069824e-02],
                        [  4.49523926e-02,   4.49218750e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [ -1.63574219e-02,  -1.63879395e-02],
                        [ -8.16040039e-02,  -8.15734863e-02],
                        [ -1.48468018e-01,  -1.48437500e-01],
                        [ -1.97479248e-01,  -1.97509766e-01],
                        [ -2.14080811e-01,  -2.14080811e-01],
                        [ -1.96044922e-01,  -1.96014404e-01],
                        [ -1.60583496e-01,  -1.60583496e-01],
                        [ -1.32995605e-01,  -1.32995605e-01],
                        [ -1.23168945e-01,  -1.23168945e-01],
                        [ -1.20147705e-01,  -1.20147705e-01],
                        [ -1.08764648e-01,  -1.08764648e-01],
                        [ -8.46862793e-02,  -8.46862793e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  1.11358643e-01,   1.11358643e-01],
                        [  1.31591797e-01,   1.31591797e-01],
                        [  1.29669189e-01,   1.29699707e-01],
                        [  9.39331055e-02,   9.39331055e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [ -7.61413574e-02,  -7.61413574e-02],
                        [ -1.67449951e-01,  -1.67449951e-01],
                        [ -2.17407227e-01,  -2.17407227e-01],
                        [ -2.09533691e-01,  -2.09533691e-01],
                        [ -1.60308838e-01,  -1.60308838e-01],
                        [ -1.03912354e-01,  -1.03912354e-01],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  5.18798828e-04,   5.49316406e-04],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.37329102e-03,   1.34277344e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  1.51550293e-01,   1.51550293e-01],
                        [  1.67755127e-01,   1.67724609e-01],
                        [  1.69372559e-01,   1.69372559e-01],
                        [  1.62231445e-01,   1.62261963e-01],
                        [  1.52221680e-01,   1.52221680e-01],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.07269287e-01,   1.07269287e-01],
                        [  8.96911621e-02,   8.97216797e-02],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  2.65197754e-02,   2.65502930e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -2.60925293e-02,  -2.61230469e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -3.01513672e-02,  -3.01818848e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  5.85632324e-02,   5.85937500e-02],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.34979248e-01,   1.34979248e-01],
                        [  1.33789062e-01,   1.33789062e-01],
                        [  1.12792969e-01,   1.12792969e-01],
                        [  8.52966309e-02,   8.52966309e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -5.65795898e-02,  -5.65490723e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -3.93371582e-02,  -3.93066406e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -5.14221191e-02,  -5.13916016e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -5.39245605e-02,  -5.39550781e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -5.29785156e-02,  -5.29479980e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -1.28173828e-03,  -1.31225586e-03],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -9.63134766e-02,  -9.63134766e-02],
                        [ -1.72790527e-01,  -1.72790527e-01],
                        [ -2.21221924e-01,  -2.21221924e-01],
                        [ -2.29919434e-01,  -2.29919434e-01],
                        [ -2.07366943e-01,  -2.07366943e-01],
                        [ -1.73736572e-01,  -1.73736572e-01],
                        [ -1.45965576e-01,  -1.45965576e-01],
                        [ -1.27441406e-01,  -1.27441406e-01],
                        [ -1.10839844e-01,  -1.10839844e-01],
                        [ -9.00878906e-02,  -9.00573730e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.43066406e-01,   1.43066406e-01],
                        [  1.47369385e-01,   1.47369385e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  8.28857422e-02,   8.28857422e-02],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -9.87548828e-02,  -9.87548828e-02],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -2.31689453e-01,  -2.31689453e-01],
                        [ -2.19177246e-01,  -2.19177246e-01],
                        [ -1.66076660e-01,  -1.66076660e-01],
                        [ -1.05133057e-01,  -1.05163574e-01],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.45874023e-02,   1.45568848e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [  9.76562500e-04,   9.76562500e-04],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  8.30993652e-02,   8.30688477e-02],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.72790527e-01,   1.72821045e-01],
                        [  1.91528320e-01,   1.91497803e-01],
                        [  1.87622070e-01,   1.87622070e-01],
                        [  1.69799805e-01,   1.69799805e-01],
                        [  1.51489258e-01,   1.51489258e-01],
                        [  1.39221191e-01,   1.39190674e-01],
                        [  1.28540039e-01,   1.28540039e-01],
                        [  1.13555908e-01,   1.13555908e-01],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [ -1.78833008e-02,  -1.78527832e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  5.10864258e-02,   5.10864258e-02],
                        [  9.46044922e-02,   9.46044922e-02],
                        [  1.26098633e-01,   1.26098633e-01],
                        [  1.35955811e-01,   1.35955811e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  5.35888672e-02,   5.35888672e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [ -1.25122070e-03,  -1.28173828e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -6.56738281e-02,  -6.57043457e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -4.46472168e-02,  -4.46166992e-02],
                        [ -4.18090820e-02,  -4.17785645e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  7.22656250e-02,   7.22961426e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -8.89892578e-02,  -8.89892578e-02],
                        [ -1.72912598e-01,  -1.72912598e-01],
                        [ -2.36053467e-01,  -2.36053467e-01],
                        [ -2.56011963e-01,  -2.56011963e-01],
                        [ -2.30529785e-01,  -2.30529785e-01],
                        [ -1.80877686e-01,  -1.80877686e-01],
                        [ -1.36047363e-01,  -1.36047363e-01],
                        [ -1.10778809e-01,  -1.10778809e-01],
                        [ -9.80529785e-02,  -9.80529785e-02],
                        [ -8.38928223e-02,  -8.38928223e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.41796875e-02,  -3.41491699e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  3.78723145e-02,   3.79028320e-02],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  1.02081299e-01,   1.02081299e-01],
                        [  1.24053955e-01,   1.24053955e-01],
                        [  1.36230469e-01,   1.36260986e-01],
                        [  1.35314941e-01,   1.35314941e-01],
                        [  1.15753174e-01,   1.15753174e-01],
                        [  6.94580078e-02,   6.94580078e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.06475830e-01,  -1.06506348e-01],
                        [ -1.90063477e-01,  -1.90063477e-01],
                        [ -2.22595215e-01,  -2.22595215e-01],
                        [ -1.96319580e-01,  -1.96319580e-01],
                        [ -1.37176514e-01,  -1.37176514e-01],
                        [ -8.00170898e-02,  -8.00170898e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  1.45416260e-01,   1.45416260e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.86279297e-01,   1.86279297e-01],
                        [  1.74316406e-01,   1.74316406e-01],
                        [  1.53076172e-01,   1.53076172e-01],
                        [  1.34826660e-01,   1.34826660e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.17736816e-01,   1.17736816e-01],
                        [  1.09619141e-01,   1.09619141e-01],
                        [  9.92736816e-02,   9.92736816e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  9.73510742e-02,   9.73510742e-02],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.41998291e-01,   1.41998291e-01],
                        [  1.28051758e-01,   1.28051758e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -2.72521973e-02,  -2.72216797e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.91027832e-02,  -4.90722656e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  1.21154785e-02,   1.21459961e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -1.32110596e-01,  -1.32141113e-01],
                        [ -2.10723877e-01,  -2.10723877e-01],
                        [ -2.55157471e-01,  -2.55157471e-01],
                        [ -2.45880127e-01,  -2.45880127e-01],
                        [ -1.94274902e-01,  -1.94274902e-01],
                        [ -1.37664795e-01,  -1.37664795e-01],
                        [ -1.06964111e-01,  -1.06964111e-01],
                        [ -1.01470947e-01,  -1.01470947e-01],
                        [ -9.93957520e-02,  -9.93957520e-02],
                        [ -8.81958008e-02,  -8.81958008e-02],
                        [ -7.45239258e-02,  -7.45239258e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  1.19842529e-01,   1.19842529e-01],
                        [  1.34490967e-01,   1.34490967e-01],
                        [  1.42120361e-01,   1.42120361e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  4.42504883e-02,   4.42504883e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -1.51763916e-01,  -1.51763916e-01],
                        [ -2.18963623e-01,  -2.18963623e-01],
                        [ -2.30438232e-01,  -2.30438232e-01],
                        [ -1.90612793e-01,  -1.90612793e-01],
                        [ -1.28875732e-01,  -1.28875732e-01],
                        [ -7.83081055e-02,  -7.83081055e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  2.99072266e-02,   2.99377441e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  1.32904053e-01,   1.32904053e-01],
                        [  1.74102783e-01,   1.74102783e-01],
                        [  1.91772461e-01,   1.91772461e-01],
                        [  1.83013916e-01,   1.83013916e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.41235352e-01,   1.41235352e-01],
                        [  1.31164551e-01,   1.31164551e-01],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -2.47802734e-02,  -2.47497559e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  1.16577148e-01,   1.16577148e-01],
                        [  1.43218994e-01,   1.43218994e-01],
                        [  1.40350342e-01,   1.40350342e-01],
                        [  1.18652344e-01,   1.18652344e-01],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -5.91430664e-02,  -5.91430664e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -1.49810791e-01,  -1.49810791e-01],
                        [ -2.18963623e-01,  -2.18963623e-01],
                        [ -2.50000000e-01,  -2.50000000e-01],
                        [ -2.35168457e-01,  -2.35168457e-01],
                        [ -1.90979004e-01,  -1.90979004e-01],
                        [ -1.45660400e-01,  -1.45660400e-01],
                        [ -1.17584229e-01,  -1.17584229e-01],
                        [ -1.04400635e-01,  -1.04400635e-01],
                        [ -9.35363770e-02,  -9.35363770e-02],
                        [ -8.02917480e-02,  -8.02917480e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  6.58874512e-02,   6.58874512e-02],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  1.39221191e-01,   1.39221191e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  4.47692871e-02,   4.47692871e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -1.45141602e-01,  -1.45141602e-01],
                        [ -2.16796875e-01,  -2.16796875e-01],
                        [ -2.30224609e-01,  -2.30224609e-01],
                        [ -1.88842773e-01,  -1.88842773e-01],
                        [ -1.25793457e-01,  -1.25793457e-01],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  5.04150391e-02,   5.04150391e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  7.39440918e-02,   7.39440918e-02],
                        [  1.23870850e-01,   1.23870850e-01],
                        [  1.70379639e-01,   1.70379639e-01],
                        [  1.96472168e-01,   1.96472168e-01],
                        [  1.93115234e-01,   1.93115234e-01],
                        [  1.69494629e-01,   1.69494629e-01],
                        [  1.45660400e-01,   1.45660400e-01],
                        [  1.33392334e-01,   1.33392334e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  1.37634277e-01,   1.37634277e-01],
                        [  1.44805908e-01,   1.44805908e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  6.53076172e-02,   6.53076172e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.99060059e-02,  -5.99060059e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  7.40966797e-02,   7.40966797e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -1.44226074e-01,  -1.44226074e-01],
                        [ -2.16461182e-01,  -2.16461182e-01],
                        [ -2.57263184e-01,  -2.57263184e-01],
                        [ -2.55371094e-01,  -2.55371094e-01],
                        [ -2.16766357e-01,  -2.16766357e-01],
                        [ -1.65740967e-01,  -1.65740967e-01],
                        [ -1.28326416e-01,  -1.28326416e-01],
                        [ -1.12335205e-01,  -1.12335205e-01],
                        [ -1.05834961e-01,  -1.05834961e-01],
                        [ -9.45739746e-02,  -9.45739746e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  9.27124023e-02,   9.27124023e-02],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  1.14929199e-01,   1.14929199e-01],
                        [  1.19720459e-01,   1.19720459e-01],
                        [  1.12762451e-01,   1.12762451e-01],
                        [  8.59069824e-02,   8.59069824e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -1.30859375e-01,  -1.30859375e-01],
                        [ -1.92718506e-01,  -1.92718506e-01],
                        [ -2.04071045e-01,  -2.04071045e-01],
                        [ -1.68640137e-01,  -1.68640137e-01],
                        [ -1.16302490e-01,  -1.16302490e-01],
                        [ -7.74230957e-02,  -7.74230957e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  1.34094238e-01,   1.34094238e-01],
                        [  1.73492432e-01,   1.73492432e-01],
                        [  1.90948486e-01,   1.90948486e-01],
                        [  1.81243896e-01,   1.81243896e-01],
                        [  1.57287598e-01,   1.57287598e-01],
                        [  1.35559082e-01,   1.35559082e-01],
                        [  1.21673584e-01,   1.21673584e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  6.06994629e-02,   6.06994629e-02],
                        [  1.00616455e-01,   1.00616455e-01],
                        [  1.22100830e-01,   1.22100830e-01],
                        [  1.21673584e-01,   1.21673584e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -1.17462158e-01,  -1.17462158e-01],
                        [ -1.95800781e-01,  -1.95800781e-01],
                        [ -2.51098633e-01,  -2.51098633e-01],
                        [ -2.63427734e-01,  -2.63427734e-01],
                        [ -2.32055664e-01,  -2.32055664e-01],
                        [ -1.77520752e-01,  -1.77520752e-01],
                        [ -1.27105713e-01,  -1.27105713e-01],
                        [ -9.71069336e-02,  -9.71069336e-02],
                        [ -8.53271484e-02,  -8.53271484e-02],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -7.17773438e-02,  -7.17773438e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  1.16912842e-01,   1.16912842e-01],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  1.57104492e-01,   1.57104492e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  5.16967773e-02,   5.16967773e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -1.30615234e-01,  -1.30615234e-01],
                        [ -1.95251465e-01,  -1.95251465e-01],
                        [ -2.10357666e-01,  -2.10357666e-01],
                        [ -1.79504395e-01,  -1.79504395e-01],
                        [ -1.28265381e-01,  -1.28265381e-01],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  1.23199463e-01,   1.23199463e-01],
                        [  1.52282715e-01,   1.52282715e-01],
                        [  1.68212891e-01,   1.68212891e-01],
                        [  1.69647217e-01,   1.69647217e-01],
                        [  1.62048340e-01,   1.62048340e-01],
                        [  1.53137207e-01,   1.53137207e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  1.40075684e-01,   1.40075684e-01],
                        [  1.30065918e-01,   1.30065918e-01],
                        [  1.14196777e-01,   1.14196777e-01],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  8.01086426e-02,   8.01086426e-02],
                        [  1.24359131e-01,   1.24359131e-01],
                        [  1.40106201e-01,   1.40106201e-01],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  6.01196289e-02,   6.01196289e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  4.08935547e-03,   4.08935547e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.53796387e-02,  -4.53796387e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -7.42187500e-02,  -7.42187500e-02],
                        [ -1.59759521e-01,  -1.59759521e-01],
                        [ -2.28942871e-01,  -2.28942871e-01],
                        [ -2.59185791e-01,  -2.59185791e-01],
                        [ -2.45513916e-01,  -2.45513916e-01],
                        [ -2.01324463e-01,  -2.01324463e-01],
                        [ -1.50787354e-01,  -1.50787354e-01],
                        [ -1.16882324e-01,  -1.16882324e-01],
                        [ -1.05712891e-01,  -1.05712891e-01],
                        [ -1.03302002e-01,  -1.03302002e-01],
                        [ -9.28955078e-02,  -9.28955078e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  8.06884766e-02,   8.06884766e-02],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.36566162e-01,   1.36566162e-01],
                        [  1.27136230e-01,   1.27136230e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -1.36840820e-01,  -1.36840820e-01],
                        [ -1.92810059e-01,  -1.92810059e-01],
                        [ -1.96044922e-01,  -1.96044922e-01],
                        [ -1.52679443e-01,  -1.52679443e-01],
                        [ -9.59167480e-02,  -9.59167480e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  9.00573730e-02,   9.00573730e-02],
                        [  1.33666992e-01,   1.33666992e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.77398682e-01,   1.77398682e-01],
                        [  1.68670654e-01,   1.68670654e-01],
                        [  1.51824951e-01,   1.51824951e-01],
                        [  1.38519287e-01,   1.38519287e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.29882812e-01,   1.29882812e-01],
                        [  1.22558594e-01,   1.22558594e-01],
                        [  1.08032227e-01,   1.08032227e-01],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.27716064e-01,   1.27716064e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -1.36016846e-01,  -1.36016846e-01],
                        [ -2.15057373e-01,  -2.15057373e-01],
                        [ -2.53814697e-01,  -2.53814697e-01],
                        [ -2.42431641e-01,  -2.42431641e-01],
                        [ -1.96868896e-01,  -1.96868896e-01],
                        [ -1.45263672e-01,  -1.45263672e-01],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -9.43908691e-02,  -9.43908691e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -8.70361328e-02,  -8.70361328e-02],
                        [ -8.05358887e-02,  -8.05358887e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  1.05041504e-01,   1.05041504e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.08398438e-01,   1.08398438e-01],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -1.58843994e-01,  -1.58843994e-01],
                        [ -1.96777344e-01,  -1.96777344e-01],
                        [ -1.87377930e-01,  -1.87377930e-01],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -9.20715332e-02,  -9.20715332e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  1.24389648e-01,   1.24389648e-01],
                        [  1.59637451e-01,   1.59637451e-01],
                        [  1.76879883e-01,   1.76879883e-01],
                        [  1.77429199e-01,   1.77429199e-01],
                        [  1.68792725e-01,   1.68792725e-01],
                        [  1.57958984e-01,   1.57958984e-01],
                        [  1.48376465e-01,   1.48376465e-01],
                        [  1.40533447e-01,   1.40533447e-01],
                        [  1.32171631e-01,   1.32171631e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  1.25762939e-01,   1.25762939e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.24938965e-01,   1.24938965e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -1.01043701e-01,  -1.01043701e-01],
                        [ -1.82281494e-01,  -1.82281494e-01],
                        [ -2.42279053e-01,  -2.42279053e-01],
                        [ -2.61016846e-01,  -2.61016846e-01],
                        [ -2.35198975e-01,  -2.35198975e-01],
                        [ -1.85424805e-01,  -1.85424805e-01],
                        [ -1.41296387e-01,  -1.41296387e-01],
                        [ -1.15844727e-01,  -1.15844727e-01],
                        [ -1.01440430e-01,  -1.01440430e-01],
                        [ -8.85620117e-02,  -8.85620117e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  6.73522949e-02,   6.73522949e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  1.03729248e-01,   1.03729248e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.13281250e-01,   1.13281250e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  6.29577637e-02,   6.29577637e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -8.68225098e-02,  -8.68225098e-02],
                        [ -1.61132812e-01,  -1.61132812e-01],
                        [ -1.96319580e-01,  -1.96319580e-01],
                        [ -1.80908203e-01,  -1.80908203e-01],
                        [ -1.29852295e-01,  -1.29852295e-01],
                        [ -7.55310059e-02,  -7.55310059e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  4.27246094e-04,   4.27246094e-04],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  9.51843262e-02,   9.51843262e-02],
                        [  1.40350342e-01,   1.40350342e-01],
                        [  1.70867920e-01,   1.70867920e-01],
                        [  1.80755615e-01,   1.80755615e-01],
                        [  1.72821045e-01,   1.72821045e-01],
                        [  1.56311035e-01,   1.56311035e-01],
                        [  1.42608643e-01,   1.42608643e-01],
                        [  1.37542725e-01,   1.37542725e-01],
                        [  1.35437012e-01,   1.35437012e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.06353760e-01,   1.06353760e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  9.56420898e-02,   9.56420898e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  9.62829590e-02,   9.62829590e-02],
                        [  1.09466553e-01,   1.09466553e-01],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -4.54406738e-02,  -4.54406738e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -1.54876709e-01,  -1.54876709e-01],
                        [ -2.35015869e-01,  -2.35015869e-01],
                        [ -2.76000977e-01,  -2.76000977e-01],
                        [ -2.68005371e-01,  -2.68005371e-01],
                        [ -2.24334717e-01,  -2.24334717e-01],
                        [ -1.70867920e-01,  -1.70867920e-01],
                        [ -1.30401611e-01,  -1.30401611e-01],
                        [ -1.08825684e-01,  -1.08825684e-01],
                        [ -9.41162109e-02,  -9.41162109e-02],
                        [ -7.51037598e-02,  -7.51037598e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  6.67114258e-02,   6.67114258e-02],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.12213135e-01,   1.12213135e-01],
                        [  1.13647461e-01,   1.13647461e-01],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -1.49475098e-01,  -1.49475098e-01],
                        [ -1.98547363e-01,  -1.98547363e-01],
                        [ -1.99188232e-01,  -1.99188232e-01],
                        [ -1.61712646e-01,  -1.61712646e-01],
                        [ -1.13861084e-01,  -1.13861084e-01],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  9.94262695e-02,   9.94262695e-02],
                        [  1.41601562e-01,   1.41601562e-01],
                        [  1.73339844e-01,   1.73339844e-01],
                        [  1.87591553e-01,   1.87591553e-01],
                        [  1.80847168e-01,   1.80847168e-01],
                        [  1.59393311e-01,   1.59393311e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.24542236e-01,   1.24542236e-01],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.13342285e-01,   1.13342285e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.08398438e-01,   1.08398438e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  7.61108398e-02,   7.61108398e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  1.04309082e-01,   1.04309082e-01],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  2.68554688e-03,   2.68554688e-03],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -1.61529541e-01,  -1.61529541e-01],
                        [ -2.32452393e-01,  -2.32452393e-01],
                        [ -2.65563965e-01,  -2.65563965e-01],
                        [ -2.48687744e-01,  -2.48687744e-01],
                        [ -1.97875977e-01,  -1.97875977e-01],
                        [ -1.45416260e-01,  -1.45416260e-01],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -1.01470947e-01,  -1.01470947e-01],
                        [ -9.46350098e-02,  -9.46350098e-02],
                        [ -8.21228027e-02,  -8.21228027e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.11785889e-01,   1.11785889e-01],
                        [  6.42700195e-02,   6.42700195e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.01257324e-01,  -1.01257324e-01],
                        [ -1.69281006e-01,  -1.69281006e-01],
                        [ -1.93511963e-01,  -1.93511963e-01],
                        [ -1.71020508e-01,  -1.71020508e-01],
                        [ -1.23992920e-01,  -1.23992920e-01],
                        [ -8.24890137e-02,  -8.24890137e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  1.45812988e-01,   1.45812988e-01],
                        [  1.67236328e-01,   1.67236328e-01],
                        [  1.66503906e-01,   1.66503906e-01],
                        [  1.52313232e-01,   1.52313232e-01],
                        [  1.39404297e-01,   1.39404297e-01],
                        [  1.36322021e-01,   1.36322021e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.35986328e-01,   1.35986328e-01],
                        [  1.27319336e-01,   1.27319336e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  8.53881836e-02,   8.53881836e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  1.18133545e-01,   1.18133545e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  9.62829590e-02,   9.62829590e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  5.70678711e-03,   5.70678711e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -9.62829590e-02,  -9.62829590e-02],
                        [ -1.76361084e-01,  -1.76361084e-01],
                        [ -2.43194580e-01,  -2.43194580e-01],
                        [ -2.76062012e-01,  -2.76062012e-01],
                        [ -2.62237549e-01,  -2.62237549e-01],
                        [ -2.11334229e-01,  -2.11334229e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.18804932e-01,  -1.18804932e-01],
                        [ -1.04064941e-01,  -1.04064941e-01],
                        [ -9.31091309e-02,  -9.31091309e-02],
                        [ -7.83691406e-02,  -7.83691406e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  1.16241455e-01,   1.16241455e-01],
                        [  1.21765137e-01,   1.21765137e-01],
                        [  1.10046387e-01,   1.10046387e-01],
                        [  6.97937012e-02,   6.97937012e-02],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -9.60083008e-02,  -9.60083008e-02],
                        [ -1.75170898e-01,  -1.75170898e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.79382324e-01,  -1.79382324e-01],
                        [ -1.21795654e-01,  -1.21795654e-01],
                        [ -7.11975098e-02,  -7.11975098e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  1.19201660e-01,   1.19201660e-01],
                        [  1.55426025e-01,   1.55426025e-01],
                        [  1.72637939e-01,   1.72637939e-01],
                        [  1.66778564e-01,   1.66778564e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.19232178e-01,   1.19232178e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.10260010e-01,   1.10260010e-01],
                        [  9.71374512e-02,   9.71374512e-02],
                        [  8.47778320e-02,   8.47778320e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  4.99572754e-02,   4.99572754e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  8.33435059e-02,   8.33435059e-02],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.14410400e-01,   1.14410400e-01],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -8.60900879e-02,  -8.60900879e-02],
                        [ -1.69097900e-01,  -1.69097900e-01],
                        [ -2.35443115e-01,  -2.35443115e-01],
                        [ -2.60559082e-01,  -2.60559082e-01],
                        [ -2.36968994e-01,  -2.36968994e-01],
                        [ -1.83349609e-01,  -1.83349609e-01],
                        [ -1.33239746e-01,  -1.33239746e-01],
                        [ -1.09741211e-01,  -1.09741211e-01],
                        [ -1.09130859e-01,  -1.09130859e-01],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -1.02386475e-01,  -1.02386475e-01],
                        [ -8.60290527e-02,  -8.60290527e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  1.08245850e-01,   1.08245850e-01],
                        [  1.13861084e-01,   1.13861084e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -1.68518066e-01,  -1.68518066e-01],
                        [ -1.79534912e-01,  -1.79534912e-01],
                        [ -1.46972656e-01,  -1.46972656e-01],
                        [ -9.86938477e-02,  -9.86938477e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  1.14715576e-01,   1.14715576e-01],
                        [  1.53381348e-01,   1.53381348e-01],
                        [  1.72607422e-01,   1.72607422e-01],
                        [  1.67663574e-01,   1.67663574e-01],
                        [  1.48345947e-01,   1.48345947e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.22314453e-01,   1.22314453e-01],
                        [  1.20758057e-01,   1.20758057e-01],
                        [  1.17218018e-01,   1.17218018e-01],
                        [  1.10931396e-01,   1.10931396e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  9.54284668e-02,   9.54284668e-02],
                        [  9.11254883e-02,   9.11254883e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  6.02722168e-02,   6.02722168e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  1.22253418e-01,   1.22253418e-01],
                        [  1.34918213e-01,   1.34918213e-01],
                        [  1.16424561e-01,   1.16424561e-01],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  5.17272949e-02,   5.17578125e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -2.15759277e-01,  -2.15759277e-01],
                        [ -2.72277832e-01,  -2.72277832e-01],
                        [ -2.79846191e-01,  -2.79846191e-01],
                        [ -2.43591309e-01,  -2.43591309e-01],
                        [ -1.90917969e-01,  -1.90917969e-01],
                        [ -1.47277832e-01,  -1.47277832e-01],
                        [ -1.17065430e-01,  -1.17065430e-01],
                        [ -9.13696289e-02,  -9.13696289e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  4.75769043e-02,   4.75769043e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  9.12780762e-02,   9.12780762e-02],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  1.08367920e-01,   1.08367920e-01],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -1.24877930e-01,  -1.24877930e-01],
                        [ -1.73126221e-01,  -1.73126221e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.36932373e-01,  -1.36932373e-01],
                        [ -9.51232910e-02,  -9.51232910e-02],
                        [ -6.40869141e-02,  -6.40869141e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  8.01391602e-02,   8.01391602e-02],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.61437988e-01,   1.61437988e-01],
                        [  1.79748535e-01,   1.79748535e-01],
                        [  1.76055908e-01,   1.76055908e-01],
                        [  1.54785156e-01,   1.54785156e-01],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.10656738e-01,   1.10656738e-01],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  1.07391357e-01,   1.07391357e-01],
                        [  1.10351562e-01,   1.10382080e-01],
                        [  1.13952637e-01,   1.13952637e-01],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  1.13250732e-01,   1.13250732e-01],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  1.11175537e-01,   1.11175537e-01],
                        [  9.04541016e-02,   9.04541016e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  5.02624512e-02,   5.02624512e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  3.05175781e-03,   3.05175781e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.13220215e-02,  -1.12915039e-02],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  2.25524902e-02,   2.25830078e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  5.21850586e-02,   5.21850586e-02],
                        [  2.31018066e-02,   2.31323242e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -1.08276367e-01,  -1.08276367e-01],
                        [ -1.91558838e-01,  -1.91558838e-01],
                        [ -2.55218506e-01,  -2.55218506e-01],
                        [ -2.76550293e-01,  -2.76550293e-01],
                        [ -2.51586914e-01,  -2.51586914e-01],
                        [ -1.99554443e-01,  -1.99554443e-01],
                        [ -1.49993896e-01,  -1.49993896e-01],
                        [ -1.21032715e-01,  -1.21032715e-01],
                        [ -1.08795166e-01,  -1.08795166e-01],
                        [ -9.93957520e-02,  -9.93957520e-02],
                        [ -8.65478516e-02,  -8.65478516e-02],
                        [ -7.39440918e-02,  -7.39440918e-02],
                        [ -6.45751953e-02,  -6.45751953e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  5.79223633e-02,   5.79223633e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  5.04150391e-02,   5.04150391e-02],
                        [  5.84411621e-02,   5.84411621e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -1.49383545e-01,  -1.49383545e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.53472900e-01,  -1.53472900e-01],
                        [ -1.10107422e-01,  -1.10107422e-01],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -4.69360352e-02,  -4.69665527e-02],
                        [ -4.31213379e-02,  -4.30908203e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  1.39648438e-01,   1.39648438e-01],
                        [  1.68670654e-01,   1.68670654e-01],
                        [  1.75750732e-01,   1.75750732e-01],
                        [  1.59210205e-01,   1.59210205e-01],
                        [  1.28173828e-01,   1.28173828e-01],
                        [  9.92736816e-02,   9.92736816e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  8.88671875e-02,   8.88977051e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.19293213e-01,   1.19293213e-01],
                        [  1.31072998e-01,   1.31072998e-01],
                        [  1.34216309e-01,   1.34216309e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.17156982e-01,   1.17156982e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -2.73742676e-02,  -2.73437500e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  4.15039062e-03,   4.15039062e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.51660156e-02,  -4.51965332e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -1.32965088e-01,  -1.32965088e-01],
                        [ -2.07611084e-01,  -2.07611084e-01],
                        [ -2.54730225e-01,  -2.54730225e-01],
                        [ -2.59765625e-01,  -2.59765625e-01],
                        [ -2.27111816e-01,  -2.27111816e-01],
                        [ -1.77215576e-01,  -1.77215576e-01],
                        [ -1.32659912e-01,  -1.32659912e-01],
                        [ -1.06811523e-01,  -1.06811523e-01],
                        [ -9.96398926e-02,  -9.96398926e-02],
                        [ -1.00341797e-01,  -1.00341797e-01],
                        [ -9.71069336e-02,  -9.71069336e-02],
                        [ -8.57238770e-02,  -8.57238770e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  1.26464844e-01,   1.26464844e-01],
                        [  1.49169922e-01,   1.49169922e-01],
                        [  1.51641846e-01,   1.51641846e-01],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  5.35278320e-02,   5.35278320e-02],
                        [ -4.20532227e-02,  -4.20837402e-02],
                        [ -1.32202148e-01,  -1.32202148e-01],
                        [ -1.81762695e-01,  -1.81762695e-01],
                        [ -1.78009033e-01,  -1.78009033e-01],
                        [ -1.37145996e-01,  -1.37145996e-01],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  6.45751953e-02,   6.45751953e-02],
                        [  1.19018555e-01,   1.19018555e-01],
                        [  1.69342041e-01,   1.69342041e-01],
                        [  2.01293945e-01,   2.01293945e-01],
                        [  2.02087402e-01,   2.02087402e-01],
                        [  1.75231934e-01,   1.75231934e-01],
                        [  1.39587402e-01,   1.39587402e-01],
                        [  1.12304688e-01,   1.12274170e-01],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  8.70971680e-02,   8.70971680e-02],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.02111816e-01,   1.02111816e-01],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  3.34472656e-02,   3.34167480e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -4.90722656e-02,  -4.90417480e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [  3.21044922e-02,   3.20739746e-02],
                        [  8.82568359e-02,   8.82568359e-02],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.06689453e-01,   1.06689453e-01],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  3.58886719e-02,   3.58581543e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.05590820e-02,   1.05895996e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  1.10778809e-02,   1.10473633e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -4.05883789e-03,  -4.02832031e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.08227539e-02,  -3.08532715e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -1.27532959e-01,  -1.27532959e-01],
                        [ -2.05474854e-01,  -2.05474854e-01],
                        [ -2.54852295e-01,  -2.54852295e-01],
                        [ -2.61108398e-01,  -2.61108398e-01],
                        [ -2.31781006e-01,  -2.31781006e-01],
                        [ -1.89056396e-01,  -1.89056396e-01],
                        [ -1.50909424e-01,  -1.50909424e-01],
                        [ -1.22009277e-01,  -1.22009277e-01],
                        [ -9.98535156e-02,  -9.98535156e-02],
                        [ -8.25500488e-02,  -8.25500488e-02],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  1.25305176e-01,   1.25305176e-01],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  6.46972656e-03,   6.43920898e-03],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -1.52038574e-01,  -1.52038574e-01],
                        [ -1.81213379e-01,  -1.81213379e-01],
                        [ -1.67419434e-01,  -1.67419434e-01],
                        [ -1.30889893e-01,  -1.30859375e-01],
                        [ -9.67407227e-02,  -9.67407227e-02],
                        [ -7.66601562e-02,  -7.66601562e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  7.07397461e-02,   7.07702637e-02],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  1.59912109e-01,   1.59912109e-01],
                        [  1.83471680e-01,   1.83471680e-01],
                        [  1.86523438e-01,   1.86523438e-01],
                        [  1.71600342e-01,   1.71600342e-01],
                        [  1.46728516e-01,   1.46697998e-01],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  7.50427246e-02,   7.50122070e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  6.86340332e-02,   6.86035156e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  9.75341797e-02,   9.75341797e-02],
                        [  9.18579102e-02,   9.18273926e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  7.22656250e-02,   7.22656250e-02],
                        [  6.01196289e-02,   6.00891113e-02],
                        [  4.30603027e-02,   4.30908203e-02],
                        [  2.60925293e-02,   2.61230469e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -3.01818848e-02,  -3.02124023e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -1.10168457e-02,  -1.09863281e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -3.34777832e-02,  -3.35083008e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -3.93371582e-02,  -3.93676758e-02],
                        [ -3.63769531e-02,  -3.64074707e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -9.89685059e-02,  -9.89685059e-02],
                        [ -1.68579102e-01,  -1.68579102e-01],
                        [ -2.20642090e-01,  -2.20642090e-01],
                        [ -2.37274170e-01,  -2.37274170e-01],
                        [ -2.20581055e-01,  -2.20581055e-01],
                        [ -1.87377930e-01,  -1.87377930e-01],
                        [ -1.54998779e-01,  -1.54998779e-01],
                        [ -1.31408691e-01,  -1.31378174e-01],
                        [ -1.14807129e-01,  -1.14807129e-01],
                        [ -9.93957520e-02,  -9.94262695e-02],
                        [ -8.25500488e-02,  -8.25500488e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  8.23364258e-02,   8.23364258e-02],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -1.49719238e-01,  -1.49749756e-01],
                        [ -1.91253662e-01,  -1.91253662e-01],
                        [ -1.82464600e-01,  -1.82464600e-01],
                        [ -1.39770508e-01,  -1.39770508e-01],
                        [ -9.24377441e-02,  -9.24377441e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -3.82690430e-02,  -3.82385254e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -4.03747559e-02,  -4.03442383e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -3.45153809e-02,  -3.44848633e-02],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  1.46850586e-01,   1.46881104e-01],
                        [  1.70440674e-01,   1.70410156e-01],
                        [  1.71051025e-01,   1.71051025e-01],
                        [  1.53808594e-01,   1.53808594e-01],
                        [  1.26800537e-01,   1.26800537e-01],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  8.30993652e-02,   8.31298828e-02],
                        [  8.20617676e-02,   8.20617676e-02],
                        [  9.16137695e-02,   9.15832520e-02],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  8.83178711e-02,   8.83178711e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  6.30187988e-02,   6.30187988e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  5.32531738e-02,   5.32531738e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  8.91113281e-03,   8.94165039e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  7.58361816e-02,   7.58361816e-02],
                        [  1.09832764e-01,   1.09832764e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  8.30078125e-02,   8.30078125e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -2.44140625e-03,  -2.41088867e-03],
                        [ -9.49096680e-03,  -9.52148438e-03],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.02526855e-02,  -4.02832031e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -4.25109863e-02,  -4.25415039e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -1.20574951e-01,  -1.20605469e-01],
                        [ -1.97418213e-01,  -1.97418213e-01],
                        [ -2.49694824e-01,  -2.49694824e-01],
                        [ -2.63397217e-01,  -2.63397217e-01],
                        [ -2.43621826e-01,  -2.43621826e-01],
                        [ -2.07794189e-01,  -2.07794189e-01],
                        [ -1.70471191e-01,  -1.70501709e-01],
                        [ -1.36444092e-01,  -1.36444092e-01],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -8.50219727e-02,  -8.49914551e-02],
                        [ -7.51647949e-02,  -7.51647949e-02],
                        [ -7.32116699e-02,  -7.32116699e-02],
                        [ -6.95800781e-02,  -6.95495605e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -4.16870117e-02,  -4.17175293e-02],
                        [ -2.13012695e-02,  -2.12707520e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  2.22473145e-02,   2.22167969e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  4.53796387e-02,   4.54101562e-02],
                        [  4.84313965e-02,   4.84008789e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  5.04760742e-02,   5.05065918e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  8.44421387e-02,   8.44116211e-02],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.27624512e-01,   1.27655029e-01],
                        [  1.20758057e-01,   1.20727539e-01],
                        [  8.11462402e-02,   8.11462402e-02],
                        [  9.58251953e-03,   9.61303711e-03],
                        [ -7.87353516e-02,  -7.87353516e-02],
                        [ -1.55853271e-01,  -1.55853271e-01],
                        [ -1.92626953e-01,  -1.92626953e-01],
                        [ -1.78192139e-01,  -1.78192139e-01],
                        [ -1.29119873e-01,  -1.29119873e-01],
                        [ -7.66296387e-02,  -7.66296387e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -6.21948242e-02,  -6.21948242e-02],
                        [ -6.31103516e-02,  -6.30798340e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [  2.08435059e-02,   2.08740234e-02],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  1.70959473e-01,   1.70989990e-01],
                        [  1.76727295e-01,   1.76727295e-01],
                        [  1.62658691e-01,   1.62658691e-01],
                        [  1.41845703e-01,   1.41845703e-01],
                        [  1.24786377e-01,   1.24816895e-01],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.88171387e-02,   6.88476562e-02],
                        [  5.88073730e-02,   5.88073730e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  4.36401367e-02,   4.36706543e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -3.48815918e-02,  -3.48510742e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  9.59472656e-02,   9.59472656e-02],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  4.35485840e-02,   4.35791016e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  2.52990723e-02,   2.52685547e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  2.96020508e-03,   2.96020508e-03],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.35595703e-02,  -2.35290527e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -4.06494141e-02,  -4.06799316e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  4.56237793e-02,   4.55932617e-02],
                        [  5.08117676e-02,   5.08117676e-02],
                        [  4.80651855e-02,   4.80957031e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -7.38525391e-02,  -7.38525391e-02],
                        [ -1.52374268e-01,  -1.52374268e-01],
                        [ -2.21038818e-01,  -2.21038818e-01],
                        [ -2.58148193e-01,  -2.58148193e-01],
                        [ -2.55401611e-01,  -2.55401611e-01],
                        [ -2.22259521e-01,  -2.22259521e-01],
                        [ -1.79534912e-01,  -1.79565430e-01],
                        [ -1.45141602e-01,  -1.45141602e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -1.08520508e-01,  -1.08520508e-01],
                        [ -9.24682617e-02,  -9.24682617e-02],
                        [ -7.21130371e-02,  -7.21130371e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  6.02416992e-02,   6.02416992e-02],
                        [  6.85424805e-02,   6.85729980e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  8.03833008e-02,   8.03833008e-02],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  9.97924805e-02,   9.97924805e-02],
                        [  1.08154297e-01,   1.08154297e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -1.29516602e-01,  -1.29516602e-01],
                        [ -1.62506104e-01,  -1.62506104e-01],
                        [ -1.52984619e-01,  -1.52984619e-01],
                        [ -1.18072510e-01,  -1.18041992e-01],
                        [ -8.44116211e-02,  -8.44421387e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -6.68945312e-02,  -6.68945312e-02],
                        [ -7.04650879e-02,  -7.04650879e-02],
                        [ -7.23876953e-02,  -7.24182129e-02],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [  1.36108398e-02,   1.35803223e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  1.67602539e-01,   1.67602539e-01],
                        [  1.84600830e-01,   1.84600830e-01],
                        [  1.79077148e-01,   1.79077148e-01],
                        [  1.60980225e-01,   1.60949707e-01],
                        [  1.41998291e-01,   1.42028809e-01],
                        [  1.26464844e-01,   1.26464844e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  8.49304199e-02,   8.49609375e-02],
                        [  8.12377930e-02,   8.12072754e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  7.89184570e-02,   7.89489746e-02],
                        [  7.17773438e-02,   7.17468262e-02],
                        [  5.97839355e-02,   5.97534180e-02],
                        [  4.95910645e-02,   4.96215820e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  4.73327637e-02,   4.73632812e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [ -5.34057617e-03,  -5.31005859e-03],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  8.97827148e-02,   8.97827148e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  1.59301758e-02,   1.58996582e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.19628906e-02,   1.19934082e-02],
                        [  7.35473633e-03,   7.32421875e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.06811523e-02,   1.06506348e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  4.08935547e-03,   4.08935547e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.59399414e-02,  -2.59704590e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -1.48315430e-02,  -1.48010254e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -2.27966309e-02,  -2.27661133e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.97851562e-02,  -2.97546387e-02],
                        [ -3.91235352e-02,  -3.90930176e-02],
                        [ -4.26330566e-02,  -4.26635742e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  5.80139160e-02,   5.80139160e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -1.87805176e-01,  -1.87805176e-01],
                        [ -2.49725342e-01,  -2.49694824e-01],
                        [ -2.70355225e-01,  -2.70355225e-01],
                        [ -2.49572754e-01,  -2.49572754e-01],
                        [ -2.05718994e-01,  -2.05718994e-01],
                        [ -1.60217285e-01,  -1.60217285e-01],
                        [ -1.25213623e-01,  -1.25244141e-01],
                        [ -1.02447510e-01,  -1.02447510e-01],
                        [ -8.83178711e-02,  -8.82873535e-02],
                        [ -7.80639648e-02,  -7.80639648e-02],
                        [ -6.85424805e-02,  -6.85119629e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  7.58666992e-02,   7.58361816e-02],
                        [  9.42687988e-02,   9.42687988e-02],
                        [  1.19079590e-01,   1.19079590e-01],
                        [  1.35894775e-01,   1.35864258e-01],
                        [  1.26770020e-01,   1.26770020e-01],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -1.64276123e-01,  -1.64245605e-01],
                        [ -2.00347900e-01,  -2.00347900e-01],
                        [ -1.85943604e-01,  -1.85943604e-01],
                        [ -1.42852783e-01,  -1.42852783e-01],
                        [ -1.02630615e-01,  -1.02630615e-01],
                        [ -8.05664062e-02,  -8.05664062e-02],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  8.55712891e-02,   8.55407715e-02],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.67755127e-01,   1.67785645e-01],
                        [  1.77307129e-01,   1.77276611e-01],
                        [  1.60827637e-01,   1.60827637e-01],
                        [  1.30554199e-01,   1.30584717e-01],
                        [  1.04827881e-01,   1.04797363e-01],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  9.11865234e-02,   9.11865234e-02],
                        [  8.84704590e-02,   8.84399414e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  6.75354004e-02,   6.75048828e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  6.78710938e-02,   6.78710938e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  3.79028320e-02,   3.78723145e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  6.95800781e-02,   6.95800781e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.86462402e-02,  -1.86157227e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -1.75170898e-02,  -1.75476074e-02],
                        [ -1.45874023e-02,  -1.45568848e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -2.95715332e-02,  -2.96020508e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -1.23291016e-02,  -1.22985840e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  6.77795410e-02,   6.78100586e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  5.54199219e-02,   5.54199219e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.07055664e-01,  -1.07055664e-01],
                        [ -1.99310303e-01,  -1.99340820e-01],
                        [ -2.64984131e-01,  -2.64984131e-01],
                        [ -2.86621094e-01,  -2.86621094e-01],
                        [ -2.60375977e-01,  -2.60375977e-01],
                        [ -2.03552246e-01,  -2.03552246e-01],
                        [ -1.49322510e-01,  -1.49322510e-01],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -1.12915039e-01,  -1.12915039e-01],
                        [ -1.04858398e-01,  -1.04827881e-01],
                        [ -8.76464844e-02,  -8.76159668e-02],
                        [ -6.90917969e-02,  -6.91223145e-02],
                        [ -5.63354492e-02,  -5.63049316e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  4.11071777e-02,   4.10766602e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  1.17889404e-01,   1.17889404e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  5.53894043e-02,   5.53894043e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -1.62414551e-01,  -1.62414551e-01],
                        [ -1.76330566e-01,  -1.76330566e-01],
                        [ -1.54327393e-01,  -1.54327393e-01],
                        [ -1.19506836e-01,  -1.19506836e-01],
                        [ -9.43298340e-02,  -9.43603516e-02],
                        [ -8.47778320e-02,  -8.47778320e-02],
                        [ -7.99560547e-02,  -7.99560547e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.43463135e-01,   1.43493652e-01],
                        [  1.60827637e-01,   1.60827637e-01],
                        [  1.52252197e-01,   1.52252197e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  9.17968750e-02,   9.17968750e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  8.17871094e-02,   8.17871094e-02],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  6.96411133e-02,   6.96716309e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  3.99780273e-02,   3.99475098e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  3.85437012e-02,   3.85131836e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  9.16137695e-02,   9.16442871e-02],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  6.63146973e-02,   6.62841797e-02],
                        [  4.46472168e-02,   4.46777344e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  4.30908203e-02,   4.30908203e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [ -9.46044922e-04,  -9.76562500e-04],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -3.66821289e-02,  -3.66516113e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -2.00805664e-02,  -2.01110840e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -3.26232910e-02,  -3.25927734e-02],
                        [ -4.04052734e-02,  -4.04357910e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.38037109e-03,  -2.34985352e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  1.27868652e-02,   1.28173828e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  4.31213379e-02,   4.30908203e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  3.28369141e-02,   3.28063965e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.08306885e-01,  -1.08306885e-01],
                        [ -2.02056885e-01,  -2.02056885e-01],
                        [ -2.73712158e-01,  -2.73712158e-01],
                        [ -2.94891357e-01,  -2.94891357e-01],
                        [ -2.61993408e-01,  -2.62023926e-01],
                        [ -2.00592041e-01,  -2.00622559e-01],
                        [ -1.45812988e-01,  -1.45812988e-01],
                        [ -1.17065430e-01,  -1.17065430e-01],
                        [ -1.08337402e-01,  -1.08367920e-01],
                        [ -1.00189209e-01,  -1.00189209e-01],
                        [ -8.10546875e-02,  -8.10546875e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -4.28466797e-02,  -4.28771973e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  1.19934082e-02,   1.19628906e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  1.07177734e-01,   1.07177734e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.39556885e-01,   1.39556885e-01],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  6.99462891e-02,   6.99462891e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.11572266e-01,  -1.11572266e-01],
                        [ -1.79595947e-01,  -1.79565430e-01],
                        [ -2.00378418e-01,  -2.00378418e-01],
                        [ -1.77886963e-01,  -1.77886963e-01],
                        [ -1.36047363e-01,  -1.36047363e-01],
                        [ -1.01409912e-01,  -1.01409912e-01],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -7.55920410e-02,  -7.55920410e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -1.97143555e-02,  -1.97448730e-02],
                        [  2.95715332e-02,   2.96020508e-02],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  1.16546631e-01,   1.16546631e-01],
                        [  1.37756348e-01,   1.37756348e-01],
                        [  1.43463135e-01,   1.43463135e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.27502441e-01,   1.27502441e-01],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.10900879e-01,   1.10900879e-01],
                        [  1.06231689e-01,   1.06231689e-01],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.52990723e-02,   2.52685547e-02],
                        [  3.37829590e-02,   3.37829590e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  4.40979004e-02,   4.40673828e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.69970703e-02,   4.70275879e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [ -1.85546875e-02,  -1.85852051e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -5.12084961e-02,  -5.11779785e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  9.39331055e-02,   9.39331055e-02],
                        [  6.63146973e-02,   6.62841797e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -1.02844238e-02,  -1.03149414e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -1.60522461e-02,  -1.60827637e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  6.37817383e-02,   6.37817383e-02],
                        [  6.69860840e-02,   6.69860840e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -1.07452393e-01,  -1.07452393e-01],
                        [ -1.97570801e-01,  -1.97570801e-01],
                        [ -2.64770508e-01,  -2.64770508e-01],
                        [ -2.89886475e-01,  -2.89916992e-01],
                        [ -2.70324707e-01,  -2.70324707e-01],
                        [ -2.20764160e-01,  -2.20764160e-01],
                        [ -1.66015625e-01,  -1.66015625e-01],
                        [ -1.25335693e-01,  -1.25335693e-01],
                        [ -1.02020264e-01,  -1.01989746e-01],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -8.32214355e-02,  -8.32214355e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -4.21142578e-02,  -4.21447754e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  3.43322754e-02,   3.43017578e-02],
                        [  4.65393066e-02,   4.65698242e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  7.67822266e-02,   7.67822266e-02],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  1.42761230e-01,   1.42761230e-01],
                        [  1.61315918e-01,   1.61315918e-01],
                        [  1.54510498e-01,   1.54479980e-01],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  3.30505371e-02,   3.30505371e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -1.61529541e-01,  -1.61529541e-01],
                        [ -2.14599609e-01,  -2.14569092e-01],
                        [ -2.12463379e-01,  -2.12463379e-01],
                        [ -1.69403076e-01,  -1.69403076e-01],
                        [ -1.15509033e-01,  -1.15478516e-01],
                        [ -7.11364746e-02,  -7.11364746e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  5.82580566e-02,   5.82580566e-02],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.26861572e-01,   1.26892090e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  8.83178711e-02,   8.83178711e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  8.93554688e-02,   8.93554688e-02],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  1.00341797e-01,   1.00341797e-01],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.00268555e-02,   9.00573730e-02],
                        [  8.18176270e-02,   8.18176270e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  5.22155762e-02,   5.22460938e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  4.80957031e-02,   4.80957031e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.82678223e-02,  -6.82678223e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  1.14013672e-01,   1.14013672e-01],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  6.07910156e-02,   6.08215332e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  2.70080566e-02,   2.70385742e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.34582520e-02,  -1.34887695e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -3.55224609e-02,  -3.54919434e-02],
                        [ -4.10766602e-02,  -4.10766602e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -1.60522461e-02,  -1.60827637e-02],
                        [ -9.73510742e-03,  -9.70458984e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -8.36181641e-03,  -8.39233398e-03],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -8.51440430e-03,  -8.48388672e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  2.46582031e-02,   2.46276855e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  5.14526367e-02,   5.14831543e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -1.40472412e-01,  -1.40472412e-01],
                        [ -1.97906494e-01,  -1.97906494e-01],
                        [ -2.34649658e-01,  -2.34649658e-01],
                        [ -2.41058350e-01,  -2.41058350e-01],
                        [ -2.17163086e-01,  -2.17132568e-01],
                        [ -1.78924561e-01,  -1.78924561e-01],
                        [ -1.49993896e-01,  -1.49993896e-01],
                        [ -1.39068604e-01,  -1.39068604e-01],
                        [ -1.33605957e-01,  -1.33605957e-01],
                        [ -1.19110107e-01,  -1.19110107e-01],
                        [ -9.43908691e-02,  -9.43908691e-02],
                        [ -6.68945312e-02,  -6.68640137e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -2.95715332e-02,  -2.96020508e-02],
                        [ -2.37731934e-02,  -2.37426758e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.83105469e-02,  -1.83410645e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  1.55639648e-03,   1.58691406e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.78625488e-02,   2.78320312e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  5.21240234e-02,   5.21545410e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  1.21704102e-01,   1.21704102e-01],
                        [  1.38854980e-01,   1.38824463e-01],
                        [  1.38305664e-01,   1.38305664e-01],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  2.92053223e-02,   2.91748047e-02],
                        [ -7.10754395e-02,  -7.10754395e-02],
                        [ -1.61590576e-01,  -1.61560059e-01],
                        [ -2.06573486e-01,  -2.06573486e-01],
                        [ -1.92169189e-01,  -1.92169189e-01],
                        [ -1.34490967e-01,  -1.34490967e-01],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  3.62243652e-02,   3.61938477e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  7.27539062e-02,   7.27233887e-02],
                        [  6.64978027e-02,   6.65283203e-02],
                        [  6.79321289e-02,   6.79321289e-02],
                        [  7.67822266e-02,   7.67822266e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  9.56420898e-02,   9.56420898e-02],
                        [  1.02081299e-01,   1.02081299e-01],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  7.60498047e-02,   7.60498047e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  2.94799805e-02,   2.94494629e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  4.07714844e-02,   4.07409668e-02],
                        [  4.24499512e-02,   4.24804688e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [ -6.10351562e-05,  -3.05175781e-05],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -5.69458008e-02,  -5.69763184e-02],
                        [ -6.53686523e-02,  -6.53686523e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  9.69238281e-02,   9.68933105e-02],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  1.04705811e-01,   1.04705811e-01],
                        [  7.97424316e-02,   7.97424316e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  6.71386719e-04,   6.71386719e-04],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.85241699e-02,  -1.84936523e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.25427246e-02,  -1.25732422e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -1.93176270e-02,  -1.93481445e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.17492676e-02,  -1.17187500e-02],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.82495117e-02,   1.82189941e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -8.28247070e-02,  -8.28247070e-02],
                        [ -1.18957520e-01,  -1.18957520e-01],
                        [ -1.48559570e-01,  -1.48559570e-01],
                        [ -1.67327881e-01,  -1.67327881e-01],
                        [ -1.73950195e-01,  -1.73950195e-01],
                        [ -1.72180176e-01,  -1.72180176e-01],
                        [ -1.68273926e-01,  -1.68273926e-01],
                        [ -1.65313721e-01,  -1.65313721e-01],
                        [ -1.61193848e-01,  -1.61193848e-01],
                        [ -1.51000977e-01,  -1.51000977e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -1.04736328e-01,  -1.04736328e-01],
                        [ -7.58972168e-02,  -7.58972168e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.10363770e-02,  -3.10058594e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -8.78906250e-03,  -8.81958008e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  4.42504883e-03,   4.39453125e-03],
                        [  7.47680664e-03,   7.50732422e-03],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  6.98852539e-03,   6.95800781e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  3.37829590e-02,   3.37829590e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  6.96105957e-02,   6.96411133e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.30767822e-01,   1.30767822e-01],
                        [  1.02996826e-01,   1.02996826e-01],
                        [  4.53796387e-02,   4.53796387e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -1.24114990e-01,  -1.24145508e-01],
                        [ -1.84570312e-01,  -1.84570312e-01],
                        [ -1.93878174e-01,  -1.93878174e-01],
                        [ -1.52008057e-01,  -1.52008057e-01],
                        [ -8.68225098e-02,  -8.68225098e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  7.44934082e-02,   7.44934082e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  6.20422363e-02,   6.20422363e-02],
                        [  6.90002441e-02,   6.90002441e-02],
                        [  8.02001953e-02,   8.02001953e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  8.21228027e-02,   8.21228027e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  3.48815918e-02,   3.48510742e-02],
                        [  3.21044922e-02,   3.21350098e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.77294922e-02,   4.77294922e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  9.50622559e-02,   9.50622559e-02],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  6.79626465e-02,   6.79931641e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  1.00708008e-02,   1.00402832e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.41601562e-02,  -1.41296387e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -2.10571289e-03,  -2.07519531e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.13830566e-02,   1.14135742e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -9.61914062e-02,  -9.61914062e-02],
                        [ -1.47583008e-01,  -1.47583008e-01],
                        [ -1.94305420e-01,  -1.94305420e-01],
                        [ -2.22320557e-01,  -2.22320557e-01],
                        [ -2.24060059e-01,  -2.24060059e-01],
                        [ -2.05139160e-01,  -2.05139160e-01],
                        [ -1.78466797e-01,  -1.78466797e-01],
                        [ -1.52801514e-01,  -1.52801514e-01],
                        [ -1.27746582e-01,  -1.27777100e-01],
                        [ -9.95788574e-02,  -9.95788574e-02],
                        [ -7.11364746e-02,  -7.11059570e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  1.71203613e-02,   1.71508789e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  3.51562500e-02,   3.51562500e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  2.80761719e-02,   2.81066895e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  7.97424316e-02,   7.97424316e-02],
                        [  1.05468750e-01,   1.05468750e-01],
                        [  1.29852295e-01,   1.29852295e-01],
                        [  1.43463135e-01,   1.43463135e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  9.01794434e-02,   9.01794434e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [ -7.37304688e-02,  -7.36999512e-02],
                        [ -1.47003174e-01,  -1.47003174e-01],
                        [ -1.73461914e-01,  -1.73461914e-01],
                        [ -1.43280029e-01,  -1.43280029e-01],
                        [ -7.66601562e-02,  -7.66601562e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  6.73522949e-02,   6.73522949e-02],
                        [  6.81152344e-02,   6.81152344e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  3.14636230e-02,   3.14941406e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  6.45751953e-02,   6.45751953e-02],
                        [  7.37609863e-02,   7.37609863e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.04553223e-01,   1.04553223e-01],
                        [  8.37707520e-02,   8.37707520e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  5.44738770e-02,   5.44738770e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  7.29980469e-02,   7.29980469e-02],
                        [  6.05468750e-02,   6.05468750e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [ -1.38977051e-01,  -1.38977051e-01],
                        [ -2.11730957e-01,  -2.11730957e-01],
                        [ -2.56469727e-01,  -2.56469727e-01],
                        [ -2.67272949e-01,  -2.67272949e-01],
                        [ -2.46826172e-01,  -2.46826172e-01],
                        [ -2.06878662e-01,  -2.06878662e-01],
                        [ -1.64306641e-01,  -1.64306641e-01],
                        [ -1.31072998e-01,  -1.31072998e-01],
                        [ -1.08703613e-01,  -1.08703613e-01],
                        [ -9.29565430e-02,  -9.29565430e-02],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -7.63854980e-02,  -7.63854980e-02],
                        [ -6.97937012e-02,  -6.97631836e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  1.23840332e-01,   1.23840332e-01],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  1.13677979e-01,   1.13677979e-01],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -1.08917236e-01,  -1.08917236e-01],
                        [ -1.04675293e-01,  -1.04675293e-01],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  4.29992676e-02,   4.29992676e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.21673584e-01,   1.21673584e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  3.11279297e-03,   3.14331055e-03],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  5.55725098e-02,   5.55725098e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -1.12060547e-01,  -1.12060547e-01],
                        [ -1.88568115e-01,  -1.88568115e-01],
                        [ -2.38494873e-01,  -2.38525391e-01],
                        [ -2.51495361e-01,  -2.51495361e-01],
                        [ -2.32940674e-01,  -2.32940674e-01],
                        [ -1.98730469e-01,  -1.98730469e-01],
                        [ -1.64825439e-01,  -1.64825439e-01],
                        [ -1.40686035e-01,  -1.40686035e-01],
                        [ -1.26800537e-01,  -1.26800537e-01],
                        [ -1.15539551e-01,  -1.15539551e-01],
                        [ -1.00585938e-01,  -1.00585938e-01],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  1.18652344e-01,   1.18652344e-01],
                        [  1.31439209e-01,   1.31439209e-01],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -9.11254883e-02,  -9.11254883e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  3.57055664e-03,   3.57055664e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  5.70373535e-02,   5.70373535e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -1.03668213e-01,  -1.03668213e-01],
                        [ -1.75415039e-01,  -1.75415039e-01],
                        [ -2.31933594e-01,  -2.31933594e-01],
                        [ -2.53540039e-01,  -2.53540039e-01],
                        [ -2.37304688e-01,  -2.37304688e-01],
                        [ -2.00683594e-01,  -2.00683594e-01],
                        [ -1.66137695e-01,  -1.66137695e-01],
                        [ -1.43005371e-01,  -1.43005371e-01],
                        [ -1.26342773e-01,  -1.26342773e-01],
                        [ -1.09558105e-01,  -1.09558105e-01],
                        [ -9.32617188e-02,  -9.32617188e-02],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -7.32116699e-02,  -7.32116699e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  8.39233398e-03,   8.39233398e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  1.18988037e-01,   1.18988037e-01],
                        [  1.42303467e-01,   1.42303467e-01],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  1.50482178e-01,   1.50482178e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  5.38330078e-02,   5.38330078e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -8.24279785e-02,  -8.24279785e-02],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -8.73107910e-02,  -8.73107910e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  5.54199219e-02,   5.54199219e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  5.25512695e-02,   5.25512695e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.55126953e-02,   2.55126953e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -1.19689941e-01,  -1.19689941e-01],
                        [ -1.91864014e-01,  -1.91864014e-01],
                        [ -2.45117188e-01,  -2.45117188e-01],
                        [ -2.65502930e-01,  -2.65502930e-01],
                        [ -2.50030518e-01,  -2.50030518e-01],
                        [ -2.10449219e-01,  -2.10449219e-01],
                        [ -1.66870117e-01,  -1.66870117e-01],
                        [ -1.34429932e-01,  -1.34429932e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -1.02600098e-01,  -1.02600098e-01],
                        [ -8.77990723e-02,  -8.77990723e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  4.65698242e-02,   4.65698242e-02],
                        [  6.39648438e-02,   6.39648438e-02],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.73004150e-01,   1.73004150e-01],
                        [  2.10418701e-01,   2.10418701e-01],
                        [  2.21557617e-01,   2.21557617e-01],
                        [  1.89147949e-01,   1.89147949e-01],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.18408203e-02,   1.18408203e-02],
                        [ -7.05871582e-02,  -7.05871582e-02],
                        [ -1.05407715e-01,  -1.05407715e-01],
                        [ -9.15527344e-02,  -9.15527344e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  2.92968750e-03,   2.92968750e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  1.06933594e-01,   1.06933594e-01],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  8.26721191e-02,   8.26721191e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -9.87548828e-02,  -9.87548828e-02],
                        [ -1.81976318e-01,  -1.81976318e-01],
                        [ -2.50701904e-01,  -2.50701904e-01],
                        [ -2.82623291e-01,  -2.82623291e-01],
                        [ -2.67486572e-01,  -2.67486572e-01],
                        [ -2.21466064e-01,  -2.21466064e-01],
                        [ -1.77001953e-01,  -1.77001953e-01],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -1.31896973e-01,  -1.31896973e-01],
                        [ -1.09436035e-01,  -1.09436035e-01],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -7.66906738e-02,  -7.66906738e-02],
                        [ -7.26318359e-02,  -7.26318359e-02],
                        [ -6.75354004e-02,  -6.75354004e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  1.64123535e-01,   1.64123535e-01],
                        [  2.15301514e-01,   2.15301514e-01],
                        [  2.57110596e-01,   2.57110596e-01],
                        [  2.75268555e-01,   2.75268555e-01],
                        [  2.52197266e-01,   2.52197266e-01],
                        [  1.76971436e-01,   1.76971436e-01],
                        [  6.36291504e-02,   6.36291504e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -1.22070312e-01,  -1.22070312e-01],
                        [ -1.40869141e-01,  -1.40869141e-01],
                        [ -1.17218018e-01,  -1.17218018e-01],
                        [ -7.78503418e-02,  -7.78503418e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  5.70373535e-02,   5.70373535e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  2.41088867e-03,   2.41088867e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -3.30810547e-02,  -3.30810547e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  1.11267090e-01,   1.11267090e-01],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.12579346e-01,   1.12579346e-01],
                        [  1.06689453e-01,   1.06689453e-01],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -8.70666504e-02,  -8.70666504e-02],
                        [ -1.72454834e-01,  -1.72454834e-01],
                        [ -2.49420166e-01,  -2.49420166e-01],
                        [ -2.85919189e-01,  -2.85919189e-01],
                        [ -2.70782471e-01,  -2.70782471e-01],
                        [ -2.23663330e-01,  -2.23663330e-01],
                        [ -1.76666260e-01,  -1.76666260e-01],
                        [ -1.48986816e-01,  -1.48986816e-01],
                        [ -1.37115479e-01,  -1.37115479e-01],
                        [ -1.26220703e-01,  -1.26220703e-01],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -8.41369629e-02,  -8.41369629e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  6.80541992e-02,   6.80541992e-02],
                        [  1.39251709e-01,   1.39251709e-01],
                        [  2.16644287e-01,   2.16644287e-01],
                        [  2.79846191e-01,   2.79846191e-01],
                        [  3.15002441e-01,   3.15002441e-01],
                        [  3.14636230e-01,   3.14636230e-01],
                        [  2.71148682e-01,   2.71148682e-01],
                        [  1.81640625e-01,   1.81640625e-01],
                        [  6.01196289e-02,   6.01196289e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -1.44317627e-01,  -1.44317627e-01],
                        [ -1.66534424e-01,  -1.66534424e-01],
                        [ -1.34796143e-01,  -1.34796143e-01],
                        [ -8.35571289e-02,  -8.35571289e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  6.89392090e-02,   6.89392090e-02],
                        [  8.65478516e-02,   8.65478516e-02],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  9.54895020e-02,   9.54895020e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -1.42242432e-01,  -1.42242432e-01],
                        [ -2.21099854e-01,  -2.21099854e-01],
                        [ -2.78991699e-01,  -2.78991699e-01],
                        [ -2.89062500e-01,  -2.89062500e-01],
                        [ -2.50274658e-01,  -2.50274658e-01],
                        [ -1.90460205e-01,  -1.90460205e-01],
                        [ -1.41479492e-01,  -1.41479492e-01],
                        [ -1.16851807e-01,  -1.16851807e-01],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -1.10717773e-01,  -1.10717773e-01],
                        [ -1.04248047e-01,  -1.04248047e-01],
                        [ -9.09729004e-02,  -9.09729004e-02],
                        [ -7.85522461e-02,  -7.85522461e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  2.11914062e-01,   2.11914062e-01],
                        [  2.70538330e-01,   2.70538330e-01],
                        [  3.00872803e-01,   3.00872803e-01],
                        [  2.98370361e-01,   2.98370361e-01],
                        [  2.66693115e-01,   2.66693115e-01],
                        [  2.09808350e-01,   2.09808350e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  2.61840820e-02,   2.61840820e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.67541504e-01,  -1.67541504e-01],
                        [ -1.27319336e-01,  -1.27319336e-01],
                        [ -7.30285645e-02,  -7.30285645e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  6.29882812e-02,   6.29882812e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.41052246e-01,   1.41052246e-01],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  1.12731934e-01,   1.12731934e-01],
                        [  7.05566406e-02,   7.05566406e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  5.63659668e-02,   5.63659668e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.22253418e-01,   1.22253418e-01],
                        [  9.50317383e-02,   9.50317383e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -1.53167725e-01,  -1.53167725e-01],
                        [ -2.45239258e-01,  -2.45239258e-01],
                        [ -3.05938721e-01,  -3.05938721e-01],
                        [ -3.15185547e-01,  -3.15185547e-01],
                        [ -2.72949219e-01,  -2.72949219e-01],
                        [ -2.09899902e-01,  -2.09899902e-01],
                        [ -1.63787842e-01,  -1.63787842e-01],
                        [ -1.43005371e-01,  -1.43005371e-01],
                        [ -1.27868652e-01,  -1.27868652e-01],
                        [ -1.02905273e-01,  -1.02905273e-01],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  1.44714355e-01,   1.44714355e-01],
                        [  2.02056885e-01,   2.02056885e-01],
                        [  2.45727539e-01,   2.45727539e-01],
                        [  2.66479492e-01,   2.66479492e-01],
                        [  2.62054443e-01,   2.62054443e-01],
                        [  2.42218018e-01,   2.42218018e-01],
                        [  2.22167969e-01,   2.22167969e-01],
                        [  2.04895020e-01,   2.04895020e-01],
                        [  1.74835205e-01,   1.74835205e-01],
                        [  1.13739014e-01,   1.13739014e-01],
                        [  2.30407715e-02,   2.30407715e-02],
                        [ -7.09228516e-02,  -7.09228516e-02],
                        [ -1.35009766e-01,  -1.35009766e-01],
                        [ -1.54693604e-01,  -1.54693604e-01],
                        [ -1.42913818e-01,  -1.42913818e-01],
                        [ -1.23748779e-01,  -1.23748779e-01],
                        [ -1.10168457e-01,  -1.10168457e-01],
                        [ -9.99145508e-02,  -9.99145508e-02],
                        [ -8.84094238e-02,  -8.84094238e-02],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  1.12884521e-01,   1.12884521e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  1.30065918e-01,   1.30065918e-01],
                        [  1.36993408e-01,   1.36993408e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  8.45947266e-02,   8.45947266e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [ -8.53881836e-02,  -8.53881836e-02],
                        [ -1.92443848e-01,  -1.92443848e-01],
                        [ -2.74444580e-01,  -2.74444580e-01],
                        [ -3.06579590e-01,  -3.06579590e-01],
                        [ -2.88055420e-01,  -2.88055420e-01],
                        [ -2.37915039e-01,  -2.37915039e-01],
                        [ -1.81701660e-01,  -1.81701660e-01],
                        [ -1.39831543e-01,  -1.39831543e-01],
                        [ -1.16821289e-01,  -1.16821289e-01],
                        [ -1.01287842e-01,  -1.01287842e-01],
                        [ -8.25195312e-02,  -8.25195312e-02],
                        [ -6.45751953e-02,  -6.45751953e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.87866211e-01,   1.87866211e-01],
                        [  2.31445312e-01,   2.31445312e-01],
                        [  2.45574951e-01,   2.45574951e-01],
                        [  2.35260010e-01,   2.35260010e-01],
                        [  2.19848633e-01,   2.19848633e-01],
                        [  2.14660645e-01,   2.14660645e-01],
                        [  2.16644287e-01,   2.16644287e-01],
                        [  2.10449219e-01,   2.10449219e-01],
                        [  1.83319092e-01,   1.83319092e-01],
                        [  1.30798340e-01,   1.30798340e-01],
                        [  5.59082031e-02,   5.59082031e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -1.12579346e-01,  -1.12579346e-01],
                        [ -1.65924072e-01,  -1.65924072e-01],
                        [ -1.75445557e-01,  -1.75445557e-01],
                        [ -1.45111084e-01,  -1.45111084e-01],
                        [ -1.00158691e-01,  -1.00158691e-01],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.73840332e-02,   3.73840332e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  3.92456055e-02,   3.92456055e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  9.25903320e-02,   9.25903320e-02],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.15722656e-01,   1.15722656e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  1.36901855e-01,   1.36901855e-01],
                        [  1.59240723e-01,   1.59240723e-01],
                        [  1.54357910e-01,   1.54357910e-01],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  5.61523438e-02,   5.61523438e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -1.25610352e-01,  -1.25610352e-01],
                        [ -2.20550537e-01,  -2.20550537e-01],
                        [ -2.85247803e-01,  -2.85247803e-01],
                        [ -3.00354004e-01,  -3.00354004e-01],
                        [ -2.67272949e-01,  -2.67272949e-01],
                        [ -2.09716797e-01,  -2.09716797e-01],
                        [ -1.60888672e-01,  -1.60888672e-01],
                        [ -1.39831543e-01,  -1.39831543e-01],
                        [ -1.37756348e-01,  -1.37756348e-01],
                        [ -1.32141113e-01,  -1.32141113e-01],
                        [ -1.11755371e-01,  -1.11755371e-01],
                        [ -8.43505859e-02,  -8.43505859e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  6.44836426e-02,   6.44836426e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.42639160e-01,   1.42639160e-01],
                        [  1.82708740e-01,   1.82708740e-01],
                        [  2.15454102e-01,   2.15454102e-01],
                        [  2.29766846e-01,   2.29766846e-01],
                        [  2.22198486e-01,   2.22198486e-01],
                        [  2.05078125e-01,   2.05078125e-01],
                        [  1.95312500e-01,   1.95312500e-01],
                        [  1.96411133e-01,   1.96411133e-01],
                        [  1.97662354e-01,   1.97662354e-01],
                        [  1.85485840e-01,   1.85485840e-01],
                        [  1.50634766e-01,   1.50634766e-01],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [ -8.75244141e-02,  -8.75244141e-02],
                        [ -1.61041260e-01,  -1.61041260e-01],
                        [ -1.94702148e-01,  -1.94702148e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -1.53961182e-01,  -1.53961182e-01],
                        [ -1.19354248e-01,  -1.19354248e-01],
                        [ -9.51843262e-02,  -9.51843262e-02],
                        [ -7.73010254e-02,  -7.73010254e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -6.43615723e-02,  -6.43615723e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  6.51245117e-02,   6.51245117e-02],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  1.29150391e-01,   1.29150391e-01],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  1.01104736e-01,   1.01104736e-01],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  7.96813965e-02,   7.96813965e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -1.59057617e-01,  -1.59057617e-01],
                        [ -2.42004395e-01,  -2.42004395e-01],
                        [ -2.96752930e-01,  -2.96752930e-01],
                        [ -3.01177979e-01,  -3.01177979e-01],
                        [ -2.56530762e-01,  -2.56530762e-01],
                        [ -1.94641113e-01,  -1.94641113e-01],
                        [ -1.48895264e-01,  -1.48895264e-01],
                        [ -1.25610352e-01,  -1.25610352e-01],
                        [ -1.11755371e-01,  -1.11755371e-01],
                        [ -9.85412598e-02,  -9.85412598e-02],
                        [ -8.60900879e-02,  -8.60900879e-02],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -6.49108887e-02,  -6.49108887e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  1.06842041e-01,   1.06842041e-01],
                        [  1.53503418e-01,   1.53503418e-01],
                        [  1.94244385e-01,   1.94244385e-01],
                        [  2.18841553e-01,   2.18841553e-01],
                        [  2.18780518e-01,   2.18780518e-01],
                        [  2.00469971e-01,   2.00469971e-01],
                        [  1.82373047e-01,   1.82373047e-01],
                        [  1.77520752e-01,   1.77520752e-01],
                        [  1.83685303e-01,   1.83685303e-01],
                        [  1.90032959e-01,   1.90032959e-01],
                        [  1.86828613e-01,   1.86828613e-01],
                        [  1.68121338e-01,   1.68121338e-01],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  7.15026855e-02,   7.15026855e-02],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -9.79614258e-02,  -9.79614258e-02],
                        [ -1.71691895e-01,  -1.71691895e-01],
                        [ -2.06451416e-01,  -2.06451416e-01],
                        [ -1.96868896e-01,  -1.96868896e-01],
                        [ -1.57073975e-01,  -1.57073975e-01],
                        [ -1.09985352e-01,  -1.09985352e-01],
                        [ -7.33642578e-02,  -7.33642578e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  7.37915039e-02,   7.37915039e-02],
                        [  1.24481201e-01,   1.24481201e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  7.64770508e-02,   7.64770508e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  1.36077881e-01,   1.36077881e-01],
                        [  1.49261475e-01,   1.49261475e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [ -7.56835938e-02,  -7.56835938e-02],
                        [ -1.76666260e-01,  -1.76666260e-01],
                        [ -2.65655518e-01,  -2.65655518e-01],
                        [ -3.15948486e-01,  -3.15948486e-01],
                        [ -3.06610107e-01,  -3.06610107e-01],
                        [ -2.49786377e-01,  -2.49786377e-01],
                        [ -1.87103271e-01,  -1.87103271e-01],
                        [ -1.48559570e-01,  -1.48559570e-01],
                        [ -1.27136230e-01,  -1.27136230e-01],
                        [ -1.01989746e-01,  -1.01989746e-01],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  4.15039062e-03,   4.15039062e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  1.30737305e-01,   1.30737305e-01],
                        [  1.81671143e-01,   1.81671143e-01],
                        [  2.11700439e-01,   2.11700439e-01],
                        [  2.11364746e-01,   2.11364746e-01],
                        [  1.91284180e-01,   1.91284180e-01],
                        [  1.71905518e-01,   1.71905518e-01],
                        [  1.63055420e-01,   1.63055420e-01],
                        [  1.60400391e-01,   1.60400391e-01],
                        [  1.56860352e-01,   1.56860352e-01],
                        [  1.51397705e-01,   1.51397705e-01],
                        [  1.49139404e-01,   1.49139404e-01],
                        [  1.52832031e-01,   1.52832031e-01],
                        [  1.53625488e-01,   1.53625488e-01],
                        [  1.34307861e-01,   1.34307861e-01],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -9.04235840e-02,  -9.04235840e-02],
                        [ -1.71722412e-01,  -1.71722412e-01],
                        [ -2.12310791e-01,  -2.12310791e-01],
                        [ -1.95953369e-01,  -1.95953369e-01],
                        [ -1.37329102e-01,  -1.37329102e-01],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  3.57055664e-03,   3.57055664e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -6.87255859e-02,  -6.87255859e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  1.04217529e-01,   1.04217529e-01],
                        [  1.30950928e-01,   1.30950928e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  9.53063965e-02,   9.53063965e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  1.17614746e-01,   1.17614746e-01],
                        [  1.33239746e-01,   1.33239746e-01],
                        [  1.39923096e-01,   1.39923096e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -1.38916016e-01,  -1.38916016e-01],
                        [ -2.34558105e-01,  -2.34558105e-01],
                        [ -2.94403076e-01,  -2.94403076e-01],
                        [ -3.01605225e-01,  -3.01605225e-01],
                        [ -2.59185791e-01,  -2.59185791e-01],
                        [ -1.93542480e-01,  -1.93542480e-01],
                        [ -1.38885498e-01,  -1.38885498e-01],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -9.97619629e-02,  -9.97619629e-02],
                        [ -9.33837891e-02,  -9.33837891e-02],
                        [ -8.85620117e-02,  -8.85620117e-02],
                        [ -8.73718262e-02,  -8.73718262e-02],
                        [ -8.73413086e-02,  -8.73413086e-02],
                        [ -8.02612305e-02,  -8.02612305e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -7.49511719e-02,  -7.49511719e-02],
                        [ -7.59887695e-02,  -7.59887695e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -5.25207520e-02,  -5.25207520e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  1.59393311e-01,   1.59393311e-01],
                        [  2.14508057e-01,   2.14508057e-01],
                        [  2.40875244e-01,   2.40875244e-01],
                        [  2.31475830e-01,   2.31475830e-01],
                        [  1.97937012e-01,   1.97937012e-01],
                        [  1.60095215e-01,   1.60095215e-01],
                        [  1.29821777e-01,   1.29821777e-01],
                        [  1.09283447e-01,   1.09313965e-01],
                        [  9.98535156e-02,   9.98535156e-02],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.39770508e-01,   1.39770508e-01],
                        [  1.45080566e-01,   1.45080566e-01],
                        [  1.43493652e-01,   1.43493652e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  5.58471680e-02,   5.58471680e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -1.39373779e-01,  -1.39373779e-01],
                        [ -2.03216553e-01,  -2.03216553e-01],
                        [ -2.08557129e-01,  -2.08557129e-01],
                        [ -1.66503906e-01,  -1.66503906e-01],
                        [ -1.11511230e-01,  -1.11511230e-01],
                        [ -7.35473633e-02,  -7.35473633e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  5.25512695e-02,   5.25512695e-02],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.07482910e-01,   1.07482910e-01],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -8.57543945e-03,  -8.60595703e-03],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  1.03179932e-01,   1.03179932e-01],
                        [  1.17736816e-01,   1.17736816e-01],
                        [  1.30187988e-01,   1.30187988e-01],
                        [  1.35894775e-01,   1.35894775e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  9.07287598e-02,   9.07287598e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [ -6.37207031e-02,  -6.37207031e-02],
                        [ -1.67480469e-01,  -1.67480469e-01],
                        [ -2.58819580e-01,  -2.58819580e-01],
                        [ -3.04870605e-01,  -3.04870605e-01],
                        [ -2.89306641e-01,  -2.89306641e-01],
                        [ -2.29461670e-01,  -2.29461670e-01],
                        [ -1.65924072e-01,  -1.65924072e-01],
                        [ -1.30920410e-01,  -1.30920410e-01],
                        [ -1.23596191e-01,  -1.23596191e-01],
                        [ -1.19171143e-01,  -1.19171143e-01],
                        [ -1.00677490e-01,  -1.00677490e-01],
                        [ -7.34252930e-02,  -7.34252930e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -7.49816895e-02,  -7.49816895e-02],
                        [ -8.30078125e-02,  -8.30078125e-02],
                        [ -7.88879395e-02,  -7.88879395e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.61865234e-01,   1.61865234e-01],
                        [  2.06481934e-01,   2.06481934e-01],
                        [  2.29614258e-01,   2.29614258e-01],
                        [  2.22930908e-01,   2.22930908e-01],
                        [  1.93115234e-01,   1.93115234e-01],
                        [  1.56738281e-01,   1.56738281e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  1.01043701e-01,   1.01043701e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.47491455e-01,   1.47491455e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  4.27246094e-02,   4.27246094e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -1.31591797e-01,  -1.31591797e-01],
                        [ -1.96624756e-01,  -1.96624756e-01],
                        [ -2.16888428e-01,  -2.16888428e-01],
                        [ -1.92535400e-01,  -1.92535400e-01],
                        [ -1.40869141e-01,  -1.40869141e-01],
                        [ -8.78295898e-02,  -8.78601074e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -7.27539062e-02,  -7.27539062e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  7.98339844e-02,   7.98339844e-02],
                        [  1.15142822e-01,   1.15173340e-01],
                        [  1.17858887e-01,   1.17858887e-01],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.50482178e-01,   1.50482178e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.50756836e-01,   1.50756836e-01],
                        [  1.30096436e-01,   1.30096436e-01],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [ -7.17773438e-02,  -7.17773438e-02],
                        [ -1.71478271e-01,  -1.71478271e-01],
                        [ -2.57690430e-01,  -2.57690430e-01],
                        [ -3.02398682e-01,  -3.02398682e-01],
                        [ -2.88269043e-01,  -2.88269043e-01],
                        [ -2.28302002e-01,  -2.28302002e-01],
                        [ -1.62261963e-01,  -1.62261963e-01],
                        [ -1.23199463e-01,  -1.23199463e-01],
                        [ -1.10443115e-01,  -1.10443115e-01],
                        [ -1.02935791e-01,  -1.02935791e-01],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -7.70263672e-02,  -7.70263672e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -2.31933594e-03,  -2.34985352e-03],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -7.72399902e-02,  -7.72399902e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.62536621e-01,   1.62536621e-01],
                        [  1.93328857e-01,   1.93328857e-01],
                        [  2.01019287e-01,   2.01019287e-01],
                        [  1.88720703e-01,   1.88720703e-01],
                        [  1.68518066e-01,   1.68518066e-01],
                        [  1.49078369e-01,   1.49078369e-01],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  9.60388184e-02,   9.60388184e-02],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  1.16790771e-01,   1.16760254e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.11877441e-01,   1.11877441e-01],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -1.55609131e-01,  -1.55609131e-01],
                        [ -2.01660156e-01,  -2.01660156e-01],
                        [ -2.01141357e-01,  -2.01141357e-01],
                        [ -1.60675049e-01,  -1.60675049e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -7.62329102e-02,  -7.62329102e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -7.25097656e-02,  -7.25097656e-02],
                        [ -7.60192871e-02,  -7.60192871e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  1.28173828e-01,   1.28173828e-01],
                        [  1.37817383e-01,   1.37817383e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  8.85314941e-02,   8.85314941e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  4.44335938e-02,   4.44641113e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  3.76281738e-02,   3.75976562e-02],
                        [  5.05981445e-02,   5.05676270e-02],
                        [  6.94580078e-02,   6.94580078e-02],
                        [  9.41772461e-02,   9.41772461e-02],
                        [  1.23291016e-01,   1.23291016e-01],
                        [  1.50115967e-01,   1.50115967e-01],
                        [  1.62475586e-01,   1.62475586e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  4.26330566e-02,   4.26330566e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -1.56585693e-01,  -1.56585693e-01],
                        [ -2.58697510e-01,  -2.58697510e-01],
                        [ -3.18359375e-01,  -3.18328857e-01],
                        [ -3.06915283e-01,  -3.06915283e-01],
                        [ -2.34558105e-01,  -2.34558105e-01],
                        [ -1.52160645e-01,  -1.52160645e-01],
                        [ -1.07391357e-01,  -1.07391357e-01],
                        [ -1.03179932e-01,  -1.03179932e-01],
                        [ -1.08947754e-01,  -1.08978271e-01],
                        [ -1.02478027e-01,  -1.02478027e-01],
                        [ -8.70056152e-02,  -8.69750977e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -2.49938965e-02,  -2.49633789e-02],
                        [ -4.61730957e-02,  -4.62036133e-02],
                        [ -6.07910156e-02,  -6.08215332e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -5.80749512e-02,  -5.81054688e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [  1.25122070e-02,   1.24816895e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  1.77246094e-01,   1.77246094e-01],
                        [  2.09014893e-01,   2.09014893e-01],
                        [  2.08648682e-01,   2.08648682e-01],
                        [  1.81182861e-01,   1.81182861e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.03546143e-01,   1.03576660e-01],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  8.28552246e-02,   8.28552246e-02],
                        [  7.65380859e-02,   7.65686035e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  6.53076172e-02,   6.53076172e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  9.30480957e-02,   9.30480957e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [ -1.78527832e-02,  -1.78222656e-02],
                        [ -1.04919434e-01,  -1.04919434e-01],
                        [ -1.76147461e-01,  -1.76177979e-01],
                        [ -2.02331543e-01,  -2.02331543e-01],
                        [ -1.80877686e-01,  -1.80877686e-01],
                        [ -1.38580322e-01,  -1.38580322e-01],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -7.56530762e-02,  -7.56530762e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  1.83105469e-04,   2.13623047e-04],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -6.93664551e-02,  -6.93969727e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -6.00280762e-02,  -6.00585938e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  1.02172852e-01,   1.02172852e-01],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  8.53881836e-02,   8.53881836e-02],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.17004395e-01,   1.17004395e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.48651123e-01,   1.48651123e-01],
                        [  1.36810303e-01,   1.36810303e-01],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [ -6.58874512e-02,  -6.59179688e-02],
                        [ -1.67724609e-01,  -1.67724609e-01],
                        [ -2.51403809e-01,  -2.51403809e-01],
                        [ -2.92358398e-01,  -2.92358398e-01],
                        [ -2.77435303e-01,  -2.77435303e-01],
                        [ -2.20397949e-01,  -2.20397949e-01],
                        [ -1.59698486e-01,  -1.59698486e-01],
                        [ -1.26434326e-01,  -1.26434326e-01],
                        [ -1.17706299e-01,  -1.17706299e-01],
                        [ -1.10626221e-01,  -1.10626221e-01],
                        [ -9.52758789e-02,  -9.53063965e-02],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -7.63244629e-02,  -7.63244629e-02],
                        [ -7.18994141e-02,  -7.18994141e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -3.27758789e-02,  -3.27453613e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  1.11389160e-02,   1.11694336e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -7.38525391e-02,  -7.38525391e-02],
                        [ -6.55517578e-02,  -6.55212402e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [  4.27246094e-02,   4.27551270e-02],
                        [  1.12487793e-01,   1.12487793e-01],
                        [  1.79168701e-01,   1.79138184e-01],
                        [  2.18383789e-01,   2.18383789e-01],
                        [  2.18200684e-01,   2.18231201e-01],
                        [  1.88781738e-01,   1.88781738e-01],
                        [  1.52404785e-01,   1.52374268e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.09954834e-01,   1.09954834e-01],
                        [  9.93652344e-02,   9.93347168e-02],
                        [  8.59069824e-02,   8.59069824e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  6.82983398e-02,   6.82678223e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  6.36596680e-02,   6.36596680e-02],
                        [  6.96411133e-02,   6.96411133e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  8.78601074e-02,   8.78601074e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -8.03222656e-02,  -8.03222656e-02],
                        [ -1.38244629e-01,  -1.38275146e-01],
                        [ -1.67419434e-01,  -1.67419434e-01],
                        [ -1.64337158e-01,  -1.64337158e-01],
                        [ -1.40502930e-01,  -1.40502930e-01],
                        [ -1.12823486e-01,  -1.12823486e-01],
                        [ -9.10949707e-02,  -9.10644531e-02],
                        [ -7.47070312e-02,  -7.47070312e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -4.27551270e-02,  -4.27246094e-02],
                        [ -3.14941406e-02,  -3.14636230e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -5.28869629e-02,  -5.29174805e-02],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -8.59985352e-02,  -8.59985352e-02],
                        [ -8.27941895e-02,  -8.27941895e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  5.79223633e-02,   5.79223633e-02],
                        [  8.62121582e-02,   8.61816406e-02],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  8.50524902e-02,   8.50524902e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  5.94177246e-02,   5.94177246e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  4.45556641e-02,   4.45861816e-02],
                        [  4.49829102e-02,   4.49523926e-02],
                        [  4.22668457e-02,   4.22363281e-02],
                        [  4.05273438e-02,   4.05578613e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  5.19714355e-02,   5.19714355e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.42150879e-01,   1.42150879e-01],
                        [  1.21002197e-01,   1.21002197e-01],
                        [  6.54907227e-02,   6.55212402e-02],
                        [ -2.02636719e-02,  -2.02941895e-02],
                        [ -1.19995117e-01,  -1.19995117e-01],
                        [ -2.10266113e-01,  -2.10235596e-01],
                        [ -2.66784668e-01,  -2.66784668e-01],
                        [ -2.74810791e-01,  -2.74810791e-01],
                        [ -2.40661621e-01,  -2.40661621e-01],
                        [ -1.89208984e-01,  -1.89178467e-01],
                        [ -1.44989014e-01,  -1.44989014e-01],
                        [ -1.17523193e-01,  -1.17553711e-01],
                        [ -1.02569580e-01,  -1.02569580e-01],
                        [ -9.28039551e-02,  -9.27734375e-02],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -7.77282715e-02,  -7.77587891e-02],
                        [ -6.96716309e-02,  -6.96716309e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -8.56628418e-02,  -8.56628418e-02],
                        [ -8.67309570e-02,  -8.67309570e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [  1.47399902e-02,   1.47705078e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  1.25213623e-01,   1.25183105e-01],
                        [  1.76727295e-01,   1.76727295e-01],
                        [  2.04681396e-01,   2.04711914e-01],
                        [  2.00836182e-01,   2.00836182e-01],
                        [  1.71142578e-01,   1.71112061e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  9.72900391e-02,   9.72900391e-02],
                        [  8.06884766e-02,   8.06579590e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  7.22961426e-02,   7.22961426e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  3.82690430e-02,   3.82995605e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  8.47473145e-02,   8.47473145e-02],
                        [  1.08642578e-01,   1.08612061e-01],
                        [  1.22161865e-01,   1.22192383e-01],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [ -4.34570312e-02,  -4.34265137e-02],
                        [ -1.31866455e-01,  -1.31896973e-01],
                        [ -1.89239502e-01,  -1.89239502e-01],
                        [ -1.94305420e-01,  -1.94274902e-01],
                        [ -1.61468506e-01,  -1.61499023e-01],
                        [ -1.25640869e-01,  -1.25640869e-01],
                        [ -1.08062744e-01,  -1.08032227e-01],
                        [ -1.02020264e-01,  -1.02020264e-01],
                        [ -9.11560059e-02,  -9.11560059e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -7.62634277e-02,  -7.62634277e-02],
                        [ -9.18579102e-02,  -9.18579102e-02],
                        [ -9.20104980e-02,  -9.20104980e-02],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  6.87255859e-02,   6.86950684e-02],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.15722656e-01,   1.15722656e-01],
                        [  9.17968750e-02,   9.17968750e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  5.30395508e-02,   5.30395508e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  3.93371582e-02,   3.93676758e-02],
                        [  3.16162109e-02,   3.16467285e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  4.20837402e-02,   4.21142578e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  6.02722168e-02,   6.02722168e-02],
                        [  5.34362793e-02,   5.34667969e-02],
                        [  5.35583496e-02,   5.35278320e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  7.98339844e-02,   7.98339844e-02],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  1.30859375e-01,   1.30859375e-01],
                        [  1.44836426e-01,   1.44836426e-01],
                        [  1.40625000e-01,   1.40625000e-01],
                        [  1.15264893e-01,   1.15234375e-01],
                        [  6.61315918e-02,   6.61315918e-02],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -9.46350098e-02,  -9.46655273e-02],
                        [ -1.84753418e-01,  -1.84753418e-01],
                        [ -2.53936768e-01,  -2.53936768e-01],
                        [ -2.76824951e-01,  -2.76855469e-01],
                        [ -2.45574951e-01,  -2.45574951e-01],
                        [ -1.84356689e-01,  -1.84326172e-01],
                        [ -1.31561279e-01,  -1.31591797e-01],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -1.00982666e-01,  -1.00952148e-01],
                        [ -9.81445312e-02,  -9.81445312e-02],
                        [ -9.26513672e-02,  -9.26818848e-02],
                        [ -8.88366699e-02,  -8.88366699e-02],
                        [ -8.62731934e-02,  -8.62731934e-02],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -2.53906250e-02,  -2.53601074e-02],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.32751465e-02,  -1.33056641e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -3.45458984e-02,  -3.45153809e-02],
                        [ -5.48095703e-02,  -5.48400879e-02],
                        [ -6.56127930e-02,  -6.56433105e-02],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [  1.89208984e-03,   1.86157227e-03],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  1.85546875e-01,   1.85546875e-01],
                        [  2.19482422e-01,   2.19482422e-01],
                        [  2.14477539e-01,   2.14477539e-01],
                        [  1.74957275e-01,   1.74957275e-01],
                        [  1.25305176e-01,   1.25274658e-01],
                        [  9.06372070e-02,   9.06372070e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  7.86743164e-02,   7.86743164e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  8.13293457e-02,   8.13293457e-02],
                        [  7.34558105e-02,   7.34558105e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.27532959e-01,   1.27502441e-01],
                        [  1.29730225e-01,   1.29730225e-01],
                        [  9.78393555e-02,   9.78393555e-02],
                        [  2.17895508e-02,   2.17895508e-02],
                        [ -8.28552246e-02,  -8.28552246e-02],
                        [ -1.76910400e-01,  -1.76879883e-01],
                        [ -2.22534180e-01,  -2.22534180e-01],
                        [ -2.11242676e-01,  -2.11273193e-01],
                        [ -1.65832520e-01,  -1.65802002e-01],
                        [ -1.16241455e-01,  -1.16210938e-01],
                        [ -7.89794922e-02,  -7.90100098e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -4.58984375e-02,  -4.58679199e-02],
                        [ -4.11987305e-02,  -4.12292480e-02],
                        [ -4.22363281e-02,  -4.22668457e-02],
                        [ -5.14526367e-02,  -5.14221191e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -4.28771973e-02,  -4.28466797e-02],
                        [ -2.16064453e-02,  -2.15759277e-02],
                        [ -9.06372070e-03,  -9.09423828e-03],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -7.38525391e-03,  -7.35473633e-03],
                        [ -9.70458984e-03,  -9.73510742e-03],
                        [ -1.35192871e-02,  -1.35498047e-02],
                        [ -2.19726562e-02,  -2.19421387e-02],
                        [ -3.65905762e-02,  -3.65600586e-02],
                        [ -5.50537109e-02,  -5.50842285e-02],
                        [ -7.35168457e-02,  -7.35168457e-02],
                        [ -8.62731934e-02,  -8.62426758e-02],
                        [ -8.37707520e-02,  -8.37707520e-02],
                        [ -5.91430664e-02,  -5.91430664e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  5.42602539e-02,   5.42602539e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  4.48303223e-02,   4.47998047e-02],
                        [  4.93469238e-02,   4.93774414e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  6.19506836e-02,   6.19201660e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  5.16357422e-02,   5.16662598e-02],
                        [  5.43823242e-02,   5.43518066e-02],
                        [  6.53686523e-02,   6.53381348e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  1.15936279e-01,   1.15905762e-01],
                        [  1.32873535e-01,   1.32873535e-01],
                        [  1.41448975e-01,   1.41448975e-01],
                        [  1.31744385e-01,   1.31744385e-01],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  1.94702148e-02,   1.95007324e-02],
                        [ -8.21228027e-02,  -8.21228027e-02],
                        [ -1.89544678e-01,  -1.89575195e-01],
                        [ -2.71972656e-01,  -2.71942139e-01],
                        [ -3.02093506e-01,  -3.02093506e-01],
                        [ -2.72430420e-01,  -2.72430420e-01],
                        [ -2.04620361e-01,  -2.04620361e-01],
                        [ -1.36444092e-01,  -1.36413574e-01],
                        [ -9.34143066e-02,  -9.34143066e-02],
                        [ -7.61413574e-02,  -7.61718750e-02],
                        [ -7.10449219e-02,  -7.10144043e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -6.36901855e-02,  -6.37207031e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -7.74841309e-02,  -7.74536133e-02],
                        [ -7.91015625e-02,  -7.91320801e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -4.16564941e-02,  -4.16259766e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -1.40380859e-02,  -1.40686035e-02],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [ -1.78222656e-02,  -1.78527832e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  8.78601074e-02,   8.78601074e-02],
                        [  1.45812988e-01,   1.45812988e-01],
                        [  1.87316895e-01,   1.87316895e-01],
                        [  2.01690674e-01,   2.01690674e-01],
                        [  1.86309814e-01,   1.86309814e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.17736816e-01,   1.17736816e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  8.50830078e-02,   8.50524902e-02],
                        [  7.70568848e-02,   7.70568848e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  4.66918945e-02,   4.67224121e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.00195312e-02,   1.99890137e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  6.53991699e-02,   6.54296875e-02],
                        [  9.34448242e-02,   9.34143066e-02],
                        [  1.20483398e-01,   1.20483398e-01],
                        [  1.28295898e-01,   1.28326416e-01],
                        [  9.60083008e-02,   9.60388184e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [ -7.86743164e-02,  -7.86743164e-02],
                        [ -1.64093018e-01,  -1.64062500e-01],
                        [ -2.11303711e-01,  -2.11303711e-01],
                        [ -2.11975098e-01,  -2.12005615e-01],
                        [ -1.76147461e-01,  -1.76147461e-01],
                        [ -1.27624512e-01,  -1.27624512e-01],
                        [ -8.88366699e-02,  -8.88671875e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -6.09741211e-02,  -6.10046387e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -7.80334473e-02,  -7.80334473e-02],
                        [ -7.65991211e-02,  -7.65991211e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -5.17578125e-02,  -5.17272949e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [  7.53784180e-03,   7.56835938e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.92248535e-02,  -4.91943359e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  9.06372070e-02,   9.06372070e-02],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  9.80834961e-02,   9.81140137e-02],
                        [  7.91931152e-02,   7.91931152e-02],
                        [  6.43920898e-02,   6.43615723e-02],
                        [  6.08825684e-02,   6.09130859e-02],
                        [  6.10046387e-02,   6.10351562e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  6.14624023e-02,   6.14929199e-02],
                        [  7.06481934e-02,   7.06481934e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  5.26123047e-02,   5.26428223e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.41296387e-01,   1.41296387e-01],
                        [  1.53320312e-01,   1.53320312e-01],
                        [  1.35253906e-01,   1.35253906e-01],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [ -7.62023926e-02,  -7.62023926e-02],
                        [ -1.77246094e-01,  -1.77276611e-01],
                        [ -2.59796143e-01,  -2.59796143e-01],
                        [ -2.94128418e-01,  -2.94128418e-01],
                        [ -2.71148682e-01,  -2.71179199e-01],
                        [ -2.10266113e-01,  -2.10266113e-01],
                        [ -1.46026611e-01,  -1.46026611e-01],
                        [ -1.04370117e-01,  -1.04400635e-01],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -8.40759277e-02,  -8.40454102e-02],
                        [ -7.85522461e-02,  -7.85522461e-02],
                        [ -6.70471191e-02,  -6.70471191e-02],
                        [ -5.47485352e-02,  -5.47180176e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.65393066e-02,  -4.65698242e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -7.03125000e-02,  -7.03125000e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  1.31683350e-01,   1.31683350e-01],
                        [  2.02117920e-01,   2.02117920e-01],
                        [  2.35260010e-01,   2.35260010e-01],
                        [  2.20001221e-01,   2.19970703e-01],
                        [  1.76971436e-01,   1.76971436e-01],
                        [  1.32659912e-01,   1.32690430e-01],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  7.73925781e-02,   7.73925781e-02],
                        [  6.81457520e-02,   6.81457520e-02],
                        [  6.62536621e-02,   6.62536621e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  5.82885742e-02,   5.82885742e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  1.75476074e-02,   1.75781250e-02],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  3.93066406e-02,   3.92761230e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  6.29882812e-02,   6.29882812e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  9.59472656e-02,   9.59472656e-02],
                        [  7.01599121e-02,   7.01599121e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -1.34521484e-01,  -1.34552002e-01],
                        [ -1.84600830e-01,  -1.84600830e-01],
                        [ -1.96594238e-01,  -1.96594238e-01],
                        [ -1.71569824e-01,  -1.71569824e-01],
                        [ -1.27166748e-01,  -1.27166748e-01],
                        [ -8.57543945e-02,  -8.57543945e-02],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [ -4.77294922e-02,  -4.77600098e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -6.61926270e-02,  -6.61926270e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -7.95593262e-02,  -7.95593262e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -6.44836426e-02,  -6.44836426e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -4.73022461e-03,  -4.76074219e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -9.05456543e-02,  -9.05456543e-02],
                        [ -8.15734863e-02,  -8.15734863e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  8.29772949e-02,   8.29467773e-02],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  1.01837158e-01,   1.01837158e-01],
                        [  7.88574219e-02,   7.88574219e-02],
                        [  5.81665039e-02,   5.81970215e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  4.48913574e-02,   4.48608398e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  5.49011230e-02,   5.49316406e-02],
                        [  6.00891113e-02,   6.00585938e-02],
                        [  6.75659180e-02,   6.75659180e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  1.10778809e-01,   1.10748291e-01],
                        [  1.27410889e-01,   1.27380371e-01],
                        [  1.36779785e-01,   1.36779785e-01],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  8.88366699e-02,   8.88061523e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [ -8.45642090e-02,  -8.45336914e-02],
                        [ -1.95159912e-01,  -1.95159912e-01],
                        [ -2.77465820e-01,  -2.77496338e-01],
                        [ -3.05603027e-01,  -3.05572510e-01],
                        [ -2.80151367e-01,  -2.80151367e-01],
                        [ -2.23327637e-01,  -2.23327637e-01],
                        [ -1.65313721e-01,  -1.65313721e-01],
                        [ -1.27502441e-01,  -1.27502441e-01],
                        [ -1.09619141e-01,  -1.09649658e-01],
                        [ -9.79309082e-02,  -9.79309082e-02],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -3.95507812e-02,  -3.95202637e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.13525391e-02,   1.13220215e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -4.46472168e-02,  -4.46166992e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -9.84802246e-02,  -9.85107422e-02],
                        [ -9.89379883e-02,  -9.89379883e-02],
                        [ -7.58972168e-02,  -7.58666992e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  1.75262451e-01,   1.75262451e-01],
                        [  2.21008301e-01,   2.21008301e-01],
                        [  2.29431152e-01,   2.29400635e-01],
                        [  2.05566406e-01,   2.05566406e-01],
                        [  1.66931152e-01,   1.66931152e-01],
                        [  1.32507324e-01,   1.32476807e-01],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  5.51757812e-02,   5.52062988e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  3.50952148e-02,   3.50646973e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [ -2.28881836e-03,  -2.25830078e-03],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  9.90905762e-02,   9.90905762e-02],
                        [  1.05560303e-01,   1.05529785e-01],
                        [  1.06689453e-01,   1.06689453e-01],
                        [  9.61303711e-02,   9.61303711e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -9.88769531e-02,  -9.88464355e-02],
                        [ -1.78985596e-01,  -1.78985596e-01],
                        [ -2.16796875e-01,  -2.16796875e-01],
                        [ -2.02941895e-01,  -2.02941895e-01],
                        [ -1.58233643e-01,  -1.58233643e-01],
                        [ -1.15203857e-01,  -1.15203857e-01],
                        [ -9.22851562e-02,  -9.22851562e-02],
                        [ -8.56628418e-02,  -8.56628418e-02],
                        [ -8.24584961e-02,  -8.24584961e-02],
                        [ -7.64770508e-02,  -7.64770508e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.27441406e-02,  -6.27746582e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -1.15356445e-02,  -1.15661621e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -4.94384766e-03,  -4.97436523e-03],
                        [ -2.21557617e-02,  -2.21862793e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -7.40356445e-02,  -7.40356445e-02],
                        [ -9.57641602e-02,  -9.57946777e-02],
                        [ -1.04400635e-01,  -1.04400635e-01],
                        [ -1.00006104e-01,  -9.99755859e-02],
                        [ -8.36181641e-02,  -8.36181641e-02],
                        [ -4.99877930e-02,  -5.00183105e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  1.15356445e-01,   1.15325928e-01],
                        [  1.39892578e-01,   1.39892578e-01],
                        [  1.34826660e-01,   1.34826660e-01],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  7.61718750e-02,   7.61413574e-02],
                        [  5.94482422e-02,   5.94787598e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  1.30767822e-01,   1.30737305e-01],
                        [  1.19995117e-01,   1.19995117e-01],
                        [  7.27539062e-02,   7.27539062e-02],
                        [ -1.46789551e-02,  -1.47094727e-02],
                        [ -1.24755859e-01,  -1.24755859e-01],
                        [ -2.24639893e-01,  -2.24639893e-01],
                        [ -2.80792236e-01,  -2.80792236e-01],
                        [ -2.77587891e-01,  -2.77618408e-01],
                        [ -2.31689453e-01,  -2.31689453e-01],
                        [ -1.81182861e-01,  -1.81182861e-01],
                        [ -1.52374268e-01,  -1.52374268e-01],
                        [ -1.41174316e-01,  -1.41174316e-01],
                        [ -1.28906250e-01,  -1.28906250e-01],
                        [ -1.06384277e-01,  -1.06384277e-01],
                        [ -7.81555176e-02,  -7.81555176e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.76391602e-02,  -1.76696777e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -6.35375977e-02,  -6.35681152e-02],
                        [ -6.35375977e-02,  -6.35070801e-02],
                        [ -4.90722656e-02,  -4.90417480e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [  2.76184082e-02,   2.75878906e-02],
                        [  9.06372070e-02,   9.06677246e-02],
                        [  1.59790039e-01,   1.59820557e-01],
                        [  2.10571289e-01,   2.10571289e-01],
                        [  2.19787598e-01,   2.19787598e-01],
                        [  1.89941406e-01,   1.89971924e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  1.30767822e-01,   1.30767822e-01],
                        [  1.22314453e-01,   1.22314453e-01],
                        [  9.71374512e-02,   9.71374512e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  4.07714844e-02,   4.08020020e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  3.66210938e-04,   3.35693359e-04],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.83715820e-02,   1.84020996e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  8.06884766e-02,   8.06884766e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  1.10015869e-01,   1.09985352e-01],
                        [  1.12792969e-01,   1.12792969e-01],
                        [  9.68322754e-02,   9.68627930e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [ -2.82287598e-02,  -2.82592773e-02],
                        [ -1.21856689e-01,  -1.21856689e-01],
                        [ -1.97326660e-01,  -1.97326660e-01],
                        [ -2.25036621e-01,  -2.25036621e-01],
                        [ -2.01416016e-01,  -2.01416016e-01],
                        [ -1.51336670e-01,  -1.51306152e-01],
                        [ -1.05651855e-01,  -1.05651855e-01],
                        [ -7.94982910e-02,  -7.94982910e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -5.96923828e-02,  -5.97229004e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.07519531e-02,  -2.07824707e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -8.33129883e-02,  -8.33129883e-02],
                        [ -9.52148438e-02,  -9.52148438e-02],
                        [ -9.86633301e-02,  -9.86328125e-02],
                        [ -8.58459473e-02,  -8.58764648e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  6.77490234e-02,   6.77185059e-02],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.26922607e-01,   1.26953125e-01],
                        [  1.16729736e-01,   1.16699219e-01],
                        [  9.19799805e-02,   9.19494629e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  7.50427246e-02,   7.50122070e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  8.68530273e-02,   8.68835449e-02],
                        [  7.73925781e-02,   7.73620605e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.14532471e-01,   1.14532471e-01],
                        [  1.33789062e-01,   1.33789062e-01],
                        [  1.53442383e-01,   1.53411865e-01],
                        [  1.57470703e-01,   1.57470703e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  8.18786621e-02,   8.19091797e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -9.35363770e-02,  -9.35363770e-02],
                        [ -1.94793701e-01,  -1.94793701e-01],
                        [ -2.70996094e-01,  -2.70996094e-01],
                        [ -2.94830322e-01,  -2.94830322e-01],
                        [ -2.64038086e-01,  -2.64038086e-01],
                        [ -2.04284668e-01,  -2.04284668e-01],
                        [ -1.48803711e-01,  -1.48834229e-01],
                        [ -1.18560791e-01,  -1.18530273e-01],
                        [ -1.13494873e-01,  -1.13464355e-01],
                        [ -1.15447998e-01,  -1.15478516e-01],
                        [ -1.05895996e-01,  -1.05895996e-01],
                        [ -8.35571289e-02,  -8.35571289e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  1.10107422e-01,   1.10137939e-01],
                        [  1.59149170e-01,   1.59149170e-01],
                        [  1.92810059e-01,   1.92810059e-01],
                        [  1.94610596e-01,   1.94641113e-01],
                        [  1.68212891e-01,   1.68212891e-01],
                        [  1.38244629e-01,   1.38214111e-01],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  1.25305176e-01,   1.25335693e-01],
                        [  1.21765137e-01,   1.21765137e-01],
                        [  1.04217529e-01,   1.04187012e-01],
                        [  7.72705078e-02,   7.72705078e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  2.84423828e-02,   2.84729004e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  5.00488281e-03,   5.03540039e-03],
                        [ -7.35473633e-03,  -7.38525391e-03],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  1.06811523e-03,   1.09863281e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  4.62646484e-02,   4.62341309e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  1.26770020e-01,   1.26770020e-01],
                        [  1.26098633e-01,   1.26068115e-01],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -9.96704102e-02,  -9.96704102e-02],
                        [ -1.89880371e-01,  -1.89880371e-01],
                        [ -2.28912354e-01,  -2.28881836e-01],
                        [ -2.10937500e-01,  -2.10937500e-01],
                        [ -1.60766602e-01,  -1.60766602e-01],
                        [ -1.12152100e-01,  -1.12121582e-01],
                        [ -8.53271484e-02,  -8.53271484e-02],
                        [ -7.88574219e-02,  -7.88879395e-02],
                        [ -7.84912109e-02,  -7.84606934e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -5.22155762e-02,  -5.21850586e-02],
                        [ -4.39758301e-02,  -4.39453125e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -8.15124512e-02,  -8.15124512e-02],
                        [ -9.01489258e-02,  -9.01794434e-02],
                        [ -8.52355957e-02,  -8.52355957e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  9.87548828e-02,   9.87548828e-02],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  1.01654053e-01,   1.01654053e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  9.57031250e-02,   9.56726074e-02],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.17492676e-01,   1.17492676e-01],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  1.37207031e-01,   1.37207031e-01],
                        [  1.52954102e-01,   1.52954102e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.41174316e-01,   1.41174316e-01],
                        [  8.24890137e-02,   8.24890137e-02],
                        [ -5.34057617e-03,  -5.37109375e-03],
                        [ -1.00219727e-01,  -1.00219727e-01],
                        [ -1.86218262e-01,  -1.86218262e-01],
                        [ -2.52777100e-01,  -2.52807617e-01],
                        [ -2.82775879e-01,  -2.82775879e-01],
                        [ -2.62268066e-01,  -2.62268066e-01],
                        [ -2.05078125e-01,  -2.05078125e-01],
                        [ -1.49414062e-01,  -1.49444580e-01],
                        [ -1.21826172e-01,  -1.21826172e-01],
                        [ -1.15539551e-01,  -1.15539551e-01],
                        [ -1.09924316e-01,  -1.09924316e-01],
                        [ -9.77478027e-02,  -9.77478027e-02],
                        [ -8.50830078e-02,  -8.50830078e-02],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  1.38824463e-01,   1.38824463e-01],
                        [  1.82556152e-01,   1.82556152e-01],
                        [  2.00317383e-01,   2.00317383e-01],
                        [  1.91741943e-01,   1.91741943e-01],
                        [  1.69158936e-01,   1.69158936e-01],
                        [  1.45507812e-01,   1.45507812e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  9.25903320e-02,   9.25903320e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  1.41906738e-02,   1.42211914e-02],
                        [  2.78625488e-02,   2.78320312e-02],
                        [  2.92358398e-02,   2.92053223e-02],
                        [  2.35290527e-02,   2.35595703e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.12707520e-02,   2.12402344e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  4.02221680e-02,   4.02526855e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  8.66088867e-02,   8.66088867e-02],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  8.32519531e-02,   8.32824707e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -1.77215576e-01,  -1.77215576e-01],
                        [ -2.09899902e-01,  -2.09899902e-01],
                        [ -1.86370850e-01,  -1.86370850e-01],
                        [ -1.35681152e-01,  -1.35681152e-01],
                        [ -9.67407227e-02,  -9.67407227e-02],
                        [ -8.66394043e-02,  -8.66394043e-02],
                        [ -9.26818848e-02,  -9.27124023e-02],
                        [ -9.32006836e-02,  -9.32006836e-02],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -5.66406250e-02,  -5.66711426e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.23278809e-02,  -4.23583984e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -4.61120605e-02,  -4.61425781e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -8.62731934e-02,  -8.63037109e-02],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -9.75952148e-02,  -9.75646973e-02],
                        [ -7.73315430e-02,  -7.73315430e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  1.06445312e-01,   1.06414795e-01],
                        [  1.38793945e-01,   1.38763428e-01],
                        [  1.43310547e-01,   1.43341064e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.18591309e-01,   1.18591309e-01],
                        [  1.07635498e-01,   1.07635498e-01],
                        [  9.28344727e-02,   9.28344727e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  7.79113770e-02,   7.79113770e-02],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  9.57031250e-02,   9.57031250e-02],
                        [  1.02203369e-01,   1.02203369e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.24511719e-01,   1.24511719e-01],
                        [  1.38885498e-01,   1.38854980e-01],
                        [  1.49932861e-01,   1.49932861e-01],
                        [  1.52435303e-01,   1.52435303e-01],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  8.79516602e-02,   8.79516602e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -1.00036621e-01,  -1.00036621e-01],
                        [ -2.05200195e-01,  -2.05200195e-01],
                        [ -2.81677246e-01,  -2.81677246e-01],
                        [ -3.04565430e-01,  -3.04565430e-01],
                        [ -2.68432617e-01,  -2.68432617e-01],
                        [ -1.98425293e-01,  -1.98455811e-01],
                        [ -1.35192871e-01,  -1.35192871e-01],
                        [ -1.01959229e-01,  -1.01959229e-01],
                        [ -9.24072266e-02,  -9.24072266e-02],
                        [ -9.09118652e-02,  -9.09423828e-02],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -1.00128174e-01,  -1.00128174e-01],
                        [ -1.03942871e-01,  -1.03942871e-01],
                        [ -9.36584473e-02,  -9.36889648e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -3.15246582e-02,  -3.15551758e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  7.87353516e-02,   7.87048340e-02],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.71997070e-01,   1.71997070e-01],
                        [  1.91406250e-01,   1.91375732e-01],
                        [  1.85913086e-01,   1.85913086e-01],
                        [  1.63726807e-01,   1.63726807e-01],
                        [  1.42425537e-01,   1.42395020e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  8.78295898e-02,   8.78295898e-02],
                        [  7.44628906e-02,   7.44628906e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  1.61437988e-02,   1.61132812e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.73645020e-02,   1.73339844e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  7.46459961e-02,   7.46154785e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -9.62219238e-02,  -9.61914062e-02],
                        [ -1.68975830e-01,  -1.68975830e-01],
                        [ -1.98394775e-01,  -1.98394775e-01],
                        [ -1.75201416e-01,  -1.75170898e-01],
                        [ -1.23748779e-01,  -1.23748779e-01],
                        [ -8.26721191e-02,  -8.26721191e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -8.06579590e-02,  -8.06579590e-02],
                        [ -8.45947266e-02,  -8.45947266e-02],
                        [ -7.73620605e-02,  -7.73620605e-02],
                        [ -7.11059570e-02,  -7.11059570e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -8.59069824e-02,  -8.59069824e-02],
                        [ -9.46655273e-02,  -9.46655273e-02],
                        [ -9.54895020e-02,  -9.54895020e-02],
                        [ -8.38623047e-02,  -8.38623047e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  6.26831055e-02,   6.26831055e-02],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.11480713e-01,   1.11450195e-01],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  9.03320312e-02,   9.03320312e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.75018311e-01,   1.75018311e-01],
                        [  1.84844971e-01,   1.84844971e-01],
                        [  1.71295166e-01,   1.71295166e-01],
                        [  1.30310059e-01,   1.30310059e-01],
                        [  6.24694824e-02,   6.24694824e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -1.38397217e-01,  -1.38397217e-01],
                        [ -2.39135742e-01,  -2.39166260e-01],
                        [ -2.99346924e-01,  -2.99346924e-01],
                        [ -3.00750732e-01,  -3.00750732e-01],
                        [ -2.55859375e-01,  -2.55859375e-01],
                        [ -1.97723389e-01,  -1.97723389e-01],
                        [ -1.54754639e-01,  -1.54754639e-01],
                        [ -1.32965088e-01,  -1.32965088e-01],
                        [ -1.18194580e-01,  -1.18225098e-01],
                        [ -9.66796875e-02,  -9.66796875e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -5.77697754e-02,  -5.77697754e-02],
                        [ -5.50537109e-02,  -5.50537109e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -2.88696289e-02,  -2.88696289e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.34863281e-02,   7.34863281e-02],
                        [  1.38763428e-01,   1.38763428e-01],
                        [  1.87896729e-01,   1.87896729e-01],
                        [  2.15240479e-01,   2.15240479e-01],
                        [  2.22534180e-01,   2.22534180e-01],
                        [  2.11334229e-01,   2.11334229e-01],
                        [  1.85394287e-01,   1.85394287e-01],
                        [  1.52893066e-01,   1.52893066e-01],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  8.30688477e-02,   8.30688477e-02],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  5.06286621e-02,   5.05981445e-02],
                        [  5.09643555e-02,   5.09643555e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.14538574e-02,  -2.14843750e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [  1.40380859e-03,   1.43432617e-03],
                        [  6.25610352e-03,   6.22558594e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  8.77075195e-02,   8.77075195e-02],
                        [  9.90600586e-02,   9.90295410e-02],
                        [  9.91210938e-02,   9.91210938e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  7.28454590e-02,   7.28454590e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -1.10382080e-01,  -1.10351562e-01],
                        [ -1.68060303e-01,  -1.68060303e-01],
                        [ -1.86370850e-01,  -1.86370850e-01],
                        [ -1.63055420e-01,  -1.63055420e-01],
                        [ -1.19506836e-01,  -1.19506836e-01],
                        [ -8.54797363e-02,  -8.54797363e-02],
                        [ -7.55310059e-02,  -7.55310059e-02],
                        [ -8.09631348e-02,  -8.09326172e-02],
                        [ -8.52050781e-02,  -8.52050781e-02],
                        [ -8.28552246e-02,  -8.28857422e-02],
                        [ -8.05664062e-02,  -8.05664062e-02],
                        [ -8.46862793e-02,  -8.46862793e-02],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -9.80529785e-02,  -9.80529785e-02],
                        [ -9.15222168e-02,  -9.15222168e-02],
                        [ -7.45849609e-02,  -7.46154785e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -4.89807129e-02,  -4.89807129e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [  1.09558105e-02,   1.09252930e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.13708496e-01,   1.13739014e-01],
                        [  1.03729248e-01,   1.03729248e-01],
                        [  9.84191895e-02,   9.83886719e-02],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  1.04705811e-01,   1.04705811e-01],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.42791748e-01,   1.42791748e-01],
                        [  1.66778564e-01,   1.66778564e-01],
                        [  1.91986084e-01,   1.91986084e-01],
                        [  1.99615479e-01,   1.99615479e-01],
                        [  1.74072266e-01,   1.74102783e-01],
                        [  1.09954834e-01,   1.09954834e-01],
                        [  1.05285645e-02,   1.05285645e-02],
                        [ -1.10382080e-01,  -1.10382080e-01],
                        [ -2.26470947e-01,  -2.26470947e-01],
                        [ -3.06030273e-01,  -3.06030273e-01],
                        [ -3.24523926e-01,  -3.24523926e-01],
                        [ -2.78137207e-01,  -2.78137207e-01],
                        [ -1.95770264e-01,  -1.95770264e-01],
                        [ -1.27716064e-01,  -1.27716064e-01],
                        [ -1.04003906e-01,  -1.04003906e-01],
                        [ -1.09313965e-01,  -1.09313965e-01],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -9.97619629e-02,  -9.97619629e-02],
                        [ -8.83789062e-02,  -8.83789062e-02],
                        [ -8.40454102e-02,  -8.40454102e-02],
                        [ -7.99560547e-02,  -7.99560547e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  1.44287109e-01,   1.44287109e-01],
                        [  1.88720703e-01,   1.88720703e-01],
                        [  2.06298828e-01,   2.06298828e-01],
                        [  1.93328857e-01,   1.93298340e-01],
                        [  1.63360596e-01,   1.63360596e-01],
                        [  1.37023926e-01,   1.37023926e-01],
                        [  1.24481201e-01,   1.24481201e-01],
                        [  1.20819092e-01,   1.20819092e-01],
                        [  1.16699219e-01,   1.16699219e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  9.00573730e-02,   9.00573730e-02],
                        [  6.78710938e-02,   6.78710938e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -2.56958008e-02,  -2.57263184e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  1.11999512e-02,   1.11694336e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  5.35583496e-02,   5.35583496e-02],
                        [  7.47375488e-02,   7.47375488e-02],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  5.65185547e-02,   5.65185547e-02],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -7.00988770e-02,  -7.01293945e-02],
                        [ -1.28753662e-01,  -1.28753662e-01],
                        [ -1.65039062e-01,  -1.65039062e-01],
                        [ -1.71234131e-01,  -1.71234131e-01],
                        [ -1.53656006e-01,  -1.53656006e-01],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -1.18286133e-01,  -1.18286133e-01],
                        [ -1.14044189e-01,  -1.14044189e-01],
                        [ -1.11541748e-01,  -1.11511230e-01],
                        [ -1.06414795e-01,  -1.06414795e-01],
                        [ -9.84802246e-02,  -9.84802246e-02],
                        [ -9.11560059e-02,  -9.11560059e-02],
                        [ -8.70971680e-02,  -8.70971680e-02],
                        [ -8.20617676e-02,  -8.20617676e-02],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [ -5.33447266e-02,  -5.33142090e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -1.89208984e-03,  -1.92260742e-03],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  1.00677490e-01,   1.00677490e-01],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.30126953e-01,   1.30126953e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.19995117e-01,   1.19995117e-01],
                        [  1.08612061e-01,   1.08612061e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.26373291e-01,   1.26373291e-01],
                        [  1.49261475e-01,   1.49261475e-01],
                        [  1.70104980e-01,   1.70104980e-01],
                        [  1.79718018e-01,   1.79718018e-01],
                        [  1.69830322e-01,   1.69830322e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  6.30187988e-02,   6.30187988e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -1.50756836e-01,  -1.50756836e-01],
                        [ -2.51220703e-01,  -2.51220703e-01],
                        [ -3.06243896e-01,  -3.06243896e-01],
                        [ -2.96783447e-01,  -2.96783447e-01],
                        [ -2.35443115e-01,  -2.35443115e-01],
                        [ -1.65985107e-01,  -1.65985107e-01],
                        [ -1.29791260e-01,  -1.29791260e-01],
                        [ -1.29302979e-01,  -1.29302979e-01],
                        [ -1.33636475e-01,  -1.33636475e-01],
                        [ -1.19262695e-01,  -1.19262695e-01],
                        [ -9.25903320e-02,  -9.25903320e-02],
                        [ -7.11975098e-02,  -7.11975098e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  1.59973145e-01,   1.59973145e-01],
                        [  1.95892334e-01,   1.95892334e-01],
                        [  2.04772949e-01,   2.04772949e-01],
                        [  1.91619873e-01,   1.91619873e-01],
                        [  1.69921875e-01,   1.69921875e-01],
                        [  1.49536133e-01,   1.49536133e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.19476318e-01,   1.19476318e-01],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  1.00280762e-01,   1.00280762e-01],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  1.02569580e-01,   1.02569580e-01],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -1.30065918e-01,  -1.30065918e-01],
                        [ -1.81884766e-01,  -1.81884766e-01],
                        [ -1.93206787e-01,  -1.93206787e-01],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -1.43615723e-01,  -1.43615723e-01],
                        [ -1.25366211e-01,  -1.25366211e-01],
                        [ -1.20422363e-01,  -1.20422363e-01],
                        [ -1.18103027e-01,  -1.18103027e-01],
                        [ -1.07696533e-01,  -1.07696533e-01],
                        [ -9.03930664e-02,  -9.03930664e-02],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -7.47985840e-02,  -7.47985840e-02],
                        [ -7.42797852e-02,  -7.42797852e-02],
                        [ -6.86950684e-02,  -6.86950684e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -7.18994141e-02,  -7.18994141e-02],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  9.48181152e-02,   9.48181152e-02],
                        [  1.14074707e-01,   1.14074707e-01],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.07391357e-01,   1.07391357e-01],
                        [  1.02478027e-01,   1.02478027e-01],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  9.54284668e-02,   9.54284668e-02],
                        [  1.07879639e-01,   1.07879639e-01],
                        [  1.32934570e-01,   1.32934570e-01],
                        [  1.61132812e-01,   1.61132812e-01],
                        [  1.84692383e-01,   1.84692383e-01],
                        [  2.01080322e-01,   2.01080322e-01],
                        [  2.06207275e-01,   2.06207275e-01],
                        [  1.89849854e-01,   1.89849854e-01],
                        [  1.40991211e-01,   1.40991211e-01],
                        [  5.71899414e-02,   5.71899414e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -1.67358398e-01,  -1.67327881e-01],
                        [ -2.66357422e-01,  -2.66357422e-01],
                        [ -3.25653076e-01,  -3.25653076e-01],
                        [ -3.28125000e-01,  -3.28125000e-01],
                        [ -2.75451660e-01,  -2.75451660e-01],
                        [ -1.95678711e-01,  -1.95678711e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -9.64660645e-02,  -9.64660645e-02],
                        [ -9.13696289e-02,  -9.13696289e-02],
                        [ -9.09423828e-02,  -9.09423828e-02],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -7.10449219e-02,  -7.10449219e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -7.07702637e-02,  -7.07702637e-02],
                        [ -7.59887695e-02,  -7.59887695e-02],
                        [ -7.43103027e-02,  -7.43103027e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  1.30279541e-01,   1.30279541e-01],
                        [  1.73767090e-01,   1.73767090e-01],
                        [  1.94915771e-01,   1.94915771e-01],
                        [  1.90185547e-01,   1.90185547e-01],
                        [  1.67541504e-01,   1.67541504e-01],
                        [  1.43798828e-01,   1.43798828e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.20788574e-01,   1.20788574e-01],
                        [  1.12823486e-01,   1.12823486e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  6.81457520e-02,   6.81457520e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  6.42089844e-02,   6.42089844e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  8.03222656e-02,   8.03222656e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -1.16241455e-01,  -1.16241455e-01],
                        [ -1.71691895e-01,  -1.71691895e-01],
                        [ -1.85119629e-01,  -1.85119629e-01],
                        [ -1.61895752e-01,  -1.61895752e-01],
                        [ -1.26098633e-01,  -1.26098633e-01],
                        [ -1.04248047e-01,  -1.04248047e-01],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -1.15081787e-01,  -1.15081787e-01],
                        [ -1.17736816e-01,  -1.17736816e-01],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -9.20104980e-02,  -9.20104980e-02],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -8.24279785e-02,  -8.24279785e-02],
                        [ -8.18786621e-02,  -8.18786621e-02],
                        [ -7.35168457e-02,  -7.35168457e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -5.28259277e-02,  -5.28259277e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -4.74853516e-02,  -4.74853516e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  9.56420898e-02,   9.56420898e-02],
                        [  1.05712891e-01,   1.05712891e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  1.57562256e-01,   1.57562256e-01],
                        [  1.79534912e-01,   1.79534912e-01],
                        [  1.97845459e-01,   1.97845459e-01],
                        [  2.04559326e-01,   2.04559326e-01],
                        [  1.96075439e-01,   1.96075439e-01],
                        [  1.64001465e-01,   1.64001465e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -1.12426758e-01,  -1.12426758e-01],
                        [ -2.20153809e-01,  -2.20153809e-01],
                        [ -2.98126221e-01,  -2.98126221e-01],
                        [ -3.22113037e-01,  -3.22113037e-01],
                        [ -2.87658691e-01,  -2.87658691e-01],
                        [ -2.20581055e-01,  -2.20581055e-01],
                        [ -1.56829834e-01,  -1.56829834e-01],
                        [ -1.16729736e-01,  -1.16729736e-01],
                        [ -9.92126465e-02,  -9.92126465e-02],
                        [ -9.08203125e-02,  -9.08203125e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.56494141e-01,   1.56494141e-01],
                        [  1.91345215e-01,   1.91345215e-01],
                        [  1.95404053e-01,   1.95404053e-01],
                        [  1.75872803e-01,   1.75872803e-01],
                        [  1.51000977e-01,   1.51000977e-01],
                        [  1.34765625e-01,   1.34765625e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.28906250e-01,   1.28906250e-01],
                        [  1.25640869e-01,   1.25640869e-01],
                        [  1.15203857e-01,   1.15203857e-01],
                        [  1.00708008e-01,   1.00708008e-01],
                        [  8.92944336e-02,   8.92944336e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  1.07208252e-01,   1.07208252e-01],
                        [  9.39941406e-02,   9.39941406e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -8.98437500e-02,  -8.98437500e-02],
                        [ -1.61804199e-01,  -1.61804199e-01],
                        [ -1.97204590e-01,  -1.97204590e-01],
                        [ -1.85577393e-01,  -1.85577393e-01],
                        [ -1.48773193e-01,  -1.48773193e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -1.12609863e-01,  -1.12609863e-01],
                        [ -1.10229492e-01,  -1.10229492e-01],
                        [ -1.01684570e-01,  -1.01684570e-01],
                        [ -9.48486328e-02,  -9.48486328e-02],
                        [ -9.59472656e-02,  -9.59472656e-02],
                        [ -9.79309082e-02,  -9.79309082e-02],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -7.25402832e-02,  -7.25402832e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [  3.05175781e-05,   3.05175781e-05],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.14776611e-01,   1.14776611e-01],
                        [  1.13647461e-01,   1.13647461e-01],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  1.30096436e-01,   1.30096436e-01],
                        [  1.47033691e-01,   1.47033691e-01],
                        [  1.69555664e-01,   1.69555664e-01],
                        [  1.97235107e-01,   1.97235107e-01],
                        [  2.19177246e-01,   2.19177246e-01],
                        [  2.18109131e-01,   2.18109131e-01],
                        [  1.83044434e-01,   1.83044434e-01],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.78833008e-02,   1.78833008e-02],
                        [ -9.20410156e-02,  -9.20410156e-02],
                        [ -1.98577881e-01,  -1.98577881e-01],
                        [ -2.80761719e-01,  -2.80761719e-01],
                        [ -3.16650391e-01,  -3.16650391e-01],
                        [ -2.95257568e-01,  -2.95257568e-01],
                        [ -2.33337402e-01,  -2.33337402e-01],
                        [ -1.70227051e-01,  -1.70227051e-01],
                        [ -1.35345459e-01,  -1.35345459e-01],
                        [ -1.24938965e-01,  -1.24938965e-01],
                        [ -1.16455078e-01,  -1.16455078e-01],
                        [ -9.74426270e-02,  -9.74426270e-02],
                        [ -7.60192871e-02,  -7.60192871e-02],
                        [ -6.74743652e-02,  -6.74743652e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -8.66394043e-02,  -8.66394043e-02],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.73553467e-01,   1.73553467e-01],
                        [  2.01263428e-01,   2.01263428e-01],
                        [  1.99066162e-01,   1.99066162e-01],
                        [  1.75903320e-01,   1.75903320e-01],
                        [  1.51397705e-01,   1.51397705e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.24145508e-01,   1.24145508e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  7.89184570e-02,   7.89184570e-02],
                        [  8.16955566e-02,   8.16955566e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  1.09558105e-01,   1.09558105e-01],
                        [  1.06933594e-01,   1.06933594e-01],
                        [  9.03320312e-02,   9.03320312e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.06140137e-01,  -1.06140137e-01],
                        [ -1.78375244e-01,  -1.78375244e-01],
                        [ -2.17254639e-01,  -2.17254639e-01],
                        [ -2.12219238e-01,  -2.12219238e-01],
                        [ -1.77795410e-01,  -1.77795410e-01],
                        [ -1.42547607e-01,  -1.42547607e-01],
                        [ -1.21856689e-01,  -1.21856689e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -1.04095459e-01,  -1.04095459e-01],
                        [ -1.02203369e-01,  -1.02203369e-01],
                        [ -1.07543945e-01,  -1.07543945e-01],
                        [ -1.13861084e-01,  -1.13861084e-01],
                        [ -1.12091064e-01,  -1.12091064e-01],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.27227783e-01,   1.27227783e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.31134033e-01,   1.31134033e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.48254395e-01,   1.48254395e-01],
                        [  1.71539307e-01,   1.71539307e-01],
                        [  1.96929932e-01,   1.96929932e-01],
                        [  2.14721680e-01,   2.14721680e-01],
                        [  2.12158203e-01,   2.12158203e-01],
                        [  1.77246094e-01,   1.77246094e-01],
                        [  1.07208252e-01,   1.07208252e-01],
                        [  9.70458984e-03,   9.70458984e-03],
                        [ -1.02630615e-01,  -1.02630615e-01],
                        [ -2.11303711e-01,  -2.11303711e-01],
                        [ -2.90039062e-01,  -2.90039062e-01],
                        [ -3.14636230e-01,  -3.14636230e-01],
                        [ -2.81219482e-01,  -2.81219482e-01],
                        [ -2.14172363e-01,  -2.14172363e-01],
                        [ -1.50604248e-01,  -1.50604248e-01],
                        [ -1.14044189e-01,  -1.14044189e-01],
                        [ -1.04919434e-01,  -1.04919434e-01],
                        [ -1.12152100e-01,  -1.12152100e-01],
                        [ -1.22833252e-01,  -1.22833252e-01],
                        [ -1.25030518e-01,  -1.25030518e-01],
                        [ -1.14379883e-01,  -1.14379883e-01],
                        [ -9.73815918e-02,  -9.73815918e-02],
                        [ -8.22143555e-02,  -8.22143555e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -5.77392578e-02,  -5.77392578e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  1.24389648e-01,   1.24389648e-01],
                        [  1.85760498e-01,   1.85760498e-01],
                        [  2.27905273e-01,   2.27905273e-01],
                        [  2.33734131e-01,   2.33734131e-01],
                        [  2.04864502e-01,   2.04864502e-01],
                        [  1.63482666e-01,   1.63482666e-01],
                        [  1.33575439e-01,   1.33575439e-01],
                        [  1.22192383e-01,   1.22192383e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  7.33032227e-02,   7.33032227e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -7.75756836e-02,  -7.75756836e-02],
                        [ -1.50054932e-01,  -1.50054932e-01],
                        [ -1.97479248e-01,  -1.97479248e-01],
                        [ -2.07061768e-01,  -2.07061768e-01],
                        [ -1.83349609e-01,  -1.83349609e-01],
                        [ -1.49841309e-01,  -1.49841309e-01],
                        [ -1.30218506e-01,  -1.30218506e-01],
                        [ -1.27410889e-01,  -1.27410889e-01],
                        [ -1.27593994e-01,  -1.27593994e-01],
                        [ -1.21520996e-01,  -1.21520996e-01],
                        [ -1.13769531e-01,  -1.13769531e-01],
                        [ -1.09985352e-01,  -1.09985352e-01],
                        [ -1.04553223e-01,  -1.04553223e-01],
                        [ -8.91113281e-02,  -8.91113281e-02],
                        [ -6.70166016e-02,  -6.70166016e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  1.18835449e-01,   1.18835449e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  1.33392334e-01,   1.33392334e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.82495117e-01,   1.82495117e-01],
                        [  2.14782715e-01,   2.14782715e-01],
                        [  2.36633301e-01,   2.36633301e-01],
                        [  2.27325439e-01,   2.27325439e-01],
                        [  1.81762695e-01,   1.81762695e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.75781250e-02,   1.75781250e-02],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -2.04345703e-01,  -2.04345703e-01],
                        [ -2.90679932e-01,  -2.90679932e-01],
                        [ -3.21838379e-01,  -3.21838379e-01],
                        [ -2.89031982e-01,  -2.89031982e-01],
                        [ -2.17559814e-01,  -2.17559814e-01],
                        [ -1.54296875e-01,  -1.54296875e-01],
                        [ -1.27288818e-01,  -1.27288818e-01],
                        [ -1.24725342e-01,  -1.24725342e-01],
                        [ -1.23199463e-01,  -1.23199463e-01],
                        [ -1.17950439e-01,  -1.17950439e-01],
                        [ -1.14013672e-01,  -1.14013672e-01],
                        [ -1.09283447e-01,  -1.09283447e-01],
                        [ -1.00311279e-01,  -1.00311279e-01],
                        [ -8.98742676e-02,  -8.98742676e-02],
                        [ -8.15734863e-02,  -8.15734863e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  1.51824951e-01,   1.51824951e-01],
                        [  2.09320068e-01,   2.09320068e-01],
                        [  2.42126465e-01,   2.42126465e-01],
                        [  2.32482910e-01,   2.32482910e-01],
                        [  1.89056396e-01,   1.89056396e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.24053955e-01,   1.24053955e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.14379883e-01,   1.14379883e-01],
                        [  1.05072021e-01,   1.05072021e-01],
                        [  9.58557129e-02,   9.58557129e-02],
                        [  8.92333984e-02,   8.92333984e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  7.07092285e-02,   7.07092285e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  3.37524414e-02,   3.37524414e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  8.85620117e-02,   8.85620117e-02],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -1.11999512e-01,  -1.11999512e-01],
                        [ -1.75964355e-01,  -1.75964355e-01],
                        [ -2.05841064e-01,  -2.05841064e-01],
                        [ -1.96258545e-01,  -1.96258545e-01],
                        [ -1.65252686e-01,  -1.65252686e-01],
                        [ -1.36962891e-01,  -1.36962891e-01],
                        [ -1.20635986e-01,  -1.20635986e-01],
                        [ -1.11724854e-01,  -1.11724854e-01],
                        [ -1.06506348e-01,  -1.06506348e-01],
                        [ -1.06323242e-01,  -1.06323242e-01],
                        [ -1.10260010e-01,  -1.10260010e-01],
                        [ -1.10778809e-01,  -1.10778809e-01],
                        [ -1.01074219e-01,  -1.01074219e-01],
                        [ -8.41674805e-02,  -8.41674805e-02],
                        [ -7.01904297e-02,  -7.01904297e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -7.22045898e-02,  -7.22045898e-02],
                        [ -7.08923340e-02,  -7.08923340e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  1.29852295e-01,   1.29852295e-01],
                        [  1.25823975e-01,   1.25823975e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  9.10339355e-02,   9.10339355e-02],
                        [  1.08520508e-01,   1.08520508e-01],
                        [  1.35681152e-01,   1.35681152e-01],
                        [  1.56524658e-01,   1.56524658e-01],
                        [  1.75476074e-01,   1.75476074e-01],
                        [  2.03308105e-01,   2.03308105e-01],
                        [  2.27966309e-01,   2.27966309e-01],
                        [  2.23388672e-01,   2.23388672e-01],
                        [  1.79626465e-01,   1.79626465e-01],
                        [  1.04217529e-01,   1.04217529e-01],
                        [  3.90625000e-03,   3.90625000e-03],
                        [ -1.14227295e-01,  -1.14227295e-01],
                        [ -2.28851318e-01,  -2.28851318e-01],
                        [ -3.06884766e-01,  -3.06884766e-01],
                        [ -3.23059082e-01,  -3.23059082e-01],
                        [ -2.78961182e-01,  -2.78961182e-01],
                        [ -2.07458496e-01,  -2.07458496e-01],
                        [ -1.50939941e-01,  -1.50939941e-01],
                        [ -1.27655029e-01,  -1.27655029e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -1.17828369e-01,  -1.17828369e-01],
                        [ -1.06567383e-01,  -1.06567383e-01],
                        [ -9.69238281e-02,  -9.69238281e-02],
                        [ -9.13391113e-02,  -9.13391113e-02],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -8.61511230e-02,  -8.61511230e-02],
                        [ -8.29467773e-02,  -8.29467773e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  1.19293213e-01,   1.19293213e-01],
                        [  1.69647217e-01,   1.69647217e-01],
                        [  2.01080322e-01,   2.01080322e-01],
                        [  2.08648682e-01,   2.08648682e-01],
                        [  1.95678711e-01,   1.95678711e-01],
                        [  1.70318604e-01,   1.70318604e-01],
                        [  1.44378662e-01,   1.44378662e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.23291016e-01,   1.23291016e-01],
                        [  1.18408203e-01,   1.18408203e-01],
                        [  1.06445312e-01,   1.06445312e-01],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  7.18383789e-02,   7.18383789e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  9.42077637e-02,   9.42077637e-02],
                        [  7.44628906e-02,   7.44628906e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -1.27288818e-01,  -1.27288818e-01],
                        [ -1.95434570e-01,  -1.95434570e-01],
                        [ -2.14813232e-01,  -2.14813232e-01],
                        [ -1.86340332e-01,  -1.86340332e-01],
                        [ -1.39404297e-01,  -1.39404297e-01],
                        [ -1.06597900e-01,  -1.06597900e-01],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -1.15936279e-01,  -1.15936279e-01],
                        [ -1.25885010e-01,  -1.25885010e-01],
                        [ -1.18560791e-01,  -1.18560791e-01],
                        [ -1.00341797e-01,  -1.00341797e-01],
                        [ -8.43505859e-02,  -8.43505859e-02],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -7.19909668e-02,  -7.19909668e-02],
                        [ -7.94067383e-02,  -7.94067383e-02],
                        [ -7.97729492e-02,  -7.97729492e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  1.12731934e-01,   1.12731934e-01],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.09466553e-01,   1.09466553e-01],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  1.46606445e-01,   1.46606445e-01],
                        [  1.64947510e-01,   1.64947510e-01],
                        [  1.74926758e-01,   1.74926758e-01],
                        [  1.84143066e-01,   1.84143066e-01],
                        [  1.96441650e-01,   1.96441650e-01],
                        [  2.03033447e-01,   2.03033447e-01],
                        [  1.86309814e-01,   1.86309814e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  4.02221680e-02,   4.02221680e-02],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -1.84204102e-01,  -1.84204102e-01],
                        [ -2.69927979e-01,  -2.69927979e-01],
                        [ -3.09875488e-01,  -3.09875488e-01],
                        [ -2.91564941e-01,  -2.91564941e-01],
                        [ -2.27111816e-01,  -2.27111816e-01],
                        [ -1.56127930e-01,  -1.56127930e-01],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -1.07788086e-01,  -1.07788086e-01],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.04339600e-01,  -1.04339600e-01],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -1.05438232e-01,  -1.05438232e-01],
                        [ -1.07727051e-01,  -1.07727051e-01],
                        [ -1.02630615e-01,  -1.02630615e-01],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.92321777e-01,   1.92321777e-01],
                        [  2.21557617e-01,   2.21557617e-01],
                        [  2.08099365e-01,   2.08099365e-01],
                        [  1.67572021e-01,   1.67572021e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  1.07208252e-01,   1.07208252e-01],
                        [  1.17492676e-01,   1.17492676e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.25122070e-01,   1.25122070e-01],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  8.72802734e-02,   8.72802734e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [ -6.40869141e-02,  -6.40869141e-02],
                        [ -1.47064209e-01,  -1.47064209e-01],
                        [ -2.01751709e-01,  -2.01751709e-01],
                        [ -2.09686279e-01,  -2.09686279e-01],
                        [ -1.79473877e-01,  -1.79473877e-01],
                        [ -1.39190674e-01,  -1.39190674e-01],
                        [ -1.11633301e-01,  -1.11633301e-01],
                        [ -1.02447510e-01,  -1.02447510e-01],
                        [ -1.04003906e-01,  -1.04003906e-01],
                        [ -1.03485107e-01,  -1.03485107e-01],
                        [ -9.53369141e-02,  -9.53369141e-02],
                        [ -8.81042480e-02,  -8.81042480e-02],
                        [ -9.13085938e-02,  -9.13085938e-02],
                        [ -9.88159180e-02,  -9.88159180e-02],
                        [ -9.59167480e-02,  -9.59167480e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -6.65893555e-02,  -6.65893555e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  6.62231445e-02,   6.62231445e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  9.36279297e-02,   9.36279297e-02],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  9.73205566e-02,   9.73205566e-02],
                        [  1.04949951e-01,   1.04949951e-01],
                        [  1.22192383e-01,   1.22192383e-01],
                        [  1.40502930e-01,   1.40502930e-01],
                        [  1.51245117e-01,   1.51245117e-01],
                        [  1.59271240e-01,   1.59271240e-01],
                        [  1.74377441e-01,   1.74377441e-01],
                        [  1.94213867e-01,   1.94213867e-01],
                        [  2.05688477e-01,   2.05688477e-01],
                        [  1.96105957e-01,   1.96105957e-01],
                        [  1.55609131e-01,   1.55609131e-01],
                        [  7.82165527e-02,   7.82165527e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -1.51794434e-01,  -1.51794434e-01],
                        [ -2.54974365e-01,  -2.54974365e-01],
                        [ -3.13232422e-01,  -3.13232422e-01],
                        [ -3.10028076e-01,  -3.10028076e-01],
                        [ -2.53143311e-01,  -2.53143311e-01],
                        [ -1.79840088e-01,  -1.79840088e-01],
                        [ -1.31744385e-01,  -1.31744385e-01],
                        [ -1.18347168e-01,  -1.18347168e-01],
                        [ -1.18469238e-01,  -1.18469238e-01],
                        [ -1.15478516e-01,  -1.15478516e-01],
                        [ -1.13555908e-01,  -1.13555908e-01],
                        [ -1.17370605e-01,  -1.17370605e-01],
                        [ -1.18011475e-01,  -1.18011475e-01],
                        [ -1.07971191e-01,  -1.07971191e-01],
                        [ -9.08508301e-02,  -9.08508301e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  1.32324219e-01,   1.32324219e-01],
                        [  1.79962158e-01,   1.79962158e-01],
                        [  2.12097168e-01,   2.12097168e-01],
                        [  2.12890625e-01,   2.12890625e-01],
                        [  1.81640625e-01,   1.81640625e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  1.16790771e-01,   1.16790771e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  9.22851562e-02,   9.22851562e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -9.82055664e-02,  -9.82055664e-02],
                        [ -1.76177979e-01,  -1.76177979e-01],
                        [ -2.17712402e-01,  -2.17712402e-01],
                        [ -2.13867188e-01,  -2.13867188e-01],
                        [ -1.78039551e-01,  -1.78039551e-01],
                        [ -1.38397217e-01,  -1.38397217e-01],
                        [ -1.14013672e-01,  -1.14013672e-01],
                        [ -1.02966309e-01,  -1.02966309e-01],
                        [ -9.58557129e-02,  -9.58557129e-02],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -8.68530273e-02,  -8.68530273e-02],
                        [ -9.52148438e-02,  -9.52148438e-02],
                        [ -1.02355957e-01,  -1.02355957e-01],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -9.78393555e-02,  -9.78393555e-02],
                        [ -8.94775391e-02,  -8.94775391e-02],
                        [ -7.14111328e-02,  -7.14111328e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  1.26281738e-01,   1.26281738e-01],
                        [  1.48620605e-01,   1.48620605e-01],
                        [  1.71752930e-01,   1.71752930e-01],
                        [  2.02423096e-01,   2.02423096e-01],
                        [  2.30590820e-01,   2.30590820e-01],
                        [  2.32849121e-01,   2.32849121e-01],
                        [  1.95373535e-01,   1.95373535e-01],
                        [  1.20941162e-01,   1.20941162e-01],
                        [  1.75476074e-02,   1.75476074e-02],
                        [ -1.05072021e-01,  -1.05072021e-01],
                        [ -2.28179932e-01,  -2.28179932e-01],
                        [ -3.20465088e-01,  -3.20465088e-01],
                        [ -3.49731445e-01,  -3.49731445e-01],
                        [ -3.08837891e-01,  -3.08837891e-01],
                        [ -2.28851318e-01,  -2.28851318e-01],
                        [ -1.57165527e-01,  -1.57165527e-01],
                        [ -1.19903564e-01,  -1.19903564e-01],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -1.07574463e-01,  -1.07574463e-01],
                        [ -1.06323242e-01,  -1.06323242e-01],
                        [ -1.07482910e-01,  -1.07482910e-01],
                        [ -1.11022949e-01,  -1.11022949e-01],
                        [ -1.13677979e-01,  -1.13677979e-01],
                        [ -1.10534668e-01,  -1.10534668e-01],
                        [ -9.30786133e-02,  -9.30786133e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.92810059e-01,   1.92810059e-01],
                        [  2.25402832e-01,   2.25402832e-01],
                        [  2.30285645e-01,   2.30285645e-01],
                        [  2.05993652e-01,   2.05993652e-01],
                        [  1.66259766e-01,   1.66259766e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  8.13293457e-02,   8.13293457e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  7.98339844e-02,   7.98339844e-02],
                        [  6.61926270e-02,   6.61926270e-02],
                        [  5.09643555e-02,   5.09643555e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.14349365e-01,   1.14349365e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -1.46759033e-01,  -1.46759033e-01],
                        [ -1.99859619e-01,  -1.99859619e-01],
                        [ -2.18780518e-01,  -2.18780518e-01],
                        [ -2.00805664e-01,  -2.00805664e-01],
                        [ -1.61224365e-01,  -1.61224365e-01],
                        [ -1.24084473e-01,  -1.24084473e-01],
                        [ -1.02478027e-01,  -1.02478027e-01],
                        [ -9.21630859e-02,  -9.21630859e-02],
                        [ -8.63342285e-02,  -8.63342285e-02],
                        [ -8.62426758e-02,  -8.62426758e-02],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -1.02630615e-01,  -1.02630615e-01],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -1.04461670e-01,  -1.04461670e-01],
                        [ -9.85412598e-02,  -9.85412598e-02],
                        [ -8.61206055e-02,  -8.61206055e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.24786377e-01,   1.24786377e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  1.05041504e-01,   1.05041504e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.25885010e-01,   1.25885010e-01],
                        [  1.46759033e-01,   1.46759033e-01],
                        [  1.78771973e-01,   1.78771973e-01],
                        [  2.14019775e-01,   2.14019775e-01],
                        [  2.32696533e-01,   2.32696533e-01],
                        [  2.17437744e-01,   2.17437744e-01],
                        [  1.63879395e-01,   1.63879395e-01],
                        [  7.64465332e-02,   7.64465332e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -1.56646729e-01,  -1.56646729e-01],
                        [ -2.61352539e-01,  -2.61352539e-01],
                        [ -3.18054199e-01,  -3.18054199e-01],
                        [ -3.05664062e-01,  -3.05664062e-01],
                        [ -2.39013672e-01,  -2.39013672e-01],
                        [ -1.67175293e-01,  -1.67175293e-01],
                        [ -1.31469727e-01,  -1.31469727e-01],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -1.33575439e-01,  -1.33575439e-01],
                        [ -1.28417969e-01,  -1.28417969e-01],
                        [ -1.28479004e-01,  -1.28479004e-01],
                        [ -1.33941650e-01,  -1.33941650e-01],
                        [ -1.33361816e-01,  -1.33361816e-01],
                        [ -1.10321045e-01,  -1.10321045e-01],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  1.53930664e-01,   1.53930664e-01],
                        [  2.03277588e-01,   2.03277588e-01],
                        [  2.24395752e-01,   2.24395752e-01],
                        [  2.15393066e-01,   2.15393066e-01],
                        [  1.86584473e-01,   1.86584473e-01],
                        [  1.56036377e-01,   1.56036377e-01],
                        [  1.37878418e-01,   1.37878418e-01],
                        [  1.29150391e-01,   1.29150391e-01],
                        [  1.16821289e-01,   1.16821289e-01],
                        [  1.00677490e-01,   1.00677490e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  7.64770508e-02,   7.64770508e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  5.21850586e-03,   5.21850586e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  9.82971191e-02,   9.82971191e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.06536865e-01,  -1.06536865e-01],
                        [ -1.82769775e-01,  -1.82769775e-01],
                        [ -2.23693848e-01,  -2.23693848e-01],
                        [ -2.20489502e-01,  -2.20489502e-01],
                        [ -1.89727783e-01,  -1.89727783e-01],
                        [ -1.56005859e-01,  -1.56005859e-01],
                        [ -1.33422852e-01,  -1.33422852e-01],
                        [ -1.21398926e-01,  -1.21398926e-01],
                        [ -1.11724854e-01,  -1.11724854e-01],
                        [ -9.74426270e-02,  -9.74426270e-02],
                        [ -8.18176270e-02,  -8.18176270e-02],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -8.52661133e-02,  -8.52661133e-02],
                        [ -9.70764160e-02,  -9.70764160e-02],
                        [ -9.79919434e-02,  -9.79919434e-02],
                        [ -8.64868164e-02,  -8.64868164e-02],
                        [ -6.82373047e-02,  -6.82373047e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  7.91931152e-02,   7.91931152e-02],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  1.21032715e-01,   1.21032715e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.18560791e-01,   1.18560791e-01],
                        [  1.37390137e-01,   1.37390137e-01],
                        [  1.59820557e-01,   1.59820557e-01],
                        [  1.84265137e-01,   1.84265137e-01],
                        [  2.07183838e-01,   2.07183838e-01],
                        [  2.16888428e-01,   2.16888428e-01],
                        [  1.93359375e-01,   1.93359375e-01],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -1.27593994e-01,  -1.27593994e-01],
                        [ -2.46398926e-01,  -2.46398926e-01],
                        [ -3.18603516e-01,  -3.18603516e-01],
                        [ -3.25714111e-01,  -3.25714111e-01],
                        [ -2.76519775e-01,  -2.76519775e-01],
                        [ -2.06787109e-01,  -2.06787109e-01],
                        [ -1.54724121e-01,  -1.54724121e-01],
                        [ -1.33728027e-01,  -1.33728027e-01],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -1.29974365e-01,  -1.29974365e-01],
                        [ -1.24450684e-01,  -1.24450684e-01],
                        [ -1.20147705e-01,  -1.20147705e-01],
                        [ -1.20666504e-01,  -1.20666504e-01],
                        [ -1.19049072e-01,  -1.19049072e-01],
                        [ -1.02783203e-01,  -1.02783203e-01],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  1.65191650e-01,   1.65191650e-01],
                        [  2.17742920e-01,   2.17742920e-01],
                        [  2.35137939e-01,   2.35137939e-01],
                        [  2.17620850e-01,   2.17620850e-01],
                        [  1.77124023e-01,   1.77124023e-01],
                        [  1.35925293e-01,   1.35925293e-01],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.12335205e-01,   1.12335205e-01],
                        [  1.17614746e-01,   1.17614746e-01],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  1.09130859e-01,   1.09130859e-01],
                        [  9.72900391e-02,   9.72900391e-02],
                        [  8.18176270e-02,   8.18176270e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  4.99572754e-02,   4.99572754e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -1.04431152e-01,  -1.04431152e-01],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -2.10388184e-01,  -2.10388184e-01],
                        [ -2.11547852e-01,  -2.11547852e-01],
                        [ -1.88629150e-01,  -1.88629150e-01],
                        [ -1.58416748e-01,  -1.58416748e-01],
                        [ -1.31622314e-01,  -1.31622314e-01],
                        [ -1.12976074e-01,  -1.12976074e-01],
                        [ -1.03790283e-01,  -1.03790283e-01],
                        [ -1.01531982e-01,  -1.01531982e-01],
                        [ -1.01562500e-01,  -1.01562500e-01],
                        [ -1.03332520e-01,  -1.03332520e-01],
                        [ -1.08978271e-01,  -1.08978271e-01],
                        [ -1.12579346e-01,  -1.12579346e-01],
                        [ -1.03057861e-01,  -1.03057861e-01],
                        [ -8.04443359e-02,  -8.04443359e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  8.00476074e-02,   8.00476074e-02],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  1.09954834e-01,   1.09954834e-01],
                        [  1.36352539e-01,   1.36352539e-01],
                        [  1.69372559e-01,   1.69372559e-01],
                        [  2.03063965e-01,   2.03063965e-01],
                        [  2.22351074e-01,   2.22351074e-01],
                        [  2.15393066e-01,   2.15393066e-01],
                        [  1.76361084e-01,   1.76361084e-01],
                        [  1.01104736e-01,   1.01104736e-01],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -1.31103516e-01,  -1.31103516e-01],
                        [ -2.46368408e-01,  -2.46368408e-01],
                        [ -3.23211670e-01,  -3.23211670e-01],
                        [ -3.36029053e-01,  -3.36029053e-01],
                        [ -2.84881592e-01,  -2.84881592e-01],
                        [ -2.06939697e-01,  -2.06939697e-01],
                        [ -1.49505615e-01,  -1.49505615e-01],
                        [ -1.28692627e-01,  -1.28692627e-01],
                        [ -1.26464844e-01,  -1.26464844e-01],
                        [ -1.24633789e-01,  -1.24633789e-01],
                        [ -1.23504639e-01,  -1.23504639e-01],
                        [ -1.26556396e-01,  -1.26556396e-01],
                        [ -1.25946045e-01,  -1.25946045e-01],
                        [ -1.11846924e-01,  -1.11846924e-01],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.67480469e-01,   1.67480469e-01],
                        [  2.15454102e-01,   2.15454102e-01],
                        [  2.26379395e-01,   2.26379395e-01],
                        [  2.04589844e-01,   2.04589844e-01],
                        [  1.66656494e-01,   1.66656494e-01],
                        [  1.30981445e-01,   1.30981445e-01],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  1.08093262e-01,   1.08093262e-01],
                        [  1.06750488e-01,   1.06750488e-01],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  2.20947266e-02,   2.21252441e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.44653320e-02,   1.44348145e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -1.41265869e-01,  -1.41265869e-01],
                        [ -2.10845947e-01,  -2.10845947e-01],
                        [ -2.37243652e-01,  -2.37243652e-01],
                        [ -2.16125488e-01,  -2.16125488e-01],
                        [ -1.76086426e-01,  -1.76086426e-01],
                        [ -1.47583008e-01,  -1.47583008e-01],
                        [ -1.36352539e-01,  -1.36352539e-01],
                        [ -1.28143311e-01,  -1.28143311e-01],
                        [ -1.11968994e-01,  -1.11968994e-01],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -8.14514160e-02,  -8.14514160e-02],
                        [ -8.10852051e-02,  -8.10852051e-02],
                        [ -8.54797363e-02,  -8.54797363e-02],
                        [ -8.76159668e-02,  -8.76159668e-02],
                        [ -8.30383301e-02,  -8.30383301e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  1.24786377e-01,   1.24786377e-01],
                        [  1.39343262e-01,   1.39343262e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.21917725e-01,   1.21917725e-01],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  1.37573242e-01,   1.37573242e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.81274414e-01,   1.81274414e-01],
                        [  1.97692871e-01,   1.97692871e-01],
                        [  2.08435059e-01,   2.08435059e-01],
                        [  2.03918457e-01,   2.03918457e-01],
                        [  1.67846680e-01,   1.67846680e-01],
                        [  8.99658203e-02,   8.99658203e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.48162842e-01,  -1.48162842e-01],
                        [ -2.53875732e-01,  -2.53875732e-01],
                        [ -3.12927246e-01,  -3.12927246e-01],
                        [ -3.11706543e-01,  -3.11706543e-01],
                        [ -2.58636475e-01,  -2.58636475e-01],
                        [ -1.86462402e-01,  -1.86462402e-01],
                        [ -1.35772705e-01,  -1.35772705e-01],
                        [ -1.24389648e-01,  -1.24389648e-01],
                        [ -1.37664795e-01,  -1.37664795e-01],
                        [ -1.52832031e-01,  -1.52832031e-01],
                        [ -1.59851074e-01,  -1.59851074e-01],
                        [ -1.56372070e-01,  -1.56372070e-01],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -1.01440430e-01,  -1.01440430e-01],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  7.34252930e-02,   7.34252930e-02],
                        [  1.38641357e-01,   1.38641357e-01],
                        [  1.94244385e-01,   1.94244385e-01],
                        [  2.21893311e-01,   2.21893311e-01],
                        [  2.10388184e-01,   2.10388184e-01],
                        [  1.71447754e-01,   1.71447754e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  9.80529785e-02,   9.80529785e-02],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  1.01318359e-01,   1.01318359e-01],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.01593018e-01,   1.01593018e-01],
                        [  9.85107422e-02,   9.85107422e-02],
                        [  8.79821777e-02,   8.79821777e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  4.41284180e-02,   4.41284180e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  6.44836426e-02,   6.44836426e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -9.05456543e-02,  -9.05456543e-02],
                        [ -1.60339355e-01,  -1.60339355e-01],
                        [ -2.07733154e-01,  -2.07733154e-01],
                        [ -2.18688965e-01,  -2.18688965e-01],
                        [ -1.98303223e-01,  -1.98303223e-01],
                        [ -1.64947510e-01,  -1.64947510e-01],
                        [ -1.36322021e-01,  -1.36322021e-01],
                        [ -1.19567871e-01,  -1.19567871e-01],
                        [ -1.11236572e-01,  -1.11236572e-01],
                        [ -1.03790283e-01,  -1.03790283e-01],
                        [ -9.42687988e-02,  -9.42687988e-02],
                        [ -8.77685547e-02,  -8.77685547e-02],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -9.19799805e-02,  -9.19799805e-02],
                        [ -8.85314941e-02,  -8.85314941e-02],
                        [ -7.46154785e-02,  -7.46154785e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [  3.43017578e-02,   3.42712402e-02],
                        [  8.33129883e-02,   8.33129883e-02],
                        [  1.24176025e-01,   1.24176025e-01],
                        [  1.44927979e-01,   1.44927979e-01],
                        [  1.43524170e-01,   1.43524170e-01],
                        [  1.32568359e-01,   1.32568359e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  1.33575439e-01,   1.33575439e-01],
                        [  1.52435303e-01,   1.52435303e-01],
                        [  1.81671143e-01,   1.81671143e-01],
                        [  2.09381104e-01,   2.09381104e-01],
                        [  2.18139648e-01,   2.18139648e-01],
                        [  1.99127197e-01,   1.99127197e-01],
                        [  1.51458740e-01,   1.51458740e-01],
                        [  7.33642578e-02,   7.33642578e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -1.55456543e-01,  -1.55456543e-01],
                        [ -2.63275146e-01,  -2.63275146e-01],
                        [ -3.23394775e-01,  -3.23394775e-01],
                        [ -3.15155029e-01,  -3.15155029e-01],
                        [ -2.51556396e-01,  -2.51556396e-01],
                        [ -1.77551270e-01,  -1.77551270e-01],
                        [ -1.36138916e-01,  -1.36138916e-01],
                        [ -1.32537842e-01,  -1.32537842e-01],
                        [ -1.39495850e-01,  -1.39495850e-01],
                        [ -1.35833740e-01,  -1.35833740e-01],
                        [ -1.26281738e-01,  -1.26312256e-01],
                        [ -1.21368408e-01,  -1.21368408e-01],
                        [ -1.13342285e-01,  -1.13342285e-01],
                        [ -8.32519531e-02,  -8.32824707e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  1.07513428e-01,   1.07513428e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.92352295e-01,   1.92382812e-01],
                        [  2.08221436e-01,   2.08221436e-01],
                        [  1.96044922e-01,   1.96014404e-01],
                        [  1.60827637e-01,   1.60827637e-01],
                        [  1.24145508e-01,   1.24145508e-01],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  8.93859863e-02,   8.93554688e-02],
                        [  8.07189941e-02,   8.07495117e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  8.84704590e-02,   8.85009766e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  9.03015137e-02,   9.03015137e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  4.77294922e-02,   4.77294922e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  2.04467773e-02,   2.04772949e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -9.76562500e-03,  -9.73510742e-03],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  4.72106934e-02,   4.71801758e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  5.44128418e-02,   5.43823242e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -1.04888916e-01,  -1.04888916e-01],
                        [ -1.70898438e-01,  -1.70898438e-01],
                        [ -2.13897705e-01,  -2.13897705e-01],
                        [ -2.18353271e-01,  -2.18353271e-01],
                        [ -1.88232422e-01,  -1.88232422e-01],
                        [ -1.44958496e-01,  -1.44958496e-01],
                        [ -1.13250732e-01,  -1.13250732e-01],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -1.06079102e-01,  -1.06079102e-01],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -1.01135254e-01,  -1.01135254e-01],
                        [ -9.69543457e-02,  -9.69543457e-02],
                        [ -9.33532715e-02,  -9.33532715e-02],
                        [ -8.47778320e-02,  -8.48083496e-02],
                        [ -6.84509277e-02,  -6.84509277e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.35803223e-01,   1.35803223e-01],
                        [  1.33392334e-01,   1.33392334e-01],
                        [  1.31408691e-01,   1.31439209e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.38244629e-01,   1.38244629e-01],
                        [  1.55242920e-01,   1.55242920e-01],
                        [  1.83380127e-01,   1.83380127e-01],
                        [  2.07733154e-01,   2.07733154e-01],
                        [  2.08984375e-01,   2.08984375e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -1.10290527e-01,  -1.10290527e-01],
                        [ -2.24639893e-01,  -2.24639893e-01],
                        [ -2.98736572e-01,  -2.98736572e-01],
                        [ -3.08563232e-01,  -3.08563232e-01],
                        [ -2.60437012e-01,  -2.60467529e-01],
                        [ -1.92138672e-01,  -1.92138672e-01],
                        [ -1.44531250e-01,  -1.44531250e-01],
                        [ -1.30737305e-01,  -1.30737305e-01],
                        [ -1.35894775e-01,  -1.35894775e-01],
                        [ -1.41052246e-01,  -1.41052246e-01],
                        [ -1.38488770e-01,  -1.38488770e-01],
                        [ -1.28204346e-01,  -1.28204346e-01],
                        [ -1.12030029e-01,  -1.12030029e-01],
                        [ -8.98132324e-02,  -8.98132324e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  1.60491943e-01,   1.60491943e-01],
                        [  2.17102051e-01,   2.17102051e-01],
                        [  2.35260010e-01,   2.35260010e-01],
                        [  2.16888428e-01,   2.16888428e-01],
                        [  1.79687500e-01,   1.79687500e-01],
                        [  1.44104004e-01,   1.44104004e-01],
                        [  1.18804932e-01,   1.18804932e-01],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  7.61108398e-02,   7.61108398e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  7.88879395e-02,   7.88879395e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  6.44836426e-02,   6.44836426e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  4.88891602e-02,   4.89196777e-02],
                        [  4.50439453e-02,   4.50134277e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  3.79333496e-02,   3.79638672e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.47094727e-02,  -1.46789551e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.37426758e-02,  -2.37121582e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.56250000e-02,  -1.56555176e-02],
                        [ -1.63574219e-02,  -1.63269043e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -4.04968262e-02,  -4.05273438e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -6.36596680e-02,  -6.36291504e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.86865234e-02,   2.87170410e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.45153809e-02,   3.44848633e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  1.84020996e-02,   1.83715820e-02],
                        [  9.15527344e-03,   9.18579102e-03],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  2.92053223e-02,   2.91748047e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -8.21838379e-02,  -8.21838379e-02],
                        [ -1.56158447e-01,  -1.56158447e-01],
                        [ -2.09686279e-01,  -2.09686279e-01],
                        [ -2.18566895e-01,  -2.18536377e-01],
                        [ -1.86523438e-01,  -1.86492920e-01],
                        [ -1.42150879e-01,  -1.42150879e-01],
                        [ -1.10321045e-01,  -1.10321045e-01],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -8.70361328e-02,  -8.70361328e-02],
                        [ -8.52661133e-02,  -8.52661133e-02],
                        [ -8.88366699e-02,  -8.88366699e-02],
                        [ -9.58557129e-02,  -9.58557129e-02],
                        [ -1.02539062e-01,  -1.02539062e-01],
                        [ -1.03179932e-01,  -1.03179932e-01],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -5.71594238e-02,  -5.71899414e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  1.07635498e-01,   1.07635498e-01],
                        [  1.46636963e-01,   1.46636963e-01],
                        [  1.60430908e-01,   1.60430908e-01],
                        [  1.52130127e-01,   1.52130127e-01],
                        [  1.40045166e-01,   1.40045166e-01],
                        [  1.45507812e-01,   1.45507812e-01],
                        [  1.72149658e-01,   1.72149658e-01],
                        [  2.02331543e-01,   2.02331543e-01],
                        [  2.18139648e-01,   2.18139648e-01],
                        [  2.14447021e-01,   2.14447021e-01],
                        [  1.86614990e-01,   1.86614990e-01],
                        [  1.21917725e-01,   1.21917725e-01],
                        [  1.60217285e-02,   1.60217285e-02],
                        [ -1.11846924e-01,  -1.11846924e-01],
                        [ -2.29156494e-01,  -2.29156494e-01],
                        [ -3.07830811e-01,  -3.07830811e-01],
                        [ -3.28521729e-01,  -3.28521729e-01],
                        [ -2.87506104e-01,  -2.87536621e-01],
                        [ -2.12249756e-01,  -2.12249756e-01],
                        [ -1.49963379e-01,  -1.49963379e-01],
                        [ -1.26068115e-01,  -1.26068115e-01],
                        [ -1.27441406e-01,  -1.27471924e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -1.31225586e-01,  -1.31195068e-01],
                        [ -1.26281738e-01,  -1.26312256e-01],
                        [ -1.10565186e-01,  -1.10565186e-01],
                        [ -7.74841309e-02,  -7.74841309e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [  4.41589355e-02,   4.41284180e-02],
                        [  1.23474121e-01,   1.23474121e-01],
                        [  1.89117432e-01,   1.89117432e-01],
                        [  2.17010498e-01,   2.16979980e-01],
                        [  2.06298828e-01,   2.06268311e-01],
                        [  1.77429199e-01,   1.77459717e-01],
                        [  1.47644043e-01,   1.47644043e-01],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.04156494e-01,   1.04187012e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  9.73510742e-02,   9.73205566e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  8.45947266e-02,   8.46252441e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  4.63867188e-02,   4.64172363e-02],
                        [  5.23681641e-02,   5.23681641e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -1.88903809e-02,  -1.89208984e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -1.06506348e-02,  -1.06201172e-02],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.88903809e-02,   1.89208984e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  1.50146484e-02,   1.49841309e-02],
                        [  4.42504883e-03,   4.42504883e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  6.40869141e-03,   6.37817383e-03],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -8.96911621e-02,  -8.96911621e-02],
                        [ -1.62017822e-01,  -1.62017822e-01],
                        [ -2.13378906e-01,  -2.13378906e-01],
                        [ -2.24182129e-01,  -2.24182129e-01],
                        [ -1.99493408e-01,  -1.99493408e-01],
                        [ -1.64428711e-01,  -1.64428711e-01],
                        [ -1.38946533e-01,  -1.38946533e-01],
                        [ -1.22467041e-01,  -1.22467041e-01],
                        [ -1.04766846e-01,  -1.04766846e-01],
                        [ -8.48999023e-02,  -8.48999023e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -7.52868652e-02,  -7.52868652e-02],
                        [ -6.82373047e-02,  -6.82373047e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  1.08001709e-01,   1.07971191e-01],
                        [  1.42700195e-01,   1.42730713e-01],
                        [  1.58538818e-01,   1.58538818e-01],
                        [  1.61712646e-01,   1.61682129e-01],
                        [  1.63818359e-01,   1.63818359e-01],
                        [  1.70593262e-01,   1.70593262e-01],
                        [  1.79962158e-01,   1.79931641e-01],
                        [  1.87896729e-01,   1.87866211e-01],
                        [  1.89666748e-01,   1.89666748e-01],
                        [  1.73583984e-01,   1.73583984e-01],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  2.95410156e-02,   2.95410156e-02],
                        [ -9.06372070e-02,  -9.06372070e-02],
                        [ -2.08709717e-01,  -2.08709717e-01],
                        [ -2.92541504e-01,  -2.92541504e-01],
                        [ -3.18786621e-01,  -3.18786621e-01],
                        [ -2.86315918e-01,  -2.86315918e-01],
                        [ -2.22381592e-01,  -2.22381592e-01],
                        [ -1.67877197e-01,  -1.67877197e-01],
                        [ -1.47308350e-01,  -1.47308350e-01],
                        [ -1.52313232e-01,  -1.52313232e-01],
                        [ -1.57104492e-01,  -1.57073975e-01],
                        [ -1.47247314e-01,  -1.47247314e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -1.09161377e-01,  -1.09161377e-01],
                        [ -8.20312500e-02,  -8.20312500e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [  4.33959961e-02,   4.34265137e-02],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  1.96289062e-01,   1.96289062e-01],
                        [  2.26470947e-01,   2.26470947e-01],
                        [  2.15484619e-01,   2.15484619e-01],
                        [  1.78955078e-01,   1.78955078e-01],
                        [  1.39739990e-01,   1.39739990e-01],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  9.17358398e-02,   9.17358398e-02],
                        [  7.72399902e-02,   7.72399902e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  7.33642578e-02,   7.33947754e-02],
                        [  7.90405273e-02,   7.90405273e-02],
                        [  7.67211914e-02,   7.67211914e-02],
                        [  6.71386719e-02,   6.71691895e-02],
                        [  5.91125488e-02,   5.91430664e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  5.05065918e-02,   5.05371094e-02],
                        [  5.85937500e-02,   5.85632324e-02],
                        [  6.93359375e-02,   6.93054199e-02],
                        [  7.18383789e-02,   7.18383789e-02],
                        [  6.54602051e-02,   6.54907227e-02],
                        [  5.67321777e-02,   5.67016602e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  3.03344727e-02,   3.03649902e-02],
                        [  1.11389160e-02,   1.11389160e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -2.89001465e-02,  -2.88696289e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -2.74047852e-02,  -2.74353027e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.17187500e-02,   1.17492676e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  2.41088867e-03,   2.41088867e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -1.08673096e-01,  -1.08673096e-01],
                        [ -1.73492432e-01,  -1.73461914e-01],
                        [ -2.08648682e-01,  -2.08648682e-01],
                        [ -1.99951172e-01,  -1.99951172e-01],
                        [ -1.60827637e-01,  -1.60827637e-01],
                        [ -1.23321533e-01,  -1.23321533e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -9.75036621e-02,  -9.75036621e-02],
                        [ -8.77380371e-02,  -8.77380371e-02],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -7.43408203e-02,  -7.43713379e-02],
                        [ -7.55310059e-02,  -7.55310059e-02],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -6.43615723e-02,  -6.43920898e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  7.28759766e-02,   7.28454590e-02],
                        [  1.14715576e-01,   1.14715576e-01],
                        [  1.43402100e-01,   1.43402100e-01],
                        [  1.58325195e-01,   1.58325195e-01],
                        [  1.68609619e-01,   1.68609619e-01],
                        [  1.84539795e-01,   1.84539795e-01],
                        [  2.08038330e-01,   2.08038330e-01],
                        [  2.28393555e-01,   2.28393555e-01],
                        [  2.25891113e-01,   2.25891113e-01],
                        [  1.84326172e-01,   1.84326172e-01],
                        [  1.01837158e-01,   1.01837158e-01],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.36566162e-01,  -1.36566162e-01],
                        [ -2.49847412e-01,  -2.49847412e-01],
                        [ -3.19244385e-01,  -3.19213867e-01],
                        [ -3.24340820e-01,  -3.24371338e-01],
                        [ -2.75726318e-01,  -2.75726318e-01],
                        [ -2.11608887e-01,  -2.11608887e-01],
                        [ -1.69433594e-01,  -1.69433594e-01],
                        [ -1.57348633e-01,  -1.57348633e-01],
                        [ -1.55883789e-01,  -1.55883789e-01],
                        [ -1.46820068e-01,  -1.46820068e-01],
                        [ -1.30920410e-01,  -1.30920410e-01],
                        [ -1.14044189e-01,  -1.14074707e-01],
                        [ -8.96301270e-02,  -8.96301270e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.05743408e-01,   1.05743408e-01],
                        [  1.76513672e-01,   1.76513672e-01],
                        [  2.15789795e-01,   2.15759277e-01],
                        [  2.17742920e-01,   2.17742920e-01],
                        [  1.94000244e-01,   1.94000244e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.24084473e-01,   1.24084473e-01],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  7.08923340e-02,   7.09228516e-02],
                        [  6.52160645e-02,   6.51855469e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  7.15942383e-02,   7.15637207e-02],
                        [  5.69763184e-02,   5.70068359e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  5.00183105e-02,   5.00183105e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  6.33239746e-02,   6.33544922e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  5.88684082e-02,   5.88989258e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  6.35070801e-02,   6.34765625e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  1.93481445e-02,   1.93176270e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -1.22680664e-02,  -1.22375488e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.27563477e-02,  -1.27258301e-02],
                        [ -4.39453125e-03,  -4.36401367e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  2.03552246e-02,   2.03247070e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -1.54418945e-01,  -1.54418945e-01],
                        [ -1.91955566e-01,  -1.91986084e-01],
                        [ -1.90155029e-01,  -1.90155029e-01],
                        [ -1.58325195e-01,  -1.58294678e-01],
                        [ -1.22009277e-01,  -1.22009277e-01],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -8.49304199e-02,  -8.48999023e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -7.91931152e-02,  -7.91931152e-02],
                        [ -7.40356445e-02,  -7.40356445e-02],
                        [ -6.49108887e-02,  -6.49108887e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  1.17797852e-01,   1.17828369e-01],
                        [  1.60980225e-01,   1.60949707e-01],
                        [  1.90917969e-01,   1.90917969e-01],
                        [  2.15576172e-01,   2.15576172e-01],
                        [  2.36114502e-01,   2.36114502e-01],
                        [  2.44720459e-01,   2.44720459e-01],
                        [  2.32269287e-01,   2.32269287e-01],
                        [  1.92749023e-01,   1.92749023e-01],
                        [  1.22985840e-01,   1.22955322e-01],
                        [  2.48107910e-02,   2.48107910e-02],
                        [ -9.24682617e-02,  -9.24377441e-02],
                        [ -2.11975098e-01,  -2.11975098e-01],
                        [ -3.06518555e-01,  -3.06549072e-01],
                        [ -3.43048096e-01,  -3.43017578e-01],
                        [ -3.08349609e-01,  -3.08349609e-01],
                        [ -2.33123779e-01,  -2.33123779e-01],
                        [ -1.71173096e-01,  -1.71173096e-01],
                        [ -1.49841309e-01,  -1.49810791e-01],
                        [ -1.52801514e-01,  -1.52801514e-01],
                        [ -1.52160645e-01,  -1.52160645e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -1.17675781e-01,  -1.17675781e-01],
                        [ -9.11254883e-02,  -9.11254883e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  1.65985107e-01,   1.65985107e-01],
                        [  2.13470459e-01,   2.13500977e-01],
                        [  2.16674805e-01,   2.16644287e-01],
                        [  1.89056396e-01,   1.89056396e-01],
                        [  1.58416748e-01,   1.58416748e-01],
                        [  1.38305664e-01,   1.38305664e-01],
                        [  1.19964600e-01,   1.19934082e-01],
                        [  9.28344727e-02,   9.28344727e-02],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  4.61425781e-02,   4.61120605e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.92260742e-02,  -1.91955566e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.16259766e-02,  -4.15954590e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.98559570e-02,  -3.98864746e-02],
                        [ -3.85437012e-02,  -3.85131836e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [  9.73510742e-03,   9.70458984e-03],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  2.34985352e-02,   2.35290527e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  1.67541504e-02,   1.67236328e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -1.41082764e-01,  -1.41082764e-01],
                        [ -1.78314209e-01,  -1.78314209e-01],
                        [ -1.85913086e-01,  -1.85913086e-01],
                        [ -1.66198730e-01,  -1.66198730e-01],
                        [ -1.32904053e-01,  -1.32904053e-01],
                        [ -1.02722168e-01,  -1.02722168e-01],
                        [ -8.49914551e-02,  -8.49914551e-02],
                        [ -7.97119141e-02,  -7.97424316e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -7.94372559e-02,  -7.94067383e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  8.29772949e-02,   8.29772949e-02],
                        [  1.29791260e-01,   1.29791260e-01],
                        [  1.66870117e-01,   1.66870117e-01],
                        [  1.97601318e-01,   1.97631836e-01],
                        [  2.21405029e-01,   2.21405029e-01],
                        [  2.33734131e-01,   2.33734131e-01],
                        [  2.31781006e-01,   2.31781006e-01],
                        [  2.09838867e-01,   2.09838867e-01],
                        [  1.56066895e-01,   1.56066895e-01],
                        [  6.42089844e-02,   6.42089844e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -1.73797607e-01,  -1.73828125e-01],
                        [ -2.69134521e-01,  -2.69134521e-01],
                        [ -3.19183350e-01,  -3.19183350e-01],
                        [ -3.13385010e-01,  -3.13385010e-01],
                        [ -2.61596680e-01,  -2.61596680e-01],
                        [ -1.97235107e-01,  -1.97204590e-01],
                        [ -1.56982422e-01,  -1.56982422e-01],
                        [ -1.49627686e-01,  -1.49627686e-01],
                        [ -1.51977539e-01,  -1.51977539e-01],
                        [ -1.40655518e-01,  -1.40655518e-01],
                        [ -1.16119385e-01,  -1.16119385e-01],
                        [ -8.83483887e-02,  -8.83483887e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  1.38763428e-01,   1.38732910e-01],
                        [  1.94549561e-01,   1.94549561e-01],
                        [  2.16766357e-01,   2.16735840e-01],
                        [  2.03979492e-01,   2.03948975e-01],
                        [  1.73248291e-01,   1.73248291e-01],
                        [  1.45294189e-01,   1.45294189e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.05529785e-01,   1.05529785e-01],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  5.86547852e-02,   5.86242676e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  8.02001953e-02,   8.01696777e-02],
                        [  7.54089355e-02,   7.54394531e-02],
                        [  7.14111328e-02,   7.14111328e-02],
                        [  7.07702637e-02,   7.07397461e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  6.24694824e-02,   6.25000000e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.44848633e-02,   3.44543457e-02],
                        [  3.29589844e-02,   3.29284668e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  1.10473633e-02,   1.10168457e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.30712891e-02,  -2.30407715e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.99377441e-02,  -2.99072266e-02],
                        [ -2.64587402e-02,  -2.64892578e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [  1.06811523e-03,   1.03759766e-03],
                        [  5.12695312e-03,   5.15747070e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -2.74658203e-03,  -2.71606445e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -1.16149902e-01,  -1.16149902e-01],
                        [ -1.67114258e-01,  -1.67114258e-01],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -1.72271729e-01,  -1.72271729e-01],
                        [ -1.37237549e-01,  -1.37237549e-01],
                        [ -1.08062744e-01,  -1.08062744e-01],
                        [ -9.69848633e-02,  -9.69848633e-02],
                        [ -9.77478027e-02,  -9.77478027e-02],
                        [ -1.00311279e-01,  -1.00311279e-01],
                        [ -1.00067139e-01,  -1.00067139e-01],
                        [ -9.46044922e-02,  -9.46044922e-02],
                        [ -8.00476074e-02,  -8.00476074e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  1.46697998e-01,   1.46697998e-01],
                        [  1.84692383e-01,   1.84692383e-01],
                        [  2.11120605e-01,   2.11120605e-01],
                        [  2.28637695e-01,   2.28637695e-01],
                        [  2.37548828e-01,   2.37548828e-01],
                        [  2.30926514e-01,   2.30926514e-01],
                        [  1.96136475e-01,   1.96136475e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  2.10571289e-02,   2.10571289e-02],
                        [ -9.96093750e-02,  -9.96093750e-02],
                        [ -2.16094971e-01,  -2.16094971e-01],
                        [ -3.01452637e-01,  -3.01452637e-01],
                        [ -3.30841064e-01,  -3.30841064e-01],
                        [ -3.02337646e-01,  -3.02337646e-01],
                        [ -2.45086670e-01,  -2.45086670e-01],
                        [ -1.96105957e-01,  -1.96105957e-01],
                        [ -1.70898438e-01,  -1.70898438e-01],
                        [ -1.59881592e-01,  -1.59881592e-01],
                        [ -1.47308350e-01,  -1.47308350e-01],
                        [ -1.26251221e-01,  -1.26251221e-01],
                        [ -9.71679688e-02,  -9.71679688e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.87133789e-01,   1.87164307e-01],
                        [  2.14111328e-01,   2.14111328e-01],
                        [  2.11822510e-01,   2.11822510e-01],
                        [  1.87133789e-01,   1.87133789e-01],
                        [  1.49169922e-01,   1.49200439e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  8.15429688e-02,   8.15429688e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  5.74951172e-02,   5.75256348e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  4.13208008e-02,   4.12902832e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  8.02001953e-02,   8.02001953e-02],
                        [  7.96813965e-02,   7.96813965e-02],
                        [  7.73620605e-02,   7.73620605e-02],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  1.19018555e-03,   1.22070312e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  4.76074219e-03,   4.76074219e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -4.27246094e-03,  -4.30297852e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.36413574e-02,   1.36108398e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -1.06994629e-01,  -1.06994629e-01],
                        [ -1.61407471e-01,  -1.61407471e-01],
                        [ -1.89666748e-01,  -1.89697266e-01],
                        [ -1.85363770e-01,  -1.85363770e-01],
                        [ -1.58660889e-01,  -1.58630371e-01],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -1.14257812e-01,  -1.14257812e-01],
                        [ -1.06903076e-01,  -1.06903076e-01],
                        [ -9.47265625e-02,  -9.47265625e-02],
                        [ -7.47070312e-02,  -7.47070312e-02],
                        [ -5.55419922e-02,  -5.55114746e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [  9.85717773e-03,   9.82666016e-03],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  1.10229492e-01,   1.10260010e-01],
                        [  1.62139893e-01,   1.62139893e-01],
                        [  2.01904297e-01,   2.01873779e-01],
                        [  2.27386475e-01,   2.27416992e-01],
                        [  2.41729736e-01,   2.41729736e-01],
                        [  2.41516113e-01,   2.41516113e-01],
                        [  2.13745117e-01,   2.13714600e-01],
                        [  1.47247314e-01,   1.47216797e-01],
                        [  4.43725586e-02,   4.44030762e-02],
                        [ -7.97424316e-02,  -7.97119141e-02],
                        [ -2.03521729e-01,  -2.03552246e-01],
                        [ -2.99987793e-01,  -2.99987793e-01],
                        [ -3.41033936e-01,  -3.41033936e-01],
                        [ -3.17260742e-01,  -3.17230225e-01],
                        [ -2.53845215e-01,  -2.53845215e-01],
                        [ -1.94244385e-01,  -1.94213867e-01],
                        [ -1.64184570e-01,  -1.64184570e-01],
                        [ -1.56951904e-01,  -1.56982422e-01],
                        [ -1.50878906e-01,  -1.50848389e-01],
                        [ -1.32629395e-01,  -1.32629395e-01],
                        [ -1.01776123e-01,  -1.01776123e-01],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  1.36718750e-01,   1.36688232e-01],
                        [  1.87225342e-01,   1.87255859e-01],
                        [  2.05413818e-01,   2.05413818e-01],
                        [  1.92138672e-01,   1.92138672e-01],
                        [  1.62567139e-01,   1.62567139e-01],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  8.52050781e-02,   8.51745605e-02],
                        [  7.55615234e-02,   7.55310059e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  5.89294434e-02,   5.89599609e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  5.17883301e-02,   5.17578125e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  3.29895020e-02,   3.30200195e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  5.57861328e-02,   5.57556152e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  9.10339355e-02,   9.10644531e-02],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  8.83483887e-02,   8.83789062e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  5.62438965e-02,   5.62133789e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [ -5.03540039e-03,  -5.06591797e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -1.38549805e-02,  -1.38244629e-02],
                        [ -2.17285156e-02,  -2.17590332e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.70483398e-02,  -3.69873047e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -3.97033691e-02,  -3.97644043e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -1.84020996e-02,  -1.83410645e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [  3.60107422e-03,   3.57055664e-03],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  8.94165039e-03,   8.97216797e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  7.99560547e-03,   7.96508789e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.97143555e-02,  -1.97448730e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -1.25122070e-03,  -1.22070312e-03],
                        [ -1.70898438e-03,  -1.67846680e-03],
                        [ -5.12695312e-03,  -5.15747070e-03],
                        [ -6.68334961e-03,  -6.71386719e-03],
                        [ -6.95800781e-03,  -6.92749023e-03],
                        [ -6.46972656e-03,  -6.43920898e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.30920410e-02,   1.30615234e-02],
                        [  2.06298828e-02,   2.05993652e-02],
                        [  3.00292969e-02,   3.00598145e-02],
                        [  3.99475098e-02,   3.99780273e-02],
                        [  4.11071777e-02,   4.10766602e-02],
                        [  2.41394043e-02,   2.40783691e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -6.72607422e-02,  -6.71997070e-02],
                        [ -1.27319336e-01,  -1.27288818e-01],
                        [ -1.77307129e-01,  -1.77398682e-01],
                        [ -1.98791504e-01,  -1.98852539e-01],
                        [ -1.83563232e-01,  -1.83502197e-01],
                        [ -1.43127441e-01,  -1.43035889e-01],
                        [ -1.01165771e-01,  -1.01226807e-01],
                        [ -7.45544434e-02,  -7.46459961e-02],
                        [ -6.42089844e-02,  -6.41784668e-02],
                        [ -6.29272461e-02,  -6.28356934e-02],
                        [ -6.50939941e-02,  -6.50634766e-02],
                        [ -6.54907227e-02,  -6.55517578e-02],
                        [ -5.56335449e-02,  -5.56640625e-02],
                        [ -2.72827148e-02,  -2.71911621e-02],
                        [  2.05688477e-02,   2.06298828e-02],
                        [  8.00781250e-02,   8.00170898e-02],
                        [  1.39801025e-01,   1.39770508e-01],
                        [  1.90124512e-01,   1.90155029e-01],
                        [  2.23907471e-01,   2.23937988e-01],
                        [  2.36022949e-01,   2.36022949e-01],
                        [  2.24761963e-01,   2.24731445e-01],
                        [  1.90643311e-01,   1.90643311e-01],
                        [  1.30645752e-01,   1.30645752e-01],
                        [  3.95507812e-02,   3.95202637e-02],
                        [ -7.78808594e-02,  -7.78808594e-02],
                        [ -1.99279785e-01,  -1.99249268e-01],
                        [ -2.92205811e-01,  -2.92236328e-01],
                        [ -3.30169678e-01,  -3.30200195e-01],
                        [ -3.07861328e-01,  -3.07861328e-01],
                        [ -2.49481201e-01,  -2.49450684e-01],
                        [ -1.96777344e-01,  -1.96746826e-01],
                        [ -1.76330566e-01,  -1.76361084e-01],
                        [ -1.76544189e-01,  -1.76574707e-01],
                        [ -1.65222168e-01,  -1.65222168e-01],
                        [ -1.28631592e-01,  -1.28631592e-01],
                        [ -7.98339844e-02,  -7.98339844e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  9.43603516e-02,   9.43298340e-02],
                        [  1.63635254e-01,   1.63665771e-01],
                        [  2.11486816e-01,   2.11517334e-01],
                        [  2.24121094e-01,   2.24121094e-01],
                        [  2.04315186e-01,   2.04284668e-01],
                        [  1.67236328e-01,   1.67236328e-01],
                        [  1.29913330e-01,   1.29974365e-01],
                        [  1.00830078e-01,   1.00891113e-01],
                        [  7.93151855e-02,   7.92846680e-02],
                        [  6.41174316e-02,   6.40563965e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  5.67932129e-02,   5.68542480e-02],
                        [  5.55725098e-02,   5.55725098e-02],
                        [  4.87976074e-02,   4.87365723e-02],
                        [  4.03442383e-02,   4.02832031e-02],
                        [  3.65295410e-02,   3.65905762e-02],
                        [  3.91845703e-02,   3.92456055e-02],
                        [  4.66918945e-02,   4.66308594e-02],
                        [  5.82885742e-02,   5.82275391e-02],
                        [  7.43408203e-02,   7.43713379e-02],
                        [  9.10034180e-02,   9.10644531e-02],
                        [  9.89074707e-02,   9.88464355e-02],
                        [  9.13085938e-02,   9.12475586e-02],
                        [  7.14721680e-02,   7.15332031e-02],
                        [  4.82177734e-02,   4.82482910e-02],
                        [  2.80761719e-02,   2.80151367e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  3.90625000e-03,   3.96728516e-03],
                        [ -3.63159180e-03,  -3.60107422e-03],
                        [ -9.76562500e-03,  -9.79614258e-03],
                        [ -1.30920410e-02,  -1.31225586e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.19421387e-02,  -2.18811035e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -4.50439453e-02,  -4.50744629e-02],
                        [ -5.02929688e-02,  -5.02624512e-02],
                        [ -4.37927246e-02,  -4.37316895e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -1.12915039e-03,  -1.19018555e-03],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.80151367e-02,   2.80456543e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  2.25830078e-02,   2.25524902e-02],
                        [  1.16577148e-02,   1.16882324e-02],
                        [ -8.85009766e-04,  -8.54492188e-04],
                        [ -1.20239258e-02,  -1.20544434e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.72424316e-02,  -1.72119141e-02],
                        [ -1.02233887e-02,  -1.01928711e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -1.06811523e-03,  -1.09863281e-03],
                        [ -4.21142578e-03,  -4.24194336e-03],
                        [ -1.11999512e-02,  -1.11694336e-02],
                        [ -2.01721191e-02,  -2.01110840e-02],
                        [ -2.73437500e-02,  -2.73742676e-02],
                        [ -2.80761719e-02,  -2.81372070e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.38244629e-02,  -1.37329102e-02],
                        [ -9.00268555e-03,  -8.97216797e-03],
                        [ -5.40161133e-03,  -5.49316406e-03],
                        [  1.06811523e-03,   1.00708008e-03],
                        [  8.51440430e-03,   8.54492188e-03],
                        [  1.28784180e-02,   1.29699707e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  2.30407715e-02,   2.29187012e-02],
                        [  2.63061523e-02,   2.62756348e-02],
                        [  1.73339844e-02,   1.74255371e-02],
                        [ -4.54711914e-03,  -4.48608398e-03],
                        [ -3.67126465e-02,  -3.67431641e-02],
                        [ -7.99560547e-02,  -8.00476074e-02],
                        [ -1.28845215e-01,  -1.28845215e-01],
                        [ -1.63330078e-01,  -1.63269043e-01],
                        [ -1.64642334e-01,  -1.64611816e-01],
                        [ -1.36688232e-01,  -1.36718750e-01],
                        [ -1.03271484e-01,  -1.03363037e-01],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -7.62329102e-02,  -7.61413574e-02],
                        [ -6.92138672e-02,  -6.91528320e-02],
                        [ -5.86853027e-02,  -5.87463379e-02],
                        [ -4.97131348e-02,  -4.97741699e-02],
                        [ -4.18395996e-02,  -4.18090820e-02],
                        [ -2.46887207e-02,  -2.46276855e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  6.36291504e-02,   6.35986328e-02],
                        [  1.22039795e-01,   1.22009277e-01],
                        [  1.74072266e-01,   1.74072266e-01],
                        [  2.11944580e-01,   2.11975098e-01],
                        [  2.30407715e-01,   2.30407715e-01],
                        [  2.22564697e-01,   2.22534180e-01],
                        [  1.82647705e-01,   1.82647705e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  5.67626953e-03,   5.64575195e-03],
                        [ -1.20666504e-01,  -1.20635986e-01],
                        [ -2.42980957e-01,  -2.42950439e-01],
                        [ -3.22082520e-01,  -3.22082520e-01],
                        [ -3.33709717e-01,  -3.33770752e-01],
                        [ -2.89123535e-01,  -2.89123535e-01],
                        [ -2.25921631e-01,  -2.25891113e-01],
                        [ -1.82037354e-01,  -1.81976318e-01],
                        [ -1.70623779e-01,  -1.70623779e-01],
                        [ -1.72180176e-01,  -1.72241211e-01],
                        [ -1.56066895e-01,  -1.56097412e-01],
                        [ -1.12579346e-01,  -1.12518311e-01],
                        [ -5.64575195e-02,  -5.63964844e-02],
                        [ -3.05175781e-04,  -3.35693359e-04],
                        [  5.93872070e-02,   5.92956543e-02],
                        [  1.25488281e-01,   1.25488281e-01],
                        [  1.84570312e-01,   1.84661865e-01],
                        [  2.17285156e-01,   2.17315674e-01],
                        [  2.17895508e-01,   2.17864990e-01],
                        [  1.95953369e-01,   1.95922852e-01],
                        [  1.62414551e-01,   1.62414551e-01],
                        [  1.22772217e-01,   1.22802734e-01],
                        [  8.30993652e-02,   8.31298828e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  4.44335938e-02,   4.44030762e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  6.49414062e-02,   6.50024414e-02],
                        [  6.93054199e-02,   6.93359375e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  5.09948730e-02,   5.09338379e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  4.39758301e-02,   4.40368652e-02],
                        [  5.05981445e-02,   5.06591797e-02],
                        [  6.09436035e-02,   6.09130859e-02],
                        [  6.90307617e-02,   6.89697266e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  6.34765625e-02,   6.35070801e-02],
                        [  5.81665039e-02,   5.81970215e-02],
                        [  5.64575195e-02,   5.64270020e-02],
                        [  5.44128418e-02,   5.43823242e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  3.19519043e-02,   3.19824219e-02],
                        [  1.37023926e-02,   1.37023926e-02],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.74560547e-02,  -1.73950195e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.58691406e-02,  -1.58996582e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.60925293e-02,  -2.60620117e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -6.37817383e-03,  -6.40869141e-03],
                        [ -3.57055664e-03,  -3.60107422e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  2.74658203e-04,   3.05175781e-04],
                        [  5.03540039e-03,   5.00488281e-03],
                        [  1.22070312e-02,   1.21765137e-02],
                        [  1.46789551e-02,   1.47399902e-02],
                        [  8.81958008e-03,   8.85009766e-03],
                        [  1.98364258e-03,   1.89208984e-03],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  1.01928711e-02,   1.02844238e-02],
                        [  1.33972168e-02,   1.34277344e-02],
                        [  7.26318359e-03,   7.14111328e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.95007324e-02,  -1.93786621e-02],
                        [ -3.01208496e-02,  -3.00598145e-02],
                        [ -3.37829590e-02,  -3.39050293e-02],
                        [ -3.21655273e-02,  -3.22265625e-02],
                        [ -2.94494629e-02,  -2.93273926e-02],
                        [ -2.61230469e-02,  -2.60314941e-02],
                        [ -2.21862793e-02,  -2.22473145e-02],
                        [ -2.12707520e-02,  -2.13928223e-02],
                        [ -2.36816406e-02,  -2.36511230e-02],
                        [ -2.22473145e-02,  -2.21862793e-02],
                        [ -1.16271973e-02,  -1.15966797e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  2.02026367e-02,   2.01110840e-02],
                        [  3.14025879e-02,   3.13415527e-02],
                        [  3.78417969e-02,   3.79333496e-02],
                        [  3.56140137e-02,   3.57360840e-02],
                        [  1.59912109e-02,   1.59301758e-02],
                        [ -2.71911621e-02,  -2.73437500e-02],
                        [ -8.66088867e-02,  -8.66088867e-02],
                        [ -1.40533447e-01,  -1.40411377e-01],
                        [ -1.67755127e-01,  -1.67694092e-01],
                        [ -1.64489746e-01,  -1.64550781e-01],
                        [ -1.43585205e-01,  -1.43676758e-01],
                        [ -1.18804932e-01,  -1.18774414e-01],
                        [ -9.59777832e-02,  -9.58557129e-02],
                        [ -7.69958496e-02,  -7.69653320e-02],
                        [ -6.26525879e-02,  -6.27441406e-02],
                        [ -4.91943359e-02,  -4.93164062e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -4.11987305e-03,  -3.99780273e-03],
                        [  2.68554688e-02,   2.69165039e-02],
                        [  6.68029785e-02,   6.67114258e-02],
                        [  1.21582031e-01,   1.21459961e-01],
                        [  1.82830811e-01,   1.82891846e-01],
                        [  2.28485107e-01,   2.28576660e-01],
                        [  2.41088867e-01,   2.41088867e-01],
                        [  2.17163086e-01,   2.17102051e-01],
                        [  1.57714844e-01,   1.57653809e-01],
                        [  6.16760254e-02,   6.16760254e-02],
                        [ -6.43615723e-02,  -6.43005371e-02],
                        [ -1.96716309e-01,  -1.96685791e-01],
                        [ -3.00262451e-01,  -3.00262451e-01],
                        [ -3.44482422e-01,  -3.44573975e-01],
                        [ -3.21136475e-01,  -3.21166992e-01],
                        [ -2.55279541e-01,  -2.55218506e-01],
                        [ -1.92962646e-01,  -1.92871094e-01],
                        [ -1.64550781e-01,  -1.64581299e-01],
                        [ -1.61560059e-01,  -1.61682129e-01],
                        [ -1.54083252e-01,  -1.54083252e-01],
                        [ -1.25183105e-01,  -1.25091553e-01],
                        [ -8.03222656e-02,  -8.02917480e-02],
                        [ -2.90832520e-02,  -2.91137695e-02],
                        [  2.77404785e-02,   2.77099609e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  1.45935059e-01,   1.45965576e-01],
                        [  1.84082031e-01,   1.84143066e-01],
                        [  1.97937012e-01,   1.97937012e-01],
                        [  1.91009521e-01,   1.90948486e-01],
                        [  1.72637939e-01,   1.72607422e-01],
                        [  1.50909424e-01,   1.50939941e-01],
                        [  1.27441406e-01,   1.27502441e-01],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  7.52563477e-02,   7.51647949e-02],
                        [  5.56945801e-02,   5.56335449e-02],
                        [  4.59289551e-02,   4.59899902e-02],
                        [  4.34265137e-02,   4.35180664e-02],
                        [  4.33959961e-02,   4.33654785e-02],
                        [  4.39453125e-02,   4.38232422e-02],
                        [  4.53796387e-02,   4.53796387e-02],
                        [  4.82177734e-02,   4.83093262e-02],
                        [  5.39550781e-02,   5.39855957e-02],
                        [  6.30187988e-02,   6.29272461e-02],
                        [  7.12890625e-02,   7.12280273e-02],
                        [  7.42797852e-02,   7.43408203e-02],
                        [  7.32727051e-02,   7.33337402e-02],
                        [  7.25097656e-02,   7.24792480e-02],
                        [  7.32421875e-02,   7.31811523e-02],
                        [  7.18688965e-02,   7.18994141e-02],
                        [  6.27441406e-02,   6.27746582e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  2.13317871e-02,   2.12707520e-02],
                        [  1.80053711e-03,   1.77001953e-03],
                        [ -1.16577148e-02,  -1.16271973e-02],
                        [ -1.92565918e-02,  -1.91955566e-02],
                        [ -2.00500488e-02,  -2.01110840e-02],
                        [ -1.37634277e-02,  -1.38244629e-02],
                        [ -5.00488281e-03,  -4.97436523e-03],
                        [ -1.64794922e-03,  -1.55639648e-03],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -1.13830566e-02,  -1.14746094e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.50146484e-02,  -1.49536133e-02],
                        [ -1.59606934e-02,  -1.59301758e-02],
                        [ -1.33972168e-02,  -1.34582520e-02],
                        [ -5.73730469e-03,  -5.79833984e-03],
                        [  2.71606445e-03,   2.77709961e-03],
                        [  7.14111328e-03,   7.23266602e-03],
                        [  7.47680664e-03,   7.41577148e-03],
                        [  6.86645508e-03,   6.77490234e-03],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  1.06201172e-02,   1.07421875e-02],
                        [  1.48925781e-02,   1.49536133e-02],
                        [  1.69067383e-02,   1.68151855e-02],
                        [  1.19323730e-02,   1.18408203e-02],
                        [  2.44140625e-04,   3.05175781e-04],
                        [ -1.30615234e-02,  -1.29699707e-02],
                        [ -2.39257812e-02,  -2.39562988e-02],
                        [ -2.98767090e-02,  -2.99682617e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -1.96533203e-02,  -1.95922852e-02],
                        [ -8.78906250e-03,  -8.72802734e-03],
                        [ -8.85009766e-04,  -9.15527344e-04],
                        [  7.62939453e-04,   7.32421875e-04],
                        [ -4.45556641e-03,  -4.51660156e-03],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -2.03247070e-02,  -2.02636719e-02],
                        [ -2.06298828e-02,  -2.05993652e-02],
                        [ -1.31225586e-02,  -1.31835938e-02],
                        [  1.52587891e-04,   6.10351562e-05],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  3.08837891e-02,   3.10058594e-02],
                        [  3.81774902e-02,   3.82080078e-02],
                        [  2.86865234e-02,   2.85949707e-02],
                        [ -3.17382812e-03,  -3.26538086e-03],
                        [ -5.27954102e-02,  -5.27343750e-02],
                        [ -1.05346680e-01,  -1.05255127e-01],
                        [ -1.43676758e-01,  -1.43676758e-01],
                        [ -1.57012939e-01,  -1.57073975e-01],
                        [ -1.45080566e-01,  -1.45141602e-01],
                        [ -1.17858887e-01,  -1.17858887e-01],
                        [ -8.91113281e-02,  -8.90502930e-02],
                        [ -6.68640137e-02,  -6.67724609e-02],
                        [ -5.14526367e-02,  -5.14831543e-02],
                        [ -4.08020020e-02,  -4.09240723e-02],
                        [ -3.17077637e-02,  -3.17382812e-02],
                        [ -1.77917480e-02,  -1.76696777e-02],
                        [  8.45336914e-03,   8.57543945e-03],
                        [  5.15441895e-02,   5.14831543e-02],
                        [  1.09832764e-01,   1.09680176e-01],
                        [  1.73156738e-01,   1.73126221e-01],
                        [  2.22503662e-01,   2.22625732e-01],
                        [  2.36663818e-01,   2.36755371e-01],
                        [  2.04925537e-01,   2.04864502e-01],
                        [  1.32904053e-01,   1.32751465e-01],
                        [  3.28063965e-02,   3.27453613e-02],
                        [ -8.55102539e-02,  -8.53576660e-02],
                        [ -2.06878662e-01,  -2.06726074e-01],
                        [ -3.02124023e-01,  -3.02215576e-01],
                        [ -3.40393066e-01,  -3.40576172e-01],
                        [ -3.16284180e-01,  -3.16253662e-01],
                        [ -2.59460449e-01,  -2.59307861e-01],
                        [ -2.08740234e-01,  -2.08648682e-01],
                        [ -1.77185059e-01,  -1.77307129e-01],
                        [ -1.52679443e-01,  -1.52801514e-01],
                        [ -1.23260498e-01,  -1.23229980e-01],
                        [ -8.77990723e-02,  -8.76464844e-02],
                        [ -4.73327637e-02,  -4.72717285e-02],
                        [  7.32421875e-04,   6.71386719e-04],
                        [  5.90515137e-02,   5.89294434e-02],
                        [  1.20697021e-01,   1.20697021e-01],
                        [  1.67144775e-01,   1.67266846e-01],
                        [  1.84173584e-01,   1.84295654e-01],
                        [  1.77703857e-01,   1.77581787e-01],
                        [  1.65405273e-01,   1.65252686e-01],
                        [  1.56005859e-01,   1.56097412e-01],
                        [  1.43402100e-01,   1.43615723e-01],
                        [  1.20758057e-01,   1.20697021e-01],
                        [  9.21020508e-02,   9.19189453e-02],
                        [  6.70166016e-02,   6.70776367e-02],
                        [  5.04150391e-02,   5.05981445e-02],
                        [  4.18701172e-02,   4.18395996e-02],
                        [  3.74145508e-02,   3.72924805e-02],
                        [  3.13720703e-02,   3.14025879e-02],
                        [  2.38037109e-02,   2.38952637e-02],
                        [  2.19726562e-02,   2.19421387e-02],
                        [  2.94799805e-02,   2.93884277e-02],
                        [  4.11682129e-02,   4.12292480e-02],
                        [  5.17883301e-02,   5.18493652e-02],
                        [  6.06689453e-02,   6.06079102e-02],
                        [  6.68029785e-02,   6.67419434e-02],
                        [  6.67419434e-02,   6.68029785e-02],
                        [  6.07910156e-02,   6.08215332e-02],
                        [  5.45654297e-02,   5.45043945e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  4.47998047e-02,   4.48303223e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  2.70690918e-02,   2.70385742e-02],
                        [  1.95007324e-02,   1.95312500e-02],
                        [  8.97216797e-03,   8.97216797e-03],
                        [ -3.60107422e-03,  -3.66210938e-03],
                        [ -1.29699707e-02,  -1.30004883e-02],
                        [ -1.81884766e-02,  -1.81274414e-02],
                        [ -2.11486816e-02,  -2.11181641e-02],
                        [ -2.02331543e-02,  -2.03247070e-02],
                        [ -1.37939453e-02,  -1.38549805e-02],
                        [ -5.27954102e-03,  -5.21850586e-03],
                        [  1.12915039e-03,   1.19018555e-03],
                        [  4.57763672e-03,   4.51660156e-03],
                        [  4.82177734e-03,   4.76074219e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -3.50952148e-03,  -3.47900391e-03],
                        [ -6.19506836e-03,  -6.13403320e-03],
                        [ -4.76074219e-03,  -4.79125977e-03],
                        [ -6.10351562e-04,  -7.01904297e-04],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  1.19018555e-03,   1.34277344e-03],
                        [ -2.34985352e-03,  -2.28881836e-03],
                        [ -2.99072266e-03,  -3.08227539e-03],
                        [  0.00000000e+00,  -9.15527344e-05],
                        [  1.92260742e-03,   1.95312500e-03],
                        [  9.15527344e-04,   1.00708008e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  1.22070312e-03,   1.19018555e-03],
                        [ -8.54492188e-04,  -9.46044922e-04],
                        [ -8.17871094e-03,  -8.20922852e-03],
                        [ -1.79748535e-02,  -1.78833008e-02],
                        [ -2.77404785e-02,  -2.76489258e-02],
                        [ -3.76892090e-02,  -3.77502441e-02],
                        [ -4.74853516e-02,  -4.76379395e-02],
                        [ -5.44128418e-02,  -5.44433594e-02],
                        [ -5.46569824e-02,  -5.45043945e-02],
                        [ -4.60815430e-02,  -4.59899902e-02],
                        [ -3.06701660e-02,  -3.08227539e-02],
                        [ -1.29089355e-02,  -1.30615234e-02],
                        [  4.30297852e-03,   4.36401367e-03],
                        [  2.05993652e-02,   2.07214355e-02],
                        [  3.57360840e-02,   3.57666016e-02],
                        [  4.66918945e-02,   4.65698242e-02],
                        [  4.58374023e-02,   4.57763672e-02],
                        [  2.38647461e-02,   2.39257812e-02],
                        [ -2.24914551e-02,  -2.24304199e-02],
                        [ -8.34655762e-02,  -8.34350586e-02],
                        [ -1.38000488e-01,  -1.38061523e-01],
                        [ -1.66412354e-01,  -1.66442871e-01],
                        [ -1.62170410e-01,  -1.62139893e-01],
                        [ -1.32598877e-01,  -1.32537842e-01],
                        [ -9.22546387e-02,  -9.22546387e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -3.80249023e-02,  -3.79943848e-02],
                        [ -3.37219238e-02,  -3.37524414e-02],
                        [ -3.19213867e-02,  -3.19824219e-02],
                        [ -1.88903809e-02,  -1.88293457e-02],
                        [  1.24206543e-02,   1.25427246e-02],
                        [  6.21948242e-02,   6.21643066e-02],
                        [  1.25793457e-01,   1.25671387e-01],
                        [  1.90917969e-01,   1.90887451e-01],
                        [  2.35687256e-01,   2.35839844e-01],
                        [  2.39013672e-01,   2.39105225e-01],
                        [  1.94671631e-01,   1.94580078e-01],
                        [  1.10717773e-01,   1.10565186e-01],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.37908936e-01,  -1.37756348e-01],
                        [ -2.68371582e-01,  -2.68280029e-01],
                        [ -3.52966309e-01,  -3.53088379e-01],
                        [ -3.62487793e-01,  -3.62670898e-01],
                        [ -3.11126709e-01,  -3.11126709e-01],
                        [ -2.46490479e-01,  -2.46307373e-01],
                        [ -2.06298828e-01,  -2.06207275e-01],
                        [ -1.89758301e-01,  -1.89910889e-01],
                        [ -1.70959473e-01,  -1.71142578e-01],
                        [ -1.31469727e-01,  -1.31408691e-01],
                        [ -7.39135742e-02,  -7.36694336e-02],
                        [ -9.33837891e-03,  -9.27734375e-03],
                        [  5.58776855e-02,   5.56335449e-02],
                        [  1.17034912e-01,   1.16912842e-01],
                        [  1.65069580e-01,   1.65252686e-01],
                        [  1.90887451e-01,   1.91070557e-01],
                        [  1.94061279e-01,   1.93969727e-01],
                        [  1.83105469e-01,   1.82922363e-01],
                        [  1.66534424e-01,   1.66534424e-01],
                        [  1.45843506e-01,   1.45996094e-01],
                        [  1.19506836e-01,   1.19567871e-01],
                        [  9.16442871e-02,   9.15222168e-02],
                        [  7.20214844e-02,   7.18994141e-02],
                        [  6.58874512e-02,   6.59484863e-02],
                        [  6.68029785e-02,   6.68945312e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  4.65087891e-02,   4.64477539e-02],
                        [  2.67333984e-02,   2.67028809e-02],
                        [  1.32446289e-02,   1.33056641e-02],
                        [  1.14746094e-02,   1.15051270e-02],
                        [  2.12707520e-02,   2.12402344e-02],
                        [  3.93371582e-02,   3.93066406e-02],
                        [  5.99975586e-02,   6.00280762e-02],
                        [  7.65380859e-02,   7.65686035e-02],
                        [  8.46252441e-02,   8.45642090e-02],
                        [  8.39538574e-02,   8.39233398e-02],
                        [  7.60498047e-02,   7.61413574e-02],
                        [  6.20117188e-02,   6.20422363e-02],
                        [  4.48608398e-02,   4.47692871e-02],
                        [  2.96936035e-02,   2.96630859e-02],
                        [  1.80969238e-02,   1.82189941e-02],
                        [  9.12475586e-03,   9.18579102e-03],
                        [  4.97436523e-03,   4.85229492e-03],
                        [  7.17163086e-03,   7.04956055e-03],
                        [  9.30786133e-03,   9.42993164e-03],
                        [  3.23486328e-03,   3.35693359e-03],
                        [ -1.01013184e-02,  -1.02233887e-02],
                        [ -2.25219727e-02,  -2.26745605e-02],
                        [ -2.88391113e-02,  -2.86865234e-02],
                        [ -2.86560059e-02,  -2.85339355e-02],
                        [ -2.11791992e-02,  -2.13012695e-02],
                        [ -6.53076172e-03,  -6.65283203e-03],
                        [  7.04956055e-03,   7.20214844e-03],
                        [  1.02233887e-02,   1.03149414e-02],
                        [  6.59179688e-03,   6.43920898e-03],
                        [  7.53784180e-03,   7.38525391e-03],
                        [  1.35498047e-02,   1.37329102e-02],
                        [  1.48315430e-02,   1.49841309e-02],
                        [  9.21630859e-03,   9.03320312e-03],
                        [  6.16455078e-03,   5.95092773e-03],
                        [  1.03454590e-02,   1.04980469e-02],
                        [  1.38549805e-02,   1.40686035e-02],
                        [  9.09423828e-03,   9.03320312e-03],
                        [ -7.93457031e-04,  -1.03759766e-03],
                        [ -9.55200195e-03,  -9.58251953e-03],
                        [ -1.56250000e-02,  -1.54113770e-02],
                        [ -1.98059082e-02,  -1.97143555e-02],
                        [ -2.16979980e-02,  -2.18811035e-02],
                        [ -2.02331543e-02,  -2.04162598e-02],
                        [ -1.67846680e-02,  -1.67236328e-02],
                        [ -1.55639648e-02,  -1.53808594e-02],
                        [ -1.80969238e-02,  -1.80664062e-02],
                        [ -2.13623047e-02,  -2.14843750e-02],
                        [ -2.42614746e-02,  -2.43225098e-02],
                        [ -2.88696289e-02,  -2.88085938e-02],
                        [ -3.30505371e-02,  -3.29895020e-02],
                        [ -3.12194824e-02,  -3.11889648e-02],
                        [ -2.26135254e-02,  -2.26440430e-02],
                        [ -1.12915039e-02,  -1.13525391e-02],
                        [  3.35693359e-04,   3.05175781e-04],
                        [  1.15356445e-02,   1.15966797e-02],
                        [  1.95922852e-02,   1.96838379e-02],
                        [  2.18505859e-02,   2.17895508e-02],
                        [  1.75781250e-02,   1.74560547e-02],
                        [  3.38745117e-03,   3.41796875e-03],
                        [ -2.64892578e-02,  -2.63671875e-02],
                        [ -6.97631836e-02,  -6.97326660e-02],
                        [ -1.11938477e-01,  -1.12030029e-01],
                        [ -1.37573242e-01,  -1.37603760e-01],
                        [ -1.40197754e-01,  -1.40136719e-01],
                        [ -1.22802734e-01,  -1.22802734e-01],
                        [ -9.60388184e-02,  -9.60693359e-02],
                        [ -7.43713379e-02,  -7.42492676e-02],
                        [ -6.54296875e-02,  -6.53991699e-02],
                        [ -6.03332520e-02,  -6.04858398e-02],
                        [ -3.90930176e-02,  -3.92150879e-02],
                        [  7.81250000e-03,   8.05664062e-03],
                        [  6.99462891e-02,   7.01599121e-02],
                        [  1.32843018e-01,   1.32629395e-01],
                        [  1.90673828e-01,   1.90338135e-01],
                        [  2.34313965e-01,   2.34436035e-01],
                        [  2.44598389e-01,   2.45025635e-01],
                        [  2.08618164e-01,   2.08618164e-01],
                        [  1.30645752e-01,   1.30187988e-01],
                        [  2.15454102e-02,   2.13928223e-02],
                        [ -1.09161377e-01,  -1.08764648e-01],
                        [ -2.41760254e-01,  -2.41516113e-01],
                        [ -3.38653564e-01,  -3.38958740e-01],
                        [ -3.66607666e-01,  -3.66943359e-01],
                        [ -3.29833984e-01,  -3.29650879e-01],
                        [ -2.68157959e-01,  -2.67761230e-01],
                        [ -2.18719482e-01,  -2.18780518e-01],
                        [ -1.88110352e-01,  -1.88476562e-01],
                        [ -1.62414551e-01,  -1.62475586e-01],
                        [ -1.30004883e-01,  -1.29699707e-01],
                        [ -8.59069824e-02,  -8.57849121e-02],
                        [ -2.70690918e-02,  -2.73132324e-02],
                        [  4.27246094e-02,   4.25720215e-02],
                        [  1.08123779e-01,   1.08245850e-01],
                        [  1.52740479e-01,   1.52862549e-01],
                        [  1.71844482e-01,   1.71783447e-01],
                        [  1.71875000e-01,   1.71813965e-01],
                        [  1.63085938e-01,   1.63116455e-01],
                        [  1.53625488e-01,   1.53594971e-01],
                        [  1.45111084e-01,   1.45080566e-01],
                        [  1.32843018e-01,   1.32904053e-01],
                        [  1.14257812e-01,   1.14318848e-01],
                        [  9.52758789e-02,   9.51538086e-02],
                        [  8.30078125e-02,   8.29467773e-02],
                        [  7.48291016e-02,   7.49511719e-02],
                        [  6.20422363e-02,   6.21337891e-02],
                        [  4.31823730e-02,   4.30603027e-02],
                        [  2.48718262e-02,   2.47497559e-02],
                        [  1.19323730e-02,   1.20239258e-02],
                        [  6.46972656e-03,   6.53076172e-03],
                        [  1.28173828e-02,   1.27258301e-02],
                        [  3.23181152e-02,   3.22875977e-02],
                        [  5.66711426e-02,   5.67321777e-02],
                        [  7.58666992e-02,   7.58361816e-02],
                        [  8.84094238e-02,   8.82873535e-02],
                        [  9.45739746e-02,   9.46350098e-02],
                        [  8.96606445e-02,   8.98437500e-02],
                        [  7.40966797e-02,   7.40356445e-02],
                        [  5.86547852e-02,   5.84411621e-02],
                        [  4.96215820e-02,   4.96826172e-02],
                        [  3.99780273e-02,   4.01916504e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  6.04248047e-03,   5.85937500e-03],
                        [ -3.72314453e-03,  -3.75366211e-03],
                        [ -8.20922852e-03,  -8.08715820e-03],
                        [ -1.41296387e-02,  -1.40686035e-02],
                        [ -2.12402344e-02,  -2.12707520e-02],
                        [ -2.44445801e-02,  -2.44750977e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -9.30786133e-03,  -9.24682617e-03],
                        [ -5.09643555e-03,  -5.03540039e-03],
                        [ -3.66210938e-04,  -4.27246094e-04],
                        [  7.38525391e-03,   7.32421875e-03],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.56250000e-02,   1.56555176e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  1.25122070e-03,   1.28173828e-03],
                        [ -1.86157227e-03,  -1.95312500e-03],
                        [ -3.63159180e-03,  -3.69262695e-03],
                        [ -4.73022461e-03,  -4.60815430e-03],
                        [ -7.29370117e-03,  -7.14111328e-03],
                        [ -1.03454590e-02,  -1.04980469e-02],
                        [ -1.02539062e-02,  -1.04675293e-02],
                        [ -7.78198242e-03,  -7.65991211e-03],
                        [ -7.99560547e-03,  -7.75146484e-03],
                        [ -1.12609863e-02,  -1.12915039e-02],
                        [ -1.31530762e-02,  -1.34277344e-02],
                        [ -1.41601562e-02,  -1.41906738e-02],
                        [ -1.94702148e-02,  -1.92871094e-02],
                        [ -2.93579102e-02,  -2.92968750e-02],
                        [ -3.67431641e-02,  -3.68347168e-02],
                        [ -3.58581543e-02,  -3.59191895e-02],
                        [ -2.86254883e-02,  -2.85949707e-02],
                        [ -2.11791992e-02,  -2.11486816e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.70288086e-02,  -1.69982910e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.73950195e-02,  -1.74255371e-02],
                        [ -1.29089355e-02,  -1.29699707e-02],
                        [ -3.14331055e-03,  -3.11279297e-03],
                        [  1.15661621e-02,   1.16271973e-02],
                        [  2.56347656e-02,   2.56652832e-02],
                        [  2.85949707e-02,   2.85339355e-02],
                        [  1.10778809e-02,   1.09558105e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -8.03527832e-02,  -8.02001953e-02],
                        [ -1.27502441e-01,  -1.27410889e-01],
                        [ -1.51519775e-01,  -1.51702881e-01],
                        [ -1.43585205e-01,  -1.43798828e-01],
                        [ -1.13525391e-01,  -1.13403320e-01],
                        [ -8.47473145e-02,  -8.44726562e-02],
                        [ -7.08618164e-02,  -7.08923340e-02],
                        [ -6.11267090e-02,  -6.14624023e-02],
                        [ -3.75671387e-02,  -3.76586914e-02],
                        [  1.89208984e-03,   2.16674805e-03],
                        [  4.73327637e-02,   4.75158691e-02],
                        [  9.50012207e-02,   9.48181152e-02],
                        [  1.46881104e-01,   1.46667480e-01],
                        [  1.95404053e-01,   1.95465088e-01],
                        [  2.22259521e-01,   2.22442627e-01],
                        [  2.12127686e-01,   2.12188721e-01],
                        [  1.58355713e-01,   1.58264160e-01],
                        [  6.09741211e-02,   6.08825684e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -2.07977295e-01,  -2.07885742e-01],
                        [ -3.19000244e-01,  -3.18908691e-01],
                        [ -3.69506836e-01,  -3.69537354e-01],
                        [ -3.50097656e-01,  -3.50219727e-01],
                        [ -2.86651611e-01,  -2.86682129e-01],
                        [ -2.21771240e-01,  -2.21618652e-01],
                        [ -1.81091309e-01,  -1.81030273e-01],
                        [ -1.60003662e-01,  -1.60125732e-01],
                        [ -1.36718750e-01,  -1.36840820e-01],
                        [ -9.48486328e-02,  -9.47570801e-02],
                        [ -3.48205566e-02,  -3.46984863e-02],
                        [  3.23181152e-02,   3.22875977e-02],
                        [  9.54589844e-02,   9.53063965e-02],
                        [  1.44714355e-01,   1.44683838e-01],
                        [  1.72668457e-01,   1.72790527e-01],
                        [  1.80419922e-01,   1.80480957e-01],
                        [  1.78009033e-01,   1.77886963e-01],
                        [  1.72454834e-01,   1.72363281e-01],
                        [  1.59851074e-01,   1.59912109e-01],
                        [  1.34887695e-01,   1.35009766e-01],
                        [  1.04431152e-01,   1.04400635e-01],
                        [  8.18786621e-02,   8.17565918e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  6.40563965e-02,   6.41479492e-02],
                        [  5.30700684e-02,   5.31005859e-02],
                        [  3.90930176e-02,   3.90014648e-02],
                        [  2.80456543e-02,   2.80151367e-02],
                        [  2.32849121e-02,   2.33154297e-02],
                        [  2.45361328e-02,   2.45666504e-02],
                        [  3.15856934e-02,   3.15551758e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  5.68542480e-02,   5.68847656e-02],
                        [  6.81152344e-02,   6.81152344e-02],
                        [  7.58056641e-02,   7.57751465e-02],
                        [  7.77893066e-02,   7.78198242e-02],
                        [  7.16552734e-02,   7.17163086e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  4.64782715e-02,   4.64172363e-02],
                        [  3.95507812e-02,   3.95202637e-02],
                        [  3.75366211e-02,   3.75976562e-02],
                        [  3.47290039e-02,   3.48205566e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  1.15356445e-02,   1.14440918e-02],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [ -1.21765137e-02,  -1.20849609e-02],
                        [ -1.49841309e-02,  -1.49230957e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -1.66320801e-02,  -1.66931152e-02],
                        [ -1.73950195e-02,  -1.74560547e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -1.46179199e-02,  -1.45263672e-02],
                        [ -1.06506348e-02,  -1.05895996e-02],
                        [ -6.56127930e-03,  -6.62231445e-03],
                        [ -5.49316406e-04,  -7.01904297e-04],
                        [  8.81958008e-03,   8.85009766e-03],
                        [  1.73645020e-02,   1.75781250e-02],
                        [  1.99584961e-02,   2.00500488e-02],
                        [  1.85852051e-02,   1.83715820e-02],
                        [  1.86157227e-02,   1.84326172e-02],
                        [  1.97448730e-02,   1.98974609e-02],
                        [  1.71508789e-02,   1.73950195e-02],
                        [  1.09252930e-02,   1.08642578e-02],
                        [  6.34765625e-03,   6.13403320e-03],
                        [  4.66918945e-03,   4.60815430e-03],
                        [  1.25122070e-03,   1.40380859e-03],
                        [ -6.80541992e-03,  -6.71386719e-03],
                        [ -1.65710449e-02,  -1.66320801e-02],
                        [ -2.31323242e-02,  -2.32238770e-02],
                        [ -2.52685547e-02,  -2.53295898e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -3.21350098e-02,  -3.20434570e-02],
                        [ -3.68347168e-02,  -3.67736816e-02],
                        [ -3.60412598e-02,  -3.61328125e-02],
                        [ -2.95410156e-02,  -2.96936035e-02],
                        [ -2.25219727e-02,  -2.24609375e-02],
                        [ -2.10266113e-02,  -2.08740234e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.85949707e-02,  -2.87475586e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -1.58691406e-02,  -1.57470703e-02],
                        [ -5.76782227e-03,  -5.79833984e-03],
                        [  8.85009766e-03,   8.75854492e-03],
                        [  2.59094238e-02,   2.60009766e-02],
                        [  3.21960449e-02,   3.23181152e-02],
                        [  1.71508789e-02,   1.70288086e-02],
                        [ -1.65100098e-02,  -1.67236328e-02],
                        [ -5.98754883e-02,  -5.97229004e-02],
                        [ -1.02416992e-01,  -1.02142334e-01],
                        [ -1.28631592e-01,  -1.28753662e-01],
                        [ -1.24755859e-01,  -1.25091553e-01],
                        [ -9.65576172e-02,  -9.65270996e-02],
                        [ -6.83898926e-02,  -6.80541992e-02],
                        [ -5.79223633e-02,  -5.78308105e-02],
                        [ -5.83190918e-02,  -5.85937500e-02],
                        [ -4.95605469e-02,  -4.97741699e-02],
                        [ -2.03552246e-02,  -2.02026367e-02],
                        [  2.61535645e-02,   2.64282227e-02],
                        [  8.19396973e-02,   8.19091797e-02],
                        [  1.40716553e-01,   1.40472412e-01],
                        [  1.94549561e-01,   1.94458008e-01],
                        [  2.28393555e-01,   2.28576660e-01],
                        [  2.24945068e-01,   2.25128174e-01],
                        [  1.75018311e-01,   1.74987793e-01],
                        [  8.08105469e-02,   8.05969238e-02],
                        [ -4.68444824e-02,  -4.69055176e-02],
                        [ -1.86065674e-01,  -1.85913086e-01],
                        [ -3.02856445e-01,  -3.02703857e-01],
                        [ -3.63494873e-01,  -3.63555908e-01],
                        [ -3.55895996e-01,  -3.56048584e-01],
                        [ -3.00811768e-01,  -3.00842285e-01],
                        [ -2.37823486e-01,  -2.37701416e-01],
                        [ -1.94641113e-01,  -1.94519043e-01],
                        [ -1.69342041e-01,  -1.69403076e-01],
                        [ -1.41693115e-01,  -1.41876221e-01],
                        [ -9.64050293e-02,  -9.64660645e-02],
                        [ -3.40270996e-02,  -3.38439941e-02],
                        [  3.36608887e-02,   3.37829590e-02],
                        [  9.35058594e-02,   9.33532715e-02],
                        [  1.36474609e-01,   1.36260986e-01],
                        [  1.57714844e-01,   1.57836914e-01],
                        [  1.58813477e-01,   1.59057617e-01],
                        [  1.51336670e-01,   1.51275635e-01],
                        [  1.49169922e-01,   1.48864746e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.43066406e-01,   1.43402100e-01],
                        [  1.17767334e-01,   1.17828369e-01],
                        [  9.01794434e-02,   8.98437500e-02],
                        [  7.32727051e-02,   7.31811523e-02],
                        [  5.99060059e-02,   6.02111816e-02],
                        [  3.97949219e-02,   3.99169922e-02],
                        [  2.02636719e-02,   1.99890137e-02],
                        [  1.54113770e-02,   1.52282715e-02],
                        [  2.45666504e-02,   2.47802734e-02],
                        [  3.54003906e-02,   3.55834961e-02],
                        [  4.13513184e-02,   4.11682129e-02],
                        [  4.56237793e-02,   4.54101562e-02],
                        [  5.14221191e-02,   5.15441895e-02],
                        [  5.71899414e-02,   5.74035645e-02],
                        [  6.16149902e-02,   6.15539551e-02],
                        [  6.64062500e-02,   6.62231445e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  7.45239258e-02,   7.46765137e-02],
                        [  7.16552734e-02,   7.17163086e-02],
                        [  6.31713867e-02,   6.30798340e-02],
                        [  5.02014160e-02,   5.01098633e-02],
                        [  3.40270996e-02,   3.40881348e-02],
                        [  1.78527832e-02,   1.79748535e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [ -3.66210938e-04,  -5.18798828e-04],
                        [ -3.81469727e-03,  -3.87573242e-03],
                        [ -9.24682617e-03,  -9.12475586e-03],
                        [ -1.86462402e-02,  -1.85241699e-02],
                        [ -2.76489258e-02,  -2.77404785e-02],
                        [ -2.91137695e-02,  -2.92663574e-02],
                        [ -2.23693848e-02,  -2.23388672e-02],
                        [ -1.49536133e-02,  -1.47705078e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -9.27734375e-03,  -9.42993164e-03],
                        [ -1.22070312e-03,  -1.25122070e-03],
                        [  9.91821289e-03,   1.00402832e-02],
                        [  1.79443359e-02,   1.79748535e-02],
                        [  2.19421387e-02,   2.18200684e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.45056152e-02,   2.45666504e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  9.30786133e-03,   9.24682617e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  9.15527344e-05,   1.52587891e-04],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -1.25122070e-03,  -1.31225586e-03],
                        [ -2.99072266e-03,  -3.02124023e-03],
                        [ -7.59887695e-03,  -7.56835938e-03],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -2.19726562e-02,  -2.19421387e-02],
                        [ -2.78015137e-02,  -2.78320312e-02],
                        [ -3.08532715e-02,  -3.09143066e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.16467285e-02,  -3.15246582e-02],
                        [ -3.30810547e-02,  -3.30505371e-02],
                        [ -3.45153809e-02,  -3.46679688e-02],
                        [ -3.52783203e-02,  -3.53393555e-02],
                        [ -3.61633301e-02,  -3.60107422e-02],
                        [ -3.57055664e-02,  -3.55834961e-02],
                        [ -2.82287598e-02,  -2.83508301e-02],
                        [ -9.70458984e-03,  -9.82666016e-03],
                        [  1.48620605e-02,   1.49230957e-02],
                        [  3.48815918e-02,   3.50036621e-02],
                        [  4.42504883e-02,   4.42199707e-02],
                        [  4.22363281e-02,   4.21447754e-02],
                        [  2.66418457e-02,   2.66113281e-02],
                        [ -6.34765625e-03,  -6.31713867e-03],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -1.06384277e-01,  -1.06323242e-01],
                        [ -1.42150879e-01,  -1.42150879e-01],
                        [ -1.46881104e-01,  -1.46972656e-01],
                        [ -1.21246338e-01,  -1.21307373e-01],
                        [ -8.36181641e-02,  -8.35266113e-02],
                        [ -5.45654297e-02,  -5.44433594e-02],
                        [ -3.78112793e-02,  -3.78723145e-02],
                        [ -2.10266113e-02,  -2.11791992e-02],
                        [  6.50024414e-03,   6.46972656e-03],
                        [  4.48608398e-02,   4.50134277e-02],
                        [  8.97216797e-02,   8.98437500e-02],
                        [  1.36962891e-01,   1.36871338e-01],
                        [  1.81030273e-01,   1.80816650e-01],
                        [  2.10754395e-01,   2.10784912e-01],
                        [  2.08312988e-01,   2.08557129e-01],
                        [  1.58508301e-01,   1.58630371e-01],
                        [  6.24084473e-02,   6.21643066e-02],
                        [ -6.35375977e-02,  -6.37817383e-02],
                        [ -1.96197510e-01,  -1.96014404e-01],
                        [ -3.06701660e-01,  -3.06365967e-01],
                        [ -3.62976074e-01,  -3.63067627e-01],
                        [ -3.48724365e-01,  -3.49090576e-01],
                        [ -2.83996582e-01,  -2.84027100e-01],
                        [ -2.16430664e-01,  -2.16064453e-01],
                        [ -1.80938721e-01,  -1.80786133e-01],
                        [ -1.70227051e-01,  -1.70501709e-01],
                        [ -1.51153564e-01,  -1.51397705e-01],
                        [ -1.02996826e-01,  -1.02813721e-01],
                        [ -3.09448242e-02,  -3.07006836e-02],
                        [  4.65087891e-02,   4.64172363e-02],
                        [  1.11114502e-01,   1.10900879e-01],
                        [  1.50238037e-01,   1.50268555e-01],
                        [  1.62139893e-01,   1.62261963e-01],
                        [  1.59576416e-01,   1.59576416e-01],
                        [  1.60339355e-01,   1.60247803e-01],
                        [  1.67602539e-01,   1.67633057e-01],
                        [  1.67144775e-01,   1.67236328e-01],
                        [  1.47247314e-01,   1.47186279e-01],
                        [  1.12762451e-01,   1.12640381e-01],
                        [  7.71179199e-02,   7.71789551e-02],
                        [  4.89501953e-02,   4.91027832e-02],
                        [  2.99377441e-02,   2.98767090e-02],
                        [  1.98669434e-02,   1.96838379e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.95922852e-02,   1.97448730e-02],
                        [  2.33459473e-02,   2.34680176e-02],
                        [  3.01513672e-02,   3.00292969e-02],
                        [  4.01916504e-02,   4.00390625e-02],
                        [  5.13305664e-02,   5.13916016e-02],
                        [  6.25610352e-02,   6.27441406e-02],
                        [  7.31811523e-02,   7.32116699e-02],
                        [  8.00781250e-02,   7.99255371e-02],
                        [  8.04748535e-02,   8.04138184e-02],
                        [  7.37609863e-02,   7.38220215e-02],
                        [  6.09130859e-02,   6.09741211e-02],
                        [  4.55017090e-02,   4.55322266e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.15148926e-02,   2.14538574e-02],
                        [  1.65100098e-02,   1.64489746e-02],
                        [  1.71813965e-02,   1.72424316e-02],
                        [  1.75476074e-02,   1.77001953e-02],
                        [  9.42993164e-03,   9.39941406e-03],
                        [ -5.27954102e-03,  -5.49316406e-03],
                        [ -1.60217285e-02,  -1.60827637e-02],
                        [ -1.77612305e-02,  -1.75170898e-02],
                        [ -1.35192871e-02,  -1.33972168e-02],
                        [ -5.64575195e-03,  -5.85937500e-03],
                        [  3.93676758e-03,   3.81469727e-03],
                        [  9.67407227e-03,   9.82666016e-03],
                        [  8.23974609e-03,   8.30078125e-03],
                        [  3.44848633e-03,   3.35693359e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -4.85229492e-03,  -4.73022461e-03],
                        [ -7.96508789e-03,  -8.02612305e-03],
                        [ -4.57763672e-03,  -4.73022461e-03],
                        [  6.92749023e-03,   7.04956055e-03],
                        [  1.95312500e-02,   1.97448730e-02],
                        [  2.54516602e-02,   2.53601074e-02],
                        [  2.45056152e-02,   2.42309570e-02],
                        [  1.92260742e-02,   1.92565918e-02],
                        [  9.18579102e-03,   9.49096680e-03],
                        [ -4.15039062e-03,  -4.11987305e-03],
                        [ -1.37023926e-02,  -1.39770508e-02],
                        [ -1.55639648e-02,  -1.56555176e-02],
                        [ -1.61437988e-02,  -1.58996582e-02],
                        [ -2.32238770e-02,  -2.31018066e-02],
                        [ -3.35083008e-02,  -3.36914062e-02],
                        [ -3.79333496e-02,  -3.80859375e-02],
                        [ -3.61633301e-02,  -3.60412598e-02],
                        [ -3.46984863e-02,  -3.45764160e-02],
                        [ -3.38439941e-02,  -3.39355469e-02],
                        [ -2.89611816e-02,  -2.90832520e-02],
                        [ -2.15454102e-02,  -2.14538574e-02],
                        [ -1.80358887e-02,  -1.79138184e-02],
                        [ -1.96228027e-02,  -1.97143555e-02],
                        [ -2.02941895e-02,  -2.04772949e-02],
                        [ -1.52282715e-02,  -1.51672363e-02],
                        [ -6.28662109e-03,  -6.04248047e-03],
                        [  3.54003906e-03,   3.50952148e-03],
                        [  1.65405273e-02,   1.62963867e-02],
                        [  3.39965820e-02,   3.39660645e-02],
                        [  4.64172363e-02,   4.66613770e-02],
                        [  3.92150879e-02,   3.92761230e-02],
                        [  6.80541992e-03,   6.59179688e-03],
                        [ -4.35485840e-02,  -4.36401367e-02],
                        [ -9.75341797e-02,  -9.73815918e-02],
                        [ -1.37878418e-01,  -1.37756348e-01],
                        [ -1.49658203e-01,  -1.49749756e-01],
                        [ -1.31256104e-01,  -1.31347656e-01],
                        [ -9.59167480e-02,  -9.58557129e-02],
                        [ -5.87158203e-02,  -5.86853027e-02],
                        [ -2.77404785e-02,  -2.77709961e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  1.45568848e-02,   1.45874023e-02],
                        [  4.45251465e-02,   4.44946289e-02],
                        [  9.19494629e-02,   9.19189453e-02],
                        [  1.47857666e-01,   1.47918701e-01],
                        [  1.94580078e-01,   1.94580078e-01],
                        [  2.16156006e-01,   2.16094971e-01],
                        [  1.98669434e-01,   1.98699951e-01],
                        [  1.30767822e-01,   1.30859375e-01],
                        [  1.33972168e-02,   1.33361816e-02],
                        [ -1.31774902e-01,  -1.31896973e-01],
                        [ -2.68402100e-01,  -2.68310547e-01],
                        [ -3.59405518e-01,  -3.59252930e-01],
                        [ -3.81134033e-01,  -3.81195068e-01],
                        [ -3.37860107e-01,  -3.38043213e-01],
                        [ -2.65411377e-01,  -2.65350342e-01],
                        [ -2.06481934e-01,  -2.06298828e-01],
                        [ -1.76116943e-01,  -1.76177979e-01],
                        [ -1.54998779e-01,  -1.55181885e-01],
                        [ -1.15936279e-01,  -1.15905762e-01],
                        [ -5.17883301e-02,  -5.16662598e-02],
                        [  2.34375000e-02,   2.34069824e-02],
                        [  9.08203125e-02,   9.07287598e-02],
                        [  1.35711670e-01,   1.35742188e-01],
                        [  1.52587891e-01,   1.52648926e-01],
                        [  1.51702881e-01,   1.51641846e-01],
                        [  1.51275635e-01,   1.51184082e-01],
                        [  1.56677246e-01,   1.56768799e-01],
                        [  1.57226562e-01,   1.57348633e-01],
                        [  1.43585205e-01,   1.43493652e-01],
                        [  1.19110107e-01,   1.18927002e-01],
                        [  9.35363770e-02,   9.35668945e-02],
                        [  7.25708008e-02,   7.27233887e-02],
                        [  5.60607910e-02,   5.61218262e-02],
                        [  4.32739258e-02,   4.31213379e-02],
                        [  3.36608887e-02,   3.35693359e-02],
                        [  2.53601074e-02,   2.54211426e-02],
                        [  1.87988281e-02,   1.89514160e-02],
                        [  1.94091797e-02,   1.94396973e-02],
                        [  3.05175781e-02,   3.03955078e-02],
                        [  4.71801758e-02,   4.71191406e-02],
                        [  6.07299805e-02,   6.07910156e-02],
                        [  6.78100586e-02,   6.78405762e-02],
                        [  7.15637207e-02,   7.15637207e-02],
                        [  7.42797852e-02,   7.43103027e-02],
                        [  7.35778809e-02,   7.35168457e-02],
                        [  6.68945312e-02,   6.68029785e-02],
                        [  5.42602539e-02,   5.43212891e-02],
                        [  3.66821289e-02,   3.68347168e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  6.10351562e-03,   5.92041016e-03],
                        [  2.96020508e-03,   2.86865234e-03],
                        [  3.17382812e-03,   3.29589844e-03],
                        [  6.10351562e-04,   7.62939453e-04],
                        [ -4.73022461e-03,  -4.76074219e-03],
                        [ -9.88769531e-03,  -1.00402832e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.36718750e-02,  -1.36108398e-02],
                        [ -1.09558105e-02,  -1.08947754e-02],
                        [ -5.34057617e-03,  -5.31005859e-03],
                        [  1.52587891e-03,   1.49536133e-03],
                        [  7.75146484e-03,   7.62939453e-03],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.61132812e-02,   1.62658691e-02],
                        [  1.79443359e-02,   1.80358887e-02],
                        [  1.70898438e-02,   1.69067383e-02],
                        [  1.48620605e-02,   1.46789551e-02],
                        [  1.32141113e-02,   1.33056641e-02],
                        [  1.13220215e-02,   1.15051270e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  7.44628906e-03,   7.29370117e-03],
                        [  7.96508789e-03,   7.90405273e-03],
                        [  5.58471680e-03,   5.67626953e-03],
                        [ -1.34277344e-03,  -1.31225586e-03],
                        [ -8.81958008e-03,  -8.78906250e-03],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -1.66931152e-02,  -1.68151855e-02],
                        [ -1.90429688e-02,  -1.91345215e-02],
                        [ -2.12097168e-02,  -2.10876465e-02],
                        [ -2.41699219e-02,  -2.39868164e-02],
                        [ -2.57568359e-02,  -2.58483887e-02],
                        [ -2.20642090e-02,  -2.22778320e-02],
                        [ -1.59301758e-02,  -1.58996582e-02],
                        [ -1.56250000e-02,  -1.54113770e-02],
                        [ -2.26135254e-02,  -2.25830078e-02],
                        [ -2.99987793e-02,  -3.01513672e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.51867676e-02,  -3.51257324e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -2.08740234e-02,  -2.07824707e-02],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [  1.67541504e-02,   1.66015625e-02],
                        [  3.85131836e-02,   3.84521484e-02],
                        [  4.95300293e-02,   4.97436523e-02],
                        [  3.54919434e-02,   3.56140137e-02],
                        [ -4.33349609e-03,  -4.54711914e-03],
                        [ -5.55114746e-02,  -5.56945801e-02],
                        [ -1.02050781e-01,  -1.01898193e-01],
                        [ -1.33361816e-01,  -1.33148193e-01],
                        [ -1.41601562e-01,  -1.41662598e-01],
                        [ -1.23535156e-01,  -1.23779297e-01],
                        [ -8.68225098e-02,  -8.68530273e-02],
                        [ -4.75769043e-02,  -4.73327637e-02],
                        [ -1.66625977e-02,  -1.65710449e-02],
                        [  9.39941406e-03,   9.15527344e-03],
                        [  4.09240723e-02,   4.07714844e-02],
                        [  8.18176270e-02,   8.20007324e-02],
                        [  1.26800537e-01,   1.26953125e-01],
                        [  1.68029785e-01,   1.67877197e-01],
                        [  1.96868896e-01,   1.96685791e-01],
                        [  1.98455811e-01,   1.98547363e-01],
                        [  1.55151367e-01,   1.55364990e-01],
                        [  6.26220703e-02,   6.26220703e-02],
                        [ -6.34765625e-02,  -6.36901855e-02],
                        [ -1.96716309e-01,  -1.96746826e-01],
                        [ -3.06915283e-01,  -3.06732178e-01],
                        [ -3.65539551e-01,  -3.65478516e-01],
                        [ -3.59924316e-01,  -3.60076904e-01],
                        [ -3.04595947e-01,  -3.04718018e-01],
                        [ -2.33978271e-01,  -2.33886719e-01],
                        [ -1.79412842e-01,  -1.79290771e-01],
                        [ -1.46972656e-01,  -1.47033691e-01],
                        [ -1.17248535e-01,  -1.17370605e-01],
                        [ -7.09228516e-02,  -7.09228516e-02],
                        [ -9.91821289e-03,  -9.82666016e-03],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  9.34448242e-02,   9.33532715e-02],
                        [  1.20361328e-01,   1.20361328e-01],
                        [  1.33789062e-01,   1.33850098e-01],
                        [  1.39892578e-01,   1.39862061e-01],
                        [  1.44409180e-01,   1.44348145e-01],
                        [  1.47979736e-01,   1.48040771e-01],
                        [  1.45080566e-01,   1.45141602e-01],
                        [  1.33422852e-01,   1.33361816e-01],
                        [  1.18530273e-01,   1.18469238e-01],
                        [  1.04949951e-01,   1.04980469e-01],
                        [  8.93859863e-02,   8.94470215e-02],
                        [  6.70776367e-02,   6.70471191e-02],
                        [  3.82080078e-02,   3.81469727e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [ -1.44653320e-02,  -1.44042969e-02],
                        [ -2.10266113e-02,  -2.09960938e-02],
                        [ -8.60595703e-03,  -8.63647461e-03],
                        [  1.73034668e-02,   1.72424316e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  6.94274902e-02,   6.94580078e-02],
                        [  8.57849121e-02,   8.58154297e-02],
                        [  9.63745117e-02,   9.63439941e-02],
                        [  1.00860596e-01,   1.00830078e-01],
                        [  9.71984863e-02,   9.72595215e-02],
                        [  8.49914551e-02,   8.50219727e-02],
                        [  6.78100586e-02,   6.77490234e-02],
                        [  4.96826172e-02,   4.96520996e-02],
                        [  3.01818848e-02,   3.02429199e-02],
                        [  8.97216797e-03,   9.03320312e-03],
                        [ -8.08715820e-03,  -8.20922852e-03],
                        [ -1.62353516e-02,  -1.62963867e-02],
                        [ -1.89208984e-02,  -1.87988281e-02],
                        [ -2.10266113e-02,  -2.09655762e-02],
                        [ -2.14233398e-02,  -2.15148926e-02],
                        [ -1.76391602e-02,  -1.77307129e-02],
                        [ -1.16271973e-02,  -1.15661621e-02],
                        [ -6.04248047e-03,  -5.95092773e-03],
                        [  3.05175781e-04,   2.74658203e-04],
                        [  9.64355469e-03,   9.58251953e-03],
                        [  2.04772949e-02,   2.04467773e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  3.02734375e-02,   3.03039551e-02],
                        [  2.57568359e-02,   2.57873535e-02],
                        [  1.85546875e-02,   1.85241699e-02],
                        [  1.51062012e-02,   1.50146484e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.31628418e-02,   2.32849121e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  1.80969238e-02,   1.79443359e-02],
                        [  9.24682617e-03,   9.21630859e-03],
                        [ -1.37329102e-03,  -1.28173828e-03],
                        [ -1.25122070e-02,  -1.24816895e-02],
                        [ -2.05688477e-02,  -2.06604004e-02],
                        [ -2.33459473e-02,  -2.33764648e-02],
                        [ -2.49023438e-02,  -2.48413086e-02],
                        [ -3.01208496e-02,  -3.00903320e-02],
                        [ -3.65905762e-02,  -3.66516113e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.50646973e-02,  -3.50036621e-02],
                        [ -2.72827148e-02,  -2.72521973e-02],
                        [ -1.79443359e-02,  -1.80358887e-02],
                        [ -1.08337402e-02,  -1.08642578e-02],
                        [ -9.30786133e-03,  -9.18579102e-03],
                        [ -1.43127441e-02,  -1.42517090e-02],
                        [ -2.34680176e-02,  -2.35900879e-02],
                        [ -3.10363770e-02,  -3.11279297e-02],
                        [ -3.13110352e-02,  -3.12500000e-02],
                        [ -2.28881836e-02,  -2.27355957e-02],
                        [ -8.02612305e-03,  -8.05664062e-03],
                        [  8.78906250e-03,   8.63647461e-03],
                        [  2.28576660e-02,   2.27966309e-02],
                        [  3.17077637e-02,   3.18603516e-02],
                        [  3.38745117e-02,   3.39660645e-02],
                        [  2.41394043e-02,   2.40478516e-02],
                        [ -3.99780273e-03,  -4.11987305e-03],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -9.52148438e-02,  -9.51232910e-02],
                        [ -1.24938965e-01,  -1.24847412e-01],
                        [ -1.27380371e-01,  -1.27471924e-01],
                        [ -1.04461670e-01,  -1.04614258e-01],
                        [ -6.75048828e-02,  -6.74743652e-02],
                        [ -3.31420898e-02,  -3.29895020e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  2.22778320e-03,   2.10571289e-03],
                        [  2.42919922e-02,   2.42309570e-02],
                        [  6.19812012e-02,   6.20422363e-02],
                        [  1.12091064e-01,   1.12182617e-01],
                        [  1.62200928e-01,   1.62200928e-01],
                        [  1.93389893e-01,   1.93328857e-01],
                        [  1.89178467e-01,   1.89178467e-01],
                        [  1.41632080e-01,   1.41662598e-01],
                        [  5.01098633e-02,   5.01098633e-02],
                        [ -7.54089355e-02,  -7.53784180e-02],
                        [ -2.09777832e-01,  -2.09747314e-01],
                        [ -3.18603516e-01,  -3.18664551e-01],
                        [ -3.71459961e-01,  -3.71551514e-01],
                        [ -3.58520508e-01,  -3.58459473e-01],
                        [ -3.01696777e-01,  -3.01544189e-01],
                        [ -2.42156982e-01,  -2.42187500e-01],
                        [ -2.05261230e-01,  -2.05413818e-01],
                        [ -1.80358887e-01,  -1.80358887e-01],
                        [ -1.39373779e-01,  -1.39251709e-01],
                        [ -6.89392090e-02,  -6.89086914e-02],
                        [  1.93481445e-02,   1.92565918e-02],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  1.43798828e-01,   1.43859863e-01],
                        [  1.52404785e-01,   1.52404785e-01],
                        [  1.44073486e-01,   1.44012451e-01],
                        [  1.39282227e-01,   1.39343262e-01],
                        [  1.42639160e-01,   1.42700195e-01],
                        [  1.47216797e-01,   1.47125244e-01],
                        [  1.43798828e-01,   1.43737793e-01],
                        [  1.27777100e-01,   1.27838135e-01],
                        [  1.03515625e-01,   1.03607178e-01],
                        [  8.04443359e-02,   8.04138184e-02],
                        [  6.35681152e-02,   6.34460449e-02],
                        [  5.02319336e-02,   5.01708984e-02],
                        [  3.45458984e-02,   3.46374512e-02],
                        [  1.53503418e-02,   1.54724121e-02],
                        [  7.01904297e-04,   6.40869141e-04],
                        [  4.57763672e-04,   3.35693359e-04],
                        [  1.45874023e-02,   1.45568848e-02],
                        [  3.29895020e-02,   3.31115723e-02],
                        [  4.76379395e-02,   4.76989746e-02],
                        [  5.90515137e-02,   5.89904785e-02],
                        [  7.05261230e-02,   7.04650879e-02],
                        [  8.19091797e-02,   8.18786621e-02],
                        [  9.10949707e-02,   9.11254883e-02],
                        [  9.49096680e-02,   9.49707031e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  7.40051270e-02,   7.39135742e-02],
                        [  5.55419922e-02,   5.54504395e-02],
                        [  3.81774902e-02,   3.82385254e-02],
                        [  2.12097168e-02,   2.13317871e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [ -1.77612305e-02,  -1.78833008e-02],
                        [ -3.57971191e-02,  -3.58276367e-02],
                        [ -4.62951660e-02,  -4.61730957e-02],
                        [ -4.71496582e-02,  -4.70581055e-02],
                        [ -3.87878418e-02,  -3.88793945e-02],
                        [ -2.42309570e-02,  -2.42919922e-02],
                        [ -1.11999512e-02,  -1.11694336e-02],
                        [ -5.21850586e-03,  -5.15747070e-03],
                        [ -5.49316406e-04,  -6.10351562e-04],
                        [  1.13525391e-02,   1.13220215e-02],
                        [  2.87170410e-02,   2.87780762e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  4.85534668e-02,   4.84619141e-02],
                        [  4.76989746e-02,   4.77294922e-02],
                        [  4.15954590e-02,   4.16870117e-02],
                        [  3.02429199e-02,   3.02124023e-02],
                        [  1.54724121e-02,   1.53503418e-02],
                        [  9.76562500e-04,   1.00708008e-03],
                        [ -1.01013184e-02,  -1.00097656e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.02636719e-02,  -2.03857422e-02],
                        [ -2.21252441e-02,  -2.21557617e-02],
                        [ -2.37731934e-02,  -2.36511230e-02],
                        [ -2.57263184e-02,  -2.56347656e-02],
                        [ -2.59704590e-02,  -2.60925293e-02],
                        [ -2.07824707e-02,  -2.09045410e-02],
                        [ -1.14746094e-02,  -1.13525391e-02],
                        [ -5.37109375e-03,  -5.24902344e-03],
                        [ -6.10351562e-03,  -6.22558594e-03],
                        [ -9.73510742e-03,  -9.88769531e-03],
                        [ -1.26953125e-02,  -1.26342773e-02],
                        [ -1.72424316e-02,  -1.70593262e-02],
                        [ -2.63366699e-02,  -2.63671875e-02],
                        [ -3.64379883e-02,  -3.66210938e-02],
                        [ -3.98254395e-02,  -3.98559570e-02],
                        [ -3.46984863e-02,  -3.45458984e-02],
                        [ -2.60620117e-02,  -2.59704590e-02],
                        [ -1.62658691e-02,  -1.63574219e-02],
                        [ -3.72314453e-03,  -3.84521484e-03],
                        [  1.03759766e-02,   1.04064941e-02],
                        [  2.20642090e-02,   2.21557617e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.74658203e-02,   2.74353027e-02],
                        [  1.04370117e-02,   1.03759766e-02],
                        [ -2.81982422e-02,  -2.82592773e-02],
                        [ -8.12072754e-02,  -8.11767578e-02],
                        [ -1.27685547e-01,  -1.27593994e-01],
                        [ -1.47491455e-01,  -1.47430420e-01],
                        [ -1.33422852e-01,  -1.33544922e-01],
                        [ -9.36584473e-02,  -9.37500000e-02],
                        [ -4.69970703e-02,  -4.69055176e-02],
                        [ -1.03149414e-02,  -1.01928711e-02],
                        [  1.42517090e-02,   1.41906738e-02],
                        [  3.78417969e-02,   3.77197266e-02],
                        [  7.22961426e-02,   7.22656250e-02],
                        [  1.19903564e-01,   1.19995117e-01],
                        [  1.69342041e-01,   1.69403076e-01],
                        [  2.01141357e-01,   2.01110840e-01],
                        [  1.98791504e-01,   1.98699951e-01],
                        [  1.52496338e-01,   1.52496338e-01],
                        [  5.83190918e-02,   5.83801270e-02],
                        [ -7.52868652e-02,  -7.52563477e-02],
                        [ -2.20092773e-01,  -2.20153809e-01],
                        [ -3.35540771e-01,  -3.35540771e-01],
                        [ -3.89038086e-01,  -3.89038086e-01],
                        [ -3.73992920e-01,  -3.74023438e-01],
                        [ -3.12347412e-01,  -3.12377930e-01],
                        [ -2.41760254e-01,  -2.41668701e-01],
                        [ -1.91986084e-01,  -1.91894531e-01],
                        [ -1.63421631e-01,  -1.63513184e-01],
                        [ -1.30126953e-01,  -1.30249023e-01],
                        [ -7.07092285e-02,  -7.06787109e-02],
                        [  6.13403320e-03,   6.28662109e-03],
                        [  7.22045898e-02,   7.22351074e-02],
                        [  1.08978271e-01,   1.08825684e-01],
                        [  1.21032715e-01,   1.20971680e-01],
                        [  1.26251221e-01,   1.26373291e-01],
                        [  1.37573242e-01,   1.37634277e-01],
                        [  1.52587891e-01,   1.52526855e-01],
                        [  1.58660889e-01,   1.58599854e-01],
                        [  1.48223877e-01,   1.48193359e-01],
                        [  1.27105713e-01,   1.27075195e-01],
                        [  1.05468750e-01,   1.05529785e-01],
                        [  8.43200684e-02,   8.44116211e-02],
                        [  5.85632324e-02,   5.85021973e-02],
                        [  3.05175781e-02,   3.03649902e-02],
                        [  9.85717773e-03,   9.88769531e-03],
                        [  1.28173828e-03,   1.43432617e-03],
                        [  1.67846680e-03,   1.73950195e-03],
                        [  8.45336914e-03,   8.33129883e-03],
                        [  2.15759277e-02,   2.15148926e-02],
                        [  3.91540527e-02,   3.92456055e-02],
                        [  5.81359863e-02,   5.81970215e-02],
                        [  7.73010254e-02,   7.72399902e-02],
                        [  9.52758789e-02,   9.52453613e-02],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  8.95996094e-02,   8.96301270e-02],
                        [  7.04956055e-02,   7.05261230e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  1.07116699e-02,   1.06506348e-02],
                        [ -1.70288086e-02,  -1.70898438e-02],
                        [ -3.25012207e-02,  -3.24401855e-02],
                        [ -3.96728516e-02,  -3.95812988e-02],
                        [ -4.39453125e-02,  -4.39758301e-02],
                        [ -4.27856445e-02,  -4.29077148e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -1.91040039e-02,  -1.89819336e-02],
                        [ -6.10351562e-03,  -6.04248047e-03],
                        [  4.54711914e-03,   4.48608398e-03],
                        [  1.35498047e-02,   1.34582520e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.32543945e-02,   2.33459473e-02],
                        [  2.50854492e-02,   2.51464844e-02],
                        [  2.88085938e-02,   2.87475586e-02],
                        [  3.47290039e-02,   3.46679688e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.11376953e-02,   4.11682129e-02],
                        [  3.52172852e-02,   3.52478027e-02],
                        [  2.33764648e-02,   2.33154297e-02],
                        [  1.05590820e-02,   1.04675293e-02],
                        [  4.08935547e-03,   4.15039062e-03],
                        [  4.27246094e-03,   4.39453125e-03],
                        [  3.23486328e-03,   3.20434570e-03],
                        [ -5.76782227e-03,  -5.92041016e-03],
                        [ -2.16064453e-02,  -2.16369629e-02],
                        [ -3.81164551e-02,  -3.79638672e-02],
                        [ -4.98657227e-02,  -4.98046875e-02],
                        [ -5.41381836e-02,  -5.42602539e-02],
                        [ -5.04760742e-02,  -5.05371094e-02],
                        [ -4.12292480e-02,  -4.11376953e-02],
                        [ -3.15551758e-02,  -3.14941406e-02],
                        [ -2.57568359e-02,  -2.57873535e-02],
                        [ -2.25524902e-02,  -2.26440430e-02],
                        [ -1.80664062e-02,  -1.80358887e-02],
                        [ -1.30615234e-02,  -1.29394531e-02],
                        [ -1.15966797e-02,  -1.16271973e-02],
                        [ -1.39160156e-02,  -1.40380859e-02],
                        [ -1.66931152e-02,  -1.66625977e-02],
                        [ -1.80053711e-02,  -1.79138184e-02],
                        [ -1.74255371e-02,  -1.74560547e-02],
                        [ -1.42822266e-02,  -1.43737793e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [  5.76782227e-03,   5.82885742e-03],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.98364258e-02,   1.97753906e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -3.46679688e-02,  -3.46374512e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -8.90197754e-02,  -8.90502930e-02],
                        [ -8.59069824e-02,  -8.58764648e-02],
                        [ -6.30493164e-02,  -6.29882812e-02],
                        [ -3.50646973e-02,  -3.50952148e-02],
                        [ -1.37023926e-02,  -1.37634277e-02],
                        [  3.05175781e-03,   3.08227539e-03],
                        [  2.39868164e-02,   2.41088867e-02],
                        [  5.37109375e-02,   5.36804199e-02],
                        [  9.04541016e-02,   9.03320312e-02],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.57501221e-01,   1.57592773e-01],
                        [  1.61834717e-01,   1.61865234e-01],
                        [  1.24725342e-01,   1.24694824e-01],
                        [  3.76281738e-02,   3.75976562e-02],
                        [ -8.87145996e-02,  -8.87451172e-02],
                        [ -2.22717285e-01,  -2.22686768e-01],
                        [ -3.24401855e-01,  -3.24340820e-01],
                        [ -3.63800049e-01,  -3.63830566e-01],
                        [ -3.35601807e-01,  -3.35662842e-01],
                        [ -2.64892578e-01,  -2.64892578e-01],
                        [ -1.93847656e-01,  -1.93817139e-01],
                        [ -1.50970459e-01,  -1.50909424e-01],
                        [ -1.30401611e-01,  -1.30401611e-01],
                        [ -1.05133057e-01,  -1.05194092e-01],
                        [ -5.81665039e-02,  -5.81970215e-02],
                        [  1.77001953e-03,   1.80053711e-03],
                        [  5.17272949e-02,   5.17883301e-02],
                        [  7.82775879e-02,   7.82470703e-02],
                        [  8.84399414e-02,   8.83483887e-02],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  1.13586426e-01,   1.13647461e-01],
                        [  1.29638672e-01,   1.29669189e-01],
                        [  1.38916016e-01,   1.38854980e-01],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  7.01293945e-02,   7.01293945e-02],
                        [  4.87365723e-02,   4.87670898e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  1.50146484e-02,   1.49841309e-02],
                        [  1.75170898e-02,   1.74865723e-02],
                        [  3.46984863e-02,   3.47595215e-02],
                        [  5.45349121e-02,   5.45654297e-02],
                        [  6.91223145e-02,   6.90307617e-02],
                        [  8.10241699e-02,   8.09936523e-02],
                        [  9.13391113e-02,   9.14306641e-02],
                        [  9.41162109e-02,   9.41772461e-02],
                        [  8.66394043e-02,   8.65783691e-02],
                        [  7.35778809e-02,   7.35473633e-02],
                        [  5.83190918e-02,   5.83801270e-02],
                        [  4.07714844e-02,   4.08020020e-02],
                        [  2.36206055e-02,   2.35900879e-02],
                        [  1.02233887e-02,   1.02539062e-02],
                        [ -7.01904297e-04,  -6.71386719e-04],
                        [ -8.75854492e-03,  -8.81958008e-03],
                        [ -8.91113281e-03,  -8.94165039e-03],
                        [ -1.55639648e-03,  -1.46484375e-03],
                        [  5.46264648e-03,   5.49316406e-03],
                        [  8.20922852e-03,   8.14819336e-03],
                        [  9.36889648e-03,   9.30786133e-03],
                        [  1.15661621e-02,   1.15966797e-02],
                        [  1.48315430e-02,   1.48620605e-02],
                        [  1.65100098e-02,   1.65405273e-02],
                        [  1.28784180e-02,   1.28479004e-02],
                        [  4.88281250e-03,   4.82177734e-03],
                        [ -1.03759766e-03,  -1.00708008e-03],
                        [ -9.76562500e-04,  -8.85009766e-04],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  1.17797852e-02,   1.16882324e-02],
                        [  2.15454102e-02,   2.15148926e-02],
                        [  2.65808105e-02,   2.66113281e-02],
                        [  2.15148926e-02,   2.15759277e-02],
                        [  1.12915039e-02,   1.12609863e-02],
                        [  5.31005859e-03,   5.24902344e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  8.20922852e-03,   8.27026367e-03],
                        [  7.65991211e-03,   7.69042969e-03],
                        [  1.80053711e-03,   1.77001953e-03],
                        [ -9.09423828e-03,  -9.15527344e-03],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.83508301e-02,  -2.82897949e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.02941895e-02,  -2.03552246e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -9.79614258e-03,  -9.76562500e-03],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -8.54492188e-03,  -8.57543945e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  1.03759766e-03,   1.06811523e-03],
                        [ -2.56347656e-03,  -2.59399414e-03],
                        [ -1.37634277e-02,  -1.38244629e-02],
                        [ -3.04260254e-02,  -3.03955078e-02],
                        [ -4.93469238e-02,  -4.92858887e-02],
                        [ -6.17675781e-02,  -6.17980957e-02],
                        [ -5.84716797e-02,  -5.85021973e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -1.35498047e-02,  -1.34887695e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  2.65808105e-02,   2.65502930e-02],
                        [  3.01208496e-02,   3.00903320e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -6.09436035e-02,  -6.09436035e-02],
                        [ -7.24487305e-02,  -7.24792480e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -3.98254395e-02,  -3.97949219e-02],
                        [ -1.59301758e-02,  -1.58996582e-02],
                        [  5.06591797e-03,   5.00488281e-03],
                        [  2.75573730e-02,   2.75268555e-02],
                        [  5.61218262e-02,   5.61523438e-02],
                        [  9.04235840e-02,   9.04541016e-02],
                        [  1.24145508e-01,   1.24114990e-01],
                        [  1.44134521e-01,   1.44104004e-01],
                        [  1.33422852e-01,   1.33453369e-01],
                        [  8.03527832e-02,   8.03833008e-02],
                        [ -1.23596191e-02,  -1.23901367e-02],
                        [ -1.27532959e-01,  -1.27563477e-01],
                        [ -2.40203857e-01,  -2.40173340e-01],
                        [ -3.22875977e-01,  -3.22845459e-01],
                        [ -3.53546143e-01,  -3.53546143e-01],
                        [ -3.30963135e-01,  -3.30963135e-01],
                        [ -2.78137207e-01,  -2.78137207e-01],
                        [ -2.22595215e-01,  -2.22595215e-01],
                        [ -1.76208496e-01,  -1.76208496e-01],
                        [ -1.33148193e-01,  -1.33148193e-01],
                        [ -8.03222656e-02,  -8.03527832e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [  5.85632324e-02,   5.85937500e-02],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.33605957e-01,   1.33544922e-01],
                        [  1.31591797e-01,   1.31591797e-01],
                        [  1.22558594e-01,   1.22619629e-01],
                        [  1.22161865e-01,   1.22131348e-01],
                        [  1.29241943e-01,   1.29211426e-01],
                        [  1.27990723e-01,   1.28021240e-01],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  7.17773438e-02,   7.17773438e-02],
                        [  6.18591309e-02,   6.18286133e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.32238770e-02,   2.32543945e-02],
                        [  3.57666016e-02,   3.57971191e-02],
                        [  5.02014160e-02,   5.01708984e-02],
                        [  6.38732910e-02,   6.38427734e-02],
                        [  7.56225586e-02,   7.56835938e-02],
                        [  8.29772949e-02,   8.30383301e-02],
                        [  8.42285156e-02,   8.41979980e-02],
                        [  7.93762207e-02,   7.93457031e-02],
                        [  6.99462891e-02,   6.99768066e-02],
                        [  5.96008301e-02,   5.96618652e-02],
                        [  5.13916016e-02,   5.13610840e-02],
                        [  4.44030762e-02,   4.43420410e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.03955078e-02,   3.04565430e-02],
                        [  2.65808105e-02,   2.66113281e-02],
                        [  2.42309570e-02,   2.41699219e-02],
                        [  1.80053711e-02,   1.79748535e-02],
                        [  3.90625000e-03,   3.96728516e-03],
                        [ -1.40075684e-02,  -1.39770508e-02],
                        [ -2.58483887e-02,  -2.58789062e-02],
                        [ -2.56958008e-02,  -2.57568359e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -4.66918945e-03,  -4.57763672e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  3.50952148e-03,   3.41796875e-03],
                        [  4.54711914e-03,   4.51660156e-03],
                        [  7.47680664e-03,   7.56835938e-03],
                        [  1.13220215e-02,   1.13525391e-02],
                        [  1.44958496e-02,   1.44042969e-02],
                        [  1.46179199e-02,   1.45874023e-02],
                        [  1.10168457e-02,   1.10473633e-02],
                        [  8.17871094e-03,   8.20922852e-03],
                        [  9.09423828e-03,   9.06372070e-03],
                        [  9.55200195e-03,   9.52148438e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  7.90405273e-03,   7.90405273e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -1.22070312e-02,  -1.21765137e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -3.36303711e-02,  -3.36608887e-02],
                        [ -4.26940918e-02,  -4.27246094e-02],
                        [ -4.91027832e-02,  -4.90722656e-02],
                        [ -5.40466309e-02,  -5.40161133e-02],
                        [ -5.49926758e-02,  -5.50231934e-02],
                        [ -4.98352051e-02,  -4.98962402e-02],
                        [ -4.33654785e-02,  -4.33349609e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -1.94091797e-02,  -1.94702148e-02],
                        [ -2.86865234e-03,  -2.89916992e-03],
                        [  1.75170898e-02,   1.75781250e-02],
                        [  3.28674316e-02,   3.28979492e-02],
                        [  3.77197266e-02,   3.76586914e-02],
                        [  2.90222168e-02,   2.89916992e-02],
                        [  3.57055664e-03,   3.60107422e-03],
                        [ -3.42102051e-02,  -3.41796875e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -8.52050781e-02,  -8.52050781e-02],
                        [ -7.89489746e-02,  -7.89794922e-02],
                        [ -5.69763184e-02,  -5.69458008e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  9.83581543e-02,   9.83276367e-02],
                        [  1.37786865e-01,   1.37817383e-01],
                        [  1.58752441e-01,   1.58782959e-01],
                        [  1.45935059e-01,   1.45904541e-01],
                        [  9.14306641e-02,   9.13696289e-02],
                        [ -6.89697266e-03,  -6.86645508e-03],
                        [ -1.39221191e-01,  -1.39190674e-01],
                        [ -2.73559570e-01,  -2.73590088e-01],
                        [ -3.66729736e-01,  -3.66729736e-01],
                        [ -3.92517090e-01,  -3.92517090e-01],
                        [ -3.55926514e-01,  -3.55926514e-01],
                        [ -2.85858154e-01,  -2.85858154e-01],
                        [ -2.16491699e-01,  -2.16461182e-01],
                        [ -1.63970947e-01,  -1.63940430e-01],
                        [ -1.17126465e-01,  -1.17156982e-01],
                        [ -5.62133789e-02,  -5.62438965e-02],
                        [  1.96533203e-02,   1.96838379e-02],
                        [  8.86230469e-02,   8.86535645e-02],
                        [  1.28540039e-01,   1.28540039e-01],
                        [  1.36993408e-01,   1.36993408e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.24359131e-01,   1.24359131e-01],
                        [  1.23809814e-01,   1.23840332e-01],
                        [  1.15600586e-01,   1.15570068e-01],
                        [  1.02172852e-01,   1.02111816e-01],
                        [  8.57849121e-02,   8.58154297e-02],
                        [  6.38732910e-02,   6.39038086e-02],
                        [  3.80554199e-02,   3.80249023e-02],
                        [  1.61132812e-02,   1.60827637e-02],
                        [  2.68554688e-03,   2.74658203e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  5.37109375e-03,   5.31005859e-03],
                        [  2.32849121e-02,   2.33154297e-02],
                        [  4.46166992e-02,   4.46472168e-02],
                        [  6.28356934e-02,   6.28051758e-02],
                        [  7.91625977e-02,   7.91320801e-02],
                        [  9.53063965e-02,   9.53369141e-02],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  1.11938477e-01,   1.11938477e-01],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  3.88488770e-02,   3.88793945e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  5.21850586e-03,   5.21850586e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -1.22070312e-04,  -9.15527344e-05],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -3.47900391e-03,  -3.50952148e-03],
                        [  0.00000000e+00,  -3.05175781e-05],
                        [  1.02539062e-02,   1.02844238e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  1.04980469e-02,   1.04675293e-02],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -1.13830566e-02,  -1.13525391e-02],
                        [ -1.91040039e-02,  -1.91345215e-02],
                        [ -1.57470703e-02,  -1.57775879e-02],
                        [ -2.62451172e-03,  -2.59399414e-03],
                        [  1.26037598e-02,   1.26342773e-02],
                        [  2.49023438e-02,   2.48718262e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -2.15759277e-02,  -2.16064453e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -1.94396973e-02,  -1.94702148e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.14843750e-02,  -2.14538574e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.56347656e-02,  -2.56042480e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -4.21447754e-02,  -4.22058105e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -2.45361328e-02,  -2.45056152e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  3.60107422e-03,   3.57055664e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -9.04235840e-02,  -9.03930664e-02],
                        [ -7.87658691e-02,  -7.87658691e-02],
                        [ -4.56542969e-02,  -4.56848145e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  1.21704102e-01,   1.21673584e-01],
                        [  1.44775391e-01,   1.44744873e-01],
                        [  1.45538330e-01,   1.45568848e-01],
                        [  1.09924316e-01,   1.09954834e-01],
                        [  2.81372070e-02,   2.81372070e-02],
                        [ -9.28344727e-02,  -9.28344727e-02],
                        [ -2.24121094e-01,  -2.24121094e-01],
                        [ -3.24981689e-01,  -3.24981689e-01],
                        [ -3.63220215e-01,  -3.63250732e-01],
                        [ -3.34777832e-01,  -3.34747314e-01],
                        [ -2.67150879e-01,  -2.67150879e-01],
                        [ -2.00347900e-01,  -2.00378418e-01],
                        [ -1.56768799e-01,  -1.56768799e-01],
                        [ -1.26495361e-01,  -1.26464844e-01],
                        [ -8.37402344e-02,  -8.37402344e-02],
                        [ -1.94396973e-02,  -1.94702148e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  8.36181641e-02,   8.36486816e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  7.97119141e-02,   7.97424316e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  1.10351562e-01,   1.10351562e-01],
                        [  1.18103027e-01,   1.18133545e-01],
                        [  1.11450195e-01,   1.11419678e-01],
                        [  9.88464355e-02,   9.88159180e-02],
                        [  8.82873535e-02,   8.83178711e-02],
                        [  7.92236328e-02,   7.92236328e-02],
                        [  6.64672852e-02,   6.64367676e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  2.48107910e-02,   2.48413086e-02],
                        [  9.00268555e-03,   8.97216797e-03],
                        [  5.79833984e-03,   5.76782227e-03],
                        [  1.58081055e-02,   1.58386230e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  8.62731934e-02,   8.62731934e-02],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  9.73815918e-02,   9.73510742e-02],
                        [  9.71069336e-02,   9.71374512e-02],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  8.75549316e-02,   8.75244141e-02],
                        [  7.47375488e-02,   7.47375488e-02],
                        [  5.57250977e-02,   5.57556152e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  8.27026367e-03,   8.23974609e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -1.41296387e-02,  -1.40991211e-02],
                        [ -1.12609863e-02,  -1.12915039e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -3.78417969e-03,  -3.75366211e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -1.49230957e-02,  -1.49536133e-02],
                        [ -1.84936523e-02,  -1.84631348e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.77001953e-02,  -1.77307129e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  4.92553711e-02,   4.92248535e-02],
                        [  3.60412598e-02,   3.60717773e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.80664062e-02,   1.80358887e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.49230957e-02,  -1.48925781e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -3.01513672e-02,  -3.01818848e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.19006348e-02,  -4.18701172e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.40380859e-03,  -1.37329102e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.72827148e-02,  -2.73132324e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -4.26940918e-02,  -4.26635742e-02],
                        [ -5.38635254e-02,  -5.38940430e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -3.14331055e-03,  -3.17382812e-03],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  1.61834717e-01,   1.61804199e-01],
                        [  1.82739258e-01,   1.82769775e-01],
                        [  1.65496826e-01,   1.65496826e-01],
                        [  9.67712402e-02,   9.67407227e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.70196533e-01,  -1.70196533e-01],
                        [ -2.99774170e-01,  -2.99804688e-01],
                        [ -3.66546631e-01,  -3.66546631e-01],
                        [ -3.58642578e-01,  -3.58642578e-01],
                        [ -3.01300049e-01,  -3.01330566e-01],
                        [ -2.33703613e-01,  -2.33703613e-01],
                        [ -1.83746338e-01,  -1.83746338e-01],
                        [ -1.52557373e-01,  -1.52557373e-01],
                        [ -1.18164062e-01,  -1.18164062e-01],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  5.59387207e-02,   5.59082031e-02],
                        [  7.58361816e-02,   7.58666992e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  6.86035156e-02,   6.85729980e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  1.03149414e-01,   1.03179932e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.29394531e-01,   1.29364014e-01],
                        [  1.24542236e-01,   1.24542236e-01],
                        [  1.15264893e-01,   1.15264893e-01],
                        [  1.02752686e-01,   1.02752686e-01],
                        [  8.25195312e-02,   8.24890137e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  5.31005859e-03,   5.27954102e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  4.16870117e-02,   4.16564941e-02],
                        [  6.37512207e-02,   6.37207031e-02],
                        [  8.16345215e-02,   8.16650391e-02],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  1.09802246e-01,   1.09771729e-01],
                        [  1.14562988e-01,   1.14593506e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  9.02099609e-02,   9.01794434e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  4.22058105e-02,   4.22363281e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -1.67846680e-02,  -1.68151855e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [  5.49316406e-04,   5.79833984e-04],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  7.90405273e-03,   7.87353516e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [ -3.93676758e-03,  -3.96728516e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  7.32421875e-04,   7.01904297e-04],
                        [  5.92041016e-03,   5.88989258e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.61425781e-02,   4.61120605e-02],
                        [  3.73535156e-02,   3.73229980e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [ -2.08129883e-02,  -2.08435059e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -8.46557617e-02,  -8.46557617e-02],
                        [ -7.81555176e-02,  -7.81555176e-02],
                        [ -6.19506836e-02,  -6.19812012e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -9.52148438e-03,  -9.55200195e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -7.12280273e-02,  -7.12280273e-02],
                        [ -8.89892578e-02,  -8.89892578e-02],
                        [ -9.06066895e-02,  -9.05761719e-02],
                        [ -6.82067871e-02,  -6.82067871e-02],
                        [ -2.37121582e-02,  -2.37426758e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.67694092e-01,   1.67694092e-01],
                        [  1.85424805e-01,   1.85424805e-01],
                        [  1.79016113e-01,   1.79016113e-01],
                        [  1.35742188e-01,   1.35742188e-01],
                        [  4.34875488e-02,   4.35180664e-02],
                        [ -9.48486328e-02,  -9.48486328e-02],
                        [ -2.51007080e-01,  -2.51007080e-01],
                        [ -3.79394531e-01,  -3.79364014e-01],
                        [ -4.40643311e-01,  -4.40643311e-01],
                        [ -4.24468994e-01,  -4.24468994e-01],
                        [ -3.55316162e-01,  -3.55316162e-01],
                        [ -2.73803711e-01,  -2.73834229e-01],
                        [ -2.06756592e-01,  -2.06756592e-01],
                        [ -1.50634766e-01,  -1.50634766e-01],
                        [ -8.39233398e-02,  -8.39233398e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  9.21630859e-02,   9.21936035e-02],
                        [  1.52282715e-01,   1.52282715e-01],
                        [  1.69158936e-01,   1.69158936e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.34338379e-01,   1.34338379e-01],
                        [  1.22009277e-01,   1.22009277e-01],
                        [  1.16455078e-01,   1.16485596e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  9.17053223e-02,   9.16748047e-02],
                        [  7.64465332e-02,   7.64465332e-02],
                        [  6.93054199e-02,   6.93054199e-02],
                        [  6.45141602e-02,   6.44836426e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  1.78527832e-02,   1.78833008e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  6.05468750e-02,   6.05468750e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.26007080e-01,   1.26007080e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  1.17645264e-01,   1.17645264e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  4.60815430e-03,   4.57763672e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  1.23901367e-02,   1.24206543e-02],
                        [  1.37329102e-03,   1.34277344e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  3.93371582e-02,   3.93066406e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -2.83813477e-02,  -2.83508301e-02],
                        [ -3.61633301e-02,  -3.61938477e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.26940918e-02,  -4.26635742e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.18603516e-02,  -3.18298340e-02],
                        [ -3.65905762e-02,  -3.66210938e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -5.50231934e-02,  -5.49926758e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  9.52148438e-03,   9.55200195e-03],
                        [  2.13317871e-02,   2.13012695e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  3.03344727e-02,   3.03649902e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -7.73925781e-02,  -7.73620605e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -5.34057617e-02,  -5.34362793e-02],
                        [ -1.00402832e-02,  -1.00097656e-02],
                        [  4.28771973e-02,   4.29077148e-02],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  1.72393799e-01,   1.72424316e-01],
                        [  1.80694580e-01,   1.80694580e-01],
                        [  1.51367188e-01,   1.51336670e-01],
                        [  6.77490234e-02,   6.77795410e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -2.25036621e-01,  -2.25036621e-01],
                        [ -3.52203369e-01,  -3.52203369e-01],
                        [ -4.12750244e-01,  -4.12750244e-01],
                        [ -3.99749756e-01,  -3.99749756e-01],
                        [ -3.36303711e-01,  -3.36303711e-01],
                        [ -2.60070801e-01,  -2.60070801e-01],
                        [ -1.97998047e-01,  -1.97967529e-01],
                        [ -1.47369385e-01,  -1.47369385e-01],
                        [ -8.68530273e-02,  -8.68530273e-02],
                        [ -1.00708008e-02,  -1.00402832e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  1.00036621e-01,   1.00006104e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  9.99145508e-02,   9.99450684e-02],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.19995117e-01,   1.19995117e-01],
                        [  1.09527588e-01,   1.09527588e-01],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  7.82775879e-02,   7.82775879e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  1.16638184e-01,   1.16668701e-01],
                        [  1.15325928e-01,   1.15295410e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  7.75756836e-02,   7.76062012e-02],
                        [  3.67126465e-02,   3.66821289e-02],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -3.00292969e-02,  -2.99987793e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.52380371e-02,  -2.52075195e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  5.42297363e-02,   5.41992188e-02],
                        [  7.04040527e-02,   7.04345703e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.87976074e-02,  -4.88281250e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.22570801e-02,  -3.22265625e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -7.84301758e-03,  -7.87353516e-03],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [  9.46044922e-04,   9.46044922e-04],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  1.12121582e-01,   1.12121582e-01],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  7.45544434e-02,   7.45544434e-02],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -1.16821289e-01,  -1.16821289e-01],
                        [ -2.45544434e-01,  -2.45544434e-01],
                        [ -3.46252441e-01,  -3.46252441e-01],
                        [ -3.85498047e-01,  -3.85498047e-01],
                        [ -3.59893799e-01,  -3.59893799e-01],
                        [ -2.95501709e-01,  -2.95501709e-01],
                        [ -2.26867676e-01,  -2.26867676e-01],
                        [ -1.70593262e-01,  -1.70593262e-01],
                        [ -1.18804932e-01,  -1.18804932e-01],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  1.08093262e-01,   1.08093262e-01],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  9.80834961e-02,   9.80834961e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  5.87158203e-02,   5.86853027e-02],
                        [  7.75756836e-02,   7.76062012e-02],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  7.25708008e-02,   7.25708008e-02],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  3.11279297e-02,   3.10974121e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.39147949e-02,  -4.39453125e-02],
                        [ -3.65905762e-02,  -3.66210938e-02],
                        [ -2.15148926e-02,  -2.14843750e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  2.76489258e-02,   2.76489258e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  4.50439453e-02,   4.50744629e-02],
                        [  5.35583496e-02,   5.35888672e-02],
                        [  4.94384766e-02,   4.94079590e-02],
                        [  3.36608887e-02,   3.36303711e-02],
                        [  1.26953125e-02,   1.27258301e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -7.87963867e-02,  -7.87963867e-02],
                        [ -9.45129395e-02,  -9.45129395e-02],
                        [ -1.00494385e-01,  -1.00494385e-01],
                        [ -9.50012207e-02,  -9.50012207e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -6.28967285e-02,  -6.29272461e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -2.46887207e-02,  -2.47192383e-02],
                        [ -1.80969238e-02,  -1.81274414e-02],
                        [ -7.50732422e-03,  -7.47680664e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -8.02917480e-02,  -8.02917480e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  1.18041992e-01,   1.18041992e-01],
                        [  1.40777588e-01,   1.40777588e-01],
                        [  1.31622314e-01,   1.31622314e-01],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -1.04553223e-01,  -1.04583740e-01],
                        [ -2.26684570e-01,  -2.26684570e-01],
                        [ -3.17230225e-01,  -3.17230225e-01],
                        [ -3.44390869e-01,  -3.44390869e-01],
                        [ -3.09478760e-01,  -3.09478760e-01],
                        [ -2.44689941e-01,  -2.44689941e-01],
                        [ -1.87164307e-01,  -1.87164307e-01],
                        [ -1.52435303e-01,  -1.52465820e-01],
                        [ -1.28295898e-01,  -1.28295898e-01],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.72521973e-02,   2.72216797e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  8.57849121e-02,   8.57849121e-02],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.28692627e-01,   1.28692627e-01],
                        [  1.25427246e-01,   1.25427246e-01],
                        [  1.14074707e-01,   1.14074707e-01],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [  5.57861328e-02,   5.57556152e-02],
                        [  5.61218262e-02,   5.60913086e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  5.65490723e-02,   5.65185547e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  6.13098145e-02,   6.13403320e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  7.03430176e-02,   7.03125000e-02],
                        [  7.23876953e-02,   7.24182129e-02],
                        [  6.61926270e-02,   6.61926270e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -1.73950195e-03,  -1.70898438e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  1.58691406e-02,   1.58386230e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  2.57568359e-02,   2.57263184e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.40173340e-02,   2.39868164e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.89001465e-02,   2.88696289e-02],
                        [  2.96630859e-02,   2.96325684e-02],
                        [  2.46582031e-02,   2.46887207e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [ -2.01416016e-03,  -1.98364258e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -8.39233398e-03,  -8.42285156e-03],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -6.04248047e-03,  -6.07299805e-03],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -9.55200195e-03,  -9.52148438e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -4.66003418e-02,  -4.66308594e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -6.10046387e-02,  -6.09741211e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -5.63964844e-02,  -5.64270020e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -4.91027832e-02,  -4.90722656e-02],
                        [ -2.98156738e-02,  -2.98461914e-02],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  1.18865967e-01,   1.18896484e-01],
                        [  1.32843018e-01,   1.32843018e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.25762939e-01,   1.25793457e-01],
                        [  9.42077637e-02,   9.42077637e-02],
                        [  3.32031250e-02,   3.31726074e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -1.73492432e-01,  -1.73492432e-01],
                        [ -2.75604248e-01,  -2.75604248e-01],
                        [ -3.30718994e-01,  -3.30688477e-01],
                        [ -3.23852539e-01,  -3.23822021e-01],
                        [ -2.71484375e-01,  -2.71514893e-01],
                        [ -2.08892822e-01,  -2.08892822e-01],
                        [ -1.61071777e-01,  -1.61071777e-01],
                        [ -1.25610352e-01,  -1.25610352e-01],
                        [ -8.39233398e-02,  -8.39538574e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  6.51855469e-02,   6.51550293e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  6.40258789e-02,   6.40563965e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  6.18286133e-02,   6.18591309e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  8.30688477e-02,   8.30383301e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -2.59399414e-03,  -2.62451172e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  5.92041016e-03,   5.95092773e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.23901367e-02,   1.24206543e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  2.75573730e-02,   2.75268555e-02],
                        [  3.31420898e-02,   3.31726074e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.75061035e-02,   3.74755859e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.21862793e-02,   2.21557617e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  1.77001953e-03,   1.77001953e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.28173828e-02,  -1.27868652e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.82690430e-02,  -3.82995605e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -9.32617188e-02,  -9.32617188e-02],
                        [ -8.88061523e-02,  -8.88061523e-02],
                        [ -7.76062012e-02,  -7.76367188e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  2.36206055e-02,   2.35900879e-02],
                        [  2.70996094e-02,   2.71301270e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.41204834e-01,   1.41204834e-01],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [ -8.16345215e-02,  -8.16345215e-02],
                        [ -1.91131592e-01,  -1.91162109e-01],
                        [ -2.78869629e-01,  -2.78869629e-01],
                        [ -3.22662354e-01,  -3.22662354e-01],
                        [ -3.15124512e-01,  -3.15124512e-01],
                        [ -2.71392822e-01,  -2.71392822e-01],
                        [ -2.18963623e-01,  -2.18963623e-01],
                        [ -1.74652100e-01,  -1.74652100e-01],
                        [ -1.35192871e-01,  -1.35192871e-01],
                        [ -8.97521973e-02,  -8.97521973e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  9.73510742e-02,   9.73510742e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.75659180e-02,   6.75659180e-02],
                        [  5.93261719e-02,   5.93566895e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  4.10156250e-02,   4.09851074e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  7.11059570e-02,   7.11364746e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -6.34765625e-03,  -6.37817383e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.23693848e-02,   2.23999023e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.21948242e-02,  -6.21948242e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -3.67431641e-02,  -3.67126465e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.83715820e-02,   1.84020996e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.29089355e-02,  -1.29394531e-02],
                        [ -3.02429199e-02,  -3.02124023e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -6.57348633e-02,  -6.57653809e-02],
                        [ -7.88269043e-02,  -7.88269043e-02],
                        [ -8.34960938e-02,  -8.34960938e-02],
                        [ -7.45849609e-02,  -7.45849609e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.13281250e-01,   1.13281250e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.51153564e-01,   1.51153564e-01],
                        [  1.46545410e-01,   1.46545410e-01],
                        [  1.16210938e-01,   1.16241455e-01],
                        [  5.13916016e-02,   5.13916016e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -1.67999268e-01,  -1.67999268e-01],
                        [ -2.76794434e-01,  -2.76794434e-01],
                        [ -3.45672607e-01,  -3.45672607e-01],
                        [ -3.58978271e-01,  -3.58978271e-01],
                        [ -3.23822021e-01,  -3.23822021e-01],
                        [ -2.66479492e-01,  -2.66479492e-01],
                        [ -2.12432861e-01,  -2.12432861e-01],
                        [ -1.67480469e-01,  -1.67480469e-01],
                        [ -1.19110107e-01,  -1.19110107e-01],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  8.16955566e-02,   8.16955566e-02],
                        [  8.07189941e-02,   8.07495117e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  7.44323730e-02,   7.44323730e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  6.58264160e-02,   6.57958984e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  5.93261719e-02,   5.93261719e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  9.97924805e-03,   1.00097656e-02],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.48925781e-02,  -1.48620605e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  7.65686035e-02,   7.65686035e-02],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.20788574e-01,   1.20788574e-01],
                        [  1.17004395e-01,   1.17004395e-01],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -1.52313232e-01,  -1.52313232e-01],
                        [ -2.56591797e-01,  -2.56591797e-01],
                        [ -3.24005127e-01,  -3.24005127e-01],
                        [ -3.37005615e-01,  -3.37005615e-01],
                        [ -3.04473877e-01,  -3.04443359e-01],
                        [ -2.51342773e-01,  -2.51342773e-01],
                        [ -2.00286865e-01,  -2.00286865e-01],
                        [ -1.58447266e-01,  -1.58447266e-01],
                        [ -1.17858887e-01,  -1.17858887e-01],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  8.62426758e-02,   8.62426758e-02],
                        [  1.06445312e-01,   1.06445312e-01],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.25122070e-01,   1.25122070e-01],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  1.18896484e-01,   1.18896484e-01],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  5.93566895e-02,   5.93566895e-02],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  7.84301758e-03,   7.84301758e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  8.64562988e-02,   8.64562988e-02],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  1.16088867e-01,   1.16088867e-01],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  7.57751465e-02,   7.57751465e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -1.08917236e-01,  -1.08917236e-01],
                        [ -2.24731445e-01,  -2.24731445e-01],
                        [ -3.13140869e-01,  -3.13140869e-01],
                        [ -3.49243164e-01,  -3.49243164e-01],
                        [ -3.30657959e-01,  -3.30657959e-01],
                        [ -2.80426025e-01,  -2.80426025e-01],
                        [ -2.28210449e-01,  -2.28210449e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -1.47247314e-01,  -1.47247314e-01],
                        [ -9.71984863e-02,  -9.71984863e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  9.07287598e-02,   9.07287598e-02],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  8.95996094e-02,   8.95996094e-02],
                        [  8.29772949e-02,   8.29772949e-02],
                        [  7.15637207e-02,   7.15637207e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.61743164e-03,  -1.58691406e-03],
                        [  5.00488281e-03,   5.03540039e-03],
                        [  1.21765137e-02,   1.22070312e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  1.40380859e-03,   1.43432617e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.38854980e-02,  -1.39160156e-02],
                        [ -1.37329102e-02,  -1.37634277e-02],
                        [ -1.50146484e-02,  -1.50451660e-02],
                        [ -1.61743164e-02,  -1.62048340e-02],
                        [ -1.61132812e-02,  -1.61437988e-02],
                        [ -1.51977539e-02,  -1.52282715e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -5.50537109e-02,  -5.50231934e-02],
                        [ -5.46875000e-02,  -5.46569824e-02],
                        [ -4.42810059e-02,  -4.42504883e-02],
                        [ -3.26843262e-02,  -3.26538086e-02],
                        [ -2.54211426e-02,  -2.53906250e-02],
                        [ -2.18505859e-02,  -2.18200684e-02],
                        [ -1.94091797e-02,  -1.93786621e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -2.41088867e-03,  -2.44140625e-03],
                        [ -7.50732422e-03,  -7.53784180e-03],
                        [ -1.35498047e-02,  -1.35803223e-02],
                        [ -1.81884766e-02,  -1.82189941e-02],
                        [ -2.15148926e-02,  -2.15454102e-02],
                        [ -2.35290527e-02,  -2.35595703e-02],
                        [ -2.32238770e-02,  -2.32543945e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  4.09240723e-02,   4.08935547e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  8.02307129e-02,   8.02001953e-02],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  1.00708008e-01,   1.00708008e-01],
                        [  1.07788086e-01,   1.07818604e-01],
                        [  1.16485596e-01,   1.16516113e-01],
                        [  1.25061035e-01,   1.25091553e-01],
                        [  1.29455566e-01,   1.29516602e-01],
                        [  1.25518799e-01,   1.25610352e-01],
                        [  1.07910156e-01,   1.08001709e-01],
                        [  6.73217773e-02,   6.74133301e-02],
                        [ -5.27954102e-03,  -5.18798828e-03],
                        [ -1.06628418e-01,  -1.06567383e-01],
                        [ -2.16003418e-01,  -2.15972900e-01],
                        [ -3.02795410e-01,  -3.02825928e-01],
                        [ -3.43048096e-01,  -3.43109131e-01],
                        [ -3.33251953e-01,  -3.33343506e-01],
                        [ -2.89886475e-01,  -2.90069580e-01],
                        [ -2.36968994e-01,  -2.37182617e-01],
                        [ -1.91650391e-01,  -1.91864014e-01],
                        [ -1.54479980e-01,  -1.54693604e-01],
                        [ -1.13861084e-01,  -1.14044189e-01],
                        [ -6.12487793e-02,  -6.13708496e-02],
                        [ -8.85009766e-04,  -9.46044922e-04],
                        [  5.17883301e-02,   5.18188477e-02],
                        [  8.27941895e-02,   8.28857422e-02],
                        [  9.17968750e-02,   9.19799805e-02],
                        [  9.08508301e-02,   9.10949707e-02],
                        [  9.31701660e-02,   9.34753418e-02],
                        [  1.03027344e-01,   1.03332520e-01],
                        [  1.13281250e-01,   1.13616943e-01],
                        [  1.13433838e-01,   1.13708496e-01],
                        [  1.00311279e-01,   1.00524902e-01],
                        [  8.02917480e-02,   8.04138184e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  5.06896973e-02,   5.05676270e-02],
                        [  4.10766602e-02,   4.08630371e-02],
                        [  2.82897949e-02,   2.79846191e-02],
                        [  1.37634277e-02,   1.34277344e-02],
                        [  3.87573242e-03,   3.50952148e-03],
                        [  9.15527344e-04,   5.49316406e-04],
                        [  3.02124023e-03,   2.68554688e-03],
                        [  7.87353516e-03,   7.62939453e-03],
                        [  1.30920410e-02,   1.29394531e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  2.79541016e-02,   2.80456543e-02],
                        [  4.24499512e-02,   4.26635742e-02],
                        [  5.96923828e-02,   5.99975586e-02],
                        [  7.43408203e-02,   7.46765137e-02],
                        [  8.25195312e-02,   8.28552246e-02],
                        [  8.41979980e-02,   8.45336914e-02],
                        [  7.90710449e-02,   7.93457031e-02],
                        [  6.54602051e-02,   6.56738281e-02],
                        [  4.52575684e-02,   4.53796387e-02],
                        [  2.34375000e-02,   2.34680176e-02],
                        [  3.72314453e-03,   3.66210938e-03],
                        [ -1.32446289e-02,  -1.33666992e-02],
                        [ -2.70385742e-02,  -2.72216797e-02],
                        [ -3.44543457e-02,  -3.46374512e-02],
                        [ -3.19519043e-02,  -3.21350098e-02],
                        [ -2.02331543e-02,  -2.03857422e-02],
                        [ -3.32641602e-03,  -3.44848633e-03],
                        [  1.46179199e-02,   1.45568848e-02],
                        [  2.89001465e-02,   2.88696289e-02],
                        [  3.46984863e-02,   3.47290039e-02],
                        [  3.24707031e-02,   3.25012207e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  2.52990723e-02,   2.52685547e-02],
                        [  2.27355957e-02,   2.26745605e-02],
                        [  1.79443359e-02,   1.78222656e-02],
                        [  9.88769531e-03,   9.73510742e-03],
                        [ -3.35693359e-04,  -5.18798828e-04],
                        [ -8.78906250e-03,  -9.00268555e-03],
                        [ -1.11694336e-02,  -1.13525391e-02],
                        [ -7.90405273e-03,  -8.02612305e-03],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [  1.92260742e-03,   2.01416016e-03],
                        [  9.88769531e-03,   1.01318359e-02],
                        [  1.85546875e-02,   1.89208984e-02],
                        [  2.21862793e-02,   2.26745605e-02],
                        [  1.81274414e-02,   1.87377930e-02],
                        [  8.05664062e-03,   8.69750977e-03],
                        [ -5.52368164e-03,  -4.94384766e-03],
                        [ -1.99890137e-02,  -1.95312500e-02],
                        [ -3.10668945e-02,  -3.07617188e-02],
                        [ -3.47290039e-02,  -3.46374512e-02],
                        [ -3.06091309e-02,  -3.07922363e-02],
                        [ -2.16674805e-02,  -2.21252441e-02],
                        [ -1.10778809e-02,  -1.17797852e-02],
                        [ -1.73950195e-03,  -2.62451172e-03],
                        [  2.99072266e-03,   1.98364258e-03],
                        [  1.43432617e-03,   3.66210938e-04],
                        [ -3.87573242e-03,  -4.88281250e-03],
                        [ -9.39941406e-03,  -1.02233887e-02],
                        [ -1.42822266e-02,  -1.48620605e-02],
                        [ -1.92871094e-02,  -1.95312500e-02],
                        [ -2.38952637e-02,  -2.37426758e-02],
                        [ -2.78015137e-02,  -2.72827148e-02],
                        [ -3.31726074e-02,  -3.22570801e-02],
                        [ -3.99475098e-02,  -3.87573242e-02],
                        [ -4.21752930e-02,  -4.08020020e-02],
                        [ -3.63464355e-02,  -3.49121094e-02],
                        [ -2.78930664e-02,  -2.65197754e-02],
                        [ -2.28271484e-02,  -2.16369629e-02],
                        [ -1.96228027e-02,  -1.87377930e-02],
                        [ -1.34582520e-02,  -1.29699707e-02],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  1.73950195e-03,   1.25122070e-03],
                        [  3.54003906e-03,   2.62451172e-03],
                        [  3.41796875e-03,   2.13623047e-03],
                        [  3.75366211e-03,   2.19726562e-03],
                        [  6.07299805e-03,   4.39453125e-03],
                        [  1.18408203e-02,   1.02233887e-02],
                        [  2.02941895e-02,   1.88293457e-02],
                        [  2.69775391e-02,   2.57873535e-02],
                        [  2.70996094e-02,   2.63366699e-02],
                        [  2.11791992e-02,   2.08740234e-02],
                        [  1.35498047e-02,   1.37329102e-02],
                        [  6.53076172e-03,   7.20214844e-03],
                        [  6.40869141e-04,   1.73950195e-03],
                        [ -1.80053711e-03,  -3.96728516e-04],
                        [  2.04467773e-03,   3.66210938e-03],
                        [  1.37023926e-02,   1.53808594e-02],
                        [  3.19824219e-02,   3.35693359e-02],
                        [  5.30700684e-02,   5.44738770e-02],
                        [  7.29675293e-02,   7.40356445e-02],
                        [  8.96911621e-02,   9.03625488e-02],
                        [  1.02874756e-01,   1.03118896e-01],
                        [  1.10656738e-01,   1.10443115e-01],
                        [  1.07055664e-01,   1.06414795e-01],
                        [  8.07189941e-02,   7.97119141e-02],
                        [  1.92871094e-02,   1.80053711e-02],
                        [ -7.67517090e-02,  -7.81860352e-02],
                        [ -1.84143066e-01,  -1.85638428e-01],
                        [ -2.67272949e-01,  -2.68707275e-01],
                        [ -3.01391602e-01,  -3.02673340e-01],
                        [ -2.88299561e-01,  -2.89337158e-01],
                        [ -2.52410889e-01,  -2.53143311e-01],
                        [ -2.20367432e-01,  -2.20764160e-01],
                        [ -2.00927734e-01,  -2.00958252e-01],
                        [ -1.80664062e-01,  -1.80328369e-01],
                        [ -1.41113281e-01,  -1.40472412e-01],
                        [ -8.01086426e-02,  -7.91931152e-02],
                        [ -1.29699707e-02,  -1.18408203e-02],
                        [  4.24499512e-02,   4.37316895e-02],
                        [  7.73620605e-02,   7.87048340e-02],
                        [  9.41467285e-02,   9.54589844e-02],
                        [  1.00616455e-01,   1.01806641e-01],
                        [  1.03210449e-01,   1.04217529e-01],
                        [  1.05834961e-01,   1.06567383e-01],
                        [  1.09558105e-01,   1.10015869e-01],
                        [  1.11999512e-01,   1.12091064e-01],
                        [  1.08459473e-01,   1.08184814e-01],
                        [  9.53063965e-02,   9.46960449e-02],
                        [  7.27233887e-02,   7.17773438e-02],
                        [  4.45556641e-02,   4.33654785e-02],
                        [  1.68762207e-02,   1.55029297e-02],
                        [ -3.32641602e-03,  -4.79125977e-03],
                        [ -1.22680664e-02,  -1.37329102e-02],
                        [ -1.10473633e-02,  -1.23901367e-02],
                        [ -2.19726562e-03,  -3.32641602e-03],
                        [  1.13220215e-02,   1.04980469e-02],
                        [  2.61535645e-02,   2.57263184e-02],
                        [  4.12597656e-02,   4.12902832e-02],
                        [  5.68542480e-02,   5.73120117e-02],
                        [  6.99768066e-02,   7.08618164e-02],
                        [  7.55310059e-02,   7.67822266e-02],
                        [  7.12890625e-02,   7.27844238e-02],
                        [  5.99060059e-02,   6.15539551e-02],
                        [  4.57763672e-02,   4.74548340e-02],
                        [  3.05480957e-02,   3.20739746e-02],
                        [  1.36108398e-02,   1.48925781e-02],
                        [ -3.32641602e-03,  -2.41088867e-03],
                        [ -1.65100098e-02,  -1.60217285e-02],
                        [ -2.39562988e-02,  -2.39257812e-02],
                        [ -2.53601074e-02,  -2.57873535e-02],
                        [ -2.02636719e-02,  -2.11181641e-02],
                        [ -1.13525391e-02,  -1.25427246e-02],
                        [ -4.05883789e-03,  -5.46264648e-03],
                        [  3.05175781e-05,  -1.49536133e-03],
                        [  3.75366211e-03,   2.25830078e-03],
                        [  9.27734375e-03,   7.96508789e-03],
                        [  1.61437988e-02,   1.50451660e-02],
                        [  2.34069824e-02,   2.26745605e-02],
                        [  3.21044922e-02,   3.17077637e-02],
                        [  4.11987305e-02,   4.11682129e-02],
                        [  4.57763672e-02,   4.60510254e-02],
                        [  4.47082520e-02,   4.52575684e-02],
                        [  4.24499512e-02,   4.32434082e-02],
                        [  4.12597656e-02,   4.21142578e-02],
                        [  3.96423340e-02,   4.05578613e-02],
                        [  3.59802246e-02,   3.68652344e-02],
                        [  2.97241211e-02,   3.05175781e-02],
                        [  2.19726562e-02,   2.26135254e-02],
                        [  1.32141113e-02,   1.37634277e-02],
                        [  3.66210938e-03,   4.08935547e-03],
                        [ -3.75366211e-03,  -3.44848633e-03],
                        [ -5.88989258e-03,  -5.64575195e-03],
                        [ -3.23486328e-03,  -3.02124023e-03],
                        [  1.28173828e-03,   1.46484375e-03],
                        [  4.39453125e-03,   4.51660156e-03],
                        [  4.45556641e-03,   4.54711914e-03],
                        [  1.89208984e-03,   1.86157227e-03],
                        [ -3.02124023e-03,  -3.20434570e-03],
                        [ -1.11999512e-02,  -1.15661621e-02],
                        [ -2.34069824e-02,  -2.40478516e-02],
                        [ -3.75671387e-02,  -3.84521484e-02],
                        [ -4.88281250e-02,  -4.99877930e-02],
                        [ -5.47180176e-02,  -5.60913086e-02],
                        [ -5.67932129e-02,  -5.83190918e-02],
                        [ -5.67016602e-02,  -5.82275391e-02],
                        [ -5.34362793e-02,  -5.48095703e-02],
                        [ -4.53796387e-02,  -4.64782715e-02],
                        [ -3.37829590e-02,  -3.44543457e-02],
                        [ -2.21557617e-02,  -2.22167969e-02],
                        [ -1.25122070e-02,  -1.18713379e-02],
                        [ -4.88281250e-03,  -3.57055664e-03],
                        [  1.12915039e-03,   3.08227539e-03],
                        [  6.71386719e-03,   9.24682617e-03],
                        [  1.21154785e-02,   1.49841309e-02],
                        [  1.34887695e-02,   1.64489746e-02],
                        [  6.65283203e-03,   9.46044922e-03],
                        [ -6.19506836e-03,  -3.81469727e-03],
                        [ -1.76696777e-02,  -1.60522461e-02],
                        [ -2.40173340e-02,  -2.33154297e-02],
                        [ -2.88085938e-02,  -2.91748047e-02],
                        [ -3.64074707e-02,  -3.79028320e-02],
                        [ -4.41284180e-02,  -4.66613770e-02],
                        [ -4.50134277e-02,  -4.84313965e-02],
                        [ -3.60107422e-02,  -4.00085449e-02],
                        [ -1.89514160e-02,  -2.31933594e-02],
                        [  3.90625000e-03,  -2.13623047e-04],
                        [  2.98461914e-02,   2.63366699e-02],
                        [  5.32226562e-02,   5.06286621e-02],
                        [  6.68640137e-02,   6.54602051e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  5.31005859e-02,   5.45349121e-02],
                        [  3.29589844e-02,   3.57666016e-02],
                        [  1.40991211e-02,   1.80358887e-02],
                        [  2.65502930e-03,   7.35473633e-03],
                        [ -6.10351562e-05,   5.00488281e-03],
                        [  3.02124023e-03,   7.93457031e-03],
                        [  9.73510742e-03,   1.40686035e-02],
                        [  2.35290527e-02,   2.68249512e-02],
                        [  4.90112305e-02,   5.09643555e-02],
                        [  8.32824707e-02,   8.36791992e-02],
                        [  1.16333008e-01,   1.15112305e-01],
                        [  1.38671875e-01,   1.35955811e-01],
                        [  1.44409180e-01,   1.40441895e-01],
                        [  1.26647949e-01,   1.21765137e-01],
                        [  7.54699707e-02,   7.02209473e-02],
                        [ -1.33666992e-02,  -1.85241699e-02],
                        [ -1.27349854e-01,  -1.31927490e-01],
                        [ -2.36511230e-01,  -2.40081787e-01],
                        [ -3.08471680e-01,  -3.10699463e-01],
                        [ -3.28826904e-01,  -3.29528809e-01],
                        [ -3.07983398e-01,  -3.07128906e-01],
                        [ -2.70355225e-01,  -2.68005371e-01],
                        [ -2.37304688e-01,  -2.33764648e-01],
                        [ -2.14721680e-01,  -2.10357666e-01],
                        [ -1.90063477e-01,  -1.85272217e-01],
                        [ -1.45385742e-01,  -1.40686035e-01],
                        [ -7.79418945e-02,  -7.37609863e-02],
                        [ -4.82177734e-03,  -1.52587891e-03],
                        [  5.39550781e-02,   5.61218262e-02],
                        [  9.11254883e-02,   9.19494629e-02],
                        [  1.11480713e-01,   1.10961914e-01],
                        [  1.23901367e-01,   1.22192383e-01],
                        [  1.34674072e-01,   1.31958008e-01],
                        [  1.44012451e-01,   1.40625000e-01],
                        [  1.46820068e-01,   1.43127441e-01],
                        [  1.37329102e-01,   1.33697510e-01],
                        [  1.15692139e-01,   1.12457275e-01],
                        [  8.93249512e-02,   8.67614746e-02],
                        [  6.57348633e-02,   6.39953613e-02],
                        [  4.40673828e-02,   4.33044434e-02],
                        [  1.87377930e-02,   1.88903809e-02],
                        [ -7.99560547e-03,  -7.01904297e-03],
                        [ -2.52685547e-02,  -2.36511230e-02],
                        [ -2.70996094e-02,  -2.50549316e-02],
                        [ -1.65405273e-02,  -1.43432617e-02],
                        [  5.18798828e-04,   2.68554688e-03],
                        [  1.87377930e-02,   2.06604004e-02],
                        [  3.48815918e-02,   3.64379883e-02],
                        [  4.87670898e-02,   4.98352051e-02],
                        [  6.15234375e-02,   6.21032715e-02],
                        [  7.28759766e-02,   7.30285645e-02],
                        [  7.94372559e-02,   7.92236328e-02],
                        [  7.81860352e-02,   7.76977539e-02],
                        [  7.02209473e-02,   6.95800781e-02],
                        [  5.85327148e-02,   5.78613281e-02],
                        [  4.51965332e-02,   4.45861816e-02],
                        [  2.93884277e-02,   2.88391113e-02],
                        [  9.55200195e-03,   9.09423828e-03],
                        [ -1.08337402e-02,  -1.11999512e-02],
                        [ -2.54211426e-02,  -2.57568359e-02],
                        [ -3.11279297e-02,  -3.14636230e-02],
                        [ -2.89916992e-02,  -2.93884277e-02],
                        [ -2.29492188e-02,  -2.34680176e-02],
                        [ -1.75170898e-02,  -1.81274414e-02],
                        [ -1.59301758e-02,  -1.66015625e-02],
                        [ -1.87072754e-02,  -1.94091797e-02],
                        [ -2.05993652e-02,  -2.12402344e-02],
                        [ -1.31530762e-02,  -1.36108398e-02],
                        [  7.35473633e-03,   7.11059570e-03],
                        [  3.51562500e-02,   3.52478027e-02],
                        [  5.91125488e-02,   5.95703125e-02],
                        [  7.34252930e-02,   7.42797852e-02],
                        [  7.82470703e-02,   7.94372559e-02],
                        [  7.32421875e-02,   7.46459961e-02],
                        [  6.14624023e-02,   6.29882812e-02],
                        [  4.92858887e-02,   5.07812500e-02],
                        [  3.84521484e-02,   3.97644043e-02],
                        [  2.68859863e-02,   2.78625488e-02],
                        [  1.31225586e-02,   1.36413574e-02],
                        [ -7.01904297e-04,  -7.32421875e-04],
                        [ -1.11083984e-02,  -1.16577148e-02],
                        [ -1.96533203e-02,  -2.06909180e-02],
                        [ -2.70080566e-02,  -2.84118652e-02],
                        [ -2.85644531e-02,  -3.02124023e-02],
                        [ -2.29187012e-02,  -2.46582031e-02],
                        [ -1.34277344e-02,  -1.50451660e-02],
                        [ -5.67626953e-03,  -7.04956055e-03],
                        [ -5.46264648e-03,  -6.40869141e-03],
                        [ -1.21154785e-02,  -1.25732422e-02],
                        [ -2.13012695e-02,  -2.12097168e-02],
                        [ -2.96325684e-02,  -2.91137695e-02],
                        [ -3.37829590e-02,  -3.28674316e-02],
                        [ -3.52478027e-02,  -3.40881348e-02],
                        [ -3.88793945e-02,  -3.75671387e-02],
                        [ -4.19921875e-02,  -4.07409668e-02],
                        [ -3.79638672e-02,  -3.69262695e-02],
                        [ -2.72827148e-02,  -2.65502930e-02],
                        [ -1.70898438e-02,  -1.66625977e-02],
                        [ -1.28479004e-02,  -1.27868652e-02],
                        [ -1.44348145e-02,  -1.46789551e-02],
                        [ -1.92260742e-02,  -1.96533203e-02],
                        [ -2.31628418e-02,  -2.36816406e-02],
                        [ -2.04772949e-02,  -2.09655762e-02],
                        [ -1.01928711e-02,  -1.05285645e-02],
                        [  7.01904297e-04,   5.49316406e-04],
                        [  4.94384766e-03,   5.03540039e-03],
                        [  3.66210938e-03,   3.96728516e-03],
                        [  3.50952148e-03,   3.96728516e-03],
                        [  7.84301758e-03,   8.33129883e-03],
                        [  1.52893066e-02,   1.56860352e-02],
                        [  2.29492188e-02,   2.31323242e-02],
                        [  2.63366699e-02,   2.61535645e-02],
                        [  2.16979980e-02,   2.11181641e-02],
                        [  1.20239258e-02,   1.10473633e-02],
                        [  5.61523438e-03,   4.30297852e-03],
                        [  7.38525391e-03,   5.82885742e-03],
                        [  1.36108398e-02,   1.20239258e-02],
                        [  1.74865723e-02,   1.61132812e-02],
                        [  1.66320801e-02,   1.56555176e-02],
                        [  1.33666992e-02,   1.29394531e-02],
                        [  1.21765137e-02,   1.25122070e-02],
                        [  1.68762207e-02,   1.80053711e-02],
                        [  2.71301270e-02,   2.90222168e-02],
                        [  4.01611328e-02,   4.26635742e-02],
                        [  5.71289062e-02,   6.00280762e-02],
                        [  8.21533203e-02,   8.51440430e-02],
                        [  1.13525391e-01,   1.16271973e-01],
                        [  1.41510010e-01,   1.43676758e-01],
                        [  1.53045654e-01,   1.54327393e-01],
                        [  1.31988525e-01,   1.32141113e-01],
                        [  6.34460449e-02,   6.24084473e-02],
                        [ -4.99572754e-02,  -5.21545410e-02],
                        [ -1.79962158e-01,  -1.83197021e-01],
                        [ -2.86132812e-01,  -2.90069580e-01],
                        [ -3.38989258e-01,  -3.43231201e-01],
                        [ -3.35083008e-01,  -3.39202881e-01],
                        [ -2.96325684e-01,  -2.99865723e-01],
                        [ -2.53326416e-01,  -2.55798340e-01],
                        [ -2.20825195e-01,  -2.21954346e-01],
                        [ -1.89819336e-01,  -1.89422607e-01],
                        [ -1.43463135e-01,  -1.41540527e-01],
                        [ -7.67211914e-02,  -7.33947754e-02],
                        [ -2.34985352e-03,   2.04467773e-03],
                        [  5.95397949e-02,   6.45446777e-02],
                        [  9.61608887e-02,   1.01287842e-01],
                        [  1.07269287e-01,   1.11938477e-01],
                        [  1.03210449e-01,   1.06872559e-01],
                        [  9.83581543e-02,   1.00616455e-01],
                        [  9.94567871e-02,   1.00067139e-01],
                        [  1.01867676e-01,   1.00708008e-01],
                        [  9.94873047e-02,   9.66491699e-02],
                        [  9.26513672e-02,   8.84094238e-02],
                        [  8.43811035e-02,   7.92236328e-02],
                        [  7.34558105e-02,   6.79321289e-02],
                        [  5.70373535e-02,   5.17272949e-02],
                        [  3.72009277e-02,   3.27148438e-02],
                        [  1.93786621e-02,   1.62048340e-02],
                        [  7.01904297e-03,   5.49316406e-03],
                        [  1.95312500e-03,   2.25830078e-03],
                        [  6.68334961e-03,   8.75854492e-03],
                        [  2.11791992e-02,   2.48107910e-02],
                        [  3.92150879e-02,   4.39758301e-02],
                        [  5.29479980e-02,   5.83190918e-02],
                        [  5.98449707e-02,   6.52160645e-02],
                        [  6.15539551e-02,   6.63452148e-02],
                        [  6.07910156e-02,   6.44226074e-02],
                        [  6.00585938e-02,   6.21948242e-02],
                        [  5.90209961e-02,   5.94177246e-02],
                        [  5.27343750e-02,   5.13916016e-02],
                        [  3.58276367e-02,   3.29284668e-02],
                        [  1.03454590e-02,   6.25610352e-03],
                        [ -1.35803223e-02,  -1.84020996e-02],
                        [ -2.69165039e-02,  -3.18603516e-02],
                        [ -2.89306641e-02,  -3.34472656e-02],
                        [ -2.63671875e-02,  -2.99377441e-02],
                        [ -2.64282227e-02,  -2.87170410e-02],
                        [ -3.02124023e-02,  -3.09448242e-02],
                        [ -3.21960449e-02,  -3.13415527e-02],
                        [ -2.72827148e-02,  -2.50244141e-02],
                        [ -1.75476074e-02,  -1.41906738e-02],
                        [ -8.81958008e-03,  -4.79125977e-03],
                        [ -3.63159180e-03,   6.10351562e-04],
                        [ -1.64794922e-03,   2.25830078e-03],
                        [  1.15966797e-03,   4.24194336e-03],
                        [  1.25732422e-02,   1.45568848e-02],
                        [  3.22570801e-02,   3.29284668e-02],
                        [  4.76379395e-02,   4.69970703e-02],
                        [  4.97436523e-02,   4.78820801e-02],
                        [  4.29992676e-02,   4.02221680e-02],
                        [  3.75061035e-02,   3.41796875e-02],
                        [  3.77197266e-02,   3.43322754e-02],
                        [  4.15954590e-02,   3.85437012e-02],
                        [  4.50439453e-02,   4.27246094e-02],
                        [  4.38537598e-02,   4.24804688e-02],
                        [  3.64379883e-02,   3.61938477e-02],
                        [  2.51770020e-02,   2.60009766e-02],
                        [  1.30615234e-02,   1.48315430e-02],
                        [  3.11279297e-03,   5.49316406e-03],
                        [ -3.44848633e-03,  -7.62939453e-04],
                        [ -8.27026367e-03,  -5.67626953e-03],
                        [ -1.23901367e-02,  -1.02539062e-02],
                        [ -1.44348145e-02,  -1.30310059e-02],
                        [ -1.20544434e-02,  -1.15051270e-02],
                        [ -6.71386719e-03,  -7.11059570e-03],
                        [ -4.88281250e-03,  -6.16455078e-03],
                        [ -8.91113281e-03,  -1.07727051e-02],
                        [ -1.51367188e-02,  -1.73645020e-02],
                        [ -2.12707520e-02,  -2.34985352e-02],
                        [ -2.57873535e-02,  -2.76489258e-02],
                        [ -2.74047852e-02,  -2.86560059e-02],
                        [ -2.54821777e-02,  -2.59094238e-02],
                        [ -2.02331543e-02,  -1.97753906e-02],
                        [ -1.70288086e-02,  -1.57775879e-02],
                        [ -2.03857422e-02,  -1.84936523e-02],
                        [ -2.65197754e-02,  -2.42614746e-02],
                        [ -3.10363770e-02,  -2.87475586e-02],
                        [ -3.24096680e-02,  -3.04565430e-02],
                        [ -2.85949707e-02,  -2.73132324e-02],
                        [ -1.92871094e-02,  -1.88598633e-02],
                        [ -8.81958008e-03,  -9.36889648e-03],
                        [ -5.00488281e-03,  -6.50024414e-03],
                        [ -1.05895996e-02,  -1.28479004e-02],
                        [ -1.91650391e-02,  -2.19116211e-02],
                        [ -2.55126953e-02,  -2.83508301e-02],
                        [ -2.96630859e-02,  -3.21960449e-02],
                        [ -3.04565430e-02,  -3.23486328e-02],
                        [ -2.59704590e-02,  -2.68554688e-02],
                        [ -1.67236328e-02,  -1.64489746e-02],
                        [ -6.68334961e-03,  -5.18798828e-03],
                        [ -3.35693359e-04,   2.22778320e-03],
                        [  2.56347656e-03,   5.92041016e-03],
                        [  5.34057617e-03,   9.06372070e-03],
                        [  1.01623535e-02,   1.38244629e-02],
                        [  1.81884766e-02,   2.12707520e-02],
                        [  2.81372070e-02,   3.02124023e-02],
                        [  3.51867676e-02,   3.59191895e-02],
                        [  3.45458984e-02,   3.38134766e-02],
                        [  2.70385742e-02,   2.47497559e-02],
                        [  1.87683105e-02,   1.51977539e-02],
                        [  1.44958496e-02,   1.00402832e-02],
                        [  1.43127441e-02,   9.42993164e-03],
                        [  1.68762207e-02,   1.22070312e-02],
                        [  2.24914551e-02,   1.85546875e-02],
                        [  3.39660645e-02,   3.13415527e-02],
                        [  5.49621582e-02,   5.39855957e-02],
                        [  8.52966309e-02,   8.61816406e-02],
                        [  1.17523193e-01,   1.20208740e-01],
                        [  1.38305664e-01,   1.42578125e-01],
                        [  1.34979248e-01,   1.40411377e-01],
                        [  9.85412598e-02,   1.04492188e-01],
                        [  2.34985352e-02,   2.93273926e-02],
                        [ -8.41369629e-02,  -7.91625977e-02],
                        [ -2.00012207e-01,  -1.96441650e-01],
                        [ -2.90069580e-01,  -2.88421631e-01],
                        [ -3.30322266e-01,  -3.30810547e-01],
                        [ -3.19976807e-01,  -3.22631836e-01],
                        [ -2.76153564e-01,  -2.80700684e-01],
                        [ -2.20397949e-01,  -2.26348877e-01],
                        [ -1.71356201e-01,  -1.78131104e-01],
                        [ -1.36932373e-01,  -1.43737793e-01],
                        [ -1.07391357e-01,  -1.13464355e-01],
                        [ -6.71081543e-02,  -7.17773438e-02],
                        [ -1.50146484e-02,  -1.77001953e-02],
                        [  3.31420898e-02,   3.27758789e-02],
                        [  6.20117188e-02,   6.39953613e-02],
                        [  6.97326660e-02,   7.38830566e-02],
                        [  6.56433105e-02,   7.15026855e-02],
                        [  6.27441406e-02,   6.97021484e-02],
                        [  6.99157715e-02,   7.72399902e-02],
                        [  8.46252441e-02,   9.14916992e-02],
                        [  9.58251953e-02,   1.01470947e-01],
                        [  9.61608887e-02,   9.99755859e-02],
                        [  8.79821777e-02,   8.95690918e-02],
                        [  7.71484375e-02,   7.63549805e-02],
                        [  6.54602051e-02,   6.23474121e-02],
                        [  5.20935059e-02,   4.70581055e-02],
                        [  3.87268066e-02,   3.23181152e-02],
                        [  2.99987793e-02,   2.29187012e-02],
                        [  2.99377441e-02,   2.29797363e-02],
                        [  3.82080078e-02,   3.20739746e-02],
                        [  4.96520996e-02,   4.50134277e-02],
                        [  5.92956543e-02,   5.65795898e-02],
                        [  6.60400391e-02,   6.55212402e-02],
                        [  7.12280273e-02,   7.28454590e-02],
                        [  7.47070312e-02,   7.82775879e-02],
                        [  7.36083984e-02,   7.86743164e-02],
                        [  6.43310547e-02,   7.02819824e-02],
                        [  4.62036133e-02,   5.23986816e-02],
                        [  2.18505859e-02,   2.76184082e-02],
                        [ -5.18798828e-03,  -4.27246094e-04],
                        [ -2.93884277e-02,  -2.61230469e-02],
                        [ -4.35485840e-02,  -4.19921875e-02],
                        [ -4.51660156e-02,  -4.54101562e-02],
                        [ -4.05578613e-02,  -4.24499512e-02],
                        [ -3.83605957e-02,  -4.16259766e-02],
                        [ -4.04052734e-02,  -4.45556641e-02],
                        [ -4.19006348e-02,  -4.64477539e-02],
                        [ -3.91845703e-02,  -4.36096191e-02],
                        [ -3.10058594e-02,  -3.48510742e-02],
                        [ -1.64184570e-02,  -1.93481445e-02],
                        [  7.01904297e-04,  -1.06811523e-03],
                        [  1.24511719e-02,   1.19323730e-02],
                        [  1.68457031e-02,   1.74865723e-02],
                        [  2.00195312e-02,   2.16064453e-02],
                        [  2.77099609e-02,   2.99377441e-02],
                        [  3.95812988e-02,   4.20837402e-02],
                        [  5.24902344e-02,   5.49926758e-02],
                        [  6.47277832e-02,   6.68640137e-02],
                        [  7.34252930e-02,   7.50122070e-02],
                        [  7.41577148e-02,   7.51342773e-02],
                        [  6.63757324e-02,   6.66809082e-02],
                        [  5.43212891e-02,   5.40771484e-02],
                        [  4.17480469e-02,   4.11071777e-02],
                        [  2.94189453e-02,   2.86254883e-02],
                        [  1.82189941e-02,   1.74560547e-02],
                        [  1.12304688e-02,   1.07116699e-02],
                        [  9.27734375e-03,   9.12475586e-03],
                        [  7.32421875e-03,   7.56835938e-03],
                        [ -1.52587891e-04,   4.57763672e-04],
                        [ -1.11389160e-02,  -1.03149414e-02],
                        [ -1.74560547e-02,  -1.65710449e-02],
                        [ -1.57165527e-02,  -1.49841309e-02],
                        [ -1.08032227e-02,  -1.04064941e-02],
                        [ -7.26318359e-03,  -7.38525391e-03],
                        [ -6.83593750e-03,  -7.56835938e-03],
                        [ -1.08947754e-02,  -1.22375488e-02],
                        [ -1.81579590e-02,  -2.00195312e-02],
                        [ -2.39868164e-02,  -2.62145996e-02],
                        [ -2.52990723e-02,  -2.76184082e-02],
                        [ -2.42614746e-02,  -2.63977051e-02],
                        [ -2.52990723e-02,  -2.70080566e-02],
                        [ -2.85644531e-02,  -2.95715332e-02],
                        [ -3.13720703e-02,  -3.14941406e-02],
                        [ -3.32641602e-02,  -3.24401855e-02],
                        [ -3.42407227e-02,  -3.24707031e-02],
                        [ -3.37219238e-02,  -3.12194824e-02],
                        [ -3.28979492e-02,  -2.98767090e-02],
                        [ -3.34472656e-02,  -3.01818848e-02],
                        [ -3.50952148e-02,  -3.19519043e-02],
                        [ -3.52783203e-02,  -3.25927734e-02],
                        [ -3.25012207e-02,  -3.05175781e-02],
                        [ -2.75878906e-02,  -2.65502930e-02],
                        [ -2.09960938e-02,  -2.09655762e-02],
                        [ -1.26953125e-02,  -1.37023926e-02],
                        [ -4.42504883e-03,  -6.31713867e-03],
                        [  1.77001953e-03,  -7.93457031e-04],
                        [  4.54711914e-03,   1.58691406e-03],
                        [  4.02832031e-03,   9.76562500e-04],
                        [  2.04467773e-03,  -7.93457031e-04],
                        [  5.18798828e-04,  -1.86157227e-03],
                        [ -1.22070312e-04,  -1.83105469e-03],
                        [ -1.52587891e-04,  -1.09863281e-03],
                        [  2.44140625e-04,   6.10351562e-05],
                        [  1.34277344e-03,   1.80053711e-03],
                        [  3.32641602e-03,   4.30297852e-03],
                        [  6.71386719e-03,   8.02612305e-03],
                        [  1.19628906e-02,   1.34277344e-02],
                        [  1.80358887e-02,   1.94702148e-02],
                        [  2.38952637e-02,   2.51770020e-02],
                        [  3.03039551e-02,   3.13720703e-02],
                        [  3.80554199e-02,   3.89099121e-02],
                        [  4.61730957e-02,   4.69055176e-02],
                        [  5.42297363e-02,   5.49316406e-02],
                        [  6.30798340e-02,   6.38427734e-02],
                        [  7.22961426e-02,   7.32421875e-02],
                        [  8.04138184e-02,   8.16040039e-02],
                        [  8.91723633e-02,   9.05456543e-02],
                        [  1.00402832e-01,   1.01867676e-01],
                        [  1.06201172e-01,   1.07604980e-01],
                        [  8.81958008e-02,   8.92944336e-02],
                        [  3.03955078e-02,   3.09143066e-02],
                        [ -6.69250488e-02,  -6.72302246e-02],
                        [ -1.84020996e-01,  -1.85333252e-01],
                        [ -2.87445068e-01,  -2.89886475e-01],
                        [ -3.43109131e-01,  -3.46679688e-01],
                        [ -3.38012695e-01,  -3.42498779e-01],
                        [ -2.91259766e-01,  -2.96356201e-01],
                        [ -2.36663818e-01,  -2.41882324e-01],
                        [ -1.95312500e-01,  -2.00164795e-01],
                        [ -1.64642334e-01,  -1.68487549e-01],
                        [ -1.28540039e-01,  -1.30889893e-01],
                        [ -7.55615234e-02,  -7.58972168e-02],
                        [ -9.30786133e-03,  -7.41577148e-03],
                        [  5.27343750e-02,   5.69152832e-02],
                        [  9.22241211e-02,   9.85717773e-02],
                        [  1.05041504e-01,   1.13067627e-01],
                        [  1.02416992e-01,   1.11419678e-01],
                        [  9.95483398e-02,   1.08795166e-01],
                        [  1.04461670e-01,   1.12945557e-01],
                        [  1.13647461e-01,   1.20452881e-01],
                        [  1.18194580e-01,   1.22528076e-01],
                        [  1.12243652e-01,   1.13525391e-01],
                        [  9.48486328e-02,   9.27124023e-02],
                        [  6.90002441e-02,   6.34155273e-02],
                        [  4.11071777e-02,   3.24707031e-02],
                        [  1.75781250e-02,   6.56127930e-03],
                        [  2.01416016e-03,  -1.04064941e-02],
                        [ -3.35693359e-03,  -1.60217285e-02],
                        [  2.28881836e-03,  -9.36889648e-03],
                        [  1.51367188e-02,   5.61523438e-03],
                        [  2.88085938e-02,   2.24914551e-02],
                        [  4.15039062e-02,   3.91235352e-02],
                        [  5.46264648e-02,   5.65185547e-02],
                        [  6.72912598e-02,   7.34252930e-02],
                        [  7.73925781e-02,   8.73107910e-02],
                        [  8.17871094e-02,   9.46044922e-02],
                        [  7.51953125e-02,   8.96911621e-02],
                        [  5.61523438e-02,   7.10144043e-02],
                        [  3.09143066e-02,   4.47387695e-02],
                        [  6.68334961e-03,   1.80664062e-02],
                        [ -1.44348145e-02,  -6.56127930e-03],
                        [ -3.09143066e-02,  -2.73437500e-02],
                        [ -3.83911133e-02,  -3.95202637e-02],
                        [ -3.57971191e-02,  -4.15039062e-02],
                        [ -2.94189453e-02,  -3.91845703e-02],
                        [ -2.66113281e-02,  -3.94897461e-02],
                        [ -2.85644531e-02,  -4.33654785e-02],
                        [ -2.97241211e-02,  -4.50134277e-02],
                        [ -2.23083496e-02,  -3.66210938e-02],
                        [ -4.79125977e-03,  -1.68457031e-02],
                        [  1.60522461e-02,   7.41577148e-03],
                        [  3.24707031e-02,   2.79541016e-02],
                        [  3.97644043e-02,   3.97338867e-02],
                        [  3.72314453e-02,   4.15954590e-02],
                        [  2.96020508e-02,   3.78417969e-02],
                        [  2.39868164e-02,   3.52172852e-02],
                        [  2.38342285e-02,   3.68957520e-02],
                        [  2.70080566e-02,   4.07104492e-02],
                        [  2.85949707e-02,   4.15954590e-02],
                        [  2.63977051e-02,   3.75366211e-02],
                        [  2.33764648e-02,   3.17382812e-02],
                        [  2.30712891e-02,   2.80456543e-02],
                        [  2.52990723e-02,   2.65197754e-02],
                        [  2.84423828e-02,   2.60925293e-02],
                        [  3.24401855e-02,   2.69165039e-02],
                        [  3.60107422e-02,   2.79541016e-02],
                        [  3.50952148e-02,   2.54211426e-02],
                        [  2.79235840e-02,   1.76696777e-02],
                        [  1.79138184e-02,   7.99560547e-03],
                        [  9.18579102e-03,   3.96728516e-04],
                        [  3.11279297e-03,  -3.78417969e-03],
                        [ -8.23974609e-04,  -5.40161133e-03],
                        [ -4.73022461e-03,  -6.89697266e-03],
                        [ -1.00708008e-02,  -9.82666016e-03],
                        [ -1.58386230e-02,  -1.34582520e-02],
                        [ -2.14233398e-02,  -1.74560547e-02],
                        [ -2.75878906e-02,  -2.25219727e-02],
                        [ -3.39965820e-02,  -2.83508301e-02],
                        [ -3.83911133e-02,  -3.28063965e-02],
                        [ -3.68957520e-02,  -3.17687988e-02],
                        [ -2.61535645e-02,  -2.17895508e-02],
                        [ -9.94873047e-03,  -6.53076172e-03],
                        [  1.80053711e-03,   4.18090820e-03],
                        [  4.18090820e-03,   5.61523438e-03],
                        [  4.57763672e-04,   1.12915039e-03],
                        [ -6.77490234e-03,  -6.68334961e-03],
                        [ -1.69982910e-02,  -1.73034668e-02],
                        [ -2.62756348e-02,  -2.68249512e-02],
                        [ -3.08837891e-02,  -3.15856934e-02],
                        [ -3.36608887e-02,  -3.45153809e-02],
                        [ -3.87268066e-02,  -3.97644043e-02],
                        [ -4.24499512e-02,  -4.37622070e-02],
                        [ -3.95812988e-02,  -4.13208008e-02],
                        [ -3.28369141e-02,  -3.50646973e-02],
                        [ -2.71301270e-02,  -2.98767090e-02],
                        [ -2.19116211e-02,  -2.52075195e-02],
                        [ -1.56250000e-02,  -1.93481445e-02],
                        [ -8.08715820e-03,  -1.19934082e-02],
                        [  2.01416016e-03,  -1.80053711e-03],
                        [  1.30004883e-02,   9.64355469e-03],
                        [  1.88293457e-02,   1.62963867e-02],
                        [  1.71203613e-02,   1.58081055e-02],
                        [  1.38549805e-02,   1.39770508e-02],
                        [  1.62048340e-02,   1.79748535e-02],
                        [  2.34375000e-02,   2.68554688e-02],
                        [  2.85034180e-02,   3.34167480e-02],
                        [  2.74658203e-02,   3.35998535e-02],
                        [  2.19726562e-02,   2.88391113e-02],
                        [  1.46179199e-02,   2.16674805e-02],
                        [  8.11767578e-03,   1.47705078e-02],
                        [  5.67626953e-03,   1.13220215e-02],
                        [  9.61303711e-03,   1.36718750e-02],
                        [  2.09045410e-02,   2.30102539e-02],
                        [  3.94897461e-02,   3.93981934e-02],
                        [  6.35070801e-02,   6.10961914e-02],
                        [  8.99963379e-02,   8.54187012e-02],
                        [  1.15051270e-01,   1.08703613e-01],
                        [  1.30889893e-01,   1.23199463e-01],
                        [  1.25732422e-01,   1.17340088e-01],
                        [  9.12780762e-02,   8.28857422e-02],
                        [  2.63366699e-02,   1.86157227e-02],
                        [ -6.54296875e-02,  -7.18688965e-02],
                        [ -1.71722412e-01,  -1.76361084e-01],
                        [ -2.66479492e-01,  -2.68920898e-01],
                        [ -3.19763184e-01,  -3.19854736e-01],
                        [ -3.19824219e-01,  -3.17565918e-01],
                        [ -2.82928467e-01,  -2.78533936e-01],
                        [ -2.38616943e-01,  -2.32452393e-01],
                        [ -2.05383301e-01,  -1.97875977e-01],
                        [ -1.79870605e-01,  -1.71630859e-01],
                        [ -1.45568848e-01,  -1.37237549e-01],
                        [ -9.06982422e-02,  -8.27941895e-02],
                        [ -2.15759277e-02,  -1.47094727e-02],
                        [  4.08325195e-02,   4.62036133e-02],
                        [  8.01086426e-02,   8.36791992e-02],
                        [  9.71374512e-02,   9.86633301e-02],
                        [  1.02386475e-01,   1.01776123e-01],
                        [  1.03515625e-01,   1.00830078e-01],
                        [  1.04431152e-01,   9.98840332e-02],
                        [  1.07391357e-01,   1.01257324e-01],
                        [  1.08947754e-01,   1.01562500e-01],
                        [  1.01654053e-01,   9.35363770e-02],
                        [  8.34350586e-02,   7.50732422e-02],
                        [  6.01196289e-02,   5.20324707e-02],
                        [  4.01916504e-02,   3.28979492e-02],
                        [  2.75878906e-02,   2.16674805e-02],
                        [  2.03552246e-02,   1.61437988e-02],
                        [  1.72424316e-02,   1.51062012e-02],
                        [  2.14538574e-02,   2.16674805e-02],
                        [  3.30200195e-02,   3.56445312e-02],
                        [  4.41589355e-02,   4.91333008e-02],
                        [  4.94079590e-02,   5.65185547e-02],
                        [  5.33142090e-02,   6.21337891e-02],
                        [  6.07299805e-02,   7.06787109e-02],
                        [  6.72912598e-02,   7.77282715e-02],
                        [  6.52770996e-02,   7.54394531e-02],
                        [  5.22460938e-02,   6.12792969e-02],
                        [  3.10363770e-02,   3.82080078e-02],
                        [  8.30078125e-03,   1.29394531e-02],
                        [ -8.94165039e-03,  -7.32421875e-03],
                        [ -1.79138184e-02,  -1.96228027e-02],
                        [ -2.09960938e-02,  -2.60620117e-02],
                        [ -2.21862793e-02,  -3.03344727e-02],
                        [ -2.40783691e-02,  -3.47290039e-02],
                        [ -2.67944336e-02,  -3.92150879e-02],
                        [ -2.79846191e-02,  -4.11682129e-02],
                        [ -2.34680176e-02,  -3.63159180e-02],
                        [ -1.21459961e-02,  -2.35290527e-02],
                        [  1.55639648e-03,  -7.35473633e-03],
                        [  1.35803223e-02,   8.02612305e-03],
                        [  2.34985352e-02,   2.18505859e-02],
                        [  3.08532715e-02,   3.33862305e-02],
                        [  3.47595215e-02,   4.13208008e-02],
                        [  3.44543457e-02,   4.45556641e-02],
                        [  2.95410156e-02,   4.23583984e-02],
                        [  2.30712891e-02,   3.75061035e-02],
                        [  2.08129883e-02,   3.55834961e-02],
                        [  2.42614746e-02,   3.80859375e-02],
                        [  2.75268555e-02,   3.91235352e-02],
                        [  2.49938965e-02,   3.33251953e-02],
                        [  2.13317871e-02,   2.56347656e-02],
                        [  2.62451172e-02,   2.61535645e-02],
                        [  3.84521484e-02,   3.39355469e-02],
                        [  4.66308594e-02,   3.81774902e-02],
                        [  4.58374023e-02,   3.42407227e-02],
                        [  4.05883789e-02,   2.69165039e-02],
                        [  3.53088379e-02,   2.08129883e-02],
                        [  3.05480957e-02,   1.66015625e-02],
                        [  2.47802734e-02,   1.26342773e-02],
                        [  1.60522461e-02,   6.74438477e-03],
                        [  5.43212891e-03,  -2.13623047e-04],
                        [ -2.65502930e-03,  -4.24194336e-03],
                        [ -6.71386719e-03,  -4.27246094e-03],
                        [ -1.07116699e-02,  -4.60815430e-03],
                        [ -1.77917480e-02,  -8.66699219e-03],
                        [ -2.61840820e-02,  -1.50756836e-02],
                        [ -3.28369141e-02,  -2.08740234e-02],
                        [ -3.58886719e-02,  -2.41699219e-02],
                        [ -3.45764160e-02,  -2.42004395e-02],
                        [ -2.97546387e-02,  -2.16064453e-02],
                        [ -2.38342285e-02,  -1.85241699e-02],
                        [ -2.00805664e-02,  -1.78833008e-02],
                        [ -2.06298828e-02,  -2.15454102e-02],
                        [ -2.52380371e-02,  -2.89001465e-02],
                        [ -3.10058594e-02,  -3.68347168e-02],
                        [ -3.29589844e-02,  -4.02221680e-02],
                        [ -2.74047852e-02,  -3.52478027e-02],
                        [ -1.56250000e-02,  -2.31933594e-02],
                        [ -2.62451172e-03,  -9.27734375e-03],
                        [  5.00488281e-03,  -1.83105469e-04],
                        [  2.74658203e-03,  -6.40869141e-04],
                        [ -6.34765625e-03,  -7.87353516e-03],
                        [ -1.32446289e-02,  -1.30920410e-02],
                        [ -1.33666992e-02,  -1.18408203e-02],
                        [ -1.05590820e-02,  -8.08715820e-03],
                        [ -9.39941406e-03,  -6.50024414e-03],
                        [ -8.97216797e-03,  -6.13403320e-03],
                        [ -6.10351562e-03,  -3.66210938e-03],
                        [ -7.62939453e-04,   1.00708008e-03],
                        [  5.98144531e-03,   6.98852539e-03],
                        [  1.36108398e-02,   1.39465332e-02],
                        [  1.88903809e-02,   1.87683105e-02],
                        [  1.83105469e-02,   1.80358887e-02],
                        [  1.31530762e-02,   1.30615234e-02],
                        [  6.92749023e-03,   7.35473633e-03],
                        [  1.00708008e-03,   2.13623047e-03],
                        [ -3.84521484e-03,  -1.92260742e-03],
                        [ -4.82177734e-03,  -2.13623047e-03],
                        [ -7.01904297e-04,   2.53295898e-03],
                        [  5.37109375e-03,   8.75854492e-03],
                        [  1.21154785e-02,   1.52282715e-02],
                        [  2.32543945e-02,   2.55432129e-02],
                        [  4.08325195e-02,   4.19006348e-02],
                        [  6.27746582e-02,   6.22253418e-02],
                        [  8.58459473e-02,   8.34655762e-02],
                        [  1.07360840e-01,   1.03179932e-01],
                        [  1.25122070e-01,   1.19415283e-01],
                        [  1.35742188e-01,   1.28906250e-01],
                        [  1.31927490e-01,   1.24633789e-01],
                        [  1.02783203e-01,   9.57641602e-02],
                        [  3.85131836e-02,   3.24707031e-02],
                        [ -6.00585938e-02,  -6.44226074e-02],
                        [ -1.75384521e-01,  -1.77429199e-01],
                        [ -2.79144287e-01,  -2.78564453e-01],
                        [ -3.42407227e-01,  -3.39172363e-01],
                        [ -3.48114014e-01,  -3.42346191e-01],
                        [ -3.07586670e-01,  -2.99774170e-01],
                        [ -2.56835938e-01,  -2.47741699e-01],
                        [ -2.22869873e-01,  -2.13287354e-01],
                        [ -1.99188232e-01,  -1.90002441e-01],
                        [ -1.62811279e-01,  -1.55029297e-01],
                        [ -1.04492188e-01,  -9.89074707e-02],
                        [ -3.31115723e-02,  -3.02124023e-02],
                        [  3.58581543e-02,   3.57360840e-02],
                        [  8.66394043e-02,   8.34655762e-02],
                        [  1.11236572e-01,   1.05346680e-01],
                        [  1.17248535e-01,   1.09252930e-01],
                        [  1.18957520e-01,   1.09619141e-01],
                        [  1.22650146e-01,   1.12854004e-01],
                        [  1.25488281e-01,   1.16241455e-01],
                        [  1.22314453e-01,   1.14440918e-01],
                        [  1.10015869e-01,   1.04217529e-01],
                        [  8.98437500e-02,   8.66699219e-02],
                        [  6.74438477e-02,   6.70776367e-02],
                        [  4.78210449e-02,   5.01708984e-02],
                        [  3.03039551e-02,   3.50341797e-02],
                        [  1.34582520e-02,   2.00195312e-02],
                        [  2.80761719e-03,   1.04675293e-02],
                        [  5.40161133e-03,   1.33361816e-02],
                        [  1.99279785e-02,   2.73742676e-02],
                        [  3.89404297e-02,   4.52880859e-02],
                        [  5.74951172e-02,   6.21643066e-02],
                        [  7.40356445e-02,   7.67517090e-02],
                        [  8.51745605e-02,   8.58764648e-02],
                        [  8.46557617e-02,   8.34655762e-02],
                        [  6.88476562e-02,   6.60400391e-02],
                        [  4.07409668e-02,   3.68041992e-02],
                        [  8.94165039e-03,   4.39453125e-03],
                        [ -1.63879395e-02,  -2.10571289e-02],
                        [ -2.96325684e-02,  -3.39355469e-02],
                        [ -3.37219238e-02,  -3.72924805e-02],
                        [ -3.68347168e-02,  -3.94592285e-02],
                        [ -4.40063477e-02,  -4.56237793e-02],
                        [ -5.26733398e-02,  -5.33447266e-02],
                        [ -5.70373535e-02,  -5.69458008e-02],
                        [ -5.47485352e-02,  -5.41076660e-02],
                        [ -4.56237793e-02,  -4.47387695e-02],
                        [ -2.93884277e-02,  -2.84423828e-02],
                        [ -8.75854492e-03,  -7.96508789e-03],
                        [  9.39941406e-03,   9.91821289e-03],
                        [  2.15148926e-02,   2.18200684e-02],
                        [  3.19213867e-02,   3.20739746e-02],
                        [  4.39758301e-02,   4.41589355e-02],
                        [  5.33752441e-02,   5.37414551e-02],
                        [  5.62438965e-02,   5.70068359e-02],
                        [  5.63964844e-02,   5.76782227e-02],
                        [  5.66711426e-02,   5.85021973e-02],
                        [  5.32531738e-02,   5.55725098e-02],
                        [  4.34875488e-02,   4.62036133e-02],
                        [  3.19824219e-02,   3.48205566e-02],
                        [  2.48718262e-02,   2.74963379e-02],
                        [  2.38952637e-02,   2.59704590e-02],
                        [  2.71606445e-02,   2.83508301e-02],
                        [  3.07006836e-02,   3.07312012e-02],
                        [  2.92358398e-02,   2.79541016e-02],
                        [  2.07519531e-02,   1.81884766e-02],
                        [  9.24682617e-03,   5.49316406e-03],
                        [  7.62939453e-04,  -3.87573242e-03],
                        [ -1.25122070e-03,  -6.28662109e-03],
                        [  2.22778320e-03,  -2.77709961e-03],
                        [  6.68334961e-03,   2.22778320e-03],
                        [  8.30078125e-03,   4.91333008e-03],
                        [  5.18798828e-03,   3.23486328e-03],
                        [ -2.89916992e-03,  -3.17382812e-03],
                        [ -1.25122070e-02,  -1.10168457e-02],
                        [ -1.91345215e-02,  -1.59912109e-02],
                        [ -2.30102539e-02,  -1.84936523e-02],
                        [ -2.76184082e-02,  -2.21862793e-02],
                        [ -3.45764160e-02,  -2.87780762e-02],
                        [ -4.23889160e-02,  -3.68347168e-02],
                        [ -4.83398438e-02,  -4.35791016e-02],
                        [ -5.06896973e-02,  -4.71801758e-02],
                        [ -4.87060547e-02,  -4.68139648e-02],
                        [ -4.12902832e-02,  -4.11071777e-02],
                        [ -2.76794434e-02,  -2.92358398e-02],
                        [ -1.15966797e-02,  -1.46484375e-02],
                        [ -1.15966797e-03,  -5.34057617e-03],
                        [ -8.85009766e-04,  -5.70678711e-03],
                        [ -5.37109375e-03,  -1.02539062e-02],
                        [ -6.95800781e-03,  -1.14135742e-02],
                        [ -6.31713867e-03,  -9.91821289e-03],
                        [ -7.32421875e-03,  -9.70458984e-03],
                        [ -7.90405273e-03,  -8.91113281e-03],
                        [ -4.33349609e-03,  -3.93676758e-03],
                        [  8.23974609e-04,   2.41088867e-03],
                        [  1.80053711e-03,   4.30297852e-03],
                        [ -1.40380859e-03,   1.64794922e-03],
                        [ -2.77709961e-03,   3.66210938e-04],
                        [  9.76562500e-04,   3.81469727e-03],
                        [  5.46264648e-03,   7.59887695e-03],
                        [  4.02832031e-03,   5.31005859e-03],
                        [ -2.86865234e-03,  -2.53295898e-03],
                        [ -8.23974609e-03,  -8.81958008e-03],
                        [ -7.93457031e-03,  -9.21630859e-03],
                        [ -4.91333008e-03,  -6.62231445e-03],
                        [ -2.65502930e-03,  -4.45556641e-03],
                        [ -5.79833984e-04,  -2.13623047e-03],
                        [  2.68554688e-03,   1.67846680e-03],
                        [  6.74438477e-03,   6.46972656e-03],
                        [  1.19323730e-02,   1.24816895e-02],
                        [  1.95617676e-02,   2.09045410e-02],
                        [  3.01208496e-02,   3.20739746e-02],
                        [  4.41284180e-02,   4.63562012e-02],
                        [  6.30493164e-02,   6.52770996e-02],
                        [  8.68835449e-02,   8.87451172e-02],
                        [  1.11053467e-01,   1.12182617e-01],
                        [  1.28021240e-01,   1.28173828e-01],
                        [  1.31652832e-01,   1.30737305e-01],
                        [  1.18255615e-01,   1.16333008e-01],
                        [  8.38623047e-02,   8.10241699e-02],
                        [  2.40478516e-02,   2.06298828e-02],
                        [ -6.14624023e-02,  -6.51245117e-02],
                        [ -1.62719727e-01,  -1.66168213e-01],
                        [ -2.56988525e-01,  -2.59826660e-01],
                        [ -3.16864014e-01,  -3.18695068e-01],
                        [ -3.27331543e-01,  -3.27941895e-01],
                        [ -2.96630859e-01,  -2.95928955e-01],
                        [ -2.49877930e-01,  -2.47894287e-01],
                        [ -2.10693359e-01,  -2.07580566e-01],
                        [ -1.85089111e-01,  -1.81213379e-01],
                        [ -1.58874512e-01,  -1.54663086e-01],
                        [ -1.13891602e-01,  -1.09741211e-01],
                        [ -4.92248535e-02,  -4.56237793e-02],
                        [  1.73950195e-02,   2.01110840e-02],
                        [  7.03430176e-02,   7.18994141e-02],
                        [  1.06536865e-01,   1.06811523e-01],
                        [  1.26800537e-01,   1.25854492e-01],
                        [  1.31286621e-01,   1.29241943e-01],
                        [  1.25000000e-01,   1.22161865e-01],
                        [  1.16790771e-01,   1.13525391e-01],
                        [  1.09771729e-01,   1.06475830e-01],
                        [  9.91821289e-02,   9.61914062e-02],
                        [  8.18176270e-02,   7.94372559e-02],
                        [  6.23168945e-02,   6.06994629e-02],
                        [  4.67834473e-02,   4.60205078e-02],
                        [  3.51562500e-02,   3.51867676e-02],
                        [  2.42919922e-02,   2.49328613e-02],
                        [  1.49841309e-02,   1.60217285e-02],
                        [  1.25732422e-02,   1.37023926e-02],
                        [  2.09655762e-02,   2.19726562e-02],
                        [  3.92150879e-02,   3.98864746e-02],
                        [  6.17980957e-02,   6.20422363e-02],
                        [  8.02612305e-02,   8.00781250e-02],
                        [  8.59680176e-02,   8.54797363e-02],
                        [  7.55004883e-02,   7.49206543e-02],
                        [  5.29785156e-02,   5.25817871e-02],
                        [  2.59399414e-02,   2.60009766e-02],
                        [  1.19018555e-03,   1.95312500e-03],
                        [ -1.48010254e-02,  -1.32141113e-02],
                        [ -1.80969238e-02,  -1.56555176e-02],
                        [ -1.34887695e-02,  -1.02844238e-02],
                        [ -1.27258301e-02,  -9.06372070e-03],
                        [ -2.21862793e-02,  -1.84631348e-02],
                        [ -3.56445312e-02,  -3.23486328e-02],
                        [ -4.29077148e-02,  -4.05273438e-02],
                        [ -4.07409668e-02,  -3.97949219e-02],
                        [ -3.15856934e-02,  -3.23791504e-02],
                        [ -1.71203613e-02,  -1.98669434e-02],
                        [ -3.05175781e-04,  -4.97436523e-03],
                        [  1.40991211e-02,   7.78198242e-03],
                        [  2.57873535e-02,   1.83410645e-02],
                        [  3.69262695e-02,   2.90222168e-02],
                        [  4.50439453e-02,   3.74755859e-02],
                        [  4.68139648e-02,   4.04357910e-02],
                        [  4.49523926e-02,   4.05883789e-02],
                        [  4.40979004e-02,   4.23278809e-02],
                        [  4.45251465e-02,   4.58068848e-02],
                        [  4.39147949e-02,   4.83093262e-02],
                        [  4.14123535e-02,   4.87365723e-02],
                        [  3.69873047e-02,   4.66003418e-02],
                        [  2.97851562e-02,   4.09240723e-02],
                        [  2.19116211e-02,   3.35083008e-02],
                        [  1.76696777e-02,   2.85339355e-02],
                        [  1.67236328e-02,   2.57568359e-02],
                        [  1.49536133e-02,   2.11486816e-02],
                        [  1.22985840e-02,   1.49536133e-02],
                        [  1.36108398e-02,   1.22985840e-02],
                        [  2.05993652e-02,   1.53198242e-02],
                        [  2.81372070e-02,   1.92871094e-02],
                        [  3.03955078e-02,   1.87988281e-02],
                        [  2.69470215e-02,   1.36108398e-02],
                        [  2.03552246e-02,   6.62231445e-03],
                        [  1.21154785e-02,  -7.01904297e-04],
                        [  2.25830078e-03,  -8.39233398e-03],
                        [ -7.78198242e-03,  -1.51977539e-02],
                        [ -1.52587891e-02,  -1.86767578e-02],
                        [ -2.14538574e-02,  -2.05078125e-02],
                        [ -3.03039551e-02,  -2.51159668e-02],
                        [ -3.90014648e-02,  -3.00598145e-02],
                        [ -4.06799316e-02,  -2.89001465e-02],
                        [ -3.70788574e-02,  -2.35900879e-02],
                        [ -3.57360840e-02,  -2.18811035e-02],
                        [ -3.66210938e-02,  -2.37121582e-02],
                        [ -3.29284668e-02,  -2.21557617e-02],
                        [ -2.48718262e-02,  -1.72729492e-02],
                        [ -2.04467773e-02,  -1.66931152e-02],
                        [ -2.08435059e-02,  -2.11181641e-02],
                        [ -1.98364258e-02,  -2.40478516e-02],
                        [ -1.69067383e-02,  -2.45056152e-02],
                        [ -1.52587891e-02,  -2.53295898e-02],
                        [ -1.30310059e-02,  -2.45971680e-02],
                        [ -8.51440430e-03,  -2.03857422e-02],
                        [ -4.66918945e-03,  -1.56860352e-02],
                        [ -3.38745117e-03,  -1.25427246e-02],
                        [ -2.38037109e-03,  -8.97216797e-03],
                        [  8.23974609e-04,  -2.68554688e-03],
                        [  5.58471680e-03,   5.27954102e-03],
                        [  1.01318359e-02,   1.27868652e-02],
                        [  1.40686035e-02,   1.91955566e-02],
                        [  1.68151855e-02,   2.37426758e-02],
                        [  1.62353516e-02,   2.41699219e-02],
                        [  1.16882324e-02,   1.97143555e-02],
                        [  5.95092773e-03,   1.33361816e-02],
                        [  1.70898438e-03,   7.78198242e-03],
                        [ -2.25830078e-03,   2.13623047e-03],
                        [ -6.46972656e-03,  -4.02832031e-03],
                        [ -7.62939453e-03,  -7.04956055e-03],
                        [ -4.36401367e-03,  -5.43212891e-03],
                        [ -1.31225586e-03,  -3.63159180e-03],
                        [ -5.18798828e-04,  -3.66210938e-03],
                        [  4.66918945e-03,   1.28173828e-03],
                        [  2.07519531e-02,   1.75170898e-02],
                        [  4.23278809e-02,   3.95812988e-02],
                        [  5.89294434e-02,   5.68847656e-02],
                        [  7.13500977e-02,   7.00988770e-02],
                        [  8.88061523e-02,   8.81958008e-02],
                        [  1.11968994e-01,   1.11816406e-01],
                        [  1.30920410e-01,   1.30920410e-01],
                        [  1.35284424e-01,   1.35192871e-01],
                        [  1.16912842e-01,   1.16455078e-01],
                        [  6.63452148e-02,   6.53686523e-02],
                        [ -2.16064453e-02,  -2.31018066e-02],
                        [ -1.35467529e-01,  -1.37481689e-01],
                        [ -2.46002197e-01,  -2.48260498e-01],
                        [ -3.19213867e-01,  -3.21411133e-01],
                        [ -3.33496094e-01,  -3.35266113e-01],
                        [ -2.94464111e-01,  -2.95440674e-01],
                        [ -2.36114502e-01,  -2.35961914e-01],
                        [ -1.96624756e-01,  -1.95129395e-01],
                        [ -1.85516357e-01,  -1.82647705e-01],
                        [ -1.77825928e-01,  -1.73614502e-01],
                        [ -1.44409180e-01,  -1.39160156e-01],
                        [ -8.32519531e-02,  -7.73925781e-02],
                        [ -1.38549805e-02,  -7.93457031e-03],
                        [  4.71496582e-02,   5.26123047e-02],
                        [  9.26818848e-02,   9.70458984e-02],
                        [  1.19750977e-01,   1.22528076e-01],
                        [  1.28692627e-01,   1.29516602e-01],
                        [  1.23840332e-01,   1.22467041e-01],
                        [  1.12854004e-01,   1.09283447e-01],
                        [  1.04003906e-01,   9.85107422e-02],
                        [  9.95788574e-02,   9.25292969e-02],
                        [  9.43603516e-02,   8.63037109e-02],
                        [  8.39233398e-02,   7.55920410e-02],
                        [  7.11059570e-02,   6.32324219e-02],
                        [  5.96923828e-02,   5.29479980e-02],
                        [  4.72717285e-02,   4.22668457e-02],
                        [  3.24401855e-02,   2.97241211e-02],
                        [  2.23999023e-02,   2.21557617e-02],
                        [  2.46582031e-02,   2.69470215e-02],
                        [  3.83911133e-02,   4.30908203e-02],
                        [  5.62133789e-02,   6.29272461e-02],
                        [  6.82983398e-02,   7.64770508e-02],
                        [  6.60400391e-02,   7.50427246e-02],
                        [  4.70275879e-02,   5.61218262e-02],
                        [  1.70593262e-02,   2.55126953e-02],
                        [ -1.22680664e-02,  -5.09643555e-03],
                        [ -2.95410156e-02,  -2.42309570e-02],
                        [ -3.02124023e-02,  -2.71606445e-02],
                        [ -1.98364258e-02,  -1.92871094e-02],
                        [ -1.00402832e-02,  -1.19934082e-02],
                        [ -8.97216797e-03,  -1.32751465e-02],
                        [ -1.73339844e-02,  -2.36511230e-02],
                        [ -3.13720703e-02,  -3.92761230e-02],
                        [ -4.45251465e-02,  -5.33752441e-02],
                        [ -4.87976074e-02,  -5.80139160e-02],
                        [ -3.94592285e-02,  -4.83703613e-02],
                        [ -1.79138184e-02,  -2.58789062e-02],
                        [  7.72094727e-03,   1.28173828e-03],
                        [  2.67639160e-02,   2.23388672e-02],
                        [  3.45764160e-02,   3.24707031e-02],
                        [  3.46679688e-02,   3.50952148e-02],
                        [  3.31115723e-02,   3.60412598e-02],
                        [  3.29589844e-02,   3.82690430e-02],
                        [  3.39050293e-02,   4.12292480e-02],
                        [  3.52172852e-02,   4.40979004e-02],
                        [  3.79333496e-02,   4.77600098e-02],
                        [  4.15344238e-02,   5.16357422e-02],
                        [  4.25415039e-02,   5.21240234e-02],
                        [  3.90014648e-02,   4.73937988e-02],
                        [  3.28369141e-02,   3.93371582e-02],
                        [  2.70996094e-02,   3.10974121e-02],
                        [  2.43835449e-02,   2.55737305e-02],
                        [  2.65808105e-02,   2.47497559e-02],
                        [  3.18603516e-02,   2.70080566e-02],
                        [  3.55224609e-02,   2.79541016e-02],
                        [  3.64990234e-02,   2.67639160e-02],
                        [  3.73535156e-02,   2.61230469e-02],
                        [  3.64074707e-02,   2.45361328e-02],
                        [  2.88391113e-02,   1.73034668e-02],
                        [  1.55944824e-02,   5.37109375e-03],
                        [  2.34985352e-03,  -5.70678711e-03],
                        [ -8.51440430e-03,  -1.36718750e-02],
                        [ -1.86767578e-02,  -2.03857422e-02],
                        [ -2.93273926e-02,  -2.73742676e-02],
                        [ -4.04663086e-02,  -3.49731445e-02],
                        [ -5.09033203e-02,  -4.22363281e-02],
                        [ -5.71289062e-02,  -4.59594727e-02],
                        [ -5.63354492e-02,  -4.36096191e-02],
                        [ -4.96826172e-02,  -3.64990234e-02],
                        [ -4.04968262e-02,  -2.79541016e-02],
                        [ -3.24401855e-02,  -2.16979980e-02],
                        [ -2.84729004e-02,  -2.04467773e-02],
                        [ -2.67639160e-02,  -2.21557617e-02],
                        [ -2.30407715e-02,  -2.23083496e-02],
                        [ -1.77612305e-02,  -2.09350586e-02],
                        [ -1.40686035e-02,  -2.09045410e-02],
                        [ -1.09252930e-02,  -2.07214355e-02],
                        [ -5.18798828e-03,  -1.71508789e-02],
                        [  1.03759766e-03,  -1.19628906e-02],
                        [  3.14331055e-03,  -9.73510742e-03],
                        [  1.40380859e-03,  -1.01928711e-02],
                        [ -8.23974609e-04,  -1.01623535e-02],
                        [ -5.03540039e-03,  -1.12915039e-02],
                        [ -1.42517090e-02,  -1.69372559e-02],
                        [ -2.44140625e-02,  -2.33764648e-02],
                        [ -2.66113281e-02,  -2.20947266e-02],
                        [ -1.77917480e-02,  -1.02844238e-02],
                        [ -3.99780273e-03,   5.76782227e-03],
                        [  7.65991211e-03,   1.86767578e-02],
                        [  1.44348145e-02,   2.56652832e-02],
                        [  1.42211914e-02,   2.46887207e-02],
                        [  5.98144531e-03,   1.47399902e-02],
                        [ -4.48608398e-03,   1.89208984e-03],
                        [ -8.11767578e-03,  -4.54711914e-03],
                        [ -4.11987305e-03,  -3.50952148e-03],
                        [  3.96728516e-04,  -1.89208984e-03],
                        [  2.65502930e-03,  -2.04467773e-03],
                        [  7.93457031e-03,   1.37329102e-03],
                        [  1.80053711e-02,   1.03149414e-02],
                        [  2.67944336e-02,   1.87683105e-02],
                        [  3.11584473e-02,   2.35595703e-02],
                        [  3.58276367e-02,   2.92663574e-02],
                        [  4.50744629e-02,   4.00390625e-02],
                        [  5.93872070e-02,   5.61523438e-02],
                        [  7.90710449e-02,   7.77282715e-02],
                        [  1.03271484e-01,   1.03668213e-01],
                        [  1.24847412e-01,   1.26739502e-01],
                        [  1.30950928e-01,   1.33941650e-01],
                        [  1.10504150e-01,   1.14135742e-01],
                        [  6.02416992e-02,   6.41174316e-02],
                        [ -1.88598633e-02,  -1.51672363e-02],
                        [ -1.22772217e-01,  -1.19567871e-01],
                        [ -2.32940674e-01,  -2.30377197e-01],
                        [ -3.13629150e-01,  -3.11767578e-01],
                        [ -3.36456299e-01,  -3.35266113e-01],
                        [ -3.06427002e-01,  -3.05725098e-01],
                        [ -2.54852295e-01,  -2.54455566e-01],
                        [ -2.10296631e-01,  -2.10021973e-01],
                        [ -1.80480957e-01,  -1.80206299e-01],
                        [ -1.57470703e-01,  -1.57043457e-01],
                        [ -1.29760742e-01,  -1.29180908e-01],
                        [ -8.95996094e-02,  -8.89587402e-02],
                        [ -3.72314453e-02,  -3.66821289e-02],
                        [  1.87072754e-02,   1.89514160e-02],
                        [  6.75659180e-02,   6.72912598e-02],
                        [  1.03698730e-01,   1.02722168e-01],
                        [  1.26556396e-01,   1.24755859e-01],
                        [  1.37298584e-01,   1.34613037e-01],
                        [  1.38061523e-01,   1.34582520e-01],
                        [  1.32690430e-01,   1.28631592e-01],
                        [  1.23809814e-01,   1.19476318e-01],
                        [  1.09710693e-01,   1.05499268e-01],
                        [  8.95996094e-02,   8.59680176e-02],
                        [  6.96411133e-02,   6.70166016e-02],
                        [  5.73425293e-02,   5.60913086e-02],
                        [  5.33142090e-02,   5.37414551e-02],
                        [  5.38635254e-02,   5.60913086e-02],
                        [  5.66406250e-02,   6.05773926e-02],
                        [  5.96923828e-02,   6.51550293e-02],
                        [  5.90209961e-02,   6.55517578e-02],
                        [  5.14221191e-02,   5.84716797e-02],
                        [  3.77502441e-02,   4.47082520e-02],
                        [  2.05383301e-02,   2.67639160e-02],
                        [  1.40380859e-03,   6.22558594e-03],
                        [ -1.64184570e-02,  -1.34582520e-02],
                        [ -2.62756348e-02,  -2.55432129e-02],
                        [ -2.41088867e-02,  -2.58178711e-02],
                        [ -1.40380859e-02,  -1.80664062e-02],
                        [ -3.75366211e-03,  -9.76562500e-03],
                        [  2.44140625e-03,  -5.09643555e-03],
                        [  3.23486328e-03,  -5.18798828e-03],
                        [ -1.15966797e-03,  -9.70458984e-03],
                        [ -7.62939453e-03,  -1.55029297e-02],
                        [ -1.22680664e-02,  -1.87988281e-02],
                        [ -1.34582520e-02,  -1.79748535e-02],
                        [ -1.03454590e-02,  -1.24511719e-02],
                        [ -2.62451172e-03,  -2.13623047e-03],
                        [  7.11059570e-03,   1.01318359e-02],
                        [  1.48925781e-02,   2.02636719e-02],
                        [  1.98059082e-02,   2.70080566e-02],
                        [  2.29187012e-02,   3.12805176e-02],
                        [  2.38647461e-02,   3.26538086e-02],
                        [  2.27661133e-02,   3.12500000e-02],
                        [  2.27355957e-02,   3.01513672e-02],
                        [  2.52380371e-02,   3.09448242e-02],
                        [  2.84118652e-02,   3.19519043e-02],
                        [  3.23486328e-02,   3.34472656e-02],
                        [  3.78723145e-02,   3.64379883e-02],
                        [  4.22668457e-02,   3.84826660e-02],
                        [  4.27856445e-02,   3.70483398e-02],
                        [  4.10461426e-02,   3.38439941e-02],
                        [  3.97644043e-02,   3.17382812e-02],
                        [  3.88793945e-02,   3.07617188e-02],
                        [  3.68957520e-02,   2.93579102e-02],
                        [  3.38439941e-02,   2.74963379e-02],
                        [  3.09448242e-02,   2.62756348e-02],
                        [  2.91442871e-02,   2.65197754e-02],
                        [  2.86865234e-02,   2.82897949e-02],
                        [  2.87475586e-02,   3.05480957e-02],
                        [  2.63061523e-02,   3.00598145e-02],
                        [  1.86462402e-02,   2.39868164e-02],
                        [  8.08715820e-03,   1.45263672e-02],
                        [ -7.32421875e-04,   6.28662109e-03],
                        [ -8.60595703e-03,  -1.64794922e-03],
                        [ -1.95922852e-02,  -1.32141113e-02],
                        [ -3.14025879e-02,  -2.61535645e-02],
                        [ -3.76892090e-02,  -3.39355469e-02],
                        [ -3.69873047e-02,  -3.49426270e-02],
                        [ -3.34472656e-02,  -3.32641602e-02],
                        [ -3.06091309e-02,  -3.22265625e-02],
                        [ -2.77404785e-02,  -3.10058594e-02],
                        [ -2.24609375e-02,  -2.70080566e-02],
                        [ -1.48620605e-02,  -2.03247070e-02],
                        [ -8.33129883e-03,  -1.42211914e-02],
                        [ -6.77490234e-03,  -1.26037598e-02],
                        [ -1.11694336e-02,  -1.64794922e-02],
                        [ -1.81884766e-02,  -2.26135254e-02],
                        [ -2.36816406e-02,  -2.68554688e-02],
                        [ -2.61535645e-02,  -2.78320312e-02],
                        [ -2.63061523e-02,  -2.64587402e-02],
                        [ -2.60925293e-02,  -2.47497559e-02],
                        [ -2.63061523e-02,  -2.35900879e-02],
                        [ -2.51464844e-02,  -2.13317871e-02],
                        [ -2.14843750e-02,  -1.69677734e-02],
                        [ -1.53808594e-02,  -1.04980469e-02],
                        [ -6.68334961e-03,  -1.83105469e-03],
                        [  2.59399414e-03,   6.98852539e-03],
                        [  9.21630859e-03,   1.28173828e-02],
                        [  1.26953125e-02,   1.52893066e-02],
                        [  1.40075684e-02,   1.53808594e-02],
                        [  1.36413574e-02,   1.36718750e-02],
                        [  1.24206543e-02,   1.12304688e-02],
                        [  1.10778809e-02,   8.78906250e-03],
                        [  9.49096680e-03,   6.34765625e-03],
                        [  7.65991211e-03,   3.93676758e-03],
                        [  6.59179688e-03,   2.65502930e-03],
                        [  7.62939453e-03,   3.78417969e-03],
                        [  9.70458984e-03,   6.25610352e-03],
                        [  1.18408203e-02,   9.09423828e-03],
                        [  1.73645020e-02,   1.55334473e-02],
                        [  2.99072266e-02,   2.90527344e-02],
                        [  4.72717285e-02,   4.74243164e-02],
                        [  6.42089844e-02,   6.53076172e-02],
                        [  7.92236328e-02,   8.11157227e-02],
                        [  9.50622559e-02,   9.75341797e-02],
                        [  1.12945557e-01,   1.15753174e-01],
                        [  1.27471924e-01,   1.30371094e-01],
                        [  1.28692627e-01,   1.31378174e-01],
                        [  1.07391357e-01,   1.09680176e-01],
                        [  5.72814941e-02,   5.90209961e-02],
                        [ -2.51464844e-02,  -2.40478516e-02],
                        [ -1.34002686e-01,  -1.33636475e-01],
                        [ -2.44995117e-01,  -2.45269775e-01],
                        [ -3.21014404e-01,  -3.21838379e-01],
                        [ -3.35998535e-01,  -3.37249756e-01],
                        [ -2.95440674e-01,  -2.96966553e-01],
                        [ -2.34313965e-01,  -2.35961914e-01],
                        [ -1.90734863e-01,  -1.92321777e-01],
                        [ -1.76849365e-01,  -1.78283691e-01],
                        [ -1.74072266e-01,  -1.75262451e-01],
                        [ -1.54724121e-01,  -1.55578613e-01],
                        [ -1.08001709e-01,  -1.08520508e-01],
                        [ -4.57153320e-02,  -4.59594727e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  6.81457520e-02,   6.82983398e-02],
                        [  1.10198975e-01,   1.10473633e-01],
                        [  1.37817383e-01,   1.38122559e-01],
                        [  1.49017334e-01,   1.49322510e-01],
                        [  1.45935059e-01,   1.46240234e-01],
                        [  1.33148193e-01,   1.33453369e-01],
                        [  1.16363525e-01,   1.16699219e-01],
                        [  1.00402832e-01,   1.00830078e-01],
                        [  8.63952637e-02,   8.69140625e-02],
                        [  7.32116699e-02,   7.38525391e-02],
                        [  6.25610352e-02,   6.33544922e-02],
                        [  5.84106445e-02,   5.93261719e-02],
                        [  5.96923828e-02,   6.06689453e-02],
                        [  6.00891113e-02,   6.10351562e-02],
                        [  5.54199219e-02,   5.62744141e-02],
                        [  4.68750000e-02,   4.74853516e-02],
                        [  3.72924805e-02,   3.75671387e-02],
                        [  2.66723633e-02,   2.65502930e-02],
                        [  1.30310059e-02,   1.24206543e-02],
                        [ -1.67846680e-03,  -2.77709961e-03],
                        [ -9.79614258e-03,  -1.13525391e-02],
                        [ -6.07299805e-03,  -7.96508789e-03],
                        [  4.45556641e-03,   2.34985352e-03],
                        [  1.08947754e-02,   8.75854492e-03],
                        [  7.93457031e-03,   6.01196289e-03],
                        [ -1.98364258e-03,  -3.50952148e-03],
                        [ -1.58691406e-02,  -1.68151855e-02],
                        [ -3.11584473e-02,  -3.13415527e-02],
                        [ -4.18701172e-02,  -4.12597656e-02],
                        [ -4.09240723e-02,  -3.94897461e-02],
                        [ -2.66723633e-02,  -2.45361328e-02],
                        [ -5.12695312e-03,  -2.44140625e-03],
                        [  1.50756836e-02,   1.81274414e-02],
                        [  2.83203125e-02,   3.13720703e-02],
                        [  3.17382812e-02,   3.45764160e-02],
                        [  2.61230469e-02,   2.84118652e-02],
                        [  1.80358887e-02,   1.95312500e-02],
                        [  1.55944824e-02,   1.61132812e-02],
                        [  2.05688477e-02,   2.00195312e-02],
                        [  2.78320312e-02,   2.62145996e-02],
                        [  3.25317383e-02,   2.99682617e-02],
                        [  3.57666016e-02,   3.24707031e-02],
                        [  3.98559570e-02,   3.61328125e-02],
                        [  4.23278809e-02,   3.85131836e-02],
                        [  4.00695801e-02,   3.65600586e-02],
                        [  3.50036621e-02,   3.21350098e-02],
                        [  3.15856934e-02,   2.96325684e-02],
                        [  3.18908691e-02,   3.10668945e-02],
                        [  3.46984863e-02,   3.51562500e-02],
                        [  3.70483398e-02,   3.87268066e-02],
                        [  3.57055664e-02,   3.85131836e-02],
                        [  2.95715332e-02,   3.31726074e-02],
                        [  2.18505859e-02,   2.60009766e-02],
                        [  1.60827637e-02,   2.03857422e-02],
                        [  1.01623535e-02,   1.41601562e-02],
                        [  1.43432617e-03,   4.73022461e-03],
                        [ -6.77490234e-03,  -4.45556641e-03],
                        [ -1.04980469e-02,  -9.42993164e-03],
                        [ -1.17797852e-02,  -1.20544434e-02],
                        [ -1.47705078e-02,  -1.63879395e-02],
                        [ -1.95007324e-02,  -2.23083496e-02],
                        [ -2.33459473e-02,  -2.70996094e-02],
                        [ -2.61840820e-02,  -3.04870605e-02],
                        [ -2.96630859e-02,  -3.41186523e-02],
                        [ -3.32336426e-02,  -3.74450684e-02],
                        [ -3.52172852e-02,  -3.87878418e-02],
                        [ -3.55834961e-02,  -3.81164551e-02],
                        [ -3.51257324e-02,  -3.64379883e-02],
                        [ -3.45764160e-02,  -3.45458984e-02],
                        [ -3.42407227e-02,  -3.28674316e-02],
                        [ -3.33862305e-02,  -3.07617188e-02],
                        [ -3.10668945e-02,  -2.74963379e-02],
                        [ -2.67944336e-02,  -2.26135254e-02],
                        [ -1.98059082e-02,  -1.54113770e-02],
                        [ -1.07116699e-02,  -6.50024414e-03],
                        [ -2.96020508e-03,   6.10351562e-04],
                        [  2.74658203e-04,   2.92968750e-03],
                        [ -7.62939453e-04,   7.32421875e-04],
                        [ -4.76074219e-03,  -4.54711914e-03],
                        [ -1.04064941e-02,  -1.15051270e-02],
                        [ -1.48620605e-02,  -1.70898438e-02],
                        [ -1.51672363e-02,  -1.83410645e-02],
                        [ -1.24511719e-02,  -1.62353516e-02],
                        [ -1.15966797e-02,  -1.56250000e-02],
                        [ -1.46179199e-02,  -1.84936523e-02],
                        [ -1.59606934e-02,  -1.93481445e-02],
                        [ -9.85717773e-03,  -1.24816895e-02],
                        [ -3.96728516e-04,  -1.98364258e-03],
                        [  3.75366211e-03,   3.29589844e-03],
                        [  2.28881836e-03,   2.99072266e-03],
                        [  2.62451172e-03,   4.33349609e-03],
                        [  7.81250000e-03,   1.03759766e-02],
                        [  1.33972168e-02,   1.65405273e-02],
                        [  1.62963867e-02,   1.96838379e-02],
                        [  1.93481445e-02,   2.27050781e-02],
                        [  2.39562988e-02,   2.69470215e-02],
                        [  2.76794434e-02,   2.99987793e-02],
                        [  3.12805176e-02,   3.28063965e-02],
                        [  3.99780273e-02,   4.05883789e-02],
                        [  5.72204590e-02,   5.69152832e-02],
                        [  8.33129883e-02,   8.21533203e-02],
                        [  1.14105225e-01,   1.12243652e-01],
                        [  1.38214111e-01,   1.35894775e-01],
                        [  1.41815186e-01,   1.39251709e-01],
                        [  1.17370605e-01,   1.14807129e-01],
                        [  6.28356934e-02,   6.05163574e-02],
                        [ -2.35900879e-02,  -2.54516602e-02],
                        [ -1.35650635e-01,  -1.36901855e-01],
                        [ -2.46856689e-01,  -2.47467041e-01],
                        [ -3.19824219e-01,  -3.19763184e-01],
                        [ -3.33648682e-01,  -3.33007812e-01],
                        [ -2.98217773e-01,  -2.97088623e-01],
                        [ -2.43682861e-01,  -2.42218018e-01],
                        [ -1.99401855e-01,  -1.97784424e-01],
                        [ -1.76086426e-01,  -1.74499512e-01],
                        [ -1.61529541e-01,  -1.60095215e-01],
                        [ -1.36291504e-01,  -1.35131836e-01],
                        [ -9.48486328e-02,  -9.40246582e-02],
                        [ -4.55322266e-02,  -4.51049805e-02],
                        [  5.49316406e-03,   5.55419922e-03],
                        [  5.70678711e-02,   5.68542480e-02],
                        [  1.02050781e-01,   1.01562500e-01],
                        [  1.29028320e-01,   1.28448486e-01],
                        [  1.36199951e-01,   1.35620117e-01],
                        [  1.32232666e-01,   1.31652832e-01],
                        [  1.25457764e-01,   1.25000000e-01],
                        [  1.18652344e-01,   1.18347168e-01],
                        [  1.09375000e-01,   1.09191895e-01],
                        [  9.41162109e-02,   9.40246582e-02],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  8.34655762e-02,   8.33740234e-02],
                        [  9.13085938e-02,   9.11254883e-02],
                        [  8.20922852e-02,   8.17871094e-02],
                        [  5.79833984e-02,   5.75256348e-02],
                        [  2.94799805e-02,   2.89306641e-02],
                        [  2.68554688e-03,   2.10571289e-03],
                        [ -1.99279785e-02,  -2.04772949e-02],
                        [ -3.48205566e-02,  -3.52783203e-02],
                        [ -3.81774902e-02,  -3.83911133e-02],
                        [ -2.98461914e-02,  -2.97546387e-02],
                        [ -1.55334473e-02,  -1.51367188e-02],
                        [ -4.18090820e-03,  -3.41796875e-03],
                        [ -1.43432617e-03,  -3.35693359e-04],
                        [ -5.46264648e-03,  -4.11987305e-03],
                        [ -9.30786133e-03,  -7.81250000e-03],
                        [ -9.00268555e-03,  -7.50732422e-03],
                        [ -7.20214844e-03,  -5.85937500e-03],
                        [ -6.34765625e-03,  -5.31005859e-03],
                        [ -2.47192383e-03,  -1.89208984e-03],
                        [  8.20922852e-03,   8.27026367e-03],
                        [  2.03247070e-02,   1.97753906e-02],
                        [  2.49023438e-02,   2.37426758e-02],
                        [  2.18811035e-02,   2.02331543e-02],
                        [  1.90734863e-02,   1.70288086e-02],
                        [  2.11486816e-02,   1.88903809e-02],
                        [  2.69775391e-02,   2.47192383e-02],
                        [  3.35388184e-02,   3.14941406e-02],
                        [  3.67126465e-02,   3.50952148e-02],
                        [  3.39660645e-02,   3.29589844e-02],
                        [  2.77099609e-02,   2.74353027e-02],
                        [  2.24609375e-02,   2.29797363e-02],
                        [  2.15759277e-02,   2.28881836e-02],
                        [  2.71301270e-02,   2.91137695e-02],
                        [  3.70178223e-02,   3.94897461e-02],
                        [  4.52270508e-02,   4.80651855e-02],
                        [  4.76684570e-02,   5.05371094e-02],
                        [  4.44030762e-02,   4.69970703e-02],
                        [  3.68347168e-02,   3.89709473e-02],
                        [  2.61230469e-02,   2.75573730e-02],
                        [  1.46484375e-02,   1.51977539e-02],
                        [  6.68334961e-03,   6.31713867e-03],
                        [  3.75366211e-03,   2.47192383e-03],
                        [  1.95312500e-03,  -1.52587891e-04],
                        [ -1.92260742e-03,  -4.66918945e-03],
                        [ -5.61523438e-03,  -8.72802734e-03],
                        [ -6.71386719e-03,  -9.91821289e-03],
                        [ -7.08007812e-03,  -1.01013184e-02],
                        [ -8.11767578e-03,  -1.06201172e-02],
                        [ -8.51440430e-03,  -1.02539062e-02],
                        [ -9.61303711e-03,  -1.04370117e-02],
                        [ -1.48925781e-02,  -1.47399902e-02],
                        [ -2.23388672e-02,  -2.11486816e-02],
                        [ -2.56347656e-02,  -2.35595703e-02],
                        [ -2.41699219e-02,  -2.14233398e-02],
                        [ -2.18811035e-02,  -1.86767578e-02],
                        [ -2.02026367e-02,  -1.68457031e-02],
                        [ -2.05383301e-02,  -1.73645020e-02],
                        [ -2.62451172e-02,  -2.35900879e-02],
                        [ -3.46679688e-02,  -3.27148438e-02],
                        [ -3.82080078e-02,  -3.71704102e-02],
                        [ -3.62243652e-02,  -3.61938477e-02],
                        [ -3.33251953e-02,  -3.43017578e-02],
                        [ -2.96936035e-02,  -3.15551758e-02],
                        [ -2.43225098e-02,  -2.69470215e-02],
                        [ -2.00195312e-02,  -2.31018066e-02],
                        [ -1.69372559e-02,  -2.01721191e-02],
                        [ -1.16271973e-02,  -1.47399902e-02],
                        [ -4.60815430e-03,  -7.29370117e-03],
                        [ -2.74658203e-04,  -2.25830078e-03],
                        [  1.83105469e-04,  -9.46044922e-04],
                        [ -8.54492188e-04,  -1.03759766e-03],
                        [ -2.86865234e-03,  -2.10571289e-03],
                        [ -6.50024414e-03,  -4.88281250e-03],
                        [ -9.27734375e-03,  -6.98852539e-03],
                        [ -8.02612305e-03,  -5.27954102e-03],
                        [ -3.02124023e-03,  -6.10351562e-05],
                        [  3.29589844e-03,   6.13403320e-03],
                        [  8.30078125e-03,   1.07727051e-02],
                        [  1.00708008e-02,   1.19323730e-02],
                        [  9.55200195e-03,   1.06811523e-02],
                        [  9.24682617e-03,   9.52148438e-03],
                        [  9.09423828e-03,   8.54492188e-03],
                        [  7.59887695e-03,   6.28662109e-03],
                        [  6.04248047e-03,   4.15039062e-03],
                        [  7.81250000e-03,   5.46264648e-03],
                        [  1.36413574e-02,   1.11389160e-02],
                        [  2.30712891e-02,   2.06604004e-02],
                        [  3.86352539e-02,   3.65295410e-02],
                        [  6.35986328e-02,   6.19506836e-02],
                        [  9.58251953e-02,   9.47875977e-02],
                        [  1.26678467e-01,   1.26312256e-01],
                        [  1.44989014e-01,   1.45294189e-01],
                        [  1.42272949e-01,   1.43218994e-01],
                        [  1.13677979e-01,   1.15142822e-01],
                        [  5.42602539e-02,   5.59997559e-02],
                        [ -3.86657715e-02,  -3.67736816e-02],
                        [ -1.54327393e-01,  -1.52435303e-01],
                        [ -2.64373779e-01,  -2.62725830e-01],
                        [ -3.34564209e-01,  -3.33282471e-01],
                        [ -3.44390869e-01,  -3.43505859e-01],
                        [ -3.01879883e-01,  -3.01513672e-01],
                        [ -2.40447998e-01,  -2.40570068e-01],
                        [ -1.94488525e-01,  -1.95068359e-01],
                        [ -1.73828125e-01,  -1.74713135e-01],
                        [ -1.62902832e-01,  -1.64062500e-01],
                        [ -1.42974854e-01,  -1.44256592e-01],
                        [ -1.07696533e-01,  -1.08917236e-01],
                        [ -6.00280762e-02,  -6.11267090e-02],
                        [ -3.72314453e-03,  -4.63867188e-03],
                        [  5.86242676e-02,   5.79833984e-02],
                        [  1.18347168e-01,   1.18011475e-01],
                        [  1.58233643e-01,   1.58172607e-01],
                        [  1.67480469e-01,   1.67633057e-01],
                        [  1.56005859e-01,   1.56372070e-01],
                        [  1.42303467e-01,   1.42791748e-01],
                        [  1.31774902e-01,   1.32324219e-01],
                        [  1.19140625e-01,   1.19689941e-01],
                        [  1.04461670e-01,   1.04980469e-01],
                        [  9.40246582e-02,   9.44519043e-02],
                        [  8.97827148e-02,   9.01489258e-02],
                        [  8.88671875e-02,   8.91418457e-02],
                        [  8.57849121e-02,   8.60290527e-02],
                        [  7.13195801e-02,   7.15026855e-02],
                        [  3.92150879e-02,   3.93676758e-02],
                        [ -3.41796875e-03,  -3.26538086e-03],
                        [ -4.07409668e-02,  -4.05578613e-02],
                        [ -6.05163574e-02,  -6.03637695e-02],
                        [ -5.82580566e-02,  -5.81054688e-02],
                        [ -3.68347168e-02,  -3.67431641e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [  1.18103027e-02,   1.16882324e-02],
                        [  1.65405273e-02,   1.62658691e-02],
                        [  1.32751465e-02,   1.28479004e-02],
                        [  1.06201172e-02,   1.00097656e-02],
                        [  8.72802734e-03,   8.02612305e-03],
                        [  4.94384766e-03,   4.15039062e-03],
                        [  7.32421875e-04,  -9.15527344e-05],
                        [ -2.44140625e-04,  -1.03759766e-03],
                        [  4.48608398e-03,   3.87573242e-03],
                        [  1.46789551e-02,   1.42822266e-02],
                        [  2.58789062e-02,   2.57263184e-02],
                        [  3.21655273e-02,   3.23791504e-02],
                        [  3.21655273e-02,   3.27148438e-02],
                        [  2.85339355e-02,   2.93884277e-02],
                        [  2.31628418e-02,   2.42614746e-02],
                        [  1.73034668e-02,   1.85852051e-02],
                        [  1.39465332e-02,   1.53198242e-02],
                        [  1.61437988e-02,   1.74560547e-02],
                        [  2.42309570e-02,   2.53906250e-02],
                        [  3.59191895e-02,   3.68041992e-02],
                        [  4.62951660e-02,   4.68139648e-02],
                        [  5.03845215e-02,   5.04455566e-02],
                        [  4.71801758e-02,   4.68139648e-02],
                        [  4.06799316e-02,   3.98559570e-02],
                        [  3.53088379e-02,   3.40576172e-02],
                        [  3.21350098e-02,   3.06091309e-02],
                        [  3.05786133e-02,   2.88696289e-02],
                        [  2.97546387e-02,   2.79846191e-02],
                        [  2.78930664e-02,   2.62451172e-02],
                        [  2.36511230e-02,   2.22778320e-02],
                        [  1.77612305e-02,   1.67541504e-02],
                        [  1.27563477e-02,   1.22375488e-02],
                        [  1.06506348e-02,   1.06811523e-02],
                        [  9.33837891e-03,   9.91821289e-03],
                        [  3.60107422e-03,   4.69970703e-03],
                        [ -7.44628906e-03,  -5.88989258e-03],
                        [ -1.93176270e-02,  -1.74255371e-02],
                        [ -2.91748047e-02,  -2.71606445e-02],
                        [ -3.73535156e-02,  -3.53088379e-02],
                        [ -4.26940918e-02,  -4.08020020e-02],
                        [ -4.28161621e-02,  -4.12597656e-02],
                        [ -3.79333496e-02,  -3.68347168e-02],
                        [ -3.09448242e-02,  -3.03955078e-02],
                        [ -2.50854492e-02,  -2.51464844e-02],
                        [ -2.25830078e-02,  -2.32849121e-02],
                        [ -2.34069824e-02,  -2.46887207e-02],
                        [ -2.53295898e-02,  -2.70690918e-02],
                        [ -2.70385742e-02,  -2.91442871e-02],
                        [ -2.94799805e-02,  -3.17993164e-02],
                        [ -3.15246582e-02,  -3.38134766e-02],
                        [ -2.98461914e-02,  -3.19824219e-02],
                        [ -2.39868164e-02,  -2.57568359e-02],
                        [ -1.69067383e-02,  -1.81579590e-02],
                        [ -1.17797852e-02,  -1.23901367e-02],
                        [ -1.07421875e-02,  -1.06506348e-02],
                        [ -1.33361816e-02,  -1.25732422e-02],
                        [ -1.53198242e-02,  -1.39160156e-02],
                        [ -1.27868652e-02,  -1.08337402e-02],
                        [ -7.35473633e-03,  -5.00488281e-03],
                        [ -2.89916992e-03,  -3.66210938e-04],
                        [ -4.27246094e-04,   2.13623047e-03],
                        [  1.83105469e-04,   2.50244141e-03],
                        [ -2.38037109e-03,  -4.57763672e-04],
                        [ -6.62231445e-03,  -5.27954102e-03],
                        [ -7.72094727e-03,  -7.08007812e-03],
                        [ -4.27246094e-03,  -4.42504883e-03],
                        [ -2.74658203e-04,  -1.19018555e-03],
                        [  1.37329102e-03,  -2.44140625e-04],
                        [  1.06811523e-03,  -1.12915039e-03],
                        [  9.15527344e-05,  -2.53295898e-03],
                        [ -1.83105469e-04,  -2.96020508e-03],
                        [  1.83105469e-03,  -8.85009766e-04],
                        [  5.31005859e-03,   2.86865234e-03],
                        [  8.08715820e-03,   6.13403320e-03],
                        [  1.07116699e-02,   9.46044922e-03],
                        [  1.64794922e-02,   1.59912109e-02],
                        [  2.76489258e-02,   2.79846191e-02],
                        [  4.42504883e-02,   4.54101562e-02],
                        [  6.46972656e-02,   6.65588379e-02],
                        [  8.65783691e-02,   8.89587402e-02],
                        [  1.06903076e-01,   1.09619141e-01],
                        [  1.20727539e-01,   1.23565674e-01],
                        [  1.20086670e-01,   1.22741699e-01],
                        [  9.49707031e-02,   9.72290039e-02],
                        [  3.82385254e-02,   3.99169922e-02],
                        [ -4.85229492e-02,  -4.75769043e-02],
                        [ -1.51977539e-01,  -1.51824951e-01],
                        [ -2.48107910e-01,  -2.48779297e-01],
                        [ -3.07830811e-01,  -3.09204102e-01],
                        [ -3.12500000e-01,  -3.14453125e-01],
                        [ -2.71575928e-01,  -2.73956299e-01],
                        [ -2.18353271e-01,  -2.20886230e-01],
                        [ -1.81793213e-01,  -1.84295654e-01],
                        [ -1.65435791e-01,  -1.67663574e-01],
                        [ -1.53717041e-01,  -1.55487061e-01],
                        [ -1.32873535e-01,  -1.34033203e-01],
                        [ -1.00921631e-01,  -1.01409912e-01],
                        [ -6.12487793e-02,  -6.10351562e-02],
                        [ -1.38854980e-02,  -1.30310059e-02],
                        [  4.13818359e-02,   4.27551270e-02],
                        [  9.64965820e-02,   9.82360840e-02],
                        [  1.36505127e-01,   1.38427734e-01],
                        [  1.52404785e-01,   1.54357910e-01],
                        [  1.49414062e-01,   1.51214600e-01],
                        [  1.40502930e-01,   1.41967773e-01],
                        [  1.34338379e-01,   1.35406494e-01],
                        [  1.31011963e-01,   1.31622314e-01],
                        [  1.26007080e-01,   1.26129150e-01],
                        [  1.16333008e-01,   1.15997314e-01],
                        [  1.03576660e-01,   1.02905273e-01],
                        [  9.02709961e-02,   8.93249512e-02],
                        [  7.44628906e-02,   7.33642578e-02],
                        [  5.20935059e-02,   5.09643555e-02],
                        [  2.25219727e-02,   2.14843750e-02],
                        [ -1.03454590e-02,  -1.12609863e-02],
                        [ -3.91845703e-02,  -3.98559570e-02],
                        [ -5.59082031e-02,  -5.63354492e-02],
                        [ -5.74951172e-02,  -5.77392578e-02],
                        [ -4.70275879e-02,  -4.71191406e-02],
                        [ -2.98461914e-02,  -2.97546387e-02],
                        [ -1.27868652e-02,  -1.26342773e-02],
                        [ -2.71606445e-03,  -2.56347656e-03],
                        [ -6.10351562e-05,   6.10351562e-05],
                        [  2.74658203e-04,   3.96728516e-04],
                        [  3.05175781e-05,   9.15527344e-05],
                        [ -2.77709961e-03,  -2.71606445e-03],
                        [ -4.91333008e-03,  -4.82177734e-03],
                        [  7.93457031e-04,   9.76562500e-04],
                        [  1.58691406e-02,   1.61132812e-02],
                        [  3.45153809e-02,   3.49426270e-02],
                        [  5.01098633e-02,   5.06896973e-02],
                        [  5.74340820e-02,   5.81359863e-02],
                        [  5.41992188e-02,   5.49926758e-02],
                        [  4.44030762e-02,   4.52880859e-02],
                        [  3.54919434e-02,   3.62854004e-02],
                        [  3.07006836e-02,   3.13415527e-02],
                        [  2.90527344e-02,   2.94799805e-02],
                        [  2.93884277e-02,   2.94799805e-02],
                        [  2.99987793e-02,   2.96936035e-02],
                        [  2.93884277e-02,   2.87170410e-02],
                        [  2.85034180e-02,   2.74353027e-02],
                        [  2.85339355e-02,   2.71911621e-02],
                        [  2.81982422e-02,   2.66418457e-02],
                        [  2.63061523e-02,   2.46887207e-02],
                        [  2.50854492e-02,   2.35290527e-02],
                        [  2.67028809e-02,   2.53906250e-02],
                        [  2.96936035e-02,   2.87475586e-02],
                        [  3.20129395e-02,   3.15551758e-02],
                        [  3.44238281e-02,   3.45458984e-02],
                        [  3.70178223e-02,   3.76892090e-02],
                        [  3.67736816e-02,   3.79943848e-02],
                        [  3.26538086e-02,   3.43017578e-02],
                        [  2.72827148e-02,   2.92663574e-02],
                        [  2.09350586e-02,   2.30407715e-02],
                        [  9.67407227e-03,   1.16882324e-02],
                        [ -6.68334961e-03,  -4.88281250e-03],
                        [ -2.10571289e-02,  -1.96838379e-02],
                        [ -2.80761719e-02,  -2.72827148e-02],
                        [ -3.03649902e-02,  -3.01818848e-02],
                        [ -3.21044922e-02,  -3.25927734e-02],
                        [ -3.32336426e-02,  -3.43322754e-02],
                        [ -3.21960449e-02,  -3.38439941e-02],
                        [ -2.87475586e-02,  -3.07312012e-02],
                        [ -2.29797363e-02,  -2.51770020e-02],
                        [ -1.67846680e-02,  -1.89819336e-02],
                        [ -1.42211914e-02,  -1.62048340e-02],
                        [ -1.70898438e-02,  -1.87072754e-02],
                        [ -2.27355957e-02,  -2.38647461e-02],
                        [ -2.71301270e-02,  -2.76794434e-02],
                        [ -2.78015137e-02,  -2.76794434e-02],
                        [ -2.39868164e-02,  -2.32543945e-02],
                        [ -1.76696777e-02,  -1.64184570e-02],
                        [ -1.32446289e-02,  -1.15661621e-02],
                        [ -1.33972168e-02,  -1.14135742e-02],
                        [ -1.55639648e-02,  -1.35498047e-02],
                        [ -1.45568848e-02,  -1.26342773e-02],
                        [ -8.42285156e-03,  -6.71386719e-03],
                        [ -1.12915039e-03,   1.83105469e-04],
                        [  2.38037109e-03,   3.17382812e-03],
                        [  2.99072266e-03,   3.26538086e-03],
                        [  5.61523438e-03,   5.40161133e-03],
                        [  9.67407227e-03,   8.94165039e-03],
                        [  8.17871094e-03,   7.01904297e-03],
                        [ -1.83105469e-03,  -3.23486328e-03],
                        [ -1.44958496e-02,  -1.60827637e-02],
                        [ -2.27661133e-02,  -2.44445801e-02],
                        [ -2.42919922e-02,  -2.58178711e-02],
                        [ -2.10571289e-02,  -2.23388672e-02],
                        [ -1.68457031e-02,  -1.78527832e-02],
                        [ -1.20849609e-02,  -1.27258301e-02],
                        [ -2.92968750e-03,  -3.14331055e-03],
                        [  9.70458984e-03,   9.85717773e-03],
                        [  1.77307129e-02,   1.82189941e-02],
                        [  1.86462402e-02,   1.94702148e-02],
                        [  2.03552246e-02,   2.14233398e-02],
                        [  2.80761719e-02,   2.92663574e-02],
                        [  3.77807617e-02,   3.90319824e-02],
                        [  4.60815430e-02,   4.73022461e-02],
                        [  5.71899414e-02,   5.82580566e-02],
                        [  7.63244629e-02,   7.71789551e-02],
                        [  1.01928711e-01,   1.02569580e-01],
                        [  1.24969482e-01,   1.25305176e-01],
                        [  1.31500244e-01,   1.31530762e-01],
                        [  1.08154297e-01,   1.07910156e-01],
                        [  4.93164062e-02,   4.88281250e-02],
                        [ -4.03137207e-02,  -4.10156250e-02],
                        [ -1.46789551e-01,  -1.47674561e-01],
                        [ -2.46704102e-01,  -2.47680664e-01],
                        [ -3.10272217e-01,  -3.11279297e-01],
                        [ -3.17230225e-01,  -3.18176270e-01],
                        [ -2.75482178e-01,  -2.76306152e-01],
                        [ -2.19055176e-01,  -2.19696045e-01],
                        [ -1.80328369e-01,  -1.80786133e-01],
                        [ -1.64794922e-01,  -1.64978027e-01],
                        [ -1.56372070e-01,  -1.56311035e-01],
                        [ -1.41357422e-01,  -1.41052246e-01],
                        [ -1.16912842e-01,  -1.16394043e-01],
                        [ -8.30688477e-02,  -8.23669434e-02],
                        [ -3.81469727e-02,  -3.73229980e-02],
                        [  1.80053711e-02,   1.88598633e-02],
                        [  8.00170898e-02,   8.08715820e-02],
                        [  1.35467529e-01,   1.36199951e-01],
                        [  1.69860840e-01,   1.70471191e-01],
                        [  1.77978516e-01,   1.78405762e-01],
                        [  1.67907715e-01,   1.68090820e-01],
                        [  1.52587891e-01,   1.52557373e-01],
                        [  1.40808105e-01,   1.40594482e-01],
                        [  1.33575439e-01,   1.33148193e-01],
                        [  1.25366211e-01,   1.24786377e-01],
                        [  1.09375000e-01,   1.08703613e-01],
                        [  8.41674805e-02,   8.34960938e-02],
                        [  5.30700684e-02,   5.23986816e-02],
                        [  1.77917480e-02,   1.72119141e-02],
                        [ -2.10571289e-02,  -2.14843750e-02],
                        [ -5.64270020e-02,  -5.67016602e-02],
                        [ -7.58056641e-02,  -7.59277344e-02],
                        [ -7.36083984e-02,  -7.35168457e-02],
                        [ -5.66711426e-02,  -5.64575195e-02],
                        [ -3.59191895e-02,  -3.56140137e-02],
                        [ -1.72424316e-02,  -1.68457031e-02],
                        [ -3.11279297e-03,  -2.68554688e-03],
                        [  3.93676758e-03,   4.36401367e-03],
                        [  4.76074219e-03,   5.09643555e-03],
                        [  4.51660156e-03,   4.82177734e-03],
                        [  5.85937500e-03,   6.07299805e-03],
                        [  8.02612305e-03,   8.08715820e-03],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  2.87780762e-02,   2.87170410e-02],
                        [  4.86755371e-02,   4.85534668e-02],
                        [  6.33239746e-02,   6.32019043e-02],
                        [  6.58569336e-02,   6.57348633e-02],
                        [  5.57556152e-02,   5.56030273e-02],
                        [  3.71704102e-02,   3.70483398e-02],
                        [  1.97448730e-02,   1.97143555e-02],
                        [  1.26647949e-02,   1.26342773e-02],
                        [  1.46789551e-02,   1.46484375e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  1.82800293e-02,   1.83105469e-02],
                        [  1.73339844e-02,   1.73034668e-02],
                        [  1.58386230e-02,   1.57470703e-02],
                        [  1.79138184e-02,   1.78222656e-02],
                        [  2.80456543e-02,   2.78930664e-02],
                        [  4.11987305e-02,   4.09851074e-02],
                        [  4.75769043e-02,   4.74243164e-02],
                        [  4.62951660e-02,   4.61730957e-02],
                        [  4.27246094e-02,   4.26025391e-02],
                        [  3.85131836e-02,   3.84521484e-02],
                        [  3.38134766e-02,   3.38439941e-02],
                        [  3.10363770e-02,   3.11584473e-02],
                        [  2.98461914e-02,   3.00292969e-02],
                        [  2.65808105e-02,   2.68554688e-02],
                        [  2.13012695e-02,   2.16674805e-02],
                        [  1.66931152e-02,   1.70288086e-02],
                        [  1.07727051e-02,   1.11083984e-02],
                        [ -2.44140625e-04,   6.10351562e-05],
                        [ -1.44042969e-02,  -1.41906738e-02],
                        [ -2.60925293e-02,  -2.60009766e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.46374512e-02,  -3.47595215e-02],
                        [ -3.10668945e-02,  -3.13415527e-02],
                        [ -2.48718262e-02,  -2.52075195e-02],
                        [ -2.12402344e-02,  -2.16369629e-02],
                        [ -2.16979980e-02,  -2.21252441e-02],
                        [ -2.28576660e-02,  -2.32543945e-02],
                        [ -2.27661133e-02,  -2.31018066e-02],
                        [ -2.35595703e-02,  -2.38037109e-02],
                        [ -2.58483887e-02,  -2.60009766e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -2.60009766e-02,  -2.58789062e-02],
                        [ -2.56347656e-02,  -2.53906250e-02],
                        [ -2.46887207e-02,  -2.43530273e-02],
                        [ -2.10266113e-02,  -2.06298828e-02],
                        [ -1.80358887e-02,  -1.76391602e-02],
                        [ -1.86462402e-02,  -1.82495117e-02],
                        [ -1.87988281e-02,  -1.84631348e-02],
                        [ -1.58081055e-02,  -1.55944824e-02],
                        [ -1.34277344e-02,  -1.33056641e-02],
                        [ -1.35803223e-02,  -1.35192871e-02],
                        [ -1.33056641e-02,  -1.33972168e-02],
                        [ -1.08032227e-02,  -1.10168457e-02],
                        [ -6.34765625e-03,  -6.59179688e-03],
                        [ -1.61743164e-03,  -1.89208984e-03],
                        [ -1.55639648e-03,  -1.89208984e-03],
                        [ -8.27026367e-03,  -8.54492188e-03],
                        [ -1.35803223e-02,  -1.37939453e-02],
                        [ -9.06372070e-03,  -9.27734375e-03],
                        [  2.13623047e-04,   9.15527344e-05],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -1.06811523e-03,  -1.00708008e-03],
                        [ -5.88989258e-03,  -5.76782227e-03],
                        [ -6.53076172e-03,  -6.37817383e-03],
                        [ -3.23486328e-03,  -3.02124023e-03],
                        [  1.86157227e-03,   2.04467773e-03],
                        [  6.95800781e-03,   7.11059570e-03],
                        [  1.31225586e-02,   1.32751465e-02],
                        [  2.18811035e-02,   2.20031738e-02],
                        [  3.16467285e-02,   3.17077637e-02],
                        [  4.14733887e-02,   4.15039062e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  7.78503418e-02,   7.77587891e-02],
                        [  1.06658936e-01,   1.06567383e-01],
                        [  1.32293701e-01,   1.32202148e-01],
                        [  1.39709473e-01,   1.39617920e-01],
                        [  1.15081787e-01,   1.14959717e-01],
                        [  5.34057617e-02,   5.33447266e-02],
                        [ -4.02526855e-02,  -4.02832031e-02],
                        [ -1.51489258e-01,  -1.51550293e-01],
                        [ -2.53875732e-01,  -2.53875732e-01],
                        [ -3.15399170e-01,  -3.15368652e-01],
                        [ -3.19427490e-01,  -3.19396973e-01],
                        [ -2.78106689e-01,  -2.78076172e-01],
                        [ -2.21893311e-01,  -2.21832275e-01],
                        [ -1.78161621e-01,  -1.78131104e-01],
                        [ -1.56646729e-01,  -1.56616211e-01],
                        [ -1.48437500e-01,  -1.48406982e-01],
                        [ -1.38427734e-01,  -1.38427734e-01],
                        [ -1.19567871e-01,  -1.19567871e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -5.27343750e-02,  -5.27038574e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.65069580e-01,   1.65069580e-01],
                        [  1.84234619e-01,   1.84234619e-01],
                        [  1.88323975e-01,   1.88354492e-01],
                        [  1.83715820e-01,   1.83715820e-01],
                        [  1.73034668e-01,   1.73034668e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.29302979e-01,   1.29302979e-01],
                        [  9.85107422e-02,   9.85107422e-02],
                        [  6.64062500e-02,   6.63757324e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -6.03637695e-02,  -6.03942871e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  4.60815430e-03,   4.63867188e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  3.05480957e-02,   3.05786133e-02],
                        [  4.57153320e-02,   4.56848145e-02],
                        [  5.83496094e-02,   5.83801270e-02],
                        [  6.26831055e-02,   6.27136230e-02],
                        [  5.63354492e-02,   5.63049316e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  3.12194824e-02,   3.12500000e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  1.50146484e-02,   1.49841309e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  2.22778320e-02,   2.23083496e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.68554688e-02,   2.68249512e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  5.52368164e-03,   5.49316406e-03],
                        [ -2.22778320e-03,  -2.19726562e-03],
                        [ -7.26318359e-03,  -7.23266602e-03],
                        [ -1.09863281e-02,  -1.10168457e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -2.23083496e-02,  -2.23388672e-02],
                        [ -3.43627930e-02,  -3.43322754e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.38537598e-02,  -4.38842773e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.94897461e-02,  -3.94592285e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.91345215e-02,  -1.91040039e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -4.76074219e-03,  -4.73022461e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -1.36108398e-02,  -1.36413574e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  1.15356445e-01,   1.15356445e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  4.72717285e-02,   4.72717285e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -1.51367188e-01,  -1.51367188e-01],
                        [ -2.57080078e-01,  -2.57080078e-01],
                        [ -3.26080322e-01,  -3.26080322e-01],
                        [ -3.36059570e-01,  -3.36090088e-01],
                        [ -2.94769287e-01,  -2.94769287e-01],
                        [ -2.33337402e-01,  -2.33337402e-01],
                        [ -1.82281494e-01,  -1.82281494e-01],
                        [ -1.53137207e-01,  -1.53137207e-01],
                        [ -1.38092041e-01,  -1.38092041e-01],
                        [ -1.23962402e-01,  -1.23962402e-01],
                        [ -1.04736328e-01,  -1.04736328e-01],
                        [ -8.05053711e-02,  -8.05053711e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.74377441e-01,   1.74407959e-01],
                        [  2.03094482e-01,   2.03094482e-01],
                        [  2.05352783e-01,   2.05352783e-01],
                        [  1.92382812e-01,   1.92382812e-01],
                        [  1.75231934e-01,   1.75231934e-01],
                        [  1.53656006e-01,   1.53656006e-01],
                        [  1.22100830e-01,   1.22131348e-01],
                        [  8.07189941e-02,   8.07189941e-02],
                        [  3.50341797e-02,   3.50036621e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -5.53894043e-02,  -5.54199219e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -3.51257324e-02,  -3.50952148e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  2.09655762e-02,   2.09350586e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  5.40771484e-02,   5.40466309e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  3.85437012e-02,   3.85131836e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  1.62048340e-02,   1.62353516e-02],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.44445801e-02,   2.44750977e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.61743164e-03,   1.58691406e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.70593262e-02,  -1.70898438e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -4.24804688e-02,  -4.24499512e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -2.77709961e-02,  -2.78015137e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -3.29589844e-03,  -3.26538086e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -3.63159180e-03,  -3.66210938e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.17797852e-02,  -1.18103027e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  1.05895996e-02,   1.06201172e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  4.59289551e-02,   4.58984375e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.39190674e-01,   1.39190674e-01],
                        [  1.35253906e-01,   1.35284424e-01],
                        [  1.03332520e-01,   1.03332520e-01],
                        [  4.03747559e-02,   4.03747559e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -1.55883789e-01,  -1.55853271e-01],
                        [ -2.50915527e-01,  -2.50915527e-01],
                        [ -3.07067871e-01,  -3.07067871e-01],
                        [ -3.08074951e-01,  -3.08044434e-01],
                        [ -2.64099121e-01,  -2.64099121e-01],
                        [ -2.07366943e-01,  -2.07366943e-01],
                        [ -1.67633057e-01,  -1.67633057e-01],
                        [ -1.52160645e-01,  -1.52130127e-01],
                        [ -1.48437500e-01,  -1.48437500e-01],
                        [ -1.40655518e-01,  -1.40655518e-01],
                        [ -1.21826172e-01,  -1.21795654e-01],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.79351807e-01,   1.79321289e-01],
                        [  2.08892822e-01,   2.08923340e-01],
                        [  2.11853027e-01,   2.11853027e-01],
                        [  1.98364258e-01,   1.98333740e-01],
                        [  1.78070068e-01,   1.78070068e-01],
                        [  1.50238037e-01,   1.50268555e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  5.44433594e-02,   5.44128418e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -5.72204590e-02,  -5.72509766e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -3.95507812e-02,  -3.95202637e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  5.76782227e-02,   5.76477051e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  2.43530273e-02,   2.43835449e-02],
                        [  2.98461914e-02,   2.98156738e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  3.13720703e-02,   3.14025879e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.75671387e-02,   3.75366211e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  4.48913574e-02,   4.49218750e-02],
                        [  4.19311523e-02,   4.19006348e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  2.21862793e-02,   2.22167969e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.41601562e-02,  -1.41296387e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.01721191e-02,  -2.01416016e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -4.34265137e-02,  -4.33959961e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -2.77404785e-02,  -2.77099609e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.01318359e-02,  -1.01013184e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [ -1.48620605e-02,  -1.48925781e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -3.14331055e-03,  -3.11279297e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [  2.59399414e-03,   2.56347656e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  2.26135254e-02,   2.26440430e-02],
                        [  3.40881348e-02,   3.40576172e-02],
                        [  4.30908203e-02,   4.30908203e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  1.11328125e-01,   1.11358643e-01],
                        [  1.31072998e-01,   1.31072998e-01],
                        [  1.35162354e-01,   1.35162354e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  4.67224121e-02,   4.67224121e-02],
                        [ -4.74243164e-02,  -4.74548340e-02],
                        [ -1.53686523e-01,  -1.53656006e-01],
                        [ -2.46520996e-01,  -2.46520996e-01],
                        [ -3.01452637e-01,  -3.01452637e-01],
                        [ -3.04534912e-01,  -3.04534912e-01],
                        [ -2.63336182e-01,  -2.63305664e-01],
                        [ -2.06848145e-01,  -2.06848145e-01],
                        [ -1.65649414e-01,  -1.65649414e-01],
                        [ -1.47949219e-01,  -1.47918701e-01],
                        [ -1.39709473e-01,  -1.39709473e-01],
                        [ -1.27288818e-01,  -1.27288818e-01],
                        [ -1.10321045e-01,  -1.10321045e-01],
                        [ -9.19799805e-02,  -9.19799805e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  1.16821289e-01,   1.16821289e-01],
                        [  1.84783936e-01,   1.84753418e-01],
                        [  2.21374512e-01,   2.21374512e-01],
                        [  2.20275879e-01,   2.20275879e-01],
                        [  1.93695068e-01,   1.93664551e-01],
                        [  1.59149170e-01,   1.59149170e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  7.97424316e-02,   7.97424316e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [ -2.40783691e-02,  -2.40478516e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.16882324e-02,   1.16577148e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  4.40368652e-02,   4.40673828e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  6.78710938e-02,   6.78710938e-02],
                        [  7.26928711e-02,   7.26928711e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  5.76477051e-02,   5.76171875e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  2.71606445e-02,   2.71911621e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  2.67944336e-02,   2.68249512e-02],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.86462402e-02,  -1.86767578e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -2.39562988e-02,  -2.39257812e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -3.00598145e-02,  -3.00903320e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.56042480e-02,  -2.56347656e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -7.38525391e-03,  -7.41577148e-03],
                        [ -8.85009766e-03,  -8.85009766e-03],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -1.45263672e-02,  -1.45568848e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -3.44848633e-03,  -3.41796875e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  1.92260742e-03,   1.95312500e-03],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  3.43017578e-02,   3.42712402e-02],
                        [  5.42602539e-02,   5.42602539e-02],
                        [  7.50732422e-02,   7.50732422e-02],
                        [  9.60998535e-02,   9.60693359e-02],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -1.33178711e-01,  -1.33178711e-01],
                        [ -2.22320557e-01,  -2.22320557e-01],
                        [ -2.79479980e-01,  -2.79510498e-01],
                        [ -2.83966064e-01,  -2.83966064e-01],
                        [ -2.42034912e-01,  -2.42004395e-01],
                        [ -1.88690186e-01,  -1.88690186e-01],
                        [ -1.57043457e-01,  -1.57043457e-01],
                        [ -1.51214600e-01,  -1.51214600e-01],
                        [ -1.53991699e-01,  -1.53991699e-01],
                        [ -1.50360107e-01,  -1.50390625e-01],
                        [ -1.36871338e-01,  -1.36871338e-01],
                        [ -1.15142822e-01,  -1.15112305e-01],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  1.68548584e-01,   1.68548584e-01],
                        [  2.21618652e-01,   2.21649170e-01],
                        [  2.42187500e-01,   2.42187500e-01],
                        [  2.25891113e-01,   2.25891113e-01],
                        [  1.76696777e-01,   1.76696777e-01],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  3.36608887e-02,   3.36608887e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -4.66613770e-02,  -4.66308594e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  8.94165039e-03,   8.91113281e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  8.78906250e-03,   8.75854492e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  1.02539062e-02,   1.02233887e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  6.85729980e-02,   6.85729980e-02],
                        [  4.89501953e-02,   4.89807129e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.21459961e-02,   1.21154785e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  1.55334473e-02,   1.55639648e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  2.12707520e-02,   2.12402344e-02],
                        [  2.80456543e-02,   2.80761719e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  4.75769043e-02,   4.75769043e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -1.52893066e-02,  -1.52587891e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  3.87573242e-03,   3.90625000e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.20391846e-01,   1.20391846e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.29425049e-01,   1.29425049e-01],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  5.54504395e-02,   5.54504395e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -1.29730225e-01,  -1.29730225e-01],
                        [ -2.29156494e-01,  -2.29156494e-01],
                        [ -2.93914795e-01,  -2.93914795e-01],
                        [ -3.00506592e-01,  -3.00506592e-01],
                        [ -2.55615234e-01,  -2.55615234e-01],
                        [ -1.94793701e-01,  -1.94793701e-01],
                        [ -1.51214600e-01,  -1.51184082e-01],
                        [ -1.30828857e-01,  -1.30828857e-01],
                        [ -1.21093750e-01,  -1.21093750e-01],
                        [ -1.12396240e-01,  -1.12365723e-01],
                        [ -1.03851318e-01,  -1.03851318e-01],
                        [ -9.59472656e-02,  -9.59472656e-02],
                        [ -8.23364258e-02,  -8.23364258e-02],
                        [ -4.97741699e-02,  -4.97741699e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  1.70471191e-01,   1.70471191e-01],
                        [  2.26867676e-01,   2.26867676e-01],
                        [  2.42706299e-01,   2.42706299e-01],
                        [  2.12371826e-01,   2.12402344e-01],
                        [  1.46423340e-01,   1.46423340e-01],
                        [  6.72302246e-02,   6.72302246e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -2.74658203e-02,  -2.74353027e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.80358887e-02,   1.80664062e-02],
                        [  2.32849121e-02,   2.33154297e-02],
                        [  1.65405273e-02,   1.65100098e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  8.20922852e-02,   8.20922852e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  4.22363281e-02,   4.22058105e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  2.72521973e-02,   2.72827148e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.21862793e-02,  -2.22167969e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.51159668e-02,  -2.51464844e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  6.81457520e-02,   6.81457520e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  1.24084473e-01,   1.24084473e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -1.52740479e-01,  -1.52740479e-01],
                        [ -2.42706299e-01,  -2.42706299e-01],
                        [ -2.94830322e-01,  -2.94830322e-01],
                        [ -2.91961670e-01,  -2.91961670e-01],
                        [ -2.43713379e-01,  -2.43713379e-01],
                        [ -1.83197021e-01,  -1.83197021e-01],
                        [ -1.40319824e-01,  -1.40319824e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -1.10382080e-01,  -1.10382080e-01],
                        [ -1.03118896e-01,  -1.03118896e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -7.87963867e-02,  -7.88269043e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  1.56402588e-01,   1.56402588e-01],
                        [  2.16247559e-01,   2.16247559e-01],
                        [  2.29583740e-01,   2.29614258e-01],
                        [  1.87988281e-01,   1.87957764e-01],
                        [  1.06994629e-01,   1.06964111e-01],
                        [  2.09045410e-02,   2.09045410e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  5.92651367e-02,   5.92651367e-02],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  9.59777832e-02,   9.59777832e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  4.48913574e-02,   4.48913574e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.55029297e-02,   1.55334473e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.54724121e-02,   1.54418945e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  5.30700684e-02,   5.30700684e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  1.11968994e-01,   1.11968994e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  5.07202148e-02,   5.07202148e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -1.25732422e-01,  -1.25732422e-01],
                        [ -2.22564697e-01,  -2.22564697e-01],
                        [ -2.85614014e-01,  -2.85614014e-01],
                        [ -2.87902832e-01,  -2.87902832e-01],
                        [ -2.35656738e-01,  -2.35656738e-01],
                        [ -1.67633057e-01,  -1.67633057e-01],
                        [ -1.22222900e-01,  -1.22222900e-01],
                        [ -1.08489990e-01,  -1.08489990e-01],
                        [ -1.10290527e-01,  -1.10290527e-01],
                        [ -1.10656738e-01,  -1.10687256e-01],
                        [ -1.03790283e-01,  -1.03790283e-01],
                        [ -9.11560059e-02,  -9.11560059e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  1.03027344e-01,   1.02996826e-01],
                        [  1.53778076e-01,   1.53778076e-01],
                        [  1.69830322e-01,   1.69830322e-01],
                        [  1.42395020e-01,   1.42395020e-01],
                        [  8.28857422e-02,   8.28857422e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  4.27551270e-02,   4.27246094e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  2.97241211e-02,   2.96936035e-02],
                        [  3.28979492e-02,   3.28979492e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  9.26513672e-02,   9.26513672e-02],
                        [  1.14776611e-01,   1.14776611e-01],
                        [  1.31225586e-01,   1.31225586e-01],
                        [  1.31225586e-01,   1.31225586e-01],
                        [  1.05468750e-01,   1.05468750e-01],
                        [  5.19714355e-02,   5.19714355e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -1.23504639e-01,  -1.23504639e-01],
                        [ -2.17620850e-01,  -2.17620850e-01],
                        [ -2.77435303e-01,  -2.77435303e-01],
                        [ -2.81677246e-01,  -2.81677246e-01],
                        [ -2.40173340e-01,  -2.40173340e-01],
                        [ -1.86523438e-01,  -1.86523438e-01],
                        [ -1.48223877e-01,  -1.48223877e-01],
                        [ -1.28295898e-01,  -1.28295898e-01],
                        [ -1.15997314e-01,  -1.15997314e-01],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -9.39025879e-02,  -9.39025879e-02],
                        [ -8.10546875e-02,  -8.10852051e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  1.00830078e-01,   1.00830078e-01],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.22167969e-02,   2.22473145e-02],
                        [  2.62145996e-02,   2.61840820e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  8.39843750e-02,   8.39843750e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  5.70373535e-02,   5.70373535e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -1.86157227e-02,  -1.86157227e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.06933594e-01,   1.06933594e-01],
                        [  1.23077393e-01,   1.23077393e-01],
                        [  1.21429443e-01,   1.21429443e-01],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -1.27410889e-01,  -1.27410889e-01],
                        [ -2.22808838e-01,  -2.22808838e-01],
                        [ -2.83325195e-01,  -2.83325195e-01],
                        [ -2.89672852e-01,  -2.89672852e-01],
                        [ -2.48413086e-01,  -2.48413086e-01],
                        [ -1.88018799e-01,  -1.88018799e-01],
                        [ -1.39434814e-01,  -1.39434814e-01],
                        [ -1.13372803e-01,  -1.13372803e-01],
                        [ -9.86022949e-02,  -9.86022949e-02],
                        [ -8.33435059e-02,  -8.33435059e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.15356445e-01,   1.15356445e-01],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  3.69567871e-02,   3.69567871e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  1.26098633e-01,   1.26098633e-01],
                        [  1.34429932e-01,   1.34429932e-01],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -1.42333984e-01,  -1.42333984e-01],
                        [ -2.30163574e-01,  -2.30163574e-01],
                        [ -2.81341553e-01,  -2.81341553e-01],
                        [ -2.79418945e-01,  -2.79418945e-01],
                        [ -2.31750488e-01,  -2.31750488e-01],
                        [ -1.70898438e-01,  -1.70898438e-01],
                        [ -1.30828857e-01,  -1.30828857e-01],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -1.04949951e-01,  -1.04949951e-01],
                        [ -8.42285156e-02,  -8.42285156e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  4.41284180e-02,   4.41284180e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  9.19799805e-02,   9.19799805e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  7.07092285e-02,   7.07092285e-02],
                        [  5.63659668e-02,   5.63659668e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  1.29730225e-01,   1.29730225e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -1.23413086e-01,  -1.23413086e-01],
                        [ -2.18444824e-01,  -2.18444824e-01],
                        [ -2.83264160e-01,  -2.83264160e-01],
                        [ -2.87597656e-01,  -2.87597656e-01],
                        [ -2.34619141e-01,  -2.34619141e-01],
                        [ -1.62139893e-01,  -1.62139893e-01],
                        [ -1.08459473e-01,  -1.08459473e-01],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -7.28149414e-02,  -7.28149414e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -9.51232910e-02,  -9.51232910e-02],
                        [ -9.90905762e-02,  -9.90905762e-02],
                        [ -8.05664062e-02,  -8.05664062e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  8.03527832e-02,   8.03527832e-02],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  1.14959717e-01,   1.14959717e-01],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  1.14410400e-01,   1.14410400e-01],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  7.89184570e-02,   7.89184570e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -3.77502441e-02,  -3.77197266e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  5.56640625e-02,   5.56640625e-02],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  1.20727539e-01,   1.20727539e-01],
                        [  1.35559082e-01,   1.35559082e-01],
                        [  1.33941650e-01,   1.33941650e-01],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  4.27246094e-02,   4.27246094e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -1.38916016e-01,  -1.38916016e-01],
                        [ -2.17559814e-01,  -2.17559814e-01],
                        [ -2.60894775e-01,  -2.60894775e-01],
                        [ -2.56408691e-01,  -2.56408691e-01],
                        [ -2.10906982e-01,  -2.10906982e-01],
                        [ -1.51977539e-01,  -1.51947021e-01],
                        [ -1.08337402e-01,  -1.08337402e-01],
                        [ -8.75549316e-02,  -8.75549316e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -7.33642578e-02,  -7.33642578e-02],
                        [ -1.07971191e-01,  -1.07971191e-01],
                        [ -1.34735107e-01,  -1.34735107e-01],
                        [ -1.41296387e-01,  -1.41296387e-01],
                        [ -1.18438721e-01,  -1.18438721e-01],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  8.92639160e-02,   8.92639160e-02],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  1.15325928e-01,   1.15325928e-01],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  5.51452637e-02,   5.51452637e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  1.12426758e-01,   1.12457275e-01],
                        [  5.99670410e-02,   5.99670410e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.17919922e-01,  -1.17919922e-01],
                        [ -2.09442139e-01,  -2.09442139e-01],
                        [ -2.69561768e-01,  -2.69561768e-01],
                        [ -2.79541016e-01,  -2.79541016e-01],
                        [ -2.41851807e-01,  -2.41851807e-01],
                        [ -1.81671143e-01,  -1.81671143e-01],
                        [ -1.27258301e-01,  -1.27258301e-01],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -1.16241455e-01,  -1.16241455e-01],
                        [ -1.56799316e-01,  -1.56799316e-01],
                        [ -1.76544189e-01,  -1.76544189e-01],
                        [ -1.64428711e-01,  -1.64428711e-01],
                        [ -1.19293213e-01,  -1.19293213e-01],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  8.77075195e-02,   8.77075195e-02],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  1.43920898e-01,   1.43920898e-01],
                        [  1.39495850e-01,   1.39495850e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  7.90710449e-02,   7.90710449e-02],
                        [  6.29882812e-02,   6.29882812e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  1.07269287e-01,   1.07269287e-01],
                        [  1.21276855e-01,   1.21276855e-01],
                        [  1.26251221e-01,   1.26251221e-01],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  6.97937012e-02,   6.97937012e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  6.99462891e-02,   6.99462891e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.30090332e-02,  -5.29785156e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.43249512e-01,   1.43249512e-01],
                        [  1.45812988e-01,   1.45812988e-01],
                        [  1.21246338e-01,   1.21246338e-01],
                        [  6.75659180e-02,   6.75659180e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.08032227e-01,  -1.08032227e-01],
                        [ -2.03063965e-01,  -2.03063965e-01],
                        [ -2.69409180e-01,  -2.69409180e-01],
                        [ -2.84667969e-01,  -2.84667969e-01],
                        [ -2.48565674e-01,  -2.48565674e-01],
                        [ -1.86340332e-01,  -1.86340332e-01],
                        [ -1.30126953e-01,  -1.30126953e-01],
                        [ -9.46350098e-02,  -9.46350098e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -1.06048584e-01,  -1.06048584e-01],
                        [ -1.54418945e-01,  -1.54418945e-01],
                        [ -1.89849854e-01,  -1.89849854e-01],
                        [ -1.97540283e-01,  -1.97540283e-01],
                        [ -1.74987793e-01,  -1.74987793e-01],
                        [ -1.28387451e-01,  -1.28387451e-01],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  1.36535645e-01,   1.36535645e-01],
                        [  1.46057129e-01,   1.46057129e-01],
                        [  1.29821777e-01,   1.29821777e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  7.86743164e-02,   7.86743164e-02],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  1.01379395e-01,   1.01379395e-01],
                        [  1.14044189e-01,   1.14044189e-01],
                        [  1.26220703e-01,   1.26220703e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  9.14306641e-02,   9.14306641e-02],
                        [  7.86743164e-02,   7.86743164e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  7.29370117e-03,   7.32421875e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  8.34350586e-02,   8.34350586e-02],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.46209717e-01,   1.46209717e-01],
                        [  1.53991699e-01,   1.53991699e-01],
                        [  1.33636475e-01,   1.33636475e-01],
                        [  8.07189941e-02,   8.07189941e-02],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -1.03363037e-01,  -1.03363037e-01],
                        [ -2.04650879e-01,  -2.04650879e-01],
                        [ -2.73468018e-01,  -2.73468018e-01],
                        [ -2.84454346e-01,  -2.84454346e-01],
                        [ -2.38616943e-01,  -2.38616943e-01],
                        [ -1.63726807e-01,  -1.63726807e-01],
                        [ -9.53979492e-02,  -9.53979492e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -9.33532715e-02,  -9.33532715e-02],
                        [ -1.40777588e-01,  -1.40777588e-01],
                        [ -1.85943604e-01,  -1.85943604e-01],
                        [ -2.09350586e-01,  -2.09350586e-01],
                        [ -1.98638916e-01,  -1.98638916e-01],
                        [ -1.58721924e-01,  -1.58721924e-01],
                        [ -1.09069824e-01,  -1.09069824e-01],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  1.00067139e-01,   1.00067139e-01],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.17431641e-01,   1.17431641e-01],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  1.28265381e-01,   1.28265381e-01],
                        [  1.44958496e-01,   1.44958496e-01],
                        [  1.50970459e-01,   1.50970459e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  8.40454102e-02,   8.40454102e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  8.40454102e-02,   8.40454102e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  6.79626465e-02,   6.79626465e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.49047852e-01,   1.49047852e-01],
                        [  1.58081055e-01,   1.58081055e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [ -8.56323242e-02,  -8.56323242e-02],
                        [ -1.88720703e-01,  -1.88720703e-01],
                        [ -2.60437012e-01,  -2.60437012e-01],
                        [ -2.76031494e-01,  -2.76031494e-01],
                        [ -2.35717773e-01,  -2.35717773e-01],
                        [ -1.64123535e-01,  -1.64123535e-01],
                        [ -9.55505371e-02,  -9.55505371e-02],
                        [ -5.34973145e-02,  -5.34667969e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -4.74853516e-02,  -4.74853516e-02],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -1.09497070e-01,  -1.09497070e-01],
                        [ -1.57409668e-01,  -1.57409668e-01],
                        [ -1.97570801e-01,  -1.97570801e-01],
                        [ -2.13012695e-01,  -2.13012695e-01],
                        [ -1.98150635e-01,  -1.98150635e-01],
                        [ -1.61926270e-01,  -1.61926270e-01],
                        [ -1.20208740e-01,  -1.20208740e-01],
                        [ -8.29772949e-02,  -8.29772949e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  1.43280029e-01,   1.43280029e-01],
                        [  1.55731201e-01,   1.55731201e-01],
                        [  1.42822266e-01,   1.42822266e-01],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  9.26513672e-02,   9.26513672e-02],
                        [  8.55407715e-02,   8.55407715e-02],
                        [  9.01184082e-02,   9.01184082e-02],
                        [  9.52453613e-02,   9.52453613e-02],
                        [  9.77478027e-02,   9.77478027e-02],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  1.36322021e-01,   1.36322021e-01],
                        [  1.47888184e-01,   1.47888184e-01],
                        [  1.45324707e-01,   1.45324707e-01],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.06079102e-01,   1.06048584e-01],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  8.19702148e-02,   8.19702148e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  6.07299805e-02,   6.07299805e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.69677734e-02,   1.69982910e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -2.25524902e-02,  -2.25219727e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.39868164e-02,  -2.39562988e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  7.90710449e-02,   7.90710449e-02],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.41601562e-01,   1.41601562e-01],
                        [  1.44165039e-01,   1.44165039e-01],
                        [  1.21185303e-01,   1.21185303e-01],
                        [  7.11669922e-02,   7.11669922e-02],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -9.12475586e-02,  -9.12475586e-02],
                        [ -1.82037354e-01,  -1.82037354e-01],
                        [ -2.46765137e-01,  -2.46765137e-01],
                        [ -2.57720947e-01,  -2.57720947e-01],
                        [ -2.12066650e-01,  -2.12066650e-01],
                        [ -1.40716553e-01,  -1.40716553e-01],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -7.29675293e-02,  -7.29675293e-02],
                        [ -8.98132324e-02,  -8.98132324e-02],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -1.39251709e-01,  -1.39251709e-01],
                        [ -1.69250488e-01,  -1.69250488e-01],
                        [ -1.85882568e-01,  -1.85882568e-01],
                        [ -1.79840088e-01,  -1.79840088e-01],
                        [ -1.57592773e-01,  -1.57592773e-01],
                        [ -1.32293701e-01,  -1.32293701e-01],
                        [ -1.10076904e-01,  -1.10076904e-01],
                        [ -8.70666504e-02,  -8.70666504e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  1.21276855e-01,   1.21276855e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.17889404e-01,   1.17889404e-01],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  9.10644531e-02,   9.10644531e-02],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.40838623e-01,   1.40838623e-01],
                        [  1.37847900e-01,   1.37847900e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  8.69140625e-02,   8.69140625e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  3.54003906e-02,   3.53698730e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  1.33911133e-01,   1.33911133e-01],
                        [  1.62994385e-01,   1.62994385e-01],
                        [  1.62963867e-01,   1.62963867e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  6.53686523e-02,   6.53686523e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.08581543e-01,  -1.08581543e-01],
                        [ -1.92382812e-01,  -1.92382812e-01],
                        [ -2.41699219e-01,  -2.41699219e-01],
                        [ -2.37762451e-01,  -2.37762451e-01],
                        [ -1.86859131e-01,  -1.86859131e-01],
                        [ -1.19750977e-01,  -1.19750977e-01],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -8.56018066e-02,  -8.56018066e-02],
                        [ -1.22619629e-01,  -1.22619629e-01],
                        [ -1.59057617e-01,  -1.59057617e-01],
                        [ -1.84967041e-01,  -1.84967041e-01],
                        [ -1.91955566e-01,  -1.91955566e-01],
                        [ -1.77398682e-01,  -1.77398682e-01],
                        [ -1.49261475e-01,  -1.49261475e-01],
                        [ -1.21002197e-01,  -1.21002197e-01],
                        [ -1.00494385e-01,  -1.00494385e-01],
                        [ -8.59375000e-02,  -8.59375000e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  1.37786865e-01,   1.37786865e-01],
                        [  1.52984619e-01,   1.52984619e-01],
                        [  1.43859863e-01,   1.43859863e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  1.04064941e-01,   1.04064941e-01],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  9.80529785e-02,   9.80529785e-02],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.58538818e-01,   1.58538818e-01],
                        [  1.65527344e-01,   1.65527344e-01],
                        [  1.57684326e-01,   1.57684326e-01],
                        [  1.35040283e-01,   1.35040283e-01],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  6.99768066e-02,   6.99768066e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  8.88061523e-03,   8.85009766e-03],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.38244629e-02,   1.37939453e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -1.84631348e-02,  -1.84936523e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.01013184e-02,  -1.00708008e-02],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  4.03137207e-02,   4.03137207e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  1.23352051e-01,   1.23352051e-01],
                        [  1.41906738e-01,   1.41906738e-01],
                        [  1.44165039e-01,   1.44165039e-01],
                        [  1.20697021e-01,   1.20697021e-01],
                        [  6.89697266e-02,   6.89697266e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -1.73278809e-01,  -1.73278809e-01],
                        [ -2.29797363e-01,  -2.29797363e-01],
                        [ -2.35992432e-01,  -2.35992432e-01],
                        [ -1.91101074e-01,  -1.91101074e-01],
                        [ -1.26373291e-01,  -1.26373291e-01],
                        [ -8.37402344e-02,  -8.37402344e-02],
                        [ -8.42285156e-02,  -8.42285156e-02],
                        [ -1.16973877e-01,  -1.16973877e-01],
                        [ -1.56463623e-01,  -1.56463623e-01],
                        [ -1.84265137e-01,  -1.84265137e-01],
                        [ -1.93725586e-01,  -1.93725586e-01],
                        [ -1.84478760e-01,  -1.84478760e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.35162354e-01,  -1.35162354e-01],
                        [ -1.12670898e-01,  -1.12670898e-01],
                        [ -9.59472656e-02,  -9.59472656e-02],
                        [ -8.36181641e-02,  -8.36181641e-02],
                        [ -7.26318359e-02,  -7.26318359e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  9.24072266e-02,   9.24072266e-02],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.59088135e-01,   1.59088135e-01],
                        [  1.51489258e-01,   1.51489258e-01],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.04248047e-01,   1.04248047e-01],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.72271729e-01,   1.72271729e-01],
                        [  1.70715332e-01,   1.70715332e-01],
                        [  1.56677246e-01,   1.56677246e-01],
                        [  1.34338379e-01,   1.34338379e-01],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  5.60913086e-02,   5.60913086e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.91333008e-02,   4.91333008e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -6.71997070e-02,  -6.71997070e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -6.38732910e-02,  -6.38732910e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.53393555e-02,  -3.53088379e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  1.11816406e-01,   1.11816406e-01],
                        [  1.33666992e-01,   1.33666992e-01],
                        [  1.48559570e-01,   1.48559570e-01],
                        [  1.48590088e-01,   1.48590088e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  7.56530762e-02,   7.56530762e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -9.27429199e-02,  -9.27429199e-02],
                        [ -1.77368164e-01,  -1.77368164e-01],
                        [ -2.28546143e-01,  -2.28546143e-01],
                        [ -2.28210449e-01,  -2.28210449e-01],
                        [ -1.83074951e-01,  -1.83074951e-01],
                        [ -1.27563477e-01,  -1.27563477e-01],
                        [ -9.98229980e-02,  -9.98229980e-02],
                        [ -1.12121582e-01,  -1.12121582e-01],
                        [ -1.47857666e-01,  -1.47857666e-01],
                        [ -1.82342529e-01,  -1.82342529e-01],
                        [ -1.98486328e-01,  -1.98486328e-01],
                        [ -1.90979004e-01,  -1.90979004e-01],
                        [ -1.66259766e-01,  -1.66259766e-01],
                        [ -1.37237549e-01,  -1.37237549e-01],
                        [ -1.14410400e-01,  -1.14410400e-01],
                        [ -1.00555420e-01,  -1.00555420e-01],
                        [ -9.22241211e-02,  -9.22241211e-02],
                        [ -8.42590332e-02,  -8.42590332e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -4.13513184e-02,  -4.13818359e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.61041260e-01,   1.61041260e-01],
                        [  1.61102295e-01,   1.61102295e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.22955322e-01,   1.22955322e-01],
                        [  1.38488770e-01,   1.38458252e-01],
                        [  1.53808594e-01,   1.53808594e-01],
                        [  1.63818359e-01,   1.63818359e-01],
                        [  1.64245605e-01,   1.64245605e-01],
                        [  1.52862549e-01,   1.52862549e-01],
                        [  1.34246826e-01,   1.34246826e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -3.59802246e-02,  -3.60107422e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.61218262e-02,  -5.61523438e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -5.90515137e-02,  -5.90209961e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  2.01416016e-02,   2.01721191e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  6.15539551e-02,   6.15844727e-02],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  1.27136230e-01,   1.27136230e-01],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  1.42425537e-01,   1.42425537e-01],
                        [  1.19598389e-01,   1.19598389e-01],
                        [  6.67419434e-02,   6.67419434e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.04492188e-01,  -1.04492188e-01],
                        [ -1.82128906e-01,  -1.82128906e-01],
                        [ -2.25280762e-01,  -2.25280762e-01],
                        [ -2.23083496e-01,  -2.23083496e-01],
                        [ -1.84967041e-01,  -1.84967041e-01],
                        [ -1.44165039e-01,  -1.44165039e-01],
                        [ -1.36108398e-01,  -1.36108398e-01],
                        [ -1.67053223e-01,  -1.67053223e-01],
                        [ -2.10479736e-01,  -2.10449219e-01],
                        [ -2.32879639e-01,  -2.32879639e-01],
                        [ -2.20855713e-01,  -2.20855713e-01],
                        [ -1.86065674e-01,  -1.86065674e-01],
                        [ -1.49108887e-01,  -1.49108887e-01],
                        [ -1.21948242e-01,  -1.21948242e-01],
                        [ -1.03820801e-01,  -1.03820801e-01],
                        [ -8.71582031e-02,  -8.71582031e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -4.45251465e-02,  -4.44946289e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.56585693e-01,   1.56585693e-01],
                        [  1.69616699e-01,   1.69616699e-01],
                        [  1.56250000e-01,   1.56280518e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  1.05316162e-01,   1.05285645e-01],
                        [  9.85107422e-02,   9.84802246e-02],
                        [  1.11267090e-01,   1.11267090e-01],
                        [  1.37756348e-01,   1.37756348e-01],
                        [  1.66290283e-01,   1.66259766e-01],
                        [  1.84722900e-01,   1.84753418e-01],
                        [  1.87896729e-01,   1.87896729e-01],
                        [  1.77124023e-01,   1.77124023e-01],
                        [  1.55303955e-01,   1.55303955e-01],
                        [  1.26281738e-01,   1.26281738e-01],
                        [  9.69848633e-02,   9.69543457e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.62963867e-02,   1.63269043e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  8.45336914e-03,   8.42285156e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  5.67626953e-03,   5.70678711e-03],
                        [  4.02832031e-03,   4.05883789e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -1.71508789e-02,  -1.71813965e-02],
                        [ -1.95617676e-02,  -1.95922852e-02],
                        [ -2.47192383e-02,  -2.46887207e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -5.57250977e-02,  -5.56945801e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -6.32934570e-02,  -6.33239746e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -5.45654297e-02,  -5.45349121e-02],
                        [ -5.68237305e-02,  -5.68237305e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -5.76782227e-02,  -5.76782227e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [  2.83813477e-03,   2.86865234e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.27050781e-02,   2.26745605e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  9.73510742e-02,   9.73205566e-02],
                        [  1.28936768e-01,   1.28967285e-01],
                        [  1.53198242e-01,   1.53228760e-01],
                        [  1.59362793e-01,   1.59362793e-01],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  9.82055664e-02,   9.82360840e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -1.29821777e-01,  -1.29791260e-01],
                        [ -1.95678711e-01,  -1.95678711e-01],
                        [ -2.24517822e-01,  -2.24517822e-01],
                        [ -2.18017578e-01,  -2.18017578e-01],
                        [ -2.04284668e-01,  -2.04284668e-01],
                        [ -2.08801270e-01,  -2.08801270e-01],
                        [ -2.27600098e-01,  -2.27600098e-01],
                        [ -2.38098145e-01,  -2.38098145e-01],
                        [ -2.26715088e-01,  -2.26715088e-01],
                        [ -1.96929932e-01,  -1.96929932e-01],
                        [ -1.60217285e-01,  -1.60217285e-01],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -1.11022949e-01,  -1.11022949e-01],
                        [ -9.99755859e-02,  -9.99755859e-02],
                        [ -8.28552246e-02,  -8.28552246e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -1.72119141e-02,  -1.72424316e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.42333984e-01,   1.42333984e-01],
                        [  1.41754150e-01,   1.41754150e-01],
                        [  1.34429932e-01,   1.34429932e-01],
                        [  1.30371094e-01,   1.30371094e-01],
                        [  1.37481689e-01,   1.37481689e-01],
                        [  1.59576416e-01,   1.59545898e-01],
                        [  1.88934326e-01,   1.88934326e-01],
                        [  2.08953857e-01,   2.08984375e-01],
                        [  2.09808350e-01,   2.09777832e-01],
                        [  1.94335938e-01,   1.94305420e-01],
                        [  1.69891357e-01,   1.69891357e-01],
                        [  1.42547607e-01,   1.42578125e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  9.50927734e-02,   9.50927734e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  5.81359863e-02,   5.81054688e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  2.23693848e-02,   2.23388672e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.04064941e-02,   1.04370117e-02],
                        [  9.46044922e-03,   9.42993164e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  7.26318359e-03,   7.29370117e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  9.18579102e-03,   9.15527344e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  5.70678711e-03,   5.70678711e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -3.60717773e-02,  -3.61022949e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -4.47082520e-02,  -4.46777344e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -4.69360352e-02,  -4.69665527e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.25109863e-02,  -4.24804688e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -5.78613281e-02,  -5.78918457e-02],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -3.98864746e-02,  -3.99169922e-02],
                        [ -2.94189453e-02,  -2.93884277e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -3.78417969e-03,  -3.81469727e-03],
                        [  3.20434570e-03,   3.23486328e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  1.46484375e-03,   1.43432617e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  3.93676758e-03,   3.96728516e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  1.16027832e-01,   1.16027832e-01],
                        [  1.48376465e-01,   1.48376465e-01],
                        [  1.71997070e-01,   1.71997070e-01],
                        [  1.76818848e-01,   1.76818848e-01],
                        [  1.57897949e-01,   1.57897949e-01],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  4.18701172e-02,   4.18701172e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -1.45172119e-01,  -1.45172119e-01],
                        [ -2.18811035e-01,  -2.18811035e-01],
                        [ -2.58392334e-01,  -2.58392334e-01],
                        [ -2.67700195e-01,  -2.67700195e-01],
                        [ -2.60406494e-01,  -2.60406494e-01],
                        [ -2.49816895e-01,  -2.49816895e-01],
                        [ -2.41760254e-01,  -2.41760254e-01],
                        [ -2.29827881e-01,  -2.29827881e-01],
                        [ -2.02819824e-01,  -2.02819824e-01],
                        [ -1.62445068e-01,  -1.62445068e-01],
                        [ -1.25885010e-01,  -1.25885010e-01],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -7.64465332e-02,  -7.64465332e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -4.54711914e-02,  -4.54406738e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -1.87072754e-02,  -1.87377930e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  1.18743896e-01,   1.18743896e-01],
                        [  1.47521973e-01,   1.47552490e-01],
                        [  1.66992188e-01,   1.67022705e-01],
                        [  1.76544189e-01,   1.76544189e-01],
                        [  1.82373047e-01,   1.82373047e-01],
                        [  1.91497803e-01,   1.91497803e-01],
                        [  2.02789307e-01,   2.02758789e-01],
                        [  2.07611084e-01,   2.07611084e-01],
                        [  1.99798584e-01,   1.99829102e-01],
                        [  1.81945801e-01,   1.81945801e-01],
                        [  1.59973145e-01,   1.59973145e-01],
                        [  1.36627197e-01,   1.36627197e-01],
                        [  1.13647461e-01,   1.13616943e-01],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.83508301e-02,   2.83203125e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  5.64575195e-03,   5.67626953e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  8.54492188e-03,   8.57543945e-03],
                        [  3.41796875e-03,   3.38745117e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -2.02941895e-02,  -2.02941895e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.86254883e-02,  -2.86560059e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -6.37817383e-02,  -6.37512207e-02],
                        [ -6.75659180e-02,  -6.75659180e-02],
                        [ -6.37512207e-02,  -6.37817383e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -5.32836914e-02,  -5.32531738e-02],
                        [ -5.52978516e-02,  -5.53283691e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -1.94702148e-02,  -1.95007324e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.80053711e-03,  -1.77001953e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  3.70788574e-02,   3.70483398e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  6.34155273e-02,   6.33850098e-02],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  1.24359131e-01,   1.24359131e-01],
                        [  1.63482666e-01,   1.63482666e-01],
                        [  1.94702148e-01,   1.94702148e-01],
                        [  2.02392578e-01,   2.02423096e-01],
                        [  1.70471191e-01,   1.70501709e-01],
                        [  9.47265625e-02,   9.47265625e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.35192871e-01,  -1.35192871e-01],
                        [ -2.44598389e-01,  -2.44598389e-01],
                        [ -3.17016602e-01,  -3.17016602e-01],
                        [ -3.38989258e-01,  -3.38989258e-01],
                        [ -3.17871094e-01,  -3.17871094e-01],
                        [ -2.76214600e-01,  -2.76214600e-01],
                        [ -2.34161377e-01,  -2.34161377e-01],
                        [ -1.98028564e-01,  -1.98028564e-01],
                        [ -1.65740967e-01,  -1.65740967e-01],
                        [ -1.38275146e-01,  -1.38275146e-01],
                        [ -1.20269775e-01,  -1.20269775e-01],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -1.01226807e-01,  -1.01257324e-01],
                        [ -8.41979980e-02,  -8.41979980e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -4.46777344e-02,  -4.47082520e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -2.54211426e-02,  -2.53906250e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.58789062e-02,  -2.59094238e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  1.80969238e-02,   1.81274414e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.80541992e-01,   1.80541992e-01],
                        [  1.97937012e-01,   1.97937012e-01],
                        [  2.06604004e-01,   2.06604004e-01],
                        [  2.13104248e-01,   2.13104248e-01],
                        [  2.16186523e-01,   2.16156006e-01],
                        [  2.09777832e-01,   2.09777832e-01],
                        [  1.91253662e-01,   1.91253662e-01],
                        [  1.67205811e-01,   1.67205811e-01],
                        [  1.48803711e-01,   1.48803711e-01],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.32720947e-01,   1.32690430e-01],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  1.05773926e-01,   1.05773926e-01],
                        [  9.00268555e-02,   8.99963379e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  5.58471680e-03,   5.58471680e-03],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  1.86157227e-02,   1.86462402e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -1.37329102e-02,  -1.37634277e-02],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -1.61743164e-03,  -1.64794922e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -3.04870605e-02,  -3.05175781e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.73937988e-02,  -4.73632812e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -6.88781738e-02,  -6.88781738e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -7.29675293e-02,  -7.29675293e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -6.22253418e-02,  -6.21948242e-02],
                        [ -5.80444336e-02,  -5.80749512e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.18200684e-02,   2.17895508e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  8.49609375e-02,   8.49609375e-02],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.68975830e-01,   1.68975830e-01],
                        [  2.06054688e-01,   2.06054688e-01],
                        [  2.13562012e-01,   2.13562012e-01],
                        [  1.81884766e-01,   1.81884766e-01],
                        [  1.08947754e-01,   1.08947754e-01],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -1.39709473e-01,  -1.39709473e-01],
                        [ -2.74017334e-01,  -2.74017334e-01],
                        [ -3.68377686e-01,  -3.68377686e-01],
                        [ -3.96087646e-01,  -3.96087646e-01],
                        [ -3.61175537e-01,  -3.61175537e-01],
                        [ -2.95440674e-01,  -2.95440674e-01],
                        [ -2.31842041e-01,  -2.31842041e-01],
                        [ -1.85455322e-01,  -1.85455322e-01],
                        [ -1.55883789e-01,  -1.55883789e-01],
                        [ -1.35742188e-01,  -1.35742188e-01],
                        [ -1.17218018e-01,  -1.17218018e-01],
                        [ -9.79614258e-02,  -9.79309082e-02],
                        [ -8.16650391e-02,  -8.16650391e-02],
                        [ -7.10754395e-02,  -7.10754395e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -3.69567871e-02,  -3.69873047e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [  1.05895996e-02,   1.05590820e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  1.25305176e-01,   1.25305176e-01],
                        [  1.80877686e-01,   1.80847168e-01],
                        [  2.21923828e-01,   2.21923828e-01],
                        [  2.45605469e-01,   2.45605469e-01],
                        [  2.52044678e-01,   2.52044678e-01],
                        [  2.45452881e-01,   2.45422363e-01],
                        [  2.31170654e-01,   2.31170654e-01],
                        [  2.12066650e-01,   2.12066650e-01],
                        [  1.90124512e-01,   1.90093994e-01],
                        [  1.68609619e-01,   1.68640137e-01],
                        [  1.50543213e-01,   1.50543213e-01],
                        [  1.35314941e-01,   1.35284424e-01],
                        [  1.18682861e-01,   1.18652344e-01],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  7.99560547e-03,   7.96508789e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  1.95312500e-02,   1.95617676e-02],
                        [  1.04064941e-02,   1.03759766e-02],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  5.18798828e-03,   5.15747070e-03],
                        [  7.72094727e-03,   7.75146484e-03],
                        [  8.85009766e-03,   8.88061523e-03],
                        [  6.01196289e-03,   5.98144531e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -8.11767578e-03,  -8.08715820e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -6.36291504e-02,  -6.35986328e-02],
                        [ -5.82275391e-02,  -5.81970215e-02],
                        [ -5.15747070e-02,  -5.16052246e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.43518066e-02,  -5.43212891e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -6.79931641e-02,  -6.80236816e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -2.68859863e-02,  -2.68554688e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -2.23083496e-02,  -2.23388672e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.42614746e-02,  -2.42919922e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.36511230e-02,  -2.36206055e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -8.33129883e-03,  -8.30078125e-03],
                        [  1.15966797e-03,   1.12915039e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  5.01403809e-02,   5.01098633e-02],
                        [  5.70983887e-02,   5.71289062e-02],
                        [  6.62536621e-02,   6.62841797e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.34796143e-01,   1.34796143e-01],
                        [  1.70562744e-01,   1.70562744e-01],
                        [  1.99859619e-01,   1.99859619e-01],
                        [  2.07153320e-01,   2.07153320e-01],
                        [  1.77337646e-01,   1.77337646e-01],
                        [  1.01226807e-01,   1.01196289e-01],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.72821045e-01,  -1.72821045e-01],
                        [ -3.16619873e-01,  -3.16619873e-01],
                        [ -4.07073975e-01,  -4.07073975e-01],
                        [ -4.19342041e-01,  -4.19311523e-01],
                        [ -3.65417480e-01,  -3.65417480e-01],
                        [ -2.82318115e-01,  -2.82318115e-01],
                        [ -2.07580566e-01,  -2.07550049e-01],
                        [ -1.60430908e-01,  -1.60430908e-01],
                        [ -1.35131836e-01,  -1.35162354e-01],
                        [ -1.13555908e-01,  -1.13525391e-01],
                        [ -8.72497559e-02,  -8.72497559e-02],
                        [ -6.43920898e-02,  -6.43920898e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.79833984e-02,  -5.79528809e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -1.30920410e-02,  -1.30615234e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  6.16455078e-03,   6.13403320e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -5.33752441e-02,  -5.34057617e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -5.18493652e-02,  -5.18188477e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [  3.57666016e-02,   3.57360840e-02],
                        [  1.04187012e-01,   1.04217529e-01],
                        [  1.77032471e-01,   1.77032471e-01],
                        [  2.38403320e-01,   2.38403320e-01],
                        [  2.72918701e-01,   2.72918701e-01],
                        [  2.78350830e-01,   2.78381348e-01],
                        [  2.67395020e-01,   2.67395020e-01],
                        [  2.51953125e-01,   2.51953125e-01],
                        [  2.32818604e-01,   2.32818604e-01],
                        [  2.07763672e-01,   2.07763672e-01],
                        [  1.80389404e-01,   1.80358887e-01],
                        [  1.55120850e-01,   1.55120850e-01],
                        [  1.30950928e-01,   1.30950928e-01],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  8.29772949e-02,   8.29467773e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  1.90124512e-02,   1.90429688e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  1.68457031e-02,   1.68151855e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.67541504e-02,   1.67846680e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [ -4.88281250e-03,  -4.91333008e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.73034668e-02,  -1.72729492e-02],
                        [ -1.98364258e-02,  -1.98669434e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -4.94384766e-03,  -4.97436523e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.19018555e-02,  -1.18713379e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.94897461e-02,  -3.95202637e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -4.66613770e-02,  -4.66308594e-02],
                        [ -4.74548340e-02,  -4.74853516e-02],
                        [ -4.97131348e-02,  -4.97436523e-02],
                        [ -5.20629883e-02,  -5.20324707e-02],
                        [ -5.41076660e-02,  -5.41076660e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.41479492e-02,  -6.41479492e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -7.07397461e-02,  -7.07397461e-02],
                        [ -7.05871582e-02,  -7.06176758e-02],
                        [ -6.78710938e-02,  -6.78710938e-02],
                        [ -6.35681152e-02,  -6.35681152e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -4.98962402e-02,  -4.98657227e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -1.87072754e-02,  -1.87377930e-02],
                        [ -1.01013184e-02,  -1.00708008e-02],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  3.49426270e-02,   3.49121094e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  4.91638184e-02,   4.91943359e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  1.54174805e-01,   1.54174805e-01],
                        [  1.85394287e-01,   1.85394287e-01],
                        [  1.95648193e-01,   1.95617676e-01],
                        [  1.74743652e-01,   1.74743652e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.69067383e-02,   1.69067383e-02],
                        [ -1.09954834e-01,  -1.09954834e-01],
                        [ -2.46826172e-01,  -2.46795654e-01],
                        [ -3.59619141e-01,  -3.59649658e-01],
                        [ -4.07806396e-01,  -4.07806396e-01],
                        [ -3.77410889e-01,  -3.77410889e-01],
                        [ -2.99255371e-01,  -2.99255371e-01],
                        [ -2.22808838e-01,  -2.22808838e-01],
                        [ -1.76483154e-01,  -1.76483154e-01],
                        [ -1.55120850e-01,  -1.55120850e-01],
                        [ -1.37664795e-01,  -1.37695312e-01],
                        [ -1.12792969e-01,  -1.12792969e-01],
                        [ -8.74633789e-02,  -8.74633789e-02],
                        [ -7.27233887e-02,  -7.27233887e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -2.46887207e-02,  -2.47192383e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  9.90295410e-02,   9.90295410e-02],
                        [  1.71752930e-01,   1.71752930e-01],
                        [  2.38433838e-01,   2.38433838e-01],
                        [  2.81066895e-01,   2.81066895e-01],
                        [  2.89428711e-01,   2.89428711e-01],
                        [  2.69531250e-01,   2.69531250e-01],
                        [  2.36968994e-01,   2.36999512e-01],
                        [  2.05902100e-01,   2.05871582e-01],
                        [  1.82037354e-01,   1.82037354e-01],
                        [  1.63421631e-01,   1.63452148e-01],
                        [  1.46453857e-01,   1.46423340e-01],
                        [  1.30462646e-01,   1.30462646e-01],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  1.01715088e-01,   1.01745605e-01],
                        [  8.43200684e-02,   8.42895508e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  4.60815430e-03,   4.57763672e-03],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.80761719e-02,   2.80456543e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  3.09753418e-02,   3.10058594e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -6.74438477e-03,  -6.71386719e-03],
                        [ -2.19726562e-03,  -2.22778320e-03],
                        [  2.44140625e-03,   2.41088867e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.55029297e-02,  -1.54724121e-02],
                        [ -2.08129883e-02,  -2.08435059e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.64990234e-02,  -3.65295410e-02],
                        [ -3.42102051e-02,  -3.42407227e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.75976562e-02,  -3.76281738e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -6.08520508e-02,  -6.08215332e-02],
                        [ -6.70166016e-02,  -6.70471191e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -5.58166504e-02,  -5.57861328e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -6.10351562e-02,  -6.10046387e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  1.12365723e-01,   1.12365723e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.66503906e-01,   1.66503906e-01],
                        [  1.86706543e-01,   1.86706543e-01],
                        [  1.83776855e-01,   1.83776855e-01],
                        [  1.47979736e-01,   1.47979736e-01],
                        [  7.51342773e-02,   7.51342773e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -1.69006348e-01,  -1.69006348e-01],
                        [ -2.97912598e-01,  -2.97912598e-01],
                        [ -3.82019043e-01,  -3.81988525e-01],
                        [ -3.97155762e-01,  -3.97155762e-01],
                        [ -3.51074219e-01,  -3.51074219e-01],
                        [ -2.76306152e-01,  -2.76275635e-01],
                        [ -2.07672119e-01,  -2.07672119e-01],
                        [ -1.62597656e-01,  -1.62597656e-01],
                        [ -1.36749268e-01,  -1.36749268e-01],
                        [ -1.16851807e-01,  -1.16821289e-01],
                        [ -9.68017578e-02,  -9.68322754e-02],
                        [ -8.05358887e-02,  -8.05358887e-02],
                        [ -7.06176758e-02,  -7.05871582e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -4.37927246e-02,  -4.38232422e-02],
                        [ -2.21252441e-02,  -2.20947266e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  1.08642578e-02,   1.08337402e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -4.37316895e-02,  -4.37011719e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -5.44433594e-02,  -5.44738770e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  1.05468750e-01,   1.05468750e-01],
                        [  1.90368652e-01,   1.90368652e-01],
                        [  2.61871338e-01,   2.61871338e-01],
                        [  3.02062988e-01,   3.02062988e-01],
                        [  3.03161621e-01,   3.03131104e-01],
                        [  2.73498535e-01,   2.73498535e-01],
                        [  2.34863281e-01,   2.34863281e-01],
                        [  2.05535889e-01,   2.05535889e-01],
                        [  1.86828613e-01,   1.86828613e-01],
                        [  1.71081543e-01,   1.71081543e-01],
                        [  1.55609131e-01,   1.55609131e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  4.48303223e-02,   4.48608398e-02],
                        [  1.88293457e-02,   1.87988281e-02],
                        [  2.31933594e-03,   2.31933594e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  3.45458984e-02,   3.45764160e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  3.10974121e-02,   3.10668945e-02],
                        [  2.63061523e-02,   2.63366699e-02],
                        [  2.15759277e-02,   2.16064453e-02],
                        [  1.75170898e-02,   1.74865723e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.54418945e-02,   1.54113770e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -4.17480469e-02,  -4.17175293e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -7.14721680e-02,  -7.14721680e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -6.31408691e-02,  -6.31103516e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -5.77392578e-02,  -5.77392578e-02],
                        [ -6.02416992e-02,  -6.02722168e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -5.22460938e-02,  -5.22155762e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.49731445e-02,  -3.50036621e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -1.40991211e-02,  -1.41296387e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -8.66699219e-03,  -8.69750977e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  1.03454590e-02,   1.03759766e-02],
                        [  2.23388672e-02,   2.23083496e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  4.11987305e-02,   4.12292480e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  5.85327148e-02,   5.85021973e-02],
                        [  7.26623535e-02,   7.26928711e-02],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  1.08978271e-01,   1.08947754e-01],
                        [  1.35406494e-01,   1.35406494e-01],
                        [  1.65954590e-01,   1.65954590e-01],
                        [  1.88079834e-01,   1.88049316e-01],
                        [  1.85424805e-01,   1.85394287e-01],
                        [  1.45416260e-01,   1.45416260e-01],
                        [  6.31713867e-02,   6.31713867e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -1.88415527e-01,  -1.88415527e-01],
                        [ -3.06335449e-01,  -3.06335449e-01],
                        [ -3.77380371e-01,  -3.77380371e-01],
                        [ -3.85498047e-01,  -3.85498047e-01],
                        [ -3.39721680e-01,  -3.39721680e-01],
                        [ -2.69042969e-01,  -2.69042969e-01],
                        [ -2.04956055e-01,  -2.04956055e-01],
                        [ -1.62628174e-01,  -1.62628174e-01],
                        [ -1.36932373e-01,  -1.36932373e-01],
                        [ -1.15997314e-01,  -1.15997314e-01],
                        [ -9.50317383e-02,  -9.50317383e-02],
                        [ -7.70874023e-02,  -7.70874023e-02],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -2.70996094e-02,  -2.71301270e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -7.12280273e-02,  -7.12280273e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  9.91210938e-02,   9.91210938e-02],
                        [  1.87255859e-01,   1.87255859e-01],
                        [  2.68218994e-01,   2.68218994e-01],
                        [  3.19061279e-01,   3.19061279e-01],
                        [  3.26110840e-01,   3.26110840e-01],
                        [  2.95654297e-01,   2.95654297e-01],
                        [  2.48443604e-01,   2.48443604e-01],
                        [  2.03094482e-01,   2.03094482e-01],
                        [  1.67419434e-01,   1.67419434e-01],
                        [  1.41662598e-01,   1.41662598e-01],
                        [  1.24053955e-01,   1.24053955e-01],
                        [  1.12670898e-01,   1.12670898e-01],
                        [  1.05926514e-01,   1.05926514e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  9.48791504e-02,   9.48791504e-02],
                        [  7.84301758e-02,   7.84606934e-02],
                        [  5.35888672e-02,   5.35583496e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  1.92260742e-02,   1.92565918e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  1.55029297e-02,   1.54724121e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  2.23083496e-02,   2.23388672e-02],
                        [  2.54516602e-02,   2.54211426e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.49328613e-02,   2.49633789e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.73437500e-02,   2.73742676e-02],
                        [  2.19421387e-02,   2.19116211e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.30810547e-02,  -3.30810547e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -6.61926270e-02,  -6.61926270e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.55725098e-02,  -5.56030273e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -2.99682617e-02,  -2.99987793e-02],
                        [ -2.59399414e-02,  -2.59094238e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.36206055e-02,  -2.35900879e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  1.17736816e-01,   1.17706299e-01],
                        [  1.48284912e-01,   1.48284912e-01],
                        [  1.69250488e-01,   1.69250488e-01],
                        [  1.67266846e-01,   1.67236328e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  7.69958496e-02,   7.69958496e-02],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -1.02447510e-01,  -1.02447510e-01],
                        [ -2.01934814e-01,  -2.01904297e-01],
                        [ -2.88818359e-01,  -2.88818359e-01],
                        [ -3.45092773e-01,  -3.45092773e-01],
                        [ -3.56781006e-01,  -3.56750488e-01],
                        [ -3.23638916e-01,  -3.23638916e-01],
                        [ -2.63214111e-01,  -2.63214111e-01],
                        [ -2.01965332e-01,  -2.01995850e-01],
                        [ -1.57928467e-01,  -1.57928467e-01],
                        [ -1.29699707e-01,  -1.29699707e-01],
                        [ -1.05010986e-01,  -1.05010986e-01],
                        [ -7.94372559e-02,  -7.94372559e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -4.65087891e-02,  -4.65393066e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -6.15234375e-02,  -6.15539551e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -5.74035645e-02,  -5.73730469e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.86981201e-01,   1.86981201e-01],
                        [  2.56988525e-01,   2.56988525e-01],
                        [  2.97882080e-01,   2.97882080e-01],
                        [  2.99743652e-01,   2.99774170e-01],
                        [  2.72033691e-01,   2.72003174e-01],
                        [  2.33428955e-01,   2.33428955e-01],
                        [  1.97418213e-01,   1.97418213e-01],
                        [  1.68762207e-01,   1.68762207e-01],
                        [  1.47399902e-01,   1.47399902e-01],
                        [  1.30493164e-01,   1.30493164e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  8.11767578e-02,   8.11767578e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.43225098e-02,   2.42919922e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  2.17895508e-02,   2.18200684e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  1.65405273e-02,   1.65100098e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  5.18798828e-03,   5.15747070e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.61743164e-03,  -1.64794922e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  6.77490234e-03,   6.80541992e-03],
                        [ -6.10351562e-05,  -9.15527344e-05],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -7.59887695e-03,  -7.56835938e-03],
                        [ -7.78198242e-03,  -7.81250000e-03],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.46179199e-02,  -1.45874023e-02],
                        [ -2.03552246e-02,  -2.03857422e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.98156738e-02,  -2.97851562e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.67932129e-02,  -5.67626953e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -6.55212402e-02,  -6.55212402e-02],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -7.67211914e-02,  -7.66906738e-02],
                        [ -7.36694336e-02,  -7.36694336e-02],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -2.95104980e-02,  -2.95410156e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -2.68859863e-02,  -2.68554688e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -1.11694336e-02,  -1.11999512e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  1.52893066e-02,   1.53198242e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  4.96215820e-02,   4.96520996e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  8.34350586e-02,   8.34350586e-02],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  1.22283936e-01,   1.22283936e-01],
                        [  1.38763428e-01,   1.38763428e-01],
                        [  1.49810791e-01,   1.49780273e-01],
                        [  1.47491455e-01,   1.47521973e-01],
                        [  1.23260498e-01,   1.23260498e-01],
                        [  7.61413574e-02,   7.61108398e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -1.48437500e-01,  -1.48437500e-01],
                        [ -2.33825684e-01,  -2.33825684e-01],
                        [ -3.08044434e-01,  -3.08013916e-01],
                        [ -3.52264404e-01,  -3.52294922e-01],
                        [ -3.50250244e-01,  -3.50250244e-01],
                        [ -3.03314209e-01,  -3.03283691e-01],
                        [ -2.35473633e-01,  -2.35473633e-01],
                        [ -1.77124023e-01,  -1.77154541e-01],
                        [ -1.42242432e-01,  -1.42211914e-01],
                        [ -1.21154785e-01,  -1.21154785e-01],
                        [ -9.75952148e-02,  -9.76257324e-02],
                        [ -7.05261230e-02,  -7.05261230e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  1.85852051e-01,   1.85852051e-01],
                        [  2.54272461e-01,   2.54272461e-01],
                        [  2.96936035e-01,   2.96936035e-01],
                        [  3.07403564e-01,   3.07403564e-01],
                        [  2.88726807e-01,   2.88757324e-01],
                        [  2.51098633e-01,   2.51068115e-01],
                        [  2.07641602e-01,   2.07641602e-01],
                        [  1.68457031e-01,   1.68457031e-01],
                        [  1.38275146e-01,   1.38275146e-01],
                        [  1.18560791e-01,   1.18560791e-01],
                        [  1.06842041e-01,   1.06842041e-01],
                        [  9.72900391e-02,   9.73205566e-02],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  7.72705078e-02,   7.72705078e-02],
                        [  6.78710938e-02,   6.79016113e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  3.72009277e-02,   3.71704102e-02],
                        [  2.03247070e-02,   2.03552246e-02],
                        [  1.10473633e-02,   1.10778809e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  2.66418457e-02,   2.66113281e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -5.12695312e-03,  -5.09643555e-03],
                        [ -7.38525391e-03,  -7.35473633e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -8.30078125e-03,  -8.27026367e-03],
                        [ -3.44848633e-03,  -3.47900391e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -2.53295898e-03,  -2.50244141e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -2.15759277e-02,  -2.16064453e-02],
                        [ -3.28674316e-02,  -3.28369141e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -5.52673340e-02,  -5.52978516e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -7.16857910e-02,  -7.16552734e-02],
                        [ -7.11975098e-02,  -7.12280273e-02],
                        [ -6.79321289e-02,  -6.79626465e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -6.76879883e-02,  -6.77185059e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -6.47277832e-02,  -6.47583008e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -6.00585938e-02,  -6.00280762e-02],
                        [ -5.90209961e-02,  -5.90515137e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.78613281e-02,  -5.78308105e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -3.79943848e-02,  -3.79638672e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.18713379e-02,  -1.18408203e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -2.74658203e-04,  -3.05175781e-04],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.45935059e-01,   1.45935059e-01],
                        [  1.43127441e-01,   1.43127441e-01],
                        [  1.23840332e-01,   1.23840332e-01],
                        [  8.78601074e-02,   8.78601074e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -9.11254883e-02,  -9.11254883e-02],
                        [ -1.59973145e-01,  -1.59942627e-01],
                        [ -2.30163574e-01,  -2.30163574e-01],
                        [ -2.95776367e-01,  -2.95776367e-01],
                        [ -3.38989258e-01,  -3.38989258e-01],
                        [ -3.38867188e-01,  -3.38867188e-01],
                        [ -2.92449951e-01,  -2.92480469e-01],
                        [ -2.23480225e-01,  -2.23480225e-01],
                        [ -1.63360596e-01,  -1.63360596e-01],
                        [ -1.24908447e-01,  -1.24908447e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -7.27844238e-02,  -7.27539062e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -3.03039551e-02,  -3.03344727e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -1.66625977e-02,  -1.66931152e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -3.48815918e-02,  -3.49121094e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.93579102e-02,  -2.93273926e-02],
                        [ -1.80664062e-02,  -1.80969238e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  3.57360840e-02,   3.57666016e-02],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  1.53900146e-01,   1.53869629e-01],
                        [  2.20397949e-01,   2.20397949e-01],
                        [  2.71026611e-01,   2.71026611e-01],
                        [  2.94006348e-01,   2.94006348e-01],
                        [  2.87384033e-01,   2.87384033e-01],
                        [  2.58209229e-01,   2.58239746e-01],
                        [  2.19726562e-01,   2.19726562e-01],
                        [  1.85363770e-01,   1.85363770e-01],
                        [  1.60705566e-01,   1.60705566e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.23962402e-01,   1.23962402e-01],
                        [  1.06384277e-01,   1.06414795e-01],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  7.76977539e-02,   7.76977539e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  3.91235352e-02,   3.91540527e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  2.77709961e-03,   2.74658203e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  2.25830078e-02,   2.26135254e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  3.95202637e-02,   3.95507812e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -1.87377930e-02,  -1.87072754e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.43530273e-02,  -2.43835449e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -5.46875000e-02,  -5.47180176e-02],
                        [ -5.35278320e-02,  -5.34973145e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -5.56640625e-02,  -5.56945801e-02],
                        [ -5.89294434e-02,  -5.89599609e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.86950684e-02,  -6.86645508e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.45043945e-02,  -5.45349121e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  4.40368652e-02,   4.40063477e-02],
                        [  6.27136230e-02,   6.27136230e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  9.12170410e-02,   9.11865234e-02],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  1.24908447e-01,   1.24908447e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  9.95483398e-02,   9.95788574e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -9.28039551e-02,  -9.28039551e-02],
                        [ -1.26556396e-01,  -1.26586914e-01],
                        [ -1.84356689e-01,  -1.84356689e-01],
                        [ -2.59277344e-01,  -2.59277344e-01],
                        [ -3.14392090e-01,  -3.14422607e-01],
                        [ -3.15643311e-01,  -3.15643311e-01],
                        [ -2.65808105e-01,  -2.65808105e-01],
                        [ -1.98944092e-01,  -1.98944092e-01],
                        [ -1.48101807e-01,  -1.48101807e-01],
                        [ -1.22772217e-01,  -1.22772217e-01],
                        [ -1.09252930e-01,  -1.09252930e-01],
                        [ -8.91418457e-02,  -8.91418457e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.33459473e-02,  -2.33764648e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -4.10766602e-02,  -4.10461426e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [  1.60522461e-02,   1.60827637e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  1.09252930e-01,   1.09222412e-01],
                        [  1.59301758e-01,   1.59301758e-01],
                        [  2.05413818e-01,   2.05413818e-01],
                        [  2.44262695e-01,   2.44262695e-01],
                        [  2.71270752e-01,   2.71270752e-01],
                        [  2.78533936e-01,   2.78564453e-01],
                        [  2.62756348e-01,   2.62756348e-01],
                        [  2.32055664e-01,   2.32055664e-01],
                        [  1.98333740e-01,   1.98364258e-01],
                        [  1.67602539e-01,   1.67633057e-01],
                        [  1.41571045e-01,   1.41540527e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.02691650e-01,   1.02722168e-01],
                        [  8.55712891e-02,   8.55407715e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  5.54809570e-02,   5.55114746e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  3.51562500e-02,   3.51257324e-02],
                        [  2.23083496e-02,   2.23388672e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.53601074e-02,   2.53295898e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.37426758e-02,   2.37731934e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.22070312e-02,  -1.22375488e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -2.08435059e-02,  -2.08740234e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.07214355e-02,  -2.07519531e-02],
                        [ -2.27050781e-02,  -2.26745605e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -3.73535156e-02,  -3.73840332e-02],
                        [ -4.86145020e-02,  -4.86450195e-02],
                        [ -5.74340820e-02,  -5.74340820e-02],
                        [ -6.09741211e-02,  -6.09436035e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -5.50842285e-02,  -5.50537109e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -5.41381836e-02,  -5.41687012e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -6.26831055e-02,  -6.26525879e-02],
                        [ -6.63452148e-02,  -6.63757324e-02],
                        [ -6.73828125e-02,  -6.73828125e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.21459961e-02,  -1.21154785e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.01318359e-02,   1.01623535e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  4.77905273e-02,   4.77905273e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  8.40454102e-02,   8.40454102e-02],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  1.17004395e-01,   1.17004395e-01],
                        [  1.20849609e-01,   1.20819092e-01],
                        [  1.09466553e-01,   1.09497070e-01],
                        [  8.11462402e-02,   8.11462402e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -1.87866211e-01,  -1.87866211e-01],
                        [ -2.72857666e-01,  -2.72857666e-01],
                        [ -3.24707031e-01,  -3.24707031e-01],
                        [ -3.17321777e-01,  -3.17321777e-01],
                        [ -2.59277344e-01,  -2.59277344e-01],
                        [ -1.87683105e-01,  -1.87683105e-01],
                        [ -1.35650635e-01,  -1.35650635e-01],
                        [ -1.08154297e-01,  -1.08154297e-01],
                        [ -8.98437500e-02,  -8.98437500e-02],
                        [ -6.85729980e-02,  -6.85729980e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  5.09033203e-02,   5.09033203e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  1.13464355e-01,   1.13464355e-01],
                        [  1.47186279e-01,   1.47186279e-01],
                        [  1.81427002e-01,   1.81427002e-01],
                        [  2.18139648e-01,   2.18139648e-01],
                        [  2.55798340e-01,   2.55798340e-01],
                        [  2.81066895e-01,   2.81066895e-01],
                        [  2.77130127e-01,   2.77130127e-01],
                        [  2.42797852e-01,   2.42797852e-01],
                        [  1.95648193e-01,   1.95648193e-01],
                        [  1.54327393e-01,   1.54327393e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.05377197e-01,   1.05377197e-01],
                        [  9.04235840e-02,   9.04235840e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.25927734e-02,   3.25622559e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  3.59497070e-02,   3.59191895e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  4.76074219e-03,   4.76074219e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -8.30078125e-03,  -8.27026367e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -1.11083984e-02,  -1.11389160e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.99279785e-02,  -1.99584961e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -3.93066406e-02,  -3.92761230e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -6.62536621e-02,  -6.62841797e-02],
                        [ -6.73522949e-02,  -6.73522949e-02],
                        [ -7.28759766e-02,  -7.28759766e-02],
                        [ -7.52563477e-02,  -7.52868652e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -5.59387207e-02,  -5.59692383e-02],
                        [ -5.60302734e-02,  -5.60302734e-02],
                        [ -5.49011230e-02,  -5.48706055e-02],
                        [ -5.18493652e-02,  -5.18798828e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -4.71496582e-02,  -4.71191406e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -1.46484375e-02,  -1.46179199e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.13525391e-01,   1.13525391e-01],
                        [  1.20666504e-01,   1.20666504e-01],
                        [  1.11511230e-01,   1.11541748e-01],
                        [  7.81860352e-02,   7.81555176e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [ -1.22070312e-02,  -1.21765137e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -4.93774414e-02,  -4.94079590e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -1.01379395e-01,  -1.01379395e-01],
                        [ -1.82495117e-01,  -1.82495117e-01],
                        [ -2.62084961e-01,  -2.62084961e-01],
                        [ -3.03588867e-01,  -3.03619385e-01],
                        [ -2.90893555e-01,  -2.90893555e-01],
                        [ -2.38342285e-01,  -2.38342285e-01],
                        [ -1.77825928e-01,  -1.77825928e-01],
                        [ -1.34460449e-01,  -1.34460449e-01],
                        [ -1.10778809e-01,  -1.10778809e-01],
                        [ -9.18273926e-02,  -9.17968750e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -8.54492188e-03,  -8.51440430e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  6.05773926e-02,   6.05773926e-02],
                        [  8.54492188e-02,   8.54187012e-02],
                        [  1.06292725e-01,   1.06292725e-01],
                        [  1.25122070e-01,   1.25152588e-01],
                        [  1.49597168e-01,   1.49597168e-01],
                        [  1.86279297e-01,   1.86279297e-01],
                        [  2.29644775e-01,   2.29644775e-01],
                        [  2.61566162e-01,   2.61566162e-01],
                        [  2.66571045e-01,   2.66571045e-01],
                        [  2.46032715e-01,   2.46032715e-01],
                        [  2.13073730e-01,   2.13073730e-01],
                        [  1.78070068e-01,   1.78070068e-01],
                        [  1.45202637e-01,   1.45202637e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  6.38427734e-02,   6.38122559e-02],
                        [  5.19714355e-02,   5.19714355e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  3.32336426e-02,   3.32031250e-02],
                        [  3.52783203e-02,   3.53088379e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.73840332e-02,   3.73535156e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -1.58691406e-03,  -1.55639648e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -2.17285156e-02,  -2.17590332e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -3.22570801e-02,  -3.22265625e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -5.99670410e-02,  -5.99365234e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -5.19104004e-02,  -5.18798828e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.22155762e-02,  -5.21850586e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.68237305e-02,  -5.67932129e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -4.62951660e-02,  -4.63256836e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [  5.55419922e-03,   5.58471680e-03],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  1.33056641e-02,   1.32751465e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  4.06188965e-02,   4.06494141e-02],
                        [  6.21948242e-02,   6.21643066e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.82971191e-02,   9.83276367e-02],
                        [  1.05651855e-01,   1.05621338e-01],
                        [  9.69238281e-02,   9.69238281e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -6.93054199e-02,  -6.92749023e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -6.98547363e-02,  -6.98547363e-02],
                        [ -1.61254883e-01,  -1.61224365e-01],
                        [ -2.51739502e-01,  -2.51739502e-01],
                        [ -3.06365967e-01,  -3.06365967e-01],
                        [ -3.03466797e-01,  -3.03466797e-01],
                        [ -2.51922607e-01,  -2.51922607e-01],
                        [ -1.82617188e-01,  -1.82617188e-01],
                        [ -1.24114990e-01,  -1.24084473e-01],
                        [ -8.71887207e-02,  -8.71887207e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -3.83911133e-02,  -3.83605957e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  7.99560547e-03,   7.96508789e-03],
                        [  9.42993164e-03,   9.46044922e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  4.06188965e-02,   4.06494141e-02],
                        [  6.31713867e-02,   6.31408691e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  1.30798340e-01,   1.30828857e-01],
                        [  1.72668457e-01,   1.72668457e-01],
                        [  2.15423584e-01,   2.15423584e-01],
                        [  2.38464355e-01,   2.38464355e-01],
                        [  2.32025146e-01,   2.32025146e-01],
                        [  2.03826904e-01,   2.03826904e-01],
                        [  1.70471191e-01,   1.70501709e-01],
                        [  1.45172119e-01,   1.45172119e-01],
                        [  1.31469727e-01,   1.31469727e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  6.51855469e-02,   6.52160645e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.43127441e-02,   1.43432617e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.06701660e-02,  -3.06396484e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -6.06384277e-02,  -6.06689453e-02],
                        [ -5.85632324e-02,  -5.85632324e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -5.27343750e-02,  -5.27648926e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -5.23681641e-02,  -5.23376465e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.88684082e-02,  -5.88378906e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  1.11389160e-02,   1.11083984e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.88391113e-02,   2.88085938e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  5.32226562e-02,   5.32531738e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  1.03851318e-01,   1.03881836e-01],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  6.67419434e-02,   6.67114258e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -9.13085938e-02,  -9.13085938e-02],
                        [ -1.01837158e-01,  -1.01837158e-01],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [  1.74255371e-02,   1.73950195e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [ -1.36718750e-02,  -1.36413574e-02],
                        [ -7.63549805e-02,  -7.63854980e-02],
                        [ -1.52954102e-01,  -1.52954102e-01],
                        [ -2.23205566e-01,  -2.23175049e-01],
                        [ -2.63092041e-01,  -2.63092041e-01],
                        [ -2.58270264e-01,  -2.58270264e-01],
                        [ -2.16918945e-01,  -2.16918945e-01],
                        [ -1.64520264e-01,  -1.64489746e-01],
                        [ -1.22283936e-01,  -1.22283936e-01],
                        [ -9.44213867e-02,  -9.44519043e-02],
                        [ -7.51647949e-02,  -7.51342773e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.39965820e-02,  -3.39660645e-02],
                        [ -2.90222168e-02,  -2.90527344e-02],
                        [ -2.11791992e-02,  -2.12097168e-02],
                        [ -7.78198242e-03,  -7.75146484e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.58691406e-02,   1.58386230e-02],
                        [  1.74560547e-02,   1.74865723e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  1.87683105e-02,   1.87377930e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  2.79541016e-02,   2.79846191e-02],
                        [  4.33349609e-02,   4.33044434e-02],
                        [  6.79626465e-02,   6.79321289e-02],
                        [  9.06066895e-02,   9.06372070e-02],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  1.00799561e-01,   1.00769043e-01],
                        [  9.82360840e-02,   9.82666016e-02],
                        [  1.01318359e-01,   1.01348877e-01],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.54022217e-01,   1.54022217e-01],
                        [  1.97998047e-01,   1.98028564e-01],
                        [  2.31842041e-01,   2.31842041e-01],
                        [  2.43072510e-01,   2.43041992e-01],
                        [  2.29980469e-01,   2.30010986e-01],
                        [  1.98120117e-01,   1.98120117e-01],
                        [  1.59851074e-01,   1.59851074e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.07574463e-01,   1.07574463e-01],
                        [  8.97827148e-02,   8.97521973e-02],
                        [  7.33032227e-02,   7.33032227e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  6.71081543e-02,   6.71386719e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  1.47705078e-02,   1.48010254e-02],
                        [  9.39941406e-03,   9.36889648e-03],
                        [  6.22558594e-03,   6.19506836e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  9.79614258e-03,   9.76562500e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.48925781e-02,   1.49230957e-02],
                        [  1.19628906e-02,   1.19323730e-02],
                        [  9.91821289e-03,   9.88769531e-03],
                        [  8.14819336e-03,   8.17871094e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -5.92651367e-02,  -5.92346191e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -7.37915039e-02,  -7.37915039e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -7.60192871e-02,  -7.60192871e-02],
                        [ -6.98547363e-02,  -6.98547363e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -9.52148438e-03,  -9.55200195e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  5.18798828e-02,   5.19104004e-02],
                        [  8.19702148e-02,   8.19702148e-02],
                        [  1.01806641e-01,   1.01776123e-01],
                        [  1.05072021e-01,   1.05072021e-01],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  5.63049316e-02,   5.62744141e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [ -4.53796387e-02,  -4.53491211e-02],
                        [ -8.76464844e-02,  -8.76464844e-02],
                        [ -9.97009277e-02,  -9.97009277e-02],
                        [ -7.53173828e-02,  -7.52868652e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  3.83300781e-02,   3.83605957e-02],
                        [  2.56347656e-02,   2.56042480e-02],
                        [ -2.07214355e-02,  -2.07519531e-02],
                        [ -9.57336426e-02,  -9.57031250e-02],
                        [ -1.86096191e-01,  -1.86096191e-01],
                        [ -2.64160156e-01,  -2.64190674e-01],
                        [ -2.97668457e-01,  -2.97637939e-01],
                        [ -2.73223877e-01,  -2.73223877e-01],
                        [ -2.08068848e-01,  -2.08068848e-01],
                        [ -1.37145996e-01,  -1.37145996e-01],
                        [ -8.99353027e-02,  -8.99047852e-02],
                        [ -7.24182129e-02,  -7.24487305e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -5.56945801e-02,  -5.56640625e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -2.50244141e-02,  -2.50549316e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [  4.85229492e-03,   4.88281250e-03],
                        [  9.06372070e-03,   9.03320312e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  9.33837891e-03,   9.36889648e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  2.12402344e-02,   2.12097168e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  6.65283203e-02,   6.65588379e-02],
                        [  9.17053223e-02,   9.16748047e-02],
                        [  1.05773926e-01,   1.05773926e-01],
                        [  1.03576660e-01,   1.03607178e-01],
                        [  9.00573730e-02,   9.00573730e-02],
                        [  7.93762207e-02,   7.93762207e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  1.11877441e-01,   1.11877441e-01],
                        [  1.54235840e-01,   1.54235840e-01],
                        [  2.00042725e-01,   2.00042725e-01],
                        [  2.32330322e-01,   2.32330322e-01],
                        [  2.38128662e-01,   2.38128662e-01],
                        [  2.18750000e-01,   2.18750000e-01],
                        [  1.87591553e-01,   1.87561035e-01],
                        [  1.58111572e-01,   1.58111572e-01],
                        [  1.36260986e-01,   1.36260986e-01],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  5.56640625e-02,   5.56335449e-02],
                        [  5.17883301e-02,   5.17883301e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  2.78625488e-02,   2.78930664e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.48620605e-02,   1.48315430e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  5.46264648e-03,   5.43212891e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.85644531e-02,  -2.85949707e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.87573242e-02,  -3.87878418e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -6.06689453e-02,  -6.06689453e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -6.63146973e-02,  -6.63146973e-02],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -7.86132812e-02,  -7.86132812e-02],
                        [ -7.19604492e-02,  -7.19909668e-02],
                        [ -5.74340820e-02,  -5.74340820e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -1.81579590e-02,  -1.81274414e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -7.08007812e-03,  -7.04956055e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.74145508e-02,   3.73840332e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  9.32312012e-02,   9.32006836e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  6.66809082e-02,   6.67114258e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [ -2.51770020e-02,  -2.52075195e-02],
                        [ -7.65380859e-02,  -7.65075684e-02],
                        [ -1.09375000e-01,  -1.09375000e-01],
                        [ -1.05987549e-01,  -1.05987549e-01],
                        [ -6.45751953e-02,  -6.45446777e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [  3.82385254e-02,   3.82080078e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -9.06677246e-02,  -9.06982422e-02],
                        [ -1.68792725e-01,  -1.68762207e-01],
                        [ -2.33001709e-01,  -2.33001709e-01],
                        [ -2.59399414e-01,  -2.59429932e-01],
                        [ -2.39776611e-01,  -2.39776611e-01],
                        [ -1.90765381e-01,  -1.90765381e-01],
                        [ -1.40502930e-01,  -1.40533447e-01],
                        [ -1.06658936e-01,  -1.06658936e-01],
                        [ -8.77990723e-02,  -8.77990723e-02],
                        [ -7.28759766e-02,  -7.29064941e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -1.64184570e-02,  -1.64489746e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -3.05175781e-05,  -6.10351562e-05],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  6.85119629e-02,   6.85119629e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  1.03515625e-01,   1.03485107e-01],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  7.97424316e-02,   7.97424316e-02],
                        [  9.59472656e-02,   9.59472656e-02],
                        [  1.30554199e-01,   1.30584717e-01],
                        [  1.72973633e-01,   1.72973633e-01],
                        [  2.07092285e-01,   2.07092285e-01],
                        [  2.21221924e-01,   2.21221924e-01],
                        [  2.13714600e-01,   2.13714600e-01],
                        [  1.91253662e-01,   1.91253662e-01],
                        [  1.63513184e-01,   1.63513184e-01],
                        [  1.39251709e-01,   1.39251709e-01],
                        [  1.22253418e-01,   1.22253418e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  6.06994629e-02,   6.06689453e-02],
                        [  5.74951172e-02,   5.75256348e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.42211914e-02,   1.41906738e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  2.65197754e-02,   2.65502930e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -7.51647949e-02,  -7.51647949e-02],
                        [ -7.92846680e-02,  -7.92846680e-02],
                        [ -7.65075684e-02,  -7.65075684e-02],
                        [ -6.72302246e-02,  -6.71997070e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -4.44946289e-02,  -4.45251465e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -5.96618652e-02,  -5.96313477e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.20629883e-02,  -5.20935059e-02],
                        [ -4.25109863e-02,  -4.24804688e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  9.36584473e-02,   9.36584473e-02],
                        [  8.52966309e-02,   8.53271484e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -6.20117188e-02,  -6.19812012e-02],
                        [ -1.11602783e-01,  -1.11602783e-01],
                        [ -1.31256104e-01,  -1.31256104e-01],
                        [ -1.12548828e-01,  -1.12548828e-01],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  3.21044922e-02,   3.21350098e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  4.22058105e-02,   4.21752930e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -4.88281250e-02,  -4.87976074e-02],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -2.09716797e-01,  -2.09716797e-01],
                        [ -2.59216309e-01,  -2.59216309e-01],
                        [ -2.58636475e-01,  -2.58636475e-01],
                        [ -2.14935303e-01,  -2.14935303e-01],
                        [ -1.53594971e-01,  -1.53594971e-01],
                        [ -1.00891113e-01,  -1.00891113e-01],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -5.61218262e-02,  -5.61218262e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -6.77490234e-03,  -6.80541992e-03],
                        [  1.41296387e-02,   1.41601562e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  2.61535645e-02,   2.61230469e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  3.52478027e-02,   3.52783203e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  9.80834961e-02,   9.80529785e-02],
                        [  1.23291016e-01,   1.23321533e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.22711182e-01,   1.22680664e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  1.06231689e-01,   1.06262207e-01],
                        [  1.47735596e-01,   1.47735596e-01],
                        [  1.85485840e-01,   1.85455322e-01],
                        [  2.11273193e-01,   2.11273193e-01],
                        [  2.17102051e-01,   2.17102051e-01],
                        [  1.98760986e-01,   1.98760986e-01],
                        [  1.65405273e-01,   1.65405273e-01],
                        [  1.34765625e-01,   1.34765625e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  8.56018066e-02,   8.56323242e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  8.51440430e-02,   8.51440430e-02],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  8.13293457e-02,   8.13598633e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  4.03747559e-02,   4.03747559e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  4.63867188e-03,   4.66918945e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  1.54113770e-02,   1.54418945e-02],
                        [  1.86157227e-02,   1.85852051e-02],
                        [  1.85546875e-02,   1.85241699e-02],
                        [  2.09960938e-02,   2.10266113e-02],
                        [  2.25219727e-02,   2.24914551e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  2.16674805e-03,   2.13623047e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.66113281e-02,  -2.66418457e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.80456543e-02,  -2.80761719e-02],
                        [ -3.20739746e-02,  -3.20434570e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -4.08020020e-02,  -4.08325195e-02],
                        [ -4.08325195e-02,  -4.08630371e-02],
                        [ -4.09240723e-02,  -4.08935547e-02],
                        [ -4.44030762e-02,  -4.44335938e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -5.36499023e-02,  -5.36193848e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -5.15136719e-02,  -5.15441895e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.95190430e-02,  -6.95495605e-02],
                        [ -6.94580078e-02,  -6.94580078e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.05883789e-02,  -4.05578613e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -3.90319824e-02,  -3.90625000e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -1.65100098e-02,  -1.65405273e-02],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  1.02508545e-01,   1.02478027e-01],
                        [  8.11767578e-02,   8.11767578e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -1.51977539e-01,  -1.51977539e-01],
                        [ -1.49291992e-01,  -1.49291992e-01],
                        [ -1.03393555e-01,  -1.03393555e-01],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  6.24694824e-02,   6.25000000e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [ -7.53173828e-02,  -7.53173828e-02],
                        [ -1.73980713e-01,  -1.73980713e-01],
                        [ -2.52868652e-01,  -2.52868652e-01],
                        [ -2.82135010e-01,  -2.82135010e-01],
                        [ -2.54577637e-01,  -2.54577637e-01],
                        [ -1.92016602e-01,  -1.91986084e-01],
                        [ -1.30493164e-01,  -1.30493164e-01],
                        [ -9.39941406e-02,  -9.39941406e-02],
                        [ -7.96203613e-02,  -7.95898438e-02],
                        [ -6.97631836e-02,  -6.97937012e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.08837891e-02,  -3.09143066e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  1.20849609e-01,   1.20819092e-01],
                        [  1.29180908e-01,   1.29211426e-01],
                        [  1.18591309e-01,   1.18591309e-01],
                        [  9.75341797e-02,   9.75036621e-02],
                        [  7.73010254e-02,   7.73010254e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  9.77478027e-02,   9.77478027e-02],
                        [  1.37268066e-01,   1.37268066e-01],
                        [  1.80480957e-01,   1.80480957e-01],
                        [  2.13592529e-01,   2.13592529e-01],
                        [  2.26379395e-01,   2.26379395e-01],
                        [  2.14843750e-01,   2.14843750e-01],
                        [  1.83898926e-01,   1.83898926e-01],
                        [  1.48040771e-01,   1.48040771e-01],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.06384277e-01,   1.06353760e-01],
                        [  9.45434570e-02,   9.45434570e-02],
                        [  8.16345215e-02,   8.16650391e-02],
                        [  6.97937012e-02,   6.97937012e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  2.28881836e-02,   2.28576660e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.31225586e-02,   1.31530762e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.86962891e-02,  -3.87268066e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.76782227e-02,  -5.76782227e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.71594238e-02,  -5.71289062e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -6.30798340e-02,  -6.30798340e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -6.08215332e-02,  -6.07910156e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -3.26843262e-02,  -3.27148438e-02],
                        [ -2.64282227e-02,  -2.63977051e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -2.06298828e-02,  -2.06604004e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  5.21240234e-02,   5.21240234e-02],
                        [  6.29882812e-02,   6.29882812e-02],
                        [  7.02819824e-02,   7.03125000e-02],
                        [  7.22351074e-02,   7.22656250e-02],
                        [  6.22863770e-02,   6.22558594e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -1.32720947e-01,  -1.32720947e-01],
                        [ -1.43768311e-01,  -1.43768311e-01],
                        [ -1.11053467e-01,  -1.11022949e-01],
                        [ -5.00488281e-02,  -5.00793457e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  5.36193848e-02,   5.36499023e-02],
                        [  7.06787109e-02,   7.06481934e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  2.77099609e-02,   2.77404785e-02],
                        [ -3.81164551e-02,  -3.81469727e-02],
                        [ -1.28112793e-01,  -1.28112793e-01],
                        [ -2.16735840e-01,  -2.16735840e-01],
                        [ -2.69104004e-01,  -2.69104004e-01],
                        [ -2.65808105e-01,  -2.65838623e-01],
                        [ -2.17254639e-01,  -2.17224121e-01],
                        [ -1.54388428e-01,  -1.54388428e-01],
                        [ -1.06445312e-01,  -1.06445312e-01],
                        [ -8.25195312e-02,  -8.25195312e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  4.65393066e-02,   4.65698242e-02],
                        [  7.50732422e-02,   7.50732422e-02],
                        [  1.05712891e-01,   1.05712891e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  7.29370117e-02,   7.29370117e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  6.91833496e-02,   6.91528320e-02],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  1.29760742e-01,   1.29760742e-01],
                        [  1.73400879e-01,   1.73400879e-01],
                        [  2.09716797e-01,   2.09716797e-01],
                        [  2.25524902e-01,   2.25524902e-01],
                        [  2.15484619e-01,   2.15484619e-01],
                        [  1.85577393e-01,   1.85577393e-01],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.22802734e-01,   1.22802734e-01],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  7.79113770e-02,   7.79113770e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  6.66809082e-02,   6.67114258e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  4.08935547e-03,   4.05883789e-03],
                        [ -5.15747070e-03,  -5.12695312e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.81579590e-02,   1.81884766e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  1.38244629e-02,   1.38549805e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -5.10253906e-02,  -5.10559082e-02],
                        [ -4.28466797e-02,  -4.28161621e-02],
                        [ -3.72314453e-02,  -3.72009277e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -5.10864258e-02,  -5.10559082e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -6.50634766e-02,  -6.50939941e-02],
                        [ -7.00683594e-02,  -7.00378418e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.91430664e-02,  -5.91735840e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -5.92041016e-02,  -5.92346191e-02],
                        [ -5.66711426e-02,  -5.66711426e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  5.01403809e-02,   5.01708984e-02],
                        [  6.93054199e-02,   6.93054199e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  5.98449707e-02,   5.98449707e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -1.21551514e-01,  -1.21551514e-01],
                        [ -1.56860352e-01,  -1.56860352e-01],
                        [ -1.47094727e-01,  -1.47094727e-01],
                        [ -9.93652344e-02,  -9.93652344e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -2.14569092e-01,  -2.14538574e-01],
                        [ -2.62756348e-01,  -2.62756348e-01],
                        [ -2.54974365e-01,  -2.54974365e-01],
                        [ -2.02178955e-01,  -2.02178955e-01],
                        [ -1.39770508e-01,  -1.39770508e-01],
                        [ -9.80224609e-02,  -9.80224609e-02],
                        [ -7.98034668e-02,  -7.97729492e-02],
                        [ -7.08618164e-02,  -7.08618164e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  2.91442871e-02,   2.91137695e-02],
                        [  4.23583984e-02,   4.23889160e-02],
                        [  4.59899902e-02,   4.60205078e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.59704590e-02,   2.59399414e-02],
                        [  1.71203613e-02,   1.71508789e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  9.33227539e-02,   9.33227539e-02],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.53869629e-01,   1.53869629e-01],
                        [  1.44165039e-01,   1.44165039e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  7.62939453e-02,   7.62634277e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  1.28173828e-01,   1.28204346e-01],
                        [  1.74560547e-01,   1.74560547e-01],
                        [  2.11975098e-01,   2.11975098e-01],
                        [  2.26959229e-01,   2.26959229e-01],
                        [  2.15545654e-01,   2.15545654e-01],
                        [  1.84814453e-01,   1.84783936e-01],
                        [  1.47796631e-01,   1.47796631e-01],
                        [  1.17095947e-01,   1.17095947e-01],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  7.94372559e-02,   7.94677734e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  6.31713867e-02,   6.32019043e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  5.57250977e-02,   5.57250977e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  3.67736816e-02,   3.68041992e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  2.80761719e-03,   2.80761719e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -8.66699219e-03,  -8.69750977e-03],
                        [ -9.94873047e-03,  -9.97924805e-03],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -5.57861328e-02,  -5.57556152e-02],
                        [ -6.57348633e-02,  -6.57043457e-02],
                        [ -6.87561035e-02,  -6.87255859e-02],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -5.91735840e-02,  -5.91430664e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.48913574e-02,  -4.49218750e-02],
                        [ -3.84216309e-02,  -3.84521484e-02],
                        [ -3.97338867e-02,  -3.97644043e-02],
                        [ -4.76379395e-02,  -4.76684570e-02],
                        [ -5.38940430e-02,  -5.39245605e-02],
                        [ -5.53588867e-02,  -5.53894043e-02],
                        [ -5.62744141e-02,  -5.63354492e-02],
                        [ -5.89599609e-02,  -5.89904785e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -6.17370605e-02,  -6.17675781e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -5.01098633e-02,  -5.00793457e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -2.82287598e-02,  -2.81982422e-02],
                        [ -2.44140625e-02,  -2.43835449e-02],
                        [ -2.32543945e-02,  -2.32238770e-02],
                        [ -2.03552246e-02,  -2.02941895e-02],
                        [ -1.14746094e-02,  -1.14135742e-02],
                        [  6.22558594e-03,   6.25610352e-03],
                        [  3.07617188e-02,   3.07922363e-02],
                        [  5.52978516e-02,   5.53283691e-02],
                        [  7.42797852e-02,   7.43103027e-02],
                        [  8.61511230e-02,   8.61206055e-02],
                        [  8.70971680e-02,   8.70666504e-02],
                        [  6.71386719e-02,   6.71081543e-02],
                        [  1.74865723e-02,   1.74255371e-02],
                        [ -5.57861328e-02,  -5.58471680e-02],
                        [ -1.26892090e-01,  -1.26953125e-01],
                        [ -1.65283203e-01,  -1.65344238e-01],
                        [ -1.57928467e-01,  -1.57989502e-01],
                        [ -1.15539551e-01,  -1.15570068e-01],
                        [ -6.03637695e-02,  -6.03942871e-02],
                        [ -1.13220215e-02,  -1.13525391e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  4.70886230e-02,   4.71191406e-02],
                        [  5.80139160e-02,   5.80444336e-02],
                        [  4.94384766e-02,   4.94689941e-02],
                        [  9.88769531e-03,   9.94873047e-03],
                        [ -6.30493164e-02,  -6.29882812e-02],
                        [ -1.51550293e-01,  -1.51489258e-01],
                        [ -2.22808838e-01,  -2.22747803e-01],
                        [ -2.50213623e-01,  -2.50122070e-01],
                        [ -2.30621338e-01,  -2.30560303e-01],
                        [ -1.82312012e-01,  -1.82281494e-01],
                        [ -1.28906250e-01,  -1.28875732e-01],
                        [ -8.75549316e-02,  -8.75549316e-02],
                        [ -6.57958984e-02,  -6.58264160e-02],
                        [ -6.00891113e-02,  -6.01196289e-02],
                        [ -5.96008301e-02,  -5.96618652e-02],
                        [ -5.67626953e-02,  -5.68542480e-02],
                        [ -5.01708984e-02,  -5.02624512e-02],
                        [ -3.88183594e-02,  -3.89099121e-02],
                        [ -2.17895508e-02,  -2.19116211e-02],
                        [ -1.95312500e-03,  -2.04467773e-03],
                        [  1.54724121e-02,   1.54113770e-02],
                        [  2.74658203e-02,   2.74047852e-02],
                        [  3.43322754e-02,   3.43017578e-02],
                        [  3.72009277e-02,   3.72314453e-02],
                        [  3.57971191e-02,   3.58276367e-02],
                        [  3.09143066e-02,   3.09753418e-02],
                        [  2.84118652e-02,   2.85034180e-02],
                        [  3.67431641e-02,   3.68347168e-02],
                        [  5.92346191e-02,   5.93566895e-02],
                        [  9.06066895e-02,   9.07287598e-02],
                        [  1.21154785e-01,   1.21276855e-01],
                        [  1.40350342e-01,   1.40441895e-01],
                        [  1.38946533e-01,   1.39038086e-01],
                        [  1.16333008e-01,   1.16394043e-01],
                        [  8.50524902e-02,   8.50524902e-02],
                        [  6.12182617e-02,   6.11877441e-02],
                        [  5.24597168e-02,   5.24291992e-02],
                        [  5.85327148e-02,   5.84716797e-02],
                        [  7.89489746e-02,   7.88269043e-02],
                        [  1.12884521e-01,   1.12762451e-01],
                        [  1.53656006e-01,   1.53533936e-01],
                        [  1.89147949e-01,   1.88995361e-01],
                        [  2.09014893e-01,   2.08862305e-01],
                        [  2.08312988e-01,   2.08190918e-01],
                        [  1.88262939e-01,   1.88171387e-01],
                        [  1.58386230e-01,   1.58325195e-01],
                        [  1.33544922e-01,   1.33544922e-01],
                        [  1.20208740e-01,   1.20239258e-01],
                        [  1.09130859e-01,   1.09161377e-01],
                        [  9.05151367e-02,   9.06066895e-02],
                        [  6.92749023e-02,   6.93969727e-02],
                        [  5.52673340e-02,   5.54199219e-02],
                        [  4.83703613e-02,   4.85229492e-02],
                        [  4.30297852e-02,   4.31823730e-02],
                        [  3.74145508e-02,   3.75671387e-02],
                        [  3.21044922e-02,   3.21960449e-02],
                        [  2.70690918e-02,   2.71911621e-02],
                        [  2.18505859e-02,   2.19116211e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.21765137e-02,   1.21459961e-02],
                        [  1.48925781e-02,   1.48315430e-02],
                        [  2.33459473e-02,   2.32238770e-02],
                        [  2.97241211e-02,   2.95715332e-02],
                        [  2.76184082e-02,   2.74658203e-02],
                        [  1.77307129e-02,   1.75476074e-02],
                        [  3.50952148e-03,   3.32641602e-03],
                        [ -1.22680664e-02,  -1.24511719e-02],
                        [ -2.46582031e-02,  -2.47802734e-02],
                        [ -2.91748047e-02,  -2.92968750e-02],
                        [ -2.87170410e-02,  -2.87780762e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.36914062e-02,  -3.36303711e-02],
                        [ -3.87268066e-02,  -3.86352539e-02],
                        [ -4.45861816e-02,  -4.44335938e-02],
                        [ -5.07812500e-02,  -5.05981445e-02],
                        [ -5.35278320e-02,  -5.33447266e-02],
                        [ -5.08728027e-02,  -5.06591797e-02],
                        [ -4.79736328e-02,  -4.77600098e-02],
                        [ -4.92248535e-02,  -4.90417480e-02],
                        [ -5.03845215e-02,  -5.02319336e-02],
                        [ -4.70275879e-02,  -4.69055176e-02],
                        [ -4.42810059e-02,  -4.42199707e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -5.86547852e-02,  -5.87158203e-02],
                        [ -6.66503906e-02,  -6.67724609e-02],
                        [ -6.89086914e-02,  -6.90612793e-02],
                        [ -6.54907227e-02,  -6.57043457e-02],
                        [ -5.92041016e-02,  -5.94482422e-02],
                        [ -5.45043945e-02,  -5.47485352e-02],
                        [ -5.49926758e-02,  -5.52368164e-02],
                        [ -6.13098145e-02,  -6.15234375e-02],
                        [ -7.10144043e-02,  -7.11975098e-02],
                        [ -7.96813965e-02,  -7.98034668e-02],
                        [ -8.25195312e-02,  -8.26110840e-02],
                        [ -7.67211914e-02,  -7.67211914e-02],
                        [ -6.25610352e-02,  -6.25000000e-02],
                        [ -4.38842773e-02,  -4.37316895e-02],
                        [ -2.67333984e-02,  -2.65502930e-02],
                        [ -1.58691406e-02,  -1.56250000e-02],
                        [ -1.22375488e-02,  -1.19628906e-02],
                        [ -1.40075684e-02,  -1.37634277e-02],
                        [ -1.68762207e-02,  -1.66015625e-02],
                        [ -1.55639648e-02,  -1.53198242e-02],
                        [ -7.41577148e-03,  -7.23266602e-03],
                        [  8.17871094e-03,   8.30078125e-03],
                        [  3.14941406e-02,   3.15551758e-02],
                        [  5.96923828e-02,   5.96618652e-02],
                        [  8.43811035e-02,   8.42895508e-02],
                        [  9.49401855e-02,   9.47875977e-02],
                        [  8.19091797e-02,   8.16955566e-02],
                        [  3.82690430e-02,   3.79943848e-02],
                        [ -3.36608887e-02,  -3.39660645e-02],
                        [ -1.13525391e-01,  -1.13830566e-01],
                        [ -1.70104980e-01,  -1.70379639e-01],
                        [ -1.82159424e-01,  -1.82434082e-01],
                        [ -1.50878906e-01,  -1.51062012e-01],
                        [ -9.39636230e-02,  -9.40856934e-02],
                        [ -3.21960449e-02,  -3.22570801e-02],
                        [  2.12402344e-02,   2.12707520e-02],
                        [  6.14013672e-02,   6.15234375e-02],
                        [  8.42590332e-02,   8.44421387e-02],
                        [  8.22448730e-02,   8.25195312e-02],
                        [  4.71191406e-02,   4.74243164e-02],
                        [ -2.21862793e-02,  -2.18200684e-02],
                        [ -1.12457275e-01,  -1.12121582e-01],
                        [ -1.99249268e-01,  -1.98944092e-01],
                        [ -2.56713867e-01,  -2.56439209e-01],
                        [ -2.67364502e-01,  -2.67150879e-01],
                        [ -2.31414795e-01,  -2.31292725e-01],
                        [ -1.70166016e-01,  -1.70104980e-01],
                        [ -1.13342285e-01,  -1.13403320e-01],
                        [ -7.89794922e-02,  -7.91320801e-02],
                        [ -6.41784668e-02,  -6.44226074e-02],
                        [ -5.51757812e-02,  -5.54809570e-02],
                        [ -4.47998047e-02,  -4.51354980e-02],
                        [ -3.68347168e-02,  -3.72314453e-02],
                        [ -3.43017578e-02,  -3.46679688e-02],
                        [ -3.05175781e-02,  -3.08532715e-02],
                        [ -1.65710449e-02,  -1.68762207e-02],
                        [  6.62231445e-03,   6.37817383e-03],
                        [  2.87170410e-02,   2.85949707e-02],
                        [  4.06494141e-02,   4.06188965e-02],
                        [  4.15649414e-02,   4.16259766e-02],
                        [  3.63464355e-02,   3.65295410e-02],
                        [  2.95410156e-02,   2.98156738e-02],
                        [  2.31628418e-02,   2.34985352e-02],
                        [  2.19116211e-02,   2.23083496e-02],
                        [  3.52478027e-02,   3.56750488e-02],
                        [  6.79626465e-02,   6.83898926e-02],
                        [  1.11083984e-01,   1.11450195e-01],
                        [  1.46881104e-01,   1.47186279e-01],
                        [  1.60034180e-01,   1.60247803e-01],
                        [  1.44500732e-01,   1.44622803e-01],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  6.83593750e-02,   6.82678223e-02],
                        [  4.37011719e-02,   4.34875488e-02],
                        [  3.82995605e-02,   3.79943848e-02],
                        [  4.96826172e-02,   4.92858887e-02],
                        [  7.80334473e-02,   7.76062012e-02],
                        [  1.22894287e-01,   1.22406006e-01],
                        [  1.74255371e-01,   1.73828125e-01],
                        [  2.14843750e-01,   2.14447021e-01],
                        [  2.30651855e-01,   2.30316162e-01],
                        [  2.19573975e-01,   2.19360352e-01],
                        [  1.90765381e-01,   1.90643311e-01],
                        [  1.56524658e-01,   1.56555176e-01],
                        [  1.26007080e-01,   1.26129150e-01],
                        [  1.03088379e-01,   1.03363037e-01],
                        [  8.69140625e-02,   8.72802734e-02],
                        [  7.44628906e-02,   7.48901367e-02],
                        [  6.38427734e-02,   6.43310547e-02],
                        [  5.59082031e-02,   5.63964844e-02],
                        [  5.29785156e-02,   5.34362793e-02],
                        [  5.46569824e-02,   5.50842285e-02],
                        [  5.53894043e-02,   5.57250977e-02],
                        [  5.00183105e-02,   5.02624512e-02],
                        [  3.94592285e-02,   3.95507812e-02],
                        [  2.72216797e-02,   2.71911621e-02],
                        [  1.45874023e-02,   1.44042969e-02],
                        [  2.53295898e-03,   2.22778320e-03],
                        [ -4.33349609e-03,  -4.73022461e-03],
                        [ -2.92968750e-03,  -3.38745117e-03],
                        [  2.10571289e-03,   1.58691406e-03],
                        [  4.21142578e-03,   3.69262695e-03],
                        [  4.02832031e-03,   3.50952148e-03],
                        [  4.91333008e-03,   4.45556641e-03],
                        [  5.43212891e-03,   5.09643555e-03],
                        [  1.46484375e-03,   1.25122070e-03],
                        [ -9.18579102e-03,  -9.27734375e-03],
                        [ -2.54211426e-02,  -2.53601074e-02],
                        [ -4.28161621e-02,  -4.26025391e-02],
                        [ -5.52368164e-02,  -5.49316406e-02],
                        [ -5.88989258e-02,  -5.84411621e-02],
                        [ -5.55114746e-02,  -5.49621582e-02],
                        [ -5.11169434e-02,  -5.05371094e-02],
                        [ -4.92858887e-02,  -4.87060547e-02],
                        [ -4.77294922e-02,  -4.72106934e-02],
                        [ -4.37927246e-02,  -4.33044434e-02],
                        [ -3.98254395e-02,  -3.94897461e-02],
                        [ -4.01000977e-02,  -3.98864746e-02],
                        [ -4.39758301e-02,  -4.39147949e-02],
                        [ -4.82177734e-02,  -4.83093262e-02],
                        [ -5.32836914e-02,  -5.35278320e-02],
                        [ -6.17065430e-02,  -6.20727539e-02],
                        [ -7.24182129e-02,  -7.29064941e-02],
                        [ -8.11157227e-02,  -8.16955566e-02],
                        [ -8.34960938e-02,  -8.41064453e-02],
                        [ -7.77893066e-02,  -7.83996582e-02],
                        [ -6.73522949e-02,  -6.79321289e-02],
                        [ -5.87463379e-02,  -5.92346191e-02],
                        [ -5.60607910e-02,  -5.63964844e-02],
                        [ -5.88684082e-02,  -5.90820312e-02],
                        [ -6.35375977e-02,  -6.35986328e-02],
                        [ -6.48803711e-02,  -6.47277832e-02],
                        [ -6.09436035e-02,  -6.06384277e-02],
                        [ -5.53588867e-02,  -5.49621582e-02],
                        [ -5.10864258e-02,  -5.05371094e-02],
                        [ -4.50439453e-02,  -4.44030762e-02],
                        [ -3.42407227e-02,  -3.35998535e-02],
                        [ -2.17285156e-02,  -2.10876465e-02],
                        [ -1.15051270e-02,  -1.09252930e-02],
                        [ -3.26538086e-03,  -2.77709961e-03],
                        [  5.73730469e-03,   6.07299805e-03],
                        [  1.82189941e-02,   1.84326172e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  5.68237305e-02,   5.66711426e-02],
                        [  7.56835938e-02,   7.53784180e-02],
                        [  8.59069824e-02,   8.54187012e-02],
                        [  7.95288086e-02,   7.89184570e-02],
                        [  4.87670898e-02,   4.80957031e-02],
                        [ -8.30078125e-03,  -9.00268555e-03],
                        [ -8.16650391e-02,  -8.23364258e-02],
                        [ -1.49078369e-01,  -1.49688721e-01],
                        [ -1.84417725e-01,  -1.84906006e-01],
                        [ -1.71325684e-01,  -1.71661377e-01],
                        [ -1.15692139e-01,  -1.15875244e-01],
                        [ -4.56542969e-02,  -4.56237793e-02],
                        [  9.79614258e-03,   1.00097656e-02],
                        [  4.31518555e-02,   4.35485840e-02],
                        [  6.36596680e-02,   6.41784668e-02],
                        [  7.53784180e-02,   7.60192871e-02],
                        [  6.82983398e-02,   6.90307617e-02],
                        [  2.77709961e-02,   2.85339355e-02],
                        [ -4.94079590e-02,  -4.86755371e-02],
                        [ -1.44897461e-01,  -1.44256592e-01],
                        [ -2.25341797e-01,  -2.24822998e-01],
                        [ -2.62420654e-01,  -2.62084961e-01],
                        [ -2.49023438e-01,  -2.48870850e-01],
                        [ -1.99676514e-01,  -1.99707031e-01],
                        [ -1.40411377e-01,  -1.40655518e-01],
                        [ -9.56726074e-02,  -9.61303711e-02],
                        [ -7.41271973e-02,  -7.47070312e-02],
                        [ -6.46667480e-02,  -6.53686523e-02],
                        [ -5.35888672e-02,  -5.43823242e-02],
                        [ -4.03442383e-02,  -4.11376953e-02],
                        [ -3.12194824e-02,  -3.19519043e-02],
                        [ -2.74963379e-02,  -2.81372070e-02],
                        [ -2.46582031e-02,  -2.51770020e-02],
                        [ -1.69372559e-02,  -1.72729492e-02],
                        [ -1.37329102e-03,  -1.49536133e-03],
                        [  1.89819336e-02,   1.90429688e-02],
                        [  3.75366211e-02,   3.78112793e-02],
                        [  4.90722656e-02,   4.95910645e-02],
                        [  5.11779785e-02,   5.18188477e-02],
                        [  4.46166992e-02,   4.53796387e-02],
                        [  3.52478027e-02,   3.61022949e-02],
                        [  3.27453613e-02,   3.35693359e-02],
                        [  4.47082520e-02,   4.54711914e-02],
                        [  7.17773438e-02,   7.24487305e-02],
                        [  1.06170654e-01,   1.06689453e-01],
                        [  1.34216309e-01,   1.34521484e-01],
                        [  1.44531250e-01,   1.44653320e-01],
                        [  1.35284424e-01,   1.35192871e-01],
                        [  1.12792969e-01,   1.12426758e-01],
                        [  8.56323242e-02,   8.50830078e-02],
                        [  6.10046387e-02,   6.03027344e-02],
                        [  4.36401367e-02,   4.28161621e-02],
                        [  3.89099121e-02,   3.80249023e-02],
                        [  5.35278320e-02,   5.26428223e-02],
                        [  8.98132324e-02,   8.90197754e-02],
                        [  1.40625000e-01,   1.39953613e-01],
                        [  1.91192627e-01,   1.90673828e-01],
                        [  2.24731445e-01,   2.24456787e-01],
                        [  2.29888916e-01,   2.29797363e-01],
                        [  2.08251953e-01,   2.08404541e-01],
                        [  1.74133301e-01,   1.74560547e-01],
                        [  1.43005371e-01,   1.43615723e-01],
                        [  1.20208740e-01,   1.20971680e-01],
                        [  1.02050781e-01,   1.02935791e-01],
                        [  8.42590332e-02,   8.52050781e-02],
                        [  6.71081543e-02,   6.80236816e-02],
                        [  5.49926758e-02,   5.58166504e-02],
                        [  5.23071289e-02,   5.30090332e-02],
                        [  5.74035645e-02,   5.78918457e-02],
                        [  6.14929199e-02,   6.17675781e-02],
                        [  5.60607910e-02,   5.60913086e-02],
                        [  4.01611328e-02,   3.99475098e-02],
                        [  1.99584961e-02,   1.95007324e-02],
                        [  3.08227539e-03,   2.41088867e-03],
                        [ -5.40161133e-03,  -6.22558594e-03],
                        [ -4.33349609e-03,  -5.27954102e-03],
                        [  2.31933594e-03,   1.34277344e-03],
                        [  8.51440430e-03,   7.56835938e-03],
                        [  1.17797852e-02,   1.09252930e-02],
                        [  1.26037598e-02,   1.19018555e-02],
                        [  1.10168457e-02,   1.04980469e-02],
                        [  6.56127930e-03,   6.31713867e-03],
                        [ -2.04467773e-03,  -2.01416016e-03],
                        [ -1.56250000e-02,  -1.53503418e-02],
                        [ -2.94799805e-02,  -2.89306641e-02],
                        [ -3.68652344e-02,  -3.61328125e-02],
                        [ -3.94897461e-02,  -3.86047363e-02],
                        [ -4.35180664e-02,  -4.25415039e-02],
                        [ -4.84008789e-02,  -4.73632812e-02],
                        [ -5.01098633e-02,  -4.91333008e-02],
                        [ -5.02014160e-02,  -4.93469238e-02],
                        [ -5.21850586e-02,  -5.14831543e-02],
                        [ -5.47180176e-02,  -5.42602539e-02],
                        [ -5.55725098e-02,  -5.53894043e-02],
                        [ -5.62133789e-02,  -5.62438965e-02],
                        [ -5.78918457e-02,  -5.81970215e-02],
                        [ -5.94787598e-02,  -6.00891113e-02],
                        [ -6.03332520e-02,  -6.11572266e-02],
                        [ -6.06079102e-02,  -6.15234375e-02],
                        [ -5.93261719e-02,  -6.03942871e-02],
                        [ -5.58471680e-02,  -5.69152832e-02],
                        [ -5.15136719e-02,  -5.24902344e-02],
                        [ -4.95910645e-02,  -5.04760742e-02],
                        [ -5.21240234e-02,  -5.28259277e-02],
                        [ -5.68847656e-02,  -5.73425293e-02],
                        [ -6.00891113e-02,  -6.02722168e-02],
                        [ -6.15844727e-02,  -6.14929199e-02],
                        [ -6.26525879e-02,  -6.22558594e-02],
                        [ -6.13098145e-02,  -6.06689453e-02],
                        [ -5.63049316e-02,  -5.54504395e-02],
                        [ -5.09948730e-02,  -5.00183105e-02],
                        [ -4.77905273e-02,  -4.66918945e-02],
                        [ -4.33044434e-02,  -4.22058105e-02],
                        [ -3.43627930e-02,  -3.33251953e-02],
                        [ -2.26440430e-02,  -2.17590332e-02],
                        [ -1.17187500e-02,  -1.10473633e-02],
                        [ -2.25830078e-03,  -1.83105469e-03],
                        [  9.73510742e-03,   9.88769531e-03],
                        [  2.94494629e-02,   2.92968750e-02],
                        [  5.53894043e-02,   5.49621582e-02],
                        [  7.79724121e-02,   7.72399902e-02],
                        [  8.79516602e-02,   8.70361328e-02],
                        [  8.18786621e-02,   8.08105469e-02],
                        [  5.63049316e-02,   5.51452637e-02],
                        [  6.40869141e-03,   5.24902344e-03],
                        [ -6.35986328e-02,  -6.46362305e-02],
                        [ -1.33575439e-01,  -1.34460449e-01],
                        [ -1.77398682e-01,  -1.78100586e-01],
                        [ -1.78741455e-01,  -1.79138184e-01],
                        [ -1.39770508e-01,  -1.39862061e-01],
                        [ -8.00781250e-02,  -7.98645020e-02],
                        [ -2.36816406e-02,  -2.31933594e-02],
                        [  1.74560547e-02,   1.82189941e-02],
                        [  4.58374023e-02,   4.68444824e-02],
                        [  6.57348633e-02,   6.68640137e-02],
                        [  7.30590820e-02,   7.42492676e-02],
                        [  5.80139160e-02,   5.92041016e-02],
                        [  1.41601562e-02,   1.51977539e-02],
                        [ -5.47485352e-02,  -5.38635254e-02],
                        [ -1.33880615e-01,  -1.33209229e-01],
                        [ -2.01141357e-01,  -2.00775146e-01],
                        [ -2.34130859e-01,  -2.34069824e-01],
                        [ -2.21954346e-01,  -2.22198486e-01],
                        [ -1.76300049e-01,  -1.76879883e-01],
                        [ -1.26525879e-01,  -1.27380371e-01],
                        [ -9.57946777e-02,  -9.68627930e-02],
                        [ -8.36791992e-02,  -8.48693848e-02],
                        [ -7.61718750e-02,  -7.74230957e-02],
                        [ -6.54602051e-02,  -6.66503906e-02],
                        [ -5.28564453e-02,  -5.39245605e-02],
                        [ -4.02526855e-02,  -4.11682129e-02],
                        [ -2.75573730e-02,  -2.81982422e-02],
                        [ -1.42822266e-02,  -1.45874023e-02],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  1.37939453e-02,   1.41296387e-02],
                        [  2.57568359e-02,   2.63977051e-02],
                        [  3.45764160e-02,   3.54919434e-02],
                        [  4.04052734e-02,   4.15344238e-02],
                        [  4.35485840e-02,   4.47692871e-02],
                        [  4.56848145e-02,   4.69665527e-02],
                        [  4.94079590e-02,   5.06591797e-02],
                        [  5.53588867e-02,   5.64270020e-02],
                        [  6.42700195e-02,   6.51550293e-02],
                        [  7.93151855e-02,   7.99255371e-02],
                        [  1.00006104e-01,   1.00250244e-01],
                        [  1.18804932e-01,   1.18743896e-01],
                        [  1.27990723e-01,   1.27593994e-01],
                        [  1.24969482e-01,   1.24237061e-01],
                        [  1.11633301e-01,   1.10626221e-01],
                        [  9.27429199e-02,   9.15832520e-02],
                        [  7.41271973e-02,   7.28454590e-02],
                        [  5.87158203e-02,   5.74035645e-02],
                        [  4.84008789e-02,   4.71496582e-02],
                        [  4.95605469e-02,   4.84619141e-02],
                        [  7.04345703e-02,   6.95495605e-02],
                        [  1.11022949e-01,   1.10443115e-01],
                        [  1.60736084e-01,   1.60491943e-01],
                        [  2.04742432e-01,   2.04864502e-01],
                        [  2.29400635e-01,   2.29858398e-01],
                        [  2.27020264e-01,   2.27783203e-01],
                        [  1.99798584e-01,   2.00866699e-01],
                        [  1.58264160e-01,   1.59515381e-01],
                        [  1.15936279e-01,   1.17279053e-01],
                        [  8.40454102e-02,   8.54187012e-02],
                        [  6.65588379e-02,   6.78405762e-02],
                        [  6.04248047e-02,   6.15234375e-02],
                        [  6.16760254e-02,   6.25305176e-02],
                        [  6.77185059e-02,   6.82373047e-02],
                        [  7.36999512e-02,   7.38830566e-02],
                        [  7.12585449e-02,   7.10754395e-02],
                        [  5.50231934e-02,   5.44738770e-02],
                        [  3.00903320e-02,   2.92053223e-02],
                        [  8.57543945e-03,   7.44628906e-03],
                        [ -1.98364258e-03,  -3.26538086e-03],
                        [ -3.44848633e-03,  -4.85229492e-03],
                        [ -1.70898438e-03,  -3.08227539e-03],
                        [ -6.40869141e-04,  -1.92260742e-03],
                        [ -7.62939453e-04,  -1.86157227e-03],
                        [ -1.06811523e-03,  -1.89208984e-03],
                        [ -1.25122070e-03,  -1.77001953e-03],
                        [ -2.50244141e-03,  -2.62451172e-03],
                        [ -5.92041016e-03,  -5.67626953e-03],
                        [ -1.03454590e-02,  -9.76562500e-03],
                        [ -1.37329102e-02,  -1.27868652e-02],
                        [ -1.62963867e-02,  -1.51062012e-02],
                        [ -1.96228027e-02,  -1.82800293e-02],
                        [ -2.38952637e-02,  -2.24609375e-02],
                        [ -2.93273926e-02,  -2.79235840e-02],
                        [ -3.74145508e-02,  -3.61022949e-02],
                        [ -4.80651855e-02,  -4.69665527e-02],
                        [ -5.85937500e-02,  -5.78002930e-02],
                        [ -6.64062500e-02,  -6.59484863e-02],
                        [ -7.09533691e-02,  -7.08618164e-02],
                        [ -7.26013184e-02,  -7.29370117e-02],
                        [ -7.11059570e-02,  -7.17773438e-02],
                        [ -6.68029785e-02,  -6.78100586e-02],
                        [ -6.17675781e-02,  -6.30187988e-02],
                        [ -5.64575195e-02,  -5.78613281e-02],
                        [ -4.94995117e-02,  -5.09948730e-02],
                        [ -4.25720215e-02,  -4.40368652e-02],
                        [ -4.09545898e-02,  -4.22668457e-02],
                        [ -4.68444824e-02,  -4.79125977e-02],
                        [ -5.56335449e-02,  -5.63964844e-02],
                        [ -6.06079102e-02,  -6.10351562e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -4.94995117e-02,  -4.91027832e-02],
                        [ -4.05273438e-02,  -3.97949219e-02],
                        [ -3.74450684e-02,  -3.63769531e-02],
                        [ -3.93981934e-02,  -3.80554199e-02],
                        [ -4.20532227e-02,  -4.05883789e-02],
                        [ -4.45861816e-02,  -4.30603027e-02],
                        [ -4.69360352e-02,  -4.54711914e-02],
                        [ -4.60205078e-02,  -4.47082520e-02],
                        [ -3.94592285e-02,  -3.84216309e-02],
                        [ -2.85949707e-02,  -2.78930664e-02],
                        [ -1.55639648e-02,  -1.52282715e-02],
                        [  3.05175781e-05,  -3.05175781e-05],
                        [  1.95312500e-02,   1.90734863e-02],
                        [  4.12902832e-02,   4.04663086e-02],
                        [  6.03942871e-02,   5.92346191e-02],
                        [  7.22961426e-02,   7.09228516e-02],
                        [  7.25708008e-02,   7.10449219e-02],
                        [  5.39855957e-02,   5.24597168e-02],
                        [  9.70458984e-03,   8.20922852e-03],
                        [ -5.67932129e-02,  -5.81054688e-02],
                        [ -1.25305176e-01,  -1.26312256e-01],
                        [ -1.68121338e-01,  -1.68792725e-01],
                        [ -1.69128418e-01,  -1.69403076e-01],
                        [ -1.34490967e-01,  -1.34338379e-01],
                        [ -8.59680176e-02,  -8.54187012e-02],
                        [ -4.25720215e-02,  -4.16870117e-02],
                        [ -8.17871094e-03,  -6.95800781e-03],
                        [  2.33154297e-02,   2.47802734e-02],
                        [  5.52062988e-02,   5.67626953e-02],
                        [  8.25500488e-02,   8.41064453e-02],
                        [  9.37194824e-02,   9.52148438e-02],
                        [  7.59582520e-02,   7.72705078e-02],
                        [  2.42004395e-02,   2.51770020e-02],
                        [ -5.39550781e-02,  -5.33447266e-02],
                        [ -1.39251709e-01,  -1.39007568e-01],
                        [ -2.06176758e-01,  -2.06390381e-01],
                        [ -2.33276367e-01,  -2.33886719e-01],
                        [ -2.14385986e-01,  -2.15362549e-01],
                        [ -1.64001465e-01,  -1.65283203e-01],
                        [ -1.10809326e-01,  -1.12335205e-01],
                        [ -7.89794922e-02,  -8.05969238e-02],
                        [ -7.09533691e-02,  -7.25402832e-02],
                        [ -7.08007812e-02,  -7.22961426e-02],
                        [ -6.29272461e-02,  -6.41784668e-02],
                        [ -4.47082520e-02,  -4.56542969e-02],
                        [ -2.28576660e-02,  -2.34680176e-02],
                        [ -4.02832031e-03,  -4.18090820e-03],
                        [  9.61303711e-03,   9.88769531e-03],
                        [  1.93176270e-02,   1.99890137e-02],
                        [  2.76794434e-02,   2.87475586e-02],
                        [  3.51867676e-02,   3.65295410e-02],
                        [  3.84521484e-02,   4.00085449e-02],
                        [  3.40881348e-02,   3.57360840e-02],
                        [  2.31323242e-02,   2.47497559e-02],
                        [  1.19323730e-02,   1.34277344e-02],
                        [  9.12475586e-03,   1.03759766e-02],
                        [  2.15148926e-02,   2.24304199e-02],
                        [  5.05371094e-02,   5.10559082e-02],
                        [  8.92333984e-02,   8.93249512e-02],
                        [  1.23870850e-01,   1.23504639e-01],
                        [  1.42974854e-01,   1.42211914e-01],
                        [  1.43798828e-01,   1.42669678e-01],
                        [  1.29699707e-01,   1.28295898e-01],
                        [  1.06353760e-01,   1.04736328e-01],
                        [  8.12377930e-02,   7.95593262e-02],
                        [  6.09741211e-02,   5.93261719e-02],
                        [  4.72106934e-02,   4.57458496e-02],
                        [  3.88183594e-02,   3.75976562e-02],
                        [  3.95812988e-02,   3.87268066e-02],
                        [  5.90515137e-02,   5.85937500e-02],
                        [  1.00677490e-01,   1.00646973e-01],
                        [  1.53076172e-01,   1.53503418e-01],
                        [  1.96655273e-01,   1.97509766e-01],
                        [  2.15972900e-01,   2.17163086e-01],
                        [  2.06634521e-01,   2.08129883e-01],
                        [  1.76727295e-01,   1.78375244e-01],
                        [  1.41876221e-01,   1.43585205e-01],
                        [  1.14257812e-01,   1.15905762e-01],
                        [  9.55505371e-02,   9.70153809e-02],
                        [  8.21228027e-02,   8.33129883e-02],
                        [  7.29980469e-02,   7.38220215e-02],
                        [  6.77185059e-02,   6.81152344e-02],
                        [  6.23474121e-02,   6.23168945e-02],
                        [  5.37109375e-02,   5.32226562e-02],
                        [  4.25109863e-02,   4.15954590e-02],
                        [  2.98156738e-02,   2.85339355e-02],
                        [  1.61743164e-02,   1.46484375e-02],
                        [  4.97436523e-03,   3.29589844e-03],
                        [  1.37329102e-03,  -3.66210938e-04],
                        [  5.43212891e-03,   3.78417969e-03],
                        [  1.01013184e-02,   8.66699219e-03],
                        [  9.49096680e-03,   8.36181641e-03],
                        [  5.21850586e-03,   4.45556641e-03],
                        [  7.01904297e-04,   3.96728516e-04],
                        [ -4.15039062e-03,  -4.02832031e-03],
                        [ -1.01928711e-02,  -9.61303711e-03],
                        [ -1.59912109e-02,  -1.49841309e-02],
                        [ -2.00195312e-02,  -1.87072754e-02],
                        [ -2.31628418e-02,  -2.15759277e-02],
                        [ -2.78930664e-02,  -2.61840820e-02],
                        [ -3.45458984e-02,  -3.28063965e-02],
                        [ -4.04357910e-02,  -3.87878418e-02],
                        [ -4.51049805e-02,  -4.36706543e-02],
                        [ -5.15441895e-02,  -5.04455566e-02],
                        [ -5.94177246e-02,  -5.87158203e-02],
                        [ -6.32934570e-02,  -6.30187988e-02],
                        [ -6.09130859e-02,  -6.10961914e-02],
                        [ -5.72814941e-02,  -5.79528809e-02],
                        [ -5.70678711e-02,  -5.81359863e-02],
                        [ -5.83496094e-02,  -5.97534180e-02],
                        [ -5.81970215e-02,  -5.98449707e-02],
                        [ -5.76477051e-02,  -5.94177246e-02],
                        [ -5.78308105e-02,  -5.96008301e-02],
                        [ -5.75561523e-02,  -5.92041016e-02],
                        [ -5.72814941e-02,  -5.86853027e-02],
                        [ -5.89294434e-02,  -5.99975586e-02],
                        [ -6.12792969e-02,  -6.19201660e-02],
                        [ -6.12182617e-02,  -6.14013672e-02],
                        [ -5.94482422e-02,  -5.91735840e-02],
                        [ -5.96923828e-02,  -5.89599609e-02],
                        [ -6.23779297e-02,  -6.12487793e-02],
                        [ -6.29272461e-02,  -6.14624023e-02],
                        [ -5.65490723e-02,  -5.48706055e-02],
                        [ -4.36096191e-02,  -4.18090820e-02],
                        [ -3.01513672e-02,  -2.83813477e-02],
                        [ -2.37426758e-02,  -2.20947266e-02],
                        [ -2.62451172e-02,  -2.49023438e-02],
                        [ -3.19213867e-02,  -3.09143066e-02],
                        [ -3.29895020e-02,  -3.24096680e-02],
                        [ -2.60314941e-02,  -2.59094238e-02],
                        [ -1.16271973e-02,  -1.19934082e-02],
                        [  7.99560547e-03,   7.17163086e-03],
                        [  2.91442871e-02,   2.79235840e-02],
                        [  4.79125977e-02,   4.63867188e-02],
                        [  6.18896484e-02,   6.01501465e-02],
                        [  6.59484863e-02,   6.41479492e-02],
                        [  4.98046875e-02,   4.80346680e-02],
                        [  6.68334961e-03,   5.06591797e-03],
                        [ -5.70373535e-02,  -5.83496094e-02],
                        [ -1.24542236e-01,  -1.25488281e-01],
                        [ -1.75048828e-01,  -1.75567627e-01],
                        [ -1.89575195e-01,  -1.89605713e-01],
                        [ -1.62750244e-01,  -1.62292480e-01],
                        [ -1.11053467e-01,  -1.10168457e-01],
                        [ -6.03332520e-02,  -5.90515137e-02],
                        [ -2.50244141e-02,  -2.34375000e-02],
                        [ -1.77001953e-03,   0.00000000e+00],
                        [  2.05078125e-02,   2.23388672e-02],
                        [  4.69360352e-02,   4.87060547e-02],
                        [  7.10144043e-02,   7.26013184e-02],
                        [  7.94677734e-02,   8.07495117e-02],
                        [  6.13098145e-02,   6.21948242e-02],
                        [  1.30615234e-02,   1.34887695e-02],
                        [ -5.90209961e-02,  -5.90515137e-02],
                        [ -1.38641357e-01,  -1.39160156e-01],
                        [ -2.02301025e-01,  -2.03277588e-01],
                        [ -2.28637695e-01,  -2.29980469e-01],
                        [ -2.11639404e-01,  -2.13287354e-01],
                        [ -1.67297363e-01,  -1.69097900e-01],
                        [ -1.22741699e-01,  -1.24572754e-01],
                        [ -9.48791504e-02,  -9.66491699e-02],
                        [ -8.01391602e-02,  -8.16955566e-02],
                        [ -6.58874512e-02,  -6.71386719e-02],
                        [ -4.69665527e-02,  -4.77905273e-02],
                        [ -2.80761719e-02,  -2.84423828e-02],
                        [ -1.42822266e-02,  -1.41601562e-02],
                        [ -4.69970703e-03,  -4.08935547e-03],
                        [  5.37109375e-03,   6.40869141e-03],
                        [  1.94702148e-02,   2.09045410e-02],
                        [  3.73229980e-02,   3.90014648e-02],
                        [  5.20629883e-02,   5.38940430e-02],
                        [  5.30395508e-02,   5.49011230e-02],
                        [  3.69262695e-02,   3.86657715e-02],
                        [  1.36108398e-02,   1.51367188e-02],
                        [ -2.50244141e-03,  -1.31225586e-03],
                        [ -2.19726562e-03,  -1.46484375e-03],
                        [  1.78222656e-02,   1.81274414e-02],
                        [  5.55114746e-02,   5.52978516e-02],
                        [  1.00891113e-01,   1.00219727e-01],
                        [  1.38275146e-01,   1.37145996e-01],
                        [  1.55181885e-01,   1.53717041e-01],
                        [  1.50115967e-01,   1.48406982e-01],
                        [  1.29760742e-01,   1.27899170e-01],
                        [  1.01501465e-01,   9.96398926e-02],
                        [  7.29370117e-02,   7.11975098e-02],
                        [  5.30395508e-02,   5.15441895e-02],
                        [  4.61425781e-02,   4.50134277e-02],
                        [  4.69055176e-02,   4.62341309e-02],
                        [  4.90417480e-02,   4.88281250e-02],
                        [  5.80139160e-02,   5.82885742e-02],
                        [  8.50219727e-02,   8.57849121e-02],
                        [  1.28112793e-01,   1.29302979e-01],
                        [  1.70471191e-01,   1.71997070e-01],
                        [  1.96838379e-01,   1.98608398e-01],
                        [  2.01446533e-01,   2.03338623e-01],
                        [  1.84295654e-01,   1.86157227e-01],
                        [  1.52465820e-01,   1.54174805e-01],
                        [  1.20513916e-01,   1.21978760e-01],
                        [  1.00280762e-01,   1.01348877e-01],
                        [  9.13085938e-02,   9.19494629e-02],
                        [  8.58764648e-02,   8.59985352e-02],
                        [  7.90405273e-02,   7.86743164e-02],
                        [  7.01599121e-02,   6.93054199e-02],
                        [  5.83801270e-02,   5.71289062e-02],
                        [  4.36401367e-02,   4.20532227e-02],
                        [  2.97241211e-02,   2.79235840e-02],
                        [  2.05688477e-02,   1.86462402e-02],
                        [  1.49536133e-02,   1.30920410e-02],
                        [  9.85717773e-03,   8.17871094e-03],
                        [  6.25610352e-03,   4.85229492e-03],
                        [  5.24902344e-03,   4.24194336e-03],
                        [  3.17382812e-03,   2.62451172e-03],
                        [ -1.86157227e-03,  -1.92260742e-03],
                        [ -4.51660156e-03,  -4.08935547e-03],
                        [ -1.64794922e-03,  -7.01904297e-04],
                        [  1.15966797e-03,   2.47192383e-03],
                        [ -1.22070312e-03,   4.27246094e-04],
                        [ -5.43212891e-03,  -3.60107422e-03],
                        [ -7.38525391e-03,  -5.49316406e-03],
                        [ -9.82666016e-03,  -7.99560547e-03],
                        [ -1.72424316e-02,  -1.55944824e-02],
                        [ -2.92663574e-02,  -2.79235840e-02],
                        [ -4.33349609e-02,  -4.23889160e-02],
                        [ -5.72814941e-02,  -5.68237305e-02],
                        [ -6.75354004e-02,  -6.75659180e-02],
                        [ -7.07702637e-02,  -7.12890625e-02],
                        [ -6.86340332e-02,  -6.96105957e-02],
                        [ -6.47888184e-02,  -6.61926270e-02],
                        [ -6.05773926e-02,  -6.22863770e-02],
                        [ -5.67321777e-02,  -5.86242676e-02],
                        [ -5.46569824e-02,  -5.65795898e-02],
                        [ -5.37414551e-02,  -5.55725098e-02],
                        [ -5.18188477e-02,  -5.34362793e-02],
                        [ -4.86145020e-02,  -4.98962402e-02],
                        [ -4.59899902e-02,  -4.68444824e-02],
                        [ -4.57153320e-02,  -4.61120605e-02],
                        [ -4.88891602e-02,  -4.87670898e-02],
                        [ -5.52062988e-02,  -5.45959473e-02],
                        [ -6.14929199e-02,  -6.04248047e-02],
                        [ -6.51245117e-02,  -6.36901855e-02],
                        [ -6.82678223e-02,  -6.65588379e-02],
                        [ -7.19909668e-02,  -7.00988770e-02],
                        [ -7.00988770e-02,  -6.81762695e-02],
                        [ -5.72814941e-02,  -5.54809570e-02],
                        [ -3.86047363e-02,  -3.70483398e-02],
                        [ -2.43530273e-02,  -2.31323242e-02],
                        [ -1.85546875e-02,  -1.77612305e-02],
                        [ -1.61132812e-02,  -1.58081055e-02],
                        [ -9.85717773e-03,  -1.00402832e-02],
                        [  2.31933594e-03,   1.61743164e-03],
                        [  1.75781250e-02,   1.64489746e-02],
                        [  3.35083008e-02,   3.20129395e-02],
                        [  4.86450195e-02,   4.68750000e-02],
                        [  5.91125488e-02,   5.71899414e-02],
                        [  5.86547852e-02,   5.67321777e-02],
                        [  4.23889160e-02,   4.06188965e-02],
                        [  7.96508789e-03,   6.43920898e-03],
                        [ -4.44641113e-02,  -4.56237793e-02],
                        [ -1.08184814e-01,  -1.08917236e-01],
                        [ -1.66259766e-01,  -1.66503906e-01],
                        [ -1.95373535e-01,  -1.95098877e-01],
                        [ -1.80755615e-01,  -1.79992676e-01],
                        [ -1.32690430e-01,  -1.31469727e-01],
                        [ -8.07495117e-02,  -7.91625977e-02],
                        [ -4.46472168e-02,  -4.28466797e-02],
                        [ -1.98364258e-02,  -1.79138184e-02],
                        [  5.92041016e-03,   7.84301758e-03],
                        [  3.62243652e-02,   3.79943848e-02],
                        [  6.69860840e-02,   6.84814453e-02],
                        [  9.00573730e-02,   9.11560059e-02],
                        [  9.38415527e-02,   9.44824219e-02],
                        [  6.81152344e-02,   6.82678223e-02],
                        [  1.15661621e-02,   1.11999512e-02],
                        [ -6.57958984e-02,  -6.66503906e-02],
                        [ -1.45599365e-01,  -1.46881104e-01],
                        [ -2.05352783e-01,  -2.06970215e-01],
                        [ -2.26013184e-01,  -2.27874756e-01],
                        [ -2.04589844e-01,  -2.06542969e-01],
                        [ -1.59149170e-01,  -1.61041260e-01],
                        [ -1.14593506e-01,  -1.16302490e-01],
                        [ -8.38623047e-02,  -8.52966309e-02],
                        [ -6.43005371e-02,  -6.53686523e-02],
                        [ -4.78820801e-02,  -4.84619141e-02],
                        [ -3.13110352e-02,  -3.13720703e-02],
                        [ -1.68762207e-02,  -1.64489746e-02],
                        [ -7.11059570e-03,  -6.19506836e-03],
                        [ -5.79833984e-04,   7.62939453e-04],
                        [  6.10351562e-03,   7.78198242e-03],
                        [  1.40075684e-02,   1.58691406e-02],
                        [  2.04467773e-02,   2.23999023e-02],
                        [  2.22473145e-02,   2.41394043e-02],
                        [  1.95617676e-02,   2.12707520e-02],
                        [  1.82189941e-02,   1.95922852e-02],
                        [  2.48413086e-02,   2.58178711e-02],
                        [  3.81164551e-02,   3.86047363e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  5.88989258e-02,   5.83496094e-02],
                        [  7.30895996e-02,   7.21130371e-02],
                        [  9.90295410e-02,   9.76257324e-02],
                        [  1.28936768e-01,   1.27227783e-01],
                        [  1.46545410e-01,   1.44653320e-01],
                        [  1.44195557e-01,   1.42242432e-01],
                        [  1.29119873e-01,   1.27258301e-01],
                        [  1.11785889e-01,   1.10137939e-01],
                        [  9.49401855e-02,   9.35974121e-02],
                        [  7.62634277e-02,   7.53784180e-02],
                        [  5.65795898e-02,   5.61828613e-02],
                        [  4.16870117e-02,   4.17785645e-02],
                        [  3.68652344e-02,   3.74450684e-02],
                        [  4.33654785e-02,   4.44335938e-02],
                        [  6.18286133e-02,   6.32934570e-02],
                        [  9.29870605e-02,   9.47265625e-02],
                        [  1.32141113e-01,   1.34063721e-01],
                        [  1.67388916e-01,   1.69342041e-01],
                        [  1.85577393e-01,   1.87408447e-01],
                        [  1.80755615e-01,   1.82342529e-01],
                        [  1.58752441e-01,   1.60034180e-01],
                        [  1.33544922e-01,   1.34368896e-01],
                        [  1.16180420e-01,   1.16516113e-01],
                        [  1.06811523e-01,   1.06628418e-01],
                        [  9.69848633e-02,   9.62829590e-02],
                        [  8.08715820e-02,   7.97424316e-02],
                        [  6.22558594e-02,   6.07299805e-02],
                        [  4.78820801e-02,   4.60815430e-02],
                        [  3.84826660e-02,   3.65600586e-02],
                        [  3.05480957e-02,   2.85949707e-02],
                        [  2.31018066e-02,   2.12707520e-02],
                        [  1.80969238e-02,   1.65100098e-02],
                        [  1.56555176e-02,   1.44348145e-02],
                        [  1.31835938e-02,   1.24206543e-02],
                        [  8.33129883e-03,   8.08715820e-03],
                        [  1.52587891e-03,   1.80053711e-03],
                        [ -4.54711914e-03,  -3.78417969e-03],
                        [ -8.02612305e-03,  -6.83593750e-03],
                        [ -1.03149414e-02,  -8.72802734e-03],
                        [ -1.39465332e-02,  -1.21154785e-02],
                        [ -1.89819336e-02,  -1.70288086e-02],
                        [ -2.29492188e-02,  -2.10266113e-02],
                        [ -2.44750977e-02,  -2.27050781e-02],
                        [ -2.50244141e-02,  -2.35290527e-02],
                        [ -2.73742676e-02,  -2.62451172e-02],
                        [ -3.17382812e-02,  -3.10668945e-02],
                        [ -3.62548828e-02,  -3.61022949e-02],
                        [ -4.03747559e-02,  -4.07409668e-02],
                        [ -4.39453125e-02,  -4.47998047e-02],
                        [ -4.58984375e-02,  -4.71801758e-02],
                        [ -4.77294922e-02,  -4.93469238e-02],
                        [ -5.23986816e-02,  -5.42602539e-02],
                        [ -5.85021973e-02,  -6.04553223e-02],
                        [ -6.21337891e-02,  -6.40563965e-02],
                        [ -6.30798340e-02,  -6.48498535e-02],
                        [ -6.40563965e-02,  -6.55212402e-02],
                        [ -6.66503906e-02,  -6.77185059e-02],
                        [ -6.96411133e-02,  -7.02209473e-02],
                        [ -6.95190430e-02,  -6.96105957e-02],
                        [ -6.36901855e-02,  -6.32629395e-02],
                        [ -5.37109375e-02,  -5.27648926e-02],
                        [ -4.46166992e-02,  -4.32739258e-02],
                        [ -3.98864746e-02,  -3.82080078e-02],
                        [ -3.83605957e-02,  -3.64990234e-02],
                        [ -3.86962891e-02,  -3.67431641e-02],
                        [ -4.26025391e-02,  -4.06799316e-02],
                        [ -4.96215820e-02,  -4.79125977e-02],
                        [ -5.32531738e-02,  -5.18493652e-02],
                        [ -4.81567383e-02,  -4.71496582e-02],
                        [ -3.75061035e-02,  -3.69873047e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -1.48010254e-02,  -1.53198242e-02],
                        [  1.34277344e-03,   3.66210938e-04],
                        [  1.95617676e-02,   1.81579590e-02],
                        [  3.54309082e-02,   3.37219238e-02],
                        [  4.78515625e-02,   4.59594727e-02],
                        [  5.63659668e-02,   5.44128418e-02],
                        [  5.69152832e-02,   5.50231934e-02],
                        [  4.25720215e-02,   4.09240723e-02],
                        [  6.10351562e-03,   4.76074219e-03],
                        [ -5.53283691e-02,  -5.62438965e-02],
                        [ -1.30493164e-01,  -1.30920410e-01],
                        [ -1.91925049e-01,  -1.91833496e-01],
                        [ -2.12890625e-01,  -2.12280273e-01],
                        [ -1.89910889e-01,  -1.88842773e-01],
                        [ -1.42425537e-01,  -1.40960693e-01],
                        [ -9.28039551e-02,  -9.10644531e-02],
                        [ -5.40771484e-02,  -5.21545410e-02],
                        [ -2.91137695e-02,  -2.71606445e-02],
                        [ -1.06811523e-02,  -8.81958008e-03],
                        [  1.26953125e-02,   1.43127441e-02],
                        [  4.41894531e-02,   4.54711914e-02],
                        [  7.53784180e-02,   7.62329102e-02],
                        [  9.52453613e-02,   9.56115723e-02],
                        [  9.80834961e-02,   9.79003906e-02],
                        [  8.12988281e-02,   8.06274414e-02],
                        [  4.01611328e-02,   3.90319824e-02],
                        [ -2.91442871e-02,  -3.06701660e-02],
                        [ -1.17309570e-01,  -1.19079590e-01],
                        [ -1.96136475e-01,  -1.98059082e-01],
                        [ -2.34008789e-01,  -2.35961914e-01],
                        [ -2.21069336e-01,  -2.22900391e-01],
                        [ -1.75048828e-01,  -1.76605225e-01],
                        [ -1.23291016e-01,  -1.24511719e-01],
                        [ -8.51135254e-02,  -8.58764648e-02],
                        [ -6.58874512e-02,  -6.61621094e-02],
                        [ -5.74035645e-02,  -5.71594238e-02],
                        [ -4.68139648e-02,  -4.60510254e-02],
                        [ -3.09448242e-02,  -2.97241211e-02],
                        [ -1.68762207e-02,  -1.53198242e-02],
                        [ -8.48388672e-03,  -6.65283203e-03],
                        [ -1.00708008e-03,   9.46044922e-04],
                        [  9.79614258e-03,   1.17492676e-02],
                        [  2.11791992e-02,   2.29797363e-02],
                        [  2.87170410e-02,   3.02429199e-02],
                        [  3.26232910e-02,   3.37829590e-02],
                        [  3.55834961e-02,   3.62854004e-02],
                        [  3.82385254e-02,   3.84216309e-02],
                        [  4.04663086e-02,   4.01306152e-02],
                        [  4.52575684e-02,   4.44335938e-02],
                        [  5.77697754e-02,   5.64880371e-02],
                        [  7.93457031e-02,   7.77282715e-02],
                        [  1.04461670e-01,   1.02630615e-01],
                        [  1.24755859e-01,   1.22802734e-01],
                        [  1.34063721e-01,   1.32110596e-01],
                        [  1.30523682e-01,   1.28753662e-01],
                        [  1.17950439e-01,   1.16485596e-01],
                        [  1.04492188e-01,   1.03424072e-01],
                        [  9.60693359e-02,   9.54589844e-02],
                        [  9.03015137e-02,   9.02099609e-02],
                        [  7.97119141e-02,   8.01086426e-02],
                        [  6.11877441e-02,   6.21032715e-02],
                        [  4.04052734e-02,   4.17480469e-02],
                        [  2.73132324e-02,   2.89916992e-02],
                        [  3.05480957e-02,   3.24401855e-02],
                        [  5.31005859e-02,   5.50842285e-02],
                        [  9.03625488e-02,   9.22546387e-02],
                        [  1.33605957e-01,   1.35314941e-01],
                        [  1.72149658e-01,   1.73583984e-01],
                        [  1.91131592e-01,   1.92138672e-01],
                        [  1.80847168e-01,   1.81365967e-01],
                        [  1.51763916e-01,   1.51763916e-01],
                        [  1.25701904e-01,   1.25183105e-01],
                        [  1.11175537e-01,   1.10198975e-01],
                        [  1.00860596e-01,   9.94873047e-02],
                        [  8.95690918e-02,   8.78601074e-02],
                        [  7.95288086e-02,   7.76367188e-02],
                        [  7.08618164e-02,   6.89086914e-02],
                        [  5.95092773e-02,   5.76171875e-02],
                        [  4.42199707e-02,   4.25415039e-02],
                        [  2.83203125e-02,   2.69775391e-02],
                        [  1.56250000e-02,   1.46789551e-02],
                        [  7.90405273e-03,   7.44628906e-03],
                        [  4.02832031e-03,   4.11987305e-03],
                        [  1.46484375e-03,   2.04467773e-03],
                        [ -7.32421875e-04,   3.35693359e-04],
                        [ -2.22778320e-03,  -7.62939453e-04],
                        [ -3.72314453e-03,  -1.98364258e-03],
                        [ -5.52368164e-03,  -3.60107422e-03],
                        [ -6.77490234e-03,  -4.79125977e-03],
                        [ -7.99560547e-03,  -6.13403320e-03],
                        [ -9.79614258e-03,  -8.14819336e-03],
                        [ -1.07421875e-02,  -9.46044922e-03],
                        [ -1.07421875e-02,  -9.88769531e-03],
                        [ -1.40686035e-02,  -1.37329102e-02],
                        [ -2.38342285e-02,  -2.39868164e-02],
                        [ -3.58886719e-02,  -3.65600586e-02],
                        [ -4.41284180e-02,  -4.52575684e-02],
                        [ -4.84008789e-02,  -4.98962402e-02],
                        [ -5.30090332e-02,  -5.48095703e-02],
                        [ -5.99975586e-02,  -6.19506836e-02],
                        [ -6.69555664e-02,  -6.89086914e-02],
                        [ -7.04345703e-02,  -7.22656250e-02],
                        [ -6.96105957e-02,  -7.11975098e-02],
                        [ -6.59484863e-02,  -6.71691895e-02],
                        [ -6.14929199e-02,  -6.22558594e-02],
                        [ -5.85937500e-02,  -5.88989258e-02],
                        [ -5.74340820e-02,  -5.71899414e-02],
                        [ -5.47485352e-02,  -5.40161133e-02],
                        [ -4.93774414e-02,  -4.81872559e-02],
                        [ -4.48913574e-02,  -4.33349609e-02],
                        [ -4.37011719e-02,  -4.18701172e-02],
                        [ -4.36096191e-02,  -4.16564941e-02],
                        [ -4.11071777e-02,  -3.91540527e-02],
                        [ -3.49731445e-02,  -3.31726074e-02],
                        [ -2.84423828e-02,  -2.69165039e-02],
                        [ -2.78015137e-02,  -2.66418457e-02],
                        [ -3.46984863e-02,  -3.39965820e-02],
                        [ -4.13513184e-02,  -4.11376953e-02],
                        [ -3.82080078e-02,  -3.85131836e-02],
                        [ -2.48413086e-02,  -2.56652832e-02],
                        [ -8.54492188e-03,  -9.79614258e-03],
                        [  6.46972656e-03,   4.85229492e-03],
                        [  2.14843750e-02,   1.96228027e-02],
                        [  3.69262695e-02,   3.49731445e-02],
                        [  4.99267578e-02,   4.79736328e-02],
                        [  5.63354492e-02,   5.45654297e-02],
                        [  4.87060547e-02,   4.72412109e-02],
                        [  1.57470703e-02,   1.46789551e-02],
                        [ -4.72412109e-02,  -4.78515625e-02],
                        [ -1.25854492e-01,  -1.25946045e-01],
                        [ -1.89819336e-01,  -1.89422607e-01],
                        [ -2.13226318e-01,  -2.12341309e-01],
                        [ -1.92443848e-01,  -1.91101074e-01],
                        [ -1.46789551e-01,  -1.45141602e-01],
                        [ -1.02508545e-01,  -1.00646973e-01],
                        [ -7.29064941e-02,  -7.09533691e-02],
                        [ -5.23376465e-02,  -5.04150391e-02],
                        [ -2.78320312e-02,  -2.60925293e-02],
                        [  5.27954102e-03,   6.71386719e-03],
                        [  3.92761230e-02,   4.02832031e-02],
                        [  6.52160645e-02,   6.57653809e-02],
                        [  8.49609375e-02,   8.49914551e-02],
                        [  1.04187012e-01,   1.03698730e-01],
                        [  1.15539551e-01,   1.14562988e-01],
                        [  9.95788574e-02,   9.82055664e-02],
                        [  4.41894531e-02,   4.24804688e-02],
                        [ -4.25720215e-02,  -4.44641113e-02],
                        [ -1.36230469e-01,  -1.38214111e-01],
                        [ -2.07519531e-01,  -2.09411621e-01],
                        [ -2.34497070e-01,  -2.36175537e-01],
                        [ -2.13684082e-01,  -2.15026855e-01],
                        [ -1.64489746e-01,  -1.65435791e-01],
                        [ -1.17309570e-01,  -1.17767334e-01],
                        [ -9.01794434e-02,  -9.01184082e-02],
                        [ -7.75146484e-02,  -7.69653320e-02],
                        [ -6.28356934e-02,  -6.17980957e-02],
                        [ -4.04663086e-02,  -3.90319824e-02],
                        [ -2.04467773e-02,  -1.87072754e-02],
                        [ -1.23901367e-02,  -1.04980469e-02],
                        [ -1.28173828e-02,  -1.08642578e-02],
                        [ -1.15661621e-02,  -9.70458984e-03],
                        [ -3.23486328e-03,  -1.58691406e-03],
                        [  1.07727051e-02,   1.20544434e-02],
                        [  2.49633789e-02,   2.58178711e-02],
                        [  3.39965820e-02,   3.43627930e-02],
                        [  3.67736816e-02,   3.66210938e-02],
                        [  3.69262695e-02,   3.62548828e-02],
                        [  3.97644043e-02,   3.86657715e-02],
                        [  5.03540039e-02,   4.88281250e-02],
                        [  7.14111328e-02,   6.96105957e-02],
                        [  9.97314453e-02,   9.78088379e-02],
                        [  1.25366211e-01,   1.23413086e-01],
                        [  1.38610840e-01,   1.36779785e-01],
                        [  1.38488770e-01,   1.36901855e-01],
                        [  1.31408691e-01,   1.30157471e-01],
                        [  1.22192383e-01,   1.21398926e-01],
                        [  1.10076904e-01,   1.09771729e-01],
                        [  9.42687988e-02,   9.44824219e-02],
                        [  7.79724121e-02,   7.87048340e-02],
                        [  6.37512207e-02,   6.49414062e-02],
                        [  5.01403809e-02,   5.16967773e-02],
                        [  3.67126465e-02,   3.85131836e-02],
                        [  2.74963379e-02,   2.94494629e-02],
                        [  2.79235840e-02,   2.98767090e-02],
                        [  4.24804688e-02,   4.43115234e-02],
                        [  7.18078613e-02,   7.33642578e-02],
                        [  1.10198975e-01,   1.11358643e-01],
                        [  1.49719238e-01,   1.50421143e-01],
                        [  1.82067871e-01,   1.82281494e-01],
                        [  1.95251465e-01,   1.94946289e-01],
                        [  1.81030273e-01,   1.80206299e-01],
                        [  1.47979736e-01,   1.46728516e-01],
                        [  1.14715576e-01,   1.13098145e-01],
                        [  9.08508301e-02,   8.90197754e-02],
                        [  7.46459961e-02,   7.26928711e-02],
                        [  6.41174316e-02,   6.21948242e-02],
                        [  5.97229004e-02,   5.79528809e-02],
                        [  5.82580566e-02,   5.67626953e-02],
                        [  5.31005859e-02,   5.20019531e-02],
                        [  4.12902832e-02,   4.06799316e-02],
                        [  2.63366699e-02,   2.61840820e-02],
                        [  1.36718750e-02,   1.40686035e-02],
                        [  4.82177734e-03,   5.70678711e-03],
                        [ -3.50952148e-03,  -2.19726562e-03],
                        [ -1.35803223e-02,  -1.19323730e-02],
                        [ -2.26440430e-02,  -2.07824707e-02],
                        [ -2.63977051e-02,  -2.44445801e-02],
                        [ -2.31323242e-02,  -2.12097168e-02],
                        [ -1.52282715e-02,  -1.35192871e-02],
                        [ -7.41577148e-03,  -5.98144531e-03],
                        [ -3.29589844e-03,  -2.25830078e-03],
                        [ -4.39453125e-03,  -3.84521484e-03],
                        [ -1.01928711e-02,  -1.01623535e-02],
                        [ -1.75476074e-02,  -1.80053711e-02],
                        [ -2.31323242e-02,  -2.40783691e-02],
                        [ -2.73742676e-02,  -2.87475586e-02],
                        [ -3.27453613e-02,  -3.44238281e-02],
                        [ -4.00390625e-02,  -4.19311523e-02],
                        [ -4.90722656e-02,  -5.10559082e-02],
                        [ -5.92651367e-02,  -6.11572266e-02],
                        [ -6.81152344e-02,  -6.97937012e-02],
                        [ -7.25402832e-02,  -7.39135742e-02],
                        [ -7.31811523e-02,  -7.41577148e-02],
                        [ -7.43408203e-02,  -7.47985840e-02],
                        [ -7.68127441e-02,  -7.67822266e-02],
                        [ -7.51037598e-02,  -7.45544434e-02],
                        [ -6.46362305e-02,  -6.36291504e-02],
                        [ -4.94689941e-02,  -4.80346680e-02],
                        [ -3.86962891e-02,  -3.69567871e-02],
                        [ -3.64074707e-02,  -3.44848633e-02],
                        [ -3.86352539e-02,  -3.66821289e-02],
                        [ -4.01306152e-02,  -3.82690430e-02],
                        [ -4.00390625e-02,  -3.83911133e-02],
                        [ -3.96728516e-02,  -3.83605957e-02],
                        [ -3.96118164e-02,  -3.87268066e-02],
                        [ -3.85437012e-02,  -3.81469727e-02],
                        [ -3.36608887e-02,  -3.37829590e-02],
                        [ -2.40173340e-02,  -2.46582031e-02],
                        [ -1.23291016e-02,  -1.34277344e-02],
                        [ -6.71386719e-04,  -2.16674805e-03],
                        [  1.14440918e-02,   9.67407227e-03],
                        [  2.35290527e-02,   2.16064453e-02],
                        [  3.32946777e-02,   3.13415527e-02],
                        [  4.01611328e-02,   3.83300781e-02],
                        [  4.45861816e-02,   4.29687500e-02],
                        [  4.10461426e-02,   3.97949219e-02],
                        [  1.66015625e-02,   1.58081055e-02],
                        [ -3.63159180e-02,  -3.66210938e-02],
                        [ -1.06506348e-01,  -1.06292725e-01],
                        [ -1.68640137e-01,  -1.67907715e-01],
                        [ -2.01202393e-01,  -2.00042725e-01],
                        [ -1.98028564e-01,  -1.96502686e-01],
                        [ -1.67114258e-01,  -1.65313721e-01],
                        [ -1.24053955e-01,  -1.22131348e-01],
                        [ -8.47778320e-02,  -8.28247070e-02],
                        [ -5.66711426e-02,  -5.48706055e-02],
                        [ -3.58276367e-02,  -3.42712402e-02],
                        [ -1.53808594e-02,  -1.41906738e-02],
                        [  6.92749023e-03,   7.65991211e-03],
                        [  3.18298340e-02,   3.20434570e-02],
                        [  6.08825684e-02,   6.05773926e-02],
                        [  9.12475586e-02,   9.04846191e-02],
                        [  1.14318848e-01,   1.13067627e-01],
                        [  1.20788574e-01,   1.19201660e-01],
                        [  1.02478027e-01,   1.00646973e-01],
                        [  5.11169434e-02,   4.91943359e-02],
                        [ -3.38745117e-02,  -3.57971191e-02],
                        [ -1.33972168e-01,  -1.35742188e-01],
                        [ -2.14691162e-01,  -2.16186523e-01],
                        [ -2.46307373e-01,  -2.47436523e-01],
                        [ -2.23083496e-01,  -2.23724365e-01],
                        [ -1.66473389e-01,  -1.66625977e-01],
                        [ -1.10260010e-01,  -1.09893799e-01],
                        [ -7.60192871e-02,  -7.51342773e-02],
                        [ -6.09130859e-02,  -5.96313477e-02],
                        [ -5.07202148e-02,  -4.90722656e-02],
                        [ -3.91540527e-02,  -3.72924805e-02],
                        [ -2.96020508e-02,  -2.76489258e-02],
                        [ -2.31323242e-02,  -2.12402344e-02],
                        [ -1.49841309e-02,  -1.32446289e-02],
                        [ -2.53295898e-03,  -1.09863281e-03],
                        [  1.04980469e-02,   1.15356445e-02],
                        [  2.06298828e-02,   2.11791992e-02],
                        [  2.83508301e-02,   2.84118652e-02],
                        [  3.45764160e-02,   3.41186523e-02],
                        [  3.75976562e-02,   3.66516113e-02],
                        [  3.66210938e-02,   3.52783203e-02],
                        [  3.61022949e-02,   3.44238281e-02],
                        [  4.30603027e-02,   4.11987305e-02],
                        [  6.07299805e-02,   5.87768555e-02],
                        [  8.70056152e-02,   8.51135254e-02],
                        [  1.15692139e-01,   1.14013672e-01],
                        [  1.36352539e-01,   1.34979248e-01],
                        [  1.39373779e-01,   1.38397217e-01],
                        [  1.25610352e-01,   1.25122070e-01],
                        [  1.06231689e-01,   1.06262207e-01],
                        [  9.20715332e-02,   9.25903320e-02],
                        [  8.62426758e-02,   8.72497559e-02],
                        [  8.49304199e-02,   8.63342285e-02],
                        [  8.07495117e-02,   8.24584961e-02],
                        [  6.79321289e-02,   6.98242188e-02],
                        [  4.84008789e-02,   5.03540039e-02],
                        [  3.19824219e-02,   3.38439941e-02],
                        [  2.73437500e-02,   2.89611816e-02],
                        [  3.58581543e-02,   3.71704102e-02],
                        [  5.57250977e-02,   5.66406250e-02],
                        [  8.65478516e-02,   8.69445801e-02],
                        [  1.25396729e-01,   1.25305176e-01],
                        [  1.61346436e-01,   1.60736084e-01],
                        [  1.79290771e-01,   1.78192139e-01],
                        [  1.72637939e-01,   1.71173096e-01],
                        [  1.48864746e-01,   1.47125244e-01],
                        [  1.20086670e-01,   1.18164062e-01],
                        [  9.32617188e-02,   9.13391113e-02],
                        [  7.09533691e-02,   6.91223145e-02],
                        [  5.48400879e-02,   5.32531738e-02],
                        [  4.60815430e-02,   4.48608398e-02],
                        [  4.37927246e-02,   4.29687500e-02],
                        [  4.46166992e-02,   4.43115234e-02],
                        [  4.43115234e-02,   4.44946289e-02],
                        [  4.01306152e-02,   4.08020020e-02],
                        [  3.21655273e-02,   3.33251953e-02],
                        [  2.13623047e-02,   2.28881836e-02],
                        [  7.41577148e-03,   9.21630859e-03],
                        [ -8.39233398e-03,  -6.50024414e-03],
                        [ -2.08740234e-02,  -1.89514160e-02],
                        [ -2.60009766e-02,  -2.42004395e-02],
                        [ -2.60925293e-02,  -2.45361328e-02],
                        [ -2.54211426e-02,  -2.42309570e-02],
                        [ -2.51464844e-02,  -2.44140625e-02],
                        [ -2.48107910e-02,  -2.45666504e-02],
                        [ -2.48718262e-02,  -2.51464844e-02],
                        [ -2.51159668e-02,  -2.58789062e-02],
                        [ -2.32238770e-02,  -2.44140625e-02],
                        [ -1.86767578e-02,  -2.02331543e-02],
                        [ -1.64794922e-02,  -1.82800293e-02],
                        [ -2.17285156e-02,  -2.36511230e-02],
                        [ -3.26232910e-02,  -3.45458984e-02],
                        [ -4.38537598e-02,  -4.55932617e-02],
                        [ -5.35583496e-02,  -5.50537109e-02],
                        [ -6.27136230e-02,  -6.38122559e-02],
                        [ -7.11059570e-02,  -7.17773438e-02],
                        [ -7.75756836e-02,  -7.77282715e-02],
                        [ -8.08715820e-02,  -8.05358887e-02],
                        [ -7.97119141e-02,  -7.88879395e-02],
                        [ -7.38525391e-02,  -7.25708008e-02],
                        [ -6.54296875e-02,  -6.38427734e-02],
                        [ -5.76171875e-02,  -5.57861328e-02],
                        [ -5.22155762e-02,  -5.02929688e-02],
                        [ -4.91943359e-02,  -4.73022461e-02],
                        [ -4.57763672e-02,  -4.40673828e-02],
                        [ -3.92456055e-02,  -3.78417969e-02],
                        [ -3.22875977e-02,  -3.12500000e-02],
                        [ -3.07922363e-02,  -3.02429199e-02],
                        [ -3.52478027e-02,  -3.51867676e-02],
                        [ -4.02526855e-02,  -4.06799316e-02],
                        [ -4.08325195e-02,  -4.17480469e-02],
                        [ -3.52172852e-02,  -3.65295410e-02],
                        [ -2.43225098e-02,  -2.59399414e-02],
                        [ -1.06506348e-02,  -1.24816895e-02],
                        [  4.33349609e-03,   2.44140625e-03],
                        [  2.06604004e-02,   1.87988281e-02],
                        [  3.80249023e-02,   3.63464355e-02],
                        [  5.51452637e-02,   5.37719727e-02],
                        [  6.67724609e-02,   6.57958984e-02],
                        [  6.02111816e-02,   5.97229004e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [ -4.35791016e-02,  -4.30908203e-02],
                        [ -1.19323730e-01,  -1.18347168e-01],
                        [ -1.81671143e-01,  -1.80297852e-01],
                        [ -2.14538574e-01,  -2.12860107e-01],
                        [ -2.10693359e-01,  -2.08862305e-01],
                        [ -1.75750732e-01,  -1.73828125e-01],
                        [ -1.28143311e-01,  -1.26312256e-01],
                        [ -8.73413086e-02,  -8.57238770e-02],
                        [ -6.04248047e-02,  -5.91430664e-02],
                        [ -4.21142578e-02,  -4.12292480e-02],
                        [ -2.54516602e-02,  -2.50244141e-02],
                        [ -7.20214844e-03,  -7.29370117e-03],
                        [  1.56555176e-02,   1.50451660e-02],
                        [  4.58068848e-02,   4.47692871e-02],
                        [  8.01086426e-02,   7.87048340e-02],
                        [  1.11145020e-01,   1.09436035e-01],
                        [  1.32110596e-01,   1.30249023e-01],
                        [  1.33026123e-01,   1.31164551e-01],
                        [  9.93041992e-02,   9.75341797e-02],
                        [  2.38952637e-02,   2.23388672e-02],
                        [ -7.98034668e-02,  -8.10241699e-02],
                        [ -1.79626465e-01,  -1.80419922e-01],
                        [ -2.39898682e-01,  -2.40234375e-01],
                        [ -2.41271973e-01,  -2.41088867e-01],
                        [ -1.94366455e-01,  -1.93695068e-01],
                        [ -1.34246826e-01,  -1.33148193e-01],
                        [ -9.31396484e-02,  -9.16748047e-02],
                        [ -7.51037598e-02,  -7.33642578e-02],
                        [ -6.18286133e-02,  -5.99670410e-02],
                        [ -4.16870117e-02,  -3.97949219e-02],
                        [ -2.27050781e-02,  -2.09655762e-02],
                        [ -1.56860352e-02,  -1.41601562e-02],
                        [ -1.56860352e-02,  -1.45568848e-02],
                        [ -9.70458984e-03,  -9.00268555e-03],
                        [  5.34057617e-03,   5.58471680e-03],
                        [  2.13928223e-02,   2.11486816e-02],
                        [  3.16162109e-02,   3.08837891e-02],
                        [  3.58886719e-02,   3.47290039e-02],
                        [  3.69873047e-02,   3.54919434e-02],
                        [  3.76281738e-02,   3.58886719e-02],
                        [  4.07714844e-02,   3.89099121e-02],
                        [  4.95300293e-02,   4.76684570e-02],
                        [  6.50634766e-02,   6.33544922e-02],
                        [  8.59069824e-02,   8.44726562e-02],
                        [  1.08306885e-01,   1.07238770e-01],
                        [  1.25885010e-01,   1.25213623e-01],
                        [  1.32171631e-01,   1.32019043e-01],
                        [  1.26861572e-01,   1.27197266e-01],
                        [  1.15966797e-01,   1.16760254e-01],
                        [  1.06781006e-01,   1.08001709e-01],
                        [  1.03637695e-01,   1.05194092e-01],
                        [  1.03820801e-01,   1.05560303e-01],
                        [  9.70458984e-02,   9.88769531e-02],
                        [  7.67211914e-02,   7.85522461e-02],
                        [  5.06286621e-02,   5.22766113e-02],
                        [  3.28674316e-02,   3.42407227e-02],
                        [  2.77709961e-02,   2.87780762e-02],
                        [  2.93273926e-02,   2.99072266e-02],
                        [  3.56140137e-02,   3.57055664e-02],
                        [  5.37109375e-02,   5.33142090e-02],
                        [  8.83483887e-02,   8.74938965e-02],
                        [  1.31958008e-01,   1.30706787e-01],
                        [  1.68395996e-01,   1.66839600e-01],
                        [  1.83410645e-01,   1.81640625e-01],
                        [  1.73553467e-01,   1.71722412e-01],
                        [  1.48345947e-01,   1.46575928e-01],
                        [  1.22833252e-01,   1.21215820e-01],
                        [  1.05010986e-01,   1.03698730e-01],
                        [  9.11865234e-02,   9.02709961e-02],
                        [  7.51342773e-02,   7.46459961e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  3.92761230e-02,   3.97644043e-02],
                        [  2.28271484e-02,   2.37731934e-02],
                        [  9.33837891e-03,   1.06201172e-02],
                        [  2.80761719e-03,   4.39453125e-03],
                        [  2.53295898e-03,   4.30297852e-03],
                        [  1.77001953e-03,   3.60107422e-03],
                        [ -2.22778320e-03,  -4.88281250e-04],
                        [ -4.45556641e-03,  -2.89916992e-03],
                        [ -1.61743164e-03,  -3.66210938e-04],
                        [  2.13623047e-03,   2.99072266e-03],
                        [  2.41088867e-03,   2.83813477e-03],
                        [ -6.10351562e-05,  -1.22070312e-04],
                        [ -3.02124023e-03,  -3.57055664e-03],
                        [ -5.61523438e-03,  -6.59179688e-03],
                        [ -7.53784180e-03,  -8.88061523e-03],
                        [ -9.70458984e-03,  -1.12915039e-02],
                        [ -1.60827637e-02,  -1.78527832e-02],
                        [ -3.04565430e-02,  -3.22570801e-02],
                        [ -4.91943359e-02,  -5.09033203e-02],
                        [ -6.34765625e-02,  -6.49719238e-02],
                        [ -7.12280273e-02,  -7.24182129e-02],
                        [ -7.76367188e-02,  -7.83996582e-02],
                        [ -8.13598633e-02,  -8.16650391e-02],
                        [ -7.47375488e-02,  -7.45849609e-02],
                        [ -5.97534180e-02,  -5.91430664e-02],
                        [ -4.91333008e-02,  -4.80957031e-02],
                        [ -4.98962402e-02,  -4.85229492e-02],
                        [ -5.61218262e-02,  -5.45043945e-02],
                        [ -5.78002930e-02,  -5.60302734e-02],
                        [ -5.20324707e-02,  -5.02624512e-02],
                        [ -4.47387695e-02,  -4.30603027e-02],
                        [ -4.31518555e-02,  -4.17175293e-02],
                        [ -4.80041504e-02,  -4.69055176e-02],
                        [ -5.43212891e-02,  -5.36193848e-02],
                        [ -5.81665039e-02,  -5.79223633e-02],
                        [ -5.88684082e-02,  -5.90820312e-02],
                        [ -5.54199219e-02,  -5.60913086e-02],
                        [ -4.64782715e-02,  -4.75769043e-02],
                        [ -3.30810547e-02,  -3.45153809e-02],
                        [ -1.83105469e-02,  -1.99584961e-02],
                        [ -5.03540039e-03,  -6.77490234e-03],
                        [  5.55419922e-03,   3.81469727e-03],
                        [  1.58386230e-02,   1.42211914e-02],
                        [  3.00292969e-02,   2.86865234e-02],
                        [  4.86450195e-02,   4.76074219e-02],
                        [  6.39343262e-02,   6.33239746e-02],
                        [  6.28051758e-02,   6.26220703e-02],
                        [  3.46374512e-02,   3.49426270e-02],
                        [ -2.16979980e-02,  -2.09655762e-02],
                        [ -9.64660645e-02,  -9.53369141e-02],
                        [ -1.70288086e-01,  -1.68853760e-01],
                        [ -2.18872070e-01,  -2.17224121e-01],
                        [ -2.24670410e-01,  -2.22930908e-01],
                        [ -1.90277100e-01,  -1.88568115e-01],
                        [ -1.39343262e-01,  -1.37786865e-01],
                        [ -9.84191895e-02,  -9.71374512e-02],
                        [ -7.57446289e-02,  -7.47985840e-02],
                        [ -6.13098145e-02,  -6.07604980e-02],
                        [ -4.46166992e-02,  -4.45251465e-02],
                        [ -2.42004395e-02,  -2.45666504e-02],
                        [ -2.92968750e-03,  -3.72314453e-03],
                        [  1.80664062e-02,   1.69067383e-02],
                        [  4.12597656e-02,   3.97949219e-02],
                        [  7.01904297e-02,   6.85424805e-02],
                        [  1.03576660e-01,   1.01867676e-01],
                        [  1.31591797e-01,   1.29913330e-01],
                        [  1.38824463e-01,   1.37329102e-01],
                        [  1.12091064e-01,   1.10839844e-01],
                        [  4.72106934e-02,   4.63256836e-02],
                        [ -4.66613770e-02,  -4.71191406e-02],
                        [ -1.46057129e-01,  -1.46057129e-01],
                        [ -2.19543457e-01,  -2.19116211e-01],
                        [ -2.44384766e-01,  -2.43530273e-01],
                        [ -2.20275879e-01,  -2.19085693e-01],
                        [ -1.67785645e-01,  -1.66290283e-01],
                        [ -1.14807129e-01,  -1.13159180e-01],
                        [ -7.95593262e-02,  -7.78503418e-02],
                        [ -6.02111816e-02,  -5.85937500e-02],
                        [ -4.42199707e-02,  -4.27856445e-02],
                        [ -2.78320312e-02,  -2.66723633e-02],
                        [ -1.81884766e-02,  -1.73950195e-02],
                        [ -1.78222656e-02,  -1.74560547e-02],
                        [ -1.89514160e-02,  -1.90124512e-02],
                        [ -1.42517090e-02,  -1.47399902e-02],
                        [ -3.63159180e-03,  -4.51660156e-03],
                        [  8.94165039e-03,   7.72094727e-03],
                        [  1.87377930e-02,   1.72729492e-02],
                        [  2.29187012e-02,   2.12707520e-02],
                        [  2.38647461e-02,   2.22167969e-02],
                        [  2.86254883e-02,   2.70385742e-02],
                        [  4.36401367e-02,   4.22668457e-02],
                        [  7.08007812e-02,   6.97021484e-02],
                        [  1.05041504e-01,   1.04339600e-01],
                        [  1.35040283e-01,   1.34735107e-01],
                        [  1.48803711e-01,   1.48925781e-01],
                        [  1.41815186e-01,   1.42333984e-01],
                        [  1.20788574e-01,   1.21704102e-01],
                        [  9.97314453e-02,   1.01013184e-01],
                        [  9.01184082e-02,   9.15832520e-02],
                        [  9.23461914e-02,   9.39331055e-02],
                        [  9.67102051e-02,   9.83276367e-02],
                        [  9.36584473e-02,   9.51538086e-02],
                        [  8.23364258e-02,   8.36486816e-02],
                        [  6.73828125e-02,   6.83898926e-02],
                        [  5.15136719e-02,   5.21545410e-02],
                        [  3.56750488e-02,   3.58886719e-02],
                        [  2.20336914e-02,   2.18505859e-02],
                        [  1.50451660e-02,   1.44348145e-02],
                        [  2.13623047e-02,   2.03857422e-02],
                        [  4.69665527e-02,   4.56848145e-02],
                        [  9.04846191e-02,   8.89892578e-02],
                        [  1.39831543e-01,   1.38244629e-01],
                        [  1.77124023e-01,   1.75537109e-01],
                        [  1.88201904e-01,   1.86737061e-01],
                        [  1.70806885e-01,   1.69555664e-01],
                        [  1.36444092e-01,   1.35498047e-01],
                        [  1.03302002e-01,   1.02722168e-01],
                        [  8.26721191e-02,   8.24890137e-02],
                        [  7.28454590e-02,   7.31201172e-02],
                        [  6.69250488e-02,   6.75659180e-02],
                        [  6.02416992e-02,   6.12487793e-02],
                        [  4.89807129e-02,   5.02929688e-02],
                        [  3.21350098e-02,   3.36303711e-02],
                        [  1.56860352e-02,   1.72424316e-02],
                        [  6.40869141e-03,   7.93457031e-03],
                        [  3.14331055e-03,   4.54711914e-03],
                        [  2.13623047e-04,   1.37329102e-03],
                        [ -4.11987305e-03,  -3.26538086e-03],
                        [ -6.71386719e-03,  -6.19506836e-03],
                        [ -5.43212891e-03,  -5.34057617e-03],
                        [ -2.44140625e-03,  -2.74658203e-03],
                        [ -1.00708008e-03,  -1.70898438e-03],
                        [ -1.83105469e-03,  -2.86865234e-03],
                        [ -4.45556641e-03,  -5.76782227e-03],
                        [ -1.00097656e-02,  -1.14746094e-02],
                        [ -1.96838379e-02,  -2.12402344e-02],
                        [ -3.17687988e-02,  -3.32641602e-02],
                        [ -4.20837402e-02,  -4.34265137e-02],
                        [ -4.71191406e-02,  -4.82177734e-02],
                        [ -4.66613770e-02,  -4.74548340e-02],
                        [ -4.52880859e-02,  -4.57153320e-02],
                        [ -4.85229492e-02,  -4.85534668e-02],
                        [ -5.52062988e-02,  -5.48400879e-02],
                        [ -5.88073730e-02,  -5.80444336e-02],
                        [ -5.67626953e-02,  -5.57250977e-02],
                        [ -5.21240234e-02,  -5.08422852e-02],
                        [ -4.89196777e-02,  -4.74548340e-02],
                        [ -5.05371094e-02,  -4.90417480e-02],
                        [ -5.76477051e-02,  -5.62133789e-02],
                        [ -6.58264160e-02,  -6.45446777e-02],
                        [ -7.01599121e-02,  -6.91223145e-02],
                        [ -6.94885254e-02,  -6.87866211e-02],
                        [ -6.41479492e-02,  -6.38122559e-02],
                        [ -5.45654297e-02,  -5.45959473e-02],
                        [ -4.35485840e-02,  -4.39758301e-02],
                        [ -3.53393555e-02,  -3.61022949e-02],
                        [ -3.11889648e-02,  -3.22570801e-02],
                        [ -2.81066895e-02,  -2.94189453e-02],
                        [ -2.20947266e-02,  -2.35290527e-02],
                        [ -1.15966797e-02,  -1.30615234e-02],
                        [  2.19726562e-03,   7.93457031e-04],
                        [  1.70288086e-02,   1.58081055e-02],
                        [  3.11279297e-02,   3.01513672e-02],
                        [  4.37622070e-02,   4.31213379e-02],
                        [  5.38635254e-02,   5.35583496e-02],
                        [  5.54809570e-02,   5.55725098e-02],
                        [  3.78723145e-02,   3.83605957e-02],
                        [ -4.85229492e-03,  -4.05883789e-03],
                        [ -6.66809082e-02,  -6.55822754e-02],
                        [ -1.34613037e-01,  -1.33300781e-01],
                        [ -1.92840576e-01,  -1.91436768e-01],
                        [ -2.22045898e-01,  -2.20611572e-01],
                        [ -2.10266113e-01,  -2.08953857e-01],
                        [ -1.68792725e-01,  -1.67633057e-01],
                        [ -1.24389648e-01,  -1.23474121e-01],
                        [ -9.46655273e-02,  -9.40856934e-02],
                        [ -7.82470703e-02,  -7.80334473e-02],
                        [ -6.56738281e-02,  -6.58264160e-02],
                        [ -4.97131348e-02,  -5.02319336e-02],
                        [ -2.79846191e-02,  -2.88085938e-02],
                        [ -2.99072266e-03,  -4.08935547e-03],
                        [  2.19726562e-02,   2.06909180e-02],
                        [  4.96520996e-02,   4.82788086e-02],
                        [  8.47167969e-02,   8.33435059e-02],
                        [  1.21582031e-01,   1.20300293e-01],
                        [  1.45599365e-01,   1.44500732e-01],
                        [  1.44409180e-01,   1.43585205e-01],
                        [  1.10870361e-01,   1.10351562e-01],
                        [  4.17785645e-02,   4.16259766e-02],
                        [ -5.54199219e-02,  -5.52062988e-02],
                        [ -1.56188965e-01,  -1.55639648e-01],
                        [ -2.27416992e-01,  -2.26562500e-01],
                        [ -2.46368408e-01,  -2.45269775e-01],
                        [ -2.14660645e-01,  -2.13378906e-01],
                        [ -1.56890869e-01,  -1.55548096e-01],
                        [ -1.03881836e-01,  -1.02569580e-01],
                        [ -7.18994141e-02,  -7.06787109e-02],
                        [ -5.59692383e-02,  -5.49621582e-02],
                        [ -4.31213379e-02,  -4.23583984e-02],
                        [ -2.77709961e-02,  -2.73437500e-02],
                        [ -1.34887695e-02,  -1.33972168e-02],
                        [ -4.73022461e-03,  -5.00488281e-03],
                        [ -1.12915039e-03,  -1.73950195e-03],
                        [  1.86157227e-03,   1.00708008e-03],
                        [  7.99560547e-03,   6.89697266e-03],
                        [  1.62963867e-02,   1.50451660e-02],
                        [  2.30712891e-02,   2.17590332e-02],
                        [  2.63671875e-02,   2.50854492e-02],
                        [  2.75268555e-02,   2.63671875e-02],
                        [  3.02429199e-02,   2.92968750e-02],
                        [  3.95507812e-02,   3.88793945e-02],
                        [  5.96008301e-02,   5.92041016e-02],
                        [  8.94470215e-02,   8.94165039e-02],
                        [  1.21612549e-01,   1.21917725e-01],
                        [  1.45385742e-01,   1.45996094e-01],
                        [  1.51916504e-01,   1.52801514e-01],
                        [  1.40380859e-01,   1.41479492e-01],
                        [  1.20880127e-01,   1.22100830e-01],
                        [  1.07025146e-01,   1.08306885e-01],
                        [  1.02722168e-01,   1.03942871e-01],
                        [  9.97619629e-02,   1.00860596e-01],
                        [  8.99658203e-02,   9.08508301e-02],
                        [  7.51342773e-02,   7.57446289e-02],
                        [  6.10656738e-02,   6.13708496e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  3.09753418e-02,   3.06396484e-02],
                        [  1.61743164e-02,   1.55334473e-02],
                        [  9.91821289e-03,   9.03320312e-03],
                        [  1.51672363e-02,   1.40991211e-02],
                        [  3.32336426e-02,   3.20434570e-02],
                        [  6.52465820e-02,   6.40258789e-02],
                        [  1.06781006e-01,   1.05621338e-01],
                        [  1.46423340e-01,   1.45385742e-01],
                        [  1.70501709e-01,   1.69677734e-01],
                        [  1.70257568e-01,   1.69708252e-01],
                        [  1.48071289e-01,   1.47827148e-01],
                        [  1.16760254e-01,   1.16851807e-01],
                        [  8.95690918e-02,   8.99658203e-02],
                        [  7.15942383e-02,   7.22656250e-02],
                        [  6.03332520e-02,   6.12182617e-02],
                        [  5.08728027e-02,   5.19409180e-02],
                        [  4.00695801e-02,   4.12292480e-02],
                        [  2.89611816e-02,   3.01208496e-02],
                        [  2.24609375e-02,   2.35595703e-02],
                        [  2.35290527e-02,   2.44750977e-02],
                        [  2.73742676e-02,   2.81372070e-02],
                        [  2.49633789e-02,   2.54516602e-02],
                        [  1.29089355e-02,   1.30615234e-02],
                        [ -3.20434570e-03,  -3.32641602e-03],
                        [ -1.58386230e-02,  -1.62658691e-02],
                        [ -2.27966309e-02,  -2.34680176e-02],
                        [ -2.61840820e-02,  -2.70690918e-02],
                        [ -2.65197754e-02,  -2.75573730e-02],
                        [ -2.07824707e-02,  -2.19116211e-02],
                        [ -8.85009766e-03,  -9.97924805e-03],
                        [  1.86157227e-03,   8.23974609e-04],
                        [  2.77709961e-03,   1.89208984e-03],
                        [ -6.65283203e-03,  -7.35473633e-03],
                        [ -2.02331543e-02,  -2.06298828e-02],
                        [ -3.27758789e-02,  -3.28979492e-02],
                        [ -4.27856445e-02,  -4.26330566e-02],
                        [ -5.07202148e-02,  -5.02929688e-02],
                        [ -5.88073730e-02,  -5.81054688e-02],
                        [ -6.96105957e-02,  -6.86950684e-02],
                        [ -8.10546875e-02,  -8.00170898e-02],
                        [ -8.49609375e-02,  -8.38623047e-02],
                        [ -7.59582520e-02,  -7.48901367e-02],
                        [ -5.99060059e-02,  -5.89294434e-02],
                        [ -4.73022461e-02,  -4.64782715e-02],
                        [ -4.23278809e-02,  -4.17175293e-02],
                        [ -4.27551270e-02,  -4.23889160e-02],
                        [ -4.48608398e-02,  -4.47692871e-02],
                        [ -4.46777344e-02,  -4.48608398e-02],
                        [ -4.03137207e-02,  -4.07714844e-02],
                        [ -3.57360840e-02,  -3.64379883e-02],
                        [ -3.75061035e-02,  -3.83911133e-02],
                        [ -4.59289551e-02,  -4.69055176e-02],
                        [ -5.23071289e-02,  -5.33447266e-02],
                        [ -4.76989746e-02,  -4.87060547e-02],
                        [ -3.16162109e-02,  -3.25622559e-02],
                        [ -1.03149414e-02,  -1.10778809e-02],
                        [  1.09558105e-02,   1.04370117e-02],
                        [  3.05480957e-02,   3.02429199e-02],
                        [  4.83703613e-02,   4.83398438e-02],
                        [  6.31408691e-02,   6.33850098e-02],
                        [  6.98852539e-02,   7.03430176e-02],
                        [  5.87158203e-02,   5.93872070e-02],
                        [  1.87377930e-02,   1.95922852e-02],
                        [ -5.08728027e-02,  -4.98962402e-02],
                        [ -1.33087158e-01,  -1.32110596e-01],
                        [ -2.00927734e-01,  -1.99951172e-01],
                        [ -2.33215332e-01,  -2.32360840e-01],
                        [ -2.23937988e-01,  -2.23236084e-01],
                        [ -1.82830811e-01,  -1.82342529e-01],
                        [ -1.31347656e-01,  -1.31103516e-01],
                        [ -9.16748047e-02,  -9.17053223e-02],
                        [ -7.24487305e-02,  -7.26928711e-02],
                        [ -6.43615723e-02,  -6.48498535e-02],
                        [ -5.37719727e-02,  -5.44738770e-02],
                        [ -3.75671387e-02,  -3.84216309e-02],
                        [ -1.83410645e-02,  -1.92565918e-02],
                        [  8.36181641e-03,   7.38525391e-03],
                        [  4.78820801e-02,   4.69665527e-02],
                        [  9.32312012e-02,   9.24377441e-02],
                        [  1.31500244e-01,   1.30859375e-01],
                        [  1.56311035e-01,   1.55853271e-01],
                        [  1.61193848e-01,   1.60980225e-01],
                        [  1.31072998e-01,   1.31134033e-01],
                        [  5.67626953e-02,   5.70373535e-02],
                        [ -4.80651855e-02,  -4.75769043e-02],
                        [ -1.52587891e-01,  -1.51885986e-01],
                        [ -2.26074219e-01,  -2.25250244e-01],
                        [ -2.48474121e-01,  -2.47589111e-01],
                        [ -2.18566895e-01,  -2.17681885e-01],
                        [ -1.58477783e-01,  -1.57623291e-01],
                        [ -1.00677490e-01,  -9.99450684e-02],
                        [ -6.43005371e-02,  -6.37512207e-02],
                        [ -4.54101562e-02,  -4.50439453e-02],
                        [ -3.09143066e-02,  -3.07922363e-02],
                        [ -1.72424316e-02,  -1.73339844e-02],
                        [ -1.03454590e-02,  -1.06506348e-02],
                        [ -1.16271973e-02,  -1.21154785e-02],
                        [ -1.31225586e-02,  -1.37939453e-02],
                        [ -7.04956055e-03,  -7.81250000e-03],
                        [  7.32421875e-03,   6.46972656e-03],
                        [  2.52380371e-02,   2.43835449e-02],
                        [  3.98864746e-02,   3.90930176e-02],
                        [  4.58679199e-02,   4.51965332e-02],
                        [  4.31518555e-02,   4.26330566e-02],
                        [  3.58886719e-02,   3.55529785e-02],
                        [  2.92053223e-02,   2.90832520e-02],
                        [  3.10363770e-02,   3.11584473e-02],
                        [  5.09338379e-02,   5.12695312e-02],
                        [  8.83789062e-02,   8.88671875e-02],
                        [  1.27227783e-01,   1.27899170e-01],
                        [  1.49566650e-01,   1.50329590e-01],
                        [  1.50756836e-01,   1.51550293e-01],
                        [  1.38000488e-01,   1.38824463e-01],
                        [  1.20635986e-01,   1.21368408e-01],
                        [  1.05743408e-01,   1.06384277e-01],
                        [  9.68017578e-02,   9.72595215e-02],
                        [  9.21325684e-02,   9.24072266e-02],
                        [  8.83483887e-02,   8.84399414e-02],
                        [  8.45947266e-02,   8.44421387e-02],
                        [  7.94372559e-02,   7.91015625e-02],
                        [  6.86645508e-02,   6.81457520e-02],
                        [  5.04760742e-02,   4.98352051e-02],
                        [  2.94494629e-02,   2.87170410e-02],
                        [  1.28173828e-02,   1.20544434e-02],
                        [  7.56835938e-03,   6.83593750e-03],
                        [  1.99584961e-02,   1.92871094e-02],
                        [  5.15136719e-02,   5.09338379e-02],
                        [  9.43298340e-02,   9.39331055e-02],
                        [  1.34094238e-01,   1.33880615e-01],
                        [  1.57257080e-01,   1.57226562e-01],
                        [  1.56768799e-01,   1.56951904e-01],
                        [  1.36383057e-01,   1.36749268e-01],
                        [  1.10412598e-01,   1.10900879e-01],
                        [  9.20715332e-02,   9.26818848e-02],
                        [  8.15429688e-02,   8.22448730e-02],
                        [  7.15332031e-02,   7.22656250e-02],
                        [  5.99060059e-02,   6.05773926e-02],
                        [  4.81262207e-02,   4.87365723e-02],
                        [  3.53698730e-02,   3.58886719e-02],
                        [  2.20031738e-02,   2.23693848e-02],
                        [  1.22985840e-02,   1.24816895e-02],
                        [  7.69042969e-03,   7.72094727e-03],
                        [  4.39453125e-03,   4.21142578e-03],
                        [ -2.13623047e-04,  -6.10351562e-04],
                        [ -5.64575195e-03,  -6.13403320e-03],
                        [ -1.20849609e-02,  -1.26647949e-02],
                        [ -1.89208984e-02,  -1.95922852e-02],
                        [ -2.19116211e-02,  -2.26135254e-02],
                        [ -1.80969238e-02,  -1.87377930e-02],
                        [ -1.09558105e-02,  -1.15051270e-02],
                        [ -6.92749023e-03,  -7.41577148e-03],
                        [ -9.76562500e-03,  -1.00708008e-02],
                        [ -1.76086426e-02,  -1.77307129e-02],
                        [ -2.56958008e-02,  -2.56652832e-02],
                        [ -3.26843262e-02,  -3.25012207e-02],
                        [ -4.14733887e-02,  -4.11071777e-02],
                        [ -5.20324707e-02,  -5.15441895e-02],
                        [ -6.02111816e-02,  -5.96618652e-02],
                        [ -6.41479492e-02,  -6.35375977e-02],
                        [ -6.43615723e-02,  -6.37207031e-02],
                        [ -6.02111816e-02,  -5.96313477e-02],
                        [ -5.31921387e-02,  -5.27038574e-02],
                        [ -4.96215820e-02,  -4.91943359e-02],
                        [ -5.29785156e-02,  -5.27343750e-02],
                        [ -5.81665039e-02,  -5.80749512e-02],
                        [ -5.96008301e-02,  -5.96313477e-02],
                        [ -5.92956543e-02,  -5.95092773e-02],
                        [ -6.12182617e-02,  -6.15844727e-02],
                        [ -6.45446777e-02,  -6.50329590e-02],
                        [ -6.62841797e-02,  -6.68334961e-02],
                        [ -6.33544922e-02,  -6.39648438e-02],
                        [ -5.32836914e-02,  -5.38635254e-02],
                        [ -3.71093750e-02,  -3.76586914e-02],
                        [ -1.90734863e-02,  -1.95617676e-02],
                        [ -1.43432617e-03,  -1.80053711e-03],
                        [  1.56860352e-02,   1.54724121e-02],
                        [  3.14636230e-02,   3.13720703e-02],
                        [  4.49218750e-02,   4.49829102e-02],
                        [  5.55419922e-02,   5.57861328e-02],
                        [  6.03332520e-02,   6.06689453e-02],
                        [  5.27343750e-02,   5.31616211e-02],
                        [  2.60314941e-02,   2.65502930e-02],
                        [ -2.20947266e-02,  -2.15454102e-02],
                        [ -8.70971680e-02,  -8.65478516e-02],
                        [ -1.56982422e-01,  -1.56494141e-01],
                        [ -2.12951660e-01,  -2.12524414e-01],
                        [ -2.34741211e-01,  -2.34405518e-01],
                        [ -2.14721680e-01,  -2.14538574e-01],
                        [ -1.68670654e-01,  -1.68640137e-01],
                        [ -1.24389648e-01,  -1.24481201e-01],
                        [ -9.68933105e-02,  -9.71374512e-02],
                        [ -8.02001953e-02,  -8.05358887e-02],
                        [ -6.30187988e-02,  -6.34460449e-02],
                        [ -4.34570312e-02,  -4.39453125e-02],
                        [ -2.48718262e-02,  -2.53906250e-02],
                        [ -6.16455078e-03,  -6.65283203e-03],
                        [  1.66015625e-02,   1.61437988e-02],
                        [  4.40673828e-02,   4.37011719e-02],
                        [  7.41271973e-02,   7.38525391e-02],
                        [  1.03790283e-01,   1.03668213e-01],
                        [  1.27441406e-01,   1.27410889e-01],
                        [  1.36199951e-01,   1.36322021e-01],
                        [  1.21826172e-01,   1.22070312e-01],
                        [  7.92541504e-02,   7.95593262e-02],
                        [  7.50732422e-03,   7.90405273e-03],
                        [ -8.48388672e-02,  -8.43811035e-02],
                        [ -1.73187256e-01,  -1.72698975e-01],
                        [ -2.24945068e-01,  -2.24487305e-01],
                        [ -2.23419189e-01,  -2.22991943e-01],
                        [ -1.81854248e-01,  -1.81518555e-01],
                        [ -1.30828857e-01,  -1.30615234e-01],
                        [ -9.35058594e-02,  -9.33532715e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -5.45043945e-02,  -5.46264648e-02],
                        [ -3.43933105e-02,  -3.46069336e-02],
                        [ -1.46789551e-02,  -1.49841309e-02],
                        [ -3.05175781e-05,  -4.57763672e-04],
                        [  8.78906250e-03,   8.36181641e-03],
                        [  1.37939453e-02,   1.33666992e-02],
                        [  1.83410645e-02,   1.79138184e-02],
                        [  2.43225098e-02,   2.39562988e-02],
                        [  2.87475586e-02,   2.84729004e-02],
                        [  2.74658203e-02,   2.72521973e-02],
                        [  2.14233398e-02,   2.13012695e-02],
                        [  1.70288086e-02,   1.70593262e-02],
                        [  2.18505859e-02,   2.19726562e-02],
                        [  3.93676758e-02,   3.95812988e-02],
                        [  6.53381348e-02,   6.56433105e-02],
                        [  9.12780762e-02,   9.16442871e-02],
                        [  1.12487793e-01,   1.12854004e-01],
                        [  1.27532959e-01,   1.27929688e-01],
                        [  1.33392334e-01,   1.33758545e-01],
                        [  1.29425049e-01,   1.29760742e-01],
                        [  1.22833252e-01,   1.23046875e-01],
                        [  1.19415283e-01,   1.19598389e-01],
                        [  1.15936279e-01,   1.16027832e-01],
                        [  1.09619141e-01,   1.09558105e-01],
                        [  1.05346680e-01,   1.05224609e-01],
                        [  1.05255127e-01,   1.05041504e-01],
                        [  1.01959229e-01,   1.01654053e-01],
                        [  8.87145996e-02,   8.83789062e-02],
                        [  6.70166016e-02,   6.66503906e-02],
                        [  4.17785645e-02,   4.14123535e-02],
                        [  1.67846680e-02,   1.64489746e-02],
                        [ -2.99072266e-03,  -3.29589844e-03],
                        [ -8.78906250e-03,  -9.00268555e-03],
                        [  8.57543945e-03,   8.45336914e-03],
                        [  5.04760742e-02,   5.04455566e-02],
                        [  1.04858398e-01,   1.04919434e-01],
                        [  1.50817871e-01,   1.50970459e-01],
                        [  1.71203613e-01,   1.71417236e-01],
                        [  1.62353516e-01,   1.62597656e-01],
                        [  1.33941650e-01,   1.34246826e-01],
                        [  1.01837158e-01,   1.02172852e-01],
                        [  7.87963867e-02,   7.91320801e-02],
                        [  6.69860840e-02,   6.72607422e-02],
                        [  5.90820312e-02,   5.93261719e-02],
                        [  4.93774414e-02,   4.95605469e-02],
                        [  4.07409668e-02,   4.08325195e-02],
                        [  3.72924805e-02,   3.73229980e-02],
                        [  3.54003906e-02,   3.53698730e-02],
                        [  2.79541016e-02,   2.78320312e-02],
                        [  1.34582520e-02,   1.32751465e-02],
                        [ -3.57055664e-03,  -3.78417969e-03],
                        [ -1.83410645e-02,  -1.86157227e-02],
                        [ -2.80151367e-02,  -2.83203125e-02],
                        [ -3.03649902e-02,  -3.06396484e-02],
                        [ -2.54211426e-02,  -2.56652832e-02],
                        [ -1.83410645e-02,  -1.85546875e-02],
                        [ -1.54113770e-02,  -1.55639648e-02],
                        [ -1.69677734e-02,  -1.70593262e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.19421387e-02,  -2.18811035e-02],
                        [ -2.70080566e-02,  -2.68859863e-02],
                        [ -3.23791504e-02,  -3.21960449e-02],
                        [ -3.54309082e-02,  -3.51867676e-02],
                        [ -4.00085449e-02,  -3.97644043e-02],
                        [ -4.99267578e-02,  -4.96520996e-02],
                        [ -5.92041016e-02,  -5.89599609e-02],
                        [ -6.04858398e-02,  -6.02416992e-02],
                        [ -5.78613281e-02,  -5.76782227e-02],
                        [ -5.99060059e-02,  -5.97839355e-02],
                        [ -6.45141602e-02,  -6.44531250e-02],
                        [ -6.32324219e-02,  -6.32324219e-02],
                        [ -5.63659668e-02,  -5.64270020e-02],
                        [ -5.16357422e-02,  -5.17578125e-02],
                        [ -5.10253906e-02,  -5.12084961e-02],
                        [ -5.08117676e-02,  -5.10253906e-02],
                        [ -5.06896973e-02,  -5.09033203e-02],
                        [ -5.31005859e-02,  -5.33142090e-02],
                        [ -5.62438965e-02,  -5.64575195e-02],
                        [ -5.58471680e-02,  -5.60302734e-02],
                        [ -4.90112305e-02,  -4.91638184e-02],
                        [ -3.41491699e-02,  -3.42407227e-02],
                        [ -1.28479004e-02,  -1.28784180e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  2.49328613e-02,   2.49938965e-02],
                        [  3.83911133e-02,   3.85131836e-02],
                        [  5.04150391e-02,   5.05676270e-02],
                        [  5.56335449e-02,   5.58166504e-02],
                        [  4.48913574e-02,   4.50744629e-02],
                        [  1.06201172e-02,   1.08032227e-02],
                        [ -5.05371094e-02,  -5.03540039e-02],
                        [ -1.30828857e-01,  -1.30676270e-01],
                        [ -2.05261230e-01,  -2.05139160e-01],
                        [ -2.42706299e-01,  -2.42614746e-01],
                        [ -2.30194092e-01,  -2.30163574e-01],
                        [ -1.84234619e-01,  -1.84265137e-01],
                        [ -1.34765625e-01,  -1.34826660e-01],
                        [ -1.00799561e-01,  -1.00891113e-01],
                        [ -8.20617676e-02,  -8.22143555e-02],
                        [ -6.96411133e-02,  -6.97937012e-02],
                        [ -5.81665039e-02,  -5.83496094e-02],
                        [ -4.78515625e-02,  -4.80346680e-02],
                        [ -3.95507812e-02,  -3.97033691e-02],
                        [ -3.01818848e-02,  -3.03039551e-02],
                        [ -1.27563477e-02,  -1.28784180e-02],
                        [  1.80358887e-02,   1.79748535e-02],
                        [  5.99975586e-02,   5.99670410e-02],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  1.38702393e-01,   1.38763428e-01],
                        [  1.56524658e-01,   1.56616211e-01],
                        [  1.49780273e-01,   1.49902344e-01],
                        [  1.08978271e-01,   1.09100342e-01],
                        [  2.85034180e-02,   2.86560059e-02],
                        [ -7.83386230e-02,  -7.81860352e-02],
                        [ -1.76849365e-01,  -1.76727295e-01],
                        [ -2.32238770e-01,  -2.32116699e-01],
                        [ -2.32055664e-01,  -2.31964111e-01],
                        [ -1.89361572e-01,  -1.89331055e-01],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -8.41064453e-02,  -8.41369629e-02],
                        [ -5.90209961e-02,  -5.90820312e-02],
                        [ -4.82482910e-02,  -4.83398438e-02],
                        [ -3.75976562e-02,  -3.76892090e-02],
                        [ -2.17895508e-02,  -2.19116211e-02],
                        [ -5.85937500e-03,  -5.98144531e-03],
                        [  4.66918945e-03,   4.54711914e-03],
                        [  9.18579102e-03,   9.06372070e-03],
                        [  1.14746094e-02,   1.13830566e-02],
                        [  1.69372559e-02,   1.68762207e-02],
                        [  2.63366699e-02,   2.62756348e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.02429199e-02,   3.02734375e-02],
                        [  2.40173340e-02,   2.40478516e-02],
                        [  2.28576660e-02,   2.29187012e-02],
                        [  3.05480957e-02,   3.06396484e-02],
                        [  4.77294922e-02,   4.78210449e-02],
                        [  7.50122070e-02,   7.51342773e-02],
                        [  1.07360840e-01,   1.07452393e-01],
                        [  1.31256104e-01,   1.31347656e-01],
                        [  1.35894775e-01,   1.35955811e-01],
                        [  1.25213623e-01,   1.25244141e-01],
                        [  1.13891602e-01,   1.13922119e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.16546631e-01,   1.16516113e-01],
                        [  1.18591309e-01,   1.18560791e-01],
                        [  1.13189697e-01,   1.13159180e-01],
                        [  1.02783203e-01,   1.02722168e-01],
                        [  9.11560059e-02,   9.10644531e-02],
                        [  7.83386230e-02,   7.82470703e-02],
                        [  6.29272461e-02,   6.28662109e-02],
                        [  4.56237793e-02,   4.55627441e-02],
                        [  2.79541016e-02,   2.78930664e-02],
                        [  1.23596191e-02,   1.23291016e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  3.41796875e-02,   3.42102051e-02],
                        [  7.71179199e-02,   7.71484375e-02],
                        [  1.24542236e-01,   1.24603271e-01],
                        [  1.55334473e-01,   1.55395508e-01],
                        [  1.57043457e-01,   1.57135010e-01],
                        [  1.36260986e-01,   1.36352539e-01],
                        [  1.09893799e-01,   1.09954834e-01],
                        [  8.93249512e-02,   8.93859863e-02],
                        [  7.61718750e-02,   7.62329102e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  5.79528809e-02,   5.79833984e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  3.55224609e-02,   3.54919434e-02],
                        [  2.51159668e-02,   2.50549316e-02],
                        [  1.51977539e-02,   1.51672363e-02],
                        [  3.72314453e-03,   3.66210938e-03],
                        [ -8.94165039e-03,  -9.00268555e-03],
                        [ -2.00500488e-02,  -2.00805664e-02],
                        [ -2.60009766e-02,  -2.60314941e-02],
                        [ -2.49633789e-02,  -2.49938965e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -3.03039551e-02,  -3.02429199e-02],
                        [ -2.91442871e-02,  -2.91137695e-02],
                        [ -2.52075195e-02,  -2.51770020e-02],
                        [ -2.36816406e-02,  -2.36206055e-02],
                        [ -2.84729004e-02,  -2.84423828e-02],
                        [ -3.62548828e-02,  -3.62243652e-02],
                        [ -4.37011719e-02,  -4.36706543e-02],
                        [ -5.23376465e-02,  -5.23071289e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.20422363e-02,  -6.20727539e-02],
                        [ -6.08520508e-02,  -6.08825684e-02],
                        [ -5.48706055e-02,  -5.49011230e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -2.92053223e-02,  -2.92358398e-02],
                        [ -2.47497559e-02,  -2.48107910e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.63769531e-02,  -3.64074707e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [  2.42309570e-02,   2.42614746e-02],
                        [  4.94995117e-02,   4.95300293e-02],
                        [  6.42395020e-02,   6.42700195e-02],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  6.86645508e-03,   6.89697266e-03],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -1.24389648e-01,  -1.24389648e-01],
                        [ -1.90277100e-01,  -1.90277100e-01],
                        [ -2.29736328e-01,  -2.29736328e-01],
                        [ -2.25189209e-01,  -2.25189209e-01],
                        [ -1.79779053e-01,  -1.79809570e-01],
                        [ -1.20941162e-01,  -1.20941162e-01],
                        [ -7.87963867e-02,  -7.87963867e-02],
                        [ -6.19506836e-02,  -6.19812012e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -5.07507324e-02,  -5.07812500e-02],
                        [ -4.21752930e-02,  -4.22058105e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -1.19018555e-03,  -1.15966797e-03],
                        [  3.47900391e-02,   3.47595215e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  1.05560303e-01,   1.05590820e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.12396240e-01,   1.12426758e-01],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -1.44470215e-01,  -1.44470215e-01],
                        [ -1.99737549e-01,  -1.99737549e-01],
                        [ -2.11425781e-01,  -2.11425781e-01],
                        [ -1.80664062e-01,  -1.80633545e-01],
                        [ -1.30371094e-01,  -1.30371094e-01],
                        [ -8.69750977e-02,  -8.69750977e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -3.56750488e-02,  -3.57055664e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.28271484e-02,   2.28576660e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  1.25366211e-01,   1.25366211e-01],
                        [  1.46270752e-01,   1.46240234e-01],
                        [  1.45599365e-01,   1.45599365e-01],
                        [  1.34094238e-01,   1.34094238e-01],
                        [  1.25762939e-01,   1.25762939e-01],
                        [  1.23413086e-01,   1.23413086e-01],
                        [  1.18804932e-01,   1.18804932e-01],
                        [  1.07574463e-01,   1.07574463e-01],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  7.44323730e-02,   7.44323730e-02],
                        [  5.59082031e-02,   5.58776855e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  6.71386719e-04,   6.71386719e-04],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  1.53686523e-01,   1.53686523e-01],
                        [  1.31866455e-01,   1.31896973e-01],
                        [  1.03485107e-01,   1.03485107e-01],
                        [  7.56530762e-02,   7.56530762e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  2.83203125e-02,   2.83508301e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.70690918e-02,  -2.70996094e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -1.78222656e-02,  -1.78527832e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -4.45251465e-02,  -4.45556641e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.16149902e-02,  -6.16455078e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.92041016e-02,  -5.92041016e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -2.90222168e-02,  -2.90527344e-02],
                        [ -1.30004883e-02,  -1.29699707e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  8.23974609e-04,   7.93457031e-04],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -1.11480713e-01,  -1.11480713e-01],
                        [ -1.75048828e-01,  -1.75079346e-01],
                        [ -2.13531494e-01,  -2.13531494e-01],
                        [ -2.12341309e-01,  -2.12310791e-01],
                        [ -1.75598145e-01,  -1.75598145e-01],
                        [ -1.24725342e-01,  -1.24725342e-01],
                        [ -8.58764648e-02,  -8.58764648e-02],
                        [ -7.08923340e-02,  -7.08618164e-02],
                        [ -6.93054199e-02,  -6.93359375e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -3.61633301e-02,  -3.61938477e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  3.50646973e-02,   3.50341797e-02],
                        [  7.32421875e-02,   7.32727051e-02],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  1.32324219e-01,   1.32324219e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  5.51757812e-02,   5.51452637e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.13159180e-01,  -1.13159180e-01],
                        [ -1.90277100e-01,  -1.90277100e-01],
                        [ -2.23144531e-01,  -2.23144531e-01],
                        [ -2.03857422e-01,  -2.03857422e-01],
                        [ -1.53350830e-01,  -1.53350830e-01],
                        [ -1.03912354e-01,  -1.03912354e-01],
                        [ -7.50122070e-02,  -7.50122070e-02],
                        [ -6.21032715e-02,  -6.20727539e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  5.21850586e-03,   5.21850586e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  1.01287842e-01,   1.01257324e-01],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.40258789e-01,   1.40258789e-01],
                        [  1.34765625e-01,   1.34765625e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.19018555e-01,   1.19049072e-01],
                        [  1.17553711e-01,   1.17553711e-01],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  8.07189941e-02,   8.07189941e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  5.62744141e-02,   5.62438965e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  1.09161377e-01,   1.09161377e-01],
                        [  1.34460449e-01,   1.34490967e-01],
                        [  1.37481689e-01,   1.37481689e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  8.05969238e-02,   8.06274414e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  6.22558594e-02,   6.22253418e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  3.06091309e-02,   3.06396484e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  1.67846680e-03,   1.64794922e-03],
                        [  1.43432617e-03,   1.46484375e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -5.17883301e-02,  -5.17578125e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -4.66613770e-02,  -4.66308594e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.62133789e-02,  -5.62438965e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.56127930e-02,  -6.56127930e-02],
                        [ -5.62438965e-02,  -5.62744141e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -4.05273438e-02,  -4.05578613e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  6.30187988e-02,   6.30187988e-02],
                        [  7.25708008e-02,   7.25708008e-02],
                        [  5.88073730e-02,   5.88073730e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -1.24755859e-01,  -1.24755859e-01],
                        [ -1.95037842e-01,  -1.95037842e-01],
                        [ -2.34436035e-01,  -2.34436035e-01],
                        [ -2.31475830e-01,  -2.31445312e-01],
                        [ -1.92901611e-01,  -1.92901611e-01],
                        [ -1.39801025e-01,  -1.39831543e-01],
                        [ -9.56115723e-02,  -9.55810547e-02],
                        [ -7.20520020e-02,  -7.20214844e-02],
                        [ -6.43005371e-02,  -6.43310547e-02],
                        [ -6.07299805e-02,  -6.07604980e-02],
                        [ -5.45349121e-02,  -5.45043945e-02],
                        [ -4.40368652e-02,  -4.40063477e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -7.26318359e-03,  -7.29370117e-03],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  6.96411133e-02,   6.96411133e-02],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.39617920e-01,   1.39617920e-01],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  6.85119629e-02,   6.85119629e-02],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.07452393e-01,  -1.07421875e-01],
                        [ -1.88232422e-01,  -1.88201904e-01],
                        [ -2.30773926e-01,  -2.30804443e-01],
                        [ -2.23114014e-01,  -2.23144531e-01],
                        [ -1.76940918e-01,  -1.76910400e-01],
                        [ -1.19628906e-01,  -1.19598389e-01],
                        [ -7.40051270e-02,  -7.40356445e-02],
                        [ -4.60510254e-02,  -4.60815430e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -1.33056641e-02,  -1.32751465e-02],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -8.57543945e-03,  -8.60595703e-03],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  8.71276855e-02,   8.70971680e-02],
                        [  1.18499756e-01,   1.18499756e-01],
                        [  1.39617920e-01,   1.39648438e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.42547607e-01,   1.42517090e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.24114990e-01,   1.24145508e-01],
                        [  1.17645264e-01,   1.17675781e-01],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.02539062e-01,   1.02539062e-01],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  7.61413574e-02,   7.61718750e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.49536133e-03,   1.52587891e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [  1.05285645e-02,   1.05590820e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  7.47375488e-02,   7.47070312e-02],
                        [  1.10198975e-01,   1.10198975e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.38214111e-01,   1.38214111e-01],
                        [  1.26464844e-01,   1.26434326e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  8.16650391e-02,   8.17260742e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  5.36804199e-02,   5.36499023e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  3.21350098e-02,   3.21960449e-02],
                        [  1.98669434e-02,   1.98974609e-02],
                        [  1.36413574e-02,   1.36108398e-02],
                        [  1.21154785e-02,   1.20849609e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [ -2.89916992e-03,  -2.83813477e-03],
                        [ -1.78222656e-02,  -1.77917480e-02],
                        [ -3.01208496e-02,  -3.01818848e-02],
                        [ -3.46374512e-02,  -3.46679688e-02],
                        [ -3.18298340e-02,  -3.17993164e-02],
                        [ -2.67028809e-02,  -2.66723633e-02],
                        [ -2.31018066e-02,  -2.31323242e-02],
                        [ -2.12707520e-02,  -2.13317871e-02],
                        [ -2.11791992e-02,  -2.11486816e-02],
                        [ -2.31323242e-02,  -2.31018066e-02],
                        [ -2.54516602e-02,  -2.54821777e-02],
                        [ -2.66113281e-02,  -2.66418457e-02],
                        [ -2.99377441e-02,  -2.99072266e-02],
                        [ -3.97033691e-02,  -3.96728516e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -6.13708496e-02,  -6.14013672e-02],
                        [ -6.14013672e-02,  -6.13708496e-02],
                        [ -5.74340820e-02,  -5.74035645e-02],
                        [ -5.39550781e-02,  -5.39855957e-02],
                        [ -5.06896973e-02,  -5.07507324e-02],
                        [ -4.67834473e-02,  -4.67529297e-02],
                        [ -4.35485840e-02,  -4.34875488e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.59289551e-02,  -4.59899902e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.52673340e-02,  -5.52368164e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -3.96118164e-02,  -3.96423340e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [  6.40869141e-04,   6.71386719e-04],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  5.02624512e-02,   5.02014160e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  6.92749023e-02,   6.93054199e-02],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  9.82666016e-03,   9.76562500e-03],
                        [ -5.14221191e-02,  -5.14831543e-02],
                        [ -1.24267578e-01,  -1.24237061e-01],
                        [ -1.91589355e-01,  -1.91497803e-01],
                        [ -2.31994629e-01,  -2.31994629e-01],
                        [ -2.31628418e-01,  -2.31750488e-01],
                        [ -1.95373535e-01,  -1.95373535e-01],
                        [ -1.45874023e-01,  -1.45782471e-01],
                        [ -1.07543945e-01,  -1.07513428e-01],
                        [ -8.74023438e-02,  -8.74938965e-02],
                        [ -7.41882324e-02,  -7.42492676e-02],
                        [ -5.65185547e-02,  -5.64575195e-02],
                        [ -3.69873047e-02,  -3.69567871e-02],
                        [ -2.42309570e-02,  -2.42919922e-02],
                        [ -1.71813965e-02,  -1.72424316e-02],
                        [ -5.18798828e-03,  -5.12695312e-03],
                        [  1.83715820e-02,   1.84020996e-02],
                        [  5.03234863e-02,   5.02319336e-02],
                        [  8.38623047e-02,   8.38317871e-02],
                        [  1.14013672e-01,   1.14105225e-01],
                        [  1.35925293e-01,   1.35955811e-01],
                        [  1.41387939e-01,   1.41265869e-01],
                        [  1.19201660e-01,   1.19171143e-01],
                        [  6.25915527e-02,   6.27136230e-02],
                        [ -2.22473145e-02,  -2.21862793e-02],
                        [ -1.15722656e-01,  -1.15814209e-01],
                        [ -1.91558838e-01,  -1.91619873e-01],
                        [ -2.25921631e-01,  -2.25860596e-01],
                        [ -2.09747314e-01,  -2.09686279e-01],
                        [ -1.58630371e-01,  -1.58691406e-01],
                        [ -1.04461670e-01,  -1.04522705e-01],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -5.16967773e-02,  -5.16662598e-02],
                        [ -3.64685059e-02,  -3.64990234e-02],
                        [ -1.80358887e-02,  -1.80664062e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  6.74438477e-03,   6.77490234e-03],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  8.85009766e-03,   8.78906250e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.55126953e-02,   2.55737305e-02],
                        [  3.59802246e-02,   3.59497070e-02],
                        [  4.00695801e-02,   3.99780273e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  1.91955566e-02,   1.92565918e-02],
                        [  7.62939453e-04,   7.93457031e-04],
                        [ -8.11767578e-03,  -8.17871094e-03],
                        [  3.84521484e-03,   3.81469727e-03],
                        [  3.72009277e-02,   3.72314453e-02],
                        [  8.13598633e-02,   8.13903809e-02],
                        [  1.22924805e-01,   1.22863770e-01],
                        [  1.52526855e-01,   1.52496338e-01],
                        [  1.67297363e-01,   1.67358398e-01],
                        [  1.69036865e-01,   1.69067383e-01],
                        [  1.60217285e-01,   1.60156250e-01],
                        [  1.42974854e-01,   1.42913818e-01],
                        [  1.22955322e-01,   1.23016357e-01],
                        [  1.08459473e-01,   1.08520508e-01],
                        [  1.01501465e-01,   1.01440430e-01],
                        [  9.60388184e-02,   9.59472656e-02],
                        [  8.63952637e-02,   8.64257812e-02],
                        [  7.23876953e-02,   7.25402832e-02],
                        [  5.64270020e-02,   5.63964844e-02],
                        [  3.97644043e-02,   3.96118164e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  2.16674805e-03,   2.31933594e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.29394531e-02,  -1.30310059e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  3.45764160e-02,   3.46679688e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  1.20727539e-01,   1.20635986e-01],
                        [  1.53137207e-01,   1.53167725e-01],
                        [  1.59729004e-01,   1.59790039e-01],
                        [  1.40472412e-01,   1.40441895e-01],
                        [  1.10260010e-01,   1.10168457e-01],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  7.14111328e-02,   7.15026855e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  5.36193848e-02,   5.34973145e-02],
                        [  3.86657715e-02,   3.86352539e-02],
                        [  2.19116211e-02,   2.20336914e-02],
                        [  7.11059570e-03,   7.17163086e-03],
                        [ -4.54711914e-03,  -4.63867188e-03],
                        [ -1.31225586e-02,  -1.31835938e-02],
                        [ -1.93176270e-02,  -1.92260742e-02],
                        [ -2.39868164e-02,  -2.39257812e-02],
                        [ -2.64282227e-02,  -2.64892578e-02],
                        [ -2.41394043e-02,  -2.42309570e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.09863281e-02,  -1.08947754e-02],
                        [ -1.04980469e-02,  -1.05285645e-02],
                        [ -1.42822266e-02,  -1.43737793e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.59399414e-02,  -2.58483887e-02],
                        [ -3.26843262e-02,  -3.27148438e-02],
                        [ -3.44238281e-02,  -3.45153809e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.97851562e-02,  -2.96936035e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -5.01403809e-02,  -5.02319336e-02],
                        [ -6.28967285e-02,  -6.29272461e-02],
                        [ -7.08618164e-02,  -7.07702637e-02],
                        [ -7.36389160e-02,  -7.36083984e-02],
                        [ -7.17773438e-02,  -7.18994141e-02],
                        [ -6.58264160e-02,  -6.59179688e-02],
                        [ -5.83801270e-02,  -5.82885742e-02],
                        [ -5.36499023e-02,  -5.35583496e-02],
                        [ -5.28259277e-02,  -5.29174805e-02],
                        [ -5.22155762e-02,  -5.23071289e-02],
                        [ -4.76074219e-02,  -4.75158691e-02],
                        [ -3.83300781e-02,  -3.82385254e-02],
                        [ -2.57873535e-02,  -2.58483887e-02],
                        [ -9.91821289e-03,  -9.97924805e-03],
                        [  9.76562500e-03,   9.79614258e-03],
                        [  3.06396484e-02,   3.07006836e-02],
                        [  4.80957031e-02,   4.80957031e-02],
                        [  5.94482422e-02,   5.94177246e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  4.87365723e-02,   4.87670898e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [ -5.42907715e-02,  -5.43212891e-02],
                        [ -1.32293701e-01,  -1.32293701e-01],
                        [ -2.01873779e-01,  -2.01843262e-01],
                        [ -2.40753174e-01,  -2.40753174e-01],
                        [ -2.37426758e-01,  -2.37457275e-01],
                        [ -1.99890137e-01,  -1.99920654e-01],
                        [ -1.51123047e-01,  -1.51092529e-01],
                        [ -1.11785889e-01,  -1.11724854e-01],
                        [ -8.74328613e-02,  -8.74633789e-02],
                        [ -7.07397461e-02,  -7.08312988e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -3.49121094e-02,  -3.48205566e-02],
                        [ -2.27355957e-02,  -2.26745605e-02],
                        [ -1.70898438e-02,  -1.72119141e-02],
                        [ -8.33129883e-03,  -8.42285156e-03],
                        [  1.23596191e-02,   1.24206543e-02],
                        [  4.36706543e-02,   4.37927246e-02],
                        [  7.71484375e-02,   7.71179199e-02],
                        [  1.04553223e-01,   1.04492188e-01],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.25518799e-01,   1.25579834e-01],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  6.56738281e-02,   6.56433105e-02],
                        [ -1.30004883e-02,  -1.30310059e-02],
                        [ -1.10565186e-01,  -1.10595703e-01],
                        [ -1.93511963e-01,  -1.93481445e-01],
                        [ -2.31323242e-01,  -2.31292725e-01],
                        [ -2.15148926e-01,  -2.15179443e-01],
                        [ -1.59820557e-01,  -1.59851074e-01],
                        [ -9.55810547e-02,  -9.55810547e-02],
                        [ -4.99572754e-02,  -4.98962402e-02],
                        [ -2.81372070e-02,  -2.81677246e-02],
                        [ -1.58691406e-02,  -1.59301758e-02],
                        [ -2.56347656e-03,  -2.53295898e-03],
                        [  7.38525391e-03,   7.41577148e-03],
                        [  8.08715820e-03,   8.02612305e-03],
                        [  5.12695312e-03,   5.06591797e-03],
                        [  8.30078125e-03,   8.33129883e-03],
                        [  1.87683105e-02,   1.87988281e-02],
                        [  2.85034180e-02,   2.84729004e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  1.42517090e-02,   1.42211914e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  7.03125000e-02,   7.03125000e-02],
                        [  1.06353760e-01,   1.06384277e-01],
                        [  1.39495850e-01,   1.39556885e-01],
                        [  1.59881592e-01,   1.59851074e-01],
                        [  1.61071777e-01,   1.61010742e-01],
                        [  1.48986816e-01,   1.48956299e-01],
                        [  1.35406494e-01,   1.35498047e-01],
                        [  1.26007080e-01,   1.26068115e-01],
                        [  1.20239258e-01,   1.20117188e-01],
                        [  1.17248535e-01,   1.17187500e-01],
                        [  1.14654541e-01,   1.14746094e-01],
                        [  1.05682373e-01,   1.05773926e-01],
                        [  8.64562988e-02,   8.63952637e-02],
                        [  6.28967285e-02,   6.28356934e-02],
                        [  4.36096191e-02,   4.36401367e-02],
                        [  2.79235840e-02,   2.79846191e-02],
                        [  9.12475586e-03,   9.09423828e-03],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -2.22167969e-02,  -2.21557617e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [  1.44042969e-02,   1.43432617e-02],
                        [  5.27954102e-02,   5.27648926e-02],
                        [  9.78088379e-02,   9.78393555e-02],
                        [  1.41296387e-01,   1.41326904e-01],
                        [  1.67053223e-01,   1.67022705e-01],
                        [  1.64276123e-01,   1.64215088e-01],
                        [  1.40350342e-01,   1.40350342e-01],
                        [  1.11083984e-01,   1.11145020e-01],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  5.56945801e-02,   5.56640625e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  1.35498047e-02,   1.35803223e-02],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -2.92968750e-03,  -2.96020508e-03],
                        [ -2.41088867e-03,  -2.38037109e-03],
                        [  3.69262695e-03,   3.72314453e-03],
                        [  9.39941406e-03,   9.33837891e-03],
                        [  9.09423828e-03,   9.06372070e-03],
                        [  2.47192383e-03,   2.56347656e-03],
                        [ -5.52368164e-03,  -5.49316406e-03],
                        [ -9.33837891e-03,  -9.39941406e-03],
                        [ -9.55200195e-03,  -9.58251953e-03],
                        [ -1.24511719e-02,  -1.24206543e-02],
                        [ -2.18200684e-02,  -2.17895508e-02],
                        [ -3.52478027e-02,  -3.52783203e-02],
                        [ -4.77905273e-02,  -4.78210449e-02],
                        [ -5.46264648e-02,  -5.45959473e-02],
                        [ -5.27038574e-02,  -5.26733398e-02],
                        [ -4.44030762e-02,  -4.44335938e-02],
                        [ -3.70788574e-02,  -3.71093750e-02],
                        [ -3.62548828e-02,  -3.61938477e-02],
                        [ -4.15954590e-02,  -4.15649414e-02],
                        [ -5.06896973e-02,  -5.07507324e-02],
                        [ -6.14624023e-02,  -6.15539551e-02],
                        [ -7.05871582e-02,  -7.05261230e-02],
                        [ -7.45849609e-02,  -7.44934082e-02],
                        [ -7.36083984e-02,  -7.36389160e-02],
                        [ -7.03430176e-02,  -7.04345703e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.13403320e-02,  -6.12792969e-02],
                        [ -5.24902344e-02,  -5.24597168e-02],
                        [ -4.08935547e-02,  -4.09545898e-02],
                        [ -3.10974121e-02,  -3.11279297e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.55334473e-02,  -1.55029297e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  5.26733398e-02,   5.26428223e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  6.28662109e-03,   6.31713867e-03],
                        [ -4.98352051e-02,  -4.98657227e-02],
                        [ -1.19995117e-01,  -1.20025635e-01],
                        [ -1.86431885e-01,  -1.86431885e-01],
                        [ -2.26562500e-01,  -2.26531982e-01],
                        [ -2.25799561e-01,  -2.25738525e-01],
                        [ -1.90826416e-01,  -1.90856934e-01],
                        [ -1.46453857e-01,  -1.46484375e-01],
                        [ -1.14746094e-01,  -1.14715576e-01],
                        [ -9.95178223e-02,  -9.94567871e-02],
                        [ -9.05456543e-02,  -9.05761719e-02],
                        [ -7.83996582e-02,  -7.84301758e-02],
                        [ -6.23779297e-02,  -6.23474121e-02],
                        [ -4.61120605e-02,  -4.60815430e-02],
                        [ -3.02124023e-02,  -3.02429199e-02],
                        [ -1.22985840e-02,  -1.23596191e-02],
                        [  1.02844238e-02,   1.03149414e-02],
                        [  4.05273438e-02,   4.05578613e-02],
                        [  7.77893066e-02,   7.77893066e-02],
                        [  1.14318848e-01,   1.14257812e-01],
                        [  1.40441895e-01,   1.40380859e-01],
                        [  1.50573730e-01,   1.50604248e-01],
                        [  1.38427734e-01,   1.38519287e-01],
                        [  9.30786133e-02,   9.31396484e-02],
                        [  1.02233887e-02,   1.01013184e-02],
                        [ -9.26818848e-02,  -9.27734375e-02],
                        [ -1.81304932e-01,  -1.81182861e-01],
                        [ -2.26715088e-01,  -2.26593018e-01],
                        [ -2.20520020e-01,  -2.20581055e-01],
                        [ -1.75231934e-01,  -1.75384521e-01],
                        [ -1.17553711e-01,  -1.17553711e-01],
                        [ -7.36389160e-02,  -7.35168457e-02],
                        [ -5.17883301e-02,  -5.17578125e-02],
                        [ -4.08020020e-02,  -4.09240723e-02],
                        [ -2.72216797e-02,  -2.72827148e-02],
                        [ -1.05590820e-02,  -1.04980469e-02],
                        [  3.35693359e-04,   3.96728516e-04],
                        [  3.20434570e-03,   3.17382812e-03],
                        [  7.35473633e-03,   7.32421875e-03],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  4.04663086e-02,   4.05273438e-02],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  5.17578125e-02,   5.17272949e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  2.19421387e-02,   2.20031738e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [ -5.37109375e-03,  -5.46264648e-03],
                        [ -3.87573242e-03,  -3.90625000e-03],
                        [  1.34887695e-02,   1.36108398e-02],
                        [  4.37622070e-02,   4.38537598e-02],
                        [  8.11462402e-02,   8.10241699e-02],
                        [  1.19781494e-01,   1.19659424e-01],
                        [  1.50756836e-01,   1.50878906e-01],
                        [  1.62963867e-01,   1.63116455e-01],
                        [  1.54602051e-01,   1.54479980e-01],
                        [  1.38153076e-01,   1.37969971e-01],
                        [  1.26892090e-01,   1.26983643e-01],
                        [  1.22589111e-01,   1.22772217e-01],
                        [  1.21734619e-01,   1.21673584e-01],
                        [  1.23809814e-01,   1.23626709e-01],
                        [  1.26251221e-01,   1.26312256e-01],
                        [  1.21490479e-01,   1.21643066e-01],
                        [  1.05102539e-01,   1.05072021e-01],
                        [  7.94067383e-02,   7.92541504e-02],
                        [  4.79125977e-02,   4.79431152e-02],
                        [  1.39465332e-02,   1.40991211e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -4.08325195e-02,  -4.09545898e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -4.07409668e-02,  -4.05883789e-02],
                        [ -5.98144531e-03,  -5.95092773e-03],
                        [  4.81872559e-02,   4.80346680e-02],
                        [  1.05926514e-01,   1.05865479e-01],
                        [  1.47369385e-01,   1.47521973e-01],
                        [  1.59027100e-01,   1.59118652e-01],
                        [  1.42669678e-01,   1.42547607e-01],
                        [  1.14318848e-01,   1.14166260e-01],
                        [  8.99047852e-02,   9.00268555e-02],
                        [  7.23571777e-02,   7.25402832e-02],
                        [  5.52978516e-02,   5.52368164e-02],
                        [  3.69567871e-02,   3.67431641e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  1.93786621e-02,   1.95922852e-02],
                        [  2.08129883e-02,   2.08435059e-02],
                        [  2.05688477e-02,   2.03247070e-02],
                        [  1.48925781e-02,   1.48315430e-02],
                        [  2.65502930e-03,   2.86865234e-03],
                        [ -1.58996582e-02,  -1.58386230e-02],
                        [ -3.56445312e-02,  -3.58276367e-02],
                        [ -4.86755371e-02,  -4.87060547e-02],
                        [ -5.12084961e-02,  -5.10559082e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -3.54003906e-02,  -3.55834961e-02],
                        [ -2.61535645e-02,  -2.61230469e-02],
                        [ -1.94091797e-02,  -1.92260742e-02],
                        [ -1.35192871e-02,  -1.35498047e-02],
                        [ -7.87353516e-03,  -8.11767578e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.73034668e-02,  -1.70593262e-02],
                        [ -3.50646973e-02,  -3.50036621e-02],
                        [ -5.18188477e-02,  -5.20629883e-02],
                        [ -6.20117188e-02,  -6.21337891e-02],
                        [ -6.64978027e-02,  -6.62841797e-02],
                        [ -6.83898926e-02,  -6.82373047e-02],
                        [ -7.01904297e-02,  -7.03430176e-02],
                        [ -7.24182129e-02,  -7.25708008e-02],
                        [ -7.31506348e-02,  -7.30590820e-02],
                        [ -6.90612793e-02,  -6.89086914e-02],
                        [ -5.82885742e-02,  -5.83801270e-02],
                        [ -4.45556641e-02,  -4.46777344e-02],
                        [ -3.50646973e-02,  -3.50036621e-02],
                        [ -3.24096680e-02,  -3.23181152e-02],
                        [ -3.20739746e-02,  -3.21350098e-02],
                        [ -2.74963379e-02,  -2.76184082e-02],
                        [ -1.34887695e-02,  -1.34277344e-02],
                        [  1.14440918e-02,   1.15966797e-02],
                        [  4.15649414e-02,   4.14733887e-02],
                        [  6.54907227e-02,   6.53381348e-02],
                        [  7.31201172e-02,   7.31811523e-02],
                        [  5.94177246e-02,   5.96008301e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [ -4.31823730e-02,  -4.33349609e-02],
                        [ -1.27410889e-01,  -1.27441406e-01],
                        [ -2.07061768e-01,  -2.06939697e-01],
                        [ -2.53723145e-01,  -2.53662109e-01],
                        [ -2.55554199e-01,  -2.55615234e-01],
                        [ -2.22351074e-01,  -2.22412109e-01],
                        [ -1.74530029e-01,  -1.74468994e-01],
                        [ -1.30645752e-01,  -1.30615234e-01],
                        [ -1.00158691e-01,  -1.00219727e-01],
                        [ -8.08105469e-02,  -8.08715820e-02],
                        [ -6.31408691e-02,  -6.30187988e-02],
                        [ -4.13818359e-02,  -4.12597656e-02],
                        [ -1.97448730e-02,  -1.98974609e-02],
                        [ -4.48608398e-03,  -4.66918945e-03],
                        [  5.92041016e-03,   6.10351562e-03],
                        [  1.84020996e-02,   1.86157227e-02],
                        [  3.78723145e-02,   3.77197266e-02],
                        [  6.47583008e-02,   6.44836426e-02],
                        [  9.50012207e-02,   9.50927734e-02],
                        [  1.21490479e-01,   1.21765137e-01],
                        [  1.37145996e-01,   1.37084961e-01],
                        [  1.34094238e-01,   1.33850098e-01],
                        [  1.00708008e-01,   1.00769043e-01],
                        [  2.93273926e-02,   2.95104980e-02],
                        [ -6.92443848e-02,  -6.93054199e-02],
                        [ -1.63543701e-01,  -1.63696289e-01],
                        [ -2.19543457e-01,  -2.19451904e-01],
                        [ -2.22259521e-01,  -2.22106934e-01],
                        [ -1.82342529e-01,  -1.82495117e-01],
                        [ -1.26495361e-01,  -1.26678467e-01],
                        [ -7.99560547e-02,  -7.98339844e-02],
                        [ -5.13610840e-02,  -5.11474609e-02],
                        [ -3.25012207e-02,  -3.26232910e-02],
                        [ -1.45263672e-02,  -1.47705078e-02],
                        [  8.85009766e-04,   9.15527344e-04],
                        [  8.33129883e-03,   8.60595703e-03],
                        [  8.42285156e-03,   8.45336914e-03],
                        [  6.92749023e-03,   6.71386719e-03],
                        [  1.07421875e-02,   1.06506348e-02],
                        [  2.39257812e-02,   2.40783691e-02],
                        [  4.24194336e-02,   4.25415039e-02],
                        [  5.44738770e-02,   5.43823242e-02],
                        [  5.03845215e-02,   5.02624512e-02],
                        [  3.22265625e-02,   3.22875977e-02],
                        [  1.06506348e-02,   1.07727051e-02],
                        [ -5.64575195e-03,  -5.67626953e-03],
                        [ -1.13525391e-02,  -1.14440918e-02],
                        [  9.15527344e-05,   1.22070312e-04],
                        [  3.21350098e-02,   3.22570801e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  1.26403809e-01,   1.26281738e-01],
                        [  1.63085938e-01,   1.63085938e-01],
                        [  1.80664062e-01,   1.80786133e-01],
                        [  1.77856445e-01,   1.77886963e-01],
                        [  1.60797119e-01,   1.60614014e-01],
                        [  1.40869141e-01,   1.40808105e-01],
                        [  1.27593994e-01,   1.27746582e-01],
                        [  1.19964600e-01,   1.20025635e-01],
                        [  1.10137939e-01,   1.10015869e-01],
                        [  9.65576172e-02,   9.64660645e-02],
                        [  8.57238770e-02,   8.58154297e-02],
                        [  8.02001953e-02,   8.02917480e-02],
                        [  7.34558105e-02,   7.33642578e-02],
                        [  5.85021973e-02,   5.84411621e-02],
                        [  3.65295410e-02,   3.66210938e-02],
                        [  1.28479004e-02,   1.29089355e-02],
                        [ -8.75854492e-03,  -8.88061523e-03],
                        [ -2.38952637e-02,  -2.39562988e-02],
                        [ -2.58178711e-02,  -2.56652832e-02],
                        [ -9.06372070e-03,  -8.97216797e-03],
                        [  2.74963379e-02,   2.73742676e-02],
                        [  7.72399902e-02,   7.70874023e-02],
                        [  1.23626709e-01,   1.23718262e-01],
                        [  1.48651123e-01,   1.48834229e-01],
                        [  1.46575928e-01,   1.46545410e-01],
                        [  1.27136230e-01,   1.26922607e-01],
                        [  1.04431152e-01,   1.04370117e-01],
                        [  8.34655762e-02,   8.36791992e-02],
                        [  5.92651367e-02,   5.93872070e-02],
                        [  2.96020508e-02,   2.94799805e-02],
                        [  4.33349609e-03,   4.18090820e-03],
                        [ -4.88281250e-03,  -4.82177734e-03],
                        [  1.83105469e-04,   3.35693359e-04],
                        [  7.93457031e-03,   7.90405273e-03],
                        [  1.17187500e-02,   1.15661621e-02],
                        [  1.08337402e-02,   1.08032227e-02],
                        [  3.75366211e-03,   3.87573242e-03],
                        [ -8.78906250e-03,  -8.75854492e-03],
                        [ -2.03552246e-02,  -2.04162598e-02],
                        [ -2.55737305e-02,  -2.56042480e-02],
                        [ -2.54821777e-02,  -2.54516602e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.20336914e-02,  -2.20642090e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.96533203e-02,  -1.96228027e-02],
                        [ -1.80053711e-02,  -1.80358887e-02],
                        [ -1.80969238e-02,  -1.81579590e-02],
                        [ -2.28881836e-02,  -2.28576660e-02],
                        [ -3.19824219e-02,  -3.18908691e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.95605469e-02,  -4.96520996e-02],
                        [ -5.28869629e-02,  -5.29479980e-02],
                        [ -5.44128418e-02,  -5.43212891e-02],
                        [ -5.81970215e-02,  -5.81054688e-02],
                        [ -6.29577637e-02,  -6.30493164e-02],
                        [ -6.32019043e-02,  -6.33850098e-02],
                        [ -5.82580566e-02,  -5.82275391e-02],
                        [ -5.26733398e-02,  -5.25207520e-02],
                        [ -4.90417480e-02,  -4.90112305e-02],
                        [ -4.54406738e-02,  -4.55932617e-02],
                        [ -3.90319824e-02,  -3.91235352e-02],
                        [ -2.85644531e-02,  -2.84729004e-02],
                        [ -1.36718750e-02,  -1.35803223e-02],
                        [  5.52368164e-03,   5.49316406e-03],
                        [  2.70690918e-02,   2.69775391e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  5.90820312e-02,   5.91125488e-02],
                        [  5.82580566e-02,   5.82885742e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [ -1.16882324e-02,  -1.17187500e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -1.54968262e-01,  -1.54937744e-01],
                        [ -2.11242676e-01,  -2.11242676e-01],
                        [ -2.31323242e-01,  -2.31323242e-01],
                        [ -2.10571289e-01,  -2.10540771e-01],
                        [ -1.64703369e-01,  -1.64703369e-01],
                        [ -1.20819092e-01,  -1.20910645e-01],
                        [ -9.60693359e-02,  -9.60693359e-02],
                        [ -8.75244141e-02,  -8.74328613e-02],
                        [ -8.29772949e-02,  -8.29162598e-02],
                        [ -7.39135742e-02,  -7.40051270e-02],
                        [ -5.90209961e-02,  -5.90820312e-02],
                        [ -4.13208008e-02,  -4.12597656e-02],
                        [ -2.31933594e-02,  -2.31018066e-02],
                        [ -2.92968750e-03,  -2.99072266e-03],
                        [  2.21862793e-02,   2.20947266e-02],
                        [  5.12390137e-02,   5.12695312e-02],
                        [  8.07495117e-02,   8.08410645e-02],
                        [  1.07147217e-01,   1.07116699e-01],
                        [  1.26586914e-01,   1.26525879e-01],
                        [  1.34582520e-01,   1.34643555e-01],
                        [  1.23443604e-01,   1.23504639e-01],
                        [  7.96813965e-02,   7.96203613e-02],
                        [ -4.82177734e-03,  -4.91333008e-03],
                        [ -1.12731934e-01,  -1.12701416e-01],
                        [ -2.02819824e-01,  -2.02697754e-01],
                        [ -2.39135742e-01,  -2.39135742e-01],
                        [ -2.16339111e-01,  -2.16461182e-01],
                        [ -1.57745361e-01,  -1.57806396e-01],
                        [ -9.53369141e-02,  -9.52453613e-02],
                        [ -5.19714355e-02,  -5.18493652e-02],
                        [ -3.35083008e-02,  -3.35693359e-02],
                        [ -2.99987793e-02,  -3.01513672e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -1.87988281e-02,  -1.86767578e-02],
                        [ -1.19934082e-02,  -1.19628906e-02],
                        [ -1.04675293e-02,  -1.05895996e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  4.36401367e-03,   4.42504883e-03],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  4.04357910e-02,   4.04052734e-02],
                        [  4.96520996e-02,   4.96826172e-02],
                        [  5.10864258e-02,   5.11474609e-02],
                        [  4.42810059e-02,   4.42199707e-02],
                        [  3.11584473e-02,   3.10974121e-02],
                        [  1.83410645e-02,   1.83715820e-02],
                        [  1.25122070e-02,   1.26037598e-02],
                        [  1.69372559e-02,   1.69067383e-02],
                        [  3.21350098e-02,   3.20434570e-02],
                        [  5.88378906e-02,   5.88378906e-02],
                        [  9.60083008e-02,   9.60998535e-02],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.58386230e-01,   1.58325195e-01],
                        [  1.60644531e-01,   1.60675049e-01],
                        [  1.49780273e-01,   1.49841309e-01],
                        [  1.39068604e-01,   1.39007568e-01],
                        [  1.32476807e-01,   1.32415771e-01],
                        [  1.26068115e-01,   1.26129150e-01],
                        [  1.17492676e-01,   1.17614746e-01],
                        [  1.07513428e-01,   1.07452393e-01],
                        [  9.56115723e-02,   9.54589844e-02],
                        [  8.07495117e-02,   8.07800293e-02],
                        [  6.29882812e-02,   6.31713867e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  2.02026367e-02,   2.00195312e-02],
                        [ -2.22778320e-03,  -2.31933594e-03],
                        [ -2.06298828e-02,  -2.05078125e-02],
                        [ -2.97241211e-02,  -2.96020508e-02],
                        [ -2.65197754e-02,  -2.65808105e-02],
                        [ -9.91821289e-03,  -1.00708008e-02],
                        [  2.17285156e-02,   2.17895508e-02],
                        [  6.61926270e-02,   6.63146973e-02],
                        [  1.10992432e-01,   1.10961914e-01],
                        [  1.39709473e-01,   1.39587402e-01],
                        [  1.44561768e-01,   1.44592285e-01],
                        [  1.29882812e-01,   1.29974365e-01],
                        [  1.05834961e-01,   1.05773926e-01],
                        [  8.13903809e-02,   8.12988281e-02],
                        [  6.00585938e-02,   6.01501465e-02],
                        [  3.97338867e-02,   3.98864746e-02],
                        [  1.86462402e-02,   1.85852051e-02],
                        [  1.25122070e-03,   1.06811523e-03],
                        [ -6.46972656e-03,  -6.37817383e-03],
                        [ -4.85229492e-03,  -4.66918945e-03],
                        [ -3.05175781e-04,  -3.35693359e-04],
                        [  1.61743164e-03,   1.40380859e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -2.62451172e-03,  -2.44140625e-03],
                        [ -4.30297852e-03,  -4.27246094e-03],
                        [ -7.96508789e-03,  -8.11767578e-03],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -3.07006836e-02,  -3.05786133e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -4.37011719e-02,  -4.38232422e-02],
                        [ -4.11071777e-02,  -4.10766602e-02],
                        [ -3.80859375e-02,  -3.79638672e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -3.80554199e-02,  -3.81774902e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -5.03845215e-02,  -5.02319336e-02],
                        [ -5.65185547e-02,  -5.64880371e-02],
                        [ -5.81970215e-02,  -5.83190918e-02],
                        [ -5.70678711e-02,  -5.71289062e-02],
                        [ -5.56335449e-02,  -5.55419922e-02],
                        [ -5.39550781e-02,  -5.38940430e-02],
                        [ -5.21850586e-02,  -5.22766113e-02],
                        [ -5.14526367e-02,  -5.15136719e-02],
                        [ -5.14526367e-02,  -5.13610840e-02],
                        [ -5.00793457e-02,  -5.00183105e-02],
                        [ -4.61730957e-02,  -4.62341309e-02],
                        [ -4.01916504e-02,  -4.02526855e-02],
                        [ -3.18908691e-02,  -3.18298340e-02],
                        [ -1.91345215e-02,  -1.90429688e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  2.14538574e-02,   2.13623047e-02],
                        [  4.31823730e-02,   4.31518555e-02],
                        [  5.98449707e-02,   5.99060059e-02],
                        [  6.40258789e-02,   6.41174316e-02],
                        [  4.53491211e-02,   4.52575684e-02],
                        [ -2.53295898e-03,  -2.65502930e-03],
                        [ -7.29064941e-02,  -7.28759766e-02],
                        [ -1.47888184e-01,  -1.47766113e-01],
                        [ -2.06359863e-01,  -2.06359863e-01],
                        [ -2.30010986e-01,  -2.30133057e-01],
                        [ -2.14447021e-01,  -2.14477539e-01],
                        [ -1.77551270e-01,  -1.77459717e-01],
                        [ -1.45263672e-01,  -1.45233154e-01],
                        [ -1.27258301e-01,  -1.27349854e-01],
                        [ -1.14929199e-01,  -1.14959717e-01],
                        [ -9.74121094e-02,  -9.73510742e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -4.57763672e-02,  -4.58374023e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -1.08947754e-02,  -1.08642578e-02],
                        [ -8.54492188e-04,  -8.85009766e-04],
                        [  1.15966797e-02,   1.15661621e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  1.14135742e-01,   1.14166260e-01],
                        [  1.38275146e-01,   1.38275146e-01],
                        [  1.41479492e-01,   1.41418457e-01],
                        [  1.09436035e-01,   1.09405518e-01],
                        [  3.46984863e-02,   3.47900391e-02],
                        [ -6.91833496e-02,  -6.90917969e-02],
                        [ -1.66473389e-01,  -1.66564941e-01],
                        [ -2.19207764e-01,  -2.19299316e-01],
                        [ -2.13073730e-01,  -2.12982178e-01],
                        [ -1.66656494e-01,  -1.66564941e-01],
                        [ -1.13525391e-01,  -1.13586426e-01],
                        [ -7.51037598e-02,  -7.51647949e-02],
                        [ -5.27954102e-02,  -5.27343750e-02],
                        [ -3.78417969e-02,  -3.77807617e-02],
                        [ -2.22473145e-02,  -2.23693848e-02],
                        [ -5.58471680e-03,  -5.61523438e-03],
                        [  5.79833984e-03,   5.98144531e-03],
                        [  8.78906250e-03,   8.85009766e-03],
                        [  1.09252930e-02,   1.07116699e-02],
                        [  2.10266113e-02,   2.09350586e-02],
                        [  3.50341797e-02,   3.52783203e-02],
                        [  4.18395996e-02,   4.19921875e-02],
                        [  4.08020020e-02,   4.05273438e-02],
                        [  3.99475098e-02,   3.97338867e-02],
                        [  4.01000977e-02,   4.02832031e-02],
                        [  3.43627930e-02,   3.46069336e-02],
                        [  2.11486816e-02,   2.10266113e-02],
                        [  7.14111328e-03,   6.89697266e-03],
                        [  5.49316406e-04,   6.40869141e-04],
                        [  7.47680664e-03,   7.69042969e-03],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  6.81152344e-02,   6.79321289e-02],
                        [  1.11724854e-01,   1.11694336e-01],
                        [  1.49291992e-01,   1.49444580e-01],
                        [  1.69586182e-01,   1.69647217e-01],
                        [  1.70043945e-01,   1.69921875e-01],
                        [  1.59667969e-01,   1.59606934e-01],
                        [  1.50634766e-01,   1.50756836e-01],
                        [  1.47094727e-01,   1.47155762e-01],
                        [  1.42822266e-01,   1.42700195e-01],
                        [  1.29669189e-01,   1.29608154e-01],
                        [  1.06811523e-01,   1.06933594e-01],
                        [  8.14819336e-02,   8.15429688e-02],
                        [  6.18286133e-02,   6.17065430e-02],
                        [  4.96215820e-02,   4.95605469e-02],
                        [  3.91235352e-02,   3.92761230e-02],
                        [  2.34985352e-02,   2.35900879e-02],
                        [  2.13623047e-03,   1.98364258e-03],
                        [ -1.92565918e-02,  -1.93786621e-02],
                        [ -3.37829590e-02,  -3.36303711e-02],
                        [ -3.60107422e-02,  -3.58276367e-02],
                        [ -2.11791992e-02,  -2.13317871e-02],
                        [  1.35803223e-02,   1.33666992e-02],
                        [  6.38122559e-02,   6.39038086e-02],
                        [  1.13281250e-01,   1.13525391e-01],
                        [  1.41754150e-01,   1.41723633e-01],
                        [  1.40594482e-01,   1.40350342e-01],
                        [  1.18408203e-01,   1.18377686e-01],
                        [  9.08508301e-02,   9.11254883e-02],
                        [  6.80541992e-02,   6.81457520e-02],
                        [  5.07507324e-02,   5.05371094e-02],
                        [  3.66516113e-02,   3.65295410e-02],
                        [  2.63061523e-02,   2.64587402e-02],
                        [  2.11181641e-02,   2.12402344e-02],
                        [  2.02331543e-02,   2.01110840e-02],
                        [  2.06604004e-02,   2.05688477e-02],
                        [  1.77001953e-02,   1.77917480e-02],
                        [  6.43920898e-03,   6.50024414e-03],
                        [ -1.38549805e-02,  -1.39770508e-02],
                        [ -3.69262695e-02,  -3.70178223e-02],
                        [ -5.33447266e-02,  -5.32226562e-02],
                        [ -5.81054688e-02,  -5.79833984e-02],
                        [ -5.28259277e-02,  -5.29479980e-02],
                        [ -4.07714844e-02,  -4.09545898e-02],
                        [ -2.48413086e-02,  -2.47497559e-02],
                        [ -1.11389160e-02,  -1.09252930e-02],
                        [ -7.56835938e-03,  -7.59887695e-03],
                        [ -1.52282715e-02,  -1.54418945e-02],
                        [ -2.60620117e-02,  -2.60925293e-02],
                        [ -3.29284668e-02,  -3.27453613e-02],
                        [ -3.78417969e-02,  -3.77807617e-02],
                        [ -4.55322266e-02,  -4.56848145e-02],
                        [ -5.41992188e-02,  -5.42602539e-02],
                        [ -5.89599609e-02,  -5.88378906e-02],
                        [ -6.02111816e-02,  -6.01501465e-02],
                        [ -6.10351562e-02,  -6.11877441e-02],
                        [ -6.10961914e-02,  -6.11267090e-02],
                        [ -5.81665039e-02,  -5.80139160e-02],
                        [ -5.37719727e-02,  -5.37414551e-02],
                        [ -5.10864258e-02,  -5.12695312e-02],
                        [ -4.94689941e-02,  -4.95300293e-02],
                        [ -4.57458496e-02,  -4.55322266e-02],
                        [ -3.75671387e-02,  -3.74755859e-02],
                        [ -2.23388672e-02,  -2.25524902e-02],
                        [  2.80761719e-03,   2.68554688e-03],
                        [  3.55834961e-02,   3.57971191e-02],
                        [  6.61315918e-02,   6.62841797e-02],
                        [  8.24279785e-02,   8.22448730e-02],
                        [  7.57751465e-02,   7.56225586e-02],
                        [  4.02221680e-02,   4.03747559e-02],
                        [ -2.62756348e-02,  -2.61230469e-02],
                        [ -1.12854004e-01,  -1.13037109e-01],
                        [ -1.93542480e-01,  -1.93695068e-01],
                        [ -2.41333008e-01,  -2.41119385e-01],
                        [ -2.44689941e-01,  -2.44537354e-01],
                        [ -2.12524414e-01,  -2.12768555e-01],
                        [ -1.67083740e-01,  -1.67266846e-01],
                        [ -1.29730225e-01,  -1.29486084e-01],
                        [ -1.08581543e-01,  -1.08367920e-01],
                        [ -9.75952148e-02,  -9.77783203e-02],
                        [ -8.62121582e-02,  -8.65173340e-02],
                        [ -7.10449219e-02,  -7.08923340e-02],
                        [ -5.59082031e-02,  -5.56030273e-02],
                        [ -4.22668457e-02,  -4.23583984e-02],
                        [ -2.53906250e-02,  -2.56347656e-02],
                        [ -6.40869141e-04,  -6.10351562e-04],
                        [  3.09448242e-02,   3.11584473e-02],
                        [  6.48193359e-02,   6.47888184e-02],
                        [  9.62219238e-02,   9.60388184e-02],
                        [  1.21643066e-01,   1.21673584e-01],
                        [  1.38702393e-01,   1.38885498e-01],
                        [  1.44958496e-01,   1.44866943e-01],
                        [  1.33117676e-01,   1.32904053e-01],
                        [  8.95996094e-02,   8.96911621e-02],
                        [  7.26318359e-03,   7.50732422e-03],
                        [ -9.77478027e-02,  -9.78393555e-02],
                        [ -1.88537598e-01,  -1.88842773e-01],
                        [ -2.30682373e-01,  -2.30651855e-01],
                        [ -2.15179443e-01,  -2.14904785e-01],
                        [ -1.62780762e-01,  -1.62750244e-01],
                        [ -1.06903076e-01,  -1.07177734e-01],
                        [ -6.97021484e-02,  -6.97937012e-02],
                        [ -5.14221191e-02,  -5.12390137e-02],
                        [ -3.86352539e-02,  -3.85131836e-02],
                        [ -2.11486816e-02,  -2.13012695e-02],
                        [ -1.83105469e-03,  -1.98364258e-03],
                        [  9.55200195e-03,   9.64355469e-03],
                        [  1.04675293e-02,   1.05895996e-02],
                        [  9.49096680e-03,   9.39941406e-03],
                        [  1.54418945e-02,   1.53198242e-02],
                        [  2.71606445e-02,   2.72521973e-02],
                        [  3.62243652e-02,   3.63464355e-02],
                        [  3.75671387e-02,   3.74755859e-02],
                        [  3.30810547e-02,   3.29284668e-02],
                        [  2.67639160e-02,   2.68249512e-02],
                        [  1.90734863e-02,   1.92565918e-02],
                        [  8.57543945e-03,   8.54492188e-03],
                        [ -2.56347656e-03,  -2.77709961e-03],
                        [ -6.80541992e-03,  -6.83593750e-03],
                        [  4.21142578e-03,   4.39453125e-03],
                        [  3.43627930e-02,   3.44543457e-02],
                        [  7.99560547e-02,   7.98034668e-02],
                        [  1.29760742e-01,   1.29638672e-01],
                        [  1.69708252e-01,   1.69769287e-01],
                        [  1.89636230e-01,   1.89758301e-01],
                        [  1.88385010e-01,   1.88354492e-01],
                        [  1.73187256e-01,   1.73095703e-01],
                        [  1.54022217e-01,   1.53991699e-01],
                        [  1.36871338e-01,   1.36932373e-01],
                        [  1.20574951e-01,   1.20574951e-01],
                        [  1.01501465e-01,   1.01470947e-01],
                        [  8.13903809e-02,   8.14208984e-02],
                        [  6.68334961e-02,   6.68029785e-02],
                        [  6.08215332e-02,   6.07604980e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  5.01403809e-02,   5.02014160e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  5.64575195e-03,   5.58471680e-03],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -3.08532715e-02,  -3.07922363e-02],
                        [ -3.30810547e-02,  -3.30505371e-02],
                        [ -2.13928223e-02,  -2.14233398e-02],
                        [  5.34057617e-03,   5.27954102e-03],
                        [  4.39758301e-02,   4.40063477e-02],
                        [  8.65783691e-02,   8.66088867e-02],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  1.36260986e-01,   1.36230469e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.00982666e-01,   1.01013184e-01],
                        [  7.73010254e-02,   7.73010254e-02],
                        [  6.39343262e-02,   6.39038086e-02],
                        [  5.53283691e-02,   5.52978516e-02],
                        [  4.22058105e-02,   4.22363281e-02],
                        [  2.45666504e-02,   2.45971680e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  7.75146484e-03,   7.69042969e-03],
                        [  8.11767578e-03,   8.14819336e-03],
                        [  3.26538086e-03,   3.32641602e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -2.22778320e-02,  -2.23693848e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.41796875e-02,  -3.40576172e-02],
                        [ -3.38439941e-02,  -3.38134766e-02],
                        [ -3.09448242e-02,  -3.10668945e-02],
                        [ -2.68859863e-02,  -2.69775391e-02],
                        [ -2.66113281e-02,  -2.65197754e-02],
                        [ -3.35998535e-02,  -3.34472656e-02],
                        [ -4.37316895e-02,  -4.37622070e-02],
                        [ -4.88891602e-02,  -4.90417480e-02],
                        [ -4.65393066e-02,  -4.65698242e-02],
                        [ -4.23583984e-02,  -4.22058105e-02],
                        [ -4.25720215e-02,  -4.24499512e-02],
                        [ -4.82177734e-02,  -4.83398438e-02],
                        [ -5.64880371e-02,  -5.66711426e-02],
                        [ -6.27136230e-02,  -6.26831055e-02],
                        [ -6.36901855e-02,  -6.35070801e-02],
                        [ -6.02722168e-02,  -6.02111816e-02],
                        [ -5.40771484e-02,  -5.42602539e-02],
                        [ -4.58374023e-02,  -4.59594727e-02],
                        [ -3.80859375e-02,  -3.79638672e-02],
                        [ -3.32031250e-02,  -3.31115723e-02],
                        [ -2.84118652e-02,  -2.85034180e-02],
                        [ -1.74560547e-02,  -1.75476074e-02],
                        [  1.95312500e-03,   2.04467773e-03],
                        [  2.56347656e-02,   2.56958008e-02],
                        [  4.70581055e-02,   4.69665527e-02],
                        [  6.13098145e-02,   6.12792969e-02],
                        [  6.17370605e-02,   6.18896484e-02],
                        [  3.82080078e-02,   3.82385254e-02],
                        [ -1.60217285e-02,  -1.62353516e-02],
                        [ -9.53369141e-02,  -9.54284668e-02],
                        [ -1.79687500e-01,  -1.79443359e-01],
                        [ -2.41394043e-01,  -2.41241455e-01],
                        [ -2.59582520e-01,  -2.59826660e-01],
                        [ -2.33428955e-01,  -2.33673096e-01],
                        [ -1.83593750e-01,  -1.83410645e-01],
                        [ -1.38305664e-01,  -1.38031006e-01],
                        [ -1.12976074e-01,  -1.13067627e-01],
                        [ -1.00921631e-01,  -1.01196289e-01],
                        [ -8.63037109e-02,  -8.62731934e-02],
                        [ -6.35986328e-02,  -6.33544922e-02],
                        [ -4.09545898e-02,  -4.09240723e-02],
                        [ -2.74963379e-02,  -2.77099609e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.53198242e-02,  -1.51977539e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  3.19213867e-02,   3.18298340e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  9.68933105e-02,   9.69848633e-02],
                        [  1.20483398e-01,   1.20483398e-01],
                        [  1.35375977e-01,   1.35284424e-01],
                        [  1.37908936e-01,   1.37908936e-01],
                        [  1.20300293e-01,   1.20361328e-01],
                        [  7.33642578e-02,   7.33947754e-02],
                        [ -6.59179688e-03,  -6.65283203e-03],
                        [ -1.06048584e-01,  -1.06109619e-01],
                        [ -1.90338135e-01,  -1.90307617e-01],
                        [ -2.24426270e-01,  -2.24365234e-01],
                        [ -2.02087402e-01,  -2.02087402e-01],
                        [ -1.47247314e-01,  -1.47277832e-01],
                        [ -9.02099609e-02,  -9.02099609e-02],
                        [ -4.91638184e-02,  -4.91943359e-02],
                        [ -2.70080566e-02,  -2.70690918e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -7.87353516e-03,  -7.78198242e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  2.01416016e-03,   1.86157227e-03],
                        [ -2.86865234e-03,  -2.92968750e-03],
                        [ -7.29370117e-03,  -7.17163086e-03],
                        [ -9.76562500e-04,  -8.54492188e-04],
                        [  1.63269043e-02,   1.62353516e-02],
                        [  3.34167480e-02,   3.32641602e-02],
                        [  3.98559570e-02,   3.99169922e-02],
                        [  3.70483398e-02,   3.72009277e-02],
                        [  3.25012207e-02,   3.24707031e-02],
                        [  2.64892578e-02,   2.63977051e-02],
                        [  1.51367188e-02,   1.51672363e-02],
                        [  4.30297852e-03,   4.36401367e-03],
                        [  7.11059570e-03,   7.04956055e-03],
                        [  2.94189453e-02,   2.93884277e-02],
                        [  6.63757324e-02,   6.64978027e-02],
                        [  1.09771729e-01,   1.09832764e-01],
                        [  1.51641846e-01,   1.51489258e-01],
                        [  1.82556152e-01,   1.82434082e-01],
                        [  1.92565918e-01,   1.92687988e-01],
                        [  1.79229736e-01,   1.79412842e-01],
                        [  1.52801514e-01,   1.52740479e-01],
                        [  1.27868652e-01,   1.27624512e-01],
                        [  1.11480713e-01,   1.11480713e-01],
                        [  1.01745605e-01,   1.01989746e-01],
                        [  9.47570801e-02,   9.48181152e-02],
                        [  9.01794434e-02,   8.99658203e-02],
                        [  8.91418457e-02,   8.89892578e-02],
                        [  8.93554688e-02,   8.94775391e-02],
                        [  8.51440430e-02,   8.53271484e-02],
                        [  7.07397461e-02,   7.06481934e-02],
                        [  4.42810059e-02,   4.40979004e-02],
                        [  1.10778809e-02,   1.11083984e-02],
                        [ -2.01721191e-02,  -2.00195312e-02],
                        [ -4.37927246e-02,  -4.38232422e-02],
                        [ -5.54809570e-02,  -5.56030273e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -1.72119141e-02,  -1.70593262e-02],
                        [  3.13415527e-02,   3.13720703e-02],
                        [  8.33435059e-02,   8.31909180e-02],
                        [  1.23962402e-01,   1.23901367e-01],
                        [  1.42456055e-01,   1.42639160e-01],
                        [  1.34948730e-01,   1.35040283e-01],
                        [  1.08367920e-01,   1.08184814e-01],
                        [  7.81555176e-02,   7.80334473e-02],
                        [  5.58166504e-02,   5.59692383e-02],
                        [  4.12292480e-02,   4.13818359e-02],
                        [  2.98461914e-02,   2.97546387e-02],
                        [  2.28881836e-02,   2.27355957e-02],
                        [  2.43835449e-02,   2.44140625e-02],
                        [  3.10363770e-02,   3.11889648e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  2.01721191e-02,   2.00500488e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -2.27050781e-02,  -2.26135254e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.55627441e-02,  -4.56542969e-02],
                        [ -4.24194336e-02,  -4.23889160e-02],
                        [ -3.24096680e-02,  -3.23181152e-02],
                        [ -2.40173340e-02,  -2.40478516e-02],
                        [ -2.27050781e-02,  -2.27966309e-02],
                        [ -2.62756348e-02,  -2.62451172e-02],
                        [ -3.08532715e-02,  -3.07617188e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.11682129e-02,  -4.12597656e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -4.86755371e-02,  -4.86145020e-02],
                        [ -4.85229492e-02,  -4.84924316e-02],
                        [ -4.83703613e-02,  -4.84313965e-02],
                        [ -4.95605469e-02,  -4.95910645e-02],
                        [ -5.00488281e-02,  -5.00183105e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -4.26330566e-02,  -4.26635742e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -1.82800293e-02,  -1.82495117e-02],
                        [ -6.71386719e-04,  -6.40869141e-04],
                        [  2.33154297e-02,   2.32543945e-02],
                        [  4.67224121e-02,   4.66918945e-02],
                        [  5.92956543e-02,   5.93872070e-02],
                        [  5.15747070e-02,   5.16357422e-02],
                        [  1.78527832e-02,   1.77307129e-02],
                        [ -4.19616699e-02,  -4.20837402e-02],
                        [ -1.19628906e-01,  -1.19537354e-01],
                        [ -1.95556641e-01,  -1.95404053e-01],
                        [ -2.42492676e-01,  -2.42523193e-01],
                        [ -2.42370605e-01,  -2.42553711e-01],
                        [ -2.04162598e-01,  -2.04162598e-01],
                        [ -1.58599854e-01,  -1.58447266e-01],
                        [ -1.30157471e-01,  -1.30126953e-01],
                        [ -1.17462158e-01,  -1.17584229e-01],
                        [ -1.04919434e-01,  -1.04980469e-01],
                        [ -8.60595703e-02,  -8.59985352e-02],
                        [ -6.84814453e-02,  -6.84204102e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -5.37414551e-02,  -5.38024902e-02],
                        [ -4.06188965e-02,  -4.06494141e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [  2.26745605e-02,   2.27355957e-02],
                        [  6.14318848e-02,   6.14624023e-02],
                        [  9.54284668e-02,   9.53979492e-02],
                        [  1.21337891e-01,   1.21276855e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.44226074e-01,   1.44287109e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.02233887e-01,   1.02172852e-01],
                        [  3.26232910e-02,   3.26232910e-02],
                        [ -6.53381348e-02,  -6.52770996e-02],
                        [ -1.62170410e-01,  -1.62170410e-01],
                        [ -2.22473145e-01,  -2.22534180e-01],
                        [ -2.26287842e-01,  -2.26318359e-01],
                        [ -1.81243896e-01,  -1.81152344e-01],
                        [ -1.17187500e-01,  -1.17156982e-01],
                        [ -6.62536621e-02,  -6.63452148e-02],
                        [ -4.16259766e-02,  -4.16870117e-02],
                        [ -3.25317383e-02,  -3.24401855e-02],
                        [ -2.14538574e-02,  -2.13623047e-02],
                        [ -4.48608398e-03,  -4.57763672e-03],
                        [  8.30078125e-03,   8.20922852e-03],
                        [  9.39941406e-03,   9.42993164e-03],
                        [  4.39453125e-03,   4.51660156e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  1.67846680e-02,   1.66931152e-02],
                        [  3.11584473e-02,   3.11279297e-02],
                        [  4.06188965e-02,   4.07104492e-02],
                        [  4.17175293e-02,   4.17480469e-02],
                        [  3.39355469e-02,   3.38745117e-02],
                        [  2.08740234e-02,   2.08435059e-02],
                        [  8.94165039e-03,   9.00268555e-03],
                        [  8.54492188e-04,   8.85009766e-04],
                        [ -4.51660156e-03,  -4.60815430e-03],
                        [ -3.81469727e-03,  -3.84521484e-03],
                        [  1.12609863e-02,   1.14135742e-02],
                        [  4.42504883e-02,   4.43115234e-02],
                        [  8.92639160e-02,   8.90808105e-02],
                        [  1.36352539e-01,   1.36230469e-01],
                        [  1.74194336e-01,   1.74346924e-01],
                        [  1.90795898e-01,   1.90948486e-01],
                        [  1.82250977e-01,   1.82098389e-01],
                        [  1.59454346e-01,   1.59271240e-01],
                        [  1.39251709e-01,   1.39343262e-01],
                        [  1.29211426e-01,   1.29425049e-01],
                        [  1.23779297e-01,   1.23718262e-01],
                        [  1.13464355e-01,   1.13281250e-01],
                        [  9.64050293e-02,   9.64355469e-02],
                        [  7.89184570e-02,   7.90710449e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  5.74340820e-02,   5.73120117e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  2.56958008e-02,   2.57873535e-02],
                        [ -2.22778320e-03,  -2.19726562e-03],
                        [ -3.27453613e-02,  -3.28369141e-02],
                        [ -5.57250977e-02,  -5.57556152e-02],
                        [ -6.15234375e-02,  -6.14624023e-02],
                        [ -4.79431152e-02,  -4.79125977e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [  1.80969238e-02,   1.80664062e-02],
                        [  6.27136230e-02,   6.26831055e-02],
                        [  1.05163574e-01,   1.05133057e-01],
                        [  1.30737305e-01,   1.30767822e-01],
                        [  1.31134033e-01,   1.31164551e-01],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  9.00878906e-02,   9.00573730e-02],
                        [  6.87866211e-02,   6.87561035e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  3.79638672e-02,   3.80249023e-02],
                        [  3.25012207e-02,   3.25317383e-02],
                        [  2.83203125e-02,   2.82287598e-02],
                        [  1.87683105e-02,   1.86462402e-02],
                        [  4.69970703e-03,   4.79125977e-03],
                        [ -8.60595703e-03,  -8.42285156e-03],
                        [ -1.89208984e-02,  -1.89819336e-02],
                        [ -2.62145996e-02,  -2.64587402e-02],
                        [ -2.93884277e-02,  -2.94189453e-02],
                        [ -2.84118652e-02,  -2.81677246e-02],
                        [ -2.64892578e-02,  -2.63977051e-02],
                        [ -2.66723633e-02,  -2.68554688e-02],
                        [ -2.83813477e-02,  -2.85034180e-02],
                        [ -3.02124023e-02,  -3.01208496e-02],
                        [ -3.30810547e-02,  -3.29284668e-02],
                        [ -3.74145508e-02,  -3.74450684e-02],
                        [ -4.02526855e-02,  -4.03442383e-02],
                        [ -3.90625000e-02,  -3.90319824e-02],
                        [ -3.64074707e-02,  -3.63464355e-02],
                        [ -3.64990234e-02,  -3.65295410e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.04968262e-02,  -4.04052734e-02],
                        [ -4.26635742e-02,  -4.26940918e-02],
                        [ -4.92248535e-02,  -4.93469238e-02],
                        [ -5.70678711e-02,  -5.70983887e-02],
                        [ -5.87158203e-02,  -5.85632324e-02],
                        [ -5.30700684e-02,  -5.30090332e-02],
                        [ -4.61730957e-02,  -4.63562012e-02],
                        [ -4.14428711e-02,  -4.15039062e-02],
                        [ -3.43627930e-02,  -3.41796875e-02],
                        [ -1.82189941e-02,  -1.81274414e-02],
                        [  7.72094727e-03,   7.56835938e-03],
                        [  3.67736816e-02,   3.66821289e-02],
                        [  5.92956543e-02,   5.94482422e-02],
                        [  6.59484863e-02,   6.61010742e-02],
                        [  4.93774414e-02,   4.92248535e-02],
                        [  5.06591797e-03,   4.91333008e-03],
                        [ -6.55822754e-02,  -6.54907227e-02],
                        [ -1.48590088e-01,  -1.48406982e-01],
                        [ -2.16766357e-01,  -2.16857910e-01],
                        [ -2.44781494e-01,  -2.44964600e-01],
                        [ -2.27264404e-01,  -2.27233887e-01],
                        [ -1.83441162e-01,  -1.83258057e-01],
                        [ -1.41632080e-01,  -1.41601562e-01],
                        [ -1.16882324e-01,  -1.17034912e-01],
                        [ -1.04125977e-01,  -1.04156494e-01],
                        [ -9.21325684e-02,  -9.20410156e-02],
                        [ -7.79418945e-02,  -7.79418945e-02],
                        [ -6.69555664e-02,  -6.70471191e-02],
                        [ -6.22863770e-02,  -6.22558594e-02],
                        [ -5.67321777e-02,  -5.66406250e-02],
                        [ -3.93981934e-02,  -3.94897461e-02],
                        [ -8.54492188e-03,  -8.63647461e-03],
                        [  2.75878906e-02,   2.77099609e-02],
                        [  5.99365234e-02,   6.01196289e-02],
                        [  8.55712891e-02,   8.54797363e-02],
                        [  1.07177734e-01,   1.06964111e-01],
                        [  1.26220703e-01,   1.26251221e-01],
                        [  1.38488770e-01,   1.38732910e-01],
                        [  1.36077881e-01,   1.36108398e-01],
                        [  1.08489990e-01,   1.08276367e-01],
                        [  4.65698242e-02,   4.64782715e-02],
                        [ -4.52880859e-02,  -4.51354980e-02],
                        [ -1.42150879e-01,  -1.41998291e-01],
                        [ -2.09289551e-01,  -2.09381104e-01],
                        [ -2.24090576e-01,  -2.24243164e-01],
                        [ -1.90795898e-01,  -1.90765381e-01],
                        [ -1.36413574e-01,  -1.36291504e-01],
                        [ -9.01794434e-02,  -9.01794434e-02],
                        [ -6.35986328e-02,  -6.36901855e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -2.71911621e-02,  -2.70996094e-02],
                        [ -2.59399414e-03,  -2.62451172e-03],
                        [  1.58081055e-02,   1.57470703e-02],
                        [  2.12402344e-02,   2.12707520e-02],
                        [  1.83105469e-02,   1.83715820e-02],
                        [  1.79748535e-02,   1.79443359e-02],
                        [  2.68249512e-02,   2.67639160e-02],
                        [  4.01916504e-02,   4.02221680e-02],
                        [  4.80957031e-02,   4.81872559e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  4.12597656e-02,   4.11682129e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  1.95617676e-02,   1.96533203e-02],
                        [  5.79833984e-03,   5.82885742e-03],
                        [ -3.17382812e-03,  -3.26538086e-03],
                        [ -1.25122070e-03,  -1.31225586e-03],
                        [  1.47094727e-02,   1.47705078e-02],
                        [  4.47387695e-02,   4.48303223e-02],
                        [  8.67614746e-02,   8.67004395e-02],
                        [  1.35345459e-01,   1.35253906e-01],
                        [  1.78375244e-01,   1.78405762e-01],
                        [  1.99493408e-01,   1.99615479e-01],
                        [  1.91162109e-01,   1.91162109e-01],
                        [  1.64093018e-01,   1.63940430e-01],
                        [  1.38397217e-01,   1.38336182e-01],
                        [  1.25000000e-01,   1.25122070e-01],
                        [  1.19689941e-01,   1.19812012e-01],
                        [  1.13342285e-01,   1.13250732e-01],
                        [  1.02844238e-01,   1.02661133e-01],
                        [  9.15222168e-02,   9.15527344e-02],
                        [  8.13598633e-02,   8.15429688e-02],
                        [  6.83593750e-02,   6.83898926e-02],
                        [  4.86145020e-02,   4.84313965e-02],
                        [  2.44750977e-02,   2.43835449e-02],
                        [ -1.52587891e-04,   0.00000000e+00],
                        [ -2.42919922e-02,  -2.41394043e-02],
                        [ -4.60205078e-02,  -4.61120605e-02],
                        [ -5.98449707e-02,  -6.00585938e-02],
                        [ -5.97229004e-02,  -5.96923828e-02],
                        [ -4.11682129e-02,  -4.09545898e-02],
                        [ -3.20434570e-03,  -3.17382812e-03],
                        [  4.85229492e-02,   4.83398438e-02],
                        [  1.00555420e-01,   1.00463867e-01],
                        [  1.35711670e-01,   1.35864258e-01],
                        [  1.43157959e-01,   1.43280029e-01],
                        [  1.26739502e-01,   1.26647949e-01],
                        [  1.01745605e-01,   1.01623535e-01],
                        [  8.16040039e-02,   8.16345215e-02],
                        [  6.82067871e-02,   6.82983398e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  4.07714844e-02,   4.07104492e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.73645020e-02,   1.73950195e-02],
                        [  1.34582520e-02,   1.34277344e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.77001953e-03,   1.83105469e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -3.17077637e-02,  -3.17993164e-02],
                        [ -4.40063477e-02,  -4.40673828e-02],
                        [ -4.74853516e-02,  -4.73632812e-02],
                        [ -4.40063477e-02,  -4.39147949e-02],
                        [ -3.86657715e-02,  -3.87573242e-02],
                        [ -3.46984863e-02,  -3.48510742e-02],
                        [ -3.08532715e-02,  -3.08227539e-02],
                        [ -2.53295898e-02,  -2.51770020e-02],
                        [ -2.09045410e-02,  -2.08435059e-02],
                        [ -2.27050781e-02,  -2.28576660e-02],
                        [ -3.14331055e-02,  -3.15551758e-02],
                        [ -4.26330566e-02,  -4.24804688e-02],
                        [ -5.19104004e-02,  -5.17272949e-02],
                        [ -5.70068359e-02,  -5.70983887e-02],
                        [ -5.69152832e-02,  -5.71289062e-02],
                        [ -5.30090332e-02,  -5.29785156e-02],
                        [ -4.93469238e-02,  -4.91638184e-02],
                        [ -4.86755371e-02,  -4.87060547e-02],
                        [ -4.81872559e-02,  -4.83093262e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -2.75268555e-02,  -2.74353027e-02],
                        [ -6.77490234e-03,  -6.80541992e-03],
                        [  1.76696777e-02,   1.75781250e-02],
                        [  4.15039062e-02,   4.15649414e-02],
                        [  5.84106445e-02,   5.84716797e-02],
                        [  6.28967285e-02,   6.28356934e-02],
                        [  4.93774414e-02,   4.92858887e-02],
                        [  1.07421875e-02,   1.08032227e-02],
                        [ -5.42602539e-02,  -5.41687012e-02],
                        [ -1.33148193e-01,  -1.33178711e-01],
                        [ -2.03277588e-01,  -2.03399658e-01],
                        [ -2.43713379e-01,  -2.43682861e-01],
                        [ -2.44812012e-01,  -2.44750977e-01],
                        [ -2.13226318e-01,  -2.13256836e-01],
                        [ -1.70593262e-01,  -1.70654297e-01],
                        [ -1.39892578e-01,  -1.39862061e-01],
                        [ -1.25305176e-01,  -1.25244141e-01],
                        [ -1.12518311e-01,  -1.12579346e-01],
                        [ -9.14001465e-02,  -9.14611816e-02],
                        [ -6.80541992e-02,  -6.79931641e-02],
                        [ -5.25207520e-02,  -5.24291992e-02],
                        [ -4.52575684e-02,  -4.52880859e-02],
                        [ -3.89099121e-02,  -3.90319824e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -5.12695312e-03,  -4.97436523e-03],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  5.63354492e-02,   5.62133789e-02],
                        [  8.30688477e-02,   8.29772949e-02],
                        [  1.03668213e-01,   1.03729248e-01],
                        [  1.20513916e-01,   1.20605469e-01],
                        [  1.30981445e-01,   1.30950928e-01],
                        [  1.26342773e-01,   1.26281738e-01],
                        [  9.81750488e-02,   9.81750488e-02],
                        [  4.18395996e-02,   4.18701172e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -1.29119873e-01,  -1.29119873e-01],
                        [ -1.93572998e-01,  -1.93542480e-01],
                        [ -2.05871582e-01,  -2.05871582e-01],
                        [ -1.68426514e-01,  -1.68487549e-01],
                        [ -1.12884521e-01,  -1.12915039e-01],
                        [ -7.25708008e-02,  -7.25097656e-02],
                        [ -5.67321777e-02,  -5.66711426e-02],
                        [ -5.11169434e-02,  -5.12084961e-02],
                        [ -3.95202637e-02,  -3.96423340e-02],
                        [ -2.11181641e-02,  -2.10876465e-02],
                        [ -6.43920898e-03,  -6.28662109e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -9.76562500e-04,  -1.09863281e-03],
                        [  2.92968750e-03,   2.89916992e-03],
                        [  1.33056641e-02,   1.33972168e-02],
                        [  2.71911621e-02,   2.72521973e-02],
                        [  3.85437012e-02,   3.84521484e-02],
                        [  4.14428711e-02,   4.13818359e-02],
                        [  3.55834961e-02,   3.56445312e-02],
                        [  2.62756348e-02,   2.63366699e-02],
                        [  1.65710449e-02,   1.65100098e-02],
                        [  5.55419922e-03,   5.52368164e-03],
                        [ -3.26538086e-03,  -3.17382812e-03],
                        [ -3.66210938e-04,  -3.35693359e-04],
                        [  1.95922852e-02,   1.95007324e-02],
                        [  5.38330078e-02,   5.37719727e-02],
                        [  9.75952148e-02,   9.76867676e-02],
                        [  1.44683838e-01,   1.44744873e-01],
                        [  1.81945801e-01,   1.81854248e-01],
                        [  1.94641113e-01,   1.94549561e-01],
                        [  1.81396484e-01,   1.81457520e-01],
                        [  1.57409668e-01,   1.57470703e-01],
                        [  1.38671875e-01,   1.38610840e-01],
                        [  1.27502441e-01,   1.27471924e-01],
                        [  1.17126465e-01,   1.17218018e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  9.21325684e-02,   9.20410156e-02],
                        [  8.27331543e-02,   8.27026367e-02],
                        [  7.47070312e-02,   7.48596191e-02],
                        [  6.59179688e-02,   6.59484863e-02],
                        [  5.39550781e-02,   5.38024902e-02],
                        [  3.47595215e-02,   3.46679688e-02],
                        [  6.13403320e-03,   6.25610352e-03],
                        [ -2.58483887e-02,  -2.57263184e-02],
                        [ -4.95300293e-02,  -4.96520996e-02],
                        [ -5.87158203e-02,  -5.88684082e-02],
                        [ -5.58471680e-02,  -5.58166504e-02],
                        [ -4.35180664e-02,  -4.33654785e-02],
                        [ -1.81884766e-02,  -1.81579590e-02],
                        [  2.31933594e-02,   2.30712891e-02],
                        [  7.25708008e-02,   7.25097656e-02],
                        [  1.12731934e-01,   1.12792969e-01],
                        [  1.30645752e-01,   1.30706787e-01],
                        [  1.25366211e-01,   1.25335693e-01],
                        [  1.04370117e-01,   1.04309082e-01],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  5.46875000e-02,   5.47180176e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  1.95617676e-02,   1.95922852e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.11389160e-02,   1.11083984e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  4.21142578e-03,   4.27246094e-03],
                        [ -1.83105469e-03,  -1.80053711e-03],
                        [ -9.73510742e-03,  -9.82666016e-03],
                        [ -1.73950195e-02,  -1.74865723e-02],
                        [ -2.31018066e-02,  -2.30407715e-02],
                        [ -2.89001465e-02,  -2.88085938e-02],
                        [ -3.63769531e-02,  -3.64379883e-02],
                        [ -4.11071777e-02,  -4.12292480e-02],
                        [ -3.78112793e-02,  -3.77807617e-02],
                        [ -2.87170410e-02,  -2.85644531e-02],
                        [ -2.17895508e-02,  -2.17590332e-02],
                        [ -2.15148926e-02,  -2.16674805e-02],
                        [ -2.49328613e-02,  -2.49938965e-02],
                        [ -2.78930664e-02,  -2.77709961e-02],
                        [ -3.11584473e-02,  -3.10363770e-02],
                        [ -3.72314453e-02,  -3.72924805e-02],
                        [ -4.56848145e-02,  -4.58374023e-02],
                        [ -5.36193848e-02,  -5.35888672e-02],
                        [ -5.79223633e-02,  -5.78002930e-02],
                        [ -5.61828613e-02,  -5.61523438e-02],
                        [ -4.59594727e-02,  -4.60510254e-02],
                        [ -2.71301270e-02,  -2.71911621e-02],
                        [ -4.73022461e-03,  -4.63867188e-03],
                        [  1.57470703e-02,   1.58386230e-02],
                        [  3.50341797e-02,   3.50036621e-02],
                        [  5.50231934e-02,   5.49316406e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  6.22863770e-02,   6.23474121e-02],
                        [  2.64892578e-02,   2.65197754e-02],
                        [ -3.72009277e-02,  -3.72619629e-02],
                        [ -1.17675781e-01,  -1.17706299e-01],
                        [ -1.96594238e-01,  -1.96533203e-01],
                        [ -2.51159668e-01,  -2.51129150e-01],
                        [ -2.63763428e-01,  -2.63793945e-01],
                        [ -2.35412598e-01,  -2.35443115e-01],
                        [ -1.87194824e-01,  -1.87164307e-01],
                        [ -1.43432617e-01,  -1.43371582e-01],
                        [ -1.14105225e-01,  -1.14135742e-01],
                        [ -9.40856934e-02,  -9.41467285e-02],
                        [ -7.62023926e-02,  -7.62023926e-02],
                        [ -6.08825684e-02,  -6.08520508e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -5.04150391e-02,  -5.04455566e-02],
                        [ -4.78210449e-02,  -4.78515625e-02],
                        [ -3.73535156e-02,  -3.73229980e-02],
                        [ -1.71508789e-02,  -1.71203613e-02],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  5.87768555e-02,   5.88378906e-02],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  1.14837646e-01,   1.14776611e-01],
                        [  1.41235352e-01,   1.41265869e-01],
                        [  1.52465820e-01,   1.52557373e-01],
                        [  1.39556885e-01,   1.39556885e-01],
                        [  1.00402832e-01,   1.00311279e-01],
                        [  3.64074707e-02,   3.63464355e-02],
                        [ -4.73327637e-02,  -4.72412109e-02],
                        [ -1.34124756e-01,  -1.34033203e-01],
                        [ -1.94946289e-01,  -1.95007324e-01],
                        [ -2.06176758e-01,  -2.06298828e-01],
                        [ -1.70562744e-01,  -1.70532227e-01],
                        [ -1.16546631e-01,  -1.16394043e-01],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -5.35888672e-02,  -5.36804199e-02],
                        [ -4.31823730e-02,  -4.32434082e-02],
                        [ -3.15856934e-02,  -3.14941406e-02],
                        [ -1.85546875e-02,  -1.84936523e-02],
                        [ -1.02233887e-02,  -1.02844238e-02],
                        [ -8.33129883e-03,  -8.39233398e-03],
                        [ -6.89697266e-03,  -6.83593750e-03],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  1.92565918e-02,   1.92260742e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  4.37622070e-02,   4.38232422e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  3.54614258e-02,   3.54003906e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  1.95617676e-02,   1.96533203e-02],
                        [  1.11999512e-02,   1.12304688e-02],
                        [  7.14111328e-03,   7.04956055e-03],
                        [  9.97924805e-03,   9.94873047e-03],
                        [  2.17895508e-02,   2.18811035e-02],
                        [  4.56237793e-02,   4.56848145e-02],
                        [  8.20312500e-02,   8.19702148e-02],
                        [  1.24389648e-01,   1.24328613e-01],
                        [  1.60430908e-01,   1.60491943e-01],
                        [  1.79962158e-01,   1.80023193e-01],
                        [  1.81060791e-01,   1.81030273e-01],
                        [  1.70318604e-01,   1.70227051e-01],
                        [  1.56524658e-01,   1.56555176e-01],
                        [  1.44287109e-01,   1.44378662e-01],
                        [  1.32324219e-01,   1.32293701e-01],
                        [  1.18041992e-01,   1.17980957e-01],
                        [  1.02630615e-01,   1.02630615e-01],
                        [  8.87756348e-02,   8.88366699e-02],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  6.05163574e-02,   6.04553223e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  1.96533203e-02,   1.96838379e-02],
                        [  1.52587891e-04,   1.52587891e-04],
                        [ -1.70288086e-02,  -1.70593262e-02],
                        [ -3.25622559e-02,  -3.25317383e-02],
                        [ -4.36401367e-02,  -4.36096191e-02],
                        [ -4.54406738e-02,  -4.55017090e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -2.42919922e-02,  -2.42309570e-02],
                        [ -3.05175781e-03,  -2.99072266e-03],
                        [  3.34472656e-02,   3.33862305e-02],
                        [  8.37707520e-02,   8.37097168e-02],
                        [  1.29180908e-01,   1.29241943e-01],
                        [  1.48162842e-01,   1.48254395e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  1.05804443e-01,   1.05712891e-01],
                        [  7.30895996e-02,   7.30590820e-02],
                        [  4.77600098e-02,   4.78210449e-02],
                        [  3.16772461e-02,   3.17077637e-02],
                        [  2.09960938e-02,   2.09350586e-02],
                        [  1.24511719e-02,   1.23901367e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  2.96020508e-03,   2.99072266e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -2.14843750e-02,  -2.15148926e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.15039062e-02,  -4.14733887e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -2.62451172e-02,  -2.62756348e-02],
                        [ -2.15759277e-02,  -2.15454102e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.42309570e-02,  -2.42614746e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.00903320e-02,  -3.00598145e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -4.46472168e-02,  -4.47082520e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -5.46875000e-02,  -5.46264648e-02],
                        [ -4.83398438e-02,  -4.83093262e-02],
                        [ -3.34167480e-02,  -3.34777832e-02],
                        [ -1.45568848e-02,  -1.45874023e-02],
                        [  5.03540039e-03,   5.09643555e-03],
                        [  2.53295898e-02,   2.53601074e-02],
                        [  4.35791016e-02,   4.34875488e-02],
                        [  5.07812500e-02,   5.07202148e-02],
                        [  3.63159180e-02,   3.63464355e-02],
                        [ -5.24902344e-03,  -5.21850586e-03],
                        [ -7.04650879e-02,  -7.04956055e-02],
                        [ -1.46087646e-01,  -1.46148682e-01],
                        [ -2.11273193e-01,  -2.11242676e-01],
                        [ -2.45666504e-01,  -2.45635986e-01],
                        [ -2.40783691e-01,  -2.40814209e-01],
                        [ -2.05413818e-01,  -2.05444336e-01],
                        [ -1.61254883e-01,  -1.61254883e-01],
                        [ -1.29638672e-01,  -1.29608154e-01],
                        [ -1.15661621e-01,  -1.15661621e-01],
                        [ -1.06506348e-01,  -1.06536865e-01],
                        [ -8.95385742e-02,  -8.95080566e-02],
                        [ -6.72302246e-02,  -6.71997070e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -4.57153320e-02,  -4.56848145e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [  4.88281250e-04,   4.57763672e-04],
                        [  3.79943848e-02,   3.79638672e-02],
                        [  7.13500977e-02,   7.13806152e-02],
                        [  9.50012207e-02,   9.50317383e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.23046875e-01,   1.23016357e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.21673584e-01,   1.21704102e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -1.33911133e-01,  -1.33911133e-01],
                        [ -2.01690674e-01,  -2.01690674e-01],
                        [ -2.14874268e-01,  -2.14874268e-01],
                        [ -1.76208496e-01,  -1.76208496e-01],
                        [ -1.18499756e-01,  -1.18499756e-01],
                        [ -7.47680664e-02,  -7.47680664e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -3.42712402e-02,  -3.42407227e-02],
                        [ -2.22473145e-02,  -2.22167969e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -2.04467773e-03,  -2.07519531e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  4.96826172e-02,   4.96520996e-02],
                        [  3.93066406e-02,   3.92761230e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  3.02124023e-03,   3.05175781e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.54418945e-02,  -1.55029297e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  1.51672363e-02,   1.51977539e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  9.26208496e-02,   9.25903320e-02],
                        [  1.37084961e-01,   1.37054443e-01],
                        [  1.72607422e-01,   1.72637939e-01],
                        [  1.87072754e-01,   1.87072754e-01],
                        [  1.79656982e-01,   1.79626465e-01],
                        [  1.62048340e-01,   1.62048340e-01],
                        [  1.46362305e-01,   1.46362305e-01],
                        [  1.36566162e-01,   1.36566162e-01],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  1.08276367e-01,   1.08276367e-01],
                        [  9.56115723e-02,   9.56115723e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  7.03125000e-02,   7.03125000e-02],
                        [  5.54199219e-02,   5.54504395e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [ -5.12695312e-03,  -5.09643555e-03],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -5.04760742e-02,  -5.05065918e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.46569824e-02,  -5.46264648e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  1.13250732e-01,   1.13250732e-01],
                        [  1.38519287e-01,   1.38488770e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.15356445e-01,   1.15356445e-01],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  7.04956055e-02,   7.04650879e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  8.08715820e-03,   8.11767578e-03],
                        [ -3.87573242e-03,  -3.90625000e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.88085938e-02,  -2.87780762e-02],
                        [ -3.12805176e-02,  -3.13110352e-02],
                        [ -2.97241211e-02,  -2.97546387e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -2.82287598e-02,  -2.81982422e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.24707031e-02,  -3.25012207e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -4.48303223e-02,  -4.47998047e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.74450684e-02,  -3.74755859e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -3.17077637e-02,  -3.16772461e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.69775391e-02,  -2.70080566e-02],
                        [ -2.43225098e-02,  -2.42919922e-02],
                        [ -1.32446289e-02,  -1.32141113e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  2.51464844e-02,   2.51159668e-02],
                        [  3.70788574e-02,   3.70483398e-02],
                        [  3.81164551e-02,   3.81469727e-02],
                        [  2.72827148e-02,   2.73132324e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -1.44836426e-01,  -1.44805908e-01],
                        [ -2.20123291e-01,  -2.20123291e-01],
                        [ -2.56652832e-01,  -2.56652832e-01],
                        [ -2.44659424e-01,  -2.44659424e-01],
                        [ -1.98944092e-01,  -1.98944092e-01],
                        [ -1.46331787e-01,  -1.46331787e-01],
                        [ -1.09710693e-01,  -1.09710693e-01],
                        [ -9.39941406e-02,  -9.39941406e-02],
                        [ -8.82263184e-02,  -8.82263184e-02],
                        [ -8.18786621e-02,  -8.18786621e-02],
                        [ -7.30285645e-02,  -7.30590820e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  9.00573730e-02,   9.00573730e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.15447998e-01,   1.15447998e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.11968994e-01,   1.11968994e-01],
                        [  7.62023926e-02,   7.62023926e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [ -8.56323242e-02,  -8.56323242e-02],
                        [ -1.67083740e-01,  -1.67083740e-01],
                        [ -2.06878662e-01,  -2.06848145e-01],
                        [ -1.93603516e-01,  -1.93603516e-01],
                        [ -1.42425537e-01,  -1.42425537e-01],
                        [ -8.29772949e-02,  -8.30078125e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.13317871e-02,  -2.13623047e-02],
                        [  3.05175781e-05,   3.05175781e-05],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  2.84118652e-02,   2.83813477e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  5.46264648e-03,   5.49316406e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -5.18798828e-03,  -5.21850586e-03],
                        [ -2.92968750e-03,  -2.96020508e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  4.58068848e-02,   4.58374023e-02],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  1.40258789e-01,   1.40258789e-01],
                        [  1.71112061e-01,   1.71112061e-01],
                        [  1.81854248e-01,   1.81854248e-01],
                        [  1.78314209e-01,   1.78314209e-01],
                        [  1.67907715e-01,   1.67907715e-01],
                        [  1.55212402e-01,   1.55212402e-01],
                        [  1.42883301e-01,   1.42913818e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -1.22680664e-02,  -1.22985840e-02],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [  3.02124023e-03,   2.99072266e-03],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  7.79113770e-02,   7.79113770e-02],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  1.73950195e-03,   1.77001953e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -1.00341797e-01,  -1.00341797e-01],
                        [ -1.80236816e-01,  -1.80236816e-01],
                        [ -2.43072510e-01,  -2.43072510e-01],
                        [ -2.66540527e-01,  -2.66540527e-01],
                        [ -2.41729736e-01,  -2.41729736e-01],
                        [ -1.88049316e-01,  -1.88049316e-01],
                        [ -1.39190674e-01,  -1.39190674e-01],
                        [ -1.11755371e-01,  -1.11724854e-01],
                        [ -9.78698730e-02,  -9.78698730e-02],
                        [ -8.61816406e-02,  -8.61816406e-02],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  8.06884766e-02,   8.06884766e-02],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  1.01043701e-01,   1.01043701e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  7.39135742e-02,   7.39135742e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -1.53961182e-01,  -1.53961182e-01],
                        [ -1.95587158e-01,  -1.95587158e-01],
                        [ -1.83990479e-01,  -1.83990479e-01],
                        [ -1.33483887e-01,  -1.33483887e-01],
                        [ -7.91931152e-02,  -7.91931152e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  5.79223633e-02,   5.79223633e-02],
                        [  9.41162109e-02,   9.41162109e-02],
                        [  1.32476807e-01,   1.32476807e-01],
                        [  1.63299561e-01,   1.63299561e-01],
                        [  1.79016113e-01,   1.79016113e-01],
                        [  1.77490234e-01,   1.77490234e-01],
                        [  1.64306641e-01,   1.64306641e-01],
                        [  1.50238037e-01,   1.50238037e-01],
                        [  1.42822266e-01,   1.42822266e-01],
                        [  1.39160156e-01,   1.39160156e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.21917725e-01,   1.21917725e-01],
                        [  1.13525391e-01,   1.13525391e-01],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  1.14624023e-01,   1.14624023e-01],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -1.43463135e-01,  -1.43463135e-01],
                        [ -2.17895508e-01,  -2.17895508e-01],
                        [ -2.58453369e-01,  -2.58453369e-01],
                        [ -2.55432129e-01,  -2.55432129e-01],
                        [ -2.18444824e-01,  -2.18444824e-01],
                        [ -1.69372559e-01,  -1.69372559e-01],
                        [ -1.30218506e-01,  -1.30218506e-01],
                        [ -1.08886719e-01,  -1.08886719e-01],
                        [ -9.55810547e-02,  -9.55810547e-02],
                        [ -7.85217285e-02,  -7.85217285e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  8.93554688e-02,   8.93554688e-02],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  1.09558105e-01,   1.09558105e-01],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  7.44934082e-02,   7.44934082e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -1.42456055e-01,  -1.42456055e-01],
                        [ -1.90917969e-01,  -1.90917969e-01],
                        [ -1.91436768e-01,  -1.91436768e-01],
                        [ -1.55853271e-01,  -1.55853271e-01],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -7.41882324e-02,  -7.41882324e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  8.39233398e-03,   8.39233398e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.62658691e-01,   1.62658691e-01],
                        [  1.81304932e-01,   1.81304932e-01],
                        [  1.81396484e-01,   1.81396484e-01],
                        [  1.67449951e-01,   1.67449951e-01],
                        [  1.50238037e-01,   1.50238037e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.31134033e-01,   1.31134033e-01],
                        [  1.22955322e-01,   1.22955322e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  9.48181152e-02,   9.48181152e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  9.39941406e-02,   9.39941406e-02],
                        [  9.77478027e-02,   9.77478027e-02],
                        [  8.54492188e-02,   8.54492188e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.42199707e-02,   4.42199707e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -2.28729248e-01,  -2.28729248e-01],
                        [ -2.68402100e-01,  -2.68402100e-01],
                        [ -2.57629395e-01,  -2.57629395e-01],
                        [ -2.07275391e-01,  -2.07275391e-01],
                        [ -1.49353027e-01,  -1.49353027e-01],
                        [ -1.11724854e-01,  -1.11724854e-01],
                        [ -9.83581543e-02,  -9.83581543e-02],
                        [ -9.57336426e-02,  -9.57336426e-02],
                        [ -9.04235840e-02,  -9.04235840e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  2.20336914e-02,   2.20336914e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  7.71484375e-02,   7.71484375e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  1.03149414e-01,   1.03149414e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.17218018e-01,   1.17218018e-01],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  6.49108887e-02,   6.49108887e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -9.57031250e-02,  -9.57031250e-02],
                        [ -1.74560547e-01,  -1.74560547e-01],
                        [ -2.10540771e-01,  -2.10540771e-01],
                        [ -1.91406250e-01,  -1.91406250e-01],
                        [ -1.37268066e-01,  -1.37268066e-01],
                        [ -8.36791992e-02,  -8.36791992e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.41754150e-01,   1.41754150e-01],
                        [  1.68823242e-01,   1.68823242e-01],
                        [  1.73004150e-01,   1.73004150e-01],
                        [  1.62689209e-01,   1.62689209e-01],
                        [  1.51733398e-01,   1.51733398e-01],
                        [  1.46575928e-01,   1.46575928e-01],
                        [  1.41967773e-01,   1.41967773e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.16271973e-01,   1.16271973e-01],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  7.20214844e-03,   7.20214844e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  1.15875244e-01,   1.15875244e-01],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -1.69128418e-01,  -1.69128418e-01],
                        [ -2.34771729e-01,  -2.34771729e-01],
                        [ -2.65930176e-01,  -2.65930176e-01],
                        [ -2.51251221e-01,  -2.51251221e-01],
                        [ -2.01721191e-01,  -2.01721191e-01],
                        [ -1.48132324e-01,  -1.48132324e-01],
                        [ -1.16760254e-01,  -1.16760254e-01],
                        [ -1.08093262e-01,  -1.08093262e-01],
                        [ -1.04187012e-01,  -1.04187012e-01],
                        [ -9.27429199e-02,  -9.27429199e-02],
                        [ -7.59582520e-02,  -7.59582520e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  6.22863770e-02,   6.22863770e-02],
                        [  7.71484375e-02,   7.71484375e-02],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  1.17187500e-01,   1.17187500e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.17218018e-01,   1.17218018e-01],
                        [  7.52868652e-02,   7.52868652e-02],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.01531982e-01,  -1.01531982e-01],
                        [ -1.85424805e-01,  -1.85424805e-01],
                        [ -2.17864990e-01,  -2.17864990e-01],
                        [ -1.91101074e-01,  -1.91101074e-01],
                        [ -1.32781982e-01,  -1.32781982e-01],
                        [ -8.05053711e-02,  -8.05053711e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  4.88281250e-04,   4.88281250e-04],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  9.79919434e-02,   9.79919434e-02],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.59729004e-01,   1.59729004e-01],
                        [  1.57745361e-01,   1.57745361e-01],
                        [  1.41510010e-01,   1.41510010e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.29882812e-01,   1.29882812e-01],
                        [  1.35437012e-01,   1.35437012e-01],
                        [  1.37664795e-01,   1.37664795e-01],
                        [  1.35742188e-01,   1.35742188e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.20452881e-01,   1.20452881e-01],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  1.25305176e-01,   1.25305176e-01],
                        [  1.22467041e-01,   1.22467041e-01],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  5.52673340e-02,   5.52673340e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -9.01489258e-02,  -9.01489258e-02],
                        [ -1.68121338e-01,  -1.68121338e-01],
                        [ -2.33154297e-01,  -2.33154297e-01],
                        [ -2.62329102e-01,  -2.62329102e-01],
                        [ -2.44873047e-01,  -2.44873047e-01],
                        [ -1.93847656e-01,  -1.93847656e-01],
                        [ -1.40747070e-01,  -1.40747070e-01],
                        [ -1.10382080e-01,  -1.10382080e-01],
                        [ -1.02203369e-01,  -1.02203369e-01],
                        [ -9.96093750e-02,  -9.96093750e-02],
                        [ -9.12780762e-02,  -9.12780762e-02],
                        [ -7.73620605e-02,  -7.73620605e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -4.54406738e-02,  -4.54406738e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  8.28552246e-02,   8.28552246e-02],
                        [  9.38720703e-02,   9.38720703e-02],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  1.18560791e-01,   1.18560791e-01],
                        [  1.05865479e-01,   1.05865479e-01],
                        [  5.70983887e-02,   5.70983887e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -1.07879639e-01,  -1.07879639e-01],
                        [ -1.71142578e-01,  -1.71142578e-01],
                        [ -1.89727783e-01,  -1.89727783e-01],
                        [ -1.61315918e-01,  -1.61315918e-01],
                        [ -1.08795166e-01,  -1.08795166e-01],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.68487549e-01,   1.68487549e-01],
                        [  1.67388916e-01,   1.67388916e-01],
                        [  1.51672363e-01,   1.51672363e-01],
                        [  1.36260986e-01,   1.36260986e-01],
                        [  1.29241943e-01,   1.29241943e-01],
                        [  1.26556396e-01,   1.26556396e-01],
                        [  1.22192383e-01,   1.22192383e-01],
                        [  1.17431641e-01,   1.17431641e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.00982666e-01,   1.00982666e-01],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  7.80334473e-02,   7.80334473e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  7.77587891e-02,   7.77587891e-02],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.21429443e-01,   1.21429443e-01],
                        [  1.02478027e-01,   1.02478027e-01],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  6.57043457e-02,   6.57043457e-02],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -1.44439697e-01,  -1.44439697e-01],
                        [ -2.26867676e-01,  -2.26867676e-01],
                        [ -2.75329590e-01,  -2.75329590e-01],
                        [ -2.73895264e-01,  -2.73895264e-01],
                        [ -2.33551025e-01,  -2.33551025e-01],
                        [ -1.83502197e-01,  -1.83502197e-01],
                        [ -1.45721436e-01,  -1.45721436e-01],
                        [ -1.20758057e-01,  -1.20758057e-01],
                        [ -9.84802246e-02,  -9.84802246e-02],
                        [ -7.53173828e-02,  -7.53173828e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  5.77392578e-02,   5.77392578e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  1.18682861e-01,   1.18682861e-01],
                        [  1.15936279e-01,   1.15936279e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -1.20208740e-01,  -1.20208740e-01],
                        [ -1.70471191e-01,  -1.70471191e-01],
                        [ -1.73126221e-01,  -1.73126221e-01],
                        [ -1.40808105e-01,  -1.40808105e-01],
                        [ -1.00738525e-01,  -1.00738525e-01],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  3.69567871e-02,   3.69567871e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  1.60247803e-01,   1.60247803e-01],
                        [  1.84753418e-01,   1.84753418e-01],
                        [  1.91375732e-01,   1.91375732e-01],
                        [  1.77490234e-01,   1.77490234e-01],
                        [  1.48590088e-01,   1.48590088e-01],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.06048584e-01,   1.06048584e-01],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.68750000e-02,   4.68750000e-02],
                        [  4.69665527e-02,   4.69665527e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -1.93969727e-01,  -1.93969727e-01],
                        [ -2.63977051e-01,  -2.63977051e-01],
                        [ -2.88238525e-01,  -2.88238525e-01],
                        [ -2.62298584e-01,  -2.62298584e-01],
                        [ -2.06878662e-01,  -2.06878662e-01],
                        [ -1.52465820e-01,  -1.52465820e-01],
                        [ -1.17736816e-01,  -1.17736816e-01],
                        [ -1.00250244e-01,  -1.00250244e-01],
                        [ -8.78295898e-02,  -8.78295898e-02],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  1.08398438e-01,   1.08398438e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  5.51452637e-02,   5.51452637e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -8.65173340e-02,  -8.65173340e-02],
                        [ -1.46240234e-01,  -1.46240234e-01],
                        [ -1.69006348e-01,  -1.69006348e-01],
                        [ -1.52252197e-01,  -1.52252197e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -6.91833496e-02,  -6.91833496e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.77392578e-02,  -5.77392578e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  5.57250977e-02,   5.57250977e-02],
                        [  9.91210938e-02,   9.91210938e-02],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.72912598e-01,   1.72912598e-01],
                        [  1.76605225e-01,   1.76605225e-01],
                        [  1.58782959e-01,   1.58782959e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  9.72595215e-02,   9.72595215e-02],
                        [  9.22851562e-02,   9.22851562e-02],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  1.15753174e-01,   1.15753174e-01],
                        [  1.24328613e-01,   1.24328613e-01],
                        [  1.24938965e-01,   1.24938965e-01],
                        [  1.15875244e-01,   1.15875244e-01],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  5.23681641e-02,   5.23681641e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  1.15722656e-01,   1.15722656e-01],
                        [  1.05072021e-01,   1.05072021e-01],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -1.35162354e-01,  -1.35162354e-01],
                        [ -2.19726562e-01,  -2.19726562e-01],
                        [ -2.73712158e-01,  -2.73712158e-01],
                        [ -2.78503418e-01,  -2.78503418e-01],
                        [ -2.39807129e-01,  -2.39807129e-01],
                        [ -1.82006836e-01,  -1.82006836e-01],
                        [ -1.30371094e-01,  -1.30371094e-01],
                        [ -9.84802246e-02,  -9.84802246e-02],
                        [ -8.64257812e-02,  -8.64257812e-02],
                        [ -8.49609375e-02,  -8.49609375e-02],
                        [ -8.42895508e-02,  -8.42895508e-02],
                        [ -7.96813965e-02,  -7.96813965e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  5.91430664e-02,   5.91430664e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  1.24328613e-01,   1.24328613e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  4.32434082e-02,   4.32434082e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -1.38275146e-01,  -1.38275146e-01],
                        [ -1.91650391e-01,  -1.91650391e-01],
                        [ -1.88201904e-01,  -1.88201904e-01],
                        [ -1.42761230e-01,  -1.42761230e-01],
                        [ -8.72192383e-02,  -8.72192383e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -7.57141113e-02,  -7.57141113e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  1.24206543e-01,   1.24206543e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  2.07794189e-01,   2.07794189e-01],
                        [  2.06573486e-01,   2.06573486e-01],
                        [  1.77917480e-01,   1.77917480e-01],
                        [  1.38549805e-01,   1.38549805e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.22344971e-01,   1.22344971e-01],
                        [  1.15539551e-01,   1.15539551e-01],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  7.28759766e-02,   7.28759766e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  8.66699219e-02,   8.66699219e-02],
                        [  1.15539551e-01,   1.15539551e-01],
                        [  1.18804932e-01,   1.18804932e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  7.42797852e-02,   7.42797852e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -1.25213623e-01,  -1.25213623e-01],
                        [ -2.01629639e-01,  -2.01629639e-01],
                        [ -2.53570557e-01,  -2.53570557e-01],
                        [ -2.63610840e-01,  -2.63610840e-01],
                        [ -2.35595703e-01,  -2.35595703e-01],
                        [ -1.91741943e-01,  -1.91741943e-01],
                        [ -1.53259277e-01,  -1.53259277e-01],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -1.03027344e-01,  -1.03027344e-01],
                        [ -8.30078125e-02,  -8.30078125e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  5.69152832e-02,   5.69152832e-02],
                        [  6.82678223e-02,   6.82678223e-02],
                        [  7.87658691e-02,   7.87658691e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  1.25091553e-01,   1.25091553e-01],
                        [  1.33636475e-01,   1.33636475e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [ -7.85217285e-02,  -7.85217285e-02],
                        [ -1.45599365e-01,  -1.45599365e-01],
                        [ -1.74468994e-01,  -1.74468994e-01],
                        [ -1.60766602e-01,  -1.60766602e-01],
                        [ -1.22650146e-01,  -1.22650146e-01],
                        [ -8.61816406e-02,  -8.61816406e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  1.58508301e-01,   1.58508301e-01],
                        [  1.84417725e-01,   1.84417725e-01],
                        [  1.88781738e-01,   1.88781738e-01],
                        [  1.74652100e-01,   1.74652100e-01],
                        [  1.49505615e-01,   1.49505615e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  8.20007324e-02,   8.20007324e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  9.08813477e-02,   9.08813477e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  4.95300293e-02,   4.95300293e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -8.95996094e-02,  -8.95996094e-02],
                        [ -1.64947510e-01,  -1.64947510e-01],
                        [ -2.23785400e-01,  -2.23785400e-01],
                        [ -2.46093750e-01,  -2.46093750e-01],
                        [ -2.31170654e-01,  -2.31170654e-01],
                        [ -1.96105957e-01,  -1.96105957e-01],
                        [ -1.60583496e-01,  -1.60583496e-01],
                        [ -1.34307861e-01,  -1.34307861e-01],
                        [ -1.15234375e-01,  -1.15234375e-01],
                        [ -9.75952148e-02,  -9.75952148e-02],
                        [ -7.96203613e-02,  -7.96203613e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  8.97216797e-02,   8.97216797e-02],
                        [  9.98840332e-02,   9.98840332e-02],
                        [  1.02203369e-01,   1.02203369e-01],
                        [  1.07330322e-01,   1.07330322e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  8.68530273e-02,   8.68530273e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -1.51702881e-01,  -1.51702881e-01],
                        [ -1.95465088e-01,  -1.95465088e-01],
                        [ -1.86798096e-01,  -1.86798096e-01],
                        [ -1.41906738e-01,  -1.41906738e-01],
                        [ -9.25598145e-02,  -9.25598145e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  1.09680176e-01,   1.09680176e-01],
                        [  1.55670166e-01,   1.55670166e-01],
                        [  1.77368164e-01,   1.77368164e-01],
                        [  1.74591064e-01,   1.74591064e-01],
                        [  1.55944824e-01,   1.55944824e-01],
                        [  1.31988525e-01,   1.31988525e-01],
                        [  1.11511230e-01,   1.11511230e-01],
                        [  1.01654053e-01,   1.01654053e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  6.81152344e-02,   6.81152344e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -1.18072510e-01,  -1.18072510e-01],
                        [ -1.93237305e-01,  -1.93237305e-01],
                        [ -2.47528076e-01,  -2.47528076e-01],
                        [ -2.64404297e-01,  -2.64404297e-01],
                        [ -2.46368408e-01,  -2.46368408e-01],
                        [ -2.11303711e-01,  -2.11303711e-01],
                        [ -1.75567627e-01,  -1.75567627e-01],
                        [ -1.43890381e-01,  -1.43890381e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -9.27734375e-02,  -9.27734375e-02],
                        [ -7.81860352e-02,  -7.81860352e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  6.06079102e-02,   6.06079102e-02],
                        [  7.89184570e-02,   7.89184570e-02],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  1.28570557e-01,   1.28570557e-01],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -1.87530518e-01,  -1.87530518e-01],
                        [ -1.76513672e-01,  -1.76513672e-01],
                        [ -1.32873535e-01,  -1.32873535e-01],
                        [ -8.56628418e-02,  -8.56628418e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.60302734e-02,  -5.60302734e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  1.44561768e-01,   1.44561768e-01],
                        [  1.81274414e-01,   1.81274414e-01],
                        [  1.90948486e-01,   1.90948486e-01],
                        [  1.78527832e-01,   1.78527832e-01],
                        [  1.56005859e-01,   1.56005859e-01],
                        [  1.34216309e-01,   1.34216309e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  8.58764648e-02,   8.58764648e-02],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  8.62731934e-02,   8.62731934e-02],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  7.93457031e-04,   7.93457031e-04],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  6.57043457e-02,   6.57043457e-02],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [ -7.08923340e-02,  -7.08923340e-02],
                        [ -1.61224365e-01,  -1.61224365e-01],
                        [ -2.37976074e-01,  -2.37976074e-01],
                        [ -2.76306152e-01,  -2.76306152e-01],
                        [ -2.67730713e-01,  -2.67730713e-01],
                        [ -2.24487305e-01,  -2.24487305e-01],
                        [ -1.70806885e-01,  -1.70806885e-01],
                        [ -1.27868652e-01,  -1.27868652e-01],
                        [ -1.04187012e-01,  -1.04187012e-01],
                        [ -9.59167480e-02,  -9.59167480e-02],
                        [ -9.14916992e-02,  -9.14916992e-02],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -1.24328613e-01,  -1.24328613e-01],
                        [ -1.63421631e-01,  -1.63421631e-01],
                        [ -1.59027100e-01,  -1.59027100e-01],
                        [ -1.26708984e-01,  -1.26708984e-01],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  1.58752441e-01,   1.58752441e-01],
                        [  1.78100586e-01,   1.78100586e-01],
                        [  1.77764893e-01,   1.77764893e-01],
                        [  1.64794922e-01,   1.64794922e-01],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  7.65686035e-02,   7.65686035e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.73840332e-02,   3.73840332e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -1.14318848e-01,  -1.14318848e-01],
                        [ -1.86889648e-01,  -1.86889648e-01],
                        [ -2.42004395e-01,  -2.42004395e-01],
                        [ -2.61322021e-01,  -2.61322021e-01],
                        [ -2.43225098e-01,  -2.43225098e-01],
                        [ -2.03094482e-01,  -2.03094482e-01],
                        [ -1.60614014e-01,  -1.60614014e-01],
                        [ -1.28173828e-01,  -1.28173828e-01],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -8.06579590e-02,  -8.06579590e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  1.12152100e-01,   1.12152100e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -1.54205322e-01,  -1.54205322e-01],
                        [ -1.88354492e-01,  -1.88354492e-01],
                        [ -1.73614502e-01,  -1.73614502e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -9.09118652e-02,  -9.09118652e-02],
                        [ -6.63452148e-02,  -6.63452148e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  1.49536133e-01,   1.49536133e-01],
                        [  1.61376953e-01,   1.61376953e-01],
                        [  1.50421143e-01,   1.50421143e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.08367920e-01,   1.08367920e-01],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  8.71276855e-02,   8.71276855e-02],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  7.73925781e-02,   7.73925781e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  6.95800781e-02,   6.95800781e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  4.57458496e-02,   4.57458496e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -1.85974121e-01,  -1.85974121e-01],
                        [ -2.53387451e-01,  -2.53387451e-01],
                        [ -2.81433105e-01,  -2.81433105e-01],
                        [ -2.63183594e-01,  -2.63183594e-01],
                        [ -2.11761475e-01,  -2.11761475e-01],
                        [ -1.56799316e-01,  -1.56799316e-01],
                        [ -1.23077393e-01,  -1.23077393e-01],
                        [ -1.10717773e-01,  -1.10717773e-01],
                        [ -1.02294922e-01,  -1.02294922e-01],
                        [ -8.71276855e-02,  -8.71276855e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  9.27429199e-02,   9.27429199e-02],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -1.56433105e-01,  -1.56433105e-01],
                        [ -1.67022705e-01,  -1.67022705e-01],
                        [ -1.45904541e-01,  -1.45904541e-01],
                        [ -1.17095947e-01,  -1.17095947e-01],
                        [ -1.01013184e-01,  -1.01013184e-01],
                        [ -9.94567871e-02,  -9.94567871e-02],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -8.11767578e-02,  -8.11767578e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.60614014e-01,   1.60614014e-01],
                        [  1.51977539e-01,   1.51977539e-01],
                        [  1.35742188e-01,   1.35742188e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  7.01904297e-02,   7.01904297e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  7.00683594e-02,   7.00683594e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  6.19812012e-02,   6.19812012e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  4.02526855e-02,   4.02526855e-02],
                        [  7.62329102e-02,   7.62329102e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -1.13250732e-01,  -1.13250732e-01],
                        [ -2.05352783e-01,  -2.05352783e-01],
                        [ -2.73803711e-01,  -2.73803711e-01],
                        [ -2.94769287e-01,  -2.94769287e-01],
                        [ -2.65289307e-01,  -2.65289307e-01],
                        [ -2.06481934e-01,  -2.06481934e-01],
                        [ -1.49993896e-01,  -1.49993896e-01],
                        [ -1.16699219e-01,  -1.16699219e-01],
                        [ -1.04919434e-01,  -1.04919434e-01],
                        [ -9.86022949e-02,  -9.86022949e-02],
                        [ -8.66088867e-02,  -8.66088867e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  1.06262207e-01,   1.06262207e-01],
                        [  1.32049561e-01,   1.32049561e-01],
                        [  1.44775391e-01,   1.44775391e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  7.32116699e-02,   7.32116699e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.12609863e-01,  -1.12609863e-01],
                        [ -1.81793213e-01,  -1.81793213e-01],
                        [ -2.03491211e-01,  -2.03491211e-01],
                        [ -1.81640625e-01,  -1.81640625e-01],
                        [ -1.40258789e-01,  -1.40258789e-01],
                        [ -1.05499268e-01,  -1.05499268e-01],
                        [ -8.67309570e-02,  -8.67309570e-02],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  1.28692627e-01,   1.28692627e-01],
                        [  1.36688232e-01,   1.36688232e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.19018555e-01,   1.19018555e-01],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.05255127e-01,   1.05255127e-01],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  2.95410156e-02,   2.95410156e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  5.48400879e-02,   5.48400879e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -5.50842285e-02,  -5.50842285e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -1.28631592e-01,  -1.28631592e-01],
                        [ -2.11608887e-01,  -2.11608887e-01],
                        [ -2.65747070e-01,  -2.65747070e-01],
                        [ -2.77496338e-01,  -2.77496338e-01],
                        [ -2.49145508e-01,  -2.49145508e-01],
                        [ -1.98394775e-01,  -1.98394775e-01],
                        [ -1.49993896e-01,  -1.49993896e-01],
                        [ -1.19659424e-01,  -1.19659424e-01],
                        [ -1.05072021e-01,  -1.05072021e-01],
                        [ -9.54284668e-02,  -9.54284668e-02],
                        [ -8.43200684e-02,  -8.43200684e-02],
                        [ -7.07397461e-02,  -7.07397461e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.34826660e-01,   1.34826660e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.50604248e-01,   1.50604248e-01],
                        [  1.17675781e-01,   1.17675781e-01],
                        [  4.40368652e-02,   4.40368652e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -1.59698486e-01,  -1.59698486e-01],
                        [ -2.23175049e-01,  -2.23175049e-01],
                        [ -2.31414795e-01,  -2.31414795e-01],
                        [ -1.94396973e-01,  -1.94396973e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  1.19750977e-01,   1.19750977e-01],
                        [  1.33880615e-01,   1.33880615e-01],
                        [  1.24938965e-01,   1.24938965e-01],
                        [  1.06842041e-01,   1.06842041e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.04217529e-01,   1.04217529e-01],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  7.94372559e-02,   7.94372559e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -5.89294434e-02,  -5.89294434e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.00677490e-01,   1.00677490e-01],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -6.93359375e-02,  -6.93359375e-02],
                        [ -1.33270264e-01,  -1.33270264e-01],
                        [ -1.93359375e-01,  -1.93359375e-01],
                        [ -2.37060547e-01,  -2.37060547e-01],
                        [ -2.51129150e-01,  -2.51129150e-01],
                        [ -2.29858398e-01,  -2.29858398e-01],
                        [ -1.87683105e-01,  -1.87683105e-01],
                        [ -1.50939941e-01,  -1.50939941e-01],
                        [ -1.32171631e-01,  -1.32171631e-01],
                        [ -1.23168945e-01,  -1.23168945e-01],
                        [ -1.12915039e-01,  -1.12915039e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -8.15734863e-02,  -8.15734863e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  9.42077637e-02,   9.42077637e-02],
                        [  1.14685059e-01,   1.14685059e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.43615723e-01,   1.43615723e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -1.77673340e-01,  -1.77673340e-01],
                        [ -2.23175049e-01,  -2.23175049e-01],
                        [ -2.03796387e-01,  -2.03796387e-01],
                        [ -1.37939453e-01,  -1.37939453e-01],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  8.63342285e-02,   8.63342285e-02],
                        [  7.96508789e-02,   7.96508789e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  7.96813965e-02,   7.96813965e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  7.87658691e-02,   7.87658691e-02],
                        [  5.93261719e-02,   5.93261719e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.21429443e-01,   1.21429443e-01],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  9.21936035e-02,   9.21936035e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -7.96203613e-02,  -7.96203613e-02],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -1.64306641e-01,  -1.64306641e-01],
                        [ -1.90673828e-01,  -1.90673828e-01],
                        [ -2.01843262e-01,  -2.01843262e-01],
                        [ -1.97906494e-01,  -1.97906494e-01],
                        [ -1.83227539e-01,  -1.83227539e-01],
                        [ -1.64031982e-01,  -1.64031982e-01],
                        [ -1.43829346e-01,  -1.43829346e-01],
                        [ -1.23413086e-01,  -1.23413086e-01],
                        [ -1.04217529e-01,  -1.04217529e-01],
                        [ -8.90197754e-02,  -8.90197754e-02],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -6.78710938e-02,  -6.78710938e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.41204834e-01,   1.41204834e-01],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.16760254e-01,   1.16760254e-01],
                        [  6.22863770e-02,   6.22863770e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -1.01959229e-01,  -1.01959229e-01],
                        [ -1.67968750e-01,  -1.67968750e-01],
                        [ -1.89636230e-01,  -1.89636230e-01],
                        [ -1.60675049e-01,  -1.60675049e-01],
                        [ -1.00494385e-01,  -1.00494385e-01],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  6.89392090e-02,   6.89392090e-02],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.28234863e-01,   1.28234863e-01],
                        [  1.17156982e-01,   1.17156982e-01],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  1.60522461e-02,   1.60827637e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [ -4.21142578e-03,  -4.24194336e-03],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -1.01623535e-01,  -1.01654053e-01],
                        [ -1.51885986e-01,  -1.51885986e-01],
                        [ -1.95587158e-01,  -1.95587158e-01],
                        [ -2.20672607e-01,  -2.20672607e-01],
                        [ -2.21099854e-01,  -2.21069336e-01],
                        [ -2.03002930e-01,  -2.02972412e-01],
                        [ -1.77825928e-01,  -1.77825928e-01],
                        [ -1.52130127e-01,  -1.52099609e-01],
                        [ -1.26159668e-01,  -1.26129150e-01],
                        [ -1.00463867e-01,  -1.00463867e-01],
                        [ -7.88574219e-02,  -7.88574219e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -5.62438965e-02,  -5.62744141e-02],
                        [ -4.95300293e-02,  -4.95605469e-02],
                        [ -4.00695801e-02,  -4.01306152e-02],
                        [ -2.71301270e-02,  -2.71606445e-02],
                        [ -1.21765137e-02,  -1.22070312e-02],
                        [  2.07519531e-03,   2.04467773e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.03759766e-02,   1.04064941e-02],
                        [  4.66918945e-03,   4.73022461e-03],
                        [ -3.66210938e-04,  -2.74658203e-04],
                        [ -6.71386719e-04,  -6.10351562e-04],
                        [  4.73022461e-03,   4.79125977e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  2.79541016e-02,   2.79235840e-02],
                        [  4.91943359e-02,   4.91333008e-02],
                        [  7.48901367e-02,   7.47985840e-02],
                        [  9.81750488e-02,   9.80834961e-02],
                        [  1.14959717e-01,   1.14868164e-01],
                        [  1.24694824e-01,   1.24664307e-01],
                        [  1.25061035e-01,   1.25091553e-01],
                        [  1.10076904e-01,   1.10137939e-01],
                        [  7.43408203e-02,   7.44628906e-02],
                        [  1.66931152e-02,   1.68151855e-02],
                        [ -5.55419922e-02,  -5.54199219e-02],
                        [ -1.20422363e-01,  -1.20361328e-01],
                        [ -1.47796631e-01,  -1.47766113e-01],
                        [ -1.22253418e-01,  -1.22314453e-01],
                        [ -5.93261719e-02,  -5.94482422e-02],
                        [  4.82177734e-03,   4.63867188e-03],
                        [  4.11071777e-02,   4.09545898e-02],
                        [  4.73022461e-02,   4.71801758e-02],
                        [  4.11376953e-02,   4.11071777e-02],
                        [  3.81469727e-02,   3.82080078e-02],
                        [  3.92456055e-02,   3.93981934e-02],
                        [  3.71398926e-02,   3.73535156e-02],
                        [  2.99377441e-02,   3.01513672e-02],
                        [  2.57568359e-02,   2.59399414e-02],
                        [  3.28674316e-02,   3.29284668e-02],
                        [  4.95910645e-02,   4.95605469e-02],
                        [  6.83593750e-02,   6.82067871e-02],
                        [  8.30993652e-02,   8.28247070e-02],
                        [  8.85925293e-02,   8.83178711e-02],
                        [  8.03527832e-02,   8.00781250e-02],
                        [  6.01501465e-02,   5.99975586e-02],
                        [  3.92456055e-02,   3.91845703e-02],
                        [  3.03955078e-02,   3.04870605e-02],
                        [  3.62243652e-02,   3.64685059e-02],
                        [  4.72106934e-02,   4.75158691e-02],
                        [  5.21240234e-02,   5.24597168e-02],
                        [  4.76684570e-02,   4.79125977e-02],
                        [  3.79943848e-02,   3.81469727e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  2.57568359e-02,   2.56347656e-02],
                        [  2.59094238e-02,   2.56652832e-02],
                        [  2.60009766e-02,   2.57263184e-02],
                        [  2.22167969e-02,   2.19421387e-02],
                        [  1.38854980e-02,   1.37023926e-02],
                        [  3.75366211e-03,   3.63159180e-03],
                        [ -6.68334961e-03,  -6.71386719e-03],
                        [ -1.86157227e-02,  -1.85546875e-02],
                        [ -3.16467285e-02,  -3.15856934e-02],
                        [ -4.12292480e-02,  -4.11376953e-02],
                        [ -4.05273438e-02,  -4.04663086e-02],
                        [ -2.38952637e-02,  -2.38342285e-02],
                        [  9.52148438e-03,   9.58251953e-03],
                        [  5.14221191e-02,   5.14526367e-02],
                        [  8.52355957e-02,   8.53271484e-02],
                        [  9.65576172e-02,   9.66796875e-02],
                        [  8.63037109e-02,   8.64868164e-02],
                        [  7.06481934e-02,   7.08312988e-02],
                        [  6.30493164e-02,   6.32019043e-02],
                        [  6.13708496e-02,   6.14318848e-02],
                        [  5.49011230e-02,   5.48400879e-02],
                        [  3.91235352e-02,   3.89099121e-02],
                        [  1.98364258e-02,   1.94702148e-02],
                        [  6.25610352e-03,   5.79833984e-03],
                        [  1.77001953e-03,   1.31225586e-03],
                        [  1.58691406e-03,   1.19018555e-03],
                        [ -7.62939453e-04,  -9.46044922e-04],
                        [ -6.68334961e-03,  -6.65283203e-03],
                        [ -1.41906738e-02,  -1.38854980e-02],
                        [ -2.10876465e-02,  -2.05688477e-02],
                        [ -2.40783691e-02,  -2.34375000e-02],
                        [ -1.92260742e-02,  -1.85241699e-02],
                        [ -8.39233398e-03,  -7.81250000e-03],
                        [ -3.96728516e-04,  -9.15527344e-05],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -2.89916992e-03,  -3.23486328e-03],
                        [ -2.83813477e-03,  -3.44848633e-03],
                        [ -1.61743164e-03,  -2.41088867e-03],
                        [ -3.08227539e-03,  -3.87573242e-03],
                        [ -6.22558594e-03,  -6.89697266e-03],
                        [ -6.80541992e-03,  -7.23266602e-03],
                        [ -2.99072266e-03,  -3.05175781e-03],
                        [  4.08935547e-03,   4.39453125e-03],
                        [  1.45568848e-02,   1.51977539e-02],
                        [  3.02734375e-02,   3.10974121e-02],
                        [  4.98352051e-02,   5.06896973e-02],
                        [  6.69555664e-02,   6.76574707e-02],
                        [  7.31201172e-02,   7.35473633e-02],
                        [  5.95092773e-02,   5.96008301e-02],
                        [  1.95922852e-02,   1.92871094e-02],
                        [ -4.57153320e-02,  -4.63256836e-02],
                        [ -1.24969482e-01,  -1.25762939e-01],
                        [ -1.99951172e-01,  -2.00775146e-01],
                        [ -2.52197266e-01,  -2.52899170e-01],
                        [ -2.68920898e-01,  -2.69348145e-01],
                        [ -2.48596191e-01,  -2.48687744e-01],
                        [ -2.04223633e-01,  -2.03948975e-01],
                        [ -1.57440186e-01,  -1.56890869e-01],
                        [ -1.24786377e-01,  -1.24084473e-01],
                        [ -1.08154297e-01,  -1.07421875e-01],
                        [ -9.92431641e-02,  -9.86328125e-02],
                        [ -9.17053223e-02,  -9.13391113e-02],
                        [ -8.49304199e-02,  -8.48388672e-02],
                        [ -7.76672363e-02,  -7.78503418e-02],
                        [ -6.60400391e-02,  -6.64367676e-02],
                        [ -5.08117676e-02,  -5.13305664e-02],
                        [ -3.81469727e-02,  -3.86657715e-02],
                        [ -2.94189453e-02,  -2.98767090e-02],
                        [ -1.89514160e-02,  -1.92565918e-02],
                        [ -3.20434570e-03,  -3.35693359e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  2.61535645e-02,   2.62756348e-02],
                        [  2.95715332e-02,   2.97546387e-02],
                        [  2.48413086e-02,   2.50549316e-02],
                        [  1.48925781e-02,   1.51062012e-02],
                        [  3.90625000e-03,   4.11987305e-03],
                        [ -2.44140625e-03,  -2.19726562e-03],
                        [  1.19018555e-03,   1.49536133e-03],
                        [  1.49841309e-02,   1.53198242e-02],
                        [  3.41186523e-02,   3.44238281e-02],
                        [  5.54809570e-02,   5.57556152e-02],
                        [  8.06884766e-02,   8.08105469e-02],
                        [  1.08520508e-01,   1.08428955e-01],
                        [  1.30615234e-01,   1.30249023e-01],
                        [  1.37725830e-01,   1.37084961e-01],
                        [  1.25762939e-01,   1.24908447e-01],
                        [  9.32922363e-02,   9.23767090e-02],
                        [  4.02221680e-02,   3.94287109e-02],
                        [ -2.70690918e-02,  -2.75878906e-02],
                        [ -9.08203125e-02,  -9.09118652e-02],
                        [ -1.24572754e-01,  -1.24145508e-01],
                        [ -1.08947754e-01,  -1.08093262e-01],
                        [ -5.14221191e-02,  -5.02014160e-02],
                        [  1.33666992e-02,   1.47399902e-02],
                        [  4.84619141e-02,   4.97436523e-02],
                        [  4.30908203e-02,   4.39758301e-02],
                        [  1.78222656e-02,   1.81884766e-02],
                        [  1.80053711e-03,   1.55639648e-03],
                        [  4.76074219e-03,   3.93676758e-03],
                        [  1.48010254e-02,   1.35498047e-02],
                        [  2.03552246e-02,   1.88903809e-02],
                        [  2.46887207e-02,   2.32543945e-02],
                        [  3.57666016e-02,   3.46069336e-02],
                        [  5.18493652e-02,   5.11779785e-02],
                        [  6.39343262e-02,   6.38122559e-02],
                        [  6.70166016e-02,   6.74438477e-02],
                        [  6.19812012e-02,   6.28967285e-02],
                        [  5.17578125e-02,   5.29785156e-02],
                        [  4.11071777e-02,   4.24499512e-02],
                        [  3.59802246e-02,   3.72314453e-02],
                        [  3.93981934e-02,   4.03747559e-02],
                        [  4.72412109e-02,   4.78210449e-02],
                        [  4.95605469e-02,   4.96826172e-02],
                        [  4.02221680e-02,   3.98559570e-02],
                        [  2.52075195e-02,   2.44445801e-02],
                        [  1.55639648e-02,   1.45263672e-02],
                        [  1.42517090e-02,   1.30920410e-02],
                        [  1.64184570e-02,   1.53198242e-02],
                        [  1.76696777e-02,   1.68151855e-02],
                        [  1.74560547e-02,   1.69677734e-02],
                        [  1.71203613e-02,   1.70898438e-02],
                        [  1.72119141e-02,   1.76391602e-02],
                        [  1.54113770e-02,   1.62048340e-02],
                        [  7.72094727e-03,   8.66699219e-03],
                        [ -7.90405273e-03,  -6.98852539e-03],
                        [ -2.89916992e-02,  -2.82897949e-02],
                        [ -4.86450195e-02,  -4.83398438e-02],
                        [ -5.64880371e-02,  -5.66101074e-02],
                        [ -4.19311523e-02,  -4.24499512e-02],
                        [ -2.71606445e-03,  -3.41796875e-03],
                        [  4.87976074e-02,   4.80957031e-02],
                        [  9.18579102e-02,   9.14611816e-02],
                        [  1.11328125e-01,   1.11389160e-01],
                        [  1.05041504e-01,   1.05590820e-01],
                        [  8.32214355e-02,   8.41674805e-02],
                        [  6.14929199e-02,   6.25610352e-02],
                        [  4.84313965e-02,   4.92858887e-02],
                        [  3.96728516e-02,   3.99475098e-02],
                        [  2.72216797e-02,   2.67028809e-02],
                        [  1.16882324e-02,   1.03454590e-02],
                        [  1.95312500e-03,   0.00000000e+00],
                        [  3.93676758e-03,   1.73950195e-03],
                        [  1.22985840e-02,   1.04675293e-02],
                        [  1.57775879e-02,   1.48010254e-02],
                        [  8.02612305e-03,   8.30078125e-03],
                        [ -8.11767578e-03,  -6.46972656e-03],
                        [ -2.37731934e-02,  -2.09655762e-02],
                        [ -2.99072266e-02,  -2.64892578e-02],
                        [ -2.49023438e-02,  -2.16064453e-02],
                        [ -1.55639648e-02,  -1.32141113e-02],
                        [ -8.30078125e-03,  -7.47680664e-03],
                        [ -1.98364258e-03,  -3.05175781e-03],
                        [  7.75146484e-03,   4.91333008e-03],
                        [  2.03247070e-02,   1.62963867e-02],
                        [  2.92663574e-02,   2.49023438e-02],
                        [  2.94189453e-02,   2.56652832e-02],
                        [  2.16369629e-02,   1.94091797e-02],
                        [  1.04064941e-02,   1.02233887e-02],
                        [  1.95312500e-03,   3.90625000e-03],
                        [  3.47900391e-03,   7.14111328e-03],
                        [  1.79748535e-02,   2.25219727e-02],
                        [  4.10156250e-02,   4.54101562e-02],
                        [  6.48498535e-02,   6.81152344e-02],
                        [  8.07800293e-02,   8.21838379e-02],
                        [  7.69042969e-02,   7.62023926e-02],
                        [  4.14123535e-02,   3.88183594e-02],
                        [ -2.67333984e-02,  -3.05175781e-02],
                        [ -1.11633301e-01,  -1.15753174e-01],
                        [ -1.89422607e-01,  -1.92901611e-01],
                        [ -2.40936279e-01,  -2.43011475e-01],
                        [ -2.56683350e-01,  -2.56988525e-01],
                        [ -2.38800049e-01,  -2.37426758e-01],
                        [ -2.02392578e-01,  -1.99829102e-01],
                        [ -1.67083740e-01,  -1.64001465e-01],
                        [ -1.43066406e-01,  -1.40258789e-01],
                        [ -1.27899170e-01,  -1.25946045e-01],
                        [ -1.14196777e-01,  -1.13403320e-01],
                        [ -9.81750488e-02,  -9.86022949e-02],
                        [ -8.23974609e-02,  -8.36486816e-02],
                        [ -7.03125000e-02,  -7.19604492e-02],
                        [ -6.10351562e-02,  -6.25915527e-02],
                        [ -5.01098633e-02,  -5.12084961e-02],
                        [ -3.38134766e-02,  -3.43017578e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [  7.14111328e-03,   7.38525391e-03],
                        [  2.07214355e-02,   2.08740234e-02],
                        [  2.59704590e-02,   2.58789062e-02],
                        [  2.33764648e-02,   2.29492188e-02],
                        [  1.49230957e-02,   1.43432617e-02],
                        [  5.24902344e-03,   4.85229492e-03],
                        [ -8.85009766e-04,  -7.93457031e-04],
                        [ -2.86865234e-03,  -2.04467773e-03],
                        [ -2.44140625e-03,  -7.93457031e-04],
                        [  1.40380859e-03,   3.57055664e-03],
                        [  1.18408203e-02,   1.40380859e-02],
                        [  2.88696289e-02,   3.05480957e-02],
                        [  4.93774414e-02,   4.99572754e-02],
                        [  7.08923340e-02,   7.00378418e-02],
                        [  9.07592773e-02,   8.84704590e-02],
                        [  1.05957031e-01,   1.02630615e-01],
                        [  1.17889404e-01,   1.14196777e-01],
                        [  1.29364014e-01,   1.26129150e-01],
                        [  1.34918213e-01,   1.32934570e-01],
                        [  1.21917725e-01,   1.21704102e-01],
                        [  8.13598633e-02,   8.30383301e-02],
                        [  1.62048340e-02,   1.94396973e-02],
                        [ -5.54504395e-02,  -5.13305664e-02],
                        [ -1.05712891e-01,  -1.01623535e-01],
                        [ -1.13006592e-01,  -1.09832764e-01],
                        [ -7.87353516e-02,  -7.71179199e-02],
                        [ -2.78625488e-02,  -2.81066895e-02],
                        [  1.03149414e-02,   8.36181641e-03],
                        [  2.47802734e-02,   2.16369629e-02],
                        [  2.58483887e-02,   2.22473145e-02],
                        [  2.73132324e-02,   2.40478516e-02],
                        [  3.07312012e-02,   2.84423828e-02],
                        [  2.95715332e-02,   2.86254883e-02],
                        [  2.27050781e-02,   2.31018066e-02],
                        [  1.62963867e-02,   1.77612305e-02],
                        [  1.53808594e-02,   1.74255371e-02],
                        [  2.07214355e-02,   2.28271484e-02],
                        [  3.16162109e-02,   3.33557129e-02],
                        [  4.51354980e-02,   4.62341309e-02],
                        [  5.64270020e-02,   5.68237305e-02],
                        [  6.29577637e-02,   6.28051758e-02],
                        [  6.45446777e-02,   6.39953613e-02],
                        [  6.04248047e-02,   5.97229004e-02],
                        [  5.10253906e-02,   5.03540039e-02],
                        [  3.95507812e-02,   3.90319824e-02],
                        [  3.05175781e-02,   3.01208496e-02],
                        [  2.74658203e-02,   2.71911621e-02],
                        [  2.98461914e-02,   2.96630859e-02],
                        [  3.17077637e-02,   3.16467285e-02],
                        [  2.78930664e-02,   2.80151367e-02],
                        [  2.03247070e-02,   2.06298828e-02],
                        [  1.40991211e-02,   1.46179199e-02],
                        [  9.91821289e-03,   1.05285645e-02],
                        [  4.21142578e-03,   4.76074219e-03],
                        [ -4.27246094e-03,  -4.02832031e-03],
                        [ -1.27258301e-02,  -1.30310059e-02],
                        [ -1.90734863e-02,  -2.00195312e-02],
                        [ -2.36206055e-02,  -2.51770020e-02],
                        [ -2.63061523e-02,  -2.81372070e-02],
                        [ -2.46582031e-02,  -2.63061523e-02],
                        [ -1.42822266e-02,  -1.51672363e-02],
                        [  9.00268555e-03,   9.33837891e-03],
                        [  4.33044434e-02,   4.51354980e-02],
                        [  7.74230957e-02,   8.05664062e-02],
                        [  9.71069336e-02,   1.01043701e-01],
                        [  9.57641602e-02,   9.96398926e-02],
                        [  7.91931152e-02,   8.20007324e-02],
                        [  6.01501465e-02,   6.10656738e-02],
                        [  4.70275879e-02,   4.55017090e-02],
                        [  3.89709473e-02,   3.50646973e-02],
                        [  3.20434570e-02,   2.63671875e-02],
                        [  2.54211426e-02,   1.91650391e-02],
                        [  2.11486816e-02,   1.56555176e-02],
                        [  1.98974609e-02,   1.65100098e-02],
                        [  1.74255371e-02,   1.70593262e-02],
                        [  7.29370117e-03,   1.01623535e-02],
                        [ -1.03759766e-02,  -4.76074219e-03],
                        [ -2.67639160e-02,  -1.95922852e-02],
                        [ -3.36914062e-02,  -2.64892578e-02],
                        [ -3.11889648e-02,  -2.55432129e-02],
                        [ -2.48413086e-02,  -2.20031738e-02],
                        [ -1.86462402e-02,  -1.91650391e-02],
                        [ -1.33666992e-02,  -1.70898438e-02],
                        [ -8.17871094e-03,  -1.41601562e-02],
                        [ -7.32421875e-04,  -7.50732422e-03],
                        [  1.06811523e-02,   4.57763672e-03],
                        [  2.23693848e-02,   1.82800293e-02],
                        [  2.72827148e-02,   2.59094238e-02],
                        [  2.22778320e-02,   2.37121582e-02],
                        [  1.18103027e-02,   1.53503418e-02],
                        [  4.63867188e-03,   9.27734375e-03],
                        [  6.95800781e-03,   1.14440918e-02],
                        [  1.80358887e-02,   2.13623047e-02],
                        [  3.44543457e-02,   3.59802246e-02],
                        [  5.25207520e-02,   5.22155762e-02],
                        [  6.37817383e-02,   6.20727539e-02],
                        [  5.61828613e-02,   5.38635254e-02],
                        [  2.43835449e-02,   2.22778320e-02],
                        [ -2.78930664e-02,  -2.91442871e-02],
                        [ -9.46655273e-02,  -9.47875977e-02],
                        [ -1.66809082e-01,  -1.65954590e-01],
                        [ -2.26135254e-01,  -2.24792480e-01],
                        [ -2.53112793e-01,  -2.51922607e-01],
                        [ -2.44293213e-01,  -2.43865967e-01],
                        [ -2.15209961e-01,  -2.15820312e-01],
                        [ -1.84020996e-01,  -1.85607910e-01],
                        [ -1.58142090e-01,  -1.60308838e-01],
                        [ -1.35162354e-01,  -1.37268066e-01],
                        [ -1.10839844e-01,  -1.12213135e-01],
                        [ -8.56018066e-02,  -8.57543945e-02],
                        [ -6.45751953e-02,  -6.33239746e-02],
                        [ -5.20935059e-02,  -4.96826172e-02],
                        [ -4.92553711e-02,  -4.62036133e-02],
                        [ -5.28869629e-02,  -4.99572754e-02],
                        [ -5.44433594e-02,  -5.23376465e-02],
                        [ -4.54101562e-02,  -4.45861816e-02],
                        [ -2.75573730e-02,  -2.82287598e-02],
                        [ -1.07421875e-02,  -1.26647949e-02],
                        [  6.10351562e-04,  -2.13623047e-03],
                        [  9.27734375e-03,   6.34765625e-03],
                        [  1.53503418e-02,   1.28479004e-02],
                        [  1.52587891e-02,   1.36413574e-02],
                        [  1.01928711e-02,   9.64355469e-03],
                        [  5.64575195e-03,   6.13403320e-03],
                        [  3.23486328e-03,   4.54711914e-03],
                        [  6.71386719e-04,   2.50244141e-03],
                        [ -1.25122070e-03,   7.93457031e-04],
                        [  2.19726562e-03,   4.21142578e-03],
                        [  1.38549805e-02,   1.56555176e-02],
                        [  3.17382812e-02,   3.31726074e-02],
                        [  5.13610840e-02,   5.23071289e-02],
                        [  6.98547363e-02,   7.01293945e-02],
                        [  8.84094238e-02,   8.78601074e-02],
                        [  1.10015869e-01,   1.08551025e-01],
                        [  1.33728027e-01,   1.31286621e-01],
                        [  1.51947021e-01,   1.48773193e-01],
                        [  1.53320312e-01,   1.49871826e-01],
                        [  1.27868652e-01,   1.24755859e-01],
                        [  7.47680664e-02,   7.27539062e-02],
                        [  8.54492188e-03,   8.23974609e-03],
                        [ -4.68139648e-02,  -4.50134277e-02],
                        [ -7.28149414e-02,  -6.90307617e-02],
                        [ -6.73522949e-02,  -6.21643066e-02],
                        [ -4.40368652e-02,  -3.84521484e-02],
                        [ -2.09655762e-02,  -1.61743164e-02],
                        [ -6.98852539e-03,  -4.15039062e-03],
                        [  6.40869141e-04,   7.93457031e-04],
                        [  6.83593750e-03,   4.08935547e-03],
                        [  1.08032227e-02,   5.67626953e-03],
                        [  9.03320312e-03,   2.65502930e-03],
                        [  2.96020508e-03,  -3.29589844e-03],
                        [ -3.66210938e-04,  -5.09643555e-03],
                        [  4.57763672e-03,   2.38037109e-03],
                        [  1.67236328e-02,   1.74865723e-02],
                        [  3.07922363e-02,   3.41186523e-02],
                        [  4.17785645e-02,   4.67529297e-02],
                        [  4.85229492e-02,   5.38024902e-02],
                        [  5.32836914e-02,   5.76171875e-02],
                        [  5.76171875e-02,   6.00585938e-02],
                        [  5.84411621e-02,   5.86853027e-02],
                        [  5.13916016e-02,   4.98046875e-02],
                        [  3.76892090e-02,   3.50952148e-02],
                        [  2.42614746e-02,   2.17590332e-02],
                        [  1.58691406e-02,   1.44348145e-02],
                        [  1.14440918e-02,   1.15051270e-02],
                        [  1.01013184e-02,   1.15051270e-02],
                        [  1.37634277e-02,   1.58386230e-02],
                        [  2.07824707e-02,   2.23999023e-02],
                        [  2.34375000e-02,   2.36206055e-02],
                        [  1.59606934e-02,   1.40686035e-02],
                        [  3.96728516e-04,  -3.60107422e-03],
                        [ -1.74865723e-02,  -2.27355957e-02],
                        [ -3.40270996e-02,  -3.92150879e-02],
                        [ -4.76074219e-02,  -5.11779785e-02],
                        [ -5.50842285e-02,  -5.56945801e-02],
                        [ -5.19409180e-02,  -4.88891602e-02],
                        [ -3.45458984e-02,  -2.81372070e-02],
                        [ -1.31225586e-03,   7.26318359e-03],
                        [  4.49829102e-02,   5.38635254e-02],
                        [  9.25903320e-02,   9.96398926e-02],
                        [  1.22222900e-01,   1.25732422e-01],
                        [  1.20361328e-01,   1.19323730e-01],
                        [  9.25598145e-02,   8.70971680e-02],
                        [  6.00891113e-02,   5.14221191e-02],
                        [  4.08935547e-02,   3.09753418e-02],
                        [  3.64379883e-02,   2.74963379e-02],
                        [  3.64074707e-02,   3.03955078e-02],
                        [  3.10974121e-02,   2.91442871e-02],
                        [  1.82189941e-02,   2.04162598e-02],
                        [  4.08935547e-03,   9.52148438e-03],
                        [ -1.19018555e-03,   5.88989258e-03],
                        [  3.84521484e-03,   1.06811523e-02],
                        [  6.71386719e-03,   1.18103027e-02],
                        [ -3.54003906e-03,  -1.00708008e-03],
                        [ -2.05688477e-02,  -2.06604004e-02],
                        [ -2.94799805e-02,  -3.13415527e-02],
                        [ -2.56652832e-02,  -2.80761719e-02],
                        [ -1.70288086e-02,  -1.87988281e-02],
                        [ -1.13830566e-02,  -1.17797852e-02],
                        [ -8.78906250e-03,  -7.78198242e-03],
                        [ -5.34057617e-03,  -3.60107422e-03],
                        [  8.54492188e-04,   2.16674805e-03],
                        [  9.33837891e-03,   8.97216797e-03],
                        [  1.85241699e-02,   1.57165527e-02],
                        [  2.49938965e-02,   1.97448730e-02],
                        [  2.62756348e-02,   1.94702148e-02],
                        [  2.63366699e-02,   1.96228027e-02],
                        [  3.39050293e-02,   2.92053223e-02],
                        [  5.16967773e-02,   5.07202148e-02],
                        [  7.08007812e-02,   7.44628906e-02],
                        [  7.87353516e-02,   8.68530273e-02],
                        [  6.92138672e-02,   8.03527832e-02],
                        [  4.08630371e-02,   5.26428223e-02],
                        [ -6.68334961e-03,   3.08227539e-03],
                        [ -6.99462891e-02,  -6.46057129e-02],
                        [ -1.39282227e-01,  -1.39831543e-01],
                        [ -2.00958252e-01,  -2.07489014e-01],
                        [ -2.40173340e-01,  -2.51403809e-01],
                        [ -2.47192383e-01,  -2.60711670e-01],
                        [ -2.24578857e-01,  -2.37457275e-01],
                        [ -1.87347412e-01,  -1.96777344e-01],
                        [ -1.53106689e-01,  -1.57226562e-01],
                        [ -1.31195068e-01,  -1.29302979e-01],
                        [ -1.19018555e-01,  -1.11816406e-01],
                        [ -1.07360840e-01,  -9.66796875e-02],
                        [ -8.97216797e-02,  -7.79724121e-02],
                        [ -6.87255859e-02,  -5.83801270e-02],
                        [ -5.32836914e-02,  -4.62036133e-02],
                        [ -4.76074219e-02,  -4.47692871e-02],
                        [ -4.62341309e-02,  -4.76074219e-02],
                        [ -4.06188965e-02,  -4.52575684e-02],
                        [ -2.76489258e-02,  -3.42407227e-02],
                        [ -1.08032227e-02,  -1.78833008e-02],
                        [  4.97436523e-03,  -1.43432617e-03],
                        [  1.69677734e-02,   1.19323730e-02],
                        [  2.43530273e-02,   2.09350586e-02],
                        [  2.70690918e-02,   2.51464844e-02],
                        [  2.57873535e-02,   2.51770020e-02],
                        [  2.02636719e-02,   2.08740234e-02],
                        [  9.30786133e-03,   1.12609863e-02],
                        [ -4.21142578e-03,  -7.62939453e-04],
                        [ -1.30920410e-02,  -7.99560547e-03],
                        [ -1.30004883e-02,  -6.46972656e-03],
                        [ -6.46972656e-03,   7.93457031e-04],
                        [  2.19726562e-03,   9.00268555e-03],
                        [  1.24816895e-02,   1.73034668e-02],
                        [  2.65808105e-02,   2.79846191e-02],
                        [  4.53186035e-02,   4.23583984e-02],
                        [  6.81152344e-02,   6.06689453e-02],
                        [  9.56726074e-02,   8.47473145e-02],
                        [  1.30126953e-01,   1.17675781e-01],
                        [  1.70898438e-01,   1.59484863e-01],
                        [  2.09655762e-01,   2.01934814e-01],
                        [  2.28088379e-01,   2.26043701e-01],
                        [  2.04589844e-01,   2.09045410e-01],
                        [  1.31774902e-01,   1.42028809e-01],
                        [  3.07006836e-02,   4.47387695e-02],
                        [ -5.65490723e-02,  -4.17175293e-02],
                        [ -9.51538086e-02,  -8.27636719e-02],
                        [ -8.25195312e-02,  -7.52868652e-02],
                        [ -4.67529297e-02,  -4.61425781e-02],
                        [ -2.09350586e-02,  -2.69165039e-02],
                        [ -1.74255371e-02,  -2.84118652e-02],
                        [ -2.38647461e-02,  -3.72009277e-02],
                        [ -2.24914551e-02,  -3.51257324e-02],
                        [ -1.12915039e-02,  -2.05383301e-02],
                        [ -3.23486328e-03,  -7.44628906e-03],
                        [ -5.88989258e-03,  -4.76074219e-03],
                        [ -1.06201172e-02,  -5.18798828e-03],
                        [ -6.22558594e-03,   1.61743164e-03],
                        [  5.00488281e-03,   1.29699707e-02],
                        [  1.29089355e-02,   1.91040039e-02],
                        [  1.56860352e-02,   1.89819336e-02],
                        [  2.13623047e-02,   2.17895508e-02],
                        [  3.49731445e-02,   3.34472656e-02],
                        [  4.97741699e-02,   4.76989746e-02],
                        [  5.43823242e-02,   5.31616211e-02],
                        [  4.59899902e-02,   4.64782715e-02],
                        [  3.25927734e-02,   3.47595215e-02],
                        [  2.34985352e-02,   2.64282227e-02],
                        [  2.06909180e-02,   2.29797363e-02],
                        [  2.02026367e-02,   2.02941895e-02],
                        [  1.96838379e-02,   1.65710449e-02],
                        [  2.03857422e-02,   1.40380859e-02],
                        [  1.97448730e-02,   1.11389160e-02],
                        [  9.94873047e-03,   1.06811523e-03],
                        [ -1.02844238e-02,  -1.71813965e-02],
                        [ -3.05480957e-02,  -3.33557129e-02],
                        [ -4.09851074e-02,  -3.84826660e-02],
                        [ -4.39758301e-02,  -3.62548828e-02],
                        [ -4.75463867e-02,  -3.60412598e-02],
                        [ -5.04455566e-02,  -3.76281738e-02],
                        [ -4.14428711e-02,  -3.01513672e-02],
                        [ -1.19628906e-02,  -4.85229492e-03],
                        [  3.61633301e-02,   3.75061035e-02],
                        [  9.12475586e-02,   8.66088867e-02],
                        [  1.32995605e-01,   1.23626709e-01],
                        [  1.41265869e-01,   1.29425049e-01],
                        [  1.13739014e-01,   1.02233887e-01],
                        [  7.17163086e-02,   6.30798340e-02],
                        [  4.08935547e-02,   3.67736816e-02],
                        [  2.92053223e-02,   2.99987793e-02],
                        [  2.79235840e-02,   3.28063965e-02],
                        [  2.75268555e-02,   3.46679688e-02],
                        [  2.49633789e-02,   3.22265625e-02],
                        [  2.05078125e-02,   2.60314941e-02],
                        [  1.51062012e-02,   1.77612305e-02],
                        [  9.61303711e-03,   9.36889648e-03],
                        [  3.78417969e-03,   1.46484375e-03],
                        [ -3.50952148e-03,  -6.40869141e-03],
                        [ -1.24816895e-02,  -1.44958496e-02],
                        [ -2.13928223e-02,  -2.14843750e-02],
                        [ -2.67028809e-02,  -2.46276855e-02],
                        [ -2.53906250e-02,  -2.18200684e-02],
                        [ -1.69067383e-02,  -1.31530762e-02],
                        [ -3.96728516e-03,  -1.61743164e-03],
                        [  7.93457031e-03,   7.56835938e-03],
                        [  1.43737793e-02,   1.07421875e-02],
                        [  1.69677734e-02,   1.05590820e-02],
                        [  2.16979980e-02,   1.38244629e-02],
                        [  3.10668945e-02,   2.36206055e-02],
                        [  4.10156250e-02,   3.59802246e-02],
                        [  4.77294922e-02,   4.66003418e-02],
                        [  5.41992188e-02,   5.75256348e-02],
                        [  6.63146973e-02,   7.35473633e-02],
                        [  8.37707520e-02,   9.33837891e-02],
                        [  9.68017578e-02,   1.06658936e-01],
                        [  9.08508301e-02,   9.87548828e-02],
                        [  5.58166504e-02,   6.00891113e-02],
                        [ -7.01904297e-03,  -7.23266602e-03],
                        [ -8.67004395e-02,  -9.11865234e-02],
                        [ -1.69067383e-01,  -1.76635742e-01],
                        [ -2.38220215e-01,  -2.47100830e-01],
                        [ -2.76062012e-01,  -2.84332275e-01],
                        [ -2.71301270e-01,  -2.77374268e-01],
                        [ -2.33520508e-01,  -2.36419678e-01],
                        [ -1.89941406e-01,  -1.89453125e-01],
                        [ -1.60430908e-01,  -1.57135010e-01],
                        [ -1.42639160e-01,  -1.37542725e-01],
                        [ -1.25854492e-01,  -1.20147705e-01],
                        [ -1.08062744e-01,  -1.02813721e-01],
                        [ -9.27124023e-02,  -8.86535645e-02],
                        [ -7.93151855e-02,  -7.68432617e-02],
                        [ -6.44226074e-02,  -6.35375977e-02],
                        [ -4.69665527e-02,  -4.74853516e-02],
                        [ -2.93884277e-02,  -3.09753418e-02],
                        [ -1.51977539e-02,  -1.76696777e-02],
                        [ -7.44628906e-03,  -1.05590820e-02],
                        [ -6.31713867e-03,  -9.82666016e-03],
                        [ -7.01904297e-03,  -1.05895996e-02],
                        [ -4.02832031e-03,  -7.26318359e-03],
                        [  1.83105469e-03,  -4.88281250e-04],
                        [  5.00488281e-03,   4.11987305e-03],
                        [  4.36401367e-03,   5.34057617e-03],
                        [  5.31005859e-03,   8.23974609e-03],
                        [  1.00097656e-02,   1.44958496e-02],
                        [  1.20849609e-02,   1.73645020e-02],
                        [  6.22558594e-03,   1.11999512e-02],
                        [ -3.87573242e-03,  -3.35693359e-04],
                        [ -1.21765137e-02,  -1.09558105e-02],
                        [ -1.64794922e-02,  -1.79748535e-02],
                        [ -1.36413574e-02,  -1.75476074e-02],
                        [  1.92260742e-03,  -3.50952148e-03],
                        [  2.97546387e-02,   2.40783691e-02],
                        [  6.27136230e-02,   5.81665039e-02],
                        [  9.83276367e-02,   9.59777832e-02],
                        [  1.41876221e-01,   1.42181396e-01],
                        [  1.94580078e-01,   1.97204590e-01],
                        [  2.45239258e-01,   2.49298096e-01],
                        [  2.73590088e-01,   2.77801514e-01],
                        [  2.57415771e-01,   2.60528564e-01],
                        [  1.85272217e-01,   1.86462402e-01],
                        [  7.25708008e-02,   7.17163086e-02],
                        [ -4.09545898e-02,  -4.33044434e-02],
                        [ -1.16577148e-01,  -1.19262695e-01],
                        [ -1.39068604e-01,  -1.40777588e-01],
                        [ -1.19110107e-01,  -1.18865967e-01],
                        [ -8.09020996e-02,  -7.83691406e-02],
                        [ -4.53796387e-02,  -4.11071777e-02],
                        [ -2.06604004e-02,  -1.59301758e-02],
                        [ -5.52368164e-03,  -2.01416016e-03],
                        [  6.71386719e-04,   1.31225586e-03],
                        [ -4.73022461e-03,  -7.90405273e-03],
                        [ -2.02941895e-02,  -2.71911621e-02],
                        [ -3.55834961e-02,  -4.50439453e-02],
                        [ -3.88183594e-02,  -4.86145020e-02],
                        [ -2.79235840e-02,  -3.54919434e-02],
                        [ -1.11389160e-02,  -1.41601562e-02],
                        [  4.66918945e-03,   7.56835938e-03],
                        [  2.16674805e-02,   3.05175781e-02],
                        [  4.33654785e-02,   5.65795898e-02],
                        [  6.37512207e-02,   7.86132812e-02],
                        [  7.20214844e-02,   8.51135254e-02],
                        [  6.46667480e-02,   7.29064941e-02],
                        [  4.85839844e-02,   4.98046875e-02],
                        [  3.38745117e-02,   2.75268555e-02],
                        [  2.50549316e-02,   1.23596191e-02],
                        [  1.80969238e-02,   1.80053711e-03],
                        [  7.01904297e-03,  -9.33837891e-03],
                        [ -8.05664062e-03,  -2.09045410e-02],
                        [ -2.14843750e-02,  -2.81066895e-02],
                        [ -2.85949707e-02,  -2.77099609e-02],
                        [ -2.82592773e-02,  -2.03552246e-02],
                        [ -2.33154297e-02,  -1.04675293e-02],
                        [ -2.04162598e-02,  -5.64575195e-03],
                        [ -2.44750977e-02,  -1.10473633e-02],
                        [ -3.28369141e-02,  -2.34680176e-02],
                        [ -3.77807617e-02,  -3.41186523e-02],
                        [ -3.14331055e-02,  -3.35998535e-02],
                        [ -6.86645508e-03,  -1.37329102e-02],
                        [  3.61022949e-02,   2.66113281e-02],
                        [  8.34960938e-02,   7.37915039e-02],
                        [  1.14166260e-01,   1.06384277e-01],
                        [  1.16546631e-01,   1.11999512e-01],
                        [  9.57031250e-02,   9.48181152e-02],
                        [  6.65893555e-02,   6.87866211e-02],
                        [  4.19616699e-02,   4.61120605e-02],
                        [  2.62451172e-02,   3.09448242e-02],
                        [  1.76696777e-02,   2.16674805e-02],
                        [  1.38244629e-02,   1.63574219e-02],
                        [  1.40380859e-02,   1.48620605e-02],
                        [  1.80053711e-02,   1.74255371e-02],
                        [  2.38342285e-02,   2.24304199e-02],
                        [  2.67639160e-02,   2.51464844e-02],
                        [  2.00500488e-02,   1.87072754e-02],
                        [  7.32421875e-04,  -9.15527344e-05],
                        [ -2.41088867e-02,  -2.43835449e-02],
                        [ -4.09851074e-02,  -4.08325195e-02],
                        [ -4.11987305e-02,  -4.07409668e-02],
                        [ -2.58178711e-02,  -2.50549316e-02],
                        [ -3.44848633e-03,  -2.38037109e-03],
                        [  1.39160156e-02,   1.53808594e-02],
                        [  1.88293457e-02,   2.06604004e-02],
                        [  1.47705078e-02,   1.67236328e-02],
                        [  1.21765137e-02,   1.37329102e-02],
                        [  1.83410645e-02,   1.88598633e-02],
                        [  3.36914062e-02,   3.25317383e-02],
                        [  5.53283691e-02,   5.21850586e-02],
                        [  8.04748535e-02,   7.54394531e-02],
                        [  1.04797363e-01,   9.86328125e-02],
                        [  1.20819092e-01,   1.14807129e-01],
                        [  1.20147705e-01,   1.15814209e-01],
                        [  9.89074707e-02,   9.76867676e-02],
                        [  6.03027344e-02,   6.31103516e-02],
                        [  6.77490234e-03,   1.36413574e-02],
                        [ -6.63757324e-02,  -5.65185547e-02],
                        [ -1.57012939e-01,  -1.46057129e-01],
                        [ -2.39868164e-01,  -2.30194092e-01],
                        [ -2.81219482e-01,  -2.75177002e-01],
                        [ -2.69989014e-01,  -2.69256592e-01],
                        [ -2.25891113e-01,  -2.30957031e-01],
                        [ -1.81091309e-01,  -1.91162109e-01],
                        [ -1.56585693e-01,  -1.69616699e-01],
                        [ -1.49749756e-01,  -1.62933350e-01],
                        [ -1.42639160e-01,  -1.53106689e-01],
                        [ -1.23962402e-01,  -1.29394531e-01],
                        [ -9.97619629e-02,  -9.90600586e-02],
                        [ -8.19396973e-02,  -7.54089355e-02],
                        [ -7.26013184e-02,  -6.19201660e-02],
                        [ -6.48803711e-02,  -5.25512695e-02],
                        [ -5.33142090e-02,  -4.21447754e-02],
                        [ -3.81164551e-02,  -3.04260254e-02],
                        [ -2.32543945e-02,  -2.03552246e-02],
                        [ -1.23291016e-02,  -1.43127441e-02],
                        [ -3.81469727e-03,  -9.58251953e-03],
                        [  6.28662109e-03,  -1.43432617e-03],
                        [  1.64184570e-02,   8.88061523e-03],
                        [  2.20947266e-02,   1.63879395e-02],
                        [  2.33459473e-02,   2.03247070e-02],
                        [  2.15148926e-02,   2.11791992e-02],
                        [  1.43432617e-02,   1.58386230e-02],
                        [  2.68554688e-03,   4.76074219e-03],
                        [ -5.67626953e-03,  -4.11987305e-03],
                        [ -5.98144531e-03,  -5.55419922e-03],
                        [ -2.68554688e-03,  -3.29589844e-03],
                        [ -1.37329102e-03,  -2.22778320e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -4.76074219e-03,  -2.89916992e-03],
                        [ -3.08227539e-03,   1.03759766e-03],
                        [  1.43127441e-02,   2.02331543e-02],
                        [  5.92346191e-02,   6.55822754e-02],
                        [  1.30279541e-01,   1.35162354e-01],
                        [  2.11425781e-01,   2.13012695e-01],
                        [  2.82348633e-01,   2.79296875e-01],
                        [  3.25988770e-01,   3.18206787e-01],
                        [  3.29345703e-01,   3.18023682e-01],
                        [  2.83477783e-01,   2.71026611e-01],
                        [  1.88262939e-01,   1.77764893e-01],
                        [  5.87158203e-02,   5.31311035e-02],
                        [ -7.26318359e-02,  -7.12890625e-02],
                        [ -1.64733887e-01,  -1.56097412e-01],
                        [ -1.90246582e-01,  -1.75750732e-01],
                        [ -1.56494141e-01,  -1.39129639e-01],
                        [ -1.01348877e-01,  -8.51440430e-02],
                        [ -6.06689453e-02,  -4.95910645e-02],
                        [ -4.05273438e-02,  -3.75061035e-02],
                        [ -2.62756348e-02,  -3.24401855e-02],
                        [ -1.06201172e-02,  -2.49328613e-02],
                        [ -3.96728516e-04,  -1.98669434e-02],
                        [ -3.14331055e-03,  -2.33764648e-02],
                        [ -1.61743164e-02,  -3.25622559e-02],
                        [ -2.70080566e-02,  -3.57971191e-02],
                        [ -2.32849121e-02,  -2.24304199e-02],
                        [ -4.94384766e-03,   5.34057617e-03],
                        [  1.74865723e-02,   3.48510742e-02],
                        [  3.67126465e-02,   5.71899414e-02],
                        [  5.28869629e-02,   7.18688965e-02],
                        [  6.44836426e-02,   7.78808594e-02],
                        [  6.41784668e-02,   6.92749023e-02],
                        [  4.86755371e-02,   4.47692871e-02],
                        [  2.59094238e-02,   1.43432617e-02],
                        [  7.23266602e-03,  -8.94165039e-03],
                        [ -2.96020508e-03,  -1.99279785e-02],
                        [ -7.56835938e-03,  -2.16064453e-02],
                        [ -1.04980469e-02,  -1.87988281e-02],
                        [ -1.26342773e-02,  -1.40380859e-02],
                        [ -1.38244629e-02,  -8.78906250e-03],
                        [ -1.64794922e-02,  -6.92749023e-03],
                        [ -2.22167969e-02,  -1.08947754e-02],
                        [ -2.70690918e-02,  -1.68151855e-02],
                        [ -2.79235840e-02,  -2.08740234e-02],
                        [ -2.85949707e-02,  -2.59399414e-02],
                        [ -3.25317383e-02,  -3.41186523e-02],
                        [ -3.43322754e-02,  -3.89709473e-02],
                        [ -2.35595703e-02,  -2.94494629e-02],
                        [  7.01904297e-03,   1.80053711e-03],
                        [  5.44128418e-02,   5.13305664e-02],
                        [  1.02111816e-01,   1.01806641e-01],
                        [  1.28692627e-01,   1.31011963e-01],
                        [  1.25152588e-01,   1.29058838e-01],
                        [  1.00250244e-01,   1.04370117e-01],
                        [  6.99462891e-02,   7.29370117e-02],
                        [  4.64477539e-02,   4.71801758e-02],
                        [  3.38745117e-02,   3.20129395e-02],
                        [  2.87475586e-02,   2.45666504e-02],
                        [  2.56347656e-02,   1.99890137e-02],
                        [  2.29187012e-02,   1.70288086e-02],
                        [  2.00195312e-02,   1.52282715e-02],
                        [  1.34582520e-02,   1.08032227e-02],
                        [  1.06811523e-03,   1.22070312e-03],
                        [ -1.38244629e-02,  -1.08032227e-02],
                        [ -2.48718262e-02,  -1.94091797e-02],
                        [ -2.64282227e-02,  -1.93481445e-02],
                        [ -1.68762207e-02,  -9.30786133e-03],
                        [ -1.80053711e-03,   5.03540039e-03],
                        [  8.54492188e-03,   1.36108398e-02],
                        [  8.81958008e-03,   1.12304688e-02],
                        [  4.02832031e-03,   3.29589844e-03],
                        [  3.47900391e-03,  -4.57763672e-04],
                        [  1.15356445e-02,   4.79125977e-03],
                        [  2.55737305e-02,   1.69067383e-02],
                        [  4.07409668e-02,   3.13415527e-02],
                        [  5.67626953e-02,   4.80957031e-02],
                        [  7.83386230e-02,   7.17773438e-02],
                        [  1.05194092e-01,   1.02050781e-01],
                        [  1.27288818e-01,   1.28204346e-01],
                        [  1.31835938e-01,   1.36962891e-01],
                        [  1.10534668e-01,   1.19232178e-01],
                        [  6.18286133e-02,   7.26928711e-02],
                        [ -7.75146484e-03,   3.54003906e-03],
                        [ -8.76159668e-02,  -7.79113770e-02],
                        [ -1.69219971e-01,  -1.62841797e-01],
                        [ -2.40783691e-01,  -2.38922119e-01],
                        [ -2.82135010e-01,  -2.85095215e-01],
                        [ -2.76458740e-01,  -2.83721924e-01],
                        [ -2.29095459e-01,  -2.39257812e-01],
                        [ -1.68243408e-01,  -1.79412842e-01],
                        [ -1.24206543e-01,  -1.34338379e-01],
                        [ -1.08825684e-01,  -1.16180420e-01],
                        [ -1.14715576e-01,  -1.18103027e-01],
                        [ -1.25885010e-01,  -1.25030518e-01],
                        [ -1.27136230e-01,  -1.22558594e-01],
                        [ -1.13220215e-01,  -1.06079102e-01],
                        [ -9.24682617e-02,  -8.43505859e-02],
                        [ -7.32421875e-02,  -6.56738281e-02],
                        [ -5.08728027e-02,  -4.50134277e-02],
                        [ -1.91955566e-02,  -1.58081055e-02],
                        [  1.20544434e-02,   1.29699707e-02],
                        [  2.81982422e-02,   2.69775391e-02],
                        [  2.95104980e-02,   2.69165039e-02],
                        [  2.56347656e-02,   2.23999023e-02],
                        [  1.80969238e-02,   1.48925781e-02],
                        [  4.39453125e-03,   1.52587891e-03],
                        [ -1.02233887e-02,  -1.27258301e-02],
                        [ -1.80969238e-02,  -2.03552246e-02],
                        [ -2.06604004e-02,  -2.28271484e-02],
                        [ -2.34680176e-02,  -2.56042480e-02],
                        [ -2.49328613e-02,  -2.68249512e-02],
                        [ -2.05078125e-02,  -2.17895508e-02],
                        [ -1.44653320e-02,  -1.45568848e-02],
                        [ -1.47399902e-02,  -1.32141113e-02],
                        [ -1.94091797e-02,  -1.59912109e-02],
                        [ -1.84936523e-02,  -1.33972168e-02],
                        [ -5.70678711e-03,   3.66210938e-04],
                        [  2.22167969e-02,   2.82592773e-02],
                        [  7.24182129e-02,   7.71179199e-02],
                        [  1.47735596e-01,   1.49963379e-01],
                        [  2.32635498e-01,   2.31567383e-01],
                        [  2.98645020e-01,   2.94128418e-01],
                        [  3.25927734e-01,   3.18542480e-01],
                        [  3.13262939e-01,   3.04260254e-01],
                        [  2.70019531e-01,   2.61138916e-01],
                        [  2.03948975e-01,   1.96990967e-01],
                        [  1.17065430e-01,   1.13647461e-01],
                        [  1.40686035e-02,   1.51367188e-02],
                        [ -8.65478516e-02,  -8.09631348e-02],
                        [ -1.54693604e-01,  -1.45477295e-01],
                        [ -1.67083740e-01,  -1.55944824e-01],
                        [ -1.29241943e-01,  -1.18347168e-01],
                        [ -7.75146484e-02,  -6.90612793e-02],
                        [ -4.91638184e-02,  -4.50134277e-02],
                        [ -4.96215820e-02,  -5.07202148e-02],
                        [ -5.76477051e-02,  -6.39953613e-02],
                        [ -5.69763184e-02,  -6.74743652e-02],
                        [ -4.94995117e-02,  -6.21948242e-02],
                        [ -4.17480469e-02,  -5.41687012e-02],
                        [ -3.32946777e-02,  -4.29687500e-02],
                        [ -2.08129883e-02,  -2.58178711e-02],
                        [ -3.93676758e-03,  -3.20434570e-03],
                        [  1.56860352e-02,   2.21557617e-02],
                        [  3.59191895e-02,   4.69055176e-02],
                        [  5.28259277e-02,   6.62536621e-02],
                        [  6.20117188e-02,   7.52563477e-02],
                        [  6.07910156e-02,   7.13500977e-02],
                        [  4.87365723e-02,   5.45959473e-02],
                        [  2.76794434e-02,   2.77404785e-02],
                        [  2.62451172e-03,  -3.02124023e-03],
                        [ -1.80969238e-02,  -2.82592773e-02],
                        [ -2.66418457e-02,  -3.92761230e-02],
                        [ -2.25830078e-02,  -3.51867676e-02],
                        [ -1.36718750e-02,  -2.38952637e-02],
                        [ -7.93457031e-03,  -1.39770508e-02],
                        [ -8.33129883e-03,  -9.33837891e-03],
                        [ -1.48925781e-02,  -1.09863281e-02],
                        [ -2.62756348e-02,  -1.86462402e-02],
                        [ -4.03137207e-02,  -3.06701660e-02],
                        [ -5.43212891e-02,  -4.47082520e-02],
                        [ -6.41174316e-02,  -5.63049316e-02],
                        [ -6.25000000e-02,  -5.76782227e-02],
                        [ -4.21142578e-02,  -4.06494141e-02],
                        [ -1.19018555e-03,  -2.74658203e-03],
                        [  5.24597168e-02,   4.88281250e-02],
                        [  1.03179932e-01,   9.87243652e-02],
                        [  1.34277344e-01,   1.30065918e-01],
                        [  1.35955811e-01,   1.32720947e-01],
                        [  1.09802246e-01,   1.07696533e-01],
                        [  6.84814453e-02,   6.72302246e-02],
                        [  3.13415527e-02,   3.03649902e-02],
                        [  1.34277344e-02,   1.21154785e-02],
                        [  1.48010254e-02,   1.28479004e-02],
                        [  2.35900879e-02,   2.10876465e-02],
                        [  2.86865234e-02,   2.63061523e-02],
                        [  2.61840820e-02,   2.48413086e-02],
                        [  1.76391602e-02,   1.83105469e-02],
                        [  6.77490234e-03,   1.00708008e-02],
                        [ -4.21142578e-03,   1.80053711e-03],
                        [ -1.50146484e-02,  -7.08007812e-03],
                        [ -2.39562988e-02,  -1.54724121e-02],
                        [ -2.75878906e-02,  -2.04467773e-02],
                        [ -2.41699219e-02,  -2.01721191e-02],
                        [ -1.48315430e-02,  -1.52893066e-02],
                        [ -3.41796875e-03,  -8.75854492e-03],
                        [  4.85229492e-03,  -4.57763672e-03],
                        [  8.81958008e-03,  -3.02124023e-03],
                        [  1.46789551e-02,   2.86865234e-03],
                        [  2.91442871e-02,   1.99890137e-02],
                        [  5.02624512e-02,   4.58068848e-02],
                        [  7.11669922e-02,   7.25402832e-02],
                        [  8.88671875e-02,   9.58557129e-02],
                        [  1.02416992e-01,   1.13525391e-01],
                        [  1.11053467e-01,   1.23779297e-01],
                        [  1.16363525e-01,   1.27899170e-01],
                        [  1.15112305e-01,   1.22863770e-01],
                        [  9.15222168e-02,   9.38415527e-02],
                        [  3.13720703e-02,   2.78625488e-02],
                        [ -5.99060059e-02,  -6.82067871e-02],
                        [ -1.62353516e-01,  -1.73370361e-01],
                        [ -2.56072998e-01,  -2.67059326e-01],
                        [ -3.21319580e-01,  -3.29620361e-01],
                        [ -3.37127686e-01,  -3.40850830e-01],
                        [ -2.97515869e-01,  -2.95959473e-01],
                        [ -2.26745605e-01,  -2.20489502e-01],
                        [ -1.62170410e-01,  -1.52923584e-01],
                        [ -1.21398926e-01,  -1.11633301e-01],
                        [ -9.65881348e-02,  -8.87756348e-02],
                        [ -7.65075684e-02,  -7.26013184e-02],
                        [ -6.20727539e-02,  -6.29882812e-02],
                        [ -5.99975586e-02,  -6.54296875e-02],
                        [ -6.92138672e-02,  -7.77587891e-02],
                        [ -7.73925781e-02,  -8.69140625e-02],
                        [ -7.00073242e-02,  -7.81250000e-02],
                        [ -4.40368652e-02,  -4.88281250e-02],
                        [ -1.28784180e-02,  -1.32446289e-02],
                        [  5.98144531e-03,   1.01013184e-02],
                        [  7.99560547e-03,   1.55639648e-02],
                        [  2.25830078e-03,   1.15661621e-02],
                        [ -1.86157227e-03,   7.08007812e-03],
                        [ -2.28881836e-03,   4.39453125e-03],
                        [ -8.85009766e-04,   2.19726562e-03],
                        [  3.96728516e-04,  -6.10351562e-04],
                        [ -1.46484375e-03,  -6.16455078e-03],
                        [ -1.06201172e-02,  -1.78833008e-02],
                        [ -2.70690918e-02,  -3.53393555e-02],
                        [ -4.29382324e-02,  -5.05981445e-02],
                        [ -4.93469238e-02,  -5.50231934e-02],
                        [ -4.57458496e-02,  -4.85534668e-02],
                        [ -3.66210938e-02,  -3.63464355e-02],
                        [ -1.93786621e-02,  -1.62963867e-02],
                        [  1.56860352e-02,   2.07824707e-02],
                        [  7.15942383e-02,   7.77282715e-02],
                        [  1.38122559e-01,   1.44226074e-01],
                        [  2.00439453e-01,   2.05566406e-01],
                        [  2.48107910e-01,   2.51586914e-01],
                        [  2.74932861e-01,   2.76367188e-01],
                        [  2.77709961e-01,   2.76977539e-01],
                        [  2.60162354e-01,   2.57507324e-01],
                        [  2.34069824e-01,   2.29949951e-01],
                        [  2.07366943e-01,   2.02453613e-01],
                        [  1.71905518e-01,   1.66961670e-01],
                        [  1.12426758e-01,   1.08276367e-01],
                        [  2.70080566e-02,   2.43835449e-02],
                        [ -6.62231445e-02,  -6.68334961e-02],
                        [ -1.38610840e-01,  -1.37084961e-01],
                        [ -1.67968750e-01,  -1.64550781e-01],
                        [ -1.55670166e-01,  -1.51031494e-01],
                        [ -1.24969482e-01,  -1.20025635e-01],
                        [ -9.92736816e-02,  -9.51538086e-02],
                        [ -8.60290527e-02,  -8.36486816e-02],
                        [ -7.98034668e-02,  -7.98339844e-02],
                        [ -7.26318359e-02,  -7.51037598e-02],
                        [ -5.96313477e-02,  -6.40258789e-02],
                        [ -4.04052734e-02,  -4.57153320e-02],
                        [ -1.95312500e-02,  -2.44445801e-02],
                        [ -3.60107422e-03,  -6.80541992e-03],
                        [  6.62231445e-03,   6.07299805e-03],
                        [  1.73950195e-02,   1.98059082e-02],
                        [  3.12194824e-02,   3.61938477e-02],
                        [  4.19006348e-02,   4.83398438e-02],
                        [  4.41589355e-02,   5.05065918e-02],
                        [  4.13208008e-02,   4.59289551e-02],
                        [  3.73229980e-02,   3.88793945e-02],
                        [  2.89306641e-02,   2.67944336e-02],
                        [  1.40075684e-02,   8.48388672e-03],
                        [  9.15527344e-05,  -7.72094727e-03],
                        [ -6.62231445e-03,  -1.49841309e-02],
                        [ -1.11083984e-02,  -1.80053711e-02],
                        [ -1.80358887e-02,  -2.17590332e-02],
                        [ -2.28576660e-02,  -2.23999023e-02],
                        [ -2.49023438e-02,  -2.02026367e-02],
                        [ -3.35083008e-02,  -2.55432129e-02],
                        [ -5.03845215e-02,  -4.08935547e-02],
                        [ -6.16455078e-02,  -5.27648926e-02],
                        [ -5.66406250e-02,  -5.04150391e-02],
                        [ -4.08935547e-02,  -3.87878418e-02],
                        [ -2.30407715e-02,  -2.55432129e-02],
                        [ -1.40380859e-03,  -7.87353516e-03],
                        [  3.01513672e-02,   2.12097168e-02],
                        [  6.94580078e-02,   6.01196289e-02],
                        [  1.04095459e-01,   9.64965820e-02],
                        [  1.19903564e-01,   1.15753174e-01],
                        [  1.10809326e-01,   1.10931396e-01],
                        [  8.34045410e-02,   8.76159668e-02],
                        [  5.51452637e-02,   6.23474121e-02],
                        [  4.27856445e-02,   5.11169434e-02],
                        [  4.59594727e-02,   5.34057617e-02],
                        [  4.75463867e-02,   5.23986816e-02],
                        [  3.50952148e-02,   3.63769531e-02],
                        [  1.47399902e-02,   1.23291016e-02],
                        [ -1.12915039e-03,  -6.43920898e-03],
                        [ -1.00708008e-02,  -1.68762207e-02],
                        [ -1.66931152e-02,  -2.31933594e-02],
                        [ -2.13317871e-02,  -2.60009766e-02],
                        [ -2.19421387e-02,  -2.38037109e-02],
                        [ -1.98364258e-02,  -1.85852051e-02],
                        [ -1.61132812e-02,  -1.23291016e-02],
                        [ -8.81958008e-03,  -3.57055664e-03],
                        [  2.28881836e-03,   7.56835938e-03],
                        [  1.35192871e-02,   1.75476074e-02],
                        [  2.05688477e-02,   2.24914551e-02],
                        [  2.32543945e-02,   2.28576660e-02],
                        [  2.93884277e-02,   2.70385742e-02],
                        [  4.80346680e-02,   4.45861816e-02],
                        [  7.71789551e-02,   7.36694336e-02],
                        [  1.05224609e-01,   1.02600098e-01],
                        [  1.24938965e-01,   1.23748779e-01],
                        [  1.37298584e-01,   1.37573242e-01],
                        [  1.41571045e-01,   1.42852783e-01],
                        [  1.28967285e-01,   1.30462646e-01],
                        [  8.75854492e-02,   8.85620117e-02],
                        [  1.23291016e-02,   1.22375488e-02],
                        [ -8.95385742e-02,  -9.07592773e-02],
                        [ -1.96685791e-01,  -1.98638916e-01],
                        [ -2.78320312e-01,  -2.80181885e-01],
                        [ -3.08990479e-01,  -3.09814453e-01],
                        [ -2.85614014e-01,  -2.84637451e-01],
                        [ -2.30438232e-01,  -2.27325439e-01],
                        [ -1.75933838e-01,  -1.71051025e-01],
                        [ -1.43402100e-01,  -1.37664795e-01],
                        [ -1.30889893e-01,  -1.25732422e-01],
                        [ -1.20910645e-01,  -1.17858887e-01],
                        [ -1.01440430e-01,  -1.01684570e-01],
                        [ -7.80944824e-02,  -8.21533203e-02],
                        [ -6.34765625e-02,  -7.09533691e-02],
                        [ -5.86242676e-02,  -6.82373047e-02],
                        [ -5.27648926e-02,  -6.25610352e-02],
                        [ -3.92456055e-02,  -4.70581055e-02],
                        [ -2.20031738e-02,  -2.59094238e-02],
                        [ -7.53784180e-03,  -6.37817383e-03],
                        [  2.41088867e-03,   8.72802734e-03],
                        [  9.64355469e-03,   2.00195312e-02],
                        [  1.49536133e-02,   2.74047852e-02],
                        [  1.51672363e-02,   2.71606445e-02],
                        [  5.58471680e-03,   1.46789551e-02],
                        [ -1.16882324e-02,  -7.41577148e-03],
                        [ -2.58789062e-02,  -2.72521973e-02],
                        [ -2.95104980e-02,  -3.61938477e-02],
                        [ -2.85339355e-02,  -3.90014648e-02],
                        [ -3.28979492e-02,  -4.50134277e-02],
                        [ -4.23583984e-02,  -5.36193848e-02],
                        [ -4.71496582e-02,  -5.54504395e-02],
                        [ -4.03442383e-02,  -4.43115234e-02],
                        [ -2.25524902e-02,  -2.18200684e-02],
                        [  6.80541992e-03,   1.15356445e-02],
                        [  5.49316406e-02,   6.23168945e-02],
                        [  1.23382568e-01,   1.31622314e-01],
                        [  1.94458008e-01,   2.01904297e-01],
                        [  2.41271973e-01,   2.46734619e-01],
                        [  2.51373291e-01,   2.54364014e-01],
                        [  2.36816406e-01,   2.37487793e-01],
                        [  2.21160889e-01,   2.20153809e-01],
                        [  2.18078613e-01,   2.16247559e-01],
                        [  2.22198486e-01,   2.20214844e-01],
                        [  2.17742920e-01,   2.16003418e-01],
                        [  1.91284180e-01,   1.89666748e-01],
                        [  1.38122559e-01,   1.36322021e-01],
                        [  6.36901855e-02,   6.11877441e-02],
                        [ -1.99890137e-02,  -2.34985352e-02],
                        [ -9.75036621e-02,  -1.01867676e-01],
                        [ -1.50939941e-01,  -1.55548096e-01],
                        [ -1.65832520e-01,  -1.69647217e-01],
                        [ -1.44927979e-01,  -1.46789551e-01],
                        [ -1.12426758e-01,  -1.11358643e-01],
                        [ -9.42077637e-02,  -8.98132324e-02],
                        [ -9.24987793e-02,  -8.51135254e-02],
                        [ -8.86840820e-02,  -7.94982910e-02],
                        [ -7.02209473e-02,  -6.09741211e-02],
                        [ -4.28161621e-02,  -3.54919434e-02],
                        [ -1.67846680e-02,  -1.31225586e-02],
                        [  5.12695312e-03,   4.08935547e-03],
                        [  2.37731934e-02,   1.80053711e-02],
                        [  3.64074707e-02,   2.69775391e-02],
                        [  3.94592285e-02,   2.82592773e-02],
                        [  3.50036621e-02,   2.43835449e-02],
                        [  2.96936035e-02,   2.18811035e-02],
                        [  2.71301270e-02,   2.36816406e-02],
                        [  2.64282227e-02,   2.79235840e-02],
                        [  2.73437500e-02,   3.33251953e-02],
                        [  2.92663574e-02,   3.82385254e-02],
                        [  2.57568359e-02,   3.57360840e-02],
                        [  9.55200195e-03,   1.84020996e-02],
                        [ -1.59912109e-02,  -9.91821289e-03],
                        [ -3.85437012e-02,  -3.61938477e-02],
                        [ -5.06896973e-02,  -5.20629883e-02],
                        [ -5.49621582e-02,  -5.93261719e-02],
                        [ -5.68542480e-02,  -6.29272461e-02],
                        [ -5.87768555e-02,  -6.51550293e-02],
                        [ -5.93261719e-02,  -6.47888184e-02],
                        [ -5.45349121e-02,  -5.83801270e-02],
                        [ -4.03137207e-02,  -4.22973633e-02],
                        [ -1.54724121e-02,  -1.58691406e-02],
                        [  1.62963867e-02,   1.70898438e-02],
                        [  4.92858887e-02,   5.08117676e-02],
                        [  8.02917480e-02,   8.23059082e-02],
                        [  1.06597900e-01,   1.09100342e-01],
                        [  1.20117188e-01,   1.23229980e-01],
                        [  1.13067627e-01,   1.16882324e-01],
                        [  9.00878906e-02,   9.44213867e-02],
                        [  6.55517578e-02,   6.98242188e-02],
                        [  4.75158691e-02,   5.08117676e-02],
                        [  3.23791504e-02,   3.36303711e-02],
                        [  1.64794922e-02,   1.48315430e-02],
                        [  4.51660156e-03,  -4.57763672e-04],
                        [  3.17382812e-03,  -4.73022461e-03],
                        [  1.07116699e-02,   1.15966797e-03],
                        [  1.57470703e-02,   6.43920898e-03],
                        [  8.17871094e-03,   1.37329102e-03],
                        [ -7.93457031e-03,  -1.02844238e-02],
                        [ -1.89819336e-02,  -1.57165527e-02],
                        [ -1.84936523e-02,  -9.70458984e-03],
                        [ -1.11083984e-02,   1.73950195e-03],
                        [ -2.74658203e-03,   1.15661621e-02],
                        [  3.47900391e-03,   1.60522461e-02],
                        [  5.79833984e-03,   1.36718750e-02],
                        [  6.19506836e-03,   7.26318359e-03],
                        [  1.15661621e-02,   5.21850586e-03],
                        [  2.75573730e-02,   1.49230957e-02],
                        [  5.27954102e-02,   3.65295410e-02],
                        [  8.32824707e-02,   6.70166016e-02],
                        [  1.18011475e-01,   1.05407715e-01],
                        [  1.51672363e-01,   1.45629883e-01],
                        [  1.68334961e-01,   1.70196533e-01],
                        [  1.53259277e-01,   1.62567139e-01],
                        [  1.06689453e-01,   1.21185303e-01],
                        [  3.86352539e-02,   5.49316406e-02],
                        [ -4.35180664e-02,  -2.91748047e-02],
                        [ -1.34490967e-01,  -1.25305176e-01],
                        [ -2.21282959e-01,  -2.19085693e-01],
                        [ -2.81188965e-01,  -2.86132812e-01],
                        [ -2.94647217e-01,  -3.05114746e-01],
                        [ -2.61260986e-01,  -2.74383545e-01],
                        [ -2.04345703e-01,  -2.16827393e-01],
                        [ -1.56341553e-01,  -1.65252686e-01],
                        [ -1.34582520e-01,  -1.38031006e-01],
                        [ -1.31103516e-01,  -1.28723145e-01],
                        [ -1.26403809e-01,  -1.19354248e-01],
                        [ -1.09191895e-01,  -9.97009277e-02],
                        [ -8.31909180e-02,  -7.39440918e-02],
                        [ -6.01806641e-02,  -5.36193848e-02],
                        [ -4.73022461e-02,  -4.49523926e-02],
                        [ -4.00085449e-02,  -4.21447754e-02],
                        [ -2.98156738e-02,  -3.54919434e-02],
                        [ -1.64184570e-02,  -2.37731934e-02],
                        [ -5.82885742e-03,  -1.27258301e-02],
                        [ -6.10351562e-05,  -4.57763672e-03],
                        [  3.14331055e-03,   2.10571289e-03],
                        [  1.83105469e-03,   4.45556641e-03],
                        [ -8.94165039e-03,  -3.50952148e-03],
                        [ -2.67944336e-02,  -2.01110840e-02],
                        [ -4.11071777e-02,  -3.48815918e-02],
                        [ -4.48608398e-02,  -4.05578613e-02],
                        [ -4.29992676e-02,  -4.15039062e-02],
                        [ -4.41284180e-02,  -4.55627441e-02],
                        [ -4.65698242e-02,  -5.02624512e-02],
                        [ -4.04357910e-02,  -4.54101562e-02],
                        [ -2.20642090e-02,  -2.71606445e-02],
                        [  2.65502930e-03,  -1.61743164e-03],
                        [  2.89001465e-02,   2.60314941e-02],
                        [  5.94177246e-02,   5.80749512e-02],
                        [  9.87548828e-02,   9.87243652e-02],
                        [  1.44775391e-01,   1.45721436e-01],
                        [  1.88079834e-01,   1.89666748e-01],
                        [  2.17712402e-01,   2.19818115e-01],
                        [  2.27386475e-01,   2.30041504e-01],
                        [  2.21160889e-01,   2.24487305e-01],
                        [  2.12860107e-01,   2.16827393e-01],
                        [  2.12677002e-01,   2.16979980e-01],
                        [  2.15972900e-01,   2.20031738e-01],
                        [  2.11029053e-01,   2.13958740e-01],
                        [  1.90826416e-01,   1.91680908e-01],
                        [  1.52069092e-01,   1.50115967e-01],
                        [  8.98132324e-02,   8.48999023e-02],
                        [  3.17382812e-03,  -4.24194336e-03],
                        [ -9.33532715e-02,  -1.02050781e-01],
                        [ -1.70898438e-01,  -1.79138184e-01],
                        [ -2.04467773e-01,  -2.10449219e-01],
                        [ -1.91619873e-01,  -1.93847656e-01],
                        [ -1.53900146e-01,  -1.51580811e-01],
                        [ -1.19628906e-01,  -1.13006592e-01],
                        [ -1.00311279e-01,  -9.06372070e-02],
                        [ -8.41979980e-02,  -7.34558105e-02],
                        [ -5.63659668e-02,  -4.68444824e-02],
                        [ -1.91040039e-02,  -1.28784180e-02],
                        [  1.25427246e-02,   1.42517090e-02],
                        [  2.92663574e-02,   2.61840820e-02],
                        [  3.31726074e-02,   2.61535645e-02],
                        [  2.93579102e-02,   2.01721191e-02],
                        [  2.02331543e-02,   1.10168457e-02],
                        [  8.81958008e-03,   1.58691406e-03],
                        [ -3.35693359e-04,  -4.15039062e-03],
                        [ -5.18798828e-03,  -5.12695312e-03],
                        [ -6.10351562e-03,  -2.59399414e-03],
                        [ -2.62451172e-03,   3.05175781e-03],
                        [  3.08227539e-03,   9.30786133e-03],
                        [  3.47900391e-03,   8.63647461e-03],
                        [ -6.56127930e-03,  -3.47900391e-03],
                        [ -2.15148926e-02,  -2.09350586e-02],
                        [ -3.15551758e-02,  -3.30810547e-02],
                        [ -3.33251953e-02,  -3.61022949e-02],
                        [ -3.03955078e-02,  -3.33557129e-02],
                        [ -2.74047852e-02,  -2.96020508e-02],
                        [ -2.80761719e-02,  -2.89611816e-02],
                        [ -3.43933105e-02,  -3.39660645e-02],
                        [ -4.42504883e-02,  -4.29687500e-02],
                        [ -5.13305664e-02,  -4.98352051e-02],
                        [ -4.69665527e-02,  -4.59899902e-02],
                        [ -2.25830078e-02,  -2.24609375e-02],
                        [  2.43835449e-02,   2.36816406e-02],
                        [  8.16345215e-02,   8.04443359e-02],
                        [  1.24816895e-01,   1.23779297e-01],
                        [  1.36230469e-01,   1.35833740e-01],
                        [  1.18835449e-01,   1.19415283e-01],
                        [  9.02404785e-02,   9.16442871e-02],
                        [  6.66809082e-02,   6.83898926e-02],
                        [  5.23681641e-02,   5.36193848e-02],
                        [  4.00390625e-02,   4.00695801e-02],
                        [  2.22167969e-02,   2.06298828e-02],
                        [  1.15966797e-03,  -1.92260742e-03],
                        [ -1.51672363e-02,  -1.90734863e-02],
                        [ -2.22473145e-02,  -2.58483887e-02],
                        [ -2.04162598e-02,  -2.24609375e-02],
                        [ -1.19934082e-02,  -1.14746094e-02],
                        [ -1.28173828e-03,   2.13623047e-03],
                        [  4.60815430e-03,   1.05895996e-02],
                        [  1.40380859e-03,   8.78906250e-03],
                        [ -5.34057617e-03,   1.70898438e-03],
                        [ -5.98144531e-03,  -1.12915039e-03],
                        [  3.05175781e-04,   1.49536133e-03],
                        [  8.45336914e-03,   5.31005859e-03],
                        [  1.92260742e-02,   1.20239258e-02],
                        [  3.67126465e-02,   2.68249512e-02],
                        [  5.90209961e-02,   4.84924316e-02],
                        [  8.05664062e-02,   7.17163086e-02],
                        [  9.98840332e-02,   9.47265625e-02],
                        [  1.18835449e-01,   1.18591309e-01],
                        [  1.35711670e-01,   1.40563965e-01],
                        [  1.41693115e-01,   1.50665283e-01],
                        [  1.24603271e-01,   1.35894775e-01],
                        [  7.83996582e-02,   8.96301270e-02],
                        [  8.30078125e-03,   1.72119141e-02],
                        [ -7.48291016e-02,  -6.99768066e-02],
                        [ -1.62475586e-01,  -1.62536621e-01],
                        [ -2.43499756e-01,  -2.48229980e-01],
                        [ -2.95623779e-01,  -3.03955078e-01],
                        [ -2.97485352e-01,  -3.07678223e-01],
                        [ -2.53570557e-01,  -2.63580322e-01],
                        [ -1.96197510e-01,  -2.04254150e-01],
                        [ -1.55273438e-01,  -1.60064697e-01],
                        [ -1.33300781e-01,  -1.34185791e-01],
                        [ -1.16882324e-01,  -1.13983154e-01],
                        [ -1.00463867e-01,  -9.45434570e-02],
                        [ -8.69445801e-02,  -7.91625977e-02],
                        [ -7.54699707e-02,  -6.72302246e-02],
                        [ -6.28356934e-02,  -5.55419922e-02],
                        [ -5.08422852e-02,  -4.56848145e-02],
                        [ -4.17480469e-02,  -3.95202637e-02],
                        [ -3.06091309e-02,  -3.16162109e-02],
                        [ -1.20849609e-02,  -1.62048340e-02],
                        [  7.14111328e-03,   6.40869141e-04],
                        [  1.35192871e-02,   5.70678711e-03],
                        [  2.59399414e-03,  -5.09643555e-03],
                        [ -1.74560547e-02,  -2.35595703e-02],
                        [ -3.59191895e-02,  -3.92150879e-02],
                        [ -4.60205078e-02,  -4.56542969e-02],
                        [ -4.55627441e-02,  -4.14123535e-02],
                        [ -3.86047363e-02,  -3.14025879e-02],
                        [ -3.54919434e-02,  -2.66113281e-02],
                        [ -4.30908203e-02,  -3.44238281e-02],
                        [ -5.43823242e-02,  -4.78820801e-02],
                        [ -5.30700684e-02,  -5.03845215e-02],
                        [ -2.95410156e-02,  -3.15246582e-02],
                        [  1.29394531e-02,   6.46972656e-03],
                        [  6.44531250e-02,   5.47790527e-02],
                        [  1.16058350e-01,   1.05255127e-01],
                        [  1.62872314e-01,   1.53472900e-01],
                        [  2.00225830e-01,   1.94458008e-01],
                        [  2.18841553e-01,   2.18200684e-01],
                        [  2.13775635e-01,   2.18505859e-01],
                        [  1.96411133e-01,   2.05505371e-01],
                        [  1.86187744e-01,   1.97540283e-01],
                        [  1.89575195e-01,   2.00469971e-01],
                        [  1.96533203e-01,   2.04376221e-01],
                        [  1.95617676e-01,   1.98577881e-01],
                        [  1.82952881e-01,   1.80450439e-01],
                        [  1.58477783e-01,   1.51275635e-01],
                        [  1.21063232e-01,   1.11114502e-01],
                        [  6.68640137e-02,   5.67321777e-02],
                        [ -8.11767578e-03,  -1.58996582e-02],
                        [ -9.61914062e-02,  -9.98229980e-02],
                        [ -1.71386719e-01,  -1.70288086e-01],
                        [ -2.05993652e-01,  -2.00927734e-01],
                        [ -1.94793701e-01,  -1.87561035e-01],
                        [ -1.57196045e-01,  -1.50177002e-01],
                        [ -1.17218018e-01,  -1.12609863e-01],
                        [ -8.58154297e-02,  -8.48999023e-02],
                        [ -6.05163574e-02,  -6.34765625e-02],
                        [ -3.63769531e-02,  -4.20227051e-02],
                        [ -1.39465332e-02,  -2.02331543e-02],
                        [  3.96728516e-04,  -4.18090820e-03],
                        [  1.28173828e-03,   3.35693359e-04],
                        [ -7.90405273e-03,  -4.42504883e-03],
                        [ -1.61437988e-02,  -8.78906250e-03],
                        [ -1.51062012e-02,  -5.73730469e-03],
                        [ -4.85229492e-03,   3.84521484e-03],
                        [  1.02539062e-02,   1.55334473e-02],
                        [  2.42919922e-02,   2.40783691e-02],
                        [  2.78015137e-02,   2.14843750e-02],
                        [  1.51062012e-02,   3.63159180e-03],
                        [ -4.21142578e-03,  -1.84020996e-02],
                        [ -1.35498047e-02,  -2.71301270e-02],
                        [ -1.13525391e-02,  -2.09350586e-02],
                        [ -1.00708008e-02,  -1.31530762e-02],
                        [ -1.44042969e-02,  -9.94873047e-03],
                        [ -1.66015625e-02,  -5.40161133e-03],
                        [ -1.36413574e-02,   1.86157227e-03],
                        [ -1.24511719e-02,   3.87573242e-03],
                        [ -1.73645020e-02,  -3.81469727e-03],
                        [ -2.55432129e-02,  -1.77001953e-02],
                        [ -3.57971191e-02,  -3.51867676e-02],
                        [ -4.85229492e-02,  -5.49926758e-02],
                        [ -5.40466309e-02,  -6.57348633e-02],
                        [ -3.53698730e-02,  -4.94384766e-02],
                        [  1.18103027e-02,  -1.52587891e-03],
                        [  7.12585449e-02,   6.14013672e-02],
                        [  1.18865967e-01,   1.14074707e-01],
                        [  1.36657715e-01,   1.37207031e-01],
                        [  1.20422363e-01,   1.25335693e-01],
                        [  8.36791992e-02,   9.11254883e-02],
                        [  5.05676270e-02,   5.84411621e-02],
                        [  3.50036621e-02,   4.15649414e-02],
                        [  2.94494629e-02,   3.36608887e-02],
                        [  1.95617676e-02,   2.12707520e-02],
                        [  4.39453125e-03,   4.18090820e-03],
                        [ -5.40161133e-03,  -6.50024414e-03],
                        [ -2.68554688e-03,  -3.72314453e-03],
                        [  7.23266602e-03,   6.83593750e-03],
                        [  1.14746094e-02,   1.17187500e-02],
                        [  4.63867188e-03,   5.09643555e-03],
                        [ -3.02124023e-03,  -3.14331055e-03],
                        [  8.23974609e-04,  -5.18798828e-04],
                        [  1.26647949e-02,   9.73510742e-03],
                        [  1.87988281e-02,   1.46179199e-02],
                        [  1.70898438e-02,   1.24206543e-02],
                        [  1.97753906e-02,   1.57165527e-02],
                        [  3.37219238e-02,   3.14025879e-02],
                        [  5.09338379e-02,   5.10864258e-02],
                        [  6.38122559e-02,   6.64672852e-02],
                        [  7.69653320e-02,   8.15124512e-02],
                        [  9.71374512e-02,   1.02508545e-01],
                        [  1.21551514e-01,   1.26403809e-01],
                        [  1.40197754e-01,   1.43432617e-01],
                        [  1.40930176e-01,   1.42028809e-01],
                        [  1.11053467e-01,   1.10076904e-01],
                        [  4.40368652e-02,   4.17480469e-02],
                        [ -5.20935059e-02,  -5.46569824e-02],
                        [ -1.57989502e-01,  -1.59820557e-01],
                        [ -2.50823975e-01,  -2.51281738e-01],
                        [ -3.05541992e-01,  -3.04626465e-01],
                        [ -3.04077148e-01,  -3.02459717e-01],
                        [ -2.57263184e-01,  -2.55981445e-01],
                        [ -2.03582764e-01,  -2.03796387e-01],
                        [ -1.71844482e-01,  -1.74163818e-01],
                        [ -1.53594971e-01,  -1.57989502e-01],
                        [ -1.25518799e-01,  -1.31103516e-01],
                        [ -8.74633789e-02,  -9.27429199e-02],
                        [ -6.14929199e-02,  -6.46972656e-02],
                        [ -5.80444336e-02,  -5.77392578e-02],
                        [ -6.26831055e-02,  -5.82275391e-02],
                        [ -5.71899414e-02,  -4.90417480e-02],
                        [ -3.87878418e-02,  -2.85949707e-02],
                        [ -1.65710449e-02,  -6.68334961e-03],
                        [ -1.09863281e-03,   5.95092773e-03],
                        [  2.38037109e-03,   4.54711914e-03],
                        [ -2.22778320e-03,  -5.79833984e-03],
                        [ -6.31713867e-03,  -1.50451660e-02],
                        [ -7.93457031e-03,  -1.98669434e-02],
                        [ -1.31530762e-02,  -2.54821777e-02],
                        [ -2.60620117e-02,  -3.57055664e-02],
                        [ -4.40063477e-02,  -4.84924316e-02],
                        [ -6.13403320e-02,  -5.95397949e-02],
                        [ -7.27233887e-02,  -6.50634766e-02],
                        [ -7.48596191e-02,  -6.33239746e-02],
                        [ -6.58874512e-02,  -5.34057617e-02],
                        [ -4.20227051e-02,  -3.17993164e-02],
                        [ -1.22070312e-03,   4.21142578e-03],
                        [  4.99572754e-02,   4.93164062e-02],
                        [  1.01135254e-01,   9.47875977e-02],
                        [  1.45904541e-01,   1.35711670e-01],
                        [  1.78680420e-01,   1.67480469e-01],
                        [  1.92596436e-01,   1.83441162e-01],
                        [  1.88079834e-01,   1.83349609e-01],
                        [  1.75689697e-01,   1.76544189e-01],
                        [  1.66046143e-01,   1.72088623e-01],
                        [  1.61376953e-01,   1.70806885e-01],
                        [  1.58599854e-01,   1.68792725e-01],
                        [  1.55487061e-01,   1.63665771e-01],
                        [  1.51947021e-01,   1.56036377e-01],
                        [  1.50146484e-01,   1.49291992e-01],
                        [  1.52374268e-01,   1.47094727e-01],
                        [  1.53228760e-01,   1.45202637e-01],
                        [  1.37023926e-01,   1.28631592e-01],
                        [  8.92944336e-02,   8.28247070e-02],
                        [  8.94165039e-03,   6.07299805e-03],
                        [ -8.83789062e-02,  -8.71582031e-02],
                        [ -1.73919678e-01,  -1.69311523e-01],
                        [ -2.15911865e-01,  -2.09564209e-01],
                        [ -1.99340820e-01,  -1.93298340e-01],
                        [ -1.42883301e-01,  -1.38946533e-01],
                        [ -8.75549316e-02,  -8.67919922e-02],
                        [ -5.90820312e-02,  -6.14318848e-02],
                        [ -4.90417480e-02,  -5.34362793e-02],
                        [ -4.00390625e-02,  -4.47692871e-02],
                        [ -3.31420898e-02,  -3.64074707e-02],
                        [ -3.76892090e-02,  -3.81164551e-02],
                        [ -4.87060547e-02,  -4.58374023e-02],
                        [ -5.02014160e-02,  -4.46777344e-02],
                        [ -3.44543457e-02,  -2.78015137e-02],
                        [ -8.75854492e-03,  -2.99072266e-03],
                        [  1.39465332e-02,   1.69067383e-02],
                        [  2.50549316e-02,   2.39868164e-02],
                        [  2.29187012e-02,   1.77001953e-02],
                        [  1.04675293e-02,   2.10571289e-03],
                        [ -6.80541992e-03,  -1.63879395e-02],
                        [ -2.19116211e-02,  -3.03344727e-02],
                        [ -2.96020508e-02,  -3.47290039e-02],
                        [ -2.94494629e-02,  -2.98461914e-02],
                        [ -2.44140625e-02,  -1.97448730e-02],
                        [ -1.66320801e-02,  -7.81250000e-03],
                        [ -6.34765625e-03,   4.79125977e-03],
                        [  3.90625000e-03,   1.49230957e-02],
                        [  5.31005859e-03,   1.39465332e-02],
                        [ -9.79614258e-03,  -5.27954102e-03],
                        [ -3.55224609e-02,  -3.58886719e-02],
                        [ -5.55419922e-02,  -6.04858398e-02],
                        [ -5.84716797e-02,  -6.67419434e-02],
                        [ -4.10156250e-02,  -5.07812500e-02],
                        [ -8.23974609e-04,  -1.01318359e-02],
                        [  5.72814941e-02,   5.01403809e-02],
                        [  1.09771729e-01,   1.05834961e-01],
                        [  1.27868652e-01,   1.27502441e-01],
                        [  1.08245850e-01,   1.11083984e-01],
                        [  7.58972168e-02,   8.10852051e-02],
                        [  5.24291992e-02,   5.88684082e-02],
                        [  3.76586914e-02,   4.42199707e-02],
                        [  2.55432129e-02,   3.12500000e-02],
                        [  1.91345215e-02,   2.33764648e-02],
                        [  2.18505859e-02,   2.42309570e-02],
                        [  2.87170410e-02,   2.92053223e-02],
                        [  3.39660645e-02,   3.26843262e-02],
                        [  3.69873047e-02,   3.42712402e-02],
                        [  3.58276367e-02,   3.21044922e-02],
                        [  2.47497559e-02,   2.05383301e-02],
                        [  4.45556641e-03,   3.96728516e-04],
                        [ -1.38854980e-02,  -1.71813965e-02],
                        [ -2.07519531e-02,  -2.27966309e-02],
                        [ -1.59606934e-02,  -1.63879395e-02],
                        [ -1.40380859e-03,  -1.22070312e-04],
                        [  2.30102539e-02,   2.56347656e-02],
                        [  5.29479980e-02,   5.63659668e-02],
                        [  7.99560547e-02,   8.33435059e-02],
                        [  1.00555420e-01,   1.03118896e-01],
                        [  1.17156982e-01,   1.18316650e-01],
                        [  1.28997803e-01,   1.28479004e-01],
                        [  1.31988525e-01,   1.30065918e-01],
                        [  1.24633789e-01,   1.21948242e-01],
                        [  1.02996826e-01,   1.00463867e-01],
                        [  5.54199219e-02,   5.39550781e-02],
                        [ -2.56347656e-02,  -2.53601074e-02],
                        [ -1.29028320e-01,  -1.26861572e-01],
                        [ -2.27752686e-01,  -2.24121094e-01],
                        [ -2.92602539e-01,  -2.88421631e-01],
                        [ -3.03802490e-01,  -3.00292969e-01],
                        [ -2.62756348e-01,  -2.61016846e-01],
                        [ -1.97174072e-01,  -1.97998047e-01],
                        [ -1.43371582e-01,  -1.46881104e-01],
                        [ -1.15264893e-01,  -1.20849609e-01],
                        [ -1.01074219e-01,  -1.07543945e-01],
                        [ -8.86230469e-02,  -9.44213867e-02],
                        [ -7.88574219e-02,  -8.25500488e-02],
                        [ -7.50427246e-02,  -7.56225586e-02],
                        [ -7.32727051e-02,  -7.04650879e-02],
                        [ -6.52770996e-02,  -5.96008301e-02],
                        [ -4.65698242e-02,  -3.92761230e-02],
                        [ -2.26135254e-02,  -1.53198242e-02],
                        [ -4.11987305e-03,   1.49536133e-03],
                        [  4.36401367e-03,   7.11059570e-03],
                        [  6.22558594e-03,   5.64575195e-03],
                        [  4.02832031e-03,   3.66210938e-04],
                        [ -4.11987305e-03,  -9.79614258e-03],
                        [ -1.92260742e-02,  -2.55126953e-02],
                        [ -3.78112793e-02,  -4.32434082e-02],
                        [ -5.35888672e-02,  -5.69763184e-02],
                        [ -6.17675781e-02,  -6.25915527e-02],
                        [ -6.32019043e-02,  -6.16149902e-02],
                        [ -6.23168945e-02,  -5.90209961e-02],
                        [ -5.85937500e-02,  -5.47180176e-02],
                        [ -4.45556641e-02,  -4.12292480e-02],
                        [ -1.41296387e-02,  -1.22070312e-02],
                        [  3.17687988e-02,   3.19519043e-02],
                        [  8.95385742e-02,   8.81042480e-02],
                        [  1.53747559e-01,   1.51306152e-01],
                        [  2.10388184e-01,   2.07824707e-01],
                        [  2.38769531e-01,   2.36907959e-01],
                        [  2.28302002e-01,   2.27722168e-01],
                        [  1.90032959e-01,   1.90948486e-01],
                        [  1.46881104e-01,   1.49078369e-01],
                        [  1.15234375e-01,   1.18133545e-01],
                        [  9.92126465e-02,   1.02111816e-01],
                        [  9.73815918e-02,   9.95788574e-02],
                        [  1.07269287e-01,   1.08215332e-01],
                        [  1.22894287e-01,   1.22406006e-01],
                        [  1.36474609e-01,   1.34552002e-01],
                        [  1.45996094e-01,   1.42944336e-01],
                        [  1.54144287e-01,   1.50482178e-01],
                        [  1.54907227e-01,   1.51123047e-01],
                        [  1.29333496e-01,   1.25976562e-01],
                        [  6.20117188e-02,   5.95092773e-02],
                        [ -3.96423340e-02,  -4.08935547e-02],
                        [ -1.42456055e-01,  -1.42211914e-01],
                        [ -2.05169678e-01,  -2.03338623e-01],
                        [ -2.06604004e-01,  -2.03277588e-01],
                        [ -1.61224365e-01,  -1.56646729e-01],
                        [ -1.05224609e-01,  -9.99755859e-02],
                        [ -6.80236816e-02,  -6.28967285e-02],
                        [ -5.60302734e-02,  -5.19409180e-02],
                        [ -5.67932129e-02,  -5.46569824e-02],
                        [ -5.36499023e-02,  -5.41381836e-02],
                        [ -4.17480469e-02,  -4.51354980e-02],
                        [ -3.23791504e-02,  -3.82995605e-02],
                        [ -3.63464355e-02,  -4.39758301e-02],
                        [ -4.77905273e-02,  -5.57556152e-02],
                        [ -5.25817871e-02,  -5.93261719e-02],
                        [ -4.47082520e-02,  -4.87976074e-02],
                        [ -2.58178711e-02,  -2.63061523e-02],
                        [ -1.25122070e-03,   2.04467773e-03],
                        [  1.77307129e-02,   2.42004395e-02],
                        [  2.11791992e-02,   2.94799805e-02],
                        [  1.34277344e-02,   2.17285156e-02],
                        [  7.17163086e-03,   1.37023926e-02],
                        [  5.76782227e-03,   9.09423828e-03],
                        [  2.19726562e-03,   1.67846680e-03],
                        [ -6.56127930e-03,  -1.06201172e-02],
                        [ -1.56250000e-02,  -2.21557617e-02],
                        [ -2.05688477e-02,  -2.79235840e-02],
                        [ -2.14538574e-02,  -2.78625488e-02],
                        [ -2.16369629e-02,  -2.57263184e-02],
                        [ -2.68859863e-02,  -2.78625488e-02],
                        [ -3.93981934e-02,  -3.74755859e-02],
                        [ -5.00183105e-02,  -4.60510254e-02],
                        [ -4.20532227e-02,  -3.74755859e-02],
                        [ -7.50732422e-03,  -3.72314453e-03],
                        [  4.32739258e-02,   4.51049805e-02],
                        [  8.86535645e-02,   8.81347656e-02],
                        [  1.09985352e-01,   1.07452393e-01],
                        [  1.01379395e-01,   9.78088379e-02],
                        [  7.35778809e-02,   7.02819824e-02],
                        [  4.82177734e-02,   4.63867188e-02],
                        [  3.96118164e-02,   3.99475098e-02],
                        [  4.31213379e-02,   4.56237793e-02],
                        [  4.61120605e-02,   5.00488281e-02],
                        [  4.28161621e-02,   4.69665527e-02],
                        [  3.32336426e-02,   3.61633301e-02],
                        [  1.89208984e-02,   1.95617676e-02],
                        [  5.70678711e-03,   3.57055664e-03],
                        [  3.96728516e-04,  -4.15039062e-03],
                        [  1.43432617e-03,  -4.36401367e-03],
                        [  8.23974609e-04,  -4.69970703e-03],
                        [ -3.14331055e-03,  -6.83593750e-03],
                        [ -2.41088867e-03,  -3.17382812e-03],
                        [  9.70458984e-03,   1.22070312e-02],
                        [  2.95104980e-02,   3.46374512e-02],
                        [  4.91638184e-02,   5.55419922e-02],
                        [  6.80847168e-02,   7.39746094e-02],
                        [  9.14611816e-02,   9.51538086e-02],
                        [  1.17614746e-01,   1.17980957e-01],
                        [  1.37603760e-01,   1.34399414e-01],
                        [  1.47796631e-01,   1.41845703e-01],
                        [  1.50665283e-01,   1.43463135e-01],
                        [  1.40502930e-01,   1.33941650e-01],
                        [  1.02325439e-01,   9.82055664e-02],
                        [  2.81372070e-02,   2.75573730e-02],
                        [ -7.36389160e-02,  -7.04650879e-02],
                        [ -1.82312012e-01,  -1.76177979e-01],
                        [ -2.71179199e-01,  -2.63732910e-01],
                        [ -3.14117432e-01,  -3.07250977e-01],
                        [ -2.98278809e-01,  -2.93823242e-01],
                        [ -2.37670898e-01,  -2.36755371e-01],
                        [ -1.69036865e-01,  -1.71875000e-01],
                        [ -1.25000000e-01,  -1.30859375e-01],
                        [ -1.08520508e-01,  -1.15936279e-01],
                        [ -1.00067139e-01,  -1.07208252e-01],
                        [ -8.71887207e-02,  -9.24072266e-02],
                        [ -7.42492676e-02,  -7.64465332e-02],
                        [ -6.59179688e-02,  -6.47888184e-02],
                        [ -5.93872070e-02,  -5.54504395e-02],
                        [ -5.27038574e-02,  -4.71496582e-02],
                        [ -4.62951660e-02,  -4.05883789e-02],
                        [ -3.77807617e-02,  -3.32641602e-02],
                        [ -2.56042480e-02,  -2.31628418e-02],
                        [ -1.33972168e-02,  -1.33056641e-02],
                        [ -4.63867188e-03,  -6.53076172e-03],
                        [  1.19018555e-03,  -1.80053711e-03],
                        [  2.31933594e-03,  -8.54492188e-04],
                        [ -7.26318359e-03,  -9.73510742e-03],
                        [ -2.74963379e-02,  -2.88085938e-02],
                        [ -4.90417480e-02,  -4.91943359e-02],
                        [ -6.49108887e-02,  -6.43005371e-02],
                        [ -7.47375488e-02,  -7.39440918e-02],
                        [ -7.44628906e-02,  -7.40356445e-02],
                        [ -5.49926758e-02,  -5.52673340e-02],
                        [ -1.57165527e-02,  -1.67236328e-02],
                        [  3.32031250e-02,   3.18298340e-02],
                        [  8.52966309e-02,   8.40454102e-02],
                        [  1.41784668e-01,   1.41235352e-01],
                        [  1.96472168e-01,   1.96990967e-01],
                        [  2.29766846e-01,   2.31414795e-01],
                        [  2.27569580e-01,   2.30010986e-01],
                        [  1.97845459e-01,   2.00561523e-01],
                        [  1.61376953e-01,   1.63665771e-01],
                        [  1.32476807e-01,   1.33819580e-01],
                        [  1.14318848e-01,   1.14379883e-01],
                        [  1.06475830e-01,   1.05346680e-01],
                        [  1.09344482e-01,   1.07360840e-01],
                        [  1.19842529e-01,   1.17553711e-01],
                        [  1.29760742e-01,   1.27746582e-01],
                        [  1.32965088e-01,   1.31561279e-01],
                        [  1.31683350e-01,   1.31042480e-01],
                        [  1.30462646e-01,   1.30432129e-01],
                        [  1.24816895e-01,   1.25091553e-01],
                        [  1.00769043e-01,   1.00952148e-01],
                        [  4.69055176e-02,   4.67529297e-02],
                        [ -3.34777832e-02,  -3.39050293e-02],
                        [ -1.20330811e-01,  -1.20788574e-01],
                        [ -1.84906006e-01,  -1.84936523e-01],
                        [ -2.04956055e-01,  -2.04101562e-01],
                        [ -1.79656982e-01,  -1.77642822e-01],
                        [ -1.30523682e-01,  -1.27441406e-01],
                        [ -8.48693848e-02,  -8.12072754e-02],
                        [ -5.73425293e-02,  -5.38940430e-02],
                        [ -4.53491211e-02,  -4.30297852e-02],
                        [ -3.90014648e-02,  -3.86657715e-02],
                        [ -3.35083008e-02,  -3.55224609e-02],
                        [ -3.08532715e-02,  -3.51257324e-02],
                        [ -3.32946777e-02,  -3.90625000e-02],
                        [ -3.77197266e-02,  -4.37622070e-02],
                        [ -3.72009277e-02,  -4.21752930e-02],
                        [ -2.81066895e-02,  -3.07617188e-02],
                        [ -1.42517090e-02,  -1.38854980e-02],
                        [ -2.07519531e-03,   1.37329102e-03],
                        [  6.62231445e-03,   1.25122070e-02],
                        [  1.11083984e-02,   1.81274414e-02],
                        [  7.11059570e-03,   1.37634277e-02],
                        [ -5.18798828e-03,  -3.96728516e-04],
                        [ -1.56860352e-02,  -1.37023926e-02],
                        [ -1.66320801e-02,  -1.77612305e-02],
                        [ -1.49536133e-02,  -1.87377930e-02],
                        [ -2.13623047e-02,  -2.67639160e-02],
                        [ -3.39355469e-02,  -3.95507812e-02],
                        [ -4.24194336e-02,  -4.69055176e-02],
                        [ -4.54406738e-02,  -4.78210449e-02],
                        [ -5.05371094e-02,  -5.04760742e-02],
                        [ -5.75561523e-02,  -5.53283691e-02],
                        [ -5.38024902e-02,  -5.02319336e-02],
                        [ -2.83203125e-02,  -2.45056152e-02],
                        [  1.67846680e-02,   1.98059082e-02],
                        [  6.81457520e-02,   6.96411133e-02],
                        [  1.06384277e-01,   1.06201172e-01],
                        [  1.15203857e-01,   1.13647461e-01],
                        [  9.63134766e-02,   9.41162109e-02],
                        [  7.17163086e-02,   6.97631836e-02],
                        [  6.24084473e-02,   6.14624023e-02],
                        [  6.71691895e-02,   6.76879883e-02],
                        [  6.92749023e-02,   7.11669922e-02],
                        [  5.88073730e-02,   6.15539551e-02],
                        [  4.01916504e-02,   4.29992676e-02],
                        [  2.18200684e-02,   2.38342285e-02],
                        [  8.08715820e-03,   8.66699219e-03],
                        [ -3.05175781e-05,  -1.15966797e-03],
                        [ -3.57055664e-03,  -6.16455078e-03],
                        [ -4.66918945e-03,  -8.08715820e-03],
                        [ -5.00488281e-03,  -8.33129883e-03],
                        [ -4.33349609e-03,  -6.65283203e-03],
                        [  5.79833984e-04,  -1.22070312e-04],
                        [  1.37329102e-02,   1.49536133e-02],
                        [  3.64074707e-02,   3.92761230e-02],
                        [  6.64367676e-02,   7.03430176e-02],
                        [  9.93957520e-02,   1.03424072e-01],
                        [  1.28265381e-01,   1.31500244e-01],
                        [  1.46789551e-01,   1.48559570e-01],
                        [  1.54235840e-01,   1.54205322e-01],
                        [  1.52252197e-01,   1.50543213e-01],
                        [  1.35925293e-01,   1.33026123e-01],
                        [  9.53063965e-02,   9.19799805e-02],
                        [  2.64282227e-02,   2.34680176e-02],
                        [ -6.48803711e-02,  -6.67724609e-02],
                        [ -1.66870117e-01,  -1.67327881e-01],
                        [ -2.59460449e-01,  -2.58422852e-01],
                        [ -3.12255859e-01,  -3.09997559e-01],
                        [ -3.02856445e-01,  -2.99957275e-01],
                        [ -2.42858887e-01,  -2.39898682e-01],
                        [ -1.73522949e-01,  -1.71112061e-01],
                        [ -1.29364014e-01,  -1.27899170e-01],
                        [ -1.11541748e-01,  -1.11267090e-01],
                        [ -1.01684570e-01,  -1.02508545e-01],
                        [ -9.08508301e-02,  -9.24987793e-02],
                        [ -8.34350586e-02,  -8.55712891e-02],
                        [ -8.11157227e-02,  -8.32519531e-02],
                        [ -7.79418945e-02,  -7.96813965e-02],
                        [ -6.92138672e-02,  -7.02514648e-02],
                        [ -5.49316406e-02,  -5.50537109e-02],
                        [ -3.71398926e-02,  -3.63464355e-02],
                        [ -1.84936523e-02,  -1.68457031e-02],
                        [ -1.34277344e-03,   8.85009766e-04],
                        [  1.08642578e-02,   1.33361816e-02],
                        [  1.30920410e-02,   1.54113770e-02],
                        [  3.78417969e-03,   5.58471680e-03],
                        [ -1.22070312e-02,  -1.12304688e-02],
                        [ -3.05175781e-02,  -3.06091309e-02],
                        [ -5.10253906e-02,  -5.21850586e-02],
                        [ -7.10144043e-02,  -7.30590820e-02],
                        [ -8.17871094e-02,  -8.43505859e-02],
                        [ -7.52563477e-02,  -7.78503418e-02],
                        [ -4.90722656e-02,  -5.11474609e-02],
                        [ -5.31005859e-03,  -6.40869141e-03],
                        [  5.13916016e-02,   5.15136719e-02],
                        [  1.13342285e-01,   1.14715576e-01],
                        [  1.69036865e-01,   1.71447754e-01],
                        [  2.04132080e-01,   2.07092285e-01],
                        [  2.09045410e-01,   2.12036133e-01],
                        [  1.88079834e-01,   1.90460205e-01],
                        [  1.56799316e-01,   1.58111572e-01],
                        [  1.28906250e-01,   1.28936768e-01],
                        [  1.08886719e-01,   1.07727051e-01],
                        [  9.59167480e-02,   9.38415527e-02],
                        [  8.93249512e-02,   8.68835449e-02],
                        [  9.06982422e-02,   8.84094238e-02],
                        [  1.02416992e-01,   1.00799561e-01],
                        [  1.20910645e-01,   1.20239258e-01],
                        [  1.33300781e-01,   1.33636475e-01],
                        [  1.28753662e-01,   1.29974365e-01],
                        [  1.12274170e-01,   1.13952637e-01],
                        [  9.81445312e-02,   9.99145508e-02],
                        [  9.08203125e-02,   9.22241211e-02],
                        [  7.82775879e-02,   7.91015625e-02],
                        [  4.52575684e-02,   4.54101562e-02],
                        [ -1.22375488e-02,  -1.26342773e-02],
                        [ -8.41674805e-02,  -8.49304199e-02],
                        [ -1.50421143e-01,  -1.51214600e-01],
                        [ -1.86065674e-01,  -1.86706543e-01],
                        [ -1.76086426e-01,  -1.76391602e-01],
                        [ -1.32049561e-01,  -1.32019043e-01],
                        [ -8.71887207e-02,  -8.69140625e-02],
                        [ -6.61621094e-02,  -6.57958984e-02],
                        [ -6.48193359e-02,  -6.45141602e-02],
                        [ -6.35986328e-02,  -6.34765625e-02],
                        [ -5.37109375e-02,  -5.37719727e-02],
                        [ -4.18090820e-02,  -4.20227051e-02],
                        [ -3.45153809e-02,  -3.47595215e-02],
                        [ -3.08227539e-02,  -3.09753418e-02],
                        [ -2.94189453e-02,  -2.93884277e-02],
                        [ -2.98461914e-02,  -2.96936035e-02],
                        [ -2.60925293e-02,  -2.58178711e-02],
                        [ -1.12915039e-02,  -1.10473633e-02],
                        [  8.42285156e-03,   8.45336914e-03],
                        [  1.75781250e-02,   1.73645020e-02],
                        [  1.13525391e-02,   1.08947754e-02],
                        [ -3.05175781e-04,  -8.85009766e-04],
                        [ -9.24682617e-03,  -9.82666016e-03],
                        [ -1.79138184e-02,  -1.82495117e-02],
                        [ -3.00903320e-02,  -3.00292969e-02],
                        [ -4.32128906e-02,  -4.27246094e-02],
                        [ -5.14221191e-02,  -5.05371094e-02],
                        [ -5.33752441e-02,  -5.23376465e-02],
                        [ -5.52673340e-02,  -5.43518066e-02],
                        [ -6.21032715e-02,  -6.15539551e-02],
                        [ -6.65893555e-02,  -6.66809082e-02],
                        [ -5.40771484e-02,  -5.48095703e-02],
                        [ -1.71508789e-02,  -1.84631348e-02],
                        [  3.76281738e-02,   3.59802246e-02],
                        [  9.31396484e-02,   9.15222168e-02],
                        [  1.29547119e-01,   1.28295898e-01],
                        [  1.36291504e-01,   1.35681152e-01],
                        [  1.18713379e-01,   1.18896484e-01],
                        [  9.12780762e-02,   9.21630859e-02],
                        [  6.56738281e-02,   6.70776367e-02],
                        [  4.59594727e-02,   4.75463867e-02],
                        [  3.13415527e-02,   3.27453613e-02],
                        [  2.23388672e-02,   2.32543945e-02],
                        [  2.18811035e-02,   2.21252441e-02],
                        [  2.86254883e-02,   2.81677246e-02],
                        [  3.32946777e-02,   3.22570801e-02],
                        [  2.74047852e-02,   2.60314941e-02],
                        [  1.39160156e-02,   1.24816895e-02],
                        [  4.39453125e-03,   3.17382812e-03],
                        [  6.13403320e-03,   5.27954102e-03],
                        [  1.51977539e-02,   1.47705078e-02],
                        [  2.40173340e-02,   2.39868164e-02],
                        [  3.23181152e-02,   3.25622559e-02],
                        [  4.65087891e-02,   4.69055176e-02],
                        [  6.91528320e-02,   6.96105957e-02],
                        [  9.61914062e-02,   9.65881348e-02],
                        [  1.23992920e-01,   1.24298096e-01],
                        [  1.49200439e-01,   1.49414062e-01],
                        [  1.61132812e-01,   1.61224365e-01],
                        [  1.46484375e-01,   1.46514893e-01],
                        [  1.03149414e-01,   1.03088379e-01],
                        [  3.75061035e-02,   3.73535156e-02],
                        [ -4.80651855e-02,  -4.84008789e-02],
                        [ -1.50299072e-01,  -1.50848389e-01],
                        [ -2.47711182e-01,  -2.48413086e-01],
                        [ -3.02276611e-01,  -3.03100586e-01],
                        [ -2.88665771e-01,  -2.89428711e-01],
                        [ -2.22167969e-01,  -2.22778320e-01],
                        [ -1.51550293e-01,  -1.51885986e-01],
                        [ -1.16302490e-01,  -1.16302490e-01],
                        [ -1.13830566e-01,  -1.13525391e-01],
                        [ -1.14135742e-01,  -1.13586426e-01],
                        [ -9.93652344e-02,  -9.87854004e-02],
                        [ -7.79113770e-02,  -7.74841309e-02],
                        [ -6.43920898e-02,  -6.43005371e-02],
                        [ -6.05468750e-02,  -6.08215332e-02],
                        [ -5.76477051e-02,  -5.83190918e-02],
                        [ -4.91333008e-02,  -5.00488281e-02],
                        [ -3.55529785e-02,  -3.65295410e-02],
                        [ -2.13928223e-02,  -2.21557617e-02],
                        [ -1.07421875e-02,  -1.11389160e-02],
                        [ -5.43212891e-03,  -5.37109375e-03],
                        [ -6.77490234e-03,  -6.28662109e-03],
                        [ -1.60217285e-02,  -1.52893066e-02],
                        [ -3.12500000e-02,  -3.04870605e-02],
                        [ -4.61120605e-02,  -4.55932617e-02],
                        [ -5.61828613e-02,  -5.61523438e-02],
                        [ -6.24694824e-02,  -6.29882812e-02],
                        [ -6.46362305e-02,  -6.56433105e-02],
                        [ -5.58166504e-02,  -5.71594238e-02],
                        [ -2.81372070e-02,  -2.95410156e-02],
                        [  1.91955566e-02,   1.80664062e-02],
                        [  7.91320801e-02,   7.85217285e-02],
                        [  1.39892578e-01,   1.39923096e-01],
                        [  1.88446045e-01,   1.89086914e-01],
                        [  2.13806152e-01,   2.14904785e-01],
                        [  2.09869385e-01,   2.11090088e-01],
                        [  1.79016113e-01,   1.80053711e-01],
                        [  1.36505127e-01,   1.37115479e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.43603516e-02,   9.36889648e-02],
                        [  9.85107422e-02,   9.73510742e-02],
                        [  1.01928711e-01,   1.00494385e-01],
                        [  9.86328125e-02,   9.72290039e-02],
                        [  9.27734375e-02,   9.16442871e-02],
                        [  8.82263184e-02,   8.75854492e-02],
                        [  8.27941895e-02,   8.27331543e-02],
                        [  7.36389160e-02,   7.40661621e-02],
                        [  6.46057129e-02,   6.53686523e-02],
                        [  6.44531250e-02,   6.53381348e-02],
                        [  7.73010254e-02,   7.80944824e-02],
                        [  9.66796875e-02,   9.71374512e-02],
                        [  1.08459473e-01,   1.08581543e-01],
                        [  9.84497070e-02,   9.81750488e-02],
                        [  5.72204590e-02,   5.66406250e-02],
                        [ -1.52282715e-02,  -1.59606934e-02],
                        [ -1.03515625e-01,  -1.04278564e-01],
                        [ -1.77398682e-01,  -1.78009033e-01],
                        [ -2.07183838e-01,  -2.07611084e-01],
                        [ -1.86889648e-01,  -1.87103271e-01],
                        [ -1.41265869e-01,  -1.41296387e-01],
                        [ -1.02905273e-01,  -1.02813721e-01],
                        [ -8.18481445e-02,  -8.16955566e-02],
                        [ -6.59484863e-02,  -6.57958984e-02],
                        [ -4.78515625e-02,  -4.76989746e-02],
                        [ -3.51257324e-02,  -3.50341797e-02],
                        [ -3.35388184e-02,  -3.34777832e-02],
                        [ -3.68957520e-02,  -3.68652344e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -3.66516113e-02,  -3.66821289e-02],
                        [ -3.22875977e-02,  -3.23486328e-02],
                        [ -2.30407715e-02,  -2.31933594e-02],
                        [ -1.29089355e-02,  -1.31835938e-02],
                        [ -8.91113281e-03,  -9.24682617e-03],
                        [ -9.03320312e-03,  -9.39941406e-03],
                        [ -6.80541992e-03,  -7.17163086e-03],
                        [ -6.10351562e-03,  -6.34765625e-03],
                        [ -1.49230957e-02,  -1.50146484e-02],
                        [ -2.98767090e-02,  -2.98156738e-02],
                        [ -4.26025391e-02,  -4.23889160e-02],
                        [ -5.23681641e-02,  -5.20324707e-02],
                        [ -6.14929199e-02,  -6.10961914e-02],
                        [ -6.91223145e-02,  -6.87866211e-02],
                        [ -7.35778809e-02,  -7.33642578e-02],
                        [ -6.89697266e-02,  -6.89392090e-02],
                        [ -4.44641113e-02,  -4.46166992e-02],
                        [  1.64794922e-03,   1.34277344e-03],
                        [  5.44433594e-02,   5.40161133e-02],
                        [  9.60998535e-02,   9.56726074e-02],
                        [  1.19079590e-01,   1.18713379e-01],
                        [  1.22985840e-01,   1.22772217e-01],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  9.01794434e-02,   9.03320312e-02],
                        [  6.90002441e-02,   6.92749023e-02],
                        [  4.80041504e-02,   4.83398438e-02],
                        [  2.58789062e-02,   2.61840820e-02],
                        [  9.15527344e-03,   9.42993164e-03],
                        [  7.35473633e-03,   7.53784180e-03],
                        [  1.91650391e-02,   1.92260742e-02],
                        [  3.28674316e-02,   3.28369141e-02],
                        [  4.00390625e-02,   3.99780273e-02],
                        [  4.14428711e-02,   4.13513184e-02],
                        [  3.96423340e-02,   3.95812988e-02],
                        [  3.46374512e-02,   3.46069336e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  3.79333496e-02,   3.79638672e-02],
                        [  6.21643066e-02,   6.21948242e-02],
                        [  9.40551758e-02,   9.40856934e-02],
                        [  1.19842529e-01,   1.19903564e-01],
                        [  1.35742188e-01,   1.35803223e-01],
                        [  1.45690918e-01,   1.45751953e-01],
                        [  1.48864746e-01,   1.48986816e-01],
                        [  1.34887695e-01,   1.35070801e-01],
                        [  9.13085938e-02,   9.15222168e-02],
                        [  1.50146484e-02,   1.52893066e-02],
                        [ -8.24890137e-02,  -8.22143555e-02],
                        [ -1.80267334e-01,  -1.80023193e-01],
                        [ -2.56256104e-01,  -2.56072998e-01],
                        [ -2.91320801e-01,  -2.91198730e-01],
                        [ -2.75756836e-01,  -2.75726318e-01],
                        [ -2.21679688e-01,  -2.21679688e-01],
                        [ -1.61773682e-01,  -1.61865234e-01],
                        [ -1.23687744e-01,  -1.23748779e-01],
                        [ -1.07299805e-01,  -1.07330322e-01],
                        [ -9.49401855e-02,  -9.49096680e-02],
                        [ -7.82775879e-02,  -7.81555176e-02],
                        [ -6.53076172e-02,  -6.50939941e-02],
                        [ -6.35681152e-02,  -6.32934570e-02],
                        [ -6.67419434e-02,  -6.64367676e-02],
                        [ -6.16149902e-02,  -6.13098145e-02],
                        [ -4.32128906e-02,  -4.29382324e-02],
                        [ -1.87683105e-02,  -1.85241699e-02],
                        [  6.40869141e-04,   7.93457031e-04],
                        [  8.75854492e-03,   8.88061523e-03],
                        [  4.88281250e-03,   4.94384766e-03],
                        [ -9.97924805e-03,  -9.91821289e-03],
                        [ -3.23486328e-02,  -3.22875977e-02],
                        [ -5.42602539e-02,  -5.41687012e-02],
                        [ -6.83898926e-02,  -6.82678223e-02],
                        [ -7.46154785e-02,  -7.44628906e-02],
                        [ -7.51647949e-02,  -7.49816895e-02],
                        [ -6.68640137e-02,  -6.66503906e-02],
                        [ -4.30297852e-02,  -4.28161621e-02],
                        [  1.52587891e-04,   3.66210938e-04],
                        [  6.09436035e-02,   6.11267090e-02],
                        [  1.30126953e-01,   1.30310059e-01],
                        [  1.90124512e-01,   1.90307617e-01],
                        [  2.22045898e-01,   2.22198486e-01],
                        [  2.19390869e-01,   2.19543457e-01],
                        [  1.92749023e-01,   1.92932129e-01],
                        [  1.58599854e-01,   1.58752441e-01],
                        [  1.27319336e-01,   1.27502441e-01],
                        [  1.03363037e-01,   1.03546143e-01],
                        [  8.79516602e-02,   8.81347656e-02],
                        [  7.85522461e-02,   7.87353516e-02],
                        [  7.22961426e-02,   7.24487305e-02],
                        [  6.98852539e-02,   7.00378418e-02],
                        [  7.06787109e-02,   7.08312988e-02],
                        [  6.88476562e-02,   6.90307617e-02],
                        [  6.11877441e-02,   6.13403320e-02],
                        [  5.23986816e-02,   5.25817871e-02],
                        [  4.81567383e-02,   4.83398438e-02],
                        [  4.96215820e-02,   4.98352051e-02],
                        [  5.81359863e-02,   5.83496094e-02],
                        [  7.59887695e-02,   7.61718750e-02],
                        [  9.87854004e-02,   9.89685059e-02],
                        [  1.12762451e-01,   1.12945557e-01],
                        [  1.03332520e-01,   1.03515625e-01],
                        [  6.36596680e-02,   6.38122559e-02],
                        [ -2.62451172e-03,  -2.44140625e-03],
                        [ -8.01391602e-02,  -7.99560547e-02],
                        [ -1.44592285e-01,  -1.44439697e-01],
                        [ -1.74377441e-01,  -1.74224854e-01],
                        [ -1.63757324e-01,  -1.63574219e-01],
                        [ -1.26464844e-01,  -1.26312256e-01],
                        [ -8.64868164e-02,  -8.63037109e-02],
                        [ -6.09741211e-02,  -6.08215332e-02],
                        [ -5.05676270e-02,  -5.03845215e-02],
                        [ -4.60815430e-02,  -4.59289551e-02],
                        [ -4.27551270e-02,  -4.26025391e-02],
                        [ -4.32128906e-02,  -4.30603027e-02],
                        [ -4.87060547e-02,  -4.85534668e-02],
                        [ -5.22155762e-02,  -5.20629883e-02],
                        [ -4.47082520e-02,  -4.45556641e-02],
                        [ -2.66723633e-02,  -2.65197754e-02],
                        [ -8.30078125e-03,  -8.17871094e-03],
                        [  1.77001953e-03,   1.89208984e-03],
                        [  3.60107422e-03,   3.75366211e-03],
                        [  1.43432617e-03,   1.58691406e-03],
                        [ -2.44140625e-03,  -2.28881836e-03],
                        [ -7.84301758e-03,  -7.72094727e-03],
                        [ -1.53808594e-02,  -1.52587891e-02],
                        [ -2.64282227e-02,  -2.63061523e-02],
                        [ -4.19921875e-02,  -4.18701172e-02],
                        [ -5.87158203e-02,  -5.85937500e-02],
                        [ -6.90002441e-02,  -6.88781738e-02],
                        [ -6.72302246e-02,  -6.71386719e-02],
                        [ -5.49621582e-02,  -5.48706055e-02],
                        [ -3.76892090e-02,  -3.75976562e-02],
                        [ -1.67846680e-02,  -1.66931152e-02],
                        [  1.14746094e-02,   1.15661621e-02],
                        [  4.58374023e-02,   4.59289551e-02],
                        [  7.45544434e-02,   7.46459961e-02],
                        [  8.70666504e-02,   8.71582031e-02],
                        [  8.60290527e-02,   8.61206055e-02],
                        [  7.94067383e-02,   7.94677734e-02],
                        [  6.80236816e-02,   6.80847168e-02],
                        [  5.02014160e-02,   5.02929688e-02],
                        [  3.12194824e-02,   3.12805176e-02],
                        [  1.97143555e-02,   1.97448730e-02],
                        [  1.93176270e-02,   1.93786621e-02],
                        [  2.75268555e-02,   2.75878906e-02],
                        [  3.84521484e-02,   3.84826660e-02],
                        [  4.57153320e-02,   4.57458496e-02],
                        [  4.66613770e-02,   4.66918945e-02],
                        [  4.33959961e-02,   4.34570312e-02],
                        [  3.96423340e-02,   3.96728516e-02],
                        [  3.85131836e-02,   3.85437012e-02],
                        [  4.31823730e-02,   4.32128906e-02],
                        [  5.59082031e-02,   5.59387207e-02],
                        [  7.62023926e-02,   7.62023926e-02],
                        [  1.00128174e-01,   1.00128174e-01],
                        [  1.21429443e-01,   1.21459961e-01],
                        [  1.34338379e-01,   1.34338379e-01],
                        [  1.33850098e-01,   1.33850098e-01],
                        [  1.12365723e-01,   1.12365723e-01],
                        [  6.14929199e-02,   6.14929199e-02],
                        [ -1.83105469e-02,  -1.83410645e-02],
                        [ -1.14074707e-01,  -1.14074707e-01],
                        [ -2.05017090e-01,  -2.05047607e-01],
                        [ -2.66845703e-01,  -2.66876221e-01],
                        [ -2.79785156e-01,  -2.79815674e-01],
                        [ -2.45513916e-01,  -2.45544434e-01],
                        [ -1.90979004e-01,  -1.91009521e-01],
                        [ -1.46026611e-01,  -1.46057129e-01],
                        [ -1.19476318e-01,  -1.19537354e-01],
                        [ -1.01715088e-01,  -1.01776123e-01],
                        [ -8.36791992e-02,  -8.37402344e-02],
                        [ -6.57653809e-02,  -6.58264160e-02],
                        [ -5.17578125e-02,  -5.18188477e-02],
                        [ -4.26635742e-02,  -4.27246094e-02],
                        [ -3.71704102e-02,  -3.72314453e-02],
                        [ -3.33862305e-02,  -3.34777832e-02],
                        [ -2.87475586e-02,  -2.88391113e-02],
                        [ -2.09960938e-02,  -2.10876465e-02],
                        [ -1.17187500e-02,  -1.18103027e-02],
                        [ -6.68334961e-03,  -6.77490234e-03],
                        [ -1.05285645e-02,  -1.06201172e-02],
                        [ -2.27355957e-02,  -2.28271484e-02],
                        [ -4.04357910e-02,  -4.05273438e-02],
                        [ -6.02722168e-02,  -6.03942871e-02],
                        [ -7.48901367e-02,  -7.50122070e-02],
                        [ -7.52868652e-02,  -7.54089355e-02],
                        [ -5.91430664e-02,  -5.92651367e-02],
                        [ -3.03039551e-02,  -3.03955078e-02],
                        [  1.01928711e-02,   1.00708008e-02],
                        [  6.39038086e-02,   6.37817383e-02],
                        [  1.25610352e-01,   1.25488281e-01],
                        [  1.79504395e-01,   1.79382324e-01],
                        [  2.08435059e-01,   2.08312988e-01],
                        [  2.04498291e-01,   2.04376221e-01],
                        [  1.72485352e-01,   1.72363281e-01],
                        [  1.28845215e-01,   1.28692627e-01],
                        [  9.57946777e-02,   9.56420898e-02],
                        [  8.45947266e-02,   8.44421387e-02],
                        [  8.40148926e-02,   8.38928223e-02],
                        [  7.76367188e-02,   7.74841309e-02],
                        [  6.72607422e-02,   6.71081543e-02],
                        [  6.55517578e-02,   6.53991699e-02],
                        [  7.13195801e-02,   7.11364746e-02],
                        [  7.02209473e-02,   7.00683594e-02],
                        [  5.63049316e-02,   5.61218262e-02],
                        [  3.90014648e-02,   3.88488770e-02],
                        [  3.03955078e-02,   3.02429199e-02],
                        [  3.39965820e-02,   3.38439941e-02],
                        [  4.65698242e-02,   4.64172363e-02],
                        [  6.45751953e-02,   6.43920898e-02],
                        [  8.61816406e-02,   8.60290527e-02],
                        [  1.08459473e-01,   1.08306885e-01],
                        [  1.24420166e-01,   1.24237061e-01],
                        [  1.24389648e-01,   1.24206543e-01],
                        [  9.88159180e-02,   9.86328125e-02],
                        [  4.08325195e-02,   4.06494141e-02],
                        [ -4.54406738e-02,  -4.55932617e-02],
                        [ -1.36199951e-01,  -1.36352539e-01],
                        [ -1.96044922e-01,  -1.96228027e-01],
                        [ -2.04223633e-01,  -2.04406738e-01],
                        [ -1.72790527e-01,  -1.72973633e-01],
                        [ -1.33941650e-01,  -1.34124756e-01],
                        [ -1.09069824e-01,  -1.09252930e-01],
                        [ -9.44213867e-02,  -9.46044922e-02],
                        [ -7.67517090e-02,  -7.69348145e-02],
                        [ -5.31005859e-02,  -5.32836914e-02],
                        [ -3.11889648e-02,  -3.13720703e-02],
                        [ -1.95922852e-02,  -1.97753906e-02],
                        [ -2.15454102e-02,  -2.17285156e-02],
                        [ -3.17077637e-02,  -3.18908691e-02],
                        [ -3.82385254e-02,  -3.84216309e-02],
                        [ -3.41186523e-02,  -3.43017578e-02],
                        [ -2.51770020e-02,  -2.53601074e-02],
                        [ -2.20642090e-02,  -2.22473145e-02],
                        [ -2.60925293e-02,  -2.62756348e-02],
                        [ -2.85034180e-02,  -2.86560059e-02],
                        [ -2.28576660e-02,  -2.30102539e-02],
                        [ -1.33972168e-02,  -1.35803223e-02],
                        [ -1.07116699e-02,  -1.08947754e-02],
                        [ -2.23388672e-02,  -2.24914551e-02],
                        [ -4.66918945e-02,  -4.68444824e-02],
                        [ -7.28759766e-02,  -7.30285645e-02],
                        [ -8.75549316e-02,  -8.77380371e-02],
                        [ -8.39233398e-02,  -8.40759277e-02],
                        [ -6.26220703e-02,  -6.27746582e-02],
                        [ -2.64892578e-02,  -2.66418457e-02],
                        [  2.07824707e-02,   2.05993652e-02],
                        [  6.96105957e-02,   6.94274902e-02],
                        [  1.05102539e-01,   1.04949951e-01],
                        [  1.17248535e-01,   1.17095947e-01],
                        [  1.08581543e-01,   1.08428955e-01],
                        [  9.03015137e-02,   9.01489258e-02],
                        [  7.33032227e-02,   7.31811523e-02],
                        [  6.32629395e-02,   6.31408691e-02],
                        [  5.78002930e-02,   5.76782227e-02],
                        [  4.90722656e-02,   4.89196777e-02],
                        [  3.48815918e-02,   3.47290039e-02],
                        [  2.48107910e-02,   2.46887207e-02],
                        [  2.84118652e-02,   2.82897949e-02],
                        [  4.15344238e-02,   4.14123535e-02],
                        [  5.19104004e-02,   5.17883301e-02],
                        [  5.44128418e-02,   5.42907715e-02],
                        [  5.32531738e-02,   5.31311035e-02],
                        [  5.32226562e-02,   5.31005859e-02],
                        [  5.76171875e-02,   5.74951172e-02],
                        [  7.10449219e-02,   7.09228516e-02],
                        [  9.47875977e-02,   9.46960449e-02],
                        [  1.21002197e-01,   1.20910645e-01],
                        [  1.38488770e-01,   1.38397217e-01],
                        [  1.41326904e-01,   1.41235352e-01],
                        [  1.26129150e-01,   1.26037598e-01],
                        [  8.63647461e-02,   8.62731934e-02],
                        [  1.67541504e-02,   1.66625977e-02],
                        [ -7.76977539e-02,  -7.77893066e-02],
                        [ -1.78009033e-01,  -1.78070068e-01],
                        [ -2.54302979e-01,  -2.54364014e-01],
                        [ -2.78472900e-01,  -2.78533936e-01],
                        [ -2.45666504e-01,  -2.45758057e-01],
                        [ -1.84295654e-01,  -1.84356689e-01],
                        [ -1.34765625e-01,  -1.34826660e-01],
                        [ -1.15112305e-01,  -1.15173340e-01],
                        [ -1.12152100e-01,  -1.12182617e-01],
                        [ -1.05010986e-01,  -1.05041504e-01],
                        [ -8.92944336e-02,  -8.93249512e-02],
                        [ -7.42797852e-02,  -7.43103027e-02],
                        [ -6.40563965e-02,  -6.40869141e-02],
                        [ -5.28564453e-02,  -5.28869629e-02],
                        [ -3.72619629e-02,  -3.72924805e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -5.09643555e-03,  -5.12695312e-03],
                        [  7.65991211e-03,   7.62939453e-03],
                        [  1.27258301e-02,   1.26953125e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -7.66601562e-02,  -7.66296387e-02],
                        [ -9.08508301e-02,  -9.08203125e-02],
                        [ -8.29467773e-02,  -8.29162598e-02],
                        [ -5.49926758e-02,  -5.49621582e-02],
                        [ -1.22070312e-02,  -1.21765137e-02],
                        [  4.42504883e-02,   4.42810059e-02],
                        [  1.10992432e-01,   1.11022949e-01],
                        [  1.75720215e-01,   1.75781250e-01],
                        [  2.18811035e-01,   2.18872070e-01],
                        [  2.23724365e-01,   2.23785400e-01],
                        [  1.92413330e-01,   1.92474365e-01],
                        [  1.47766113e-01,   1.47827148e-01],
                        [  1.12792969e-01,   1.12854004e-01],
                        [  9.22851562e-02,   9.23461914e-02],
                        [  8.06274414e-02,   8.06884766e-02],
                        [  7.44323730e-02,   7.45239258e-02],
                        [  7.05261230e-02,   7.06176758e-02],
                        [  6.37207031e-02,   6.37817383e-02],
                        [  5.33447266e-02,   5.34362793e-02],
                        [  4.37316895e-02,   4.38232422e-02],
                        [  3.55834961e-02,   3.56750488e-02],
                        [  2.49938965e-02,   2.50854492e-02],
                        [  1.25732422e-02,   1.26953125e-02],
                        [  7.72094727e-03,   7.84301758e-03],
                        [  1.94091797e-02,   1.95007324e-02],
                        [  4.59594727e-02,   4.60815430e-02],
                        [  7.65380859e-02,   7.66296387e-02],
                        [  1.00769043e-01,   1.00891113e-01],
                        [  1.15661621e-01,   1.15753174e-01],
                        [  1.23229980e-01,   1.23321533e-01],
                        [  1.23596191e-01,   1.23718262e-01],
                        [  1.10321045e-01,   1.10443115e-01],
                        [  7.22961426e-02,   7.24487305e-02],
                        [  2.59399414e-03,   2.74658203e-03],
                        [ -8.91418457e-02,  -8.90197754e-02],
                        [ -1.72760010e-01,  -1.72637939e-01],
                        [ -2.14752197e-01,  -2.14630127e-01],
                        [ -2.05474854e-01,  -2.05322266e-01],
                        [ -1.64916992e-01,  -1.64764404e-01],
                        [ -1.21856689e-01,  -1.21704102e-01],
                        [ -9.21325684e-02,  -9.19799805e-02],
                        [ -7.53784180e-02,  -7.52258301e-02],
                        [ -6.33544922e-02,  -6.32019043e-02],
                        [ -5.10559082e-02,  -5.09033203e-02],
                        [ -4.29382324e-02,  -4.27856445e-02],
                        [ -4.50134277e-02,  -4.48608398e-02],
                        [ -5.00183105e-02,  -4.98657227e-02],
                        [ -4.25109863e-02,  -4.23583984e-02],
                        [ -2.08435059e-02,  -2.06909180e-02],
                        [ -5.49316406e-04,  -3.66210938e-04],
                        [  6.07299805e-03,   6.25610352e-03],
                        [  1.03759766e-03,   1.22070312e-03],
                        [ -7.56835938e-03,  -7.38525391e-03],
                        [ -1.45874023e-02,  -1.44042969e-02],
                        [ -2.01721191e-02,  -2.00195312e-02],
                        [ -2.83813477e-02,  -2.82287598e-02],
                        [ -4.16564941e-02,  -4.14733887e-02],
                        [ -5.77697754e-02,  -5.75866699e-02],
                        [ -7.40661621e-02,  -7.38830566e-02],
                        [ -8.81347656e-02,  -8.79821777e-02],
                        [ -9.17053223e-02,  -9.15222168e-02],
                        [ -7.32421875e-02,  -7.30590820e-02],
                        [ -3.10668945e-02,  -3.08837891e-02],
                        [  2.28576660e-02,   2.30407715e-02],
                        [  7.22961426e-02,   7.24792480e-02],
                        [  1.04736328e-01,   1.04919434e-01],
                        [  1.13952637e-01,   1.14105225e-01],
                        [  1.02935791e-01,   1.03118896e-01],
                        [  8.31298828e-02,   8.33129883e-02],
                        [  6.59484863e-02,   6.61315918e-02],
                        [  5.59387207e-02,   5.61218262e-02],
                        [  5.11474609e-02,   5.13305664e-02],
                        [  4.80346680e-02,   4.82177734e-02],
                        [  4.59899902e-02,   4.61425781e-02],
                        [  4.70581055e-02,   4.72412109e-02],
                        [  5.09033203e-02,   5.10559082e-02],
                        [  5.32226562e-02,   5.34057617e-02],
                        [  5.19104004e-02,   5.20935059e-02],
                        [  5.13305664e-02,   5.14831543e-02],
                        [  5.69763184e-02,   5.71594238e-02],
                        [  6.73217773e-02,   6.75048828e-02],
                        [  7.68127441e-02,   7.69653320e-02],
                        [  8.70056152e-02,   8.71582031e-02],
                        [  1.05773926e-01,   1.05926514e-01],
                        [  1.32781982e-01,   1.32965088e-01],
                        [  1.53808594e-01,   1.53961182e-01],
                        [  1.50787354e-01,   1.50939941e-01],
                        [  1.11755371e-01,   1.11907959e-01],
                        [  3.40576172e-02,   3.42102051e-02],
                        [ -7.29064941e-02,  -7.27539062e-02],
                        [ -1.86737061e-01,  -1.86584473e-01],
                        [ -2.76214600e-01,  -2.76092529e-01],
                        [ -3.12377930e-01,  -3.12225342e-01],
                        [ -2.85247803e-01,  -2.85095215e-01],
                        [ -2.15087891e-01,  -2.14935303e-01],
                        [ -1.40350342e-01,  -1.40197754e-01],
                        [ -8.99658203e-02,  -8.98437500e-02],
                        [ -6.89392090e-02,  -6.88171387e-02],
                        [ -6.63757324e-02,  -6.62231445e-02],
                        [ -7.00988770e-02,  -6.99462891e-02],
                        [ -7.49206543e-02,  -7.48291016e-02],
                        [ -8.18786621e-02,  -8.17565918e-02],
                        [ -8.79211426e-02,  -8.77990723e-02],
                        [ -8.12072754e-02,  -8.10852051e-02],
                        [ -5.57250977e-02,  -5.56030273e-02],
                        [ -2.41088867e-02,  -2.40173340e-02],
                        [ -2.25830078e-03,  -2.16674805e-03],
                        [  9.12475586e-03,   9.21630859e-03],
                        [  1.43432617e-02,   1.44348145e-02],
                        [  7.56835938e-03,   7.65991211e-03],
                        [ -1.71813965e-02,  -1.70898438e-02],
                        [ -5.14221191e-02,  -5.13305664e-02],
                        [ -7.80334473e-02,  -7.79418945e-02],
                        [ -8.57238770e-02,  -8.56628418e-02],
                        [ -7.29675293e-02,  -7.29064941e-02],
                        [ -4.14123535e-02,  -4.13208008e-02],
                        [  8.48388672e-03,   8.57543945e-03],
                        [  7.26318359e-02,   7.26928711e-02],
                        [  1.37420654e-01,   1.37481689e-01],
                        [  1.83929443e-01,   1.83990479e-01],
                        [  1.99127197e-01,   1.99188232e-01],
                        [  1.83959961e-01,   1.83990479e-01],
                        [  1.53045654e-01,   1.53106689e-01],
                        [  1.25122070e-01,   1.25152588e-01],
                        [  1.09558105e-01,   1.09588623e-01],
                        [  1.02447510e-01,   1.02478027e-01],
                        [  9.54895020e-02,   9.55200195e-02],
                        [  8.60595703e-02,   8.60900879e-02],
                        [  7.47985840e-02,   7.48291016e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  1.99890137e-02,   1.99584961e-02],
                        [  3.86962891e-02,   3.86657715e-02],
                        [  5.15136719e-02,   5.14831543e-02],
                        [  6.75354004e-02,   6.75048828e-02],
                        [  9.07592773e-02,   9.07287598e-02],
                        [  1.16851807e-01,   1.16821289e-01],
                        [  1.37908936e-01,   1.37847900e-01],
                        [  1.39282227e-01,   1.39251709e-01],
                        [  1.01806641e-01,   1.01776123e-01],
                        [  1.96838379e-02,   1.96228027e-02],
                        [ -8.61511230e-02,  -8.62121582e-02],
                        [ -1.78802490e-01,  -1.78863525e-01],
                        [ -2.27905273e-01,  -2.27966309e-01],
                        [ -2.23693848e-01,  -2.23754883e-01],
                        [ -1.79748535e-01,  -1.79809570e-01],
                        [ -1.25732422e-01,  -1.25823975e-01],
                        [ -8.84094238e-02,  -8.85009766e-02],
                        [ -7.39440918e-02,  -7.40051270e-02],
                        [ -7.12890625e-02,  -7.13806152e-02],
                        [ -7.05261230e-02,  -7.05871582e-02],
                        [ -7.01599121e-02,  -7.02514648e-02],
                        [ -6.99157715e-02,  -7.00073242e-02],
                        [ -6.59790039e-02,  -6.60705566e-02],
                        [ -5.65185547e-02,  -5.66101074e-02],
                        [ -4.36096191e-02,  -4.37011719e-02],
                        [ -2.84729004e-02,  -2.85644531e-02],
                        [ -1.20849609e-02,  -1.22070312e-02],
                        [ -1.77001953e-03,  -1.86157227e-03],
                        [ -5.49316406e-03,  -5.58471680e-03],
                        [ -1.89819336e-02,  -1.90734863e-02],
                        [ -3.03649902e-02,  -3.04565430e-02],
                        [ -3.64685059e-02,  -3.65905762e-02],
                        [ -4.27856445e-02,  -4.29077148e-02],
                        [ -5.18493652e-02,  -5.19714355e-02],
                        [ -6.34155273e-02,  -6.35375977e-02],
                        [ -7.81555176e-02,  -7.82775879e-02],
                        [ -8.99047852e-02,  -9.00268555e-02],
                        [ -8.23974609e-02,  -8.25500488e-02],
                        [ -4.61425781e-02,  -4.62646484e-02],
                        [  7.56835938e-03,   7.44628906e-03],
                        [  5.86547852e-02,   5.85021973e-02],
                        [  9.66796875e-02,   9.65270996e-02],
                        [  1.17797852e-01,   1.17645264e-01],
                        [  1.17584229e-01,   1.17431641e-01],
                        [  1.00891113e-01,   1.00738525e-01],
                        [  8.47473145e-02,   8.46252441e-02],
                        [  7.80639648e-02,   7.79113770e-02],
                        [  7.27844238e-02,   7.26318359e-02],
                        [  6.32019043e-02,   6.30493164e-02],
                        [  5.70373535e-02,   5.68847656e-02],
                        [  5.99670410e-02,   5.98144531e-02],
                        [  6.42700195e-02,   6.41174316e-02],
                        [  6.05163574e-02,   6.03637695e-02],
                        [  5.15747070e-02,   5.14221191e-02],
                        [  4.75769043e-02,   4.73937988e-02],
                        [  5.34973145e-02,   5.33447266e-02],
                        [  6.85424805e-02,   6.83898926e-02],
                        [  9.25598145e-02,   9.24072266e-02],
                        [  1.23779297e-01,   1.23626709e-01],
                        [  1.51306152e-01,   1.51153564e-01],
                        [  1.58813477e-01,   1.58630371e-01],
                        [  1.37298584e-01,   1.37145996e-01],
                        [  8.86230469e-02,   8.84704590e-02],
                        [  1.63574219e-02,   1.62048340e-02],
                        [ -7.75146484e-02,  -7.76672363e-02],
                        [ -1.81823730e-01,  -1.81976318e-01],
                        [ -2.69409180e-01,  -2.69592285e-01],
                        [ -3.09478760e-01,  -3.09631348e-01],
                        [ -2.90008545e-01,  -2.90161133e-01],
                        [ -2.29431152e-01,  -2.29583740e-01],
                        [ -1.63757324e-01,  -1.63909912e-01],
                        [ -1.18927002e-01,  -1.19079590e-01],
                        [ -9.60083008e-02,  -9.61914062e-02],
                        [ -8.27026367e-02,  -8.28857422e-02],
                        [ -7.10754395e-02,  -7.12280273e-02],
                        [ -6.15844727e-02,  -6.17370605e-02],
                        [ -5.63964844e-02,  -5.65490723e-02],
                        [ -5.41687012e-02,  -5.43212891e-02],
                        [ -5.06591797e-02,  -5.08117676e-02],
                        [ -4.16259766e-02,  -4.17785645e-02],
                        [ -2.52380371e-02,  -2.53906250e-02],
                        [ -5.03540039e-03,  -5.15747070e-03],
                        [  9.82666016e-03,   9.70458984e-03],
                        [  1.13525391e-02,   1.11999512e-02],
                        [ -9.76562500e-04,  -1.12915039e-03],
                        [ -2.39562988e-02,  -2.40783691e-02],
                        [ -5.26123047e-02,  -5.27648926e-02],
                        [ -7.47375488e-02,  -7.48901367e-02],
                        [ -7.45544434e-02,  -7.47070312e-02],
                        [ -4.79736328e-02,  -4.81262207e-02],
                        [ -2.10571289e-03,  -2.25830078e-03],
                        [  5.87768555e-02,   5.86547852e-02],
                        [  1.30004883e-01,   1.29882812e-01],
                        [  1.91833496e-01,   1.91711426e-01],
                        [  2.19940186e-01,   2.19818115e-01],
                        [  2.10662842e-01,   2.10540771e-01],
                        [  1.81304932e-01,   1.81182861e-01],
                        [  1.48162842e-01,   1.48040771e-01],
                        [  1.17126465e-01,   1.17004395e-01],
                        [  9.05456543e-02,   9.04235840e-02],
                        [  7.01904297e-02,   7.00683594e-02],
                        [  5.51452637e-02,   5.50537109e-02],
                        [  4.42504883e-02,   4.41589355e-02],
                        [  3.91235352e-02,   3.90014648e-02],
                        [  4.07409668e-02,   4.06494141e-02],
                        [  4.41284180e-02,   4.40368652e-02],
                        [  4.14733887e-02,   4.13818359e-02],
                        [  3.09143066e-02,   3.08227539e-02],
                        [  1.78222656e-02,   1.77307129e-02],
                        [  8.75854492e-03,   8.69750977e-03],
                        [  7.62939453e-03,   7.56835938e-03],
                        [  1.60827637e-02,   1.59912109e-02],
                        [  3.17687988e-02,   3.17077637e-02],
                        [  4.74853516e-02,   4.74243164e-02],
                        [  5.69458008e-02,   5.68847656e-02],
                        [  6.16455078e-02,   6.15844727e-02],
                        [  6.77795410e-02,   6.77185059e-02],
                        [  7.86743164e-02,   7.86132812e-02],
                        [  9.26818848e-02,   9.26513672e-02],
                        [  1.03881836e-01,   1.03851318e-01],
                        [  1.00769043e-01,   1.00738525e-01],
                        [  7.03735352e-02,   7.03430176e-02],
                        [  9.46044922e-03,   9.42993164e-03],
                        [ -6.99157715e-02,  -6.99462891e-02],
                        [ -1.46026611e-01,  -1.46087646e-01],
                        [ -1.95739746e-01,  -1.95770264e-01],
                        [ -2.03125000e-01,  -2.03155518e-01],
                        [ -1.70074463e-01,  -1.70104980e-01],
                        [ -1.18377686e-01,  -1.18408203e-01],
                        [ -7.49206543e-02,  -7.49206543e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -7.20214844e-02,  -7.20214844e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -8.14208984e-02,  -8.14208984e-02],
                        [ -7.93762207e-02,  -7.93762207e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -2.91442871e-02,  -2.91137695e-02],
                        [ -6.53076172e-03,  -6.50024414e-03],
                        [  1.00708008e-03,   1.03759766e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.48315430e-02,  -1.48010254e-02],
                        [ -2.16064453e-02,  -2.15759277e-02],
                        [ -2.99682617e-02,  -2.99377441e-02],
                        [ -4.57153320e-02,  -4.56848145e-02],
                        [ -6.68640137e-02,  -6.68029785e-02],
                        [ -8.32824707e-02,  -8.32214355e-02],
                        [ -8.24279785e-02,  -8.23974609e-02],
                        [ -5.75561523e-02,  -5.74951172e-02],
                        [ -1.40075684e-02,  -1.39465332e-02],
                        [  3.39660645e-02,   3.40270996e-02],
                        [  7.31811523e-02,   7.32421875e-02],
                        [  9.71069336e-02,   9.71679688e-02],
                        [  1.05560303e-01,   1.05621338e-01],
                        [  1.02233887e-01,   1.02294922e-01],
                        [  9.22851562e-02,   9.23461914e-02],
                        [  8.02307129e-02,   8.02917480e-02],
                        [  6.90917969e-02,   6.91528320e-02],
                        [  6.06994629e-02,   6.07910156e-02],
                        [  5.64880371e-02,   5.65795898e-02],
                        [  5.72204590e-02,   5.72814941e-02],
                        [  6.14318848e-02,   6.15234375e-02],
                        [  6.49108887e-02,   6.50024414e-02],
                        [  6.40258789e-02,   6.41174316e-02],
                        [  6.13098145e-02,   6.14013672e-02],
                        [  6.43920898e-02,   6.44836426e-02],
                        [  7.75451660e-02,   7.76367188e-02],
                        [  9.67102051e-02,   9.68322754e-02],
                        [  1.14318848e-01,   1.14410400e-01],
                        [  1.25244141e-01,   1.25366211e-01],
                        [  1.27380371e-01,   1.27502441e-01],
                        [  1.17980957e-01,   1.18072510e-01],
                        [  8.82263184e-02,   8.83483887e-02],
                        [  2.48718262e-02,   2.49938965e-02],
                        [ -7.38830566e-02,  -7.37609863e-02],
                        [ -1.84539795e-01,  -1.84417725e-01],
                        [ -2.69500732e-01,  -2.69378662e-01],
                        [ -3.02490234e-01,  -3.02368164e-01],
                        [ -2.81890869e-01,  -2.81768799e-01],
                        [ -2.27722168e-01,  -2.27600098e-01],
                        [ -1.70166016e-01,  -1.70043945e-01],
                        [ -1.30920410e-01,  -1.30798340e-01],
                        [ -1.10198975e-01,  -1.10076904e-01],
                        [ -9.58251953e-02,  -9.57031250e-02],
                        [ -8.14208984e-02,  -8.12988281e-02],
                        [ -6.84814453e-02,  -6.83593750e-02],
                        [ -5.66101074e-02,  -5.64880371e-02],
                        [ -4.19006348e-02,  -4.17785645e-02],
                        [ -2.30102539e-02,  -2.28881836e-02],
                        [ -4.05883789e-03,  -3.93676758e-03],
                        [  7.90405273e-03,   8.02612305e-03],
                        [  8.78906250e-03,   8.94165039e-03],
                        [  5.18798828e-04,   6.71386719e-04],
                        [ -1.40686035e-02,  -1.39465332e-02],
                        [ -3.58886719e-02,  -3.57666016e-02],
                        [ -6.28356934e-02,  -6.26831055e-02],
                        [ -8.27941895e-02,  -8.26721191e-02],
                        [ -8.17871094e-02,  -8.16650391e-02],
                        [ -5.67321777e-02,  -5.65795898e-02],
                        [ -1.46789551e-02,  -1.45568848e-02],
                        [  3.74450684e-02,   3.75671387e-02],
                        [  9.53979492e-02,   9.55200195e-02],
                        [  1.50878906e-01,   1.51031494e-01],
                        [  1.91284180e-01,   1.91406250e-01],
                        [  2.07733154e-01,   2.07855225e-01],
                        [  1.99951172e-01,   2.00073242e-01],
                        [  1.75079346e-01,   1.75201416e-01],
                        [  1.45233154e-01,   1.45355225e-01],
                        [  1.21307373e-01,   1.21429443e-01],
                        [  1.04675293e-01,   1.04827881e-01],
                        [  8.88671875e-02,   8.89892578e-02],
                        [  7.05261230e-02,   7.06481934e-02],
                        [  5.30395508e-02,   5.31616211e-02],
                        [  3.93676758e-02,   3.94897461e-02],
                        [  2.76489258e-02,   2.77709961e-02],
                        [  1.45263672e-02,   1.46484375e-02],
                        [ -9.15527344e-05,   3.05175781e-05],
                        [ -1.12304688e-02,  -1.11083984e-02],
                        [ -1.22680664e-02,  -1.21459961e-02],
                        [ -2.71606445e-03,  -2.62451172e-03],
                        [  9.30786133e-03,   9.39941406e-03],
                        [  1.63574219e-02,   1.64794922e-02],
                        [  1.96533203e-02,   1.97448730e-02],
                        [  2.45666504e-02,   2.46582031e-02],
                        [  3.35083008e-02,   3.35998535e-02],
                        [  4.57458496e-02,   4.58679199e-02],
                        [  5.98754883e-02,   5.99670410e-02],
                        [  7.39746094e-02,   7.40661621e-02],
                        [  8.64868164e-02,   8.65783691e-02],
                        [  9.66796875e-02,   9.67712402e-02],
                        [  1.02539062e-01,   1.02600098e-01],
                        [  9.67102051e-02,   9.68017578e-02],
                        [  6.60400391e-02,   6.61315918e-02],
                        [  5.18798828e-04,   5.79833984e-04],
                        [ -9.03930664e-02,  -9.03320312e-02],
                        [ -1.73767090e-01,  -1.73675537e-01],
                        [ -2.14599609e-01,  -2.14538574e-01],
                        [ -2.04132080e-01,  -2.04071045e-01],
                        [ -1.64398193e-01,  -1.64306641e-01],
                        [ -1.26403809e-01,  -1.26342773e-01],
                        [ -1.06201172e-01,  -1.06170654e-01],
                        [ -9.89379883e-02,  -9.88769531e-02],
                        [ -9.18273926e-02,  -9.17663574e-02],
                        [ -7.96203613e-02,  -7.95593262e-02],
                        [ -6.68334961e-02,  -6.68029785e-02],
                        [ -5.86547852e-02,  -5.85937500e-02],
                        [ -5.47790527e-02,  -5.47180176e-02],
                        [ -5.14221191e-02,  -5.13916016e-02],
                        [ -4.42810059e-02,  -4.42504883e-02],
                        [ -3.03649902e-02,  -3.03039551e-02],
                        [ -1.22680664e-02,  -1.22375488e-02],
                        [  7.01904297e-04,   7.32421875e-04],
                        [ -1.22070312e-04,  -9.15527344e-05],
                        [ -1.54418945e-02,  -1.53808594e-02],
                        [ -4.01000977e-02,  -4.00695801e-02],
                        [ -6.84204102e-02,  -6.83898926e-02],
                        [ -9.38415527e-02,  -9.37805176e-02],
                        [ -1.07604980e-01,  -1.07574463e-01],
                        [ -1.04644775e-01,  -1.04644775e-01],
                        [ -8.77685547e-02,  -8.77380371e-02],
                        [ -6.14013672e-02,  -6.13708496e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  7.31201172e-02,   7.31506348e-02],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  1.31561279e-01,   1.31561279e-01],
                        [  1.27746582e-01,   1.27746582e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  8.70971680e-02,   8.70666504e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  6.24389648e-02,   6.24084473e-02],
                        [  5.96313477e-02,   5.96008301e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  6.47277832e-02,   6.46972656e-02],
                        [  7.91320801e-02,   7.91015625e-02],
                        [  9.46350098e-02,   9.46044922e-02],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  1.07757568e-01,   1.07727051e-01],
                        [  1.09527588e-01,   1.09497070e-01],
                        [  1.15478516e-01,   1.15447998e-01],
                        [  1.26098633e-01,   1.26068115e-01],
                        [  1.32263184e-01,   1.32232666e-01],
                        [  1.17675781e-01,   1.17645264e-01],
                        [  6.79626465e-02,   6.79626465e-02],
                        [ -1.83715820e-02,  -1.84020996e-02],
                        [ -1.25885010e-01,  -1.25915527e-01],
                        [ -2.25769043e-01,  -2.25799561e-01],
                        [ -2.86102295e-01,  -2.86132812e-01],
                        [ -2.89093018e-01,  -2.89154053e-01],
                        [ -2.47070312e-01,  -2.47131348e-01],
                        [ -1.94824219e-01,  -1.94854736e-01],
                        [ -1.58294678e-01,  -1.58355713e-01],
                        [ -1.35528564e-01,  -1.35559082e-01],
                        [ -1.12976074e-01,  -1.13006592e-01],
                        [ -8.84399414e-02,  -8.84704590e-02],
                        [ -6.85119629e-02,  -6.86035156e-02],
                        [ -5.47790527e-02,  -5.48400879e-02],
                        [ -4.33044434e-02,  -4.33654785e-02],
                        [ -3.24096680e-02,  -3.24707031e-02],
                        [ -2.31323242e-02,  -2.32238770e-02],
                        [ -1.68151855e-02,  -1.68762207e-02],
                        [ -1.52587891e-02,  -1.52893066e-02],
                        [ -1.94091797e-02,  -1.95007324e-02],
                        [ -2.74353027e-02,  -2.74963379e-02],
                        [ -3.69567871e-02,  -3.70178223e-02],
                        [ -4.74548340e-02,  -4.75463867e-02],
                        [ -5.56945801e-02,  -5.57556152e-02],
                        [ -5.38024902e-02,  -5.38635254e-02],
                        [ -3.76281738e-02,  -3.76892090e-02],
                        [ -9.97924805e-03,  -1.00708008e-02],
                        [  2.99072266e-02,   2.98461914e-02],
                        [  8.78906250e-02,   8.78295898e-02],
                        [  1.56402588e-01,   1.56311035e-01],
                        [  2.07000732e-01,   2.06909180e-01],
                        [  2.14111328e-01,   2.14050293e-01],
                        [  1.81884766e-01,   1.81793213e-01],
                        [  1.40960693e-01,   1.40869141e-01],
                        [  1.19445801e-01,   1.19384766e-01],
                        [  1.18194580e-01,   1.18133545e-01],
                        [  1.16546631e-01,   1.16455078e-01],
                        [  1.00646973e-01,   1.00585938e-01],
                        [  7.77893066e-02,   7.77282715e-02],
                        [  6.10961914e-02,   6.10046387e-02],
                        [  5.18798828e-02,   5.17883301e-02],
                        [  4.33959961e-02,   4.33349609e-02],
                        [  3.25317383e-02,   3.24401855e-02],
                        [  2.10266113e-02,   2.09350586e-02],
                        [  1.10168457e-02,   1.09558105e-02],
                        [  3.35693359e-03,   3.26538086e-03],
                        [ -1.77001953e-03,  -1.86157227e-03],
                        [ -4.54711914e-03,  -4.63867188e-03],
                        [ -5.09643555e-03,  -5.15747070e-03],
                        [ -2.89916992e-03,  -2.99072266e-03],
                        [  2.22778320e-03,   2.13623047e-03],
                        [  9.42993164e-03,   9.33837891e-03],
                        [  1.78527832e-02,   1.77612305e-02],
                        [  2.85034180e-02,   2.84118652e-02],
                        [  4.36096191e-02,   4.35485840e-02],
                        [  6.27441406e-02,   6.26525879e-02],
                        [  8.13293457e-02,   8.12377930e-02],
                        [  9.52758789e-02,   9.51843262e-02],
                        [  1.04095459e-01,   1.04034424e-01],
                        [  1.06048584e-01,   1.05987549e-01],
                        [  9.20104980e-02,   9.19494629e-02],
                        [  4.94079590e-02,   4.93469238e-02],
                        [ -2.49938965e-02,  -2.50549316e-02],
                        [ -1.14685059e-01,  -1.14776611e-01],
                        [ -1.87530518e-01,  -1.87591553e-01],
                        [ -2.15637207e-01,  -2.15698242e-01],
                        [ -1.96685791e-01,  -1.96777344e-01],
                        [ -1.54571533e-01,  -1.54632568e-01],
                        [ -1.16912842e-01,  -1.16973877e-01],
                        [ -9.41467285e-02,  -9.42077637e-02],
                        [ -8.01391602e-02,  -8.02001953e-02],
                        [ -6.73217773e-02,  -6.74133301e-02],
                        [ -5.51452637e-02,  -5.52062988e-02],
                        [ -4.78515625e-02,  -4.79125977e-02],
                        [ -4.90722656e-02,  -4.91333008e-02],
                        [ -5.53894043e-02,  -5.54504395e-02],
                        [ -5.58776855e-02,  -5.59387207e-02],
                        [ -4.37316895e-02,  -4.37927246e-02],
                        [ -2.62756348e-02,  -2.63366699e-02],
                        [ -1.71813965e-02,  -1.72424316e-02],
                        [ -2.06909180e-02,  -2.07519531e-02],
                        [ -3.08837891e-02,  -3.09448242e-02],
                        [ -4.33044434e-02,  -4.33654785e-02],
                        [ -5.88989258e-02,  -5.89599609e-02],
                        [ -7.69653320e-02,  -7.70263672e-02],
                        [ -9.18579102e-02,  -9.18884277e-02],
                        [ -9.86328125e-02,  -9.86633301e-02],
                        [ -9.59167480e-02,  -9.59777832e-02],
                        [ -8.07189941e-02,  -8.07800293e-02],
                        [ -4.69970703e-02,  -4.70275879e-02],
                        [  5.06591797e-03,   5.03540039e-03],
                        [  6.17065430e-02,   6.16760254e-02],
                        [  1.03668213e-01,   1.03637695e-01],
                        [  1.20635986e-01,   1.20574951e-01],
                        [  1.15844727e-01,   1.15814209e-01],
                        [  9.95178223e-02,   9.94873047e-02],
                        [  8.22753906e-02,   8.22448730e-02],
                        [  7.29675293e-02,   7.29370117e-02],
                        [  7.45544434e-02,   7.45239258e-02],
                        [  7.94982910e-02,   7.94677734e-02],
                        [  7.82470703e-02,   7.82165527e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  7.81555176e-02,   7.81555176e-02],
                        [  9.22851562e-02,   9.22241211e-02],
                        [  1.04309082e-01,   1.04278564e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.12731934e-01,   1.12701416e-01],
                        [  1.22528076e-01,   1.22497559e-01],
                        [  1.33758545e-01,   1.33758545e-01],
                        [  1.36108398e-01,   1.36108398e-01],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  3.47900391e-03,   3.44848633e-03],
                        [ -9.20715332e-02,  -9.21020508e-02],
                        [ -1.90887451e-01,  -1.90887451e-01],
                        [ -2.62298584e-01,  -2.62298584e-01],
                        [ -2.82043457e-01,  -2.82073975e-01],
                        [ -2.51281738e-01,  -2.51281738e-01],
                        [ -1.96105957e-01,  -1.96105957e-01],
                        [ -1.47491455e-01,  -1.47491455e-01],
                        [ -1.21368408e-01,  -1.21368408e-01],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -1.09252930e-01,  -1.09222412e-01],
                        [ -9.72900391e-02,  -9.72900391e-02],
                        [ -7.86743164e-02,  -7.86743164e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.57666016e-02,  -3.57360840e-02],
                        [ -3.53088379e-02,  -3.52783203e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -2.85034180e-02,  -2.84729004e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  1.60247803e-01,   1.60278320e-01],
                        [  1.92779541e-01,   1.92779541e-01],
                        [  1.94335938e-01,   1.94335938e-01],
                        [  1.67327881e-01,   1.67358398e-01],
                        [  1.34735107e-01,   1.34765625e-01],
                        [  1.19171143e-01,   1.19201660e-01],
                        [  1.20178223e-01,   1.20208740e-01],
                        [  1.20330811e-01,   1.20391846e-01],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  6.10656738e-02,   6.11267090e-02],
                        [  4.27246094e-02,   4.27856445e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.06604004e-02,   2.06909180e-02],
                        [  1.36108398e-02,   1.36718750e-02],
                        [  6.40869141e-03,   6.43920898e-03],
                        [ -2.92968750e-03,  -2.89916992e-03],
                        [ -1.02539062e-02,  -1.02233887e-02],
                        [ -9.27734375e-03,  -9.21630859e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  5.37109375e-03,   5.40161133e-03],
                        [  9.73510742e-03,   9.76562500e-03],
                        [  1.49536133e-02,   1.49841309e-02],
                        [  2.00500488e-02,   2.00805664e-02],
                        [  1.91650391e-02,   1.91955566e-02],
                        [  1.24511719e-02,   1.24816895e-02],
                        [  9.42993164e-03,   9.46044922e-03],
                        [  1.89514160e-02,   1.89819336e-02],
                        [  4.00085449e-02,   4.00390625e-02],
                        [  6.39038086e-02,   6.39343262e-02],
                        [  8.30688477e-02,   8.30993652e-02],
                        [  9.53063965e-02,   9.53369141e-02],
                        [  9.74121094e-02,   9.74731445e-02],
                        [  7.62634277e-02,   7.62939453e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [ -7.56225586e-02,  -7.55615234e-02],
                        [ -1.61621094e-01,  -1.61560059e-01],
                        [ -2.03338623e-01,  -2.03338623e-01],
                        [ -1.93908691e-01,  -1.93878174e-01],
                        [ -1.56097412e-01,  -1.56036377e-01],
                        [ -1.17156982e-01,  -1.17126465e-01],
                        [ -9.14001465e-02,  -9.14001465e-02],
                        [ -7.86743164e-02,  -7.86437988e-02],
                        [ -7.17468262e-02,  -7.16857910e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -6.43920898e-02,  -6.43615723e-02],
                        [ -7.01293945e-02,  -7.00683594e-02],
                        [ -7.69348145e-02,  -7.69042969e-02],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -5.86547852e-02,  -5.85937500e-02],
                        [ -4.44335938e-02,  -4.43725586e-02],
                        [ -4.04968262e-02,  -4.04663086e-02],
                        [ -4.33654785e-02,  -4.33349609e-02],
                        [ -4.50439453e-02,  -4.49829102e-02],
                        [ -4.58679199e-02,  -4.58374023e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -6.92138672e-02,  -6.91833496e-02],
                        [ -8.77685547e-02,  -8.77075195e-02],
                        [ -9.73510742e-02,  -9.73510742e-02],
                        [ -9.02709961e-02,  -9.02404785e-02],
                        [ -6.58264160e-02,  -6.57653809e-02],
                        [ -2.89001465e-02,  -2.88696289e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.59082031e-02,   5.59692383e-02],
                        [  8.88061523e-02,   8.88671875e-02],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  1.08459473e-01,   1.08489990e-01],
                        [  1.06109619e-01,   1.06140137e-01],
                        [  1.06262207e-01,   1.06292725e-01],
                        [  1.08764648e-01,   1.08764648e-01],
                        [  1.08856201e-01,   1.08886719e-01],
                        [  1.02966309e-01,   1.02996826e-01],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  8.96301270e-02,   8.96606445e-02],
                        [  9.64965820e-02,   9.65270996e-02],
                        [  1.08825684e-01,   1.08856201e-01],
                        [  1.16027832e-01,   1.16058350e-01],
                        [  1.16333008e-01,   1.16363525e-01],
                        [  1.19384766e-01,   1.19415283e-01],
                        [  1.32232666e-01,   1.32263184e-01],
                        [  1.44287109e-01,   1.44317627e-01],
                        [  1.31835938e-01,   1.31866455e-01],
                        [  8.06274414e-02,   8.06274414e-02],
                        [ -6.40869141e-04,  -6.10351562e-04],
                        [ -9.20410156e-02,  -9.20104980e-02],
                        [ -1.80053711e-01,  -1.80023193e-01],
                        [ -2.53387451e-01,  -2.53387451e-01],
                        [ -2.90557861e-01,  -2.90527344e-01],
                        [ -2.73071289e-01,  -2.73071289e-01],
                        [ -2.14813232e-01,  -2.14782715e-01],
                        [ -1.57714844e-01,  -1.57714844e-01],
                        [ -1.30035400e-01,  -1.30035400e-01],
                        [ -1.22924805e-01,  -1.22894287e-01],
                        [ -1.14868164e-01,  -1.14837646e-01],
                        [ -1.01470947e-01,  -1.01440430e-01],
                        [ -9.02099609e-02,  -9.01794434e-02],
                        [ -8.04443359e-02,  -8.04138184e-02],
                        [ -6.39343262e-02,  -6.39038086e-02],
                        [ -4.00390625e-02,  -4.00085449e-02],
                        [ -1.85852051e-02,  -1.85546875e-02],
                        [ -8.54492188e-03,  -8.51440430e-03],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -1.98364258e-02,  -1.98059082e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  1.33666992e-01,   1.33697510e-01],
                        [  1.77917480e-01,   1.77917480e-01],
                        [  1.99584961e-01,   1.99554443e-01],
                        [  1.94183350e-01,   1.94183350e-01],
                        [  1.70318604e-01,   1.70318604e-01],
                        [  1.42730713e-01,   1.42730713e-01],
                        [  1.21246338e-01,   1.21246338e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  8.28857422e-02,   8.28552246e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  5.76782227e-02,   5.77087402e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  5.10864258e-02,   5.10864258e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.29895020e-02,  -3.30200195e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  2.81677246e-02,   2.81372070e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.10046387e-01,   1.10046387e-01],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -8.18786621e-02,  -8.19091797e-02],
                        [ -1.61804199e-01,  -1.61804199e-01],
                        [ -1.99127197e-01,  -1.99127197e-01],
                        [ -1.84082031e-01,  -1.84082031e-01],
                        [ -1.39892578e-01,  -1.39923096e-01],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -8.80737305e-02,  -8.80737305e-02],
                        [ -8.93859863e-02,  -8.94165039e-02],
                        [ -8.92333984e-02,  -8.92333984e-02],
                        [ -8.24279785e-02,  -8.24279785e-02],
                        [ -7.57751465e-02,  -7.58056641e-02],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -6.98242188e-02,  -6.98242188e-02],
                        [ -6.38122559e-02,  -6.38427734e-02],
                        [ -5.82275391e-02,  -5.82580566e-02],
                        [ -5.27954102e-02,  -5.27648926e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -6.29272461e-02,  -6.29577637e-02],
                        [ -8.19702148e-02,  -8.19702148e-02],
                        [ -9.45129395e-02,  -9.45129395e-02],
                        [ -8.80737305e-02,  -8.80737305e-02],
                        [ -6.28051758e-02,  -6.28356934e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [  1.55029297e-02,   1.54724121e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.28570557e-01,   1.28570557e-01],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  1.08734131e-01,   1.08764648e-01],
                        [  1.08184814e-01,   1.08154297e-01],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  9.86633301e-02,   9.86633301e-02],
                        [  1.08032227e-01,   1.08001709e-01],
                        [  1.22222900e-01,   1.22222900e-01],
                        [  1.37695312e-01,   1.37695312e-01],
                        [  1.51489258e-01,   1.51489258e-01],
                        [  1.55670166e-01,   1.55670166e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  8.19702148e-02,   8.19702148e-02],
                        [ -5.61523438e-03,  -5.64575195e-03],
                        [ -1.12121582e-01,  -1.12121582e-01],
                        [ -2.15667725e-01,  -2.15667725e-01],
                        [ -2.90985107e-01,  -2.90985107e-01],
                        [ -3.14056396e-01,  -3.14056396e-01],
                        [ -2.78533936e-01,  -2.78533936e-01],
                        [ -2.11181641e-01,  -2.11181641e-01],
                        [ -1.54724121e-01,  -1.54724121e-01],
                        [ -1.28204346e-01,  -1.28234863e-01],
                        [ -1.16699219e-01,  -1.16729736e-01],
                        [ -1.01959229e-01,  -1.01959229e-01],
                        [ -8.54492188e-02,  -8.54492188e-02],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  7.07702637e-02,   7.07702637e-02],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.66595459e-01,   1.66595459e-01],
                        [  1.91619873e-01,   1.91619873e-01],
                        [  1.95343018e-01,   1.95343018e-01],
                        [  1.80389404e-01,   1.80389404e-01],
                        [  1.59637451e-01,   1.59637451e-01],
                        [  1.44195557e-01,   1.44226074e-01],
                        [  1.29608154e-01,   1.29577637e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  8.16650391e-02,   8.16955566e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  5.96923828e-02,   5.96618652e-02],
                        [  5.58471680e-02,   5.58776855e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.92858887e-02,   4.92553711e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [ -5.06591797e-03,  -5.09643555e-03],
                        [ -2.39868164e-02,  -2.40173340e-02],
                        [ -3.41186523e-02,  -3.40881348e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -2.31628418e-02,  -2.31933594e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.89514160e-02,   1.89208984e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.89514160e-02,   1.89819336e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  2.84729004e-02,   2.84423828e-02],
                        [  2.79541016e-02,   2.79846191e-02],
                        [  3.16467285e-02,   3.16467285e-02],
                        [  4.36706543e-02,   4.36401367e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  6.79321289e-02,   6.79626465e-02],
                        [  7.81860352e-02,   7.82165527e-02],
                        [  8.65783691e-02,   8.65478516e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [ -1.71203613e-02,  -1.71508789e-02],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -1.70593262e-01,  -1.70562744e-01],
                        [ -1.99890137e-01,  -1.99890137e-01],
                        [ -1.77917480e-01,  -1.77947998e-01],
                        [ -1.26464844e-01,  -1.26434326e-01],
                        [ -8.24890137e-02,  -8.24584961e-02],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [ -7.79724121e-02,  -7.80029297e-02],
                        [ -8.61816406e-02,  -8.61816406e-02],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -7.91931152e-02,  -7.91931152e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -8.06579590e-02,  -8.06274414e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -7.87658691e-02,  -7.87963867e-02],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -7.62329102e-02,  -7.62634277e-02],
                        [ -7.94067383e-02,  -7.94067383e-02],
                        [ -7.64465332e-02,  -7.64465332e-02],
                        [ -6.39038086e-02,  -6.38732910e-02],
                        [ -3.61633301e-02,  -3.61938477e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  4.71496582e-02,   4.71801758e-02],
                        [  8.54187012e-02,   8.53881836e-02],
                        [  1.13037109e-01,   1.13037109e-01],
                        [  1.24938965e-01,   1.24969482e-01],
                        [  1.19293213e-01,   1.19293213e-01],
                        [  1.02325439e-01,   1.02294922e-01],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  8.37402344e-02,   8.37707520e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  9.59472656e-02,   9.59472656e-02],
                        [  9.77783203e-02,   9.78088379e-02],
                        [  9.87548828e-02,   9.87548828e-02],
                        [  1.06140137e-01,   1.06109619e-01],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.77886963e-01,   1.77856445e-01],
                        [  1.85089111e-01,   1.85089111e-01],
                        [  1.69403076e-01,   1.69403076e-01],
                        [  1.31164551e-01,   1.31164551e-01],
                        [  6.77490234e-02,   6.77490234e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -1.37237549e-01,  -1.37237549e-01],
                        [ -2.42675781e-01,  -2.42675781e-01],
                        [ -3.06884766e-01,  -3.06884766e-01],
                        [ -3.12286377e-01,  -3.12286377e-01],
                        [ -2.70629883e-01,  -2.70629883e-01],
                        [ -2.13653564e-01,  -2.13653564e-01],
                        [ -1.68365479e-01,  -1.68365479e-01],
                        [ -1.39984131e-01,  -1.39984131e-01],
                        [ -1.16699219e-01,  -1.16699219e-01],
                        [ -8.89282227e-02,  -8.89282227e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.41894531e-02,  -4.41589355e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.19311523e-02,  -4.19616699e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.77600098e-02,  -4.77294922e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [  1.91650391e-02,   1.91955566e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.86157227e-01,   1.86157227e-01],
                        [  2.15454102e-01,   2.15454102e-01],
                        [  2.20336914e-01,   2.20336914e-01],
                        [  2.03674316e-01,   2.03674316e-01],
                        [  1.77795410e-01,   1.77825928e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.36718750e-01,   1.36688232e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  9.51232910e-02,   9.51538086e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  5.41076660e-02,   5.41076660e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  4.56237793e-02,   4.55932617e-02],
                        [  3.61633301e-02,   3.61938477e-02],
                        [  2.91442871e-02,   2.91748047e-02],
                        [  2.25524902e-02,   2.25219727e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -3.05175781e-03,  -3.02124023e-03],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  2.11791992e-02,   2.12097168e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.58886719e-02,   3.58581543e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  7.82470703e-02,   7.82470703e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -1.11724854e-01,  -1.11724854e-01],
                        [ -1.76361084e-01,  -1.76361084e-01],
                        [ -1.99615479e-01,  -1.99615479e-01],
                        [ -1.76605225e-01,  -1.76605225e-01],
                        [ -1.27136230e-01,  -1.27105713e-01],
                        [ -8.45336914e-02,  -8.45336914e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -7.65686035e-02,  -7.65380859e-02],
                        [ -8.33740234e-02,  -8.33740234e-02],
                        [ -8.05358887e-02,  -8.05664062e-02],
                        [ -7.40661621e-02,  -7.40661621e-02],
                        [ -7.16857910e-02,  -7.16857910e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -7.27233887e-02,  -7.27233887e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.84509277e-02,  -6.84509277e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -6.72912598e-02,  -6.73217773e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  6.82373047e-02,   6.82373047e-02],
                        [  1.06628418e-01,   1.06628418e-01],
                        [  1.28540039e-01,   1.28540039e-01],
                        [  1.31378174e-01,   1.31378174e-01],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  7.91931152e-02,   7.91931152e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  1.04614258e-01,   1.04614258e-01],
                        [  1.15936279e-01,   1.15936279e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.47888184e-01,   1.47888184e-01],
                        [  1.73126221e-01,   1.73126221e-01],
                        [  1.95098877e-01,   1.95129395e-01],
                        [  1.97174072e-01,   1.97143555e-01],
                        [  1.67083740e-01,   1.67083740e-01],
                        [  1.02996826e-01,   1.02996826e-01],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -1.00402832e-01,  -1.00402832e-01],
                        [ -2.09777832e-01,  -2.09777832e-01],
                        [ -2.92236328e-01,  -2.92236328e-01],
                        [ -3.21075439e-01,  -3.21075439e-01],
                        [ -2.84332275e-01,  -2.84332275e-01],
                        [ -2.04864502e-01,  -2.04864502e-01],
                        [ -1.34063721e-01,  -1.34063721e-01],
                        [ -1.07086182e-01,  -1.07086182e-01],
                        [ -1.10748291e-01,  -1.10748291e-01],
                        [ -1.09436035e-01,  -1.09436035e-01],
                        [ -9.12170410e-02,  -9.12170410e-02],
                        [ -7.20520020e-02,  -7.20520020e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -7.20520020e-02,  -7.20520020e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -2.51159668e-02,  -2.51464844e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.85302734e-01,   1.85302734e-01],
                        [  2.06268311e-01,   2.06298828e-01],
                        [  1.97296143e-01,   1.97296143e-01],
                        [  1.69342041e-01,   1.69342041e-01],
                        [  1.41937256e-01,   1.41937256e-01],
                        [  1.25793457e-01,   1.25793457e-01],
                        [  1.16760254e-01,   1.16760254e-01],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  7.78198242e-02,   7.78198242e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  2.68859863e-02,   2.68554688e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [ -8.78906250e-03,  -8.75854492e-03],
                        [ -1.12304688e-02,  -1.12609863e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.79443359e-02,  -1.79138184e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -2.68554688e-02,  -2.68249512e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  1.83105469e-03,   1.86157227e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  5.21240234e-02,   5.21240234e-02],
                        [  6.95495605e-02,   6.95495605e-02],
                        [  8.34350586e-02,   8.34350586e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  8.95996094e-02,   8.96301270e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -1.34277344e-01,  -1.34277344e-01],
                        [ -1.74835205e-01,  -1.74865723e-01],
                        [ -1.80114746e-01,  -1.80114746e-01],
                        [ -1.56219482e-01,  -1.56219482e-01],
                        [ -1.27410889e-01,  -1.27410889e-01],
                        [ -1.11480713e-01,  -1.11480713e-01],
                        [ -1.05743408e-01,  -1.05743408e-01],
                        [ -1.00921631e-01,  -1.00921631e-01],
                        [ -9.45739746e-02,  -9.45739746e-02],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -8.13293457e-02,  -8.13293457e-02],
                        [ -7.59887695e-02,  -7.59582520e-02],
                        [ -7.19909668e-02,  -7.19909668e-02],
                        [ -6.66503906e-02,  -6.66809082e-02],
                        [ -5.85327148e-02,  -5.85021973e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.01098633e-02,  -5.01403809e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -6.65588379e-02,  -6.65283203e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -3.29284668e-02,  -3.29589844e-02],
                        [  7.56835938e-03,   7.59887695e-03],
                        [  5.42297363e-02,   5.42602539e-02],
                        [  9.44519043e-02,   9.44213867e-02],
                        [  1.20391846e-01,   1.20391846e-01],
                        [  1.31256104e-01,   1.31286621e-01],
                        [  1.28814697e-01,   1.28784180e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  1.00341797e-01,   1.00341797e-01],
                        [  9.10339355e-02,   9.10339355e-02],
                        [  9.14001465e-02,   9.13696289e-02],
                        [  9.87548828e-02,   9.87854004e-02],
                        [  1.11328125e-01,   1.11358643e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.51611328e-01,   1.51580811e-01],
                        [  1.74194336e-01,   1.74224854e-01],
                        [  1.90155029e-01,   1.90155029e-01],
                        [  1.87652588e-01,   1.87622070e-01],
                        [  1.53411865e-01,   1.53411865e-01],
                        [  8.12072754e-02,   8.12377930e-02],
                        [ -2.30407715e-02,  -2.30712891e-02],
                        [ -1.42456055e-01,  -1.42456055e-01],
                        [ -2.51281738e-01,  -2.51251221e-01],
                        [ -3.18359375e-01,  -3.18359375e-01],
                        [ -3.19946289e-01,  -3.19946289e-01],
                        [ -2.61322021e-01,  -2.61322021e-01],
                        [ -1.82525635e-01,  -1.82525635e-01],
                        [ -1.28845215e-01,  -1.28845215e-01],
                        [ -1.12884521e-01,  -1.12884521e-01],
                        [ -1.13983154e-01,  -1.13983154e-01],
                        [ -1.09649658e-01,  -1.09649658e-01],
                        [ -9.50317383e-02,  -9.50317383e-02],
                        [ -7.61108398e-02,  -7.61108398e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -4.50134277e-02,  -4.50439453e-02],
                        [ -3.45458984e-02,  -3.45764160e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -1.83410645e-02,  -1.83105469e-02],
                        [ -1.54724121e-02,  -1.55029297e-02],
                        [ -1.47094727e-02,  -1.46789551e-02],
                        [ -1.06201172e-02,  -1.05895996e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.59179688e-01,   1.59179688e-01],
                        [  1.98242188e-01,   1.98242188e-01],
                        [  2.08343506e-01,   2.08343506e-01],
                        [  1.95678711e-01,   1.95648193e-01],
                        [  1.75323486e-01,   1.75323486e-01],
                        [  1.56158447e-01,   1.56158447e-01],
                        [  1.36810303e-01,   1.36810303e-01],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  9.24072266e-02,   9.24072266e-02],
                        [  8.46252441e-02,   8.45947266e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  4.85229492e-03,   4.88281250e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -2.28881836e-03,  -2.31933594e-03],
                        [ -6.50024414e-03,  -6.46972656e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  8.90197754e-02,   8.90197754e-02],
                        [  1.07360840e-01,   1.07360840e-01],
                        [  1.16088867e-01,   1.16088867e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  8.78295898e-02,   8.77990723e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -1.29882812e-01,  -1.29882812e-01],
                        [ -1.88507080e-01,  -1.88507080e-01],
                        [ -2.08587646e-01,  -2.08587646e-01],
                        [ -1.92749023e-01,  -1.92749023e-01],
                        [ -1.60736084e-01,  -1.60736084e-01],
                        [ -1.32568359e-01,  -1.32568359e-01],
                        [ -1.13586426e-01,  -1.13555908e-01],
                        [ -9.77783203e-02,  -9.77783203e-02],
                        [ -8.16955566e-02,  -8.16955566e-02],
                        [ -7.02514648e-02,  -7.02514648e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -8.27941895e-02,  -8.27636719e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -7.15637207e-02,  -7.15637207e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -6.29577637e-02,  -6.29272461e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -7.18994141e-02,  -7.18994141e-02],
                        [ -7.64465332e-02,  -7.64465332e-02],
                        [ -6.90307617e-02,  -6.90612793e-02],
                        [ -4.27246094e-02,  -4.26940918e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  9.35668945e-02,   9.35363770e-02],
                        [  1.09375000e-01,   1.09405518e-01],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  1.08276367e-01,   1.08276367e-01],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  1.12152100e-01,   1.12152100e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.54724121e-01,   1.54724121e-01],
                        [  1.77856445e-01,   1.77856445e-01],
                        [  1.97235107e-01,   1.97235107e-01],
                        [  2.04681396e-01,   2.04681396e-01],
                        [  1.90032959e-01,   1.90032959e-01],
                        [  1.43829346e-01,   1.43829346e-01],
                        [  6.16760254e-02,   6.16760254e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -1.66137695e-01,  -1.66137695e-01],
                        [ -2.63000488e-01,  -2.63000488e-01],
                        [ -3.17504883e-01,  -3.17504883e-01],
                        [ -3.17962646e-01,  -3.17962646e-01],
                        [ -2.67974854e-01,  -2.67974854e-01],
                        [ -1.91986084e-01,  -1.91986084e-01],
                        [ -1.26617432e-01,  -1.26617432e-01],
                        [ -9.52453613e-02,  -9.52453613e-02],
                        [ -9.10034180e-02,  -9.10034180e-02],
                        [ -9.06372070e-02,  -9.06372070e-02],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -7.30285645e-02,  -7.30285645e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -7.06787109e-02,  -7.06787109e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -6.98547363e-02,  -6.98547363e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -7.77282715e-02,  -7.77282715e-02],
                        [ -6.64367676e-02,  -6.64672852e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  7.46154785e-02,   7.45849609e-02],
                        [  1.32171631e-01,   1.32171631e-01],
                        [  1.76635742e-01,   1.76635742e-01],
                        [  2.01293945e-01,   2.01293945e-01],
                        [  2.01599121e-01,   2.01568604e-01],
                        [  1.82922363e-01,   1.82952881e-01],
                        [  1.61285400e-01,   1.61315918e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.34735107e-01,   1.34735107e-01],
                        [  1.22619629e-01,   1.22650146e-01],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  9.75646973e-02,   9.75341797e-02],
                        [  7.83996582e-02,   7.84301758e-02],
                        [  5.97839355e-02,   5.98144531e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -3.37829590e-02,  -3.37524414e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.22570801e-02,  -3.22875977e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  8.08105469e-02,   8.07800293e-02],
                        [  8.69140625e-02,   8.69140625e-02],
                        [  8.11462402e-02,   8.11462402e-02],
                        [  4.48608398e-02,   4.48303223e-02],
                        [ -2.53295898e-02,  -2.52990723e-02],
                        [ -1.07482910e-01,  -1.07452393e-01],
                        [ -1.69891357e-01,  -1.69891357e-01],
                        [ -1.91497803e-01,  -1.91497803e-01],
                        [ -1.72454834e-01,  -1.72424316e-01],
                        [ -1.34918213e-01,  -1.34918213e-01],
                        [ -1.08581543e-01,  -1.08612061e-01],
                        [ -1.04736328e-01,  -1.04736328e-01],
                        [ -1.09893799e-01,  -1.09893799e-01],
                        [ -1.08032227e-01,  -1.08032227e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -9.11254883e-02,  -9.10949707e-02],
                        [ -9.15832520e-02,  -9.15832520e-02],
                        [ -9.71679688e-02,  -9.71679688e-02],
                        [ -9.60083008e-02,  -9.60083008e-02],
                        [ -7.81555176e-02,  -7.81555176e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -5.49621582e-02,  -5.49926758e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [  1.63574219e-02,   1.63269043e-02],
                        [  5.93872070e-02,   5.93872070e-02],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  1.11267090e-01,   1.11267090e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.03454590e-01,   1.03424072e-01],
                        [  1.04125977e-01,   1.04125977e-01],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.26434326e-01,   1.26403809e-01],
                        [  1.45355225e-01,   1.45355225e-01],
                        [  1.72302246e-01,   1.72332764e-01],
                        [  1.95648193e-01,   1.95648193e-01],
                        [  2.03002930e-01,   2.03002930e-01],
                        [  1.90734863e-01,   1.90765381e-01],
                        [  1.58508301e-01,   1.58477783e-01],
                        [  1.01135254e-01,   1.01135254e-01],
                        [  1.42517090e-02,   1.42822266e-02],
                        [ -9.54284668e-02,  -9.54284668e-02],
                        [ -2.06237793e-01,  -2.06268311e-01],
                        [ -2.86773682e-01,  -2.86773682e-01],
                        [ -3.11218262e-01,  -3.11218262e-01],
                        [ -2.78656006e-01,  -2.78656006e-01],
                        [ -2.15820312e-01,  -2.15820312e-01],
                        [ -1.57012939e-01,  -1.56982422e-01],
                        [ -1.20971680e-01,  -1.20971680e-01],
                        [ -1.04675293e-01,  -1.04675293e-01],
                        [ -9.38720703e-02,  -9.38415527e-02],
                        [ -7.96813965e-02,  -7.96813965e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -6.43615723e-02,  -6.43615723e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  5.50842285e-02,   5.51147461e-02],
                        [  9.63745117e-02,   9.63745117e-02],
                        [  1.41784668e-01,   1.41784668e-01],
                        [  1.78039551e-01,   1.78070068e-01],
                        [  1.90429688e-01,   1.90429688e-01],
                        [  1.77185059e-01,   1.77185059e-01],
                        [  1.52282715e-01,   1.52252197e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.25305176e-01,   1.25274658e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  8.72802734e-02,   8.72802734e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.85034180e-02,  -2.84729004e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -5.49316406e-03,  -5.52368164e-03],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -1.45874023e-02,  -1.46179199e-02],
                        [ -1.13830566e-02,  -1.13525391e-02],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [  2.62451172e-03,   2.59399414e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  3.59191895e-02,   3.58886719e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  8.56933594e-02,   8.56933594e-02],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  7.83386230e-02,   7.83691406e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -7.99255371e-02,  -7.99255371e-02],
                        [ -1.44744873e-01,  -1.44744873e-01],
                        [ -1.77124023e-01,  -1.77124023e-01],
                        [ -1.68212891e-01,  -1.68212891e-01],
                        [ -1.39099121e-01,  -1.39068604e-01],
                        [ -1.18316650e-01,  -1.18316650e-01],
                        [ -1.15844727e-01,  -1.15844727e-01],
                        [ -1.22955322e-01,  -1.22955322e-01],
                        [ -1.27288818e-01,  -1.27258301e-01],
                        [ -1.21520996e-01,  -1.21520996e-01],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -9.21936035e-02,  -9.21936035e-02],
                        [ -9.60083008e-02,  -9.60083008e-02],
                        [ -9.17663574e-02,  -9.17663574e-02],
                        [ -7.47985840e-02,  -7.47985840e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  9.50622559e-02,   9.50927734e-02],
                        [  9.25903320e-02,   9.25903320e-02],
                        [  9.90905762e-02,   9.90600586e-02],
                        [  1.10046387e-01,   1.10046387e-01],
                        [  1.20697021e-01,   1.20697021e-01],
                        [  1.29241943e-01,   1.29211426e-01],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.56280518e-01,   1.56311035e-01],
                        [  1.85150146e-01,   1.85119629e-01],
                        [  2.12188721e-01,   2.12219238e-01],
                        [  2.17956543e-01,   2.17987061e-01],
                        [  1.90307617e-01,   1.90307617e-01],
                        [  1.26708984e-01,   1.26708984e-01],
                        [  3.19213867e-02,   3.19519043e-02],
                        [ -8.08410645e-02,  -8.08410645e-02],
                        [ -1.91589355e-01,  -1.91619873e-01],
                        [ -2.77648926e-01,  -2.77648926e-01],
                        [ -3.16864014e-01,  -3.16833496e-01],
                        [ -2.98034668e-01,  -2.98034668e-01],
                        [ -2.36450195e-01,  -2.36450195e-01],
                        [ -1.70288086e-01,  -1.70288086e-01],
                        [ -1.31072998e-01,  -1.31072998e-01],
                        [ -1.20178223e-01,  -1.20208740e-01],
                        [ -1.16363525e-01,  -1.16363525e-01],
                        [ -1.01715088e-01,  -1.01684570e-01],
                        [ -7.83691406e-02,  -7.83996582e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -7.34252930e-02,  -7.34252930e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -7.37304688e-02,  -7.37304688e-02],
                        [ -6.67724609e-02,  -6.67419434e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  1.41448975e-01,   1.41448975e-01],
                        [  1.85943604e-01,   1.85943604e-01],
                        [  2.05017090e-01,   2.05017090e-01],
                        [  1.97326660e-01,   1.97326660e-01],
                        [  1.74865723e-01,   1.74865723e-01],
                        [  1.51580811e-01,   1.51580811e-01],
                        [  1.35284424e-01,   1.35284424e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.20666504e-01,   1.20666504e-01],
                        [  1.08123779e-01,   1.08123779e-01],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.44348145e-02,  -1.44042969e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  1.98669434e-02,   1.98364258e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  1.06048584e-01,   1.06079102e-01],
                        [  1.07208252e-01,   1.07208252e-01],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -1.16058350e-01,  -1.16088867e-01],
                        [ -1.80877686e-01,  -1.80877686e-01],
                        [ -2.14233398e-01,  -2.14202881e-01],
                        [ -2.09747314e-01,  -2.09747314e-01],
                        [ -1.79626465e-01,  -1.79626465e-01],
                        [ -1.45324707e-01,  -1.45324707e-01],
                        [ -1.18896484e-01,  -1.18896484e-01],
                        [ -1.01470947e-01,  -1.01470947e-01],
                        [ -9.39941406e-02,  -9.39941406e-02],
                        [ -9.73205566e-02,  -9.73205566e-02],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -1.13006592e-01,  -1.13006592e-01],
                        [ -1.13769531e-01,  -1.13769531e-01],
                        [ -1.06353760e-01,  -1.06353760e-01],
                        [ -8.79211426e-02,  -8.79211426e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  1.26739502e-01,   1.26739502e-01],
                        [  1.23077393e-01,   1.23077393e-01],
                        [  1.18347168e-01,   1.18347168e-01],
                        [  1.19445801e-01,   1.19445801e-01],
                        [  1.33483887e-01,   1.33483887e-01],
                        [  1.60339355e-01,   1.60339355e-01],
                        [  1.91497803e-01,   1.91497803e-01],
                        [  2.16003418e-01,   2.16003418e-01],
                        [  2.25555420e-01,   2.25555420e-01],
                        [  2.14416504e-01,   2.14416504e-01],
                        [  1.77764893e-01,   1.77764893e-01],
                        [  1.10839844e-01,   1.10839844e-01],
                        [  1.27258301e-02,   1.27258301e-02],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -2.23602295e-01,  -2.23602295e-01],
                        [ -3.07006836e-01,  -3.07006836e-01],
                        [ -3.31695557e-01,  -3.31695557e-01],
                        [ -2.94189453e-01,  -2.94189453e-01],
                        [ -2.20245361e-01,  -2.20245361e-01],
                        [ -1.52008057e-01,  -1.52008057e-01],
                        [ -1.18774414e-01,  -1.18774414e-01],
                        [ -1.18377686e-01,  -1.18377686e-01],
                        [ -1.27990723e-01,  -1.27990723e-01],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -1.18743896e-01,  -1.18743896e-01],
                        [ -1.01013184e-01,  -1.00982666e-01],
                        [ -7.98645020e-02,  -7.98645020e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.79565430e-01,   1.79565430e-01],
                        [  2.29980469e-01,   2.29980469e-01],
                        [  2.43041992e-01,   2.43041992e-01],
                        [  2.21313477e-01,   2.21313477e-01],
                        [  1.83807373e-01,   1.83837891e-01],
                        [  1.49291992e-01,   1.49291992e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.49401855e-02,   9.49401855e-02],
                        [  8.55407715e-02,   8.55407715e-02],
                        [  8.00170898e-02,   8.00170898e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  5.77392578e-02,   5.77697754e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  9.73510742e-03,   9.76562500e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  1.07177734e-01,   1.07177734e-01],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -1.52008057e-01,  -1.52008057e-01],
                        [ -2.00103760e-01,  -2.00103760e-01],
                        [ -2.09411621e-01,  -2.09411621e-01],
                        [ -1.83410645e-01,  -1.83410645e-01],
                        [ -1.47033691e-01,  -1.47033691e-01],
                        [ -1.26007080e-01,  -1.26007080e-01],
                        [ -1.23016357e-01,  -1.23016357e-01],
                        [ -1.22955322e-01,  -1.22955322e-01],
                        [ -1.16912842e-01,  -1.16912842e-01],
                        [ -1.10656738e-01,  -1.10656738e-01],
                        [ -1.11053467e-01,  -1.11053467e-01],
                        [ -1.13159180e-01,  -1.13159180e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -8.46862793e-02,  -8.46862793e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  9.92736816e-02,   9.92736816e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  1.04553223e-01,   1.04553223e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.83624268e-01,   1.83624268e-01],
                        [  2.08953857e-01,   2.08953857e-01],
                        [  2.27844238e-01,   2.27844238e-01],
                        [  2.19604492e-01,   2.19604492e-01],
                        [  1.76788330e-01,   1.76788330e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  2.13317871e-02,   2.13317871e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -1.98486328e-01,  -1.98486328e-01],
                        [ -2.89367676e-01,  -2.89367676e-01],
                        [ -3.22967529e-01,  -3.22967529e-01],
                        [ -2.90130615e-01,  -2.90130615e-01],
                        [ -2.19757080e-01,  -2.19757080e-01],
                        [ -1.58966064e-01,  -1.58966064e-01],
                        [ -1.32843018e-01,  -1.32843018e-01],
                        [ -1.29608154e-01,  -1.29577637e-01],
                        [ -1.27410889e-01,  -1.27410889e-01],
                        [ -1.21124268e-01,  -1.21124268e-01],
                        [ -1.15051270e-01,  -1.15051270e-01],
                        [ -1.08337402e-01,  -1.08337402e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -8.86230469e-02,  -8.86230469e-02],
                        [ -8.02307129e-02,  -8.02307129e-02],
                        [ -6.91528320e-02,  -6.91528320e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -1.10473633e-02,  -1.10168457e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  8.31298828e-02,   8.31298828e-02],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.95404053e-01,   1.95404053e-01],
                        [  2.36602783e-01,   2.36602783e-01],
                        [  2.36328125e-01,   2.36328125e-01],
                        [  1.98730469e-01,   1.98730469e-01],
                        [  1.55761719e-01,   1.55761719e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.15264893e-01,   1.15264893e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  8.44726562e-02,   8.44726562e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.66210938e-02,  -3.66516113e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  1.14440918e-02,   1.14746094e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  6.85729980e-02,   6.85729980e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -1.73461914e-01,  -1.73461914e-01],
                        [ -2.09564209e-01,  -2.09564209e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.77551270e-01,  -1.77551270e-01],
                        [ -1.50024414e-01,  -1.50024414e-01],
                        [ -1.33880615e-01,  -1.33880615e-01],
                        [ -1.22619629e-01,  -1.22619629e-01],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -1.03820801e-01,  -1.03820801e-01],
                        [ -1.04309082e-01,  -1.04309082e-01],
                        [ -1.07360840e-01,  -1.07360840e-01],
                        [ -1.03607178e-01,  -1.03607178e-01],
                        [ -9.09118652e-02,  -9.09118652e-02],
                        [ -7.75146484e-02,  -7.75146484e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  8.58764648e-02,   8.58764648e-02],
                        [  1.18682861e-01,   1.18682861e-01],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.23046875e-01,   1.23046875e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.02966309e-01,   1.02966309e-01],
                        [  1.20880127e-01,   1.20880127e-01],
                        [  1.42730713e-01,   1.42730713e-01],
                        [  1.57836914e-01,   1.57836914e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  1.95526123e-01,   1.95526123e-01],
                        [  2.15515137e-01,   2.15515137e-01],
                        [  2.09564209e-01,   2.09564209e-01],
                        [  1.70806885e-01,   1.70806885e-01],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  1.29699707e-02,   1.29699707e-02],
                        [ -1.02325439e-01,  -1.02325439e-01],
                        [ -2.18505859e-01,  -2.18505859e-01],
                        [ -2.98553467e-01,  -2.98553467e-01],
                        [ -3.15490723e-01,  -3.15490723e-01],
                        [ -2.72125244e-01,  -2.72125244e-01],
                        [ -2.02392578e-01,  -2.02392578e-01],
                        [ -1.49200439e-01,  -1.49200439e-01],
                        [ -1.31591797e-01,  -1.31591797e-01],
                        [ -1.34857178e-01,  -1.34857178e-01],
                        [ -1.35192871e-01,  -1.35192871e-01],
                        [ -1.26464844e-01,  -1.26464844e-01],
                        [ -1.16882324e-01,  -1.16882324e-01],
                        [ -1.10687256e-01,  -1.10687256e-01],
                        [ -1.04888916e-01,  -1.04888916e-01],
                        [ -9.65270996e-02,  -9.65270996e-02],
                        [ -8.26721191e-02,  -8.26721191e-02],
                        [ -5.89294434e-02,  -5.89294434e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  1.12762451e-01,   1.12762451e-01],
                        [  1.68914795e-01,   1.68914795e-01],
                        [  2.11730957e-01,   2.11730957e-01],
                        [  2.26531982e-01,   2.26531982e-01],
                        [  2.13806152e-01,   2.13806152e-01],
                        [  1.85974121e-01,   1.85974121e-01],
                        [  1.55548096e-01,   1.55548096e-01],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.04339600e-01,   1.04339600e-01],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  2.34985352e-03,   2.34985352e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  1.00006104e-01,   1.00006104e-01],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -1.28753662e-01,  -1.28753662e-01],
                        [ -1.99645996e-01,  -1.99645996e-01],
                        [ -2.24365234e-01,  -2.24365234e-01],
                        [ -2.01660156e-01,  -2.01660156e-01],
                        [ -1.56097412e-01,  -1.56097412e-01],
                        [ -1.17767334e-01,  -1.17767334e-01],
                        [ -1.02569580e-01,  -1.02569580e-01],
                        [ -1.05590820e-01,  -1.05590820e-01],
                        [ -1.09527588e-01,  -1.09527588e-01],
                        [ -1.03393555e-01,  -1.03393555e-01],
                        [ -9.19494629e-02,  -9.19494629e-02],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -8.22753906e-02,  -8.22753906e-02],
                        [ -8.05053711e-02,  -8.05053711e-02],
                        [ -8.09326172e-02,  -8.09326172e-02],
                        [ -8.41979980e-02,  -8.41979980e-02],
                        [ -8.21533203e-02,  -8.21533203e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  8.94775391e-02,   8.94775391e-02],
                        [  9.58557129e-02,   9.58557129e-02],
                        [  1.19140625e-01,   1.19140625e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.63604736e-01,   1.63604736e-01],
                        [  1.77612305e-01,   1.77612305e-01],
                        [  1.92016602e-01,   1.92016602e-01],
                        [  2.03308105e-01,   2.03308105e-01],
                        [  2.02026367e-01,   2.02026367e-01],
                        [  1.76940918e-01,   1.76940918e-01],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  2.86865234e-02,   2.86865234e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -1.88232422e-01,  -1.88232422e-01],
                        [ -2.71057129e-01,  -2.71057129e-01],
                        [ -3.07525635e-01,  -3.07525635e-01],
                        [ -2.86041260e-01,  -2.86041260e-01],
                        [ -2.22015381e-01,  -2.22015381e-01],
                        [ -1.55487061e-01,  -1.55487061e-01],
                        [ -1.18621826e-01,  -1.18621826e-01],
                        [ -1.09771729e-01,  -1.09771729e-01],
                        [ -1.08978271e-01,  -1.08978271e-01],
                        [ -1.06750488e-01,  -1.06750488e-01],
                        [ -1.06781006e-01,  -1.06781006e-01],
                        [ -1.11541748e-01,  -1.11541748e-01],
                        [ -1.17004395e-01,  -1.17004395e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -1.01074219e-01,  -1.01074219e-01],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  7.13500977e-02,   7.13500977e-02],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  2.00469971e-01,   2.00469971e-01],
                        [  2.32818604e-01,   2.32818604e-01],
                        [  2.22625732e-01,   2.22625732e-01],
                        [  1.84234619e-01,   1.84234619e-01],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  1.09130859e-01,   1.09130859e-01],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  9.82666016e-02,   9.82666016e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.03851318e-01,   1.03851318e-01],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -1.61926270e-01,  -1.61926270e-01],
                        [ -2.12127686e-01,  -2.12127686e-01],
                        [ -2.10754395e-01,  -2.10754395e-01],
                        [ -1.69891357e-01,  -1.69891357e-01],
                        [ -1.21643066e-01,  -1.21643066e-01],
                        [ -9.17053223e-02,  -9.17053223e-02],
                        [ -8.70971680e-02,  -8.70971680e-02],
                        [ -9.84802246e-02,  -9.84802246e-02],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -1.03637695e-01,  -1.03637695e-01],
                        [ -9.28649902e-02,  -9.28649902e-02],
                        [ -8.95690918e-02,  -8.95690918e-02],
                        [ -9.28344727e-02,  -9.28344727e-02],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -7.55920410e-02,  -7.55920410e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  1.06933594e-01,   1.06933594e-01],
                        [  1.05377197e-01,   1.05377197e-01],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.43341064e-01,   1.43371582e-01],
                        [  1.60247803e-01,   1.60247803e-01],
                        [  1.70410156e-01,   1.70410156e-01],
                        [  1.80236816e-01,   1.80236816e-01],
                        [  1.90826416e-01,   1.90826416e-01],
                        [  1.97265625e-01,   1.97265625e-01],
                        [  1.90063477e-01,   1.90063477e-01],
                        [  1.53228760e-01,   1.53228760e-01],
                        [  7.37609863e-02,   7.37609863e-02],
                        [ -4.24804688e-02,  -4.25109863e-02],
                        [ -1.69525146e-01,  -1.69525146e-01],
                        [ -2.73468018e-01,  -2.73468018e-01],
                        [ -3.23974609e-01,  -3.23974609e-01],
                        [ -3.07098389e-01,  -3.07098389e-01],
                        [ -2.40173340e-01,  -2.40173340e-01],
                        [ -1.67114258e-01,  -1.67114258e-01],
                        [ -1.25610352e-01,  -1.25610352e-01],
                        [ -1.18347168e-01,  -1.18347168e-01],
                        [ -1.21643066e-01,  -1.21643066e-01],
                        [ -1.18835449e-01,  -1.18835449e-01],
                        [ -1.14074707e-01,  -1.14074707e-01],
                        [ -1.15356445e-01,  -1.15356445e-01],
                        [ -1.18652344e-01,  -1.18652344e-01],
                        [ -1.15173340e-01,  -1.15173340e-01],
                        [ -1.01684570e-01,  -1.01684570e-01],
                        [ -7.59582520e-02,  -7.59582520e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  1.37664795e-01,   1.37664795e-01],
                        [  1.84600830e-01,   1.84600830e-01],
                        [  2.14538574e-01,   2.14538574e-01],
                        [  2.15850830e-01,   2.15850830e-01],
                        [  1.89208984e-01,   1.89208984e-01],
                        [  1.52069092e-01,   1.52069092e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  1.19659424e-01,   1.19659424e-01],
                        [  1.13616943e-01,   1.13616943e-01],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  9.91210938e-02,   9.91210938e-02],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  6.86950684e-02,   6.86950684e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  1.00280762e-01,   1.00280762e-01],
                        [  1.07543945e-01,   1.07543945e-01],
                        [  1.02569580e-01,   1.02569580e-01],
                        [  6.85424805e-02,   6.85424805e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -9.65576172e-02,  -9.65576172e-02],
                        [ -1.82952881e-01,  -1.82952881e-01],
                        [ -2.32177734e-01,  -2.32177734e-01],
                        [ -2.30285645e-01,  -2.30285645e-01],
                        [ -1.89117432e-01,  -1.89117432e-01],
                        [ -1.41540527e-01,  -1.41540527e-01],
                        [ -1.14166260e-01,  -1.14166260e-01],
                        [ -1.05804443e-01,  -1.05804443e-01],
                        [ -9.93347168e-02,  -9.93347168e-02],
                        [ -8.85009766e-02,  -8.85009766e-02],
                        [ -8.29772949e-02,  -8.29772949e-02],
                        [ -9.08813477e-02,  -9.08813477e-02],
                        [ -1.06079102e-01,  -1.06079102e-01],
                        [ -1.14440918e-01,  -1.14440918e-01],
                        [ -1.09558105e-01,  -1.09588623e-01],
                        [ -9.77172852e-02,  -9.77172852e-02],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.26464844e-01,   1.26464844e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  9.13085938e-02,   9.13085938e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.49414062e-01,   1.49414062e-01],
                        [  1.67144775e-01,   1.67144775e-01],
                        [  1.95312500e-01,   1.95312500e-01],
                        [  2.23663330e-01,   2.23663330e-01],
                        [  2.30987549e-01,   2.30987549e-01],
                        [  2.01110840e-01,   2.01080322e-01],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  1.81274414e-02,   1.81274414e-02],
                        [ -1.16027832e-01,  -1.16027832e-01],
                        [ -2.46826172e-01,  -2.46856689e-01],
                        [ -3.38043213e-01,  -3.38043213e-01],
                        [ -3.58673096e-01,  -3.58673096e-01],
                        [ -3.07617188e-01,  -3.07617188e-01],
                        [ -2.22656250e-01,  -2.22656250e-01],
                        [ -1.52770996e-01,  -1.52740479e-01],
                        [ -1.19537354e-01,  -1.19537354e-01],
                        [ -1.10931396e-01,  -1.10931396e-01],
                        [ -1.07299805e-01,  -1.07299805e-01],
                        [ -1.03057861e-01,  -1.03057861e-01],
                        [ -1.03363037e-01,  -1.03363037e-01],
                        [ -1.10870361e-01,  -1.10870361e-01],
                        [ -1.20666504e-01,  -1.20666504e-01],
                        [ -1.22802734e-01,  -1.22802734e-01],
                        [ -1.06018066e-01,  -1.06018066e-01],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  1.45751953e-01,   1.45751953e-01],
                        [  2.02239990e-01,   2.02239990e-01],
                        [  2.37182617e-01,   2.37182617e-01],
                        [  2.42279053e-01,   2.42279053e-01],
                        [  2.20153809e-01,   2.20153809e-01],
                        [  1.85302734e-01,   1.85302734e-01],
                        [  1.51794434e-01,   1.51794434e-01],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  8.60595703e-02,   8.60290527e-02],
                        [  8.43505859e-02,   8.43505859e-02],
                        [  8.01391602e-02,   8.01391602e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -3.18298340e-02,  -3.18603516e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.68652344e-02,  -3.68957520e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -6.77490234e-03,  -6.80541992e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.10809326e-01,   1.10809326e-01],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -1.20452881e-01,  -1.20452881e-01],
                        [ -1.87774658e-01,  -1.87774658e-01],
                        [ -2.20764160e-01,  -2.20733643e-01],
                        [ -2.11456299e-01,  -2.11456299e-01],
                        [ -1.75079346e-01,  -1.75079346e-01],
                        [ -1.40625000e-01,  -1.40655518e-01],
                        [ -1.22680664e-01,  -1.22680664e-01],
                        [ -1.13525391e-01,  -1.13525391e-01],
                        [ -1.05072021e-01,  -1.05072021e-01],
                        [ -1.00616455e-01,  -1.00616455e-01],
                        [ -1.02752686e-01,  -1.02752686e-01],
                        [ -1.05834961e-01,  -1.05865479e-01],
                        [ -1.04431152e-01,  -1.04431152e-01],
                        [ -9.93041992e-02,  -9.92736816e-02],
                        [ -9.38720703e-02,  -9.38720703e-02],
                        [ -8.90197754e-02,  -8.90197754e-02],
                        [ -7.97729492e-02,  -7.97424316e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -1.37023926e-02,  -1.37329102e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  1.28265381e-01,   1.28265381e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.12365723e-01,   1.12365723e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.75598145e-01,   1.75598145e-01],
                        [  2.14538574e-01,   2.14538574e-01],
                        [  2.33032227e-01,   2.33032227e-01],
                        [  2.17590332e-01,   2.17590332e-01],
                        [  1.66259766e-01,   1.66259766e-01],
                        [  8.26721191e-02,   8.26721191e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -1.40411377e-01,  -1.40411377e-01],
                        [ -2.40875244e-01,  -2.40875244e-01],
                        [ -2.98431396e-01,  -2.98431396e-01],
                        [ -2.92999268e-01,  -2.92999268e-01],
                        [ -2.35870361e-01,  -2.35870361e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.42547607e-01,  -1.42547607e-01],
                        [ -1.43066406e-01,  -1.43066406e-01],
                        [ -1.46179199e-01,  -1.46179199e-01],
                        [ -1.38519287e-01,  -1.38519287e-01],
                        [ -1.27838135e-01,  -1.27838135e-01],
                        [ -1.24481201e-01,  -1.24481201e-01],
                        [ -1.29364014e-01,  -1.29364014e-01],
                        [ -1.31958008e-01,  -1.31927490e-01],
                        [ -1.15783691e-01,  -1.15783691e-01],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [  6.39648438e-02,   6.39648438e-02],
                        [  1.36322021e-01,   1.36322021e-01],
                        [  1.95343018e-01,   1.95343018e-01],
                        [  2.27691650e-01,   2.27691650e-01],
                        [  2.29614258e-01,   2.29614258e-01],
                        [  2.09594727e-01,   2.09594727e-01],
                        [  1.81945801e-01,   1.81945801e-01],
                        [  1.57684326e-01,   1.57684326e-01],
                        [  1.37847900e-01,   1.37847900e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  9.98840332e-02,   9.99145508e-02],
                        [  9.06677246e-02,   9.06982422e-02],
                        [  9.02099609e-02,   9.01794434e-02],
                        [  9.17358398e-02,   9.17358398e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  8.43200684e-02,   8.43200684e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  4.63867188e-02,   4.64172363e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -4.76074219e-02,  -4.76379395e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  8.64257812e-02,   8.64257812e-02],
                        [  1.00341797e-01,   1.00341797e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  8.06579590e-02,   8.06884766e-02],
                        [  4.69360352e-02,   4.69360352e-02],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -8.56933594e-02,  -8.56628418e-02],
                        [ -1.61926270e-01,  -1.61926270e-01],
                        [ -2.09381104e-01,  -2.09381104e-01],
                        [ -2.14263916e-01,  -2.14263916e-01],
                        [ -1.87042236e-01,  -1.87042236e-01],
                        [ -1.51947021e-01,  -1.51947021e-01],
                        [ -1.26800537e-01,  -1.26800537e-01],
                        [ -1.13861084e-01,  -1.13861084e-01],
                        [ -1.06475830e-01,  -1.06475830e-01],
                        [ -9.84191895e-02,  -9.84191895e-02],
                        [ -8.91418457e-02,  -8.91418457e-02],
                        [ -8.54492188e-02,  -8.54492188e-02],
                        [ -9.37500000e-02,  -9.37500000e-02],
                        [ -1.07910156e-01,  -1.07910156e-01],
                        [ -1.12518311e-01,  -1.12518311e-01],
                        [ -1.00769043e-01,  -1.00769043e-01],
                        [ -7.85217285e-02,  -7.85217285e-02],
                        [ -4.89807129e-02,  -4.89807129e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  8.92639160e-02,   8.92639160e-02],
                        [  1.21765137e-01,   1.21765137e-01],
                        [  1.32537842e-01,   1.32537842e-01],
                        [  1.24053955e-01,   1.24053955e-01],
                        [  1.07208252e-01,   1.07238770e-01],
                        [  9.51843262e-02,   9.51843262e-02],
                        [  9.56420898e-02,   9.56420898e-02],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.73278809e-01,   1.73278809e-01],
                        [  2.02789307e-01,   2.02789307e-01],
                        [  2.16705322e-01,   2.16705322e-01],
                        [  2.08557129e-01,   2.08557129e-01],
                        [  1.71630859e-01,   1.71630859e-01],
                        [  9.97619629e-02,   9.97619629e-02],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.20544434e-01,  -1.20544434e-01],
                        [ -2.23937988e-01,  -2.23937988e-01],
                        [ -2.86346436e-01,  -2.86346436e-01],
                        [ -2.91992188e-01,  -2.91992188e-01],
                        [ -2.49877930e-01,  -2.49877930e-01],
                        [ -1.93237305e-01,  -1.93237305e-01],
                        [ -1.55151367e-01,  -1.55151367e-01],
                        [ -1.43035889e-01,  -1.43035889e-01],
                        [ -1.42700195e-01,  -1.42700195e-01],
                        [ -1.42639160e-01,  -1.42639160e-01],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -1.50024414e-01,  -1.50024414e-01],
                        [ -1.51153564e-01,  -1.51153564e-01],
                        [ -1.35131836e-01,  -1.35131836e-01],
                        [ -9.85717773e-02,  -9.86022949e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  1.58569336e-01,   1.58569336e-01],
                        [  2.10662842e-01,   2.10662842e-01],
                        [  2.31079102e-01,   2.31079102e-01],
                        [  2.18811035e-01,   2.18811035e-01],
                        [  1.86065674e-01,   1.86065674e-01],
                        [  1.52435303e-01,   1.52435303e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.21673584e-01,   1.21704102e-01],
                        [  1.07086182e-01,   1.07086182e-01],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  5.21240234e-02,   5.21545410e-02],
                        [  5.06286621e-02,   5.06286621e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.48913574e-02,   4.48913574e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.23486328e-02,  -3.23181152e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.94702148e-02,  -1.94396973e-02],
                        [ -9.18579102e-03,  -9.18579102e-03],
                        [ -1.43432617e-03,  -1.46484375e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  8.61206055e-02,   8.61511230e-02],
                        [  8.49914551e-02,   8.49609375e-02],
                        [  7.32727051e-02,   7.32421875e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [ -3.37524414e-02,  -3.37829590e-02],
                        [ -1.11450195e-01,  -1.11450195e-01],
                        [ -1.83532715e-01,  -1.83532715e-01],
                        [ -2.16430664e-01,  -2.16430664e-01],
                        [ -2.06420898e-01,  -2.06420898e-01],
                        [ -1.77246094e-01,  -1.77215576e-01],
                        [ -1.49993896e-01,  -1.50024414e-01],
                        [ -1.30187988e-01,  -1.30187988e-01],
                        [ -1.16149902e-01,  -1.16119385e-01],
                        [ -1.06079102e-01,  -1.06079102e-01],
                        [ -9.81445312e-02,  -9.81750488e-02],
                        [ -9.29565430e-02,  -9.29260254e-02],
                        [ -9.45739746e-02,  -9.45434570e-02],
                        [ -1.03637695e-01,  -1.03637695e-01],
                        [ -1.09771729e-01,  -1.09802246e-01],
                        [ -9.99755859e-02,  -9.99450684e-02],
                        [ -7.45239258e-02,  -7.45239258e-02],
                        [ -4.37622070e-02,  -4.37927246e-02],
                        [ -1.07116699e-02,  -1.06811523e-02],
                        [  2.93884277e-02,   2.94189453e-02],
                        [  7.30590820e-02,   7.30285645e-02],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  1.17065430e-01,   1.17126465e-01],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  8.90808105e-02,   8.90502930e-02],
                        [  8.08410645e-02,   8.08715820e-02],
                        [  9.17663574e-02,   9.17968750e-02],
                        [  1.16943359e-01,   1.16912842e-01],
                        [  1.47186279e-01,   1.47155762e-01],
                        [  1.78314209e-01,   1.78344727e-01],
                        [  2.05383301e-01,   2.05383301e-01],
                        [  2.19573975e-01,   2.19543457e-01],
                        [  2.14111328e-01,   2.14141846e-01],
                        [  1.82037354e-01,   1.82037354e-01],
                        [  1.11785889e-01,   1.11755371e-01],
                        [  7.93457031e-04,   8.23974609e-04],
                        [ -1.30798340e-01,  -1.30767822e-01],
                        [ -2.48199463e-01,  -2.48199463e-01],
                        [ -3.19366455e-01,  -3.19366455e-01],
                        [ -3.26873779e-01,  -3.26873779e-01],
                        [ -2.78411865e-01,  -2.78411865e-01],
                        [ -2.08923340e-01,  -2.08953857e-01],
                        [ -1.57562256e-01,  -1.57531738e-01],
                        [ -1.36413574e-01,  -1.36413574e-01],
                        [ -1.30340576e-01,  -1.30340576e-01],
                        [ -1.24877930e-01,  -1.24877930e-01],
                        [ -1.21490479e-01,  -1.21490479e-01],
                        [ -1.24481201e-01,  -1.24481201e-01],
                        [ -1.26586914e-01,  -1.26586914e-01],
                        [ -1.15631104e-01,  -1.15631104e-01],
                        [ -8.72802734e-02,  -8.73107910e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  1.72393799e-01,   1.72363281e-01],
                        [  2.21923828e-01,   2.21954346e-01],
                        [  2.34802246e-01,   2.34802246e-01],
                        [  2.14569092e-01,   2.14538574e-01],
                        [  1.76910400e-01,   1.76910400e-01],
                        [  1.39709473e-01,   1.39709473e-01],
                        [  1.12854004e-01,   1.12823486e-01],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  8.70971680e-02,   8.70971680e-02],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  9.84802246e-02,   9.84802246e-02],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.77099609e-02,   2.77404785e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.58789062e-02,  -2.59094238e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -2.79541016e-02,  -2.79846191e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -2.02941895e-02,  -2.02636719e-02],
                        [ -1.21154785e-02,  -1.21459961e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.91040039e-02,   1.90734863e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  6.37817383e-02,   6.37817383e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  7.39746094e-02,   7.39746094e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -1.28448486e-01,  -1.28448486e-01],
                        [ -1.96441650e-01,  -1.96441650e-01],
                        [ -2.25372314e-01,  -2.25372314e-01],
                        [ -2.12585449e-01,  -2.12585449e-01],
                        [ -1.81274414e-01,  -1.81274414e-01],
                        [ -1.54815674e-01,  -1.54815674e-01],
                        [ -1.38366699e-01,  -1.38366699e-01],
                        [ -1.23840332e-01,  -1.23840332e-01],
                        [ -1.05743408e-01,  -1.05712891e-01],
                        [ -8.92944336e-02,  -8.92944336e-02],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -8.27331543e-02,  -8.27026367e-02],
                        [ -8.20922852e-02,  -8.20922852e-02],
                        [ -7.65075684e-02,  -7.65075684e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -5.42602539e-02,  -5.42297363e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [  1.55639648e-03,   1.52587891e-03],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.16943359e-01,   1.16943359e-01],
                        [  1.11968994e-01,   1.11968994e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.33697510e-01,   1.33728027e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.68090820e-01,   1.68090820e-01],
                        [  1.85516357e-01,   1.85516357e-01],
                        [  2.02087402e-01,   2.02117920e-01],
                        [  2.06481934e-01,   2.06451416e-01],
                        [  1.78100586e-01,   1.78100586e-01],
                        [  1.01745605e-01,   1.01776123e-01],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -1.49597168e-01,  -1.49627686e-01],
                        [ -2.59887695e-01,  -2.59857178e-01],
                        [ -3.18420410e-01,  -3.18420410e-01],
                        [ -3.14117432e-01,  -3.14147949e-01],
                        [ -2.58728027e-01,  -2.58728027e-01],
                        [ -1.86767578e-01,  -1.86767578e-01],
                        [ -1.38854980e-01,  -1.38854980e-01],
                        [ -1.29760742e-01,  -1.29760742e-01],
                        [ -1.39617920e-01,  -1.39617920e-01],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -1.40075684e-01,  -1.40075684e-01],
                        [ -1.34704590e-01,  -1.34674072e-01],
                        [ -1.25946045e-01,  -1.25946045e-01],
                        [ -1.03790283e-01,  -1.03790283e-01],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -5.85937500e-03,  -5.82885742e-03],
                        [  6.07299805e-02,   6.07299805e-02],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.95251465e-01,   1.95251465e-01],
                        [  2.32421875e-01,   2.32421875e-01],
                        [  2.27508545e-01,   2.27508545e-01],
                        [  1.90155029e-01,   1.90185547e-01],
                        [  1.48498535e-01,   1.48498535e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  1.07574463e-01,   1.07574463e-01],
                        [  1.01074219e-01,   1.01104736e-01],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  9.50927734e-02,   9.51232910e-02],
                        [  9.30480957e-02,   9.30480957e-02],
                        [  8.72192383e-02,   8.71887207e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  5.61828613e-02,   5.62133789e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.69470215e-02,   2.69165039e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  4.30908203e-02,   4.31213379e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  3.41491699e-02,   3.41796875e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [ -1.23596191e-02,  -1.23901367e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -5.13610840e-02,  -5.13305664e-02],
                        [ -5.52062988e-02,  -5.52368164e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -4.26025391e-02,  -4.25720215e-02],
                        [ -1.89514160e-02,  -1.89819336e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  1.01013184e-02,   1.01318359e-02],
                        [  1.31835938e-02,   1.32141113e-02],
                        [  1.44653320e-02,   1.44348145e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  1.84020996e-02,   1.83715820e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.28576660e-02,   2.28881836e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.04870605e-02,   3.04565430e-02],
                        [  4.41284180e-02,   4.41284180e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  6.99157715e-02,   6.99462891e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -1.00738525e-01,  -1.00708008e-01],
                        [ -1.61437988e-01,  -1.61437988e-01],
                        [ -2.01232910e-01,  -2.01232910e-01],
                        [ -2.12371826e-01,  -2.12341309e-01],
                        [ -1.97143555e-01,  -1.97143555e-01],
                        [ -1.66717529e-01,  -1.66717529e-01],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -1.22161865e-01,  -1.22161865e-01],
                        [ -1.14624023e-01,  -1.14624023e-01],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -8.38012695e-02,  -8.38012695e-02],
                        [ -7.20520020e-02,  -7.20825195e-02],
                        [ -7.84301758e-02,  -7.84301758e-02],
                        [ -9.47265625e-02,  -9.46960449e-02],
                        [ -1.02020264e-01,  -1.02020264e-01],
                        [ -8.95080566e-02,  -8.95080566e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  1.30798340e-01,   1.30828857e-01],
                        [  1.48834229e-01,   1.48834229e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.48406982e-01,   1.48437500e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  1.45751953e-01,   1.45721436e-01],
                        [  1.50848389e-01,   1.50848389e-01],
                        [  1.69769287e-01,   1.69769287e-01],
                        [  1.97723389e-01,   1.97692871e-01],
                        [  2.13806152e-01,   2.13775635e-01],
                        [  1.99157715e-01,   1.99188232e-01],
                        [  1.49566650e-01,   1.49597168e-01],
                        [  6.88476562e-02,   6.88171387e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -1.57073975e-01,  -1.57043457e-01],
                        [ -2.65228271e-01,  -2.65258789e-01],
                        [ -3.28674316e-01,  -3.28704834e-01],
                        [ -3.24493408e-01,  -3.24462891e-01],
                        [ -2.63275146e-01,  -2.63275146e-01],
                        [ -1.88781738e-01,  -1.88812256e-01],
                        [ -1.43768311e-01,  -1.43768311e-01],
                        [ -1.35528564e-01,  -1.35498047e-01],
                        [ -1.40899658e-01,  -1.40899658e-01],
                        [ -1.39190674e-01,  -1.39221191e-01],
                        [ -1.29577637e-01,  -1.29547119e-01],
                        [ -1.19415283e-01,  -1.19415283e-01],
                        [ -1.06536865e-01,  -1.06567383e-01],
                        [ -7.65686035e-02,  -7.65686035e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  1.77154541e-01,   1.77154541e-01],
                        [  2.10693359e-01,   2.10693359e-01],
                        [  2.20092773e-01,   2.20092773e-01],
                        [  2.01385498e-01,   2.01385498e-01],
                        [  1.61804199e-01,   1.61804199e-01],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  7.57141113e-02,   7.56835938e-02],
                        [  7.07702637e-02,   7.07702637e-02],
                        [  7.49816895e-02,   7.50122070e-02],
                        [  8.54187012e-02,   8.53881836e-02],
                        [  9.38720703e-02,   9.38720703e-02],
                        [  9.42382812e-02,   9.42687988e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  6.57653809e-02,   6.57958984e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  5.99060059e-02,   5.98754883e-02],
                        [  5.93566895e-02,   5.93566895e-02],
                        [  5.09643555e-02,   5.09948730e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.53198242e-02,   1.53503418e-02],
                        [  5.49316406e-03,   5.52368164e-03],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -1.69982910e-02,  -1.69677734e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.68249512e-02,  -2.68554688e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.05480957e-02,  -3.05175781e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.41394043e-02,  -2.41699219e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.92053223e-02,  -2.91748047e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  5.70373535e-02,   5.70068359e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.67834473e-02,   4.68139648e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [ -4.58679199e-02,  -4.58984375e-02],
                        [ -1.21002197e-01,  -1.21002197e-01],
                        [ -1.87866211e-01,  -1.87866211e-01],
                        [ -2.24639893e-01,  -2.24639893e-01],
                        [ -2.23571777e-01,  -2.23571777e-01],
                        [ -1.94244385e-01,  -1.94244385e-01],
                        [ -1.56677246e-01,  -1.56707764e-01],
                        [ -1.27380371e-01,  -1.27380371e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -1.00769043e-01,  -1.00769043e-01],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -9.43908691e-02,  -9.43908691e-02],
                        [ -9.37500000e-02,  -9.37194824e-02],
                        [ -8.98132324e-02,  -8.98132324e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  5.63964844e-02,   5.63964844e-02],
                        [  9.52758789e-02,   9.52758789e-02],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.30523682e-01,   1.30523682e-01],
                        [  1.31683350e-01,   1.31713867e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.29089355e-01,   1.29058838e-01],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  1.68426514e-01,   1.68426514e-01],
                        [  2.00653076e-01,   2.00653076e-01],
                        [  2.17926025e-01,   2.17926025e-01],
                        [  2.08679199e-01,   2.08709717e-01],
                        [  1.73461914e-01,   1.73431396e-01],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.77917480e-02,   1.78222656e-02],
                        [ -1.03149414e-01,  -1.03149414e-01],
                        [ -2.23144531e-01,  -2.23144531e-01],
                        [ -3.02856445e-01,  -3.02856445e-01],
                        [ -3.16284180e-01,  -3.16284180e-01],
                        [ -2.70263672e-01,  -2.70263672e-01],
                        [ -2.01995850e-01,  -2.01995850e-01],
                        [ -1.52862549e-01,  -1.52862549e-01],
                        [ -1.38702393e-01,  -1.38702393e-01],
                        [ -1.45263672e-01,  -1.45263672e-01],
                        [ -1.49871826e-01,  -1.49871826e-01],
                        [ -1.42425537e-01,  -1.42425537e-01],
                        [ -1.25335693e-01,  -1.25335693e-01],
                        [ -1.02783203e-01,  -1.02783203e-01],
                        [ -7.49816895e-02,  -7.49816895e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  9.17358398e-02,   9.17358398e-02],
                        [  1.65435791e-01,   1.65435791e-01],
                        [  2.17071533e-01,   2.17071533e-01],
                        [  2.30560303e-01,   2.30590820e-01],
                        [  2.08801270e-01,   2.08801270e-01],
                        [  1.70806885e-01,   1.70806885e-01],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.09527588e-01,   1.09527588e-01],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  8.02917480e-02,   8.03222656e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  8.20617676e-02,   8.20617676e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.72607422e-02,   6.72912598e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  3.56140137e-02,   3.55834961e-02],
                        [  2.80456543e-02,   2.80151367e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [ -5.61523438e-03,  -5.58471680e-03],
                        [ -1.87072754e-02,  -1.87377930e-02],
                        [ -2.85034180e-02,  -2.85339355e-02],
                        [ -3.28979492e-02,  -3.28674316e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -2.88696289e-02,  -2.89001465e-02],
                        [ -2.93884277e-02,  -2.93579102e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -4.62646484e-02,  -4.62951660e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -3.39965820e-02,  -3.39660645e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [  1.49536133e-03,   1.46484375e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  2.19726562e-03,   2.16674805e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.33361816e-02,   1.33056641e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  2.90832520e-02,   2.90527344e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.60620117e-02,   2.60925293e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  5.38940430e-02,   5.38635254e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  2.04162598e-02,   2.03857422e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -1.50726318e-01,  -1.50756836e-01],
                        [ -2.00439453e-01,  -2.00439453e-01],
                        [ -2.12829590e-01,  -2.12829590e-01],
                        [ -1.87561035e-01,  -1.87561035e-01],
                        [ -1.47491455e-01,  -1.47521973e-01],
                        [ -1.17645264e-01,  -1.17614746e-01],
                        [ -1.05255127e-01,  -1.05255127e-01],
                        [ -1.03332520e-01,  -1.03363037e-01],
                        [ -1.03271484e-01,  -1.03271484e-01],
                        [ -1.00799561e-01,  -1.00799561e-01],
                        [ -9.65270996e-02,  -9.65576172e-02],
                        [ -9.24377441e-02,  -9.24377441e-02],
                        [ -8.67614746e-02,  -8.67309570e-02],
                        [ -7.42187500e-02,  -7.42187500e-02],
                        [ -4.97741699e-02,  -4.98046875e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  8.77990723e-02,   8.77990723e-02],
                        [  1.26464844e-01,   1.26434326e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.42456055e-01,   1.42456055e-01],
                        [  1.37115479e-01,   1.37115479e-01],
                        [  1.47979736e-01,   1.47979736e-01],
                        [  1.80297852e-01,   1.80328369e-01],
                        [  2.15362549e-01,   2.15332031e-01],
                        [  2.30926514e-01,   2.30895996e-01],
                        [  2.22595215e-01,   2.22595215e-01],
                        [  1.91589355e-01,   1.91619873e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  2.06909180e-02,   2.06909180e-02],
                        [ -1.09771729e-01,  -1.09771729e-01],
                        [ -2.30987549e-01,  -2.30987549e-01],
                        [ -3.12744141e-01,  -3.12774658e-01],
                        [ -3.32397461e-01,  -3.32397461e-01],
                        [ -2.83721924e-01,  -2.83721924e-01],
                        [ -1.97174072e-01,  -1.97204590e-01],
                        [ -1.27685547e-01,  -1.27685547e-01],
                        [ -1.05773926e-01,  -1.05773926e-01],
                        [ -1.16851807e-01,  -1.16851807e-01],
                        [ -1.32324219e-01,  -1.32354736e-01],
                        [ -1.40289307e-01,  -1.40258789e-01],
                        [ -1.40136719e-01,  -1.40106201e-01],
                        [ -1.27593994e-01,  -1.27624512e-01],
                        [ -9.55505371e-02,  -9.55505371e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.86950684e-01,   1.86950684e-01],
                        [  2.18597412e-01,   2.18597412e-01],
                        [  2.12005615e-01,   2.12005615e-01],
                        [  1.82525635e-01,   1.82495117e-01],
                        [  1.45904541e-01,   1.45904541e-01],
                        [  1.12915039e-01,   1.12945557e-01],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  8.39538574e-02,   8.39843750e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  8.80737305e-02,   8.80737305e-02],
                        [  8.18176270e-02,   8.17871094e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  6.44836426e-02,   6.44836426e-02],
                        [  5.69152832e-02,   5.69152832e-02],
                        [  5.18798828e-02,   5.19104004e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -2.31018066e-02,  -2.31323242e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.35900879e-02,  -2.36206055e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.49633789e-02,  -2.49328613e-02],
                        [ -2.03552246e-02,  -2.03857422e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -1.43432617e-02,  -1.43127441e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  8.23974609e-03,   8.20922852e-03],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  4.39453125e-03,   4.42504883e-03],
                        [  2.47192383e-03,   2.44140625e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  1.83105469e-04,   2.13623047e-04],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.67846680e-03,  -1.64794922e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  1.10168457e-02,   1.10473633e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -8.52966309e-02,  -8.52661133e-02],
                        [ -1.45080566e-01,  -1.45080566e-01],
                        [ -1.86981201e-01,  -1.86981201e-01],
                        [ -1.99157715e-01,  -1.99157715e-01],
                        [ -1.85150146e-01,  -1.85150146e-01],
                        [ -1.61529541e-01,  -1.61529541e-01],
                        [ -1.43920898e-01,  -1.43920898e-01],
                        [ -1.34002686e-01,  -1.33972168e-01],
                        [ -1.22619629e-01,  -1.22619629e-01],
                        [ -1.05438232e-01,  -1.05468750e-01],
                        [ -8.95690918e-02,  -8.95690918e-02],
                        [ -8.17565918e-02,  -8.17565918e-02],
                        [ -7.59887695e-02,  -7.59887695e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -9.94873047e-03,  -9.97924805e-03],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  8.80432129e-02,   8.80432129e-02],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.43432617e-01,   1.43432617e-01],
                        [  1.55853271e-01,   1.55853271e-01],
                        [  1.71234131e-01,   1.71234131e-01],
                        [  1.90704346e-01,   1.90704346e-01],
                        [  2.05963135e-01,   2.05963135e-01],
                        [  2.09777832e-01,   2.09777832e-01],
                        [  1.99584961e-01,   1.99584961e-01],
                        [  1.70989990e-01,   1.70989990e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  2.05383301e-02,   2.05383301e-02],
                        [ -9.80224609e-02,  -9.80224609e-02],
                        [ -2.13745117e-01,  -2.13745117e-01],
                        [ -2.92633057e-01,  -2.92633057e-01],
                        [ -3.12744141e-01,  -3.12713623e-01],
                        [ -2.77801514e-01,  -2.77832031e-01],
                        [ -2.16949463e-01,  -2.16949463e-01],
                        [ -1.67236328e-01,  -1.67205811e-01],
                        [ -1.49749756e-01,  -1.49749756e-01],
                        [ -1.56280518e-01,  -1.56280518e-01],
                        [ -1.61010742e-01,  -1.61010742e-01],
                        [ -1.48651123e-01,  -1.48651123e-01],
                        [ -1.26342773e-01,  -1.26373291e-01],
                        [ -1.05438232e-01,  -1.05438232e-01],
                        [ -7.95593262e-02,  -7.95593262e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [  4.19006348e-02,   4.18701172e-02],
                        [  1.22589111e-01,   1.22558594e-01],
                        [  1.87194824e-01,   1.87194824e-01],
                        [  2.20367432e-01,   2.20336914e-01],
                        [  2.17102051e-01,   2.17102051e-01],
                        [  1.84295654e-01,   1.84295654e-01],
                        [  1.39617920e-01,   1.39587402e-01],
                        [  1.01684570e-01,   1.01684570e-01],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  8.27636719e-02,   8.27636719e-02],
                        [  7.46765137e-02,   7.47070312e-02],
                        [  6.70166016e-02,   6.70471191e-02],
                        [  6.06384277e-02,   6.06689453e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  6.26525879e-02,   6.26220703e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  5.85021973e-02,   5.85327148e-02],
                        [  5.25817871e-02,   5.25817871e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  2.52075195e-02,   2.51770020e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -2.47497559e-02,  -2.47192383e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.56140137e-02,  -3.56445312e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -2.54821777e-02,  -2.54516602e-02],
                        [ -1.90124512e-02,  -1.89819336e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.14233398e-02,  -2.14538574e-02],
                        [ -2.87780762e-02,  -2.88085938e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -6.62231445e-03,  -6.59179688e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  1.19323730e-02,   1.19018555e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  2.51770020e-02,   2.52075195e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  1.55029297e-02,   1.54724121e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [ -2.59399414e-03,  -2.56347656e-03],
                        [ -8.27026367e-03,  -8.23974609e-03],
                        [ -6.04248047e-03,  -6.01196289e-03],
                        [  1.80053711e-03,   1.77001953e-03],
                        [  1.40686035e-02,   1.40380859e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  5.83496094e-02,   5.84106445e-02],
                        [  5.13305664e-02,   5.13610840e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [ -3.72924805e-02,  -3.73229980e-02],
                        [ -1.08276367e-01,  -1.08276367e-01],
                        [ -1.70806885e-01,  -1.70806885e-01],
                        [ -2.01843262e-01,  -2.01812744e-01],
                        [ -1.93939209e-01,  -1.93908691e-01],
                        [ -1.62933350e-01,  -1.62933350e-01],
                        [ -1.34246826e-01,  -1.34307861e-01],
                        [ -1.19781494e-01,  -1.19781494e-01],
                        [ -1.12182617e-01,  -1.12182617e-01],
                        [ -1.02264404e-01,  -1.02264404e-01],
                        [ -9.07287598e-02,  -9.06982422e-02],
                        [ -8.29162598e-02,  -8.28857422e-02],
                        [ -8.09020996e-02,  -8.09631348e-02],
                        [ -8.00170898e-02,  -8.00476074e-02],
                        [ -6.96411133e-02,  -6.96105957e-02],
                        [ -4.27551270e-02,  -4.27246094e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  4.22363281e-02,   4.22668457e-02],
                        [  8.66394043e-02,   8.66088867e-02],
                        [  1.23992920e-01,   1.23901367e-01],
                        [  1.47491455e-01,   1.47491455e-01],
                        [  1.57714844e-01,   1.57806396e-01],
                        [  1.65344238e-01,   1.65374756e-01],
                        [  1.81793213e-01,   1.81793213e-01],
                        [  2.07611084e-01,   2.07580566e-01],
                        [  2.28363037e-01,   2.28302002e-01],
                        [  2.22625732e-01,   2.22595215e-01],
                        [  1.77001953e-01,   1.77062988e-01],
                        [  9.32006836e-02,   9.32922363e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -1.41876221e-01,  -1.41937256e-01],
                        [ -2.51861572e-01,  -2.51922607e-01],
                        [ -3.17718506e-01,  -3.17718506e-01],
                        [ -3.21380615e-01,  -3.21380615e-01],
                        [ -2.72644043e-01,  -2.72583008e-01],
                        [ -2.06939697e-01,  -2.06909180e-01],
                        [ -1.61407471e-01,  -1.61468506e-01],
                        [ -1.46240234e-01,  -1.46301270e-01],
                        [ -1.44195557e-01,  -1.44195557e-01],
                        [ -1.38610840e-01,  -1.38549805e-01],
                        [ -1.29943848e-01,  -1.29882812e-01],
                        [ -1.20727539e-01,  -1.20697021e-01],
                        [ -9.97924805e-02,  -9.98229980e-02],
                        [ -5.38940430e-02,  -5.39550781e-02],
                        [  1.59912109e-02,   1.59301758e-02],
                        [  9.64965820e-02,   9.65270996e-02],
                        [  1.68395996e-01,   1.68487549e-01],
                        [  2.10906982e-01,   2.10937500e-01],
                        [  2.15087891e-01,   2.15057373e-01],
                        [  1.93145752e-01,   1.93084717e-01],
                        [  1.63024902e-01,   1.62963867e-01],
                        [  1.30279541e-01,   1.30310059e-01],
                        [  9.50927734e-02,   9.51843262e-02],
                        [  6.68945312e-02,   6.69860840e-02],
                        [  5.78002930e-02,   5.77697754e-02],
                        [  6.71081543e-02,   6.70166016e-02],
                        [  8.20617676e-02,   8.20007324e-02],
                        [  8.92333984e-02,   8.92639160e-02],
                        [  8.28857422e-02,   8.29467773e-02],
                        [  6.80847168e-02,   6.81152344e-02],
                        [  5.57861328e-02,   5.57556152e-02],
                        [  5.21545410e-02,   5.20629883e-02],
                        [  5.52062988e-02,   5.51147461e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  6.10046387e-02,   6.10961914e-02],
                        [  5.76477051e-02,   5.77392578e-02],
                        [  5.29785156e-02,   5.29479980e-02],
                        [  5.27343750e-02,   5.26733398e-02],
                        [  5.72204590e-02,   5.71289062e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  5.00793457e-02,   5.01403809e-02],
                        [  3.37524414e-02,   3.38439941e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [ -4.33349609e-03,  -4.42504883e-03],
                        [ -2.31323242e-02,  -2.32238770e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -5.23681641e-02,  -5.23071289e-02],
                        [ -5.73425293e-02,  -5.72509766e-02],
                        [ -5.32531738e-02,  -5.32226562e-02],
                        [ -4.26940918e-02,  -4.27856445e-02],
                        [ -3.13720703e-02,  -3.14941406e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.96838379e-02,  -1.95922852e-02],
                        [ -2.03857422e-02,  -2.02941895e-02],
                        [ -2.28881836e-02,  -2.28576660e-02],
                        [ -2.11791992e-02,  -2.12402344e-02],
                        [ -1.11083984e-02,  -1.12304688e-02],
                        [  5.76782227e-03,   5.70678711e-03],
                        [  2.37731934e-02,   2.38647461e-02],
                        [  3.60107422e-02,   3.61328125e-02],
                        [  3.83605957e-02,   3.84216309e-02],
                        [  3.22265625e-02,   3.21655273e-02],
                        [  2.08435059e-02,   2.07214355e-02],
                        [  5.85937500e-03,   5.82885742e-03],
                        [ -9.42993164e-03,  -9.36889648e-03],
                        [ -1.77612305e-02,  -1.76391602e-02],
                        [ -1.35498047e-02,  -1.34887695e-02],
                        [ -7.62939453e-04,  -7.93457031e-04],
                        [  1.03149414e-02,   1.01623535e-02],
                        [  1.52282715e-02,   1.51672363e-02],
                        [  1.82800293e-02,   1.83410645e-02],
                        [  2.14538574e-02,   2.15759277e-02],
                        [  2.11791992e-02,   2.12402344e-02],
                        [  1.72424316e-02,   1.71813965e-02],
                        [  1.53198242e-02,   1.51977539e-02],
                        [  1.62963867e-02,   1.61743164e-02],
                        [  1.14440918e-02,   1.14746094e-02],
                        [ -8.54492188e-03,  -8.42285156e-03],
                        [ -4.67224121e-02,  -4.66308594e-02],
                        [ -9.91516113e-02,  -9.92126465e-02],
                        [ -1.51763916e-01,  -1.51885986e-01],
                        [ -1.83074951e-01,  -1.83197021e-01],
                        [ -1.82006836e-01,  -1.82006836e-01],
                        [ -1.58569336e-01,  -1.58416748e-01],
                        [ -1.31256104e-01,  -1.31134033e-01],
                        [ -1.10504150e-01,  -1.10534668e-01],
                        [ -9.77783203e-02,  -9.79309082e-02],
                        [ -9.17968750e-02,  -9.19189453e-02],
                        [ -8.79211426e-02,  -8.79211426e-02],
                        [ -7.91015625e-02,  -7.89794922e-02],
                        [ -6.55212402e-02,  -6.53991699e-02],
                        [ -5.59387207e-02,  -5.59082031e-02],
                        [ -5.12390137e-02,  -5.13916016e-02],
                        [ -3.62243652e-02,  -3.63464355e-02],
                        [  3.63159180e-03,   3.60107422e-03],
                        [  6.22253418e-02,   6.23779297e-02],
                        [  1.18347168e-01,   1.18469238e-01],
                        [  1.57318115e-01,   1.57348633e-01],
                        [  1.81182861e-01,   1.81060791e-01],
                        [  1.99066162e-01,   1.98883057e-01],
                        [  2.16217041e-01,   2.16156006e-01],
                        [  2.29461670e-01,   2.29583740e-01],
                        [  2.26837158e-01,   2.26989746e-01],
                        [  1.93725586e-01,   1.93756104e-01],
                        [  1.23718262e-01,   1.23626709e-01],
                        [  2.25219727e-02,   2.23693848e-02],
                        [ -9.71984863e-02,  -9.72595215e-02],
                        [ -2.17132568e-01,  -2.17041016e-01],
                        [ -3.08380127e-01,  -3.08197021e-01],
                        [ -3.39355469e-01,  -3.39294434e-01],
                        [ -3.03253174e-01,  -3.03344727e-01],
                        [ -2.32055664e-01,  -2.32238770e-01],
                        [ -1.72302246e-01,  -1.72393799e-01],
                        [ -1.46636963e-01,  -1.46545410e-01],
                        [ -1.43676758e-01,  -1.43463135e-01],
                        [ -1.41387939e-01,  -1.41265869e-01],
                        [ -1.31378174e-01,  -1.31469727e-01],
                        [ -1.17218018e-01,  -1.17401123e-01],
                        [ -9.78393555e-02,  -9.79309082e-02],
                        [ -6.11267090e-02,  -6.10351562e-02],
                        [  4.54711914e-03,   4.73022461e-03],
                        [  9.32922363e-02,   9.34448242e-02],
                        [  1.77703857e-01,   1.77642822e-01],
                        [  2.25402832e-01,   2.25189209e-01],
                        [  2.23541260e-01,   2.23419189e-01],
                        [  1.87927246e-01,   1.88018799e-01],
                        [  1.48071289e-01,   1.48254395e-01],
                        [  1.21063232e-01,   1.21215820e-01],
                        [  1.01837158e-01,   1.01776123e-01],
                        [  7.88879395e-02,   7.87048340e-02],
                        [  5.35278320e-02,   5.33752441e-02],
                        [  3.85437012e-02,   3.85742188e-02],
                        [  4.19311523e-02,   4.21447754e-02],
                        [  5.73120117e-02,   5.74645996e-02],
                        [  7.06787109e-02,   7.06481934e-02],
                        [  7.38525391e-02,   7.36694336e-02],
                        [  6.98242188e-02,   6.96411133e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  7.08007812e-02,   7.09838867e-02],
                        [  7.62939453e-02,   7.65075684e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  7.36999512e-02,   7.35168457e-02],
                        [  6.48498535e-02,   6.46667480e-02],
                        [  5.27648926e-02,   5.27343750e-02],
                        [  4.03137207e-02,   4.04968262e-02],
                        [  3.11889648e-02,   3.14025879e-02],
                        [  2.52380371e-02,   2.52685547e-02],
                        [  1.82495117e-02,   1.80358887e-02],
                        [  8.72802734e-03,   8.51440430e-03],
                        [ -2.44140625e-04,  -2.74658203e-04],
                        [ -8.11767578e-03,  -7.96508789e-03],
                        [ -1.73950195e-02,  -1.71813965e-02],
                        [ -2.77404785e-02,  -2.76794434e-02],
                        [ -3.65905762e-02,  -3.67431641e-02],
                        [ -4.25109863e-02,  -4.27551270e-02],
                        [ -4.44030762e-02,  -4.44946289e-02],
                        [ -4.18701172e-02,  -4.17175293e-02],
                        [ -3.62854004e-02,  -3.60717773e-02],
                        [ -2.86254883e-02,  -2.85339355e-02],
                        [ -1.89208984e-02,  -1.90429688e-02],
                        [ -9.33837891e-03,  -9.61303711e-03],
                        [ -1.31225586e-03,  -1.43432617e-03],
                        [  8.94165039e-03,   9.09423828e-03],
                        [  2.23999023e-02,   2.26440430e-02],
                        [  2.88391113e-02,   2.89611816e-02],
                        [  1.98669434e-02,   1.97448730e-02],
                        [  4.63867188e-03,   4.39453125e-03],
                        [ -2.16674805e-03,  -2.31933594e-03],
                        [ -8.54492188e-04,  -7.32421875e-04],
                        [ -1.19018555e-03,  -9.15527344e-04],
                        [ -4.42504883e-03,  -4.27246094e-03],
                        [ -3.50952148e-03,  -3.60107422e-03],
                        [  1.92260742e-03,   1.67846680e-03],
                        [  3.44848633e-03,   3.26538086e-03],
                        [ -1.73950195e-03,  -1.64794922e-03],
                        [ -5.27954102e-03,  -5.03540039e-03],
                        [ -1.34277344e-03,  -1.12915039e-03],
                        [  5.27954102e-03,   5.18798828e-03],
                        [  7.87353516e-03,   7.59887695e-03],
                        [  8.17871094e-03,   7.96508789e-03],
                        [  1.36413574e-02,   1.36718750e-02],
                        [  2.69470215e-02,   2.71911621e-02],
                        [  4.06188965e-02,   4.08325195e-02],
                        [  4.18395996e-02,   4.18090820e-02],
                        [  2.21557617e-02,   2.19116211e-02],
                        [ -1.77612305e-02,  -1.80053711e-02],
                        [ -7.14721680e-02,  -7.14416504e-02],
                        [ -1.29211426e-01,  -1.28936768e-01],
                        [ -1.76361084e-01,  -1.76116943e-01],
                        [ -1.96868896e-01,  -1.96899414e-01],
                        [ -1.84722900e-01,  -1.84967041e-01],
                        [ -1.49444580e-01,  -1.49688721e-01],
                        [ -1.10046387e-01,  -1.10076904e-01],
                        [ -8.33740234e-02,  -8.31604004e-02],
                        [ -7.43103027e-02,  -7.40356445e-02],
                        [ -7.42797852e-02,  -7.42187500e-02],
                        [ -7.14721680e-02,  -7.17163086e-02],
                        [ -6.16149902e-02,  -6.18896484e-02],
                        [ -4.78515625e-02,  -4.78820801e-02],
                        [ -3.09753418e-02,  -3.07617188e-02],
                        [ -4.60815430e-03,  -4.33349609e-03],
                        [  3.61328125e-02,   3.62243652e-02],
                        [  8.41064453e-02,   8.38928223e-02],
                        [  1.26037598e-01,   1.25701904e-01],
                        [  1.56738281e-01,   1.56646729e-01],
                        [  1.80450439e-01,   1.80664062e-01],
                        [  1.99890137e-01,   2.00195312e-01],
                        [  2.12158203e-01,   2.12249756e-01],
                        [  2.12951660e-01,   2.12768555e-01],
                        [  1.95770264e-01,   1.95465088e-01],
                        [  1.48773193e-01,   1.48620605e-01],
                        [  6.40869141e-02,   6.42395020e-02],
                        [ -4.95300293e-02,  -4.91943359e-02],
                        [ -1.68762207e-01,  -1.68609619e-01],
                        [ -2.66815186e-01,  -2.66967773e-01],
                        [ -3.20007324e-01,  -3.20343018e-01],
                        [ -3.14178467e-01,  -3.14361572e-01],
                        [ -2.57110596e-01,  -2.56988525e-01],
                        [ -1.84570312e-01,  -1.84234619e-01],
                        [ -1.38183594e-01,  -1.37969971e-01],
                        [ -1.29394531e-01,  -1.29516602e-01],
                        [ -1.35253906e-01,  -1.35589600e-01],
                        [ -1.31713867e-01,  -1.31927490e-01],
                        [ -1.16363525e-01,  -1.16271973e-01],
                        [ -9.48181152e-02,  -9.44824219e-02],
                        [ -6.19812012e-02,  -6.17370605e-02],
                        [ -7.96508789e-03,  -8.05664062e-03],
                        [  6.54907227e-02,   6.51550293e-02],
                        [  1.41357422e-01,   1.41113281e-01],
                        [  1.96441650e-01,   1.96533203e-01],
                        [  2.14355469e-01,   2.14691162e-01],
                        [  1.97052002e-01,   1.97326660e-01],
                        [  1.63513184e-01,   1.63482666e-01],
                        [  1.33544922e-01,   1.33209229e-01],
                        [  1.13311768e-01,   1.13037109e-01],
                        [  9.79614258e-02,   9.79919434e-02],
                        [  8.34655762e-02,   8.37707520e-02],
                        [  7.22045898e-02,   7.25097656e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  6.90307617e-02,   6.87255859e-02],
                        [  7.18688965e-02,   7.15332031e-02],
                        [  7.15637207e-02,   7.15332031e-02],
                        [  6.72607422e-02,   6.75659180e-02],
                        [  6.23779297e-02,   6.27441406e-02],
                        [  5.97839355e-02,   5.98144531e-02],
                        [  5.94787598e-02,   5.91735840e-02],
                        [  6.13708496e-02,   6.10351562e-02],
                        [  6.39953613e-02,   6.39343262e-02],
                        [  6.26831055e-02,   6.29272461e-02],
                        [  5.48706055e-02,   5.52368164e-02],
                        [  4.49523926e-02,   4.50439453e-02],
                        [  3.83911133e-02,   3.81164551e-02],
                        [  3.47900391e-02,   3.44238281e-02],
                        [  3.03039551e-02,   3.02124023e-02],
                        [  2.30407715e-02,   2.32849121e-02],
                        [  1.28479004e-02,   1.32141113e-02],
                        [ -6.40869141e-04,  -4.88281250e-04],
                        [ -1.68762207e-02,  -1.71203613e-02],
                        [ -3.20739746e-02,  -3.24707031e-02],
                        [ -3.97033691e-02,  -3.98559570e-02],
                        [ -3.65600586e-02,  -3.63159180e-02],
                        [ -2.81982422e-02,  -2.78320312e-02],
                        [ -2.23388672e-02,  -2.21557617e-02],
                        [ -1.91955566e-02,  -1.93786621e-02],
                        [ -1.58691406e-02,  -1.62658691e-02],
                        [ -1.38854980e-02,  -1.40991211e-02],
                        [ -1.49536133e-02,  -1.47705078e-02],
                        [ -1.51977539e-02,  -1.48010254e-02],
                        [ -9.85717773e-03,  -9.64355469e-03],
                        [ -1.22070312e-04,  -3.05175781e-04],
                        [  8.17871094e-03,   7.78198242e-03],
                        [  1.10778809e-02,   1.08032227e-02],
                        [  9.36889648e-03,   9.52148438e-03],
                        [  6.98852539e-03,   7.38525391e-03],
                        [  6.80541992e-03,   7.08007812e-03],
                        [  7.41577148e-03,   7.32421875e-03],
                        [  5.79833984e-03,   5.37109375e-03],
                        [  2.96020508e-03,   2.65502930e-03],
                        [  2.13623047e-03,   2.22778320e-03],
                        [  1.49536133e-03,   1.89208984e-03],
                        [ -4.08935547e-03,  -3.78417969e-03],
                        [ -1.37939453e-02,  -1.38549805e-02],
                        [ -1.95312500e-02,  -1.98974609e-02],
                        [ -1.51672363e-02,  -1.55334473e-02],
                        [ -2.96020508e-03,  -2.92968750e-03],
                        [  9.30786133e-03,   9.70458984e-03],
                        [  1.37939453e-02,   1.41601562e-02],
                        [  8.85009766e-03,   8.81958008e-03],
                        [  3.44848633e-03,   3.08227539e-03],
                        [  8.30078125e-03,   7.93457031e-03],
                        [  1.95922852e-02,   1.95617676e-02],
                        [  1.99584961e-02,   2.03247070e-02],
                        [ -3.72314453e-03,  -3.29589844e-03],
                        [ -5.05981445e-02,  -5.05371094e-02],
                        [ -1.09344482e-01,  -1.09710693e-01],
                        [ -1.62048340e-01,  -1.62445068e-01],
                        [ -1.88262939e-01,  -1.88323975e-01],
                        [ -1.78497314e-01,  -1.78161621e-01],
                        [ -1.44989014e-01,  -1.44592285e-01],
                        [ -1.10626221e-01,  -1.10504150e-01],
                        [ -8.82873535e-02,  -8.85925293e-02],
                        [ -7.68737793e-02,  -7.73315430e-02],
                        [ -7.23571777e-02,  -7.24792480e-02],
                        [ -7.40356445e-02,  -7.37304688e-02],
                        [ -7.99255371e-02,  -7.94982910e-02],
                        [ -8.06579590e-02,  -8.05053711e-02],
                        [ -6.30798340e-02,  -6.33544922e-02],
                        [ -2.18811035e-02,  -2.23388672e-02],
                        [  3.46679688e-02,   3.44848633e-02],
                        [  9.12475586e-02,   9.15222168e-02],
                        [  1.36749268e-01,   1.37237549e-01],
                        [  1.69281006e-01,   1.69494629e-01],
                        [  1.92718506e-01,   1.92474365e-01],
                        [  2.11517334e-01,   2.11059570e-01],
                        [  2.26257324e-01,   2.26013184e-01],
                        [  2.28881836e-01,   2.29095459e-01],
                        [  2.03063965e-01,   2.03552246e-01],
                        [  1.35375977e-01,   1.35650635e-01],
                        [  2.81677246e-02,   2.79846191e-02],
                        [ -9.91821289e-02,  -9.96704102e-02],
                        [ -2.19451904e-01,  -2.19757080e-01],
                        [ -3.05175781e-01,  -3.04992676e-01],
                        [ -3.34869385e-01,  -3.34381104e-01],
                        [ -3.06304932e-01,  -3.05999756e-01],
                        [ -2.44995117e-01,  -2.45147705e-01],
                        [ -1.88751221e-01,  -1.89239502e-01],
                        [ -1.59210205e-01,  -1.59545898e-01],
                        [ -1.49719238e-01,  -1.49597168e-01],
                        [ -1.40075684e-01,  -1.39617920e-01],
                        [ -1.19903564e-01,  -1.19537354e-01],
                        [ -9.28955078e-02,  -9.29870605e-02],
                        [ -6.02416992e-02,  -6.07299805e-02],
                        [ -1.29394531e-02,  -1.33361816e-02],
                        [  5.29479980e-02,   5.29785156e-02],
                        [  1.23565674e-01,   1.24023438e-01],
                        [  1.77978516e-01,   1.78405762e-01],
                        [  2.04559326e-01,   2.04528809e-01],
                        [  2.02667236e-01,   2.02209473e-01],
                        [  1.77124023e-01,   1.76696777e-01],
                        [  1.39251709e-01,   1.39251709e-01],
                        [  1.05529785e-01,   1.05957031e-01],
                        [  8.63647461e-02,   8.67919922e-02],
                        [  7.88574219e-02,   7.88879395e-02],
                        [  7.46765137e-02,   7.42492676e-02],
                        [  7.08312988e-02,   7.03735352e-02],
                        [  6.89392090e-02,   6.88781738e-02],
                        [  6.76879883e-02,   6.80847168e-02],
                        [  6.32019043e-02,   6.36901855e-02],
                        [  5.59387207e-02,   5.60302734e-02],
                        [  5.06286621e-02,   5.02624512e-02],
                        [  5.04455566e-02,   4.99572754e-02],
                        [  5.47485352e-02,   5.46264648e-02],
                        [  6.09130859e-02,   6.12487793e-02],
                        [  6.65588379e-02,   6.70776367e-02],
                        [  7.04650879e-02,   7.06481934e-02],
                        [  7.14721680e-02,   7.11364746e-02],
                        [  6.87255859e-02,   6.82067871e-02],
                        [  6.22863770e-02,   6.21032715e-02],
                        [  5.20019531e-02,   5.23071289e-02],
                        [  3.81164551e-02,   3.86352539e-02],
                        [  2.44750977e-02,   2.47192383e-02],
                        [  1.56555176e-02,   1.53503418e-02],
                        [  9.64355469e-03,   9.09423828e-03],
                        [ -1.37329102e-03,  -1.61743164e-03],
                        [ -1.95922852e-02,  -1.93481445e-02],
                        [ -3.61022949e-02,  -3.55529785e-02],
                        [ -4.09240723e-02,  -4.06188965e-02],
                        [ -3.43322754e-02,  -3.45458984e-02],
                        [ -2.42309570e-02,  -2.47802734e-02],
                        [ -1.69067383e-02,  -1.72424316e-02],
                        [ -1.38244629e-02,  -1.36108398e-02],
                        [ -1.39160156e-02,  -1.33972168e-02],
                        [ -1.47399902e-02,  -1.44042969e-02],
                        [ -1.23291016e-02,  -1.25122070e-02],
                        [ -4.45556641e-03,  -4.97436523e-03],
                        [  5.95092773e-03,   5.55419922e-03],
                        [  1.37329102e-02,   1.38854980e-02],
                        [  1.70593262e-02,   1.76086426e-02],
                        [  1.80664062e-02,   1.84631348e-02],
                        [  1.95312500e-02,   1.94091797e-02],
                        [  2.08740234e-02,   2.03552246e-02],
                        [  1.80969238e-02,   1.76391602e-02],
                        [  1.03759766e-02,   1.04675293e-02],
                        [  2.34985352e-03,   2.86865234e-03],
                        [ -3.81469727e-03,  -3.35693359e-03],
                        [ -1.17492676e-02,  -1.17797852e-02],
                        [ -2.25524902e-02,  -2.30407715e-02],
                        [ -2.96020508e-02,  -3.00903320e-02],
                        [ -2.69165039e-02,  -2.68859863e-02],
                        [ -1.68151855e-02,  -1.63269043e-02],
                        [ -5.49316406e-03,  -4.97436523e-03],
                        [  4.42504883e-03,   4.45556641e-03],
                        [  1.22680664e-02,   1.17797852e-02],
                        [  1.68457031e-02,   1.63269043e-02],
                        [  1.95007324e-02,   1.94396973e-02],
                        [  2.48718262e-02,   2.53295898e-02],
                        [  3.46069336e-02,   3.51562500e-02],
                        [  4.17785645e-02,   4.18701172e-02],
                        [  3.44238281e-02,   3.39965820e-02],
                        [  4.82177734e-03,   4.27246094e-03],
                        [ -4.55932617e-02,  -4.57153320e-02],
                        [ -1.05865479e-01,  -1.05438232e-01],
                        [ -1.56677246e-01,  -1.56127930e-01],
                        [ -1.78741455e-01,  -1.78558350e-01],
                        [ -1.67419434e-01,  -1.67816162e-01],
                        [ -1.39251709e-01,  -1.39831543e-01],
                        [ -1.18591309e-01,  -1.18804932e-01],
                        [ -1.15051270e-01,  -1.14685059e-01],
                        [ -1.16271973e-01,  -1.15692139e-01],
                        [ -1.05499268e-01,  -1.05255127e-01],
                        [ -8.21533203e-02,  -8.24890137e-02],
                        [ -5.92956543e-02,  -5.98754883e-02],
                        [ -4.46472168e-02,  -4.49523926e-02],
                        [ -3.06701660e-02,  -3.03649902e-02],
                        [ -3.35693359e-03,  -2.74658203e-03],
                        [  4.28466797e-02,   4.31518555e-02],
                        [  1.00646973e-01,   1.00372314e-01],
                        [  1.56463623e-01,   1.55853271e-01],
                        [  1.99493408e-01,   1.99127197e-01],
                        [  2.27722168e-01,   2.27966309e-01],
                        [  2.44598389e-01,   2.45208740e-01],
                        [  2.47222900e-01,   2.47619629e-01],
                        [  2.22076416e-01,   2.21862793e-01],
                        [  1.57135010e-01,   1.56524658e-01],
                        [  5.53894043e-02,   5.49926758e-02],
                        [ -6.79016113e-02,  -6.77185059e-02],
                        [ -1.92840576e-01,  -1.92260742e-01],
                        [ -2.91992188e-01,  -2.91534424e-01],
                        [ -3.34564209e-01,  -3.34686279e-01],
                        [ -3.11950684e-01,  -3.12530518e-01],
                        [ -2.52471924e-01,  -2.52929688e-01],
                        [ -1.98730469e-01,  -1.98638916e-01],
                        [ -1.72760010e-01,  -1.72180176e-01],
                        [ -1.66381836e-01,  -1.65893555e-01],
                        [ -1.58813477e-01,  -1.58874512e-01],
                        [ -1.37451172e-01,  -1.38000488e-01],
                        [ -1.02874756e-01,  -1.03424072e-01],
                        [ -5.95703125e-02,  -5.95397949e-02],
                        [ -6.40869141e-03,  -5.85937500e-03],
                        [  5.85021973e-02,   5.90515137e-02],
                        [  1.26922607e-01,   1.26953125e-01],
                        [  1.80725098e-01,   1.80206299e-01],
                        [  2.05657959e-01,   2.05108643e-01],
                        [  2.01751709e-01,   2.01690674e-01],
                        [  1.79595947e-01,   1.80084229e-01],
                        [  1.50604248e-01,   1.51214600e-01],
                        [  1.22680664e-01,   1.22772217e-01],
                        [  1.01196289e-01,   1.00708008e-01],
                        [  8.77685547e-02,   8.71582031e-02],
                        [  7.75756836e-02,   7.74230957e-02],
                        [  6.48498535e-02,   6.53076172e-02],
                        [  5.10864258e-02,   5.17272949e-02],
                        [  4.11987305e-02,   4.13818359e-02],
                        [  3.51867676e-02,   3.47595215e-02],
                        [  3.15246582e-02,   3.08837891e-02],
                        [  3.35998535e-02,   3.33862305e-02],
                        [  4.51354980e-02,   4.55627441e-02],
                        [  6.19812012e-02,   6.26220703e-02],
                        [  7.71179199e-02,   7.73620605e-02],
                        [  8.88977051e-02,   8.85314941e-02],
                        [  9.64660645e-02,   9.58251953e-02],
                        [  9.47570801e-02,   9.44519043e-02],
                        [  8.18786621e-02,   8.22143555e-02],
                        [  6.42089844e-02,   6.48803711e-02],
                        [  4.83093262e-02,   4.86450195e-02],
                        [  3.44543457e-02,   3.41186523e-02],
                        [  2.18200684e-02,   2.11486816e-02],
                        [  1.19323730e-02,   1.15661621e-02],
                        [  3.60107422e-03,   3.87573242e-03],
                        [ -7.87353516e-03,  -7.23266602e-03],
                        [ -2.24609375e-02,  -2.20642090e-02],
                        [ -3.40270996e-02,  -3.42407227e-02],
                        [ -3.95202637e-02,  -4.01611328e-02],
                        [ -4.18701172e-02,  -4.22973633e-02],
                        [ -4.23278809e-02,  -4.21142578e-02],
                        [ -3.73229980e-02,  -3.66821289e-02],
                        [ -2.52075195e-02,  -2.47497559e-02],
                        [ -1.11999512e-02,  -1.13525391e-02],
                        [ -2.10571289e-03,  -2.71606445e-03],
                        [  2.22778320e-03,   1.70898438e-03],
                        [  8.02612305e-03,   8.11767578e-03],
                        [  1.72424316e-02,   1.78833008e-02],
                        [  2.16979980e-02,   2.22167969e-02],
                        [  1.30615234e-02,   1.29699707e-02],
                        [ -3.29589844e-03,  -3.90625000e-03],
                        [ -1.33972168e-02,  -1.39465332e-02],
                        [ -1.22680664e-02,  -1.22375488e-02],
                        [ -6.46972656e-03,  -5.85937500e-03],
                        [ -1.83105469e-03,  -1.25122070e-03],
                        [  2.74658203e-04,   3.05175781e-04],
                        [ -1.95312500e-03,  -2.53295898e-03],
                        [ -9.85717773e-03,  -1.04675293e-02],
                        [ -1.95617676e-02,  -1.95922852e-02],
                        [ -2.49328613e-02,  -2.43835449e-02],
                        [ -2.42614746e-02,  -2.36206055e-02],
                        [ -2.05688477e-02,  -2.04772949e-02],
                        [ -1.69677734e-02,  -1.74865723e-02],
                        [ -1.31530762e-02,  -1.37939453e-02],
                        [ -7.32421875e-03,  -7.47680664e-03],
                        [  5.79833984e-04,   1.06811523e-03],
                        [  9.70458984e-03,   1.03759766e-02],
                        [  2.20947266e-02,   2.22473145e-02],
                        [  3.96118164e-02,   3.91235352e-02],
                        [  5.58776855e-02,   5.52062988e-02],
                        [  5.81359863e-02,   5.79223633e-02],
                        [  3.89404297e-02,   3.93676758e-02],
                        [  3.66210938e-04,   1.06811523e-03],
                        [ -5.14526367e-02,  -5.12084961e-02],
                        [ -1.08642578e-01,  -1.09039307e-01],
                        [ -1.57928467e-01,  -1.58630371e-01],
                        [ -1.83532715e-01,  -1.83837891e-01],
                        [ -1.78771973e-01,  -1.78405762e-01],
                        [ -1.54083252e-01,  -1.53381348e-01],
                        [ -1.28509521e-01,  -1.28173828e-01],
                        [ -1.12396240e-01,  -1.12762451e-01],
                        [ -1.00952148e-01,  -1.01654053e-01],
                        [ -8.55712891e-02,  -8.59680176e-02],
                        [ -6.69860840e-02,  -6.66809082e-02],
                        [ -5.13000488e-02,  -5.05981445e-02],
                        [ -3.72009277e-02,  -3.67736816e-02],
                        [ -1.47399902e-02,  -1.50146484e-02],
                        [  2.35290527e-02,   2.28271484e-02],
                        [  7.54089355e-02,   7.49511719e-02],
                        [  1.32141113e-01,   1.32354736e-01],
                        [  1.84875488e-01,   1.85546875e-01],
                        [  2.26074219e-01,   2.26562500e-01],
                        [  2.47802734e-01,   2.47650146e-01],
                        [  2.42584229e-01,   2.41912842e-01],
                        [  2.05902100e-01,   2.05383301e-01],
                        [  1.36230469e-01,   1.36383057e-01],
                        [  3.53698730e-02,   3.60412598e-02],
                        [ -8.64868164e-02,  -8.59375000e-02],
                        [ -2.07092285e-01,  -2.07183838e-01],
                        [ -2.97210693e-01,  -2.97851562e-01],
                        [ -3.33099365e-01,  -3.33679199e-01],
                        [ -3.10302734e-01,  -3.10241699e-01],
                        [ -2.52014160e-01,  -2.51403809e-01],
                        [ -1.98486328e-01,  -1.97875977e-01],
                        [ -1.75384521e-01,  -1.75415039e-01],
                        [ -1.72851562e-01,  -1.73461914e-01],
                        [ -1.62200928e-01,  -1.62841797e-01],
                        [ -1.29119873e-01,  -1.29150391e-01],
                        [ -8.01086426e-02,  -7.95288086e-02],
                        [ -2.29492188e-02,  -2.23083496e-02],
                        [  4.27551270e-02,   4.28466797e-02],
                        [  1.13250732e-01,   1.12670898e-01],
                        [  1.72912598e-01,   1.72241211e-01],
                        [  2.06451416e-01,   2.06329346e-01],
                        [  2.11212158e-01,   2.11761475e-01],
                        [  1.94183350e-01,   1.94854736e-01],
                        [  1.65008545e-01,   1.65191650e-01],
                        [  1.32934570e-01,   1.32415771e-01],
                        [  1.03179932e-01,   1.02478027e-01],
                        [  7.66906738e-02,   7.64770508e-02],
                        [  5.73120117e-02,   5.78002930e-02],
                        [  5.23986816e-02,   5.31311035e-02],
                        [  6.01196289e-02,   6.03637695e-02],
                        [  6.53076172e-02,   6.48803711e-02],
                        [  5.70678711e-02,   5.63354492e-02],
                        [  4.19006348e-02,   4.15954590e-02],
                        [  3.33251953e-02,   3.37219238e-02],
                        [  3.56445312e-02,   3.63769531e-02],
                        [  4.47998047e-02,   4.51354980e-02],
                        [  5.78002930e-02,   5.74340820e-02],
                        [  7.36999512e-02,   7.29675293e-02],
                        [  8.70361328e-02,   8.66699219e-02],
                        [  8.90502930e-02,   8.93554688e-02],
                        [  7.73315430e-02,   7.80334473e-02],
                        [  5.90820312e-02,   5.95092773e-02],
                        [  4.24194336e-02,   4.21447754e-02],
                        [  2.98156738e-02,   2.90832520e-02],
                        [  1.94091797e-02,   1.89514160e-02],
                        [  8.42285156e-03,   8.66699219e-03],
                        [ -3.60107422e-03,  -2.89916992e-03],
                        [ -1.26037598e-02,  -1.21154785e-02],
                        [ -1.47399902e-02,  -1.49230957e-02],
                        [ -1.32141113e-02,  -1.39160156e-02],
                        [ -1.49230957e-02,  -1.54724121e-02],
                        [ -2.19726562e-02,  -2.18200684e-02],
                        [ -3.09448242e-02,  -3.02734375e-02],
                        [ -3.72009277e-02,  -3.66516113e-02],
                        [ -3.56750488e-02,  -3.57971191e-02],
                        [ -2.38952637e-02,  -2.45666504e-02],
                        [ -6.56127930e-03,  -7.17163086e-03],
                        [  7.50732422e-03,   7.56835938e-03],
                        [  1.38854980e-02,   1.45263672e-02],
                        [  1.43737793e-02,   1.49841309e-02],
                        [  1.30920410e-02,   1.30615234e-02],
                        [  1.18713379e-02,   1.12609863e-02],
                        [  8.23974609e-03,   7.59887695e-03],
                        [ -7.93457031e-04,  -8.23974609e-04],
                        [ -1.23596191e-02,  -1.17492676e-02],
                        [ -1.89819336e-02,  -1.83410645e-02],
                        [ -1.70288086e-02,  -1.69677734e-02],
                        [ -1.01928711e-02,  -1.07727051e-02],
                        [ -4.05883789e-03,  -4.73022461e-03],
                        [ -1.15966797e-03,  -1.28173828e-03],
                        [ -2.56347656e-03,  -2.01416016e-03],
                        [ -1.00097656e-02,  -9.30786133e-03],
                        [ -2.23999023e-02,  -2.22473145e-02],
                        [ -3.30505371e-02,  -3.35998535e-02],
                        [ -3.56750488e-02,  -3.64074707e-02],
                        [ -3.15551758e-02,  -3.17687988e-02],
                        [ -2.48718262e-02,  -2.43835449e-02],
                        [ -1.44042969e-02,  -1.36718750e-02],
                        [  1.25122070e-03,   1.49536133e-03],
                        [  1.57775879e-02,   1.53198242e-02],
                        [  2.30712891e-02,   2.23083496e-02],
                        [  2.61535645e-02,   2.58483887e-02],
                        [  2.92968750e-02,   2.97241211e-02],
                        [  2.81677246e-02,   2.89001465e-02],
                        [  1.72119141e-02,   1.75476074e-02],
                        [ -2.74658203e-03,  -3.11279297e-03],
                        [ -3.16162109e-02,  -3.23486328e-02],
                        [ -7.32421875e-02,  -7.36389160e-02],
                        [ -1.21917725e-01,  -1.21551514e-01],
                        [ -1.56433105e-01,  -1.55700684e-01],
                        [ -1.59332275e-01,  -1.58905029e-01],
                        [ -1.36199951e-01,  -1.36535645e-01],
                        [ -1.08825684e-01,  -1.09558105e-01],
                        [ -9.19799805e-02,  -9.24377441e-02],
                        [ -8.36486816e-02,  -8.34045410e-02],
                        [ -7.46154785e-02,  -7.38830566e-02],
                        [ -6.15844727e-02,  -6.10961914e-02],
                        [ -4.78210449e-02,  -4.80346680e-02],
                        [ -3.43322754e-02,  -3.50646973e-02],
                        [ -1.51367188e-02,  -1.56555176e-02],
                        [  1.73339844e-02,   1.75170898e-02],
                        [  6.35681152e-02,   6.42700195e-02],
                        [  1.16058350e-01,   1.16638184e-01],
                        [  1.66137695e-01,   1.66015625e-01],
                        [  2.07824707e-01,   2.07153320e-01],
                        [  2.33215332e-01,   2.32635498e-01],
                        [  2.30072021e-01,   2.30133057e-01],
                        [  1.89514160e-01,   1.90185547e-01],
                        [  1.12243652e-01,   1.12854004e-01],
                        [  3.99780273e-03,   3.96728516e-03],
                        [ -1.24877930e-01,  -1.25518799e-01],
                        [ -2.49114990e-01,  -2.49755859e-01],
                        [ -3.30383301e-01,  -3.30413818e-01],
                        [ -3.42468262e-01,  -3.41827393e-01],
                        [ -2.93487549e-01,  -2.92816162e-01],
                        [ -2.20916748e-01,  -2.20855713e-01],
                        [ -1.66076660e-01,  -1.66687012e-01],
                        [ -1.47735596e-01,  -1.48406982e-01],
                        [ -1.52008057e-01,  -1.52130127e-01],
                        [ -1.48071289e-01,  -1.47491455e-01],
                        [ -1.16973877e-01,  -1.16241455e-01],
                        [ -6.39648438e-02,  -6.38122559e-02],
                        [ -2.71606445e-03,  -3.26538086e-03],
                        [  6.17980957e-02,   6.10961914e-02],
                        [  1.27227783e-01,   1.27044678e-01],
                        [  1.80877686e-01,   1.81396484e-01],
                        [  2.06420898e-01,   2.07153320e-01],
                        [  2.01873779e-01,   2.02117920e-01],
                        [  1.80541992e-01,   1.80053711e-01],
                        [  1.54937744e-01,   1.54174805e-01],
                        [  1.28143311e-01,   1.27868652e-01],
                        [  1.00433350e-01,   1.00891113e-01],
                        [  7.61413574e-02,   7.69042969e-02],
                        [  6.16455078e-02,   6.19812012e-02],
                        [  5.91125488e-02,   5.87158203e-02],
                        [  6.29882812e-02,   6.22253418e-02],
                        [  6.38427734e-02,   6.34460449e-02],
                        [  5.72814941e-02,   5.76477051e-02],
                        [  4.74243164e-02,   4.81567383e-02],
                        [  4.03442383e-02,   4.07714844e-02],
                        [  3.81164551e-02,   3.77807617e-02],
                        [  3.99780273e-02,   3.92456055e-02],
                        [  4.58374023e-02,   4.53796387e-02],
                        [  5.48400879e-02,   5.51147461e-02],
                        [  6.35375977e-02,   6.42700195e-02],
                        [  6.87561035e-02,   6.92749023e-02],
                        [  7.02514648e-02,   7.00378418e-02],
                        [  6.85119629e-02,   6.77795410e-02],
                        [  6.23474121e-02,   6.18286133e-02],
                        [  5.02014160e-02,   5.04150391e-02],
                        [  3.22875977e-02,   3.29895020e-02],
                        [  1.11999512e-02,   1.17797852e-02],
                        [ -7.41577148e-03,  -7.56835938e-03],
                        [ -1.72119141e-02,  -1.79138184e-02],
                        [ -1.65710449e-02,  -1.71508789e-02],
                        [ -1.27563477e-02,  -1.26342773e-02],
                        [ -1.62658691e-02,  -1.55639648e-02],
                        [ -2.86254883e-02,  -2.80151367e-02],
                        [ -3.86047363e-02,  -3.86657715e-02],
                        [ -3.50646973e-02,  -3.57360840e-02],
                        [ -2.05688477e-02,  -2.12097168e-02],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [  2.74658203e-04,   9.46044922e-04],
                        [  4.30297852e-03,   4.97436523e-03],
                        [  8.11767578e-03,   8.14819336e-03],
                        [  1.08032227e-02,   1.01623535e-02],
                        [  1.18103027e-02,   1.11083984e-02],
                        [  1.08947754e-02,   1.08032227e-02],
                        [  5.46264648e-03,   6.04248047e-03],
                        [ -4.21142578e-03,  -3.47900391e-03],
                        [ -9.85717773e-03,  -9.73510742e-03],
                        [ -3.93676758e-03,  -4.51660156e-03],
                        [  9.33837891e-03,   8.63647461e-03],
                        [  1.91955566e-02,   1.90124512e-02],
                        [  2.01110840e-02,   2.06298828e-02],
                        [  1.14440918e-02,   1.21765137e-02],
                        [ -6.59179688e-03,  -6.37817383e-03],
                        [ -2.82287598e-02,  -2.87170410e-02],
                        [ -4.29382324e-02,  -4.37011719e-02],
                        [ -4.65087891e-02,  -4.67834473e-02],
                        [ -4.22058105e-02,  -4.17480469e-02],
                        [ -3.21350098e-02,  -3.13720703e-02],
                        [ -1.80969238e-02,  -1.77917480e-02],
                        [ -6.86645508e-03,  -7.26318359e-03],
                        [ -3.78417969e-03,  -4.51660156e-03],
                        [ -6.50024414e-03,  -6.86645508e-03],
                        [ -9.55200195e-03,  -9.15527344e-03],
                        [ -8.69750977e-03,  -7.93457031e-03],
                        [ -7.62939453e-04,  -3.66210938e-04],
                        [  1.33972168e-02,   1.30615234e-02],
                        [  2.63977051e-02,   2.56347656e-02],
                        [  2.85949707e-02,   2.81677246e-02],
                        [  1.17797852e-02,   1.20849609e-02],
                        [ -2.83813477e-02,  -2.76489258e-02],
                        [ -8.43200684e-02,  -8.38317871e-02],
                        [ -1.34582520e-01,  -1.34826660e-01],
                        [ -1.59027100e-01,  -1.59790039e-01],
                        [ -1.54846191e-01,  -1.55395508e-01],
                        [ -1.34185791e-01,  -1.33972168e-01],
                        [ -1.10473633e-01,  -1.09741211e-01],
                        [ -9.09118652e-02,  -9.03625488e-02],
                        [ -7.60498047e-02,  -7.62023926e-02],
                        [ -6.19812012e-02,  -6.26831055e-02],
                        [ -4.41894531e-02,  -4.47692871e-02],
                        [ -2.21252441e-02,  -2.20336914e-02],
                        [  9.76562500e-04,   1.67846680e-03],
                        [  2.53295898e-02,   2.59399414e-02],
                        [  5.89294434e-02,   5.88378906e-02],
                        [  1.09771729e-01,   1.09069824e-01],
                        [  1.70776367e-01,   1.70135498e-01],
                        [  2.18750000e-01,   2.18780518e-01],
                        [  2.32849121e-01,   2.33489990e-01],
                        [  2.08557129e-01,   2.09228516e-01],
                        [  1.50085449e-01,   1.50115967e-01],
                        [  5.89294434e-02,   5.82885742e-02],
                        [ -6.05163574e-02,  -6.11877441e-02],
                        [ -1.88568115e-01,  -1.88659668e-01],
                        [ -2.92266846e-01,  -2.91656494e-01],
                        [ -3.40515137e-01,  -3.39813232e-01],
                        [ -3.23181152e-01,  -3.23059082e-01],
                        [ -2.61749268e-01,  -2.62329102e-01],
                        [ -1.98059082e-01,  -1.98791504e-01],
                        [ -1.61834717e-01,  -1.61987305e-01],
                        [ -1.48956299e-01,  -1.48406982e-01],
                        [ -1.34887695e-01,  -1.34155273e-01],
                        [ -1.04248047e-01,  -1.04034424e-01],
                        [ -6.21337891e-02,  -6.26220703e-02],
                        [ -1.91040039e-02,  -1.98669434e-02],
                        [  2.48107910e-02,   2.45666504e-02],
                        [  7.59887695e-02,   7.64465332e-02],
                        [  1.31225586e-01,   1.31988525e-01],
                        [  1.75720215e-01,   1.76025391e-01],
                        [  1.96624756e-01,   1.96166992e-01],
                        [  1.93054199e-01,   1.92291260e-01],
                        [  1.73583984e-01,   1.73217773e-01],
                        [  1.47827148e-01,   1.48223877e-01],
                        [  1.20574951e-01,   1.21337891e-01],
                        [  9.21630859e-02,   9.25598145e-02],
                        [  6.49719238e-02,   6.46057129e-02],
                        [  4.67224121e-02,   4.59594727e-02],
                        [  4.28161621e-02,   4.23889160e-02],
                        [  4.85534668e-02,   4.88586426e-02],
                        [  5.42297363e-02,   5.49926758e-02],
                        [  5.63964844e-02,   5.68542480e-02],
                        [  5.79833984e-02,   5.77392578e-02],
                        [  6.06079102e-02,   5.98754883e-02],
                        [  6.28967285e-02,   6.23779297e-02],
                        [  6.44531250e-02,   6.46667480e-02],
                        [  6.61621094e-02,   6.68945312e-02],
                        [  6.77490234e-02,   6.82983398e-02],
                        [  6.85729980e-02,   6.83898926e-02],
                        [  6.85119629e-02,   6.77795410e-02],
                        [  6.63757324e-02,   6.57958984e-02],
                        [  5.98144531e-02,   5.99365234e-02],
                        [  4.84008789e-02,   4.91027832e-02],
                        [  3.48205566e-02,   3.54309082e-02],
                        [  2.28576660e-02,   2.27661133e-02],
                        [  1.45874023e-02,   1.38854980e-02],
                        [  8.91113281e-03,   8.27026367e-03],
                        [  2.50244141e-03,   2.53295898e-03],
                        [ -6.25610352e-03,  -5.58471680e-03],
                        [ -1.49230957e-02,  -1.42822266e-02],
                        [ -2.01416016e-02,  -2.01110840e-02],
                        [ -2.13317871e-02,  -2.19726562e-02],
                        [ -1.91955566e-02,  -1.98669434e-02],
                        [ -1.24511719e-02,  -1.25122070e-02],
                        [ -1.77001953e-03,  -1.12915039e-03],
                        [  6.22558594e-03,   6.92749023e-03],
                        [  6.10351562e-03,   6.22558594e-03],
                        [  2.44140625e-03,   1.86157227e-03],
                        [  2.34985352e-03,   1.64794922e-03],
                        [  4.11987305e-03,   3.96728516e-03],
                        [  2.16674805e-03,   2.71606445e-03],
                        [ -1.49536133e-03,  -7.62939453e-04],
                        [ -1.06811523e-03,  -8.85009766e-04],
                        [  3.23486328e-03,   2.71606445e-03],
                        [  7.69042969e-03,   6.95800781e-03],
                        [  1.15661621e-02,   1.13220215e-02],
                        [  1.47705078e-02,   1.52587891e-02],
                        [  1.38244629e-02,   1.45874023e-02],
                        [  5.31005859e-03,   5.58471680e-03],
                        [ -8.48388672e-03,  -8.94165039e-03],
                        [ -2.02331543e-02,  -2.09960938e-02],
                        [ -2.35900879e-02,  -2.39562988e-02],
                        [ -1.83105469e-02,  -1.78833008e-02],
                        [ -9.82666016e-03,  -9.06372070e-03],
                        [ -4.66918945e-03,  -4.27246094e-03],
                        [ -5.43212891e-03,  -5.79833984e-03],
                        [ -1.08947754e-02,  -1.16577148e-02],
                        [ -1.86157227e-02,  -1.90429688e-02],
                        [ -2.54516602e-02,  -2.51159668e-02],
                        [ -2.70690918e-02,  -2.63061523e-02],
                        [ -2.13317871e-02,  -2.08740234e-02],
                        [ -1.13220215e-02,  -1.15966797e-02],
                        [ -1.52587891e-03,  -2.25830078e-03],
                        [  7.65991211e-03,   7.17163086e-03],
                        [  1.71813965e-02,   1.74255371e-02],
                        [  2.30712891e-02,   2.38037109e-02],
                        [  1.69372559e-02,   1.74865723e-02],
                        [ -7.32421875e-03,  -7.50732422e-03],
                        [ -4.85534668e-02,  -4.92858887e-02],
                        [ -9.73510742e-02,  -9.79003906e-02],
                        [ -1.38122559e-01,  -1.38000488e-01],
                        [ -1.55700684e-01,  -1.54968262e-01],
                        [ -1.43981934e-01,  -1.43402100e-01],
                        [ -1.11450195e-01,  -1.11541748e-01],
                        [ -7.59887695e-02,  -7.66906738e-02],
                        [ -5.15441895e-02,  -5.21545410e-02],
                        [ -3.86657715e-02,  -3.86047363e-02],
                        [ -2.91442871e-02,  -2.84729004e-02],
                        [ -1.66931152e-02,  -1.60522461e-02],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  2.22473145e-02,   2.16064453e-02],
                        [  5.30395508e-02,   5.23681641e-02],
                        [  9.71984863e-02,   9.71374512e-02],
                        [  1.52618408e-01,   1.53228760e-01],
                        [  2.01812744e-01,   2.02514648e-01],
                        [  2.18200684e-01,   2.18292236e-01],
                        [  1.86767578e-01,   1.86157227e-01],
                        [  1.13372803e-01,   1.12670898e-01],
                        [  1.21459961e-02,   1.19934082e-02],
                        [ -1.05163574e-01,  -1.04583740e-01],
                        [ -2.21618652e-01,  -2.20886230e-01],
                        [ -3.08502197e-01,  -3.08288574e-01],
                        [ -3.38165283e-01,  -3.38714600e-01],
                        [ -3.07769775e-01,  -3.08502197e-01],
                        [ -2.46185303e-01,  -2.46429443e-01],
                        [ -1.91009521e-01,  -1.90521240e-01],
                        [ -1.56921387e-01,  -1.56158447e-01],
                        [ -1.31896973e-01,  -1.31622314e-01],
                        [ -1.02447510e-01,  -1.02905273e-01],
                        [ -6.94274902e-02,  -7.01904297e-02],
                        [ -3.76281738e-02,  -3.79333496e-02],
                        [ -2.80761719e-03,  -2.41088867e-03],
                        [  4.33044434e-02,   4.40673828e-02],
                        [  9.89990234e-02,   9.93652344e-02],
                        [  1.47918701e-01,   1.47521973e-01],
                        [  1.72698975e-01,   1.71936035e-01],
                        [  1.73065186e-01,   1.72637939e-01],
                        [  1.63757324e-01,   1.64093018e-01],
                        [  1.54449463e-01,   1.55212402e-01],
                        [  1.41662598e-01,   1.42120361e-01],
                        [  1.21063232e-01,   1.20758057e-01],
                        [  9.62524414e-02,   9.54895020e-02],
                        [  7.38220215e-02,   7.33337402e-02],
                        [  5.82580566e-02,   5.85021973e-02],
                        [  5.12695312e-02,   5.20019531e-02],
                        [  4.97131348e-02,   5.02319336e-02],
                        [  4.65698242e-02,   4.63562012e-02],
                        [  3.92150879e-02,   3.84826660e-02],
                        [  3.32031250e-02,   3.26538086e-02],
                        [  3.39660645e-02,   3.41186523e-02],
                        [  3.93676758e-02,   4.01000977e-02],
                        [  4.43420410e-02,   4.49523926e-02],
                        [  4.82482910e-02,   4.81262207e-02],
                        [  5.26428223e-02,   5.19409180e-02],
                        [  5.59387207e-02,   5.53283691e-02],
                        [  5.52978516e-02,   5.53588867e-02],
                        [  5.16967773e-02,   5.23681641e-02],
                        [  4.75769043e-02,   4.82177734e-02],
                        [  4.22363281e-02,   4.22058105e-02],
                        [  3.45153809e-02,   3.38745117e-02],
                        [  2.63977051e-02,   2.57263184e-02],
                        [  1.95922852e-02,   1.95617676e-02],
                        [  1.31530762e-02,   1.37939453e-02],
                        [  6.34765625e-03,   7.04956055e-03],
                        [ -5.49316406e-04,  -4.88281250e-04],
                        [ -8.39233398e-03,  -9.00268555e-03],
                        [ -1.61743164e-02,  -1.68762207e-02],
                        [ -1.90734863e-02,  -1.91955566e-02],
                        [ -1.47094727e-02,  -1.41296387e-02],
                        [ -7.59887695e-03,  -6.86645508e-03],
                        [ -2.68554688e-03,  -2.50244141e-03],
                        [ -7.93457031e-04,  -1.34277344e-03],
                        [ -2.19726562e-03,  -2.92968750e-03],
                        [ -7.04956055e-03,  -7.29370117e-03],
                        [ -1.19628906e-02,  -1.14440918e-02],
                        [ -1.22070312e-02,  -1.14746094e-02],
                        [ -7.44628906e-03,  -7.20214844e-03],
                        [ -9.76562500e-04,  -1.46484375e-03],
                        [  4.42504883e-03,   3.66210938e-03],
                        [  8.51440430e-03,   8.20922852e-03],
                        [  1.28784180e-02,   1.33056641e-02],
                        [  1.80358887e-02,   1.87988281e-02],
                        [  2.03247070e-02,   2.06909180e-02],
                        [  1.53198242e-02,   1.49230957e-02],
                        [  4.97436523e-03,   4.21142578e-03],
                        [ -2.80761719e-03,  -3.17382812e-03],
                        [ -3.96728516e-03,  -3.60107422e-03],
                        [ -4.18090820e-03,  -3.41796875e-03],
                        [ -1.16577148e-02,  -1.12304688e-02],
                        [ -2.65808105e-02,  -2.69165039e-02],
                        [ -4.08935547e-02,  -4.16564941e-02],
                        [ -4.78210449e-02,  -4.83093262e-02],
                        [ -4.79125977e-02,  -4.76379395e-02],
                        [ -4.50439453e-02,  -4.43115234e-02],
                        [ -4.08630371e-02,  -4.03747559e-02],
                        [ -3.43933105e-02,  -3.46069336e-02],
                        [ -2.52075195e-02,  -2.59704590e-02],
                        [ -1.41296387e-02,  -1.46789551e-02],
                        [ -9.15527344e-04,  -7.32421875e-04],
                        [  1.49536133e-02,   1.56555176e-02],
                        [  3.05480957e-02,   3.11279297e-02],
                        [  3.93676758e-02,   3.92456055e-02],
                        [  3.51257324e-02,   3.44238281e-02],
                        [  1.29394531e-02,   1.23291016e-02],
                        [ -3.00292969e-02,  -2.99377441e-02],
                        [ -8.73718262e-02,  -8.66699219e-02],
                        [ -1.38763428e-01,  -1.38122559e-01],
                        [ -1.61804199e-01,  -1.61834717e-01],
                        [ -1.49719238e-01,  -1.50390625e-01],
                        [ -1.14471436e-01,  -1.15142822e-01],
                        [ -7.48596191e-02,  -7.48901367e-02],
                        [ -4.58068848e-02,  -4.51660156e-02],
                        [ -3.32946777e-02,  -3.26232910e-02],
                        [ -3.20739746e-02,  -3.20129395e-02],
                        [ -2.88391113e-02,  -2.94494629e-02],
                        [ -1.21154785e-02,  -1.28173828e-02],
                        [  2.13012695e-02,   2.12097168e-02],
                        [  6.98547363e-02,   7.04345703e-02],
                        [  1.29638672e-01,   1.30371094e-01],
                        [  1.89270020e-01,   1.89422607e-01],
                        [  2.27600098e-01,   2.27050781e-01],
                        [  2.24975586e-01,   2.24243164e-01],
                        [  1.76086426e-01,   1.75872803e-01],
                        [  8.93859863e-02,   8.99047852e-02],
                        [ -2.36511230e-02,  -2.29187012e-02],
                        [ -1.51702881e-01,  -1.51458740e-01],
                        [ -2.72338867e-01,  -2.72827148e-01],
                        [ -3.48388672e-01,  -3.49151611e-01],
                        [ -3.53057861e-01,  -3.53332520e-01],
                        [ -3.00354004e-01,  -2.99896240e-01],
                        [ -2.36907959e-01,  -2.36145020e-01],
                        [ -1.98577881e-01,  -1.98242188e-01],
                        [ -1.82495117e-01,  -1.82891846e-01],
                        [ -1.62597656e-01,  -1.63360596e-01],
                        [ -1.22894287e-01,  -1.23291016e-01],
                        [ -6.86950684e-02,  -6.83288574e-02],
                        [ -1.07421875e-02,  -9.97924805e-03],
                        [  4.85229492e-02,   4.89501953e-02],
                        [  1.08276367e-01,   1.07940674e-01],
                        [  1.58203125e-01,   1.57470703e-01],
                        [  1.85211182e-01,   1.84753418e-01],
                        [  1.87774658e-01,   1.88079834e-01],
                        [  1.77215576e-01,   1.77947998e-01],
                        [  1.64398193e-01,   1.64886475e-01],
                        [  1.49566650e-01,   1.49322510e-01],
                        [  1.26739502e-01,   1.25976562e-01],
                        [  9.70458984e-02,   9.64965820e-02],
                        [  7.19604492e-02,   7.21740723e-02],
                        [  6.01501465e-02,   6.08825684e-02],
                        [  5.66711426e-02,   5.72509766e-02],
                        [  5.05981445e-02,   5.04760742e-02],
                        [  3.89709473e-02,   3.82690430e-02],
                        [  2.78320312e-02,   2.72216797e-02],
                        [  2.26745605e-02,   2.27661133e-02],
                        [  2.38037109e-02,   2.45056152e-02],
                        [  2.99072266e-02,   3.05175781e-02],
                        [  4.04968262e-02,   4.04663086e-02],
                        [  5.36193848e-02,   5.29479980e-02],
                        [  6.54907227e-02,   6.48498535e-02],
                        [  7.33642578e-02,   7.33642578e-02],
                        [  7.59582520e-02,   7.65991211e-02],
                        [  7.20825195e-02,   7.27844238e-02],
                        [  6.20422363e-02,   6.21032715e-02],
                        [  4.88586426e-02,   4.82177734e-02],
                        [  3.62854004e-02,   3.55834961e-02],
                        [  2.67333984e-02,   2.66113281e-02],
                        [  2.08740234e-02,   2.14538574e-02],
                        [  1.76696777e-02,   1.83715820e-02],
                        [  1.44348145e-02,   1.45874023e-02],
                        [  8.30078125e-03,   7.72094727e-03],
                        [ -1.43432617e-03,  -2.16674805e-03],
                        [ -1.22070312e-02,  -1.24206543e-02],
                        [ -2.08129883e-02,  -2.02941895e-02],
                        [ -2.57263184e-02,  -2.49633789e-02],
                        [ -2.52685547e-02,  -2.50244141e-02],
                        [ -1.69677734e-02,  -1.74560547e-02],
                        [ -2.99072266e-03,  -3.75366211e-03],
                        [  6.71386719e-03,   6.43920898e-03],
                        [  5.09643555e-03,   5.55419922e-03],
                        [ -1.25122070e-03,  -4.88281250e-04],
                        [ -7.62939453e-04,  -4.57763672e-04],
                        [  6.25610352e-03,   5.82885742e-03],
                        [  1.05590820e-02,   9.79614258e-03],
                        [  1.09558105e-02,   1.05895996e-02],
                        [  1.48010254e-02,   1.51672363e-02],
                        [  2.15454102e-02,   2.23083496e-02],
                        [  2.10876465e-02,   2.15148926e-02],
                        [  1.05590820e-02,   1.02233887e-02],
                        [ -9.15527344e-04,  -1.67846680e-03],
                        [ -6.37817383e-03,  -6.83593750e-03],
                        [ -9.06372070e-03,  -8.78906250e-03],
                        [ -1.46484375e-02,  -1.38854980e-02],
                        [ -2.28271484e-02,  -2.23388672e-02],
                        [ -2.90527344e-02,  -2.92968750e-02],
                        [ -3.04870605e-02,  -3.12500000e-02],
                        [ -2.85949707e-02,  -2.91442871e-02],
                        [ -2.61230469e-02,  -2.59399414e-02],
                        [ -2.41699219e-02,  -2.34375000e-02],
                        [ -2.34069824e-02,  -2.28576660e-02],
                        [ -2.44750977e-02,  -2.46276855e-02],
                        [ -2.55126953e-02,  -2.62145996e-02],
                        [ -2.31323242e-02,  -2.37121582e-02],
                        [ -1.69067383e-02,  -1.67846680e-02],
                        [ -8.23974609e-03,  -7.53784180e-03],
                        [  2.92968750e-03,   3.57055664e-03],
                        [  1.55944824e-02,   1.55334473e-02],
                        [  2.42309570e-02,   2.35595703e-02],
                        [  2.39562988e-02,   2.33154297e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [ -2.83813477e-03,  -2.16674805e-03],
                        [ -3.20739746e-02,  -3.14025879e-02],
                        [ -7.11669922e-02,  -7.11364746e-02],
                        [ -1.06292725e-01,  -1.06933594e-01],
                        [ -1.22802734e-01,  -1.23474121e-01],
                        [ -1.19903564e-01,  -1.19995117e-01],
                        [ -1.06353760e-01,  -1.05743408e-01],
                        [ -8.91113281e-02,  -8.84094238e-02],
                        [ -7.40051270e-02,  -7.38830566e-02],
                        [ -6.57348633e-02,  -6.63146973e-02],
                        [ -5.85632324e-02,  -5.92651367e-02],
                        [ -3.72619629e-02,  -3.74145508e-02],
                        [  5.46264648e-03,   5.98144531e-03],
                        [  6.16455078e-02,   6.23779297e-02],
                        [  1.21032715e-01,   1.21246338e-01],
                        [  1.78924561e-01,   1.78405762e-01],
                        [  2.25769043e-01,   2.25036621e-01],
                        [  2.40936279e-01,   2.40661621e-01],
                        [  2.07214355e-01,   2.07672119e-01],
                        [  1.26739502e-01,   1.27502441e-01],
                        [  1.37939453e-02,   1.40991211e-02],
                        [ -1.18377686e-01,  -1.18804932e-01],
                        [ -2.49969482e-01,  -2.50732422e-01],
                        [ -3.44024658e-01,  -3.44390869e-01],
                        [ -3.67340088e-01,  -3.66943359e-01],
                        [ -3.26019287e-01,  -3.25256348e-01],
                        [ -2.62969971e-01,  -2.62573242e-01],
                        [ -2.14843750e-01,  -2.15209961e-01],
                        [ -1.85211182e-01,  -1.85974121e-01],
                        [ -1.58874512e-01,  -1.59301758e-01],
                        [ -1.24572754e-01,  -1.24267578e-01],
                        [ -7.77893066e-02,  -7.70263672e-02],
                        [ -1.73339844e-02,  -1.68457031e-02],
                        [  5.01403809e-02,   4.98962402e-02],
                        [  1.09466553e-01,   1.08703613e-01],
                        [  1.48559570e-01,   1.48040771e-01],
                        [  1.67999268e-01,   1.68212891e-01],
                        [  1.75933838e-01,   1.76666260e-01],
                        [  1.77886963e-01,   1.78405762e-01],
                        [  1.73309326e-01,   1.73126221e-01],
                        [  1.58325195e-01,   1.57623291e-01],
                        [  1.31378174e-01,   1.30798340e-01],
                        [  9.96093750e-02,   9.97314453e-02],
                        [  7.72094727e-02,   7.79113770e-02],
                        [  7.12585449e-02,   7.18688965e-02],
                        [  7.28149414e-02,   7.27233887e-02],
                        [  6.71691895e-02,   6.64978027e-02],
                        [  5.14831543e-02,   5.08422852e-02],
                        [  3.43322754e-02,   3.43627930e-02],
                        [  2.26440430e-02,   2.33154297e-02],
                        [  1.76086426e-02,   1.82495117e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  3.11889648e-02,   3.05480957e-02],
                        [  4.58984375e-02,   4.52270508e-02],
                        [  5.87158203e-02,   5.86547852e-02],
                        [  6.85424805e-02,   6.91223145e-02],
                        [  7.47985840e-02,   7.55004883e-02],
                        [  7.23876953e-02,   7.24792480e-02],
                        [  5.94177246e-02,   5.88378906e-02],
                        [  4.55322266e-02,   4.48303223e-02],
                        [  4.06188965e-02,   4.04663086e-02],
                        [  4.00085449e-02,   4.05578613e-02],
                        [  3.21655273e-02,   3.28979492e-02],
                        [  1.67541504e-02,   1.69677734e-02],
                        [  2.44140625e-03,   1.92260742e-03],
                        [ -6.59179688e-03,  -7.32421875e-03],
                        [ -1.18713379e-02,  -1.21154785e-02],
                        [ -1.43127441e-02,  -1.38244629e-02],
                        [ -1.43127441e-02,  -1.35803223e-02],
                        [ -1.36108398e-02,  -1.33361816e-02],
                        [ -1.27563477e-02,  -1.31835938e-02],
                        [ -9.61303711e-03,  -1.03454590e-02],
                        [ -2.25830078e-03,  -2.59399414e-03],
                        [  7.32421875e-03,   7.72094727e-03],
                        [  1.33972168e-02,   1.41601562e-02],
                        [  1.16882324e-02,   1.20544434e-02],
                        [  4.30297852e-03,   3.96728516e-03],
                        [ -1.73950195e-03,  -2.50244141e-03],
                        [ -2.22778320e-03,  -2.65502930e-03],
                        [  1.15966797e-03,   1.46484375e-03],
                        [  5.00488281e-03,   5.73730469e-03],
                        [  7.50732422e-03,   7.96508789e-03],
                        [  7.08007812e-03,   6.80541992e-03],
                        [  2.83813477e-03,   2.10571289e-03],
                        [ -2.16674805e-03,  -2.65502930e-03],
                        [ -3.60107422e-03,  -3.38745117e-03],
                        [ -3.17382812e-03,  -2.44140625e-03],
                        [ -6.46972656e-03,  -5.95092773e-03],
                        [ -1.30920410e-02,  -1.32446289e-02],
                        [ -1.72119141e-02,  -1.79138184e-02],
                        [ -1.88903809e-02,  -1.94702148e-02],
                        [ -2.39562988e-02,  -2.38342285e-02],
                        [ -3.20434570e-02,  -3.13415527e-02],
                        [ -3.60717773e-02,  -3.54614258e-02],
                        [ -3.44848633e-02,  -3.45764160e-02],
                        [ -3.31115723e-02,  -3.37829590e-02],
                        [ -3.41796875e-02,  -3.47900391e-02],
                        [ -3.35388184e-02,  -3.35083008e-02],
                        [ -2.88391113e-02,  -2.81982422e-02],
                        [ -2.22778320e-02,  -2.16674805e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -8.30078125e-03,  -8.91113281e-03],
                        [  2.13623047e-03,   1.49536133e-03],
                        [  1.45568848e-02,   1.45263672e-02],
                        [  2.43225098e-02,   2.49328613e-02],
                        [  2.45971680e-02,   2.52990723e-02],
                        [  9.18579102e-03,   9.27734375e-03],
                        [ -2.46582031e-02,  -2.52380371e-02],
                        [ -7.22045898e-02,  -7.28759766e-02],
                        [ -1.17340088e-01,  -1.17492676e-01],
                        [ -1.39160156e-01,  -1.38610840e-01],
                        [ -1.29516602e-01,  -1.28814697e-01],
                        [ -1.02996826e-01,  -1.02813721e-01],
                        [ -8.31909180e-02,  -8.37097168e-02],
                        [ -7.82165527e-02,  -7.89489746e-02],
                        [ -7.31811523e-02,  -7.33947754e-02],
                        [ -4.94079590e-02,  -4.89196777e-02],
                        [ -6.34765625e-03,  -5.61523438e-03],
                        [  4.37927246e-02,   4.40673828e-02],
                        [  9.57031250e-02,   9.52758789e-02],
                        [  1.51428223e-01,   1.50726318e-01],
                        [  2.03674316e-01,   2.03369141e-01],
                        [  2.32971191e-01,   2.33367920e-01],
                        [  2.21466064e-01,   2.22198486e-01],
                        [  1.62475586e-01,   1.62841797e-01],
                        [  5.97839355e-02,   5.94177246e-02],
                        [ -7.25708008e-02,  -7.33032227e-02],
                        [ -2.08984375e-01,  -2.09381104e-01],
                        [ -3.15399170e-01,  -3.15093994e-01],
                        [ -3.62182617e-01,  -3.61480713e-01],
                        [ -3.42285156e-01,  -3.41857910e-01],
                        [ -2.79876709e-01,  -2.80181885e-01],
                        [ -2.15637207e-01,  -2.16339111e-01],
                        [ -1.77124023e-01,  -1.77612305e-01],
                        [ -1.60949707e-01,  -1.60705566e-01],
                        [ -1.42303467e-01,  -1.41601562e-01],
                        [ -1.02783203e-01,  -1.02294922e-01],
                        [ -4.53796387e-02,  -4.55932617e-02],
                        [  1.69067383e-02,   1.62048340e-02],
                        [  7.58056641e-02,   7.52868652e-02],
                        [  1.25457764e-01,   1.25610352e-01],
                        [  1.58081055e-01,   1.58752441e-01],
                        [  1.73034668e-01,   1.73583984e-01],
                        [  1.80297852e-01,   1.80206299e-01],
                        [  1.85211182e-01,   1.84539795e-01],
                        [  1.79290771e-01,   1.78680420e-01],
                        [  1.54785156e-01,   1.54846191e-01],
                        [  1.19781494e-01,   1.20452881e-01],
                        [  8.98742676e-02,   9.04846191e-02],
                        [  7.07397461e-02,   7.07092285e-02],
                        [  5.64575195e-02,   5.58471680e-02],
                        [  4.11682129e-02,   4.05273438e-02],
                        [  2.57873535e-02,   2.57568359e-02],
                        [  1.63574219e-02,   1.69677734e-02],
                        [  1.76086426e-02,   1.82800293e-02],
                        [  2.77404785e-02,   2.78015137e-02],
                        [  4.03747559e-02,   3.97949219e-02],
                        [  5.10559082e-02,   5.03845215e-02],
                        [  5.87463379e-02,   5.86242676e-02],
                        [  6.39648438e-02,   6.45141602e-02],
                        [  6.79626465e-02,   6.86340332e-02],
                        [  7.04956055e-02,   7.06481934e-02],
                        [  6.91223145e-02,   6.86035156e-02],
                        [  6.29577637e-02,   6.22558594e-02],
                        [  5.47790527e-02,   5.45654297e-02],
                        [  4.75463867e-02,   4.80041504e-02],
                        [  4.10461426e-02,   4.17480469e-02],
                        [  3.25317383e-02,   3.28063965e-02],
                        [  1.97753906e-02,   1.93176270e-02],
                        [  4.08935547e-03,   3.38745117e-03],
                        [ -8.69750977e-03,  -9.00268555e-03],
                        [ -1.36413574e-02,  -1.32446289e-02],
                        [ -1.25732422e-02,  -1.18408203e-02],
                        [ -1.11999512e-02,  -1.08642578e-02],
                        [ -1.19018555e-02,  -1.22375488e-02],
                        [ -1.25122070e-02,  -1.32141113e-02],
                        [ -1.07727051e-02,  -1.11694336e-02],
                        [ -6.83593750e-03,  -6.53076172e-03],
                        [ -2.19726562e-03,  -1.49536133e-03],
                        [  2.25830078e-03,   2.65502930e-03],
                        [  6.65283203e-03,   6.34765625e-03],
                        [  1.00708008e-02,   9.36889648e-03],
                        [  1.02233887e-02,   9.79614258e-03],
                        [  7.29370117e-03,   7.53784180e-03],
                        [  5.92041016e-03,   6.62231445e-03],
                        [  9.15527344e-03,   9.61303711e-03],
                        [  1.36108398e-02,   1.33972168e-02],
                        [  1.46789551e-02,   1.40075684e-02],
                        [  1.24206543e-02,   1.19018555e-02],
                        [  9.27734375e-03,   9.42993164e-03],
                        [  5.79833984e-03,   6.46972656e-03],
                        [  1.31225586e-03,   1.83105469e-03],
                        [ -4.60815430e-03,  -4.73022461e-03],
                        [ -1.22375488e-02,  -1.28784180e-02],
                        [ -2.05383301e-02,  -2.10876465e-02],
                        [ -2.66723633e-02,  -2.66113281e-02],
                        [ -3.02429199e-02,  -2.96325684e-02],
                        [ -3.37219238e-02,  -3.31420898e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.10974121e-02,  -3.16772461e-02],
                        [ -2.00195312e-02,  -2.05993652e-02],
                        [ -1.19934082e-02,  -1.20239258e-02],
                        [ -1.55334473e-02,  -1.49536133e-02],
                        [ -2.70080566e-02,  -2.63977051e-02],
                        [ -3.41491699e-02,  -3.40881348e-02],
                        [ -3.02429199e-02,  -3.07922363e-02],
                        [ -1.83105469e-02,  -1.89514160e-02],
                        [ -1.92260742e-03,  -2.01416016e-03],
                        [  1.79138184e-02,   1.84326172e-02],
                        [  3.43627930e-02,   3.50036621e-02],
                        [  3.46984863e-02,   3.48510742e-02],
                        [  1.28784180e-02,   1.23901367e-02],
                        [ -2.56652832e-02,  -2.63366699e-02],
                        [ -7.20214844e-02,  -7.22045898e-02],
                        [ -1.15692139e-01,  -1.15234375e-01],
                        [ -1.40258789e-01,  -1.39587402e-01],
                        [ -1.31866455e-01,  -1.31652832e-01],
                        [ -9.69543457e-02,  -9.73815918e-02],
                        [ -6.12487793e-02,  -6.19201660e-02],
                        [ -4.49218750e-02,  -4.51965332e-02],
                        [ -4.41894531e-02,  -4.37927246e-02],
                        [ -3.97033691e-02,  -3.90319824e-02],
                        [ -1.74560547e-02,  -1.71508789e-02],
                        [  2.29492188e-02,   2.25830078e-02],
                        [  7.47985840e-02,   7.41271973e-02],
                        [  1.30462646e-01,   1.30126953e-01],
                        [  1.80236816e-01,   1.80572510e-01],
                        [  2.11059570e-01,   2.11730957e-01],
                        [  2.10144043e-01,   2.10510254e-01],
                        [  1.69372559e-01,   1.69097900e-01],
                        [  8.64257812e-02,   8.57543945e-02],
                        [ -3.28369141e-02,  -3.32336426e-02],
                        [ -1.68640137e-01,  -1.68395996e-01],
                        [ -2.86529541e-01,  -2.85858154e-01],
                        [ -3.50738525e-01,  -3.50311279e-01],
                        [ -3.47412109e-01,  -3.47595215e-01],
                        [ -2.95806885e-01,  -2.96478271e-01],
                        [ -2.34375000e-01,  -2.34863281e-01],
                        [ -1.91711426e-01,  -1.91558838e-01],
                        [ -1.68945312e-01,  -1.68334961e-01],
                        [ -1.47308350e-01,  -1.46820068e-01],
                        [ -1.08551025e-01,  -1.08673096e-01],
                        [ -4.87976074e-02,  -4.94384766e-02],
                        [  2.09045410e-02,   2.03857422e-02],
                        [  8.44726562e-02,   8.45642090e-02],
                        [  1.30493164e-01,   1.31072998e-01],
                        [  1.54418945e-01,   1.54968262e-01],
                        [  1.59210205e-01,   1.59179688e-01],
                        [  1.56372070e-01,   1.55792236e-01],
                        [  1.56921387e-01,   1.56372070e-01],
                        [  1.57470703e-01,   1.57470703e-01],
                        [  1.44287109e-01,   1.44836426e-01],
                        [  1.15386963e-01,   1.15966797e-01],
                        [  8.70361328e-02,   8.70666504e-02],
                        [  7.15942383e-02,   7.10754395e-02],
                        [  6.22863770e-02,   6.17065430e-02],
                        [  4.80346680e-02,   4.79431152e-02],
                        [  3.15246582e-02,   3.20129395e-02],
                        [  2.29187012e-02,   2.35290527e-02],
                        [  2.33459473e-02,   2.34680176e-02],
                        [  2.53601074e-02,   2.49023438e-02],
                        [  2.68249512e-02,   2.62145996e-02],
                        [  3.33862305e-02,   3.32336426e-02],
                        [  4.69055176e-02,   4.73327637e-02],
                        [  6.11572266e-02,   6.17980957e-02],
                        [  7.14111328e-02,   7.16247559e-02],
                        [  7.83386230e-02,   7.79418945e-02],
                        [  8.21228027e-02,   8.15124512e-02],
                        [  8.13598633e-02,   8.11157227e-02],
                        [  7.69042969e-02,   7.72705078e-02],
                        [  6.97631836e-02,   7.03735352e-02],
                        [  5.78918457e-02,   5.81665039e-02],
                        [  4.08020020e-02,   4.04357910e-02],
                        [  2.25219727e-02,   2.19116211e-02],
                        [  7.99560547e-03,   7.69042969e-03],
                        [ -1.19018555e-03,  -8.85009766e-04],
                        [ -7.50732422e-03,  -6.86645508e-03],
                        [ -1.59606934e-02,  -1.56250000e-02],
                        [ -2.93273926e-02,  -2.96020508e-02],
                        [ -4.29687500e-02,  -4.35791016e-02],
                        [ -4.61120605e-02,  -4.65087891e-02],
                        [ -3.32336426e-02,  -3.30200195e-02],
                        [ -1.21765137e-02,  -1.15661621e-02],
                        [  3.35693359e-03,   3.75366211e-03],
                        [  7.29370117e-03,   7.11059570e-03],
                        [  4.51660156e-03,   3.90625000e-03],
                        [  2.80761719e-03,   2.38037109e-03],
                        [  5.79833984e-03,   5.98144531e-03],
                        [  1.25732422e-02,   1.31835938e-02],
                        [  1.95007324e-02,   1.99279785e-02],
                        [  2.12707520e-02,   2.11486816e-02],
                        [  1.61132812e-02,   1.55334473e-02],
                        [  9.15527344e-03,   8.66699219e-03],
                        [  5.82885742e-03,   5.92041016e-03],
                        [  4.91333008e-03,   5.46264648e-03],
                        [  2.44140625e-03,   2.92968750e-03],
                        [ -2.53295898e-03,  -2.59399414e-03],
                        [ -8.85009766e-03,  -9.39941406e-03],
                        [ -1.58996582e-02,  -1.64184570e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.85034180e-02,  -2.79846191e-02],
                        [ -3.08532715e-02,  -3.03039551e-02],
                        [ -2.92663574e-02,  -2.92358398e-02],
                        [ -2.49328613e-02,  -2.54211426e-02],
                        [ -2.09350586e-02,  -2.14538574e-02],
                        [ -1.90734863e-02,  -1.91345215e-02],
                        [ -1.82800293e-02,  -1.77917480e-02],
                        [ -1.79138184e-02,  -1.73645020e-02],
                        [ -1.98364258e-02,  -1.97143555e-02],
                        [ -2.32543945e-02,  -2.36816406e-02],
                        [ -2.14233398e-02,  -2.19726562e-02],
                        [ -9.18579102e-03,  -9.30786133e-03],
                        [  8.78906250e-03,   9.21630859e-03],
                        [  2.28881836e-02,   2.34375000e-02],
                        [  2.79235840e-02,   2.81066895e-02],
                        [  2.31933594e-02,   2.28271484e-02],
                        [  6.77490234e-03,   6.22558594e-03],
                        [ -2.47497559e-02,  -2.49633789e-02],
                        [ -6.89392090e-02,  -6.85729980e-02],
                        [ -1.13128662e-01,  -1.12548828e-01],
                        [ -1.40991211e-01,  -1.40747070e-01],
                        [ -1.41143799e-01,  -1.41479492e-01],
                        [ -1.13494873e-01,  -1.14074707e-01],
                        [ -7.31811523e-02,  -7.34558105e-02],
                        [ -4.10766602e-02,  -4.08020020e-02],
                        [ -2.46276855e-02,  -2.40783691e-02],
                        [ -1.32446289e-02,  -1.29394531e-02],
                        [  6.86645508e-03,   6.59179688e-03],
                        [  3.90930176e-02,   3.85131836e-02],
                        [  7.86132812e-02,   7.83081055e-02],
                        [  1.21459961e-01,   1.21704102e-01],
                        [  1.64062500e-01,   1.64611816e-01],
                        [  1.94641113e-01,   1.95007324e-01],
                        [  1.93542480e-01,   1.93359375e-01],
                        [  1.47186279e-01,   1.46636963e-01],
                        [  5.83190918e-02,   5.79528809e-02],
                        [ -5.91125488e-02,  -5.89599609e-02],
                        [ -1.85974121e-01,  -1.85424805e-01],
                        [ -2.94158936e-01,  -2.93762207e-01],
                        [ -3.49700928e-01,  -3.49822998e-01],
                        [ -3.35784912e-01,  -3.36303711e-01],
                        [ -2.74475098e-01,  -2.74902344e-01],
                        [ -2.13897705e-01,  -2.13806152e-01],
                        [ -1.85272217e-01,  -1.84753418e-01],
                        [ -1.77368164e-01,  -1.76910400e-01],
                        [ -1.56799316e-01,  -1.56860352e-01],
                        [ -1.04888916e-01,  -1.05407715e-01],
                        [ -2.96630859e-02,  -3.00903320e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  1.12945557e-01,   1.13433838e-01],
                        [  1.52130127e-01,   1.52618408e-01],
                        [  1.65588379e-01,   1.65618896e-01],
                        [  1.64733887e-01,   1.64276123e-01],
                        [  1.63269043e-01,   1.62780762e-01],
                        [  1.63391113e-01,   1.63330078e-01],
                        [  1.55914307e-01,   1.56341553e-01],
                        [  1.33575439e-01,   1.34094238e-01],
                        [  1.01959229e-01,   1.02050781e-01],
                        [  7.40051270e-02,   7.35778809e-02],
                        [  5.58166504e-02,   5.53283691e-02],
                        [  4.36401367e-02,   4.35485840e-02],
                        [  3.30810547e-02,   3.34472656e-02],
                        [  2.45361328e-02,   2.50549316e-02],
                        [  2.02331543e-02,   2.03857422e-02],
                        [  2.13623047e-02,   2.09960938e-02],
                        [  2.81677246e-02,   2.76489258e-02],
                        [  3.93676758e-02,   3.91845703e-02],
                        [  5.17578125e-02,   5.20629883e-02],
                        [  6.23779297e-02,   6.28967285e-02],
                        [  6.99768066e-02,   7.01904297e-02],
                        [  7.37915039e-02,   7.34863281e-02],
                        [  7.34252930e-02,   7.29064941e-02],
                        [  6.93359375e-02,   6.91223145e-02],
                        [  6.28051758e-02,   6.30493164e-02],
                        [  5.46264648e-02,   5.51147461e-02],
                        [  4.44335938e-02,   4.46777344e-02],
                        [  3.20434570e-02,   3.17993164e-02],
                        [  2.02331543e-02,   1.97448730e-02],
                        [  1.27258301e-02,   1.24511719e-02],
                        [  8.23974609e-03,   8.45336914e-03],
                        [  1.37329102e-03,   1.86157227e-03],
                        [ -7.96508789e-03,  -7.65991211e-03],
                        [ -1.38854980e-02,  -1.40686035e-02],
                        [ -1.50146484e-02,  -1.55029297e-02],
                        [ -1.43127441e-02,  -1.46179199e-02],
                        [ -1.12609863e-02,  -1.11083984e-02],
                        [ -5.49316406e-03,  -5.03540039e-03],
                        [ -1.09863281e-03,  -7.32421875e-04],
                        [  3.05175781e-05,  -9.15527344e-05],
                        [  4.57763672e-04,   0.00000000e+00],
                        [  8.54492188e-04,   5.18798828e-04],
                        [  6.10351562e-05,   1.52587891e-04],
                        [  4.88281250e-04,   9.46044922e-04],
                        [  7.26318359e-03,   7.62939453e-03],
                        [  1.99584961e-02,   1.98974609e-02],
                        [  3.07922363e-02,   3.03649902e-02],
                        [  3.28063965e-02,   3.24096680e-02],
                        [  2.66418457e-02,   2.66723633e-02],
                        [  1.66320801e-02,   1.70593262e-02],
                        [  4.54711914e-03,   4.94384766e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.98974609e-02,  -2.02941895e-02],
                        [ -2.30102539e-02,  -2.34069824e-02],
                        [ -2.24304199e-02,  -2.24609375e-02],
                        [ -2.60925293e-02,  -2.56958008e-02],
                        [ -3.27148438e-02,  -3.22875977e-02],
                        [ -3.43017578e-02,  -3.42407227e-02],
                        [ -3.05480957e-02,  -3.09143066e-02],
                        [ -2.76184082e-02,  -2.80456543e-02],
                        [ -2.53906250e-02,  -2.54821777e-02],
                        [ -2.07519531e-02,  -2.04162598e-02],
                        [ -1.73950195e-02,  -1.69677734e-02],
                        [ -1.98974609e-02,  -1.97753906e-02],
                        [ -2.47192383e-02,  -2.50244141e-02],
                        [ -2.41699219e-02,  -2.45971680e-02],
                        [ -1.53503418e-02,  -1.55029297e-02],
                        [ -2.74658203e-03,  -2.44140625e-03],
                        [  8.63647461e-03,   9.06372070e-03],
                        [  1.98669434e-02,   2.00500488e-02],
                        [  3.24401855e-02,   3.21960449e-02],
                        [  3.87573242e-02,   3.83300781e-02],
                        [  2.74963379e-02,   2.73132324e-02],
                        [ -3.90625000e-03,  -3.66210938e-03],
                        [ -4.84008789e-02,  -4.79736328e-02],
                        [ -9.60693359e-02,  -9.58557129e-02],
                        [ -1.33880615e-01,  -1.34094238e-01],
                        [ -1.46942139e-01,  -1.47369385e-01],
                        [ -1.30981445e-01,  -1.31225586e-01],
                        [ -9.79003906e-02,  -9.77172852e-02],
                        [ -6.31408691e-02,  -6.27136230e-02],
                        [ -3.49426270e-02,  -3.46984863e-02],
                        [ -1.36108398e-02,  -1.37634277e-02],
                        [  8.33129883e-03,   7.90405273e-03],
                        [  4.15344238e-02,   4.12597656e-02],
                        [  8.90808105e-02,   8.92333984e-02],
                        [  1.41784668e-01,   1.42211914e-01],
                        [  1.85272217e-01,   1.85546875e-01],
                        [  2.06268311e-01,   2.06176758e-01],
                        [  1.91772461e-01,   1.91375732e-01],
                        [  1.30615234e-01,   1.30310059e-01],
                        [  2.23999023e-02,   2.24914551e-02],
                        [ -1.15875244e-01,  -1.15509033e-01],
                        [ -2.52716064e-01,  -2.52410889e-01],
                        [ -3.50189209e-01,  -3.50250244e-01],
                        [ -3.78753662e-01,  -3.79150391e-01],
                        [ -3.38073730e-01,  -3.38409424e-01],
                        [ -2.64434814e-01,  -2.64404297e-01],
                        [ -2.05352783e-01,  -2.04986572e-01],
                        [ -1.79809570e-01,  -1.79443359e-01],
                        [ -1.66625977e-01,  -1.66625977e-01],
                        [ -1.32263184e-01,  -1.32598877e-01],
                        [ -6.47888184e-02,  -6.51550293e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  9.72900391e-02,   9.76257324e-02],
                        [  1.48254395e-01,   1.48620605e-01],
                        [  1.68090820e-01,   1.68151855e-01],
                        [  1.67938232e-01,   1.67633057e-01],
                        [  1.64154053e-01,   1.63787842e-01],
                        [  1.61590576e-01,   1.61529541e-01],
                        [  1.54571533e-01,   1.54846191e-01],
                        [  1.39251709e-01,   1.39617920e-01],
                        [  1.17309570e-01,   1.17401123e-01],
                        [  9.10644531e-02,   9.08203125e-02],
                        [  6.16760254e-02,   6.13098145e-02],
                        [  3.21960449e-02,   3.20739746e-02],
                        [  9.27734375e-03,   9.52148438e-03],
                        [ -1.49536133e-03,  -1.12915039e-03],
                        [ -1.22070312e-04,   0.00000000e+00],
                        [  1.01318359e-02,   9.91821289e-03],
                        [  2.74963379e-02,   2.71301270e-02],
                        [  5.04150391e-02,   5.02624512e-02],
                        [  7.31201172e-02,   7.33337402e-02],
                        [  8.80126953e-02,   8.83789062e-02],
                        [  9.26818848e-02,   9.28344727e-02],
                        [  8.99658203e-02,   8.97827148e-02],
                        [  8.30383301e-02,   8.26721191e-02],
                        [  7.25097656e-02,   7.22961426e-02],
                        [  5.79223633e-02,   5.80749512e-02],
                        [  4.11987305e-02,   4.15649414e-02],
                        [  2.72827148e-02,   2.74658203e-02],
                        [  1.94091797e-02,   1.92565918e-02],
                        [  1.54418945e-02,   1.51062012e-02],
                        [  1.07727051e-02,   1.05590820e-02],
                        [  4.45556641e-03,   4.54711914e-03],
                        [ -5.49316406e-04,  -2.13623047e-04],
                        [ -3.44848633e-03,  -3.20434570e-03],
                        [ -7.44628906e-03,  -7.53784180e-03],
                        [ -1.35498047e-02,  -1.38549805e-02],
                        [ -1.82800293e-02,  -1.85241699e-02],
                        [ -1.87988281e-02,  -1.87377930e-02],
                        [ -1.55029297e-02,  -1.51672363e-02],
                        [ -9.61303711e-03,  -9.36889648e-03],
                        [ -1.86157227e-03,  -1.92260742e-03],
                        [  7.01904297e-03,   6.68334961e-03],
                        [  1.58691406e-02,   1.56250000e-02],
                        [  2.24304199e-02,   2.24609375e-02],
                        [  2.51770020e-02,   2.54516602e-02],
                        [  2.71301270e-02,   2.74047852e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  3.07312012e-02,   3.04565430e-02],
                        [  2.26440430e-02,   2.23693848e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [ -4.57763672e-03,  -4.30297852e-03],
                        [ -1.73645020e-02,  -1.70898438e-02],
                        [ -2.67639160e-02,  -2.67333984e-02],
                        [ -2.99682617e-02,  -3.02124023e-02],
                        [ -2.78625488e-02,  -2.81677246e-02],
                        [ -2.40173340e-02,  -2.40783691e-02],
                        [ -2.04467773e-02,  -2.02331543e-02],
                        [ -1.80053711e-02,  -1.77001953e-02],
                        [ -1.74255371e-02,  -1.73645020e-02],
                        [ -1.59301758e-02,  -1.61743164e-02],
                        [ -9.64355469e-03,  -9.94873047e-03],
                        [ -1.98364258e-03,  -2.07519531e-03],
                        [ -9.15527344e-04,  -7.32421875e-04],
                        [ -7.41577148e-03,  -7.11059570e-03],
                        [ -1.57470703e-02,  -1.56555176e-02],
                        [ -2.42309570e-02,  -2.44140625e-02],
                        [ -3.51562500e-02,  -3.54309082e-02],
                        [ -4.51354980e-02,  -4.52575684e-02],
                        [ -4.59594727e-02,  -4.58068848e-02],
                        [ -3.55224609e-02,  -3.52172852e-02],
                        [ -1.81579590e-02,  -1.80358887e-02],
                        [  2.71606445e-03,   2.56347656e-03],
                        [  2.43835449e-02,   2.41088867e-02],
                        [  3.92150879e-02,   3.90930176e-02],
                        [  3.62854004e-02,   3.64074707e-02],
                        [  9.58251953e-03,   9.85717773e-03],
                        [ -3.53698730e-02,  -3.51867676e-02],
                        [ -8.31298828e-02,  -8.32519531e-02],
                        [ -1.16394043e-01,  -1.16668701e-01],
                        [ -1.24389648e-01,  -1.24572754e-01],
                        [ -1.07391357e-01,  -1.07299805e-01],
                        [ -7.56225586e-02,  -7.53479004e-02],
                        [ -4.28771973e-02,  -4.26940918e-02],
                        [ -1.68457031e-02,  -1.69372559e-02],
                        [  5.43212891e-03,   5.15747070e-03],
                        [  3.20739746e-02,   3.18908691e-02],
                        [  6.74743652e-02,   6.75354004e-02],
                        [  1.08093262e-01,   1.08337402e-01],
                        [  1.46453857e-01,   1.46667480e-01],
                        [  1.74987793e-01,   1.74957275e-01],
                        [  1.80877686e-01,   1.80633545e-01],
                        [  1.46484375e-01,   1.46270752e-01],
                        [  6.50939941e-02,   6.51245117e-02],
                        [ -5.13916016e-02,  -5.11779785e-02],
                        [ -1.80664062e-01,  -1.80450439e-01],
                        [ -2.94464111e-01,  -2.94494629e-01],
                        [ -3.61389160e-01,  -3.61602783e-01],
                        [ -3.63006592e-01,  -3.63220215e-01],
                        [ -3.11340332e-01,  -3.11340332e-01],
                        [ -2.42828369e-01,  -2.42645264e-01],
                        [ -1.89117432e-01,  -1.88873291e-01],
                        [ -1.53991699e-01,  -1.53961182e-01],
                        [ -1.19659424e-01,  -1.19842529e-01],
                        [ -6.99462891e-02,  -7.01599121e-02],
                        [ -6.10351562e-03,  -6.16455078e-03],
                        [  5.67626953e-02,   5.69458008e-02],
                        [  1.04309082e-01,   1.04522705e-01],
                        [  1.31225586e-01,   1.31286621e-01],
                        [  1.40411377e-01,   1.40228271e-01],
                        [  1.40380859e-01,   1.40167236e-01],
                        [  1.41052246e-01,   1.40991211e-01],
                        [  1.44104004e-01,   1.44256592e-01],
                        [  1.40991211e-01,   1.41204834e-01],
                        [  1.26861572e-01,   1.26953125e-01],
                        [  1.10198975e-01,   1.10076904e-01],
                        [  9.99145508e-02,   9.96704102e-02],
                        [  9.08813477e-02,   9.07897949e-02],
                        [  7.22351074e-02,   7.23571777e-02],
                        [  4.27551270e-02,   4.29687500e-02],
                        [  1.24816895e-02,   1.25732422e-02],
                        [ -6.92749023e-03,  -7.04956055e-03],
                        [ -9.76562500e-03,  -9.97924805e-03],
                        [  2.34985352e-03,   2.25830078e-03],
                        [  2.31933594e-02,   2.32849121e-02],
                        [  4.60815430e-02,   4.62951660e-02],
                        [  6.64062500e-02,   6.65283203e-02],
                        [  8.17260742e-02,   8.16345215e-02],
                        [  9.10644531e-02,   9.08508301e-02],
                        [  9.32617188e-02,   9.31396484e-02],
                        [  8.69140625e-02,   8.69750977e-02],
                        [  7.34252930e-02,   7.36389160e-02],
                        [  5.74340820e-02,   5.75561523e-02],
                        [  4.14733887e-02,   4.14123535e-02],
                        [  2.48718262e-02,   2.46887207e-02],
                        [  8.39233398e-03,   8.23974609e-03],
                        [ -3.08227539e-03,  -3.02124023e-03],
                        [ -5.40161133e-03,  -5.21850586e-03],
                        [ -2.74658203e-03,  -2.62451172e-03],
                        [ -3.05175781e-03,  -3.08227539e-03],
                        [ -6.62231445e-03,  -6.80541992e-03],
                        [ -8.81958008e-03,  -8.97216797e-03],
                        [ -8.94165039e-03,  -8.91113281e-03],
                        [ -8.08715820e-03,  -7.90405273e-03],
                        [ -3.96728516e-03,  -3.81469727e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  1.51672363e-02,   1.50146484e-02],
                        [  2.14233398e-02,   2.12707520e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.17895508e-02,   2.19421387e-02],
                        [  2.05993652e-02,   2.07519531e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  1.62048340e-02,   1.60522461e-02],
                        [  1.11694336e-02,   1.10168457e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [ -1.31225586e-03,  -1.15966797e-03],
                        [ -4.05883789e-03,  -3.90625000e-03],
                        [ -3.90625000e-03,  -3.87573242e-03],
                        [ -2.71606445e-03,  -2.83813477e-03],
                        [ -1.09863281e-03,  -1.25122070e-03],
                        [ -6.10351562e-05,  -9.15527344e-05],
                        [ -3.23486328e-03,  -3.11279297e-03],
                        [ -1.25122070e-02,  -1.23596191e-02],
                        [ -2.40173340e-02,  -2.39562988e-02],
                        [ -3.14941406e-02,  -3.16162109e-02],
                        [ -3.24401855e-02,  -3.25927734e-02],
                        [ -2.88696289e-02,  -2.89306641e-02],
                        [ -2.48718262e-02,  -2.47802734e-02],
                        [ -2.39868164e-02,  -2.38037109e-02],
                        [ -2.65808105e-02,  -2.65197754e-02],
                        [ -3.03955078e-02,  -3.04870605e-02],
                        [ -3.39660645e-02,  -3.41186523e-02],
                        [ -3.57360840e-02,  -3.57971191e-02],
                        [ -3.18298340e-02,  -3.17687988e-02],
                        [ -1.94091797e-02,  -1.92565918e-02],
                        [ -9.15527344e-04,  -8.54492188e-04],
                        [  1.66015625e-02,   1.65405273e-02],
                        [  2.75268555e-02,   2.74047852e-02],
                        [  3.17382812e-02,   3.16467285e-02],
                        [  2.92663574e-02,   2.93273926e-02],
                        [  1.48925781e-02,   1.50451660e-02],
                        [ -1.66320801e-02,  -1.65405273e-02],
                        [ -6.10961914e-02,  -6.11267090e-02],
                        [ -1.03057861e-01,  -1.03179932e-01],
                        [ -1.25061035e-01,  -1.25152588e-01],
                        [ -1.20117188e-01,  -1.20056152e-01],
                        [ -9.30786133e-02,  -9.29565430e-02],
                        [ -5.55725098e-02,  -5.54809570e-02],
                        [ -2.28881836e-02,  -2.29187012e-02],
                        [ -4.39453125e-03,  -4.51660156e-03],
                        [  6.92749023e-03,   6.83593750e-03],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  6.07604980e-02,   6.08825684e-02],
                        [  1.08947754e-01,   1.09039307e-01],
                        [  1.59118652e-01,   1.59118652e-01],
                        [  1.92016602e-01,   1.91925049e-01],
                        [  1.89910889e-01,   1.89819336e-01],
                        [  1.43951416e-01,   1.43951416e-01],
                        [  5.31005859e-02,   5.31921387e-02],
                        [ -7.33337402e-02,  -7.32116699e-02],
                        [ -2.10205078e-01,  -2.10205078e-01],
                        [ -3.21838379e-01,  -3.21929932e-01],
                        [ -3.77655029e-01,  -3.77746582e-01],
                        [ -3.68164062e-01,  -3.68164062e-01],
                        [ -3.12927246e-01,  -3.12835693e-01],
                        [ -2.49237061e-01,  -2.49114990e-01],
                        [ -2.02911377e-01,  -2.02911377e-01],
                        [ -1.69647217e-01,  -1.69738770e-01],
                        [ -1.26922607e-01,  -1.27044678e-01],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [  1.98059082e-02,   1.98669434e-02],
                        [  9.21020508e-02,   9.22241211e-02],
                        [  1.35375977e-01,   1.35406494e-01],
                        [  1.49169922e-01,   1.49108887e-01],
                        [  1.51306152e-01,   1.51184082e-01],
                        [  1.55792236e-01,   1.55731201e-01],
                        [  1.60766602e-01,   1.60827637e-01],
                        [  1.56890869e-01,   1.56982422e-01],
                        [  1.38610840e-01,   1.38671875e-01],
                        [  1.09893799e-01,   1.09832764e-01],
                        [  8.13903809e-02,   8.12683105e-02],
                        [  6.01196289e-02,   6.00891113e-02],
                        [  4.50439453e-02,   4.51049805e-02],
                        [  3.12500000e-02,   3.13720703e-02],
                        [  1.49841309e-02,   1.50146484e-02],
                        [ -1.22070312e-03,  -1.25122070e-03],
                        [ -7.41577148e-03,  -7.50732422e-03],
                        [  3.44848633e-03,   3.38745117e-03],
                        [  2.62145996e-02,   2.62451172e-02],
                        [  4.93469238e-02,   4.94384766e-02],
                        [  6.83288574e-02,   6.83898926e-02],
                        [  8.55407715e-02,   8.55102539e-02],
                        [  9.92126465e-02,   9.91210938e-02],
                        [  1.04431152e-01,   1.04370117e-01],
                        [  1.02447510e-01,   1.02478027e-01],
                        [  9.61608887e-02,   9.62524414e-02],
                        [  8.26110840e-02,   8.26721191e-02],
                        [  6.10351562e-02,   6.10046387e-02],
                        [  3.93676758e-02,   3.93066406e-02],
                        [  2.45971680e-02,   2.45361328e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.65502930e-03,   2.74658203e-03],
                        [ -1.08337402e-02,  -1.07727051e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.63977051e-02,  -2.64587402e-02],
                        [ -2.89611816e-02,  -2.90527344e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.33459473e-02,  -2.32849121e-02],
                        [ -1.44958496e-02,  -1.44348145e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -5.18798828e-04,  -5.79833984e-04],
                        [  1.40075684e-02,   1.39465332e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  4.11987305e-02,   4.12597656e-02],
                        [  4.22973633e-02,   4.23583984e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.40576172e-02,   3.40270996e-02],
                        [  2.41394043e-02,   2.40783691e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [ -5.18798828e-04,  -4.88281250e-04],
                        [ -5.92041016e-03,  -5.85937500e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -5.49316406e-03,  -5.55419922e-03],
                        [ -7.44628906e-03,  -7.50732422e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -2.38037109e-02,  -2.37426758e-02],
                        [ -3.24401855e-02,  -3.23791504e-02],
                        [ -3.52478027e-02,  -3.52172852e-02],
                        [ -3.17077637e-02,  -3.17687988e-02],
                        [ -2.58178711e-02,  -2.58789062e-02],
                        [ -2.06604004e-02,  -2.06909180e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -1.36718750e-02,  -1.36413574e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -2.40783691e-02,  -2.41088867e-02],
                        [ -3.10363770e-02,  -3.10974121e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.20849609e-02,  -1.20239258e-02],
                        [ -3.96728516e-03,  -3.93676758e-03],
                        [  7.01904297e-03,   6.98852539e-03],
                        [  1.98669434e-02,   1.98364258e-02],
                        [  2.87170410e-02,   2.86865234e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  1.99279785e-02,   1.99890137e-02],
                        [ -3.81469727e-03,  -3.78417969e-03],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -9.31396484e-02,  -9.32006836e-02],
                        [ -1.33361816e-01,  -1.33392334e-01],
                        [ -1.46942139e-01,  -1.46942139e-01],
                        [ -1.28448486e-01,  -1.28387451e-01],
                        [ -8.76159668e-02,  -8.75854492e-02],
                        [ -4.35180664e-02,  -4.35485840e-02],
                        [ -1.07727051e-02,  -1.08337402e-02],
                        [  1.14746094e-02,   1.14440918e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  7.00988770e-02,   7.01293945e-02],
                        [  1.16149902e-01,   1.16180420e-01],
                        [  1.62170410e-01,   1.62170410e-01],
                        [  1.92443848e-01,   1.92413330e-01],
                        [  1.92749023e-01,   1.92718506e-01],
                        [  1.51306152e-01,   1.51306152e-01],
                        [  6.13098145e-02,   6.13403320e-02],
                        [ -7.08007812e-02,  -7.07702637e-02],
                        [ -2.17895508e-01,  -2.17895508e-01],
                        [ -3.37860107e-01,  -3.37890625e-01],
                        [ -3.94714355e-01,  -3.94744873e-01],
                        [ -3.79547119e-01,  -3.79547119e-01],
                        [ -3.15551758e-01,  -3.15521240e-01],
                        [ -2.42858887e-01,  -2.42828369e-01],
                        [ -1.91131592e-01,  -1.91101074e-01],
                        [ -1.59179688e-01,  -1.59210205e-01],
                        [ -1.22192383e-01,  -1.22222900e-01],
                        [ -6.11572266e-02,  -6.11877441e-02],
                        [  1.55334473e-02,   1.55639648e-02],
                        [  8.24890137e-02,   8.25195312e-02],
                        [  1.21948242e-01,   1.21978760e-01],
                        [  1.35131836e-01,   1.35101318e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.38946533e-01,   1.38946533e-01],
                        [  1.44714355e-01,   1.44744873e-01],
                        [  1.44592285e-01,   1.44622803e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.14593506e-01,   1.14562988e-01],
                        [  9.57641602e-02,   9.57336426e-02],
                        [  7.62329102e-02,   7.62329102e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  3.44238281e-02,   3.44543457e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.55639648e-02,   1.55334473e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.66015625e-02,   1.65710449e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  6.11877441e-02,   6.12182617e-02],
                        [  7.47985840e-02,   7.47985840e-02],
                        [  8.48388672e-02,   8.48083496e-02],
                        [  8.98742676e-02,   8.98742676e-02],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  7.25708008e-02,   7.25708008e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -2.13623047e-02,  -2.13317871e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [  1.52587891e-04,   1.83105469e-04],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  3.48510742e-02,   3.48815918e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  6.80541992e-03,   6.80541992e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -7.75146484e-03,  -7.78198242e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.91650391e-02,  -1.91345215e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -7.33947754e-02,  -7.33947754e-02],
                        [ -9.88769531e-02,  -9.88769531e-02],
                        [ -1.02752686e-01,  -1.02752686e-01],
                        [ -8.44421387e-02,  -8.44421387e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  1.40594482e-01,   1.40594482e-01],
                        [  1.67938232e-01,   1.67938232e-01],
                        [  1.69982910e-01,   1.69982910e-01],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  3.84826660e-02,   3.84826660e-02],
                        [ -8.66394043e-02,  -8.66394043e-02],
                        [ -2.16400146e-01,  -2.16400146e-01],
                        [ -3.15307617e-01,  -3.15307617e-01],
                        [ -3.56506348e-01,  -3.56506348e-01],
                        [ -3.34960938e-01,  -3.34960938e-01],
                        [ -2.74139404e-01,  -2.74139404e-01],
                        [ -2.12463379e-01,  -2.12463379e-01],
                        [ -1.72119141e-01,  -1.72119141e-01],
                        [ -1.42883301e-01,  -1.42883301e-01],
                        [ -1.01501465e-01,  -1.01501465e-01],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.36627197e-01,   1.36627197e-01],
                        [  1.48193359e-01,   1.48193359e-01],
                        [  1.43615723e-01,   1.43615723e-01],
                        [  1.26708984e-01,   1.26708984e-01],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -8.15734863e-02,  -8.15734863e-02],
                        [ -7.82165527e-02,  -7.82165527e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  1.39282227e-01,   1.39282227e-01],
                        [  1.66992188e-01,   1.66992188e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  8.81958008e-03,   8.81958008e-03],
                        [ -1.18072510e-01,  -1.18072510e-01],
                        [ -2.44293213e-01,  -2.44293213e-01],
                        [ -3.39111328e-01,  -3.39111328e-01],
                        [ -3.79119873e-01,  -3.79119873e-01],
                        [ -3.61663818e-01,  -3.61663818e-01],
                        [ -3.08044434e-01,  -3.08044434e-01],
                        [ -2.46673584e-01,  -2.46673584e-01],
                        [ -1.91619873e-01,  -1.91650391e-01],
                        [ -1.37481689e-01,  -1.37481689e-01],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  1.34002686e-01,   1.34002686e-01],
                        [  1.46118164e-01,   1.46118164e-01],
                        [  1.34429932e-01,   1.34429932e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  6.74743652e-02,   6.74743652e-02],
                        [  4.53796387e-02,   4.53796387e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  7.73010254e-02,   7.73010254e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  1.83410645e-02,   1.83715820e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  2.96020508e-03,   2.92968750e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -8.95690918e-02,  -8.95690918e-02],
                        [ -8.76159668e-02,  -8.76159668e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  1.58477783e-01,   1.58477783e-01],
                        [  1.85180664e-01,   1.85180664e-01],
                        [  1.71264648e-01,   1.71264648e-01],
                        [  1.06842041e-01,   1.06842041e-01],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.49841309e-01,  -1.49841309e-01],
                        [ -2.87963867e-01,  -2.87963867e-01],
                        [ -3.79943848e-01,  -3.79943848e-01],
                        [ -4.05029297e-01,  -4.05029297e-01],
                        [ -3.70208740e-01,  -3.70208740e-01],
                        [ -3.01513672e-01,  -3.01513672e-01],
                        [ -2.29125977e-01,  -2.29125977e-01],
                        [ -1.70288086e-01,  -1.70288086e-01],
                        [ -1.19201660e-01,  -1.19201660e-01],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  8.85620117e-02,   8.85620117e-02],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.35437012e-01,   1.35437012e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.19018555e-01,   1.19018555e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  1.09924316e-01,   1.09924316e-01],
                        [  9.54895020e-02,   9.54895020e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  6.13708496e-02,   6.13708496e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  7.06481934e-02,   7.06481934e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  7.22351074e-02,   7.22656250e-02],
                        [  6.38427734e-02,   6.38122559e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.52282715e-02,  -1.52587891e-02],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -9.57946777e-02,  -9.57946777e-02],
                        [ -8.78295898e-02,  -8.78295898e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  1.40045166e-01,   1.40045166e-01],
                        [  1.69097900e-01,   1.69097900e-01],
                        [  1.69433594e-01,   1.69433594e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  4.05273438e-02,   4.05273438e-02],
                        [ -8.50830078e-02,  -8.50830078e-02],
                        [ -2.21252441e-01,  -2.21252441e-01],
                        [ -3.30322266e-01,  -3.30322266e-01],
                        [ -3.80645752e-01,  -3.80645752e-01],
                        [ -3.64318848e-01,  -3.64318848e-01],
                        [ -3.02581787e-01,  -3.02581787e-01],
                        [ -2.30743408e-01,  -2.30743408e-01],
                        [ -1.72210693e-01,  -1.72210693e-01],
                        [ -1.24816895e-01,  -1.24816895e-01],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  9.07897949e-02,   9.07897949e-02],
                        [  8.14208984e-02,   8.13903809e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  5.68847656e-02,   5.68542480e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  9.45129395e-02,   9.45129395e-02],
                        [  9.09423828e-02,   9.09118652e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  6.85729980e-02,   6.85729980e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  1.66015625e-02,   1.66320801e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [ -1.86462402e-02,  -1.86157227e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  1.10107422e-01,   1.10107422e-01],
                        [  1.33697510e-01,   1.33697510e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.08337402e-01,   1.08337402e-01],
                        [  3.69873047e-02,   3.69873047e-02],
                        [ -7.59887695e-02,  -7.59887695e-02],
                        [ -2.07977295e-01,  -2.07977295e-01],
                        [ -3.15948486e-01,  -3.15948486e-01],
                        [ -3.62060547e-01,  -3.62091064e-01],
                        [ -3.41491699e-01,  -3.41491699e-01],
                        [ -2.81982422e-01,  -2.81982422e-01],
                        [ -2.18811035e-01,  -2.18811035e-01],
                        [ -1.71936035e-01,  -1.71936035e-01],
                        [ -1.38122559e-01,  -1.38122559e-01],
                        [ -9.94873047e-02,  -9.94873047e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  8.05664062e-02,   8.05358887e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  8.63342285e-02,   8.63647461e-02],
                        [  1.05743408e-01,   1.05712891e-01],
                        [  1.29821777e-01,   1.29821777e-01],
                        [  1.42181396e-01,   1.42181396e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.24511719e-01,   1.24511719e-01],
                        [  1.08398438e-01,   1.08398438e-01],
                        [  9.05761719e-02,   9.05761719e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [  1.06201172e-02,   1.06506348e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  7.55310059e-02,   7.55615234e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -9.27734375e-03,  -9.30786133e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  1.83105469e-03,   1.86157227e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.05895996e-02,  -1.06201172e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  6.40869141e-03,   6.43920898e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -5.85632324e-02,  -5.85632324e-02],
                        [ -7.20214844e-02,  -7.20214844e-02],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -6.56127930e-02,  -6.56127930e-02],
                        [ -2.83508301e-02,  -2.83203125e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  1.45874023e-01,   1.45874023e-01],
                        [  1.63085938e-01,   1.63085938e-01],
                        [  1.57714844e-01,   1.57714844e-01],
                        [  1.17858887e-01,   1.17858887e-01],
                        [  3.31420898e-02,   3.31420898e-02],
                        [ -9.48181152e-02,  -9.48181152e-02],
                        [ -2.41638184e-01,  -2.41638184e-01],
                        [ -3.63647461e-01,  -3.63647461e-01],
                        [ -4.21966553e-01,  -4.21966553e-01],
                        [ -4.06585693e-01,  -4.06585693e-01],
                        [ -3.39050293e-01,  -3.39050293e-01],
                        [ -2.56011963e-01,  -2.56011963e-01],
                        [ -1.83227539e-01,  -1.83227539e-01],
                        [ -1.19354248e-01,  -1.19354248e-01],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  1.47583008e-01,   1.47583008e-01],
                        [  1.49536133e-01,   1.49536133e-01],
                        [  1.30462646e-01,   1.30462646e-01],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  9.14916992e-02,   9.14916992e-02],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  6.89086914e-02,   6.88781738e-02],
                        [  6.51855469e-02,   6.52160645e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  4.73022461e-02,   4.72717285e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  4.67529297e-02,   4.67224121e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  4.74853516e-02,   4.75158691e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.34375000e-02,   2.34069824e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.23693848e-02,   2.23999023e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  3.02124023e-03,   2.99072266e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -5.03540039e-03,  -5.06591797e-03],
                        [ -9.03320312e-03,  -9.00268555e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -4.10766602e-02,  -4.10766602e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -1.53198242e-02,  -1.52893066e-02],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  6.77490234e-03,   6.80541992e-03],
                        [  9.15527344e-03,   9.12475586e-03],
                        [  4.66918945e-03,   4.63867188e-03],
                        [ -1.23596191e-02,  -1.23291016e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  9.33227539e-02,   9.33227539e-02],
                        [  1.33239746e-01,   1.33239746e-01],
                        [  1.67175293e-01,   1.67175293e-01],
                        [  1.82098389e-01,   1.82098389e-01],
                        [  1.58233643e-01,   1.58233643e-01],
                        [  7.68737793e-02,   7.68432617e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -2.22625732e-01,  -2.22625732e-01],
                        [ -3.52783203e-01,  -3.52783203e-01],
                        [ -4.13543701e-01,  -4.13543701e-01],
                        [ -3.99780273e-01,  -3.99780273e-01],
                        [ -3.36914062e-01,  -3.36914062e-01],
                        [ -2.63397217e-01,  -2.63397217e-01],
                        [ -2.04650879e-01,  -2.04650879e-01],
                        [ -1.56433105e-01,  -1.56433105e-01],
                        [ -9.84802246e-02,  -9.84802246e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  7.32116699e-02,   7.32116699e-02],
                        [  7.96508789e-02,   7.96508789e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  1.17004395e-01,   1.16973877e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  5.73120117e-02,   5.72814941e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  6.98852539e-03,   6.98852539e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.72216797e-02,   2.71911621e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.56860352e-02,   1.57165527e-02],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -4.79125977e-02,  -4.78820801e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -7.95898438e-02,  -7.95898438e-02],
                        [ -9.04235840e-02,  -9.04235840e-02],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -8.12683105e-02,  -8.12683105e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  5.23071289e-02,   5.23376465e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -6.36291504e-02,  -6.35986328e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -1.09619141e-01,  -1.09619141e-01],
                        [ -2.27233887e-01,  -2.27203369e-01],
                        [ -3.17901611e-01,  -3.17901611e-01],
                        [ -3.49792480e-01,  -3.49792480e-01],
                        [ -3.20007324e-01,  -3.20007324e-01],
                        [ -2.54394531e-01,  -2.54394531e-01],
                        [ -1.87683105e-01,  -1.87683105e-01],
                        [ -1.38305664e-01,  -1.38305664e-01],
                        [ -9.90600586e-02,  -9.90600586e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  8.43811035e-02,   8.43811035e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  7.06481934e-02,   7.06481934e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  6.44531250e-02,   6.44836426e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  8.93554688e-02,   8.93554688e-02],
                        [  9.45129395e-02,   9.45129395e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  7.80334473e-02,   7.80334473e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  3.32641602e-03,   3.35693359e-03],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.28784180e-02,  -1.29089355e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  5.02929688e-02,   5.02624512e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  9.46044922e-04,   9.15527344e-04],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -2.10571289e-03,  -2.13623047e-03],
                        [ -6.16455078e-03,  -6.13403320e-03],
                        [ -1.31530762e-02,  -1.31225586e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -4.75158691e-02,  -4.75463867e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  5.05981445e-02,   5.06286621e-02],
                        [  5.69763184e-02,   5.69458008e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  2.46276855e-02,   2.46582031e-02],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.52685547e-02,  -2.52380371e-02],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -1.62902832e-01,  -1.62902832e-01],
                        [ -2.77404785e-01,  -2.77404785e-01],
                        [ -3.57208252e-01,  -3.57208252e-01],
                        [ -3.75213623e-01,  -3.75213623e-01],
                        [ -3.35510254e-01,  -3.35510254e-01],
                        [ -2.66845703e-01,  -2.66845703e-01],
                        [ -1.98455811e-01,  -1.98455811e-01],
                        [ -1.42883301e-01,  -1.42883301e-01],
                        [ -9.45434570e-02,  -9.45434570e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  5.35583496e-02,   5.35583496e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  1.02020264e-01,   1.02020264e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.03332520e-01,   1.03332520e-01],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  6.89392090e-02,   6.89392090e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  5.22460938e-02,   5.22155762e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  2.44140625e-02,   2.44445801e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  3.17993164e-02,   3.17687988e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  1.67846680e-02,   1.67541504e-02],
                        [  2.38952637e-02,   2.38647461e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.39465332e-02,   1.39160156e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.96728516e-02,   3.96423340e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -4.48608398e-03,  -4.51660156e-03],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -2.59094238e-02,  -2.58789062e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -4.35485840e-02,  -4.35791016e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -3.51257324e-02,  -3.51562500e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [  2.92968750e-03,   2.89916992e-03],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  8.29772949e-02,   8.29772949e-02],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.29486084e-01,   1.29486084e-01],
                        [  1.38854980e-01,   1.38854980e-01],
                        [  1.34765625e-01,   1.34765625e-01],
                        [  1.12213135e-01,   1.12213135e-01],
                        [  6.06384277e-02,   6.06689453e-02],
                        [ -2.89916992e-02,  -2.90222168e-02],
                        [ -1.47552490e-01,  -1.47521973e-01],
                        [ -2.60711670e-01,  -2.60711670e-01],
                        [ -3.28308105e-01,  -3.28308105e-01],
                        [ -3.31359863e-01,  -3.31359863e-01],
                        [ -2.84240723e-01,  -2.84210205e-01],
                        [ -2.23449707e-01,  -2.23449707e-01],
                        [ -1.77886963e-01,  -1.77886963e-01],
                        [ -1.46759033e-01,  -1.46759033e-01],
                        [ -1.09100342e-01,  -1.09100342e-01],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  6.83593750e-02,   6.83288574e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  1.04980469e-01,   1.05010986e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  1.19689941e-01,   1.19689941e-01],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  8.67614746e-02,   8.67309570e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  3.91235352e-02,   3.90930176e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.82189941e-02,   1.81884766e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  9.42993164e-03,   9.42993164e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [ -2.41088867e-03,  -2.38037109e-03],
                        [ -8.69750977e-03,  -8.72802734e-03],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.65405273e-02,  -1.65100098e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.72729492e-02,   1.73034668e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.69665527e-02,  -4.69970703e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -3.78417969e-02,  -3.78723145e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -4.45556641e-02,  -4.45861816e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -5.65490723e-02,  -5.65490723e-02],
                        [ -4.91943359e-02,  -4.92248535e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -1.26647949e-02,  -1.26953125e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  5.88989258e-03,   5.92041016e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.24816895e-02,  -1.24511719e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  1.38549805e-01,   1.38549805e-01],
                        [  1.75170898e-01,   1.75170898e-01],
                        [  1.97998047e-01,   1.97998047e-01],
                        [  1.95861816e-01,   1.95831299e-01],
                        [  1.55273438e-01,   1.55273438e-01],
                        [  6.85729980e-02,   6.85729980e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -1.92443848e-01,  -1.92443848e-01],
                        [ -3.07830811e-01,  -3.07830811e-01],
                        [ -3.72833252e-01,  -3.72833252e-01],
                        [ -3.77471924e-01,  -3.77471924e-01],
                        [ -3.36914062e-01,  -3.36914062e-01],
                        [ -2.79632568e-01,  -2.79632568e-01],
                        [ -2.24243164e-01,  -2.24243164e-01],
                        [ -1.68792725e-01,  -1.68792725e-01],
                        [ -1.03637695e-01,  -1.03637695e-01],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  9.31701660e-02,   9.31701660e-02],
                        [  1.17034912e-01,   1.17065430e-01],
                        [  1.19079590e-01,   1.19079590e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  8.17871094e-02,   8.17871094e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  7.17163086e-03,   7.14111328e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.04663086e-02,   4.04968262e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -1.94091797e-02,  -1.93786621e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  1.33056641e-02,   1.32751465e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.01818848e-02,   3.02124023e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.59802246e-02,   3.60107422e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -5.25207520e-02,  -5.25207520e-02],
                        [ -6.73828125e-02,  -6.73828125e-02],
                        [ -6.82678223e-02,  -6.82678223e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -5.05981445e-02,  -5.05676270e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  3.49731445e-02,   3.50036621e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.31256104e-01,   1.31256104e-01],
                        [  1.49139404e-01,   1.49139404e-01],
                        [  1.53045654e-01,   1.53045654e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -2.14874268e-01,  -2.14874268e-01],
                        [ -3.17535400e-01,  -3.17535400e-01],
                        [ -3.76251221e-01,  -3.76251221e-01],
                        [ -3.77044678e-01,  -3.77044678e-01],
                        [ -3.29284668e-01,  -3.29254150e-01],
                        [ -2.60589600e-01,  -2.60620117e-01],
                        [ -1.96990967e-01,  -1.96990967e-01],
                        [ -1.44165039e-01,  -1.44165039e-01],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  9.29565430e-02,   9.29565430e-02],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  8.61206055e-02,   8.61206055e-02],
                        [  7.44934082e-02,   7.44628906e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  9.52148438e-03,   9.55200195e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  6.75659180e-02,   6.75354004e-02],
                        [  5.89904785e-02,   5.90209961e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  2.19726562e-03,   2.22778320e-03],
                        [  1.61743164e-03,   1.58691406e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -1.76391602e-02,  -1.76086426e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -9.64355469e-03,  -9.61303711e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  2.74963379e-02,   2.75268555e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.67944336e-02,  -2.68249512e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -7.44628906e-03,  -7.41577148e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -4.67529297e-02,  -4.67834473e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  9.58251953e-03,   9.55200195e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.11694336e-02,   1.11999512e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  6.71386719e-02,   6.71691895e-02],
                        [  9.34143066e-02,   9.34143066e-02],
                        [  1.19049072e-01,   1.19018555e-01],
                        [  1.33117676e-01,   1.33148193e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  7.57751465e-02,   7.57446289e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.27105713e-01,  -1.27105713e-01],
                        [ -2.39898682e-01,  -2.39898682e-01],
                        [ -3.15826416e-01,  -3.15826416e-01],
                        [ -3.35723877e-01,  -3.35723877e-01],
                        [ -3.07464600e-01,  -3.07464600e-01],
                        [ -2.58056641e-01,  -2.58056641e-01],
                        [ -2.12005615e-01,  -2.12005615e-01],
                        [ -1.75994873e-01,  -1.75994873e-01],
                        [ -1.40502930e-01,  -1.40502930e-01],
                        [ -9.30175781e-02,  -9.30175781e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  9.85107422e-02,   9.85107422e-02],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.08917236e-01,   1.08886719e-01],
                        [  8.48388672e-02,   8.48388672e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.49023438e-02,  -2.48718262e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [  1.70898438e-03,   1.67846680e-03],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  6.10656738e-02,   6.10351562e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.56347656e-03,   2.53295898e-03],
                        [  1.86157227e-03,   1.89208984e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  1.37329102e-03,   1.40380859e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -1.28173828e-03,  -1.31225586e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -5.99060059e-02,  -5.99060059e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -2.54821777e-02,  -2.55126953e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.71398926e-02,   3.71093750e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  9.78393555e-02,   9.78393555e-02],
                        [  1.16790771e-01,   1.16790771e-01],
                        [  1.20239258e-01,   1.20269775e-01],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  2.27355957e-02,   2.27050781e-02],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -1.94610596e-01,  -1.94610596e-01],
                        [ -2.85095215e-01,  -2.85095215e-01],
                        [ -3.26293945e-01,  -3.26293945e-01],
                        [ -3.11645508e-01,  -3.11645508e-01],
                        [ -2.62786865e-01,  -2.62786865e-01],
                        [ -2.14080811e-01,  -2.14080811e-01],
                        [ -1.83807373e-01,  -1.83807373e-01],
                        [ -1.63574219e-01,  -1.63574219e-01],
                        [ -1.34185791e-01,  -1.34185791e-01],
                        [ -8.61206055e-02,  -8.60900879e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [  3.21960449e-02,   3.21655273e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  9.39025879e-02,   9.39025879e-02],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  1.08520508e-01,   1.08551025e-01],
                        [  1.12548828e-01,   1.12548828e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  6.82678223e-02,   6.82678223e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [ -4.82177734e-03,  -4.85229492e-03],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  4.50744629e-02,   4.50439453e-02],
                        [  5.93872070e-02,   5.93872070e-02],
                        [  6.99157715e-02,   6.99462891e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -6.50024414e-03,  -6.46972656e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  4.10461426e-02,   4.10766602e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -2.32238770e-02,  -2.31933594e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.38037109e-02,  -2.37731934e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  3.47900391e-03,   3.44848633e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -3.23486328e-03,  -3.26538086e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -1.22070312e-03,  -1.25122070e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -1.12915039e-02,  -1.12609863e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  2.85034180e-02,   2.85339355e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  7.08312988e-02,   7.08007812e-02],
                        [  8.45031738e-02,   8.45336914e-02],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  1.21704102e-01,   1.21734619e-01],
                        [  1.31713867e-01,   1.31713867e-01],
                        [  1.24969482e-01,   1.24969482e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -1.62841797e-01,  -1.62841797e-01],
                        [ -2.47253418e-01,  -2.47283936e-01],
                        [ -2.94799805e-01,  -2.94769287e-01],
                        [ -2.98797607e-01,  -2.98828125e-01],
                        [ -2.72491455e-01,  -2.72491455e-01],
                        [ -2.36419678e-01,  -2.36389160e-01],
                        [ -2.02789307e-01,  -2.02789307e-01],
                        [ -1.69952393e-01,  -1.69952393e-01],
                        [ -1.26983643e-01,  -1.26953125e-01],
                        [ -6.73522949e-02,  -6.73522949e-02],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  8.48388672e-02,   8.48693848e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  9.34143066e-02,   9.34143066e-02],
                        [  8.29162598e-02,   8.29162598e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  4.10461426e-02,   4.10766602e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  5.54199219e-02,   5.54504395e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.58996582e-02,   1.59301758e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  4.79125977e-03,   4.82177734e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -4.66918945e-03,  -4.63867188e-03],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  1.52282715e-02,   1.51977539e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  3.54309082e-02,   3.54003906e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  7.17163086e-03,   7.14111328e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -5.09643555e-03,  -5.12695312e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.87072754e-02,  -1.87377930e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  6.46972656e-03,   6.43920898e-03],
                        [  1.30920410e-02,   1.30615234e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  4.30297852e-03,   4.30297852e-03],
                        [ -4.11987305e-03,  -4.15039062e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -3.07922363e-02,  -3.07617188e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -2.18811035e-02,  -2.19116211e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.20544434e-02,  -1.20849609e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.97448730e-02,   1.97753906e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  4.73327637e-02,   4.73632812e-02],
                        [  4.81262207e-02,   4.80957031e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  4.04052734e-02,   4.04357910e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  6.09741211e-02,   6.10046387e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  9.16442871e-02,   9.16442871e-02],
                        [  1.05224609e-01,   1.05224609e-01],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  7.37304688e-02,   7.37304688e-02],
                        [ -1.67846680e-03,  -1.64794922e-03],
                        [ -1.10534668e-01,  -1.10504150e-01],
                        [ -2.23236084e-01,  -2.23236084e-01],
                        [ -3.03497314e-01,  -3.03497314e-01],
                        [ -3.30871582e-01,  -3.30871582e-01],
                        [ -3.10791016e-01,  -3.10791016e-01],
                        [ -2.68249512e-01,  -2.68280029e-01],
                        [ -2.29339600e-01,  -2.29339600e-01],
                        [ -2.02423096e-01,  -2.02423096e-01],
                        [ -1.75476074e-01,  -1.75506592e-01],
                        [ -1.31896973e-01,  -1.31896973e-01],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [  0.00000000e+00,  -3.05175781e-05],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  9.08813477e-02,   9.09118652e-02],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  1.08276367e-01,   1.08276367e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.14410400e-01,   1.14379883e-01],
                        [  1.18255615e-01,   1.18255615e-01],
                        [  1.17767334e-01,   1.17767334e-01],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  6.33239746e-02,   6.32934570e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [ -6.10351562e-04,  -6.40869141e-04],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -1.34277344e-03,  -1.31225586e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  1.87683105e-02,   1.87988281e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -5.21850586e-03,  -5.18798828e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  8.69750977e-03,   8.66699219e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.59802246e-02,  -3.59497070e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.21960449e-02,  -3.22265625e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -2.99377441e-02,  -2.99682617e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.55944824e-02,  -1.56250000e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -6.50024414e-03,  -6.53076172e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  6.71386719e-03,   6.71386719e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -1.30004883e-02,  -1.30310059e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -7.41577148e-03,  -7.44628906e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  1.42822266e-02,   1.43127441e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.62036133e-02,   4.61730957e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  1.14440918e-01,   1.14471436e-01],
                        [  1.23077393e-01,   1.23107910e-01],
                        [  1.21368408e-01,   1.21368408e-01],
                        [  1.02142334e-01,   1.02142334e-01],
                        [  5.38940430e-02,   5.38940430e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -1.39190674e-01,  -1.39190674e-01],
                        [ -2.45849609e-01,  -2.45849609e-01],
                        [ -3.17016602e-01,  -3.17016602e-01],
                        [ -3.36425781e-01,  -3.36425781e-01],
                        [ -3.13629150e-01,  -3.13629150e-01],
                        [ -2.73254395e-01,  -2.73254395e-01],
                        [ -2.35839844e-01,  -2.35839844e-01],
                        [ -2.05352783e-01,  -2.05352783e-01],
                        [ -1.70898438e-01,  -1.70898438e-01],
                        [ -1.19812012e-01,  -1.19812012e-01],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [  1.15356445e-02,   1.15661621e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  1.18438721e-01,   1.18438721e-01],
                        [  1.24847412e-01,   1.24847412e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.20574951e-01,   1.20574951e-01],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  5.88378906e-02,   5.88378906e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.09252930e-02,  -1.08947754e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -2.04467773e-03,  -2.04467773e-03]],
                        dtype = numpy.float32)
))
